#
# spec file for package kernel-pae
#
# Copyright (c) 2019 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild
# This makes the OBS store the project cert as %_sourcedir/_projectcert.crt
# needssslcertforbuild

%define srcversion 3.0
%define patchversion 3.0.101
%define variant %{nil}

%include %_sourcedir/kernel-spec-macros

%define build_flavor	pae
%define build_kdump	(%build_flavor == "kdump")
%define build_xen	(%build_flavor == "xen" || %build_flavor == "ec2")
%define build_vanilla	(%build_flavor == "vanilla")
%define build_ps3	(%build_flavor == "ps3")

%define build_src_dir %my_builddir/linux-%srcversion
%define src_install_dir /usr/src/linux-%kernelrelease%variant
%define obj_install_dir %src_install_dir-obj
%define rpm_install_dir %buildroot%obj_install_dir
%define kernel_build_dir %my_builddir/linux-obj

%(chmod +x %_sourcedir/{guards,apply-patches,gen-hmacs,check-for-config-changes,built-in-where,symsets.pl,find-provides,split-modules,modversions,extract-modaliases,kabi.pl,mkspec,compute-PATCHVERSION.sh,arch-symbols,configtool.pl,log.sh})

%global cpu_arch %(%_sourcedir/arch-symbols %_target_cpu)
%define cpu_arch_flavor %cpu_arch/%build_flavor

# Define some CONFIG variables as rpm macros as well. (rpm cannot handle
# defining them all at once.)
%define config_vars CONFIG_MODULES CONFIG_MODULE_SIG CONFIG_KMSG_IDS CONFIG_SPLIT_PACKAGE CONFIG_ENTERPRISE_SUPPORT CONFIG_EFI_STUB
%{expand:%(eval "$(test -n "%cpu_arch_flavor" && tar -xjf %_sourcedir/config.tar.bz2 --to-stdout config/%cpu_arch_flavor)"; for config in %config_vars; do echo "%%global $config ${!config:-n}"; done)}
%define split_base (%CONFIG_SPLIT_PACKAGE == "y")
%define split_extra (%CONFIG_SPLIT_PACKAGE == "y" && %CONFIG_ENTERPRISE_SUPPORT == "y")

%ifarch s390 s390x
%if ! %build_vanilla
%define install_vdso 1
%else
%define install_vdso 0
%endif # ! %build_vanilla
%else
%ifarch %ix86 x86_64
%define install_vdso 1
%else
%define install_vdso 0
%endif # %ix86 x86_64
%endif # s390 s390x

Name:           kernel-pae
Summary:        Kernel with PAE Support
Version:        3.0.101
%if 0%{?is_kotd}
Release:        958.1.g7562272
%else
Release:        958.1
%endif
License:        GPL v2 only
Group:          System/Kernel
Url:            http://www.kernel.org/
BuildRequires:  coreutils module-init-tools sparse openssl
BuildRequires:  fdupes elfutils openssl
# Have the buildservice sign the kernel image (on x86_64), modules
# and firmware files
BuildRequires:  pesign-obs-integration
Provides:       multiversion(kernel)
Provides:       %{name}_%_target_cpu = %version-%release
%if %split_base
Requires:       %name-base_%_target_cpu = %version-%release
%endif
Requires(pre):  coreutils awk
# Need a module-init-tools with /usr/lib/module-init-tools/weak-modules2
Requires(post): module-init-tools >= 3.4
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for mkinitrd.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
Requires(post): mkinitrd
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release
# Do not install p-b and mkinitrd for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader mkinitrd distribution-release
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools m4 udev insserv

%ifarch ia64
# arch/ia64/scripts/unwcheck.py
BuildRequires:  python
%endif
%ifarch s390 s390x
%if %build_vanilla && 0%{?suse_version} < 1130
BuildRequires:  dwarfextract
%endif
%endif
%if %build_xen
#!BuildIgnore:  xen
%endif

%if %build_vanilla
# force bzip2 instead of lzma compression to allow install on older dist versions
%define _binary_payload w9.bzdio
%endif
# dead network if installed on SLES10, otherwise it will work (mostly)
Conflicts:      sysfsutils < 2.0
%if ! %build_vanilla
Conflicts:      apparmor-profiles <= 2.1
Conflicts:      apparmor-parser < 2.3
# root-lvm only works with newer udevs
Conflicts:      udev < 118
Conflicts:      lvm2 < 2.02.33
# Interface to hv_kvp_daemon changed
Conflicts:      hyper-v < 3
%endif
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
%ifarch %ix86
Provides:       kernel-bigsmp = 2.6.17
Obsoletes:      kernel-bigsmp <= 2.6.17
Provides:       kernel-vmi = 2.6.38
Obsoletes:      kernel-vmi <= 2.6.38
%endif

Source0:        http://www.kernel.org/pub/linux/kernel/v2.6/linux-%srcversion.tar.bz2
Source2:        source-post.sh
Source3:        kernel-source.rpmlintrc
Source8:        devel-pre.sh
Source9:        devel-post.sh
Source10:       preun.sh
Source11:       postun.sh
Source12:       pre.sh
Source13:       post.sh
Source14:       series.conf
Source16:       guards
Source17:       apply-patches
Source18:       gen-hmacs
Source21:       config.conf
Source23:       supported.conf
Source33:       check-for-config-changes
Source37:       README.SUSE
Source38:       README.KSYMS
Source39:       generic_serial-blacklist
Source40:       source-timestamp
Source41:       built-in-where
Source42:       built-in-where.mk
Source43:       symsets.pl
Source44:       find-provides
Source45:       split-modules
Source46:       modversions
Source47:       extract-modaliases
Source48:       macros.kernel-source
Source49:       kernel-module-subpackage
Source50:       kabi.pl
Source51:       mkspec
Source52:       kernel-source%variant.changes
Source53:       kernel-source.spec.in
Source54:       kernel-binary.spec.in
Source55:       kernel-syms.spec.in
Source56:       kernel-docs.spec.in
Source57:       kernel-cert-subpackage
Source58:       constraints.in
Source60:       config.sh
Source61:       compute-PATCHVERSION.sh
Source62:       old-flavors
Source63:       arch-symbols
Source64:       package-descriptions
Source65:       kernel-spec-macros
Source66:       configtool.pl
Source67:       log.sh
Source90:       SLES-UEFI-SIGN-Certificate-2048.crt
Source100:      config.tar.bz2
Source101:      config.addon.tar.bz2
Source102:      patches.arch.tar.bz2
Source103:      patches.drivers.tar.bz2
Source104:      patches.fixes.tar.bz2
Source105:      patches.rpmify.tar.bz2
Source106:      patches.suse.tar.bz2
Source107:      patches.xen.tar.bz2
Source108:      patches.addon.tar.bz2
Source109:      patches.kernel.org.tar.bz2
Source110:      patches.apparmor.tar.bz2
Source111:      patches.rt.tar.bz2
Source112:      patches.trace.tar.bz2
Source113:      patches.kabi.tar.bz2
Source114:      patches.drm.tar.bz2
Source115:      patches.ceph.tar.bz2
Source120:      kabi.tar.bz2
Source122:      modprobe-xen.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  %ix86

# These files are found in the kernel-source package:
NoSource:       0
NoSource:       100
NoSource:       101
NoSource:       102
NoSource:       103
NoSource:       104
NoSource:       105
NoSource:       106
NoSource:       107
NoSource:       108
NoSource:       109
NoSource:       110
NoSource:       111
NoSource:       112
NoSource:       113
NoSource:       114
NoSource:       115
NoSource:       120

# The following KMPs have been integrated into the kernel package,
# grouped by the last product that contained them.
# Usage: obsolete_kmp <basename> <upper bound of shipped versions>
# Note that KMPs embed the version of the kernel built against, that's why
# the _3 suffix for 2.6.x-based KMPs
%define obsolete_kmp() Obsoletes: %1-kmp-%build_flavor <= %2 \
Provides: %1-kmp = %2 \
Provides: %1-kmp-%build_flavor = %2
# sles10 / 10.3
%obsolete_kmp iwlwifi 1.3.27_3
%obsolete_kmp ipw3945 1.2.2_3
# sled10 / 11.0
%obsolete_kmp uvcvideo r200_3
# sle11-ga
%obsolete_kmp enic 0.0.1_3
%obsolete_kmp fnic 1.0.0_3
%obsolete_kmp brocade-bfa 1.1.0.2_3
%obsolete_kmp kvm 78.2.6.30.1_3
%obsolete_kmp perfmon 2_3
%obsolete_kmp iwlagn-2-6-27 1.0_3
%obsolete_kmp msi-wmi 1.0_3
# 11.1
%obsolete_kmp quickcam 0.6.7
# sle11-sp1
%obsolete_kmp wacom 0.8.1_3
%obsolete_kmp btrfs 0_3
%obsolete_kmp brocade-bna 2.1.0.0_3
%obsolete_kmp hyper-v 0_3
%obsolete_kmp intel-e1000e 2.2.14
%obsolete_kmp drm 3.7_3.1
Obsoletes:    firewire <= 3.0
Provides:     firewire = 3.0
%obsolete_kmp firewire 3.0
%obsolete_kmp iwlagn 3.0
Obsoletes:    compat-ath9k <= 3.0
Provides:     compat-ath9k = 3.0
%obsolete_kmp compat-ath9k 3.0
%obsolete_kmp realtek-r8192ce_pci 2.6.0005_3
%obsolete_kmp realtek-r8192se_pci 2.6.0019.1207.2010_3
%obsolete_kmp rt3090 2.4.0.4_3
%obsolete_kmp rt3592 2.4.1.1_3
%obsolete_kmp rt5390 2.4.0.4_3
%obsolete_kmp ath3k 1.0_3
Obsoletes:    ath3k-firmware <= 1.0
Provides:     ath3k-firmware = 1.0

# Provide the exported symbols as "ksym(symbol) = hash"
%define __find_provides %_sourcedir/find-provides %my_builddir %name

# Will modules not listed in supported.conf abort the kernel build (0/1)?
%define supported_modules_check 0

%description
This kernel supports up to 64GB of main memory. It requires Physical
Addressing Extensions (PAE), which were introduced with the Pentium Pro
processor.

PAE is not only more physical address space but also important for the
"no execute" feature which disables execution of code that is marked as
non-executable. Therefore, the PAE kernel should be used on any systems
that support it, regardless of the amount of main memory.


%source_timestamp
%prep
if ! [ -e %_sourcedir/linux-%srcversion.tar.bz2 ]; then
    echo "The %name-%version.nosrc.rpm package does not contain the" \
	 "complete sources. Please install kernel-source-%version.src.rpm."
    exit 1
fi

SYMBOLS=
if test -e %_sourcedir/extra-symbols; then
	SYMBOLS=$(cat %_sourcedir/extra-symbols)
	echo "extra symbol(s):" $SYMBOLS
fi

# Unpack all sources and patches
%setup -q -c -T -a 0 -a 100 -a 101 -a 102 -a 103 -a 104 -a 105 -a 106 -a 107 -a 108 -a 109 -a 110 -a 111 -a 112 -a 113 -a 114 -a 115 -a 120

mkdir -p %kernel_build_dir

# Generate a list of modules with their support status marking
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '
	/^\+(base|yes) / {
		print $(NF);
		next;
	}
	/^\+external / {
		print $(NF) " external";
		next;
	}
	/^[-+]/ {
		print $(NF) " no";
		next;
	}
	{
		print $(NF);
	}
' >%kernel_build_dir/Module.supported
%_sourcedir/guards --default=0 base < %_sourcedir/supported.conf | \
	sed 's,.*/,,; s,\.ko$,,' | sort -u >%kernel_build_dir/Module.base

cd linux-%srcversion

%_sourcedir/apply-patches \
%if %{build_vanilla}
	--vanilla \
%endif
	%_sourcedir/series.conf .. $SYMBOLS

cd %kernel_build_dir

if [ -f %_sourcedir/localversion ] ; then
    cat %_sourcedir/localversion > localversion
fi

if test -e ../config.addon/%cpu_arch_flavor; then
	# FIXME: config.addon doesn't affect the %CONFIG_ macros defined at
	# the top of the specfile
	%_sourcedir/configtool.pl ../config{,.addon}/%cpu_arch_flavor >.config
else
	cp ../config/%cpu_arch_flavor .config
fi
%build_src_dir/scripts/config \
	--set-str CONFIG_LOCALVERSION -%source_rel-%build_flavor \
	--enable  CONFIG_SUSE_KERNEL \
%if 0%{?__debug_package:1}
	--enable  CONFIG_DEBUG_INFO \
	--disable  CONFIG_DEBUG_INFO_REDUCED
%else
	--disable CONFIG_DEBUG_INFO
%endif

makeoutputsync=
if make --output-sync --help >/dev/null 2>&1 ; then
        makeoutputsync=--output-sync
else
        echo make does not support --output-sync flag. Build messages may be mangled. 1>&2
fi
MAKE_ARGS="$MAKE_ARGS %{?_smp_mflags} $makeoutputsync"

KERN_DIRS="-C %build_src_dir O=$PWD"
if test -e %_sourcedir/TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS; then
    yes '' | make oldconfig $MAKE_ARGS $KERN_DIRS
else
    cp .config .config.orig
    make silentoldconfig $MAKE_ARGS $KERN_DIRS < /dev/null
    %_sourcedir/check-for-config-changes .config.orig .config
    rm .config.orig
fi

make prepare $MAKE_ARGS
make scripts $MAKE_ARGS
krel=$(make -s kernelrelease $MAKE_ARGS)

if [ "$krel" != "%kernelrelease-%build_flavor" ]; then
    echo "Kernel release mismatch: $krel != %kernelrelease-%build_flavor" >&2
    exit 1
fi

make clean $MAKE_ARGS

rm -f source
find . ! -type d -printf '%%P\n' > %my_builddir/obj-files

# Override the timestamp 'uname -v' reports with the source timestamp and
# the commit hash.
date=$(head -n 1 %_sourcedir/source-timestamp)
commit=$(sed -n 's/GIT Revision: //p' %_sourcedir/source-timestamp)
cat > .kernel-binary.spec.buildenv <<EOF
export KBUILD_BUILD_TIMESTAMP="$(LANG=C date -d "$date") (${commit:0:7})"
export KBUILD_VERBOSE=0
export KBUILD_SYMTYPES=1
export KBUILD_OVERRIDE=1
export KBUILD_BUILD_USER=geeko
export KBUILD_BUILD_HOST=buildhost
export MAKE_ARGS="$MAKE_ARGS"
EOF

%build
cd %kernel_build_dir
source .kernel-binary.spec.buildenv

# create *.symref files in the tree
if test -e %my_builddir/kabi/%cpu_arch/symtypes-%build_flavor; then
    %_sourcedir/modversions --unpack . < $_
fi

# copy optional module signing files:
# *.x509, *.crt
#  - certificates with pubkeys used to verify module and firmware signatures
#    at runtime. *.crt files assumed to be in the PEM format.
# signing_key.priv
#  - unencrypted private key used to sign modules and firmware during build
# x509.genkey
#  - openssl req config to generate a new signing_key.{x509,priv} pair for the
#    build
for f in %_sourcedir/*.x509 %_sourcedir/{signing_key.priv,x509.genkey}; do
    if test -e "$f"; then
        cp "$f" .
    fi
done
for f in %_sourcedir/*.crt; do
    out=${f##*/}
    out=${out%.crt}.x509
    openssl x509 -inform PEM -in "$f" -outform DER -out "$out"
done
# Convince kernel/Makefile not to generate a new keypair
touch x509.genkey
touch signing_key.x509

# The %{_smp_mflags} macro is defined to a number, make will spawn that many jobs.
# There are several ways how to define it:
# If you are using the build script:
#     build --jobs=N kernel-$flavor.spec
# With plain rpmbuild:
#     rpmbuild -ba --define 'jobs N' kernel-$flavor.spec
# To spawn as many jobs as there are cpu cores:
#     rpmbuild -ba --define "%_smp_mflags -j 0$(grep -Ec 'cpu[0-9]' /proc/stat)" \
#         kernel-$flavor.spec
# You can also set this permanently in ~/.rpmmacros:
#     %_smp_mflags -j 0%(grep -Ec 'cpu[0-9]' /proc/stat)
%if %CONFIG_KMSG_IDS == "y"
    chmod +x ../linux-%srcversion/scripts/kmsg-doc
    MAKE_ARGS="$MAKE_ARGS D=2"
%endif
mkdir -p %_topdir/OTHER
log=%_topdir/OTHER/make-stderr.log
make all $MAKE_ARGS CONFIG_DEBUG_SECTION_MISMATCH=y 2> >(tee "$log")

%install

# sign the modules, firmware and possibly the kernel in the buildservice
export BRP_PESIGN_FILES="*.ko /lib/firmware"
%if %CONFIG_EFI_STUB == "y"
BRP_PESIGN_FILES="$BRP_PESIGN_FILES /boot/vmlinuz-%kernelrelease-%build_flavor"
%endif

# get rid of /usr/lib/rpm/brp-strip-debug
# strip removes too much from the vmlinux ELF binary
export NO_BRP_STRIP_DEBUG=true
export STRIP_KEEP_SYMTAB='*/vmlinux-*'

# /lib/modules/%kernelrelease-%build_flavor/build will be a stale symlink until the
# kernel-source package is installed. Don't check for stale symlinks
# in the brp-symlink check:
export NO_BRP_STALE_LINK_ERROR=yes

cd %kernel_build_dir

mkdir -p %buildroot/boot
# (Could strip out non-public symbols.)
cp -p System.map %buildroot/boot/System.map-%kernelrelease-%build_flavor

add_vmlinux()
{
    local vmlinux=boot/vmlinux-%kernelrelease-%build_flavor compressed=false

    if test $1 == "--compressed"; then
        compressed=true
    fi
    cp vmlinux %buildroot/$vmlinux
    >%my_builddir/vmlinux.debug.files
%if 0%{?__debug_package:1}
    if $compressed; then
        local vmlinux_debug=usr/lib/debug/$vmlinux.debug
        mkdir -p $(dirname %buildroot/$vmlinux_debug)
        local id=$(/usr/bin/eu-unstrip -n -e %buildroot/$vmlinux | \
            sed -rn 's/.* (.*)@.*/\1/p')
        /usr/lib/rpm/debugedit -b "$RPM_BUILD_DIR" -d /usr/src/debug \
            -l vmlinux.sourcefiles %buildroot/$vmlinux
        objcopy --only-keep-debug \
    	    %buildroot/$vmlinux \
    	    %buildroot/$vmlinux_debug || :
        objcopy --add-gnu-debuglink=%buildroot/$vmlinux_debug \
    	    --strip-debug \
    	    %buildroot/$vmlinux || :
        mkdir -p %buildroot/usr/src/debug
        LANG=C sort -z -u vmlinux.sourcefiles | grep -Ezv "<(built-in|stdin)>" \
    	| ( cd %_builddir && cpio -pd0m %buildroot/usr/src/debug )
        find %buildroot/usr/src/debug -type d -print0 | xargs -0 -r chmod 0755
        find %buildroot/usr/src/debug -type f -print0 | xargs -0 -r chmod 0644
        echo -e "%%defattr(-, root, root)\\n/$vmlinux_debug" >%my_builddir/vmlinux.debug.files
        # create and package build-id symlinks
        if [ -n "$id" -a "$id" != "-" ]; then
            local ldir="/usr/lib/debug/.build-id/${id:0:2}"
            local l="$ldir/${id:2}"
            mkdir -p %buildroot/$ldir
            # /boot/vmlinux-* is compressed, so this would be a dangling link:
            # ln -snf /$vmlinux %buildroot/$l
            # echo "/$l" >>%my_builddir/vmlinux.debug.files
            ln -snf ../../$vmlinux.debug %buildroot/$l.debug
            echo "/$l.debug" >>%my_builddir/vmlinux.debug.files
        fi
    else
        # make vmlinux executable so that find-debuginfo.sh picks it up
        # (TODO: fix find-debuginfo.sh instead)
        chmod +x %buildroot/$vmlinux
    fi
%endif
    if $compressed; then
	gzip -n -9 %buildroot/$vmlinux
        chmod a-x %buildroot/$vmlinux.gz
    fi
}

%if %build_kdump
    add_vmlinux
    image=vmlinux
%else

# architecture specifics
%ifarch %ix86 x86_64
    add_vmlinux --compressed
    image=bzImage
%if %build_xen
    test -f arch/x86/boot/$image || image=vmlinuz
%endif
    cp -p arch/x86/boot/$image %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinuz
%endif
%ifarch alpha
    add_vmlinux --compressed
    cp -p arch/alpha/boot/vmlinux.gz %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinuz
%endif
%ifarch ppc ppc64
    add_vmlinux
    image=vmlinux
%endif
%ifarch ia64
    add_vmlinux --compressed
    mv %buildroot/boot/vmlinux-%kernelrelease-%build_flavor.gz \
       %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinuz
%endif
%ifarch s390 s390x
    add_vmlinux --compressed
    cp -p arch/s390/boot/image %buildroot/boot/image-%kernelrelease-%build_flavor
    image=image
%if %CONFIG_KMSG_IDS == "y"
    mkdir -p %buildroot/usr/share/man/man9
    find man -name '*.9' -exec install -m 644 -D '{}' %buildroot/usr/share/man/man9/ ';'
%endif
%endif
%ifarch sparc64
    add_vmlinux --compressed
    image=zImage
    cp -p arch/sparc/boot/$image %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinux
%endif

# end of build_kdump
%endif

echo "/boot/$image-%kernelrelease-%build_flavor.hmac" >%my_builddir/hmac.files

# Package the compiled-in certificates as DER files in /etc/uefi/certs
# and have mokutil enroll them when the kernel is installed
certs=()
if test %CONFIG_MODULE_SIG = "y"; then
    for f in *.x509; do
            if ! test -s "$f"; then
                    continue
            fi
            h=$(openssl x509 -inform DER -fingerprint -noout -in "$f")
            test -n "$h"
            cert=/etc/uefi/certs/$(echo "$h" | \
                sed -rn 's/^SHA1 Fingerprint=//; T; s/://g; s/(.{8}).*/\1/p').crt
            if test -e %buildroot/"$cert"; then
                    continue
            fi
            mkdir -p %buildroot/etc/uefi/certs
            cp "$f" %buildroot/"$cert"
            certs=("${certs[@]}" "$cert")
    done
fi

# Install the frontend driver selector file for xen/ec2
%if %build_xen
mkdir -p %buildroot/etc/modprobe.d
cp %_sourcedir/modprobe-xen.conf %buildroot/etc/modprobe.d/50-xen.conf
%endif

for sub in '-base' '' '-extra'; do
    case "$sub" in
    '-base') base_package=1 ;;
%if ! %split_base
    '') base_package=1 ;;
%endif
    *) base_package=0 ;;
    esac
    for script in preun postun pre post devel-pre devel-post; do
        sed -e "s:@KERNELRELEASE@:%kernelrelease:g" \
            -e "s:@IMAGE@:$image:g" \
            -e "s:@FLAVOR""@:%build_flavor:g" \
            -e "s:@SUBPACKAGE@:%name$sub:g" \
            -e "s:@BASE_PACKAGE@:$base_package:g" \
            -e "s:@RPM_VERSION_RELEASE@:%version-%release:g" \
            -e "s:@RPM_TARGET_CPU@:%_target_cpu:g" \
	    -e "s:@CPU_ARCH_FLAVOR@:%cpu_arch_flavor:g" \
            -e "s:@SRCVARIANT@:%variant:g" \
            %_sourcedir/$script.sh > %my_builddir/$script$sub.sh
        if test "$base_package" -eq 1 -a "${#certs[@]}" -gt 0; then
            case "$script" in
            preun | postun | post)
                # Copy the respective scriptlet from kernel-cert-subpackage
                sed "1,/^%%$script / d; /^%%[^%%]/,\$ d; s:@CERTS@:${certs[*]}:g" \
                    %_sourcedir/kernel-cert-subpackage \
                    >>"%my_builddir/$script$sub.sh"
            esac
        fi
	# Do an exit 0 at the end of each scriptlet. If the last real command
	# in the scriptlet (e.g. update-bootloader call, see bnc#809617)
	# returns an error, we do not want to amplify the damage by leaving
	# the system in an inconsistent state.
	echo "exit 0" >>"%my_builddir/$script$sub.sh"
    done
done

%if %build_kdump || %build_xen || %build_vanilla || %build_ps3
# keep this -suffix list in sync with post.sh and postun.sh
suffix=-%build_flavor
%endif
ln -s $image$suffix %buildroot/boot/$image$suffix
ln -s initrd$suffix %buildroot/boot/initrd$suffix

cp -p .config %buildroot/boot/config-%kernelrelease-%build_flavor

%if %install_vdso
# Install the unstripped vdso's that are linked in the kernel image
make vdso_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot
%endif

# Create a dummy initrd with roughly the size the real one will have.
# That way, YaST will know that this package requires some additional
# space in /boot.
dd if=/dev/zero of=%buildroot/boot/initrd-%kernelrelease-%build_flavor \
	bs=1024 seek=2047 count=1

# Figure out where the symbols that vmlinux exports are defined.
%_sourcedir/built-in-where %{?jobs:-j%jobs} < Module.symvers > Module.symvers.split

if [ %CONFIG_MODULES = y ]; then
    mkdir -p %rpm_install_dir/%cpu_arch_flavor
    mkdir -p %buildroot/usr/src/linux-obj/%cpu_arch
    ln -s %build_flavor %buildroot/usr/src/linux-obj/%cpu_arch_flavor

    gzip -n -c9 < Module.symvers > %buildroot/boot/symvers-%kernelrelease-%build_flavor.gz

    make %{?_smp_mflags} modules_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot

    # Also put the resulting file in %rpm_install_dir/%cpu_arch/%build_flavor
    # so that kernel-source + kernel-%build_flavor is sufficient for building
    # modules that have modversions as well.
    mkdir -p %rpm_install_dir/%cpu_arch/%build_flavor
    cp Module.symvers %rpm_install_dir/%cpu_arch/%build_flavor

    # Table of types used in exported symbols (for modversion debugging).
    %_sourcedir/modversions --pack . > %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    if [ -s %buildroot/boot/symtypes-%kernelrelease-%build_flavor ]; then
	gzip -n -9 %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    else
	rm -f %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    fi

    # Some architecture's $(uname -m) output is different from the ARCH
    # parameter that needs to be passed to kbuild. Create symlinks from
    # $(uname -m) to the ARCH directory.
    if [ ! -e %rpm_install_dir/%_target_cpu ]; then
	ln -sf %cpu_arch %rpm_install_dir/%_target_cpu
	ln -sf %cpu_arch %buildroot/usr/src/linux-obj/%_target_cpu
    fi

    # We were building in %my_builddir/linux-%srcversion, but the sources will
    # later be installed in /usr/src/linux-%srcversion-%source_rel. Fix up the
    # build symlink.
    rm -f %buildroot/lib/modules/%kernelrelease-%build_flavor/{source,build}
    ln -s %src_install_dir \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/source
    ln -s %obj_install_dir/%cpu_arch/%build_flavor \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/build

    # Abort if there are any undefined symbols
    msg="$(/sbin/depmod -F %buildroot/boot/System.map-%kernelrelease-%build_flavor \
			-b %buildroot -ae %kernelrelease-%build_flavor 2>&1)"
    if [ $? -ne 0 ] || echo "$msg" | grep  'needs unknown symbol'; then
	exit 1
    fi

%if %split_base
    %_sourcedir/split-modules -d %buildroot \
	-o %my_builddir \
	-b %kernel_build_dir/Module.base
%if ! %split_extra
    cat %my_builddir/unsupported-modules >>%my_builddir/main-modules
%endif

%else
    (   cd %buildroot
	find lib/modules/%kernelrelease-%build_flavor -type f -name '*.ko' -printf '/%%p\n'
    ) > %my_builddir/base-modules
%endif

    res=0
    if test -e %my_builddir/kabi/%cpu_arch/symvers-%build_flavor; then
        # check for kabi changes
        %_sourcedir/kabi.pl --rules %my_builddir/kabi/severities \
            %my_builddir/kabi/%cpu_arch/symvers-%build_flavor \
            Module.symvers.split || res=$?
    fi
    if [ $res -ne 0 ]; then
	# %ignore_kabi_badness is defined in the Kernel:* projects in the
	# OBS to be able to build the KOTD in spite of kabi errors
	if [ 0%{?ignore_kabi_badness} -eq 0 -a \
	     ! -e %my_builddir/kabi/%cpu_arch/ignore-%build_flavor -a \
	     ! -e %_sourcedir/IGNORE-KABI-BADNESS ]; then
	    echo "Create a file IGNORE-KABI-BADNESS in the kernel-source" \
		 "directory to build this kernel even though its badness is" \
		 "higher than allowed for an official kernel."
	   exit 1
	fi
    fi

    # generate symsets
    mkdir -p %my_builddir/{base,main,extra}-symsets
    for f in %my_builddir/{base,main,unsupported}-modules; do
        if [ -f "$f" ]; then
            sed 's:^/:%buildroot/:' "$f"
        fi > "$f-br"
    done
    reference=
    if test -e %my_builddir/kabi/%cpu_arch/symsets-pae.tar.gz; then
        tar xzf %my_builddir/kabi/%cpu_arch/symsets-pae.tar.gz -C \
	    %my_builddir/kabi/%cpu_arch
        reference="--reference %my_builddir/kabi/%cpu_arch/symsets-*-pae/"
        if test -e %my_builddir/kabi/%cpu_arch/symvers-pae.fake; then
            reference="$reference --fake $_"
        fi
    fi
    %_sourcedir/symsets.pl --generate-symsets \
        $reference \
        --symvers=Module.symvers.split \
        --modules=%my_builddir/base-modules-br \
        --output-dir=%my_builddir/base-symsets
%if %split_base
    %_sourcedir/symsets.pl --generate-symsets \
        $reference \
        --modules=%my_builddir/main-modules-br \
        --required-modules=%my_builddir/base-modules-br \
        --output-dir=%my_builddir/main-symsets
%endif
%if %split_extra
    %_sourcedir/symsets.pl --generate-symsets \
        $reference \
        --modules=%my_builddir/unsupported-modules-br \
        --required-modules=%my_builddir/base-modules-br \
        --required-modules=%my_builddir/main-modules-br \
        --output-dir=%my_builddir/extra-symsets
%endif

    # arch/powerpc/lib/crtsavres.o is required for building external
    # modules on powerpc
    if [ -f %kernel_build_dir/arch/powerpc/lib/crtsavres.o ]; then
        echo arch/powerpc/lib/crtsavres.o >> %my_builddir/obj-files
    fi

    tar cf - -T %my_builddir/obj-files | \
	tar xf - -C %rpm_install_dir/%cpu_arch_flavor
    # bnc#507084
    find %rpm_install_dir/%cpu_arch_flavor/scripts -type f -perm -111 | \
        while read f; do
            case "$(file -b "$f")" in
            ELF\ *\ executable*)
                strip "$f"
            esac
        done
    # Replace the absolute with a relative path
    sed -i "s,%build_src_dir,../../../linux-%kernelrelease%variant,g" \
	%rpm_install_dir/%cpu_arch_flavor/Makefile
    # bnc#551348
    install -d -m 755 %buildroot/etc/modprobe.d/
    install -m 644 %_sourcedir/generic_serial-blacklist %buildroot/etc/modprobe.d/
    symsets=%my_builddir/symsets-%kernelrelease-%build_flavor
    mkdir -p $symsets
    find %my_builddir/{base,main,extra}-symsets -type f \
	| xargs --replace='{}' cp '{}' $symsets/
    tar c -C ${symsets%/*} ${symsets##*/} \
	| gzip -9 \
	> %buildroot/boot/symsets-%kernelrelease-%build_flavor.tar.gz
    find %buildroot -name '*.ko' -printf '/%%P.hmac\n' >>%my_builddir/hmac.files
fi # CONFIG_MODULES = y

add_dirs_to_filelist() {
    sed -rn '
        # print file name
        p
        # remove filelist macros
        s:%%[a-z]+(\([^)]+\))? ?::g
        # add %%dir prefix
        s:^:%%dir :
        # print all parents
        :a
            # skip directories owned by other packages
            s:^%%dir (/boot|/etc|/lib/(modules|firmware)|/usr/src)/[^/]+$::
            s:/[^/]+$::p
        ta
    ' "$@" | sort -u
}

# Collect the file lists.
shopt -s nullglob
> %my_builddir/kernel-devel.files
for file in %buildroot/boot/sym{sets,types}* \
				%buildroot/lib/modules/*/{build,source}; do
	f=${file##%buildroot}
	echo "$f"
done | add_dirs_to_filelist >%my_builddir/kernel-devel.files

{   cd %buildroot
    find boot \
	\( -type l -o -name 'initrd-*' \) -printf '%%%%ghost /%%p\n' -o \
	-type f -name 'vmlinux-*' -printf '%%%%attr(0644, root, root) /%%p\n' -o \
        -type f -printf '/%%p\n'

    # Add the auto-generated (by mkdumprd) kdump initrd to %ghost so that
    # the file gets removed when uninstalling the kernel.
    echo '%%ghost /boot/initrd-%kernelrelease-%build_flavor-kdump'
    touch $RPM_BUILD_ROOT/boot/initrd-%kernelrelease-%build_flavor-kdump

    if [ %CONFIG_MODULES = y ]; then
	find lib/modules/%kernelrelease-%build_flavor \
	    -type d -o \
	    \( -path '*/modules.*' ! -path '*/modules.order' \
	     ! -path '*/modules.builtin' \) -printf '%%%%ghost /%%p\n' \
	       -o -name '*.ko' -prune -o -printf '/%%p\n'
	cat %my_builddir/base-modules
    fi
    if test %CONFIG_MODULE_SIG = "y"; then
        find etc/uefi/certs -type f -printf '/%%p\n'
    fi
    # optional per-kernel-release module config workarounds
    if test -d etc/modprobe.d; then
        find etc/modprobe.d -type f -printf '%%%%config(noreplace) /%%p\n'
    fi
    test -d lib/firmware/%kernelrelease-%build_flavor && \
    find lib/firmware/%kernelrelease-%build_flavor \
	-type d -o \
	-printf '/%%p\n'
    if [ -e .%_docdir/%name ]; then
	echo "%%doc %_docdir/%name"
    fi
} | sort -u >%my_builddir/tmp
cat %my_builddir/tmp %my_builddir/kernel-devel.files | sort | uniq -u | \
    add_dirs_to_filelist >%my_builddir/kernel-base.files
rm %my_builddir/tmp

%if %split_base
    add_dirs_to_filelist %my_builddir/main-modules \
	> %my_builddir/kernel-main.files
%endif
%if %split_extra
    add_dirs_to_filelist %my_builddir/unsupported-modules > %my_builddir/kernel-extra.files
%endif

%_sourcedir/gen-hmacs %my_builddir/hmac.files

# Hardlink duplicate files automatically (from package fdupes): It doesn't save
# much, but it keeps rpmlint from breaking the package build. Note that we skip
# /usr/src/linux-obj intentionally, to not accidentally break timestamps there
%fdupes $RPM_BUILD_ROOT/lib

%preun -f preun.sh

%postun -f postun.sh

%pre -f pre.sh

%post -f post.sh

%if %split_base

%files -f kernel-main.files
%else

%files -f kernel-base.files
%endif
%defattr(-, root, root)

%package base
Summary:        Kernel with PAE Support - base modules
License:        GPL v2 only
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       multiversion(kernel)
Provides:       %name-base_%_target_cpu = %version-%release
Provides:       kernel-base = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): module-init-tools
Requires(post): perl-Bootloader
Requires(post): mkinitrd
%ifarch %ix86
Provides:       kernel-vmi-base = 2.6.38
Obsoletes:      kernel-vmi-base <= 2.6.38
%endif
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description base
This kernel supports up to 64GB of main memory. It requires Physical
Addressing Extensions (PAE), which were introduced with the Pentium Pro
processor.

PAE is not only more physical address space but also important for the
"no execute" feature which disables execution of code that is marked as
non-executable. Therefore, the PAE kernel should be used on any systems
that support it, regardless of the amount of main memory.

This package contains only the base modules, required in all installs.


%source_timestamp
%preun base -f preun-base.sh

%postun base -f postun-base.sh

%pre base -f pre-base.sh

%post base -f post-base.sh

%if %split_base

%files base -f kernel-base.files
%defattr(-, root, root)
%endif

%package extra
Summary:        Kernel with PAE Support - Unsupported kernel modules
License:        GPL v2 only
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       multiversion(kernel)
Provides:       %name-extra_%_target_cpu = %version-%release
Provides:       kernel-extra = %version-%source_rel
Requires:       %{name}_%_target_cpu = %version-%release
Requires(pre):  coreutils awk
Requires(post): module-init-tools
Requires(post): perl-Bootloader
Requires(post): mkinitrd
%ifarch %ix86
Provides:       kernel-vmi-extra = 2.6.38
Obsoletes:      kernel-vmi-extra <= 2.6.38
%endif
Supplements:    packageand(product(SUSE_SLED):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description extra
This kernel supports up to 64GB of main memory. It requires Physical
Addressing Extensions (PAE), which were introduced with the Pentium Pro
processor.

PAE is not only more physical address space but also important for the
"no execute" feature which disables execution of code that is marked as
non-executable. Therefore, the PAE kernel should be used on any systems
that support it, regardless of the amount of main memory.

This package contains additional modules not supported by Novell.


%source_timestamp
%preun extra -f preun-extra.sh

%postun extra -f postun-extra.sh

%pre extra -f pre-extra.sh

%post extra -f post-extra.sh

%if %split_extra

%files extra -f kernel-extra.files
%defattr(-, root, root)
%endif

%if %CONFIG_KMSG_IDS == "y"

%package man
Summary:        The collection of man pages generated by the kmsg script.
License:        GPL v2 only
Group:          System/Kernel

%description man
This package includes the man pages that have been generated from the
kmsg message documentation comments.


%source_timestamp
%files man
%defattr(-,root,root)
/usr/share/man/man9/*
%endif

%package devel
Summary:        Development files necessary for building kernel modules
License:        GPL v2 only
Group:          Development/Sources
Provides:       multiversion(kernel)
Provides:       %name-devel = %version-%source_rel
Requires:       kernel-source%variant = %version-%source_rel
%if %CONFIG_MODULE_SIG == "y"
Requires:       openssl
%endif
%ifarch %ix86
Provides:       kernel-vmi-devel = 2.6.38
Obsoletes:      kernel-vmi-devel <= 2.6.38
%endif
Supplements:    packageand(%name:kernel-source)

%description devel
This package contains files necessary for building kernel modules (and
kernel module packages) against the %build_flavor flavor of the kernel.


%source_timestamp
%if %CONFIG_MODULES == "y"

%pre devel -f devel-pre.sh

%post devel -f devel-post.sh

%files devel -f kernel-devel.files
%defattr(-,root,root)
%dir %obj_install_dir
%dir %obj_install_dir/%cpu_arch
%dir /usr/src/linux-obj
%dir /usr/src/linux-obj/%cpu_arch
%ghost /usr/src/linux-obj/%cpu_arch_flavor
%obj_install_dir/%cpu_arch_flavor
%if %_target_cpu != %cpu_arch
%obj_install_dir/%_target_cpu
/usr/src/linux-obj/%_target_cpu
%endif
%endif

%package devel-debuginfo
# rpm doesn't notice that vmlinux.debug belongs to the gzipped vmlinux.gz
Summary:        Debug information for package %name-devel
License:        GPL v2 only
Group:          Development/Debug

%description devel-debuginfo
Debug information for package %name-devel


%source_timestamp
%files devel-debuginfo -f vmlinux.debug.files

%package hmac
Summary:        HMAC files for the kernel image and modules
License:        GPL v2 only
Group:          System/Kernel
Provides:       multiversion(kernel)
Requires:       %{name}_%_target_cpu = %version-%release
%ifarch %ix86
Provides:       kernel-vmi-hmac = 2.6.38
Obsoletes:      kernel-vmi-hmac <= 2.6.38
%endif

%description hmac
This package contains HMAC hashes for the kernel image and modules.


%source_timestamp
%files hmac -f hmac.files
%defattr(-, root, root)

%changelog
* Thu Mar 21 2019 msuchanek@suse.de
- scsi: ibmvscsi: Fix empty event pool access during host removal
  (bsc#1119019).
- commit 46adb5f
* Thu Mar 21 2019 jack@suse.cz
- blacklist.conf: Blacklist c9e716eb9b34 and 231fe82b5609
- commit c585b8d
* Mon Mar 18 2019 tzimmermann@suse.de
- fbdev: chipsfb: remove set but not used variable 'size' (bsc#1106886)
- commit 401879d
* Fri Mar 15 2019 jroedel@suse.de
- KVM: x86: Use jmp to invoke kvm_spurious_fault() from .fixup
  (bsc#1129439).
- kvm: vmx: Set IA32_TSC_AUX for legacy mode guests (bsc#1129437).
- commit 92d0230
* Fri Mar 15 2019 jroedel@suse.de
- blacklist.conf: Add 53bb565fc543 x86/PCI: Fix Broadcom CNB20LE unintended sign extension (redux)
- commit ebe06ec
* Thu Mar 14 2019 jroedel@suse.de
- iommu/vt-d: Check identity map for hot-added devices
  (bsc#1129248).
- commit 2268a16
* Tue Mar 12 2019 msuchanek@suse.de
- copy_mount_string: Limit string length to PATH_MAX
  (bsc#1082943).
- commit 5ab06c4
* Tue Mar 12 2019 jgross@suse.com
- blacklist.conf: added 201676095dda7e5b31a5e1d116d10fc22985075e, as commit
  is relevant for pvops Xen only.
- commit d9bd873
* Mon Mar 11 2019 mkoutny@suse.com
- scripts: git_sort: Warn about missing upstream repo
  I've witnessed several people having misconfigured their remotes and
  then calling sortig scripts on series.conf results in cryptic error
  messages like:
  > Traceback (most recent call last):
  >   File "scripts/git_sort/series_sort.py", line 121, in <module>
  >     sorted_entries = lib.series_sort(index, input_entries)
  >   File "/home/mkoutny/suse/kernel-source-12-sp3/scripts/git_sort/lib.py", line 425, in series_sort
  >     for e in sorted(result[head].items(), key=operator.itemgetter(0))])
  > KeyError: None HEAD
  Add warning when the upstream torvalds/linux remote is not found to give
  users a clue about the situation.
- commit 4a47577
* Mon Mar 11 2019 tzimmermann@suse.de
- drm: Fix error handling in drm_legacy_addctx (bsc#1106886)
- commit 41320ee
* Mon Mar 11 2019 dkirjanov@suse.com
- blacklist.conf: 8997c27ec411 ("caif: remove wrong dev_net_set() call")
- commit 87fbee9
* Mon Mar 11 2019 dkirjanov@suse.com
- Revert "macvlan : fix checksums error when we are in bridge
  mode" (gix-fixes).
- commit 2567981
* Fri Mar  8 2019 dkirjanov@suse.com
- s390/qeth: handle failure on workqueue creation (LTC#175048,
  bsc#1127376).
- commit aff090d
* Thu Mar  7 2019 dkirjanov@suse.com
- s390/qeth: cancel close_dev work before removing a card
  (LTC#175048, bsc#1127376).
- commit e8d749e
* Thu Mar  7 2019 dkirjanov@suse.com
- s390/qeth: fix use-after-free in error path (LTC#175048,
  bsc#1127376, bsc#1127534).
- commit dafe468
* Thu Mar  7 2019 dkirjanov@suse.com
- blacklist.conf: afa0c5904ba1 ("s390/qeth: fix use-after-free in error
  path")
- commit 7f4b658
* Wed Mar  6 2019 mhocko@suse.com
- mm: enforce min addr even if capable() in expand_downwards()
  (bsc#1128166, CVE-2019-9213).
- commit 63c7a03
* Tue Mar  5 2019 lyan@suse.com
- kvm: x86: Add AMD's EX_CFG to the list of ignored MSRs
  (bsc#1127082).
- commit b8d4ab4
* Mon Mar  4 2019 jthumshirn@suse.de
- scsi: qla2xxx: don't disable a not previously enabled PCI device
  (bsc#1127738).
- commit bcdf393
* Mon Mar  4 2019 neilb@suse.com
- nfsd: fix memory corruption caused by readdir (bsc#1127445).
- commit 35cf838
* Fri Mar  1 2019 msuchanek@suse.de
- Revert "scripts/series2git: skip expanded stable patches."
  This reverts commit 79c578bbfd244101db3edde86ec7ec5b866f940e.
- commit 5e14d9a
* Fri Mar  1 2019 msuchanek@suse.de
- Fix scripts/arch-symbols and scripts/guards mismerge.
  These files were symlinks to ../rpm/ but were reinstated as plain files
  later. Relink.
- commit ed76353
* Tue Feb 26 2019 mgorman@suse.de
- mm, oom: fix use-after-free in oom_kill_process (git fixes
  (mm/mmap)).
- commit a58aade
* Tue Feb 26 2019 jack@suse.cz
- blacklist.conf: Blacklist fb265c9cb49e
- commit 9a2b390
* Mon Feb 25 2019 vliaskovitis@suse.com
- kvm: ensure hard lockup detection is disabled by default
  (bsc#1110436).
- kernel/watchdog.c: control hard lockup detection default
  (bsc#1110436).
- commit 862296b
* Fri Feb 22 2019 ptesarik@suse.cz
- s390/qeth: invoke softirqs after napi_schedule() (git-fixes).
- commit 9f33115
* Thu Feb 21 2019 ptesarik@suse.cz
- s390/dasd: fix using offset into zero size array error
  (git-fixes).
- commit ce7aa7a
* Wed Feb 20 2019 jeyu@suse.de
- fork: record start_time late (bsc#1121872).
- commit c6378f0
* Tue Feb 19 2019 tabraham@suse.com
- igb: re-assign hw address pointer on reset after PCI error
  (bnc#1012382) (bsc#1123702).
- igb: don't unmap NULL hw_addr (bsc#969471 FATE#319813 bsc#969473
  FATE#319815) (bsc#1123702).
- commit 4cc6e90
* Tue Feb 19 2019 oneukum@suse.com
- Refresh
  patches.fixes/0001-USB-serial-ch341-fix-resume-after-reset.patch.
  Fix compilation warning
- commit 0592ebd
* Tue Feb 19 2019 msuchanek@suse.de
- lib: add "on"/"off" support to strtobool (bsc#1125931).
- commit 25a24b5
* Tue Feb 19 2019 jeffm@suse.com
- btrfs: fix backport error in trim patchset
  There was a backport error in which parameters are passed to next_block_group.
- commit b200789
* Mon Feb 11 2019 ailiopoulos@suse.com
- xfs: fix the logspace waiting algorithm (bsc#1122874).
- commit 513df08
* Fri Feb  8 2019 ailiopoulos@suse.com
- Update
  patches.fixes/xfs-don-t-BUG-on-mixed-direct-and-mapped-I-O.patch
  (bsc#1114920, CVE-2016-10741).
- commit 945edea
* Fri Feb  8 2019 jroedel@suse.de
- KVM: x86: work around leak of uninitialized stack contents (CVE-2019-7222) (CVE-2019-7222 bsc#1124735).
- commit cc2ecfe
* Wed Feb  6 2019 oneukum@suse.com
- USB: serial: mct_u232: fix modem-status error handling
  (bsc#1114672).
- commit 3a0a1ca
* Tue Feb  5 2019 oneukum@suse.com
- blacklist.conf: this patch can change values visible in sysfs
- commit 2e3719e
* Tue Feb  5 2019 oneukum@suse.com
- USB: serial: ftdi_sio: fix modem-status error handling
  (bsc#1114672).
- commit 0f48f12
* Tue Feb  5 2019 oneukum@suse.com
- USB: serial: ark3116: fix open error handling (bsc#1114672).
- commit be0f527
* Tue Feb  5 2019 oneukum@suse.com
- USB: serial: io_ti: fix div-by-zero in set_termios (bsc#1114672
  CVE-2017-18360).
- commit 6bb00de
* Mon Feb  4 2019 oneukum@suse.com
- USB: serial: ch341: fix type promotion bug in ch341_control_in()
  (bsc#1114672).
- commit b00c6ad
* Mon Feb  4 2019 oneukum@suse.com
- USB: serial: ch341: fix modem-status handling (bsc#1114672).
- commit 5ef562c
* Mon Feb  4 2019 oneukum@suse.com
- USB: serial: ch341: fix control-message error handling
  (bsc#1114672).
- commit e6d9f1d
* Fri Feb  1 2019 ptesarik@suse.cz
- scsi: zfcp: fix posting too many status read buffers leading
  to adapter shutdown (bsc#1123505, LTC#174581).
- commit d1eaa6b
* Thu Jan 31 2019 oneukum@suse.com
- USB: serial: ch341: fix resume after reset (bsc#1114672).
- commit 289aaa1
* Thu Jan 31 2019 oneukum@suse.com
- USB: serial: ch341: fix open and resume after B0 (bsc#1114672).
- commit 61dd529
* Thu Jan 31 2019 jroedel@suse.de
- iommu/amd: Fix IOMMU page flush when detach device from a domain (bsc#1106105).
- commit 8aaa614
* Thu Jan 31 2019 oneukum@suse.com
- USB: serial: ch341: fix initial modem-control state
  (bsc#1114672).
- commit 18db235
* Thu Jan 31 2019 oneukum@suse.com
- USB: serial: ti_usb_3410_5052: fix NULL-deref at open
  (bsc#1114672).
- commit f3bda01
* Thu Jan 31 2019 oneukum@suse.com
- USB: serial: kobil_sct: fix NULL-deref in write (bsc#1114672).
- commit 236ee02
* Wed Jan 30 2019 oneukum@suse.com
- USB: serial: pl2303: fix NULL-deref at open (bsc#1114672).
- commit e796d9f
* Wed Jan 30 2019 oneukum@suse.com
- USB: serial: omninet: fix NULL-derefs at open and disconnect.
- commit 7fead60
* Tue Jan 29 2019 oneukum@suse.com
- USB: serial: io_ti: fix another NULL-deref at open
  (bsc#1114672).
- commit 798c5f9
* Tue Jan 29 2019 oneukum@suse.com
- USB: serial: fix tty-device error handling at probe
  (bsc#1114672).
- commit ace8f57
* Tue Jan 29 2019 ptesarik@suse.cz
- dasd: fix deadlock in dasd_times_out (bnc#1117943, LTC#174111).
- s390/qeth: sanitize strings in debug messages (bnc#1117943,
  LTC#172960).
- s390/qeth: remove outdated portname debug msg (bnc#1117943,
  LTC#172960).
- s390/qeth: fix length check in SNMP processing (bnc#1117943,
  LTC#173657).
- commit e3dfc02
* Mon Jan 21 2019 tzimmermann@suse.de
- omap2fb: Fix stack memory disclosure (bsc#1106886)
- commit 07f3b0e
* Fri Jan 18 2019 ptesarik@suse.cz
- powerpc/fadump: handle crash memory ranges array index overflow
  (git-fixes).
- powerpc/fadump: Return error when fadump registration fails
  (git-fixes).
- powerpc/fadump: Unregister fadump on kexec down path
  (git-fixes).
- commit 125b6fd
* Thu Jan 17 2019 ptesarik@suse.cz
- vmcore: Remove "weak" from function declarations (git-fixes).
- commit 5a52e2b
* Wed Jan 16 2019 tzimmermann@suse.de
- drm/fb-helper: Ignore the value of fb_var_screeninfo.pixclock (bsc#1106886)
- commit 9a83849
* Tue Jan 15 2019 colyli@suse.de
- block/swim3: Fix -EBUSY error when re-opening device after
  unmount (bsc#1121997).
- commit cf6692e
* Mon Jan 14 2019 mhocko@suse.com
- Refresh
  patches.fixes/ocfs2-fix-deadlock-issue-when-taking-inode-lock-at-v.patch.
  fix the patch application:
  + patch -s -F0 -E -p1 --no-backup-if-mismatch -i ../patches.fixes/ocfs2-fix-deadlock-issue-when-taking-inode-lock-at-v.patch
  1 out of 1 hunk FAILED -- saving rejects to file fs/ocfs2/acl.c.rej
  ++ echo '*** patch ../patches.fixes/ocfs2-fix-deadlock-issue-when-taking-inode-lock-at-v.patch failed ***'
  * ** patch ../patches.fixes/ocfs2-fix-deadlock-issue-when-taking-inode-lock-at-v.patch failed ***
- commit bbfe025
* Mon Jan 14 2019 mhocko@suse.com
- Revert "- patches.suse/0001-USB-check-usb_get_extra_descriptor-for-proper-size-F.patch:"
  This reverts commit 2cb1f2c23d7c2cec24545d9b8c50089318834b83 as it
  breaks build on 32b.
- commit 16e2270
* Wed Jan  9 2019 jroedel@suse.de
- KVM: X86: Fix scan ioapic use-before-initialization
  (CVE-2018-19407 bsc#1116841).
- commit 19bbc5d
* Wed Jan  9 2019 ghe@suse.com
- ocfs2: fix three small problems in the patch (bsc#1086695)
  These two compiler warnings were introduced by the latest
  ocfs2-fix-deadlock-issue-when-taking-inode-lock-at-v.patch,
  secondly, correct the Git-commit.
- commit d2d2d8b
* Tue Jan  8 2019 tiwai@suse.de
- USB: hso: Fix OOB memory access in hso_probe/hso_get_config_data
  (CVE-2018-19985,bsc#1120743).
- commit ff4c5fc
* Tue Jan  8 2019 tzimmermann@suse.de
- fbdev: fbcon: Fix unregister crash when more than one framebuffer (bsc#1106886)
- commit 5a01227
* Tue Jan  8 2019 tzimmermann@suse.de
- fbdev: fbmem: behave better with small rotated displays and many CPUs (bsc#1106886)
- commit 0daf391
* Tue Jan  8 2019 nsaenzjulienne@suse.de
- USB: EHCI: fix initialization bug in iso_stream_schedule()
  (bsc#1117515).
- commit 6b7e834
* Tue Jan  8 2019 nsaenzjulienne@suse.de
- EHCI: improved logic for isochronous scheduling (bsc#1117515).
- USB: EHCI: resolve some unlikely races (bsc#1117515).
- Refresh: patches.xen/xen3-patch-2.6.32.orig
  h
- USB: EHCI: fix up locking (bsc#1117515).
- USB: EHCI: simplify isochronous scanning (bsc#1117515).
- USB: EHCI: use hrtimer for the I/O watchdog (bsc#1117515).
- USB: EHCI: always scan each interrupt QH (bsc#1117515).
- USB: EHCI: don't lose events during a scan (bsc#1117515).
- USB: EHCI: use hrtimer for unlinking empty async QHs
  (bsc#1117515).
- USB: EHCI: unlink multiple async QHs together (bsc#1117515).
- USB: EHCI: use hrtimer for the IAA watchdog (bsc#1117515).
- USB: EHCI: don't refcount iso_stream structures (bsc#1117515).
- USB: EHCI: use hrtimer for (s)iTD deallocation (bsc#1117515).
- USB: EHCI: use hrtimer for controller death (bsc#1117515).
- USB: EHCI: use hrtimer for interrupt QH unlink (bsc#1117515).
- USB: EHCI: use hrtimer for async schedule (bsc#1117515).
- USB: EHCI: remove PS3 status polling (bsc#1117515).
- USB: EHCI: return void instead of 0 (bsc#1117515).
- USB: EHCI: use hrtimer for the periodic schedule (bsc#1117515).
- USB: EHCI: introduce high-res timer (bsc#1117515).
- USB: EHCI: add new root-hub state: STOPPING (bsc#1117515).
- USB: EHCI: add pointer to end of async-unlink list
  (bsc#1117515).
- USB: EHCI: rename "reclaim" (bsc#1117515).
- USB: EHCI: add symbolic constants for QHs (bsc#1117515).
- USB: EHCI: don't refcount QHs (bsc#1117515).
- USB: EHCI: remove unneeded suspend/resume code (bsc#1117515).
- USB: EHCI: initialize data before resetting hardware
  (bsc#1117515).
- commit a8ea1f4
* Mon Jan  7 2019 pmladek@suse.com
- blacklist.conf: internal API, used correctly everywhere (bsc#1120950)
- commit 684221f
* Mon Jan  7 2019 pmladek@suse.com
- blacklist.conf: link error with some gcc version or some configurations
- commit 6791b72
* Mon Jan  7 2019 pmladek@suse.com
- blacklist.conf: very old problem; might be visible only when debugging int3
  context on x86_64
- commit a50fefb
* Mon Jan  7 2019 pmladek@suse.com
- blacklist.conf: not worth backporting
- commit a0a54ea
* Mon Jan  7 2019 lma@suse.com
- KVM: x86: Fix the duplicated failure path handling in vmx_init
  (bsc#1104367).
- commit fe899c3
* Mon Jan  7 2019 wqu@suse.com
- btrfs: Ensure btrfs_trim_fs can trim the whole filesystem
  (bsc#1113667).
- commit 281940a
* Mon Jan  7 2019 wqu@suse.com
- btrfs: Enhance btrfs_trim_fs function to handle error  better
  (Dependency for bsc#1113667).
- commit 41dbfa6
* Mon Jan  7 2019 neilb@suse.com
- SUNRPC: Fix a potential race in xprt_connect() (git-fixes).
- NFSv4: Don't exit the state manager without clearing
  NFS4CLNT_MANAGER_RUNNING (git-fixes).
- commit c8f4732
* Mon Jan  7 2019 neilb@suse.com
- fscache: Fix race in fscache_op_complete() due to split
  atomic_sub & read (git-fixes).
- commit b59351e
* Thu Dec 27 2018 mbenes@suse.cz
- blacklist.conf: 1fe4293f4b8d ("tracing: Fix missing return symbol in function_graph output")
  CONFIG_FUNCTION_GRAPH_TRACER is disabled.
- commit 337b67e
* Thu Dec 27 2018 mbenes@suse.cz
- tracing: Fix regex_match_front() to not over compare the test
  string (bsc#1120223).
- commit 6f9dd5e
* Thu Dec 27 2018 mbenes@suse.cz
- tracing: probeevent: Fix to support minus offset from symbol
  (bsc#1120347).
- commit f5f45e5
* Thu Dec 27 2018 mbenes@suse.cz
- tracing/kprobes: Allow to create probe with a module name
  starting with a digit (bsc#1120336).
- commit 060dfa1
* Thu Dec 27 2018 mbenes@suse.cz
- blacklist.conf: 6b7e633fe9c2 ("tracing: Remove extra zeroing out of the ring buffer page")
  Optimization. Not really needed. The bug was fixed by backporting
  45d8b80c2ac5 ("ring-buffer: Mask out the info bits when returning buffer
  page length").
- commit cc06549
* Thu Dec 27 2018 mbenes@suse.cz
- ring-buffer: Mask out the info bits when returning buffer page
  length (bsc#1120094).
- commit 52606be
* Thu Dec 27 2018 mbenes@suse.cz
- blacklist.conf: 90e406f96f63 ("tracing: Allocate mask_str buffer dynamically")
  A memory optimization. Not really needed.
- commit 7e50f6e
* Thu Dec 27 2018 mbenes@suse.cz
- blacklist.conf: 8dd33bcb7050 ("tracing: Erase irqsoff trace with empty write")
  CONFIG_IRQSOFF_TRACER is disabled. Also the code is different and the
  fix is not applicable.
- commit e07da37
* Thu Dec 27 2018 mbenes@suse.cz
- blacklist.conf: 46320a6acc4f ("ftrace: Fix selftest goto location on error")
  Ftrace selftests are disabled.
- commit 010c63f
* Tue Dec 25 2018 bp@suse.de
- blacklist.conf:
- commit 72d8c14
* Fri Dec 21 2018 mbenes@suse.cz
- blacklist.conf: acceb72e9062 ("ftrace: Fix removing of second function probe")
  Duplicate of 82cc4fc2e70e ("ftrace: Fix removing of second function
  probe"). CONFIG_FUNCTION_TRACER is not set.
- commit ebe2119
* Fri Dec 21 2018 mbenes@suse.cz
- blacklist.conf: 82cc4fc2e70e ("ftrace: Fix removing of second function probe")
  CONFIG_FUNCTION_TRACER is not set.
- commit a5fbe2a
* Fri Dec 21 2018 mbenes@suse.cz
- tracing: Add #undef to fix compile error (bsc#1120226).
- commit 1fa30b9
* Fri Dec 21 2018 mbenes@suse.cz
- tracing: Move mutex to protect against resetting of seq data
  (bsc#1120217).
- commit c570819
* Fri Dec 21 2018 mbenes@suse.cz
- blacklist.conf: cb86e05390de ("tracing: Have preempt(irqs)off trace preempt disabled functions")
  CONFIG_PREEMPT_TRACER and CONFIG_IRQSOFF_TRACER are not set.
- commit 235d56f
* Fri Dec 21 2018 mbenes@suse.cz
- ring-buffer: Have ring_buffer_iter_empty() return true when
  empty (bsc#1120107).
- commit e0cbddd
* Fri Dec 21 2018 mbenes@suse.cz
- tracing: Fix check for cpu online when event is disabled
  (bsc#1120109).
- commit 896eca4
* Fri Dec 21 2018 mbenes@suse.cz
- ring-buffer: Fix infinite spin in reading buffer (bsc#1120107).
- commit 0db5162
* Thu Dec 20 2018 mbenes@suse.cz
- tracepoints: Do not trace when cpu is offline (bsc#1120109).
- commit 59ef321
* Thu Dec 20 2018 mbenes@suse.cz
- ring-buffer: Always reset iterator to reader page (bsc#1120107).
- commit f1cfc0d
* Thu Dec 20 2018 mbenes@suse.cz
- ring-buffer: Up rb_iter_peek() loop count to 3 (bsc#1120105).
- commit 7df010d
* Thu Dec 20 2018 mbenes@suse.cz
- blacklist.conf: 97b8ee845393 ("ring-buffer: Fix polling on trace_pipe")
  bsc#1120093 for reference. We don't have 15693458c4bc
  ("tracing/ring-buffer: Move poll wake ups into ring buffer code").
- commit b98c1cd
* Thu Dec 20 2018 mbenes@suse.cz
- tracing: Do not add event files for modules that fail
  tracepoints (bsc#1120086).
- commit 449c6ef
* Thu Dec 20 2018 mbenes@suse.cz
- ring-buffer: Fix first commit on sub-buffer having non-zero
  delta (bsc#1120077).
- commit f73d450
* Thu Dec 20 2018 mbenes@suse.cz
- blacklist.conf: a4c35ed24112 ("ftrace: Fix synchronization location disabling and freeing ftrace_ops")
  Function tracer is disabled.
- commit e1c3490
* Thu Dec 20 2018 mbenes@suse.cz
- blacklist.conf: 8a56d7761d2d ("ftrace: Fix function graph with loading of modules")
  Function graph tracer is disabled.
- commit f5cdeb2
* Thu Dec 20 2018 mbenes@suse.cz
- tracing: Allow events to have NULL strings (bsc#1120056).
- commit f5cdc0a
* Thu Dec 20 2018 oneukum@suse.com
- patches.suse/0001-USB-check-usb_get_extra_descriptor-for-proper-size-F.patch: USB: check usb_get_extra_descriptor for proper size (For SUSE) (bsc#1119714 CVE-2018-20169).
- patches.suse/0001-USB-check-usb_get_extra_descriptor-for-proper-size-F.patch:
  USB: check usb_get_extra_descriptor for proper size (For SUSE)
  (bsc#1119714 CVE-2018-20169).
- commit 6a7f962
* Thu Dec 20 2018 mbenes@suse.cz
- blacklist.conf: 67b84999b1a8 ("Revert "tracing: Include module.h in define_trace.h"")
  Just a cleanup. Prerequisites not even met.
- commit 9916dfc
* Mon Dec 17 2018 jbeulich@suse.com
- Patch cosmetics (tags etc):
- Refresh
  patches.xen/xen3-i387-use-restore_fpu_checking-directly-in-task-switc.patch.
- Refresh patches.xen/xen3-patch-2.6.27.
- x86/mm: Simplify p[g4um]xen: d_page() macros (bnc#1087081,
  bnc#1104684).
- Refresh patches.xen/xen3-x86-non-upstream-eager-fpu.patch.
- xen/x86/speculation/l1tf: Fix overflow in l1tf_pfn_limit()
  on 32bit (bnc#1087081).
- commit 73b456c
* Mon Dec 17 2018 jbeulich@suse.com
- xen: kabi: x86/speculation/l1tf: Increase l1tf memory limit
  for Nehalem+ (bnc#1105536).
- xen/x86/speculation/l1tf: Fix off-by-one error when warning
  that system has too much RAM (bnc#1105536).
- xen/x86/speculation/l1tf: Increase l1tf memory limit for
  Nehalem+ (bnc#1105536).
- Delete
  patches.xen/xen3-x86-kabi-speculation-l1tf-Increase-l1tf-memory-limit-for-.patch.
- Delete
  patches.xen/xen3-x86-speculation-l1tf-Fix-off-by-one-error-when-warni.patch.
- Delete
  patches.xen/xen3-x86-speculation-l1tf-Increase-l1tf-memory-limit-for-.patch.
- commit 471f9a6
* Mon Dec 17 2018 jbeulich@suse.com
- xen/x86/traps: add missing kernel CR3 switch in bad_iret path
  (bsc#1098658).
- xen/x86/retpoline/entry: Convert entry assembler indirect
  jumps -- ia32 (bsc#1068032 CVE-2017-5715).
- xen/x86/mm: Set IBPB upon context switch (bsc#1068032).
- commit a041791
* Mon Dec 17 2018 jbeulich@suse.com
- xen/x86/mm: Prevent kernel Oops in PTDUMP code with HIGHPTE=y
  (bsc#1106105).
- xen/x86/process: Re-export start_thread() (bsc#1110006).
- xen: x86-non-upstream-eager-fpu external modules fix
  (bnc#1087086 CVE-2018-3665 bnc#1100091 bnc#1099598).
- commit 72e1097
* Mon Dec 17 2018 jbeulich@suse.com
- xen: x86, l1tf: Protect PROT_NONE PTEs against speculation fixup
  (bnc#1104684, bnc#1104818).
- Refresh
  patches.xen/xen3-x86-l1tf-04-protect-PROT_NONE-ptes.patch.
- commit f40b984
* Mon Dec 17 2018 jbeulich@suse.com
- Refresh
  patches.xen/xen3-14.1-x86-retpoline-fill-rsb-on-context-switch-for-affected-cpus.patch
  (re-sync with parent patch).
- commit 199ae64
* Mon Dec 17 2018 jbeulich@suse.com
- Refresh
  patches.xen/xen3-03-x86-entry-use-ibrs-on-entry-to-kernel-space.patch
  (fix misplaced ENABLE_IBRS).
- commit 5abc95f
* Mon Dec 17 2018 jbeulich@suse.com
- Refresh patches.xen/xen-blkfront-build-upstream (delete xenblk
  module alias, as we have an actual driver of this name).
- rpm/modprobe-xen.conf: Add --ignore-install.
- commit 4751c85
* Mon Dec 17 2018 jbeulich@suse.com
- Refresh
  patches.suse/0001-efivarfs-maintain-the-efivarfs-interfaces-when-sysfs.patch
  (fix use of an uninitialized variable).
- commit 2f1627d
* Mon Dec 17 2018 msuchanek@suse.de
- powerpc/traps: restore recoverability of machine_check
  interrupts (bsc#1094244).
- commit 9a46663
* Mon Dec 17 2018 msuchanek@suse.de
- blacklist.conf: blacklist 8a03e81cb147 powerpc/64s: consolidate MCE
  counter increment
- commit f1d2650
* Fri Dec 14 2018 ailiopoulos@suse.com
- fuse: fix possibly missed wake-up after abort (git-fixes).
- commit 52783bb
* Fri Dec 14 2018 ohering@suse.de
- Drivers: hv: vmbus: check the creation_status in
  vmbus_establish_gpadl() (bsc#1104098).
- commit e7fcc76
* Fri Dec 14 2018 ailiopoulos@suse.com
- fuse: fix leaked notify reply (git-fixes).
- commit 895730a
* Thu Dec 13 2018 mkoutny@suse.com
- cpusets, isolcpus: exclude isolcpus from load balancing in
  cpusets (bsc#1119255).
- sched, isolcpu: make cpu_isolated_map visible outside scheduler
  (bsc#1119255).
- commit 1a414ea
* Thu Dec 13 2018 oneukum@suse.com
- blacklist.conf: we did not take the patch that requires this
- commit 1be35fe
* Thu Dec 13 2018 ailiopoulos@suse.com
- fuse: Add missed unlock_page() to fuse_readpages_fill()
  (git-fixes).
- commit cb7a0ac
* Thu Dec 13 2018 ailiopoulos@suse.com
- fuse: Fix oops at process_init_reply() (git-fixes).
- commit 0c858bd
* Wed Dec 12 2018 ailiopoulos@suse.com
- fuse: umount should wait for all requests (git-fixes).
- commit 30aed90
* Wed Dec 12 2018 mkubecek@suse.cz
- net: Set sk_prot_creator when cloning sockets to the right proto
  (CVE-2018-9568 bsc#1118319).
- commit 620b8a0
* Tue Dec 11 2018 colyli@suse.de
- blacklist.conf: add 1f2cac107c591c24b60b115d6050adc213d10fc0
- commit 74ef988
* Tue Dec 11 2018 colyli@suse.de
- block/swim: Fix array bounds check (Git-fix).
- commit 10186ec
* Tue Dec 11 2018 lchen@suse.com
- patches.fixes/ocfs2-fix-deadlock-caused-by-recursive-locking-in-xa.patch:
  (bsc#1086695).
- patches.fixes/ocfs2-fix-deadlock-issue-when-taking-inode-lock-at-v.patch:
  (bsc#1086695).
- patches.fixes/ocfs2-dlmglue-prepare-tracking-logic-to-avoid-recurs.patch:
  (bsc#1086695).
- commit 718b147
* Fri Dec  7 2018 jack@suse.cz
- blacklist.conf: Blacklist f0a7d1883d9f
- commit e0bd556
* Fri Dec  7 2018 jack@suse.cz
- blacklist.conf: Blacklist 1ccbeeb888ac
- commit 282b268
* Fri Dec  7 2018 jack@suse.cz
- blacklist.conf: Blacklist c4b7d1ba7d26
- commit a085c3c
* Fri Dec  7 2018 jack@suse.cz
- ext4: avoid possible double brelse() in add_new_gdb() on error
  path (bsc#1118760).
- commit 6b54ef1
* Tue Dec  4 2018 jroedel@suse.de
- blacklist.conf: Blacklist MAINTAINERS file
- commit b50bfa9
* Mon Dec  3 2018 tiwai@suse.de
- ALSA: usb-audio: Fix UAF decrement if card has no live
  interfaces in card.c (CVE-2018-19824,bsc#1118152).
- commit 1075c5c
* Fri Nov 30 2018 mhocko@suse.com
- Update patches.drivers/lib-add-error-checking-to-hex2bin
  (bsc#1107829 CVE-2018-14633).
- commit 7a72692
* Thu Nov 29 2018 ailiopoulos@suse.com
- fuse: fix blocked_waitq wakeup (git-fixes).
- commit 205bc6e
* Thu Nov 29 2018 jack@suse.cz
- ext4: fix buffer leak in ext4_xattr_move_to_block() on error
  path (bsc#1117806).
- commit fe31b3d
* Thu Nov 29 2018 jack@suse.cz
- ext4: release bs.bh before re-using in ext4_xattr_block_find()
  (bsc#1117805).
- commit b379d75
* Thu Nov 29 2018 jack@suse.cz
- ext4: avoid buffer leak in ext4_orphan_add() after prior errors
  (bsc#1117802).
- commit fcd85fb
* Thu Nov 29 2018 jack@suse.cz
- ext4: add missing brelse() update_backups()'s error path
  (bsc#1117796).
- commit 5a2be50
* Mon Nov 26 2018 neilb@suse.com
- Fix breakage in nfs-idmap-hang.fix (bsc#1105799, bsc#1117042).
- commit 4b31111
* Mon Nov 26 2018 mgorman@suse.de
- blacklist.conf: Add ac5b2c18911f as it should only be applied due to a customer bug
- commit 2b91249
* Thu Nov 22 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-Save-CFAR-before-branching-in-interrupt-entr.patch.
  Fix facility_unavailable (bsc#1116888).
- commit 0eac55a
* Wed Nov 21 2018 mhocko@suse.com
- Update patches.drivers/lib-add-error-checking-to-hex2bin
  (bsc#1107829 CVE-2018-14633).
- commit 6070a12
* Tue Nov 20 2018 ailiopoulos@suse.com
- xfs: don't BUG() on mixed direct and mapped I/O (bsc#1114920).
- commit f792a55
* Mon Nov 19 2018 ailiopoulos@suse.com
- Refresh
  patches.fixes/xfs-stop-searching-for-free-slots-in-an-inode-chunk-.patch.
- commit cb07bc3
* Mon Nov 19 2018 jkosina@suse.cz
- blacklist.conf: blacklist port of script to python3
- commit 2b0c8fa
* Mon Nov 19 2018 mkubecek@suse.cz
- xfrm: use complete IPv6 addresses for hash (bsc#1109330).
- commit 762bf55
* Sat Nov 17 2018 ailiopoulos@suse.com
- xfs: validate sb_logsunit is a multiple of the fs blocksize
  (bsc#1115038).
- commit 39cfaf6
* Fri Nov 16 2018 ailiopoulos@suse.com
- xfs: stop searching for free slots in an inode chunk when
  there are none (bsc#1115007).
- commit d626c29
* Thu Nov 15 2018 tzimmermann@suse.de
- drm/ast: Remove existing framebuffers before loading driver (boo#1112963)
- commit 3f40052
* Wed Nov 14 2018 lduncan@suse.com
- scsi: megaraid_sas: fix macro MEGASAS_IS_LOGICAL to avoid
  regression (bsc#1115839).
- scsi: aacraid: Fix typo in blink status (bsc#1115830).
- commit a8da4c1
* Tue Nov 13 2018 lduncan@suse.com
- scsi: esp_scsi: Track residual for PIO transfers (bsc#1115833).
- scsi: qla2xxx: shutdown chip if reset fail (bsc#1115841).
- scsi: aic94xx: fix an error code in aic94xx_init()
  (bsc#1115831).
- scsi: qla2xxx: Fix ISP recovery on unload (bsc#1115840).
- scsi: qlogicpti: Fix an error handling path in
  'qpti_sbus_probe()' (bsc#1115842).
- scsi: fas216: fix sense buffer initialization (bsc#1115834).
- scsi: libsas: fix error when getting phy events (bsc#1115837).
- scsi: bfa: integer overflow in debugfs (bsc#1115832).
- scsi: lpfc: Don't return internal MBXERR_ERROR code from probe
  function (bsc#1115838).
- scsi: libsas: fix ata xfer length (bsc#1115836).
- scsi: scsi_dh_emc: return success in clariion_std_inquiry()
  (bsc#1115843).
- scsi: aacraid: Reorder Adapter status check (bsc#1115830).
- scsi: megaraid_sas: Fix data integrity failure for JBOD
  (passthrough) devices (bsc#1115839).
- scsi: libfc: Revert " libfc: use offload EM instance again
  instead jumping to next EM" (bsc#1115835).
- megaraid_sas: Fix probing cards without io port (bsc#1115829).
- sg: fix dxferp in from_to case (bsc#1115844).
- aacraid: Fix memory leak in aac_fib_map_free (bsc#1115827).
- arcmsr: upper 32 of dma address lost (bsc#1115828).
- commit 4049f8d
* Tue Nov 13 2018 neilb@suse.com
- blacklist.conf:
- commit fa45a56
* Thu Nov  8 2018 neilb@suse.com
- fscache: Fix dead object requeue (bsc#1107371).
- commit fa52e29
* Wed Nov  7 2018 jroedel@suse.de
- PCI/ASPM: Fix link_state teardown on device removal
  (bsc#1109806).
- commit bb74799
* Tue Nov  6 2018 oneukum@suse.com
- USB: serial: keyspan_pda: verify endpoints at probe
  (bsc#1114672).
- commit bea04c8
* Tue Nov  6 2018 oneukum@suse.com
- blacklist.conf: vulnerable only if support for newer firmware than
  preset in SP4 is included
- commit a4e4acd
* Tue Nov  6 2018 ptesarik@suse.cz
- s390/qdio: don't release memory in qdio_setup_irq() (git-fixes).
- commit 05b1772
* Tue Nov  6 2018 ptesarik@suse.cz
- s390: always save and restore all registers on context switch
  (git-fixes).
- commit 639d669
* Tue Nov  6 2018 ptesarik@suse.cz
- scsi: zfcp: add handling for FCP_RESID_OVER to the fcp ingress
  path (git-fixes).
- commit 4d29694
* Tue Nov  6 2018 ptesarik@suse.cz
- s390/decompressor: fix initrd corruption caused by bss clear
  (git-fixes).
- commit 3d402bc
* Tue Nov  6 2018 neilb@suse.com
- svcrpc: don't leak contexts on PROC_DESTROY (git-fixes).
- svc: Avoid garbage replies when pc_func() returns rpc_drop_reply
  (git-fixes).
- nlm: Ensure callback code also checks that the files match
  (git-fixes).
- Revert "NFS: Make close(2) asynchronous when closing NFS
  O_DIRECT files" (git-fixes).
- NFSv4.1: Fix a kfree() of uninitialised pointers in
  decode_cb_sequence_args (git-fixes).
- NFS: Don't drop CB requests with invalid principals (git-fixes).
- commit 484a312
* Mon Nov  5 2018 oneukum@suse.com
- blacklist.conf: unlikely corner case
- commit a52a2c3
* Mon Nov  5 2018 oneukum@suse.com
- USB: serial: io_ti: fix NULL-deref at open (bsc#1114672).
- commit dd2bc89
* Mon Nov  5 2018 oneukum@suse.com
- USB: serial: cyberjack: fix NULL-deref at open (bsc#1114672).
- commit fcf661c
* Mon Nov  5 2018 oneukum@suse.com
- USB: serial: kl5kusb105: abort on open exception path
  (bsc#1114672).
- commit 6bfc0df
* Mon Nov  5 2018 oneukum@suse.com
- USB: serial: kl5kusb105: fix open error path (bsc#1114672).
- commit 7757557
* Mon Nov  5 2018 oneukum@suse.com
- USB: option: fix Cinterion AHxx enumeration (bsc#1114672).
- commit eab6142
* Mon Nov  5 2018 oneukum@suse.com
- USB: keyspan: fix overrun-error reporting (bsc#1114672).
- commit a4d949c
* Mon Nov  5 2018 oneukum@suse.com
- blacklist.conf: would break kABI
- commit 313e046
* Mon Nov  5 2018 oneukum@suse.com
- USB: keyspan: fix tty line-status reporting (bsc#1114672).
- commit 2f7af28
* Fri Nov  2 2018 mhocko@suse.com
- mremap: properly flush TLB before releasing the page
  (bnc#1113769, CVE-2018-18281).
- commit 432fc1b
* Fri Nov  2 2018 ptesarik@suse.cz
- Refresh
  patches.arch/s390-sles11sp4-11-01-zfcp-fix-fc_host-port_type-with-NPIV.patch.
- commit 52ae8dc
* Fri Nov  2 2018 ptesarik@suse.cz
- Refresh patches.arch/s390-sles11sp4-13-05-qeth-napi-del.patch.
- commit 37a3a19
* Fri Nov  2 2018 ptesarik@suse.cz
- s390: qeth: Fix potential array overrun in cmd/rc lookup
  (bnc#1114440, LTC#172682).
- commit 634b533
* Fri Nov  2 2018 ptesarik@suse.cz
- s390: qeth_core_mpc: Use ARRAY_SIZE instead of reimplementing
  its function (bnc#1114440, LTC#172682).
- commit adcbaa3
* Fri Nov  2 2018 ptesarik@suse.cz
- s390/qdio: reset old sbal_state flags (bnc#1114440, LTC#171525).
- commit 4c5ca3f
* Fri Nov  2 2018 ptesarik@suse.cz
- net/af_iucv: fix skb handling on HiperTransport xmit error
  (bnc#1114440, LTC#172679).
- commit 8e878f4
* Fri Nov  2 2018 ptesarik@suse.cz
- net/af_iucv: drop inbound packets with invalid flags
  (bnc#1114440, LTC#172679).
- commit 92753a8
* Fri Nov  2 2018 bp@suse.de
- firmware/ihex2fw.c: restore missing default in switch statement
  (bsc#1114460).
- blacklist.conf: some doc fixes blacklisted
- commit c1c57b8
* Wed Oct 31 2018 neilb@suse.com
- FS-Cache: When submitting an op, cancel it if the target object is dying (bsc#1107371).
- FS-Cache: Move fscache_report_unexpected_submission() to make it more available (bsc#1107371).
- commit 298a907
* Tue Oct 30 2018 jslaby@suse.cz
- kernel/relay.c: limit kmalloc size to KMALLOC_MAX_SIZE
  (git-fixes).
- commit ddb1ce5
* Tue Oct 30 2018 jslaby@suse.cz
- blacklist.conf: add a merge commit
- commit 997ac9c
* Mon Oct 29 2018 mkoutny@suse.com
- retpoline: Introduce start/end markers of indirect thunk
  (bsc#1113337).
- Refresh
  patches.arch/0001-x86-bugs-Read-SPEC_CTRL-MSR-during-boot-and-re-use-r.patch.
- commit f1f0dab
* Mon Oct 29 2018 tiwai@suse.de
- cdrom: fix improper type cast, which can leat to information
  leak (CVE-2018-18710,bsc#1113751).
- commit 4594c24
* Mon Oct 29 2018 tiwai@suse.de
- Fix invalid free in the fix for mceusb (bsc#1050431)
  ... and refresh patches to remove typos:
  patches.fixes/0001-media-mceusb-fix-NULL-deref-at-probe.patch
  patches.fixes/0001-media-mceusb-fix-memory-leaks-in-error-path.patch
- commit c27deb8
* Thu Oct 25 2018 jgross@suse.com
- blacklist.conf: added 10fe570fc16721d78afdba9689720094527c1ba3 as it
  is relevant for pvops based Xen only, which we don't support in SLE11
- commit 731cc38
* Thu Oct 25 2018 jroedel@suse.de
- x86/percpu: Fix this_cpu_read() (bsc#1110006).
- commit 1faf181
* Wed Oct 24 2018 hare@suse.de
- scsi: libfc: don't advance state machine for incoming FLOGI
  (bsc#1106139).
- scsi: libfc: Do not login if the port is already started
  (bsc#1106139).
- scsi: libfc: Do not drop down to FLOGI for fc_rport_login()
  (bsc#1106139).
- commit 73e27ff
* Wed Oct 24 2018 jgross@suse.com
- x86/paravirt: Fix some warning messages (bnc#1065600).
- commit e05046c
* Wed Oct 24 2018 neilb@suse.com
- add kernel parameter to disable failfast on block devices
  (bsc#1081680).
- commit 2a7870c
* Tue Oct 23 2018 msuchanek@suse.de
- powerpc/64: Fix smp_wmb barrier definition use use lwsync
  consistently (bsc#1064861).
- commit 2436b9f
* Mon Oct 22 2018 msuchanek@suse.de
- powerpc/asm: Mark cr0 as clobbered in mftb() (bsc#1049128).
- commit 3ab6765
* Thu Oct 18 2018 jeffm@suse.com
- reiserfs: don't panic on bad directory entries (bsc#1109818).
- reiserfs: add check to detect corrupted directory entry
  (bsc#1109818).
- commit 475fce9
* Thu Oct 18 2018 jslaby@suse.cz
- n_tty: fix EXTPROC vs ICANON interaction with TIOCINQ (aka
  FIONREAD) (bnc#1094825 bnc#1110711 CVE-2018-18386).
- commit b80a7a6
* Wed Oct 17 2018 ohering@suse.de
- scsi: storvsc: fix memory leak on ring buffer busy (fate#317533
  bnc#923775).
- commit 086e6ee
* Wed Oct 17 2018 ohering@suse.de
- add mainline tags to two hv patches
- commit e6e53ac
* Wed Oct 17 2018 ohering@suse.de
- add mainline tag to one hv patch
- commit ff17913
* Wed Oct 17 2018 oneukum@suse.com
- blacklist.conf: would break kABI
- commit be7a453
* Wed Oct 17 2018 oneukum@suse.com
- blacklist.conf: pure optimization
- commit 57f4b0c
* Wed Oct 17 2018 oneukum@suse.com
- media: cx25821: prevent out-of-bounds read on array card
  (bsc#1050431).
- commit e978cec
* Wed Oct 17 2018 oneukum@suse.com
- [media] mceusb: fix memory leaks in error path.
- commit b31d3cc
* Wed Oct 17 2018 oneukum@suse.com
- [media] mceusb: fix NULL-deref at probe (bsc#1050431).
- commit 9db2e03
* Wed Oct 17 2018 oneukum@suse.com
- [media] ite-cir: initialize use_demodulator before using it
  (bsc#1050431).
- commit 2289c7f
* Wed Oct 17 2018 oneukum@suse.com
- blacklist.conf: only relevant for static build
- commit fc9de08
* Tue Oct 16 2018 tiwai@suse.de
- HID: hid-cypress: validate length of report
  (CVE-2017-7273,bsc#1031240).
- commit 4b6cf85
* Tue Oct 16 2018 tiwai@suse.de
- HID: usbhid: fix out-of-bounds bug (CVE-2017-16533,bsc#1066674).
- commit ed83f56
* Tue Oct 16 2018 ptesarik@suse.cz
- blacklist.conf: Add 68c5cf5a6091 s390: Define AT_VECTOR_SIZE_ARCH for ARCH_DLINFO
  Defining ARCH_DLINFO to a non-zero value increases AT_VECTOR_SIZE,
  which in turn increases saved_auxv[] and changes struct mm_struct,
  breaking kABI all over the place.
  According to the upstrem commit message, this shouldn't be a problem
  as AT_VECTOR_SIZE_BASE includes space for AT_BASE_PLATFORM which s390
  doesn't use.
- commit 4886336
* Tue Oct 16 2018 tiwai@suse.de
- KVM: VMX: remove I/O port 0x80 bypass on Intel hosts
  (CVE-2017-1000407,bsc#1071021).
- commit 52fe1cf
* Tue Oct 16 2018 tiwai@suse.de
- HID: debug: check length before copy_to_user()
  (CVE-2018-9516,bsc#1108498).
- commit c9aa150
* Mon Oct 15 2018 lduncan@suse.com
- Removing the unused function chap_string_to_hex.
  This function should have been removed as part of the patch
  scsi-target-iscsi-use-hex2bin-instead-of-a-re-implementation
  but was not.
- commit 195ecff
* Mon Oct 15 2018 lhenriques@suse.com
- blacklist.conf: CephFS not supported on SLE11-SP4
- commit 50c4c4c
* Mon Oct 15 2018 oneukum@suse.com
- blacklist.conf: just removes unnecessary code
- commit 97b0b8d
* Mon Oct 15 2018 oneukum@suse.com
- blacklist.conf: Documentation on kbuild only
- commit 4ec5959
* Mon Oct 15 2018 oneukum@suse.com
- blacklist.conf: Android build fix
- commit 0f6f0d1
* Mon Oct 15 2018 oneukum@suse.com
- blacklist.conf: readds just Android drivers. Useless in SLE.
- commit ea633be
* Mon Oct 15 2018 oneukum@suse.com
- blacklist.conf: just an optimization
- commit c9b7ef6
* Mon Oct 15 2018 fliu@suse.com
- Revert "btrfs: let btrfs_delete_unused_bgs() to clean relocated bgs"
  This reverts commit 691cb42052f0f680f3483981c1303669f13c984c.
  (bsc#1111798)
- commit d81364d
* Wed Oct 10 2018 fdmanana@suse.com
- Btrfs: fix deadlock when finalizing block group creation
  (bsc#1107849).
- commit 377ebd0
* Wed Oct 10 2018 fdmanana@suse.com
- Btrfs: fix quick exhaustion of the system array in the
  superblock (bsc#1107849).
- commit 3af4b04
* Wed Oct 10 2018 msuchanek@suse.de
- KABI: move the new handler to end of machdep_calls and hide
  it from genksyms (bsc#1094244).
- commit 6e9778a
* Wed Oct 10 2018 msuchanek@suse.de
- powerpc/pseries: Defer the logging of rtas error to irq work queue (bsc#1094244).
- Delete patches.arch/powerpc-pseries-Dump-and-flush-SLB-contents-on-SLB-M.patch.
- powerpc/pseries: Flush SLB contents on SLB MCE errors (bsc#1094244).
- powerpc/pseries: Dump the SLB contents on SLB MCE errors (bsc#1094244).
- Refresh patches.arch/powerpc-pseries-Display-machine-check-error-details.patch.
- Refresh patches.arch/ppc64-bigmem-32-Remove-STAB-code.patch.
- Refresh patches.suse/ppc64-bigmem-introduce-CONFIG_BIGMEM.
- commit 200e344
* Wed Oct 10 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-pseries-Define-MCE-error-event-section.patch.
- commit 97fe041
* Wed Oct 10 2018 msuchanek@suse.de
- powerpc/mce: Fix SLB rebolting during MCE recovery path (bsc#1094244).
- commit c84d1dd
* Wed Oct 10 2018 msuchanek@suse.de
- powerpc/64s: move machine check SLB flushing to mm/slb.c (bsc#1094244).
- Refresh patches.arch/powerpc-pseries-Dump-and-flush-SLB-contents-on-SLB-M.patch.
- Refresh patches.arch/ppc64-bigmem-32-Remove-STAB-code.patch.
- Refresh patches.suse/ppc64-bigmem-introduce-CONFIG_BIGMEM.
- commit 55b9544
* Wed Oct 10 2018 msuchanek@suse.de
- Define early_radix_enabled() (bsc#1094244).
- Refresh patches.arch/ppc64-bigmem-11-mm-Make-some-of-the-PGTABLE_RANGE-dependency-explicit.
- Refresh patches.suse/ppc64-bigmem-introduce-CONFIG_BIGMEM.
- commit 0028b8f
* Wed Oct 10 2018 msuchanek@suse.de
- powerpc, KVM: Rework KVM checks in first-level interrupt
  handlers (bsc#1094244).
- Refresh patches.suse/powerpc-64s-Add-support-for-a-store-forwarding-barri.patch
- Refresh patches.suse/powerpc-64s-Simple-RFI-macro-conversions.patch
- commit 274288d
* Wed Oct 10 2018 msuchanek@suse.de
- powerpc: move MCE handler out-of-line and consolidate with
  machine_check_fwnmi (bsc#1094244).
- commit 2f8234f
* Wed Oct 10 2018 msuchanek@suse.de
- powerpc: replace open-coded EXCEPTION_PROLOG_1 with the macro
  in slb miss handlers (bsc#1094244).
- Refresh patches.suse/powerpc-64s-Add-support-for-a-store-forwarding-barri.patch
- commit 6fa998e
* Wed Oct 10 2018 msuchanek@suse.de
- powerpc: move stab code into #ifndef CONFIG_POWER4_ONLY
  (bsc#1094244).
- Refresh patches.arch/ppc64-bigmem-32-Remove-STAB-code.patch
- Refresh patches.suse/powerpc-64s-Simple-RFI-macro-conversions.patch
- Refresh patches.suse/ppc64-bigmem-introduce-CONFIG_BIGMEM
- commit 8d2e941
* Mon Oct  8 2018 rgoldwyn@suse.com
- locks: fix unlock when fcntl_setlk races with a close (git-fixes).
- blacklist.conf: Added some invasive patches, which are
  primarily performance improvements, not bug fixes
- commit f397cce
* Mon Oct  8 2018 jslaby@suse.cz
- blacklist.conf: add vdso vs retpoline commit
  We do not need it as it is fixing the RETPOLINE=n case.
- commit bf43307
* Mon Oct  8 2018 jroedel@suse.de
- blacklist.conf: 02e425668f5c x86/vdso: Fix vDSO syscall fallback asm constraint regression
  The functions fixes in this patch are not patched in the
  original commit either, because they do not exist yet in
  3.0.
- commit a63e188
* Mon Oct  8 2018 jroedel@suse.de
- x86/vdso: Fix asm constraints on vDSO syscall fallbacks
  (bsc#1110006).
- commit 20b4280
* Mon Oct  8 2018 mgorman@suse.de
- percpu: make pcpu_alloc_chunk() use pcpu_mem_free() instead
  of kfree() (git fixes).
- commit 5f023a8
* Fri Oct  5 2018 msuchanek@suse.de
- powerpc: Fix smp_mb__before_spinlock() (bsc#1110247).
- commit f945769
* Wed Oct  3 2018 jkosina@suse.cz
- README.BRANCH: make Michal Hocko primary branch maintainer
- commit bd9ef70
* Wed Oct  3 2018 jkosina@suse.cz
- README.BRANCH: add Michal Hocko as primary branch maintainer
- commit 01cdf50
* Wed Oct  3 2018 alnovak@suse.cz
- signals: avoid unnecessary taking of sighand->siglock
  (bsc#1110247).
- commit dcccca7
* Wed Oct  3 2018 ptesarik@suse.cz
- s390/facilites: use stfle_fac_list array size for
  MAX_FACILITY_BIT (bnc#1108314, LTC#171326).
- commit b4179ed
* Wed Oct  3 2018 ptesarik@suse.cz
- s390/sclp: Change SCLP console default buffer-full behavior
  (bnc#1108314, LTC#171049).
- commit d21c3d6
* Tue Oct  2 2018 lduncan@suse.com
- scsi: target: iscsi: Use bin2hex instead of a re-implementation
  (bsc#1107829 CVE-2018-14633).
- scsi: target: iscsi: Use hex2bin instead of a re-implementation
  (bsc#1107829 CVE-2018-14633).
- Provide a binary to hex conversion function (bsc#1107829
  CVE-2018-14633).
- lib: add error checking to hex2bin (bsc#11078229
  CVE-2018-14633).
- commit 4ef2848
* Tue Oct  2 2018 jroedel@suse.de
- blacklist.conf: Add 9b8ae63798cb97e785a667ff27e43fa6220cb734
- commit ed0dd05
* Tue Oct  2 2018 jroedel@suse.de
- KVM: VMX: remove I/O port 0x80 bypass on Intel hosts
  (bsc#1106240).
- commit 90e4803
* Tue Oct  2 2018 jroedel@suse.de
- KVM: x86: emulator: Return to user-mode on L1 CPL=0 emulation
  failure (bsc#1106240).
- KVM: SVM: obey guest PAT (bsc#1106240).
- KVM: x86: zero base3 of unusable segments (bsc#1106240).
- KVM: x86: fix use of uninitialized memory as segment descriptor
  in emulator (bsc#1106240).
- KVM: Disable irq while unregistering user notifier
  (bsc#1106240).
- KVM: emulate: fix CMPXCHG8B on 32-bit hosts (bsc#1106240).
- commit 0ca152d
* Tue Oct  2 2018 neilb@suse.com
- FS-Cache: Synchronise object death state change vs operation
  submission (bsc#1107371).
- commit cc39c2e
* Mon Oct  1 2018 jslaby@suse.cz
- blacklist.conf: add virtio_console patch
- commit 5a81833
* Mon Oct  1 2018 mhocko@suse.com
- Delete
  patches.suse/mm-vmacache-optimize-overflow-system-wide-flushing.patch
  (bnc#1108399, CVE-2018-17182)
- commit 736bcf9
* Fri Sep 28 2018 jslaby@suse.cz
- x86/fpu: Don't do __thread_fpu_end() if use_eager_fpu()
  (bnc#1109967).
- commit 1f1a471
* Fri Sep 28 2018 jroedel@suse.de
- blacklist.conf: Blacklist 5 patches for x86 which are not needed in SLE11-SP4
- commit 61f562d
* Fri Sep 28 2018 jroedel@suse.de
- x86/process: Re-export start_thread() (bsc#1110006).
- commit b58a7f3
* Fri Sep 28 2018 jroedel@suse.de
- x86/kexec: Avoid double free_page() upon do_kexec_load()
  failure (bsc#1110006).
- commit 9e43e35
* Fri Sep 28 2018 jroedel@suse.de
- x86/mm/32: Set the '__vmalloc_start_set' flag in initmem_init()
  (bsc#1110006).
- crypto: ghash-clmulni-intel - use C implementation for setkey()
  (bsc#1110006).
- commit b6ac1e6
* Thu Sep 27 2018 jroedel@suse.de
- PCI: shpchp: Fix AMD POGO identification (bsc#1109806).
- PCI/AER: Report non-fatal errors only to the affected endpoint
  (bsc#1109806).
- PCI: Supply CPU physical address (not bus address) to
  iomem_is_exclusive() (bsc#1109806).
- PCI: shpchp: Check bridge's secondary (not primary) bus speed
  (bsc#1109806).
- commit 2e3d647
* Thu Sep 27 2018 jeffm@suse.com
- selinux/nlmsg: add XFRM_MSG_MIGRATE (bsc#1109946 Git-fixes).
- selinux/nlmsg: add XFRM_MSG_REPORT (bsc#1109945 Git-fixes).
- selinux/nlmsg: add XFRM_MSG_MAPPING (bsc#1109944 Git-fixes).
- selinux/nlmsg: add XFRM_MSG_[NEW|GET]SADINFO (bsc#1109943
  Git-fixes).
- selinux/nlmsg: add XFRM_MSG_GETSPDINFO (bsc#1109942 Git-fixes).
- selinux/nlmsg: add XFRM_MSG_NEWSPDINFO (bsc#1109941 Git-fixes).
- commit 968c469
* Wed Sep 26 2018 jeffm@suse.com
- bnx2x: use the right constant (Git-fixes bsc#1109922).
- commit 5f89219
* Wed Sep 26 2018 jeffm@suse.com
- btrfs: fix missing error return in btrfs_drop_snapshot
  (Git-fixes).
- commit 7e87cdf
* Wed Sep 26 2018 jeffm@suse.com
- ubifs: Check for name being NULL while mounting (Git-fixes
  bsc#1109913).
- commit 912ec02
* Wed Sep 26 2018 jeffm@suse.com
- hostfs: Freeing an ERR_PTR in hostfs_fill_sb_common()
  (Git-fixes bsc#1109901).
- commit b91d630
* Wed Sep 26 2018 jeffm@suse.com
- fscache: Fix reference overput in fscache_attach_object()
  error handling (Git-fixes bsc#1109751).
- commit a0bbcdc
* Wed Sep 26 2018 jeffm@suse.com
- fscache: Allow cancelled operations to be enqueued (Git-fixes
  bsc#1109750).
- commit b0c95ef
* Wed Sep 26 2018 jeffm@suse.com
- cachefiles: Wait rather than BUG'ing on "Unexpected object
  collision" (Git-fixes bsc#1109749).
- commit cda96e5
* Wed Sep 26 2018 jeffm@suse.com
- cachefiles: Fix refcounting bug in backing-file read monitoring
  (Git-fixes bsc#1109748).
- commit ae53ba2
* Wed Sep 26 2018 jeffm@suse.com
- cachefiles: Fix missing clear of the CACHEFILES_OBJECT_ACTIVE
  flag (Git-fixes bsc#1109747).
- commit a10f69a
* Wed Sep 26 2018 jeffm@suse.com
- fs/binfmt_misc.c: do not allow offset overflow (Git-fixes
  bsc#1109746).
- commit b89e0d6
* Tue Sep 25 2018 jeffm@suse.com
- binfmt_elf: Respect error return from `regset->active'
  (Git-fixes bsc#1109740).
- commit 8412afc
* Tue Sep 25 2018 jeffm@suse.com
- reiserfs: fix broken xattr handling (heap corruption, bad
  retval) (Git-fixes bsc#1109734).
- commit 7a624d5
* Tue Sep 25 2018 jeffm@suse.com
- reiserfs: fix buffer overflow with long warning messages
  (Git-fixes bsc#1109733).
- commit 2a2fbde
* Tue Sep 25 2018 nstange@suse.de
- x86/fpu: fix signal handling with eager FPU switching (ia32)
  (bsc#1108227).
- commit 52c5b76
* Mon Sep 24 2018 jeffm@suse.com
- epoll: fix race between ep_poll_callback(POLLFREE) and ep_free()/ep_remove() (Git-fixes bsc#1109517).
- commit d130dcf
* Mon Sep 24 2018 bp@suse.de
- cpu/hotplug: Fix SMT supported evaluation (bsc#1089343
  CVE-2018-3646).
- commit a0b3948
* Mon Sep 24 2018 bp@suse.de
- Refresh
  patches.arch/0012-cpu-hotplug-detect-SMT-disabled-by-BIOS.patch.
- commit 7fad702
* Mon Sep 24 2018 jroedel@suse.de
- Refresh
  patches.arch/0003-x86-l1tf-Handle-EPT-disabled-state-proper.patch.
- commit fc11ed6
* Mon Sep 24 2018 tabraham@suse.com
- dm: only initialize the request_queue once (bsc#1047027).
- dm: fix incomplete request_queue initialization (bsc#1047027).
- block: allow gendisk's request_queue registration to be deferred
  (bsc#1047027).
- block: add flag QUEUE_FLAG_REGISTERED (bsc#1047027).
- commit 9e379ff
* Fri Sep 21 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-Avoid-code-patching-freed-init-sections.patch.
- commit c70fcdb
* Fri Sep 21 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-fadump-re-register-firmware-assisted-dump-if.patch.
- commit 06e6e63
* Wed Sep 19 2018 jkosina@suse.cz
- rpm/kernel-docs.spec.in: Fix mismerge, take two
- commit 9ef6e0d
* Wed Sep 19 2018 jkosina@suse.cz
- rpm/kernel-docs.spec.in: fix mismerge
- commit d67c2bd
* Wed Sep 19 2018 mhocko@suse.com
- exec: Limit arg stack to at most 75%% of _STK_LIM (bnc#1108912,
  CVE-2018-14634).
- commit 1a45952
* Tue Sep 18 2018 msuchanek@suse.de
- powerpc/fadump: re-register firmware-assisted dump if already
  registered (bsc#1108170, bsc#1108823).
- commit e68d7bf
* Thu Sep 13 2018 msuchanek@suse.de
- powerpc/fadump: Do not use hugepages when fadump is active
  (bsc#1092772, bsc#1107650).
- powerpc/fadump: exclude memory holes while reserving memory
  in second kernel (bsc#1092772, bsc#1107650).
- commit eec0092
* Thu Sep 13 2018 nborisov@suse.com
- hfsplus: fix NULL dereference in hfsplus_lookup() (bsc#1102870, CVE-2018-14617).
- commit 275b9fb
* Wed Sep 12 2018 nsaenzjulienne@suse.de
- USB: yurex: fix out-of-bounds uaccess in read handler (bsc#1106095, CVE-2018-16276).
- commit 2d7c632
* Wed Sep 12 2018 wqu@suse.com
- btrfs: scrub: Don't use inode page cache in
  scrub_handle_errored_block() (bsc#1108096).
- commit 188fe3a
* Wed Sep 12 2018 wqu@suse.com
- btrfs: scrub: Don't use inode pages for device replace
  (bsc#1107949).
- commit 8378627
* Tue Sep 11 2018 tiwai@suse.de
- kABI workaround for posix-timers it_overrun 64bit changes
  (CVE-2018-12896,bsc#1099922).
- posix-timers: Sanitize overrun handling
  (CVE-2018-12896,bsc#1099922).
- commit 617e902
* Tue Sep 11 2018 nsaenzjulienne@suse.de
- usbip: vhci_sysfs: fix potential Spectre v1 (bsc#1096547).
- commit 2f9fa03
* Tue Sep 11 2018 mwilck@suse.com
- cdrom: information leak in cdrom_ioctl_media_changed()
  (bnc#1012382, bsc#1092903, CVE-2018-10940).
- commit 0dbfd41
* Tue Sep 11 2018 mhocko@suse.com
- Refresh
  patches.arch/0001-x86-speculation-l1tf-Increase-l1tf-memory-limit-for-.patch.
- Refresh
  patches.kabi/0001-x86-kabi-speculation-l1tf-Increase-l1tf-memory-limit-for-.patch.
- commit 9c75ccd
* Mon Sep 10 2018 msuchanek@suse.de
- powerpc: Avoid code patching freed init sections (bnc#1107735).
- commit 6723116
* Mon Sep 10 2018 bpoirier@suse.com
- Refresh
  patches.fixes/qlge-Fix-netdev-features-configuration.patch.
- commit f7bc06b
* Fri Sep  7 2018 tiwai@suse.de
- cdrom: Fix info leak/OOB read in cdrom_ioctl_drive_status
  (CVE-2018-16658,bsc#1107689).
- commit d8fa03f
* Fri Sep  7 2018 mkubecek@suse.cz
- irda: Only insert new objects into the global database via
  setsockopt (CVE-2018-6555 bsc#1106511).
- irda: Fix memory leak caused by repeated binds of irda socket
  (CVE-2018-6554 bsc#1106509).
- commit d6ff750
* Fri Sep  7 2018 jthumshirn@suse.de
- Refresh
  patches.arch/s390-sles11sp4-35-03-ftrace-expolines.patch.
  Fix 31 Bit s390 build
- commit 3c31bbc
* Wed Sep  5 2018 mhocko@suse.com
- blacklist.conf: a6f572084fbe mm/tlb: Remove tlb_remove_table() non-concurrent condition
- commit 9e7d4c9
* Wed Sep  5 2018 mhocko@suse.com
- blacklist.conf: 777c6e0daebb hotplug: Make register and unregister notifier API symmetric
- commit b625d89
* Wed Sep  5 2018 neilb@suse.com
- NFSv4.1 - Don't leak IO size from one mount to another
  (bsc#1103145).
- commit a62c93a
* Tue Sep  4 2018 jslaby@suse.cz
- x86/vdso: Fix vDSO build if a retpoline is emitted (git-fixes).
- Delete patches.suse/05.2-x86-vdso-remove-retpoline-flags.patch.
- tty: vt, return error when con_startup fails (git-fixes).
- tty: vt, fix bogus division in csi_J (git-fixes).
- applicom: dereferencing NULL on error path (git-fixes).
- base: make module_create_drivers_dir race-free (git-fixes).
- commit 7d69d36
* Tue Sep  4 2018 jslaby@suse.cz
- blacklist.conf: m68k is not our cup of tea
- commit 02164db
* Tue Sep  4 2018 mhocko@suse.com
- mm/hugetlb: add migration/hwpoisoned entry check in
  hugetlb_change_protection (bnc#1107071).
- commit 4e5a707
* Tue Sep  4 2018 mhocko@suse.com
- mm/mempolicy.c: avoid use uninitialized preferred_node
  (bnc#1107064).
- commit 7844aeb
* Tue Sep  4 2018 mhocko@suse.com
- blacklist.conf: 128227e7fe40 ("slab: __GFP_ZERO is incompatible with a constructor")
- commit b609324
* Tue Sep  4 2018 jgross@suse.com
- x86/paravirt: Fix spectre-v2 mitigations for paravirt guests
  (bnc#1105348, CVE-2018-15594).
- commit bdb58d2
* Tue Sep  4 2018 mhocko@suse.com
- blacklist.conf: fc5d1073cae2 x86/mm/32: Remove unused node_memmap_size_bytes() & CONFIG_NEED_NODE_MEMMAP_SIZE logic
- commit 57086e4
* Tue Sep  4 2018 mhocko@suse.com
- blacklist.conf: f113e64121ba mm/vmstat.c: fix wrong comment
- commit 94b9858
* Tue Sep  4 2018 mhocko@suse.com
- blacklist.conf: 955c97f0859a mm/swapfile.c: fix swap_count comment about nonexistent SWAP_HAS_CONT
- commit 5e94ed3
* Tue Sep  4 2018 mhocko@suse.com
- ptrace: fix PTRACE_LISTEN race corrupting task->state
  (bnc#1107001).
- commit 649c463
* Tue Sep  4 2018 jthumshirn@suse.de
- s390: detect etoken facility (bnc#1106930, LTC#171029).
- s390: Correct register corruption in critical section cleanup
  (bnc#1106930, LTC#171029).
- s390: remove indirect branch from do_softirq_own_stack
  (bnc#1106930, LTC#171029).
- s390: move spectre sysfs attribute code (bnc#1106930,
  LTC#171029).
- s390/kernel: use expoline for indirect branches (bnc#1106930,
  LTC#171029).
- s390/ftrace: use expoline for indirect branches (bnc#1106930,
  LTC#171029).
- s390: move expoline assembler macros to a header (bnc#1106930,
  LTC#171029).
- s390: add assembler macros for CPU alternatives (bnc#1106930,
  LTC#171029).
- commit 9cd7222
* Tue Sep  4 2018 mhocko@suse.com
- sys: don't hold uts_sem while accessing userspace memory
  (bnc#1106995).
- commit c8b8f4f
* Mon Sep  3 2018 jkosina@suse.cz
- Refresh
  patches.arch/0010-x86-bugs-kvm-Introduce-boot-time-control-of-L1TF-mit.patch: fix
  kernel documentation reference URL
- commit f828b32
* Mon Sep  3 2018 jthumshirn@suse.de
- s390/qeth: don't clobber buffer on async TX completion
  (bnc#1060245, LTC#170349).
- commit fb55acf
* Mon Sep  3 2018 oneukum@suse.com
- blacklist.conf: this is too untested
- commit 1547be4
* Mon Sep  3 2018 oneukum@suse.com
- blacklist.conf: cosmetic fix, no code change
- commit b1af7a9
* Mon Sep  3 2018 oneukum@suse.com
- blacklist.conf: we do not build m68k alas
- commit b600530
* Mon Sep  3 2018 tzimmermann@suse.de
- fbdev: omapfb: off by one in omapfb_register_client() (bsc#1106886).
- commit 49167c5
* Mon Sep  3 2018 oneukum@suse.com
- USB: serial: io_ti: fix NULL-deref in interrupt callback
  (bsc#1106609).
- commit e7ac7bd
* Mon Sep  3 2018 oneukum@suse.com
- ath5k: Change led pin configuration for compaq c700 laptop
  (bsc#1048185).
- commit e44b453
* Mon Sep  3 2018 tzimmermann@suse.de
- drm/vmwgfx: Handle vmalloc() failure in vmw_local_fifo_reserve() (bsc#1106886).
- commit 5026cfe
* Mon Sep  3 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/i915/lvds: Move acpi lid notification registration to registration phase'
- commit dc2dd0f
* Mon Sep  3 2018 tzimmermann@suse.de
- drm/i915: Remove bogus __init annotation from DMI callbacks (bsc#1106886).
- commit 9963812
* Mon Sep  3 2018 oneukum@suse.com
- blacklist.conf: error return not used
- commit dd4ce6f
* Mon Sep  3 2018 oneukum@suse.com
- blacklist.conf: API breakage
- commit 029930e
* Mon Sep  3 2018 oneukum@suse.com
- PCI: Fix TI816X class code quirk (bsc#1050431).
- commit fe90d1d
* Mon Sep  3 2018 mgorman@suse.de
- blacklist.conf: cosmetic fix of a comment
- commit 65c6f68
* Mon Sep  3 2018 oneukum@suse.com
- blacklist.conf: we don't even compile the architecture
- commit 29ceba2
* Mon Sep  3 2018 oneukum@suse.com
- blacklist.conf: no point in backporting build fix for SLE11
- commit 757f430
* Mon Sep  3 2018 oneukum@suse.com
- blacklist.conf: cosmetic fix to the build system
- commit 588313a
* Mon Sep  3 2018 tzimmermann@suse.de
- drm/nouveau/gem: off by one bugs in nouveau_gem_pushbuf_reloc_apply() (bsc#1106886).
- commit 916b259
* Mon Sep  3 2018 tzimmermann@suse.de
- drm: crtc: integer overflow in drm_property_create_blob() (bsc#1106886).
- commit 4b0bc11
* Mon Sep  3 2018 jroedel@suse.de
- KVM: VMX: fixes for vmentry_l1d_flush module parameter
  (bsc#1106369).
- commit 151d575
* Mon Sep  3 2018 jroedel@suse.de
- KVM: VMX: Work around kABI breakage in 'enum vmx_l1d_flush_state' (bsc#1106369).
- commit bdb11dd
* Thu Aug 30 2018 oneukum@suse.com
- blacklist.conf: breaks API
- commit 6858bd6
* Thu Aug 30 2018 tiwai@suse.de
- blacklist.conf: Add a bogus usb-audio fix
- commit 6b50e1e
* Thu Aug 30 2018 tiwai@suse.de
- resource: fix integer overflow at reallocation (bsc#1045538).
- ACPI: APEI / ERST: Fix missing error handling in erst_reader()
  (bsc#1045538).
- ALSA: snd-aoa: add of_node_put() in error path (bsc#1045538).
- ALSA: fm801: propagate TUNER_ONLY bit when autodetected
  (bsc#1045538).
- ASoC: blackfin: Fix missing break (bsc#1045538).
- ALSA: pcm: Use dma_bytes as size parameter in
  dma_mmap_coherent() (bsc#1045538).
- ALSA: pcm: Fix snd_pcm_hw_params struct copy in compat mode
  (bsc#1045538).
- ALSA: pcm: fix fifo_size frame calculation (bsc#1045538).
- usb: audio-v2: Correct the comment for struct
  uac_clock_selector_descriptor (bsc#1045538).
- ALSA: usb-audio: Fix parsing descriptor of UAC2 processing unit
  (bsc#1045538).
- ALSA: usb-audio: Fix UAC2 get_ctl request with a RANGE attribute
  (bsc#1045538).
- ALSA: usb-audio: Fix parameter block size for UAC2 control
  requests (bsc#1045538).
- ALSA: usb-audio: Set correct type for some UAC2 mixer controls
  (bsc#1045538).
- ALSA: usb-audio: Add sanity checks in v2 clock parsers
  (bsc#1045538).
- ALSA: usb-audio: Fix potential out-of-bound access at parsing SU
  (bsc#1045538).
- ALSA: usb-audio: Add sanity checks to FE parser (bsc#1045538).
- ALSA: usb-audio: Fix bogus error return in
  snd_usb_create_stream() (bsc#1045538).
- commit ae9cb3a
* Tue Aug 28 2018 mkoutny@suse.com
- x86/init: fix build with CONFIG_SWAP=n (bsc#1105723).
- commit 11b5ea7
* Tue Aug 28 2018 jack@suse.cz
- blacklist.conf: Blacklist 4ddd56b003f2
- commit 90f5b0c
* Tue Aug 28 2018 jack@suse.cz
- tracing/blktrace: Fix to allow setting same value (bsc#1106212).
- commit 4b3de2c
* Tue Aug 28 2018 jack@suse.cz
- block: fix an error code in add_partition() (bsc#1106209).
- commit 863f31c
* Tue Aug 28 2018 jack@suse.cz
- nbd: ratelimit error msgs after socket close (bsc#1106206).
- commit 2b5b557
* Tue Aug 28 2018 jack@suse.cz
- uml: fix hostfs mknod() (bsc#1106202).
- commit a313e98
* Tue Aug 28 2018 jack@suse.cz
- blacklist.conf: Blacklist 378831e4daec
- commit 3a93c21
* Tue Aug 28 2018 jack@suse.cz
- blacklist.conf: Blacklist ubifs fixes
- commit 8cd7713
* Tue Aug 28 2018 jack@suse.cz
- blacklist.conf: Blacklist eeece469deda
- commit fa0d7cc
* Tue Aug 28 2018 jack@suse.cz
- ncpfs: return proper error from NCP_IOC_SETROOT ioctl
  (bsc#1106199).
- commit b4fdf08
* Mon Aug 27 2018 msuchanek@suse.de
- TPM: Zero buffer whole after copying to userspace (bsc#1050381).
- commit cb30e50
* Mon Aug 27 2018 jroedel@suse.de
- x86/mm: Prevent kernel Oops in PTDUMP code with HIGHPTE=y
  (bsc#1106105).
- commit 4556215
* Mon Aug 27 2018 jroedel@suse.de
- iommu/vt-d: Don't over-free page table directories
  (bsc#1106105).
- iommu/amd: Finish TLB flush in amd_iommu_unmap() (bsc#1106105).
- iommu/amd: Free domain id when free a domain of struct
  dma_ops_domain (bsc#1106105).
- iommu/vt-d: Ratelimit each dmar fault printing (bsc#1106105).
- iommu/amd: Fix the left value check of cmd buffer (bsc#1106105).
- iommu/amd: Update Alias-DTE in update_device_table()
  (bsc#1106105).
- commit eca4bb2
* Mon Aug 27 2018 mhocko@suse.com
- kabi: x86/speculation/l1tf: Increase l1tf memory limit for
  Nehalem+ (bnc#1105536).
- xen x86/speculation/l1tf: Increase l1tf memory limit for
  Nehalem+ (bnc#1105536).
- xen x86/speculation/l1tf: Fix off-by-one error when warning
  that system has too much RAM (bnc#1105536).
- xen: x86/speculation/l1tf: Fix overflow in l1tf_pfn_limit()
  on 32bit (bnc#1087081).
- kabi: x86/speculation/l1tf: Increase l1tf memory limit for
  Nehalem+ (bnc#1105536).
- x86/speculation/l1tf: Increase l1tf memory limit for Nehalem+
  (bnc#1105536).
- x86/speculation/l1tf: Suggest what to do on systems with too
  much RAM (bnc#1105536).
- x86/speculation/l1tf: Fix off-by-one error when warning that
  system has too much RAM (bnc#1105536).
- commit 8622ace
* Mon Aug 27 2018 jbeulich@suse.com
- Refresh
  patches.xen/xen3-x86-l1tf-04-protect-PROT_NONE-ptes.patch
  (bsc#1105100).
- commit efd0155
* Mon Aug 27 2018 neilb@suse.com
- NFS - don't hang if xdr decoded username is bad (bsc#1105799).
- commit 22c6058
* Mon Aug 27 2018 tonyj@suse.de
- perf/x86/intel: Add cpu_(prepare|starting|dying) for core_pmu
  (bsc#1104901).
- commit 2db3f6d
* Sun Aug 26 2018 jslaby@suse.cz
- x86: uninline kernel_fpu_end (bnc#1087086 CVE-2018-3665).
- commit f3f010c
* Fri Aug 24 2018 msuchanek@suse.de
- tpm: fix race condition in tpm_common_write() (bsc#1050381).
- commit 29fce27
* Fri Aug 24 2018 msuchanek@suse.de
- powerpc/lib: Fix the feature fixup tests to actually work
  (bsc#1064861).
- powerpc/lib: Fix off-by-one in alternate feature patching
  (bsc#1064861).
- powerpc: make feature-fixup tests fortify-safe (bsc#1064861).
- commit 75ea8cd
* Fri Aug 24 2018 msuchanek@suse.de
- powerpc/64s: Default l1d_size to 64K in RFI fallback flush
  (bsc#1068032, git-fixes).
- commit fd91ef0
* Fri Aug 24 2018 msuchanek@suse.de
- powerpc64s: Show ori31 availability in spectre_v1 sysfs file
  not v2 (bsc#1068032, bsc#1080157, git-fixes).
- commit 6304556
* Fri Aug 24 2018 bpoirier@suse.com
- qlge: Fix netdev features configuration (bsc#1098822).
- commit 1fd745b
* Thu Aug 23 2018 tonyj@suse.de
- scripts/sequence_patch
  Revert dd15feb3 (mcgrof@suse.com bump patch version req to v2.7)
  Version 2.5.9 is highest available for SLE11-SP4
- Delete scripts/ld-version.sh.
- commit 3f5f91f
* Thu Aug 23 2018 msuchanek@suse.de
- Add mainline tag
- Refresh patches.arch/powerpc-64s-Fix-compiler-store-ordering-to-SLB-shado.patch.
- Refresh patches.arch/powerpc-mm-hash-Add-missing-isync-prior-to-kernel-st.patch.
- commit 244e575
* Thu Aug 23 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/i915/lvds: Move acpi lid notification registration to registration phase'
- commit 639201e
* Wed Aug 22 2018 jthumshirn@suse.de
- dasd: Add IFCC notice message (bnc#1104481, LTC#170484).
- commit 6cd2e87
* Wed Aug 22 2018 oneukum@suse.com
- USB: serial: sierra: fix potential deadlock at close
  (bsc#1100132).
- commit 0922022
* Tue Aug 21 2018 mhocko@suse.com
- x86/speculation: Protect against userspace-userspace spectreRSB
  (bnc#1102517, CVE-2018-15572).
- commit 9d96257
* Tue Aug 21 2018 jeyu@suse.de
- Enforce module signatures if the kernel is locked down
  (bsc#1093666, fate#314486).
- module: make it clear when we're handling the module copy in
  info->hdr (bsc#1093666).
- module: setup load info before module_sig_check() (bsc#1093666).
- modsign: log module name in the event of an error (bsc#1093666).
- modsign: print module name along with error message
  (bsc#1093666).
- blacklist.conf: Blacklist 4d58e7034d19
- Refresh
  patches.arch/0001-module-retpoline-Warn-about-missing-retpoline-in-mod.patch.
- Refresh
  patches.suse/0005-MODSIGN-Add-module-certificate-blacklist-keyring.patch.
- commit 2ed1d54
* Tue Aug 21 2018 mhocko@suse.com
- patches.arch/x86-speculation-l1tf-Fix-overflow-in-l1tf_pfn_limit-.patch:
  x86/speculation/l1tf: Fix overflow in l1tf_pfn_limit() on 32bit
  (bnc#1087081).
- commit 0928c0a
* Tue Aug 21 2018 tiwai@suse.de
- ALSA: rawmidi: Change resized buffers atomically
  (CVE-2018-10902,bsc#1105322).
- commit de552ad
* Wed Aug 15 2018 mhocko@suse.com
- xen, x86, l1tf: Protect PROT_NONE PTEs against speculation fixup
  (bnc#1104684, bnc#1104818).
- commit c45dde0
* Wed Aug 15 2018 mhocko@suse.com
- x86, l1tf: Protect PROT_NONE PTEs against speculation fixup
  (bnc#1104684, bnc#1104818).
- Delete patches.arch/disable-prot_none_mitigation.patch.
- commit ae92c90
* Wed Aug 15 2018 ydfan@suse.com
- ipv6: Regenerate host route according to node pointer upon
  loopback up (bsc#1100705).
- commit 5055a35
* Wed Aug 15 2018 jslaby@suse.cz
- KVM: VMX: Make indirect call speculation safe (bsc#1068032
  CVE-2017-5754).
- x86/retpoline/entry: Convert entry assembler indirect jumps --
  ia32 (bsc#1068032 CVE-2017-5715).
- commit b3b6dd5
* Tue Aug 14 2018 mgalbraith@suse.de
- perf/core: Fix group scheduling with mixed hw and sw events (Git-fixes).
- commit dc31b12
* Tue Aug 14 2018 mgalbraith@suse.de
- blacklist.conf: add 7be8c56f8f8a58af92f8791c5a09d48e342d7101
- commit ce30977
* Tue Aug 14 2018 jslaby@suse.cz
- x86-non-upstream-eager-fpu external modules fix (bnc#1087086
  CVE-2018-3665 bnc#1100091 bnc#1099598).
  Just fix some typos and mistakes.
- commit 68c19a5
* Tue Aug 14 2018 mgalbraith@suse.de
- kthread, tracing: Don't expose half-written comm when creating kthreads (Git-fixes).
- commit 3b9b184
* Mon Aug 13 2018 mhocko@suse.com
- patches.arch/disable-prot_none_mitigation.patch: disable prot_none
  native mitigation (bnc#1104684)
- commit ef94234
* Mon Aug 13 2018 mhocko@suse.com
- x86/mm: Simplify p[g4um]d_page() macros (bnc#1087081,
  bnc#1104684).
- commit 5af6cf5
* Mon Aug 13 2018 mhocko@suse.com
- fix pgd underflow (bnc#1104475)
  custom walk_page_range rework was incorrect and could underflow pgd if
  the given range was below a first vma.
- commit c64d595
* Fri Aug 10 2018 tbogendoerfer@suse.de
- infiniband: fix a possible use-after-free bug (bsc#1103119
  CVE-2018-14734).
- commit f93994d
* Wed Aug  8 2018 mhocko@suse.com
- Refresh
  patches.fixes/0001-usbip-usbip_host-fix-NULL-ptr-deref-and-use-after-fr.patch.
  Fix build warning:
  drivers/staging/usbip/stub_dev.c: In function 'stub_probe':
  drivers/staging/usbip/stub_dev.c:482: warning: control reaches end of non-void function
  which is a result of misbackported patch.
- commit 4428024
* Wed Aug  8 2018 mhocko@suse.com
- Revert "KEYS: encrypted: fix buffer overread in valid_master_desc()"
  This reverts commit 506e0787b9adfa1e8b53f9363707359b754f9c41 because
  KEYS subsystem has diverged in cve/linux-3.0 consumers and so the fix
  has to be applied on each one separately.
- commit 531a67f
* Mon Aug  6 2018 msuchanek@suse.de
- powerpc/64: Do load of PACAKBASE in LOAD_HANDLER (bsc#1094244).
- commit 2989633
* Mon Aug  6 2018 msuchanek@suse.de
- powerpc: Make load_hander handle upto 64k offset (bsc#1094244).
- commit 695ef3f
* Mon Aug  6 2018 oneukum@suse.com
- USB: add USB_DEVICE_INTERFACE_CLASS macro (bsc#1047487).
- commit b09e426
* Mon Aug  6 2018 oneukum@suse.com
- USB: visor: Match I330 phone more precisely (bsc#1047487).
- commit 6dfbfb7
* Mon Aug  6 2018 oneukum@suse.com
- USB: hub: fix non-SS hub-descriptor handling (bsc#1047487).
- commit de61a36
* Mon Aug  6 2018 oneukum@suse.com
- USB: serial: io_edgeport: fix possible sleep-in-atomic
  (bsc#1037441).
- commit 1bf04bf
* Mon Aug  6 2018 oneukum@suse.com
- smsc75xx: Add workaround for gigabit link up hardware errata
  (bsc#1100132).
- commit cdbd6a1
* Mon Aug  6 2018 tzimmermann@suse.de
- drm/i915: fix use-after-free in page_flip_completed() (bsc#1103909).
- commit c096820
* Mon Aug  6 2018 oneukum@suse.com
- USB: serial: ftdi_sio: fix latency-timer error handling
  (bsc#1037441).
- commit 5ce908e
* Mon Aug  6 2018 tzimmermann@suse.de
- drm: re-enable error handling (bsc#1103884)
- series.conf: Remove trailing whitespaces
- commit ca6c5b4
* Mon Aug  6 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/i915: fix error path in intel_setup_gmbus()'
- commit 19acfff
* Fri Aug  3 2018 neilb@suse.com
- Remove patches.fixes/0001-NFSv4-fix-getacl-head-length-estimation.patch
- blacklist.conf:
- Delete
  patches.fixes/0001-NFSv4-fix-getacl-head-length-estimation.patch.
  Bug#1103145 - This patch was added, removed, and added again.
  Oops.
  This time it is listed in blacklist.conf so I won't make the same
  mistake again.
- commit e886bea
* Thu Aug  2 2018 jkosina@suse.cz
- x86/fpu: fix signal handling with eager FPU switching
  (bsc#1100091).
- commit 988e608
* Thu Aug  2 2018 vbabka@suse.cz
- x64/entry: move ENABLE_IBRS after switching from trampoline
  stack (bsc#1098658).
- commit 4a21a43
* Thu Aug  2 2018 alnovak@suse.cz
- Refresh patches.suse/x86-non-upstream-eager-fpu.patch.
  strnstr() is defined to operate on "length-limited" string. Limit the
  scope of searching for "eagerfpu=off" to the actual %%NUL terminated
  string. Otherwise (after warm boot e.g.) it might be found after the
  %%NUL.
- commit 0e55b99
* Wed Aug  1 2018 jkosina@suse.cz
- README.BRANCH: add Michal Hocko as co-maintainer during my absence
- commit dbe8e43
* Mon Jul 30 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/i915: fix error path in intel_setup_gmbus()'
- commit 914eb9c
* Mon Jul 30 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/i915: fix use-after-free in page_flip_completed()'
- blacklist.conf: Fix trailing whitespaces
- commit d96e56e
* Mon Jul 30 2018 jthumshirn@suse.de
- s390/qeth: fix IPA command submission race (bnc#1099709,
  LTC#169004).
- commit 942db45
* Thu Jul 26 2018 msuchanek@suse.de
- bigmem-generate-ifdef-guard: grep series.conf for bigmem patches to apply.
  Conflict resolution can leave files in patches.arch which the script
  tries to apply. Do not apply anything not listed in series.conf
- commit d96ec4a
* Thu Jul 26 2018 msuchanek@suse.de
- powerpc: Save CFAR before branching in interrupt entry paths (bsc#1094244).
- Refresh patches.suse/powerpc-64s-Add-support-for-a-store-forwarding-barri.patch.
- commit b4f1b21
* Thu Jul 26 2018 msuchanek@suse.de
- Move powerpc patches to powerpc section
- Refresh patches.arch/powerpc-KVM-Split-HVMODE_206-cpu-feature-bit-into-se.patch.
- Refresh patches.arch/ppc64-bigmem-04-mm-Convert-virtual-address-to-vpn.
- Refresh patches.arch/ppc64-bigmem-32-Remove-STAB-code.patch.
- Refresh patches.suse/powerpc-64s-Simple-RFI-macro-conversions.patch.
- Refresh patches.suse/ppc64-bigmem-introduce-CONFIG_BIGMEM.
- commit 5a79f43
* Thu Jul 26 2018 jthumshirn@suse.de
- scsi: zfcp: fix missing REC trigger trace on enqueue without
  ERP thread (bnc#1102087, LTC#168765).
- scsi: zfcp: fix missing REC trigger trace for all objects in
  ERP_FAILED (bnc#1102087, LTC#168765).
- scsi: zfcp: fix missing REC trigger trace on terminate_rport_io
  for ERP_FAILED (bnc#1102087, LTC#168765).
- scsi: zfcp: fix missing REC trigger trace on terminate_rport_io
  early return (bnc#1102087, LTC#168765).
- scsi: zfcp: fix misleading REC trigger trace where erp_action
  setup failed (bnc#1102087, LTC#168765).
- scsi: zfcp: fix missing SCSI trace for retry of abort /
  scsi_eh TMF (bnc#1102087, LTC#168765).
- scsi: zfcp: fix missing SCSI trace for result of
  eh_host_reset_handler (bnc#1102087, LTC#168765).
- scsi: zfcp: fix infinite iteration on ERP ready list
  (bnc#1102087, LTC#168038).
- commit ad2a617
* Thu Jul 26 2018 oneukum@suse.com
- xhci: xhci-mem: off by one in xhci_stream_id_to_ring()
  (bsc#1100132).
- commit 958355f
* Thu Jul 26 2018 oneukum@suse.com
- blacklist.conf: removes support for a device
- commit 93688bb
* Thu Jul 26 2018 oneukum@suse.com
- USB: kobil_sct: fix non-atomic allocation in write path
  (bsc#1015828).
- commit 8e61f0e
* Thu Jul 26 2018 oneukum@suse.com
- blacklist.conf: ARM specific driver
- commit f5d71ba
* Thu Jul 26 2018 oneukum@suse.com
- USB: serial: io_edgeport: fix NULL-deref at open (bsc#1015828).
- commit da29e37
* Thu Jul 26 2018 oneukum@suse.com
- USB: serial: keyspan_pda: fix modem-status error handling
  (bsc#1100132).
- commit a1ff2b7
* Wed Jul 25 2018 nstange@suse.de
- x86/KVM/VMX: Initialize the vmx_l1d_flush_pages' content
  (bsc#1089343 CVE-2018-3646).
- commit 4839305
* Wed Jul 25 2018 jkosina@suse.cz
- cpu/hotplug: detect SMT disabled by BIOS (bsc#1089343
  CVE-2018-3646).
- commit d4b5968
* Tue Jul 24 2018 mhocko@suse.com
- Refresh patches.arch/x86-l1tf-04-protect-PROT_NONE-ptes.patch.
- Refresh
  patches.arch/x86-speculation-l1tf-fix-up-pte-pfn-conversion-for-P.patch.
  make sure to restrict pmd clobbering to outside of reserved bits and use
  PHYSICAL_PMD_PAGE_MASK where appropriate
- commit 2691d43
* Mon Jul 23 2018 msuchanek@suse.de
- powerpc/64: Initialise thread_info for emergency stacks
  (bsc#1094244).
- commit aa59e9e
* Mon Jul 23 2018 mgorman@suse.de
- blacklist.conf: add theoretical fix for swap-over-nfs that impacts fast path
- commit d4be3bd
* Fri Jul 20 2018 jlee@suse.com
- efivarfs: maintain the efivarfs interfaces when sysfs be
  created and removed (bsc#1097125).
- commit 4dda848
* Thu Jul 19 2018 ydfan@suse.com
- ipv6: introduce ip6_rt_put() (bsc#1100705).
- commit 15417cb
* Thu Jul 19 2018 ydfan@suse.com
- ipv6: correctly add local routes when lo goes up (bsc#1100705).
- commit afd2703
* Thu Jul 19 2018 ydfan@suse.com
- ipv6: reallocate addrconf router for ipv6 address when lo
  device up (bsc#1100705).
- commit a8b6677
* Tue Jul 17 2018 jkosina@suse.cz
- Refresh
  patches.arch/x86-l1tf-05-make-sure-first-pages-is-reserved.patch.
- Refresh patches.arch/x86-l1tf-06-add-sysfs-report.patch.
- Refresh patches.xen/xen-x86-no-lapic.
- Refresh patches.xen/xen3-x86-l1tf-06-add-sysfs-report.patch.
  Update patch metadata.
- commit 829a81d
* Tue Jul 17 2018 jkosina@suse.cz
- xen: x86/bugs, kvm: Introduce boot-time control of L1TF
  mitigations (bsc#1089343 CVE-2018-3646).
- cpu/hotplug: Provide knobs to control SMT (bsc#1089343).
- xen/x86/cpu: Remove the pointless CPU printout (bsc#1089343).
- xen/x86/cpu/common: Provide detect_ht_early() (bsc#1089343).
- xen/x86/cpu/topology: Provide detect_extended_topology_early()
  (bsc#1089343).
- x86/cpu/AMD: Evaluate smp_num_siblings early (bsc#1089343).
- Refresh patches.xen/xen-x86-no-lapic.
- Refresh patches.xen/xen3-patch-2.6.28.
- Refresh patches.xen/xen3-patch-2.6.36.
  Import Xen counterparts from Jan Beulich.
- commit f88d917
* Tue Jul 17 2018 jbeulich@suse.com
- xen/x86/spectre_v1: Disable compiler optimizations over
  array_index_mask_nospec() (bsc#1068032 CVE-2017-5753).
- xen/x86/speculation: Fix up array_index_nospec_mask() asm
  constraint (bsc#1068032 CVE-2017-5753).
- commit 7152bf9
* Tue Jul 17 2018 jkosina@suse.cz
- Refresh
  patches.arch/00-x86-cpufeatures-Add-detection-of-L1D-cache-flush-sup.patch.
- Refresh patches.xen/xen3-patch-2.6.36.
  Explicitly set L1D flush feature bit, as 11-SP4 kernel doesn't have
  automatic CPUID.7 population. Spotted by Jan Beulich.
- commit f9f24bb
* Tue Jul 17 2018 jkosina@suse.cz
- Refresh
  patches.arch/00-x86-cpufeatures-Add-detection-of-L1D-cache-flush-sup.patch.
  Fix typo in X86_FEATURE_FLUSH_L1D value as spotted by Jan Beulich.
- commit 5587c06
* Mon Jul 16 2018 jthumshirn@suse.de
- scsi: sg: mitigate read/write abuse (bsc#1101296).
- commit e62125b
* Mon Jul 16 2018 mgorman@suse.de
- mm: fix the NULL mapping case in __isolate_lru_page()
  (git-fixes).
- commit 7d27b8c
* Sun Jul 15 2018 jslaby@suse.cz
- x86-non-upstream-eager-fpu 32bit fix (bnc#1087086 CVE-2018-3665
  bnc#1100091 bnc#1099598).
- commit e84b1bc
* Sat Jul 14 2018 jkosina@suse.cz
- Refresh
  patches.arch/x86-l1tf-08-disallow-non-privileged-high-MMIO-PROT_NONE.patch.
  Move pfn_modify_allowed() and arch_has_pfn_modify_check() into the
  !__ASSEMBLY__ section, otherwise ia64 build fails:
  include/asm-generic/pgtable.h: Assembler messages:
  include/asm-generic/pgtable.h:538: Error: Unknown opcode `static inline bool pfn_modify_allowed(unsigned long pfn,pgprot_t prot)'
  include/asm-generic/pgtable.h:540: Error: Unknown opcode `return true'
  include/asm-generic/pgtable.h:543: Error: Unknown opcode `static inline bool arch_has_pfn_modify_check(void)'
  include/asm-generic/pgtable.h:545: Error: Unknown opcode `return false'
  arch/ia64/kernel/entry.S:69: Error: `mov' does not fit into bundle
- commit 34378ec
* Sat Jul 14 2018 jkosina@suse.cz
- jump_label: export to modules (bsc#1089343 CVE-2018-3646).
- commit 22282f5
* Sat Jul 14 2018 jkosina@suse.cz
- x86/cpufeatures: Add detection of L1D cache flush support
  (bsc#1089343 CVE-2018-3646).
- x86/litf: Introduce vmx status variable (bsc#1089343
  CVE-2018-3646).
- x86/kvm: Drop L1TF MSR list approach (bsc#1089343
  CVE-2018-3646).
- x86/l1tf: Handle EPT disabled state proper (bsc#1089343
  CVE-2018-3646).
- x86/kvm: Move l1tf setup function (bsc#1089343 CVE-2018-3646).
- x86/kvm: Add static key for flush always (bsc#1089343
  CVE-2018-3646).
- x86/kvm: Serialize L1D flush parameter setter (bsc#1089343
  CVE-2018-3646).
- x86/kvm: Allow runtime control of L1D flush (bsc#1089343
  CVE-2018-3646).
- cpu/hotplug: Expose SMT control init function (bsc#1089343
  CVE-2018-3646).
- cpu/hotplug: Set CPU_SMT_NOT_SUPPORTED early (bsc#1089343
  CVE-2018-3646).
- x86/bugs, kvm: Introduce boot-time control of L1TF mitigations
  (bsc#1089343 CVE-2018-3646).
- Documentation: Add section about CPU vulnerabilities
  (bsc#1089343 CVE-2018-3646).
- x86/KVM: Warn user if KVM is loaded SMT and L1TF CPU bug being
  present (bsc#1089343 CVE-2018-3646).
- x86/KVM/VMX: Add module argument for L1TF mitigation
  (bsc#1089343 CVE-2018-3646).
- x86/KVM/VMX: Add L1D flush algorithm (bsc#1089343
  CVE-2018-3646).
- x86/KVM/VMX: Add L1D MSR based flush (bsc#1089343
  CVE-2018-3646).
- x86/KVM/VMX: Add L1D flush logic (bsc#1089343 CVE-2018-3646).
- x86/KVM/VMX: Split the VMX MSR LOAD structures to have an
  host/guest numbers (bsc#1089343 CVE-2018-3646).
- x86/KVM/VMX: Add find_msr() helper function (bsc#1089343
  CVE-2018-3646).
- x86/KVM/VMX: Separate the VMX AUTOLOAD guest/host number
  accounting (bsc#1089343 CVE-2018-3646).
- x86/KVM/VMX: Extend add_atomic_switch_msr() to allow VMENTER
  only MSRs (bsc#1089343 CVE-2018-3646).
- x86/KVM/VMX: Use MSR save list for IA32_FLUSH_CMD if required
  (bsc#1089343 CVE-2018-3646).
- Delete patches.arch/kvm-x86-add-support-for-L1D-flush-MSR.patch.
- Delete
  patches.arch/kvm-x86-mark_kvm_write_guest_virt_system-unconfined.patch.
- Delete
  patches.arch/kvm-x86-mitigation-for-L1-cache-terminal-fault-vulne-add-module-argument.patch.
- Delete
  patches.arch/kvm-x86-mitigation-for-L1-cache-terminal-fault-vulne.patch.
  Move from Paolo's v1 implementation to Konrad's v2 in order to be in sync
  with what's going to end up upstream. Apply runtime control knob on top.
- commit 4fb85cc
* Fri Jul 13 2018 jroedel@suse.de
- x86/ssbd: Re-evaluate SSBD features after ucode update (bsc#1087082 bsc#1100394 CVE-2018-3639).
- Refresh patches.xen/xen3-patch-2.6.26.
- commit 69c60e1
* Thu Jul 12 2018 bpoirier@suse.com
- RDMA/mlx4: Discard unknown SQP work requests (bnc#786036
  FATE#314304).
- commit de3736c
* Thu Jul 12 2018 bpoirier@suse.com
- e1000e: Ignore TSYNCRXCTL when getting I219 clock attributes
  (bug#923242).
- net/mlx4_core: Fix error handling in mlx4_init_port_info
  (bnc#786036 FATE#314304).
- sctp: fix the issue that the cookie-ack with auth can't get
  processed (bnc#902351 CVE-2014-3688).
- vmxnet3: use correct flag to indicate LRO feature (bsc#936423).
- net/mlx4_en: Change default QoS settings (bnc#786036
  FATE#314304).
- net/mlx4_en: Use __force to fix a sparse warning in TX datapath
  (bug#925105).
- IB/mlx4: fix sprintf format warning (bnc#786036 FATE#314304).
- netxen: fix incorrect loop counter decrement (bnc#784815
  FATE#313898).
- ixgbe: Initialize 64-bit stats seqcounts (bnc#795301
  FATE#313663).
- e1000e: Undo e1000e_pm_freeze if __e1000_shutdown fails
  (bug#909495 FATE#317394).
- tg3: don't clear stats while tg3_close (bnc#790588 FATE#313912).
- commit cbf2327
* Thu Jul 12 2018 msuchanek@suse.de
- powerpc: Machine check interrupt is a non-maskable interrupt
  (bsc#1094244).
- commit 06541c1
* Wed Jul 11 2018 osalvador@suse.de
- x86/traps: add missing kernel CR3 switch in bad_iret path
  (bsc#1098658).
- commit 6ad9aaf
* Wed Jul 11 2018 osalvador@suse.de
- fix a leak in /proc/schedstats (bsc#1094876).
- commit 2d9274b
* Tue Jul 10 2018 tiwai@suse.de
- sched/sysctl: Check user input value of sysctl_sched_time_avg
  (bsc#1100089).
- commit 74bd625
* Tue Jul 10 2018 tiwai@suse.de
- ALSA: hda/ca0132: fix build failure when a local macro is
  defined (bsc#1045538).
- ALSA: seq: Don't allow resizing pool in use (bsc#1045538).
- commit b71bcd5
* Mon Jul  9 2018 jkosina@suse.cz
- cpu/hotplug: Online siblings when SMT control is turned on
  (bsc#1089343 CVE-2018-3646).
- commit 2b2ec86
* Mon Jul  9 2018 tiwai@suse.de
- alarmtimer: Prevent overflow for relative nanosleep
  (CVE-2018-13053 bsc#1099924).
- commit dabdac9
* Fri Jul  6 2018 jkosina@suse.cz
- Update config files: enable CONFIG_HOTPLUG_SMT
- commit 15fdbb0
* Fri Jul  6 2018 jkosina@suse.cz
- x86/KVM/VMX: Add module argument for L1TF mitigation
  (bsc#1089343 CVE-2018-3646).
- kvm: x86: mark kvm_write_guest_virt_system() as unconfined
  (bnc#1089343, CVE-2018-3646).
- commit 6f46d86
* Fri Jul  6 2018 jkosina@suse.cz
- cpu/hotplug: Boot HT siblings at least once (bsc#1089343
  CVE-2018-3646).
- commit 491d33d
* Thu Jul  5 2018 sndirsch@suse.de
- video: uvesafb: Fix integer overflow in allocation
  (bsc#1100418, CVE-2018-13406)
- commit 0e2ca1e
* Wed Jul  4 2018 sndirsch@suse.de
- video/stifb: Return -ENOMEM after a failed kzalloc()
  in stifb_init_fb() (bnc#1099966).
- commit 2950d41
* Tue Jul  3 2018 msuchanek@suse.de
- powerpc/pseries: Avoid using the size greater than
  (bsc#1094244).
- powerpc/64s: Exception macro for stack frame and initial
  register save (bsc#1094244).
- powerpc/book3s: Split the common exception prolog logic into
  two section (bsc#1094244).
- powerpc: cputable: KABI - hide new cpu_spec member from genksyms
  (bsc#1094244).
- powerpc/book3s: Introduce a early machine check hook in cpu_spec
  (bsc#1094244).
- powerpc/book3s: handle machine check in Linux host
  (bsc#1094244).
- powerpc/book3s: Introduce exclusive emergency stack for machine
  check exception (bsc#1094244).
- powerpc: Add a symbol for hypervisor trampolines (bsc#1094244).
- powerpc: Rework runlatch code (bsc#1094244).
- commit 178f31d
* Tue Jul  3 2018 oneukum@suse.com
- fbdev: color map copying bounds checking (bsc#1099942
  CVE-2016-8405).
- commit 6b106f0
* Mon Jul  2 2018 msuchanek@suse.de
- blacklist a050d20d024d powerpc/64s: Use relon prolog for
  EXC_VIRT_OOL_MASKABLE_HV handlers
  We do not have relon exception support in SLE11
- commit 9f48f0f
* Mon Jul  2 2018 oneukum@suse.com
- USB: uss720: fix NULL-deref at probe (bnc#1047487).
- commit 4fd8b3a
* Mon Jul  2 2018 jthumshirn@suse.de
- s390/qeth: free netdevice when removing a card (bnc#1099709,
  LTC#169202).
- s390/qeth: lock read device while queueing next buffer
  (bnc#1099709, LTC#169019).
- s390/qdio: don't merge ERROR output buffers (bnc#1099709,
  LTC#169006).
- s390/qeth: don't dump control cmd twice (bnc#1099709,
  LTC#169004).
- s390/qeth: fix SETIP command handling (bnc#1099709, LTC#169004).
- s390/qeth: when thread completes, wake up all waiters
  (bnc#1099709, LTC#169002).
- commit 9358c7f
* Sat Jun 30 2018 bp@suse.de
- Delete
  patches.arch/13-11-x86-apic-ignore-secondary-threads-if-nosmt-force.patch.
- commit 9c3104d
* Fri Jun 29 2018 msuchanek@suse.de
- Delete patches.arch/powerpc-pseries-convert-rtas_log_buf-to-linear-alloc.patch.
- commit 083bd61
* Fri Jun 29 2018 jslaby@suse.cz
- x86/spectre_v1: Disable compiler optimizations over
  array_index_mask_nospec() (bsc#1068032 CVE-2017-5753).
- x86/speculation: Fix up array_index_nospec_mask() asm constraint
  (bsc#1068032 CVE-2017-5753).
- commit 270ceaf
* Thu Jun 28 2018 mhocko@suse.com
- xen: x86, l1tf: Protect swap entries against L1TF (bnc#1087081,
  CVE-2018-3620).
- xen: x86, l1tf: Protect PROT_NONE PTEs against speculation
  (bnc#1087081, CVE-2018-3620).
- xen: x86, l1tf: Add sysfs report for l1tf (bnc#1087081,
  CVE-2018-3620).
- xen: mm, l1tf: Disallow non privileged high MMIO PROT_NONE
  mappings (bnc#1087081, CVE-2018-3620).
- xen/x86/speculation/l1tf: protect PAE swap entries against L1TF
  (bnc#1087081, CVE-2018-3620).
- Refresh patches.xen/xen-x86-per-cpu-vcpu-info.
- Refresh patches.xen/xen-x86-pmd-handling.
- Refresh patches.xen/xen3-patch-2.6.26.
- commit 1cf01bd
* Thu Jun 28 2018 osalvador@suse.de
- x86/traps: Fix bad_iret_stack in fixup_bad_iret() (bsc#1098658).
- commit a37720a
* Wed Jun 27 2018 mhocko@suse.com
- x86/speculation/l1tf: fix up pte->pfn conversion for PAE
  (bnc#1087081, CVE-2018-3620).
- commit 879c996
* Wed Jun 27 2018 mhocko@suse.com
- Refresh
  patches.arch/x86-l1tf-08-disallow-non-privileged-high-MMIO-PROT_NONE.patch.
  Fix CONFIG_HUGETLB_PAGE=n compile error noticed by Jan Beulich.
- commit 4188509
* Wed Jun 27 2018 mhocko@suse.com
- x86/speculation/l1tf: protect PAE swap entries against L1TF
  (bnc#1087081, CVE-2018-3620).
- commit 2cf1a61
* Wed Jun 27 2018 jcejka@suse.com
- x86/cpu/bugs: Make retpoline module warning conditional
  (bnc#1099177).
- module/retpoline: Warn about missing retpoline in module
  (bnc#1099177).
- commit 8144cd6
* Wed Jun 27 2018 bp@suse.de
- x86/smp: Provide topology_is_primary_thread() (bsc#1089343).
- x86/topology: Provide topology_smt_supported() (bsc#1089343).
- cpu/hotplug: Split do_cpu_down() (bsc#1089343).
- cpu/hotplug: Add sysfs state interface (bsc#1089343).
- x86/topology: Add topology_max_smt_threads() (bsc#1089343).
- x86/smpboot: Do not use smp_num_siblings in
  __max_logical_packages calculation (bsc#1089343).
- cpu/hotplug: Provide knobs to control SMT (bsc#1089343).
- x86/cpu: Remove the pointless CPU printout (bsc#1089343).
- x86/cpu/AMD: Remove the pointless detect_ht() call
  (bsc#1089343).
- x86/cpu/common: Provide detect_ht_early() (bsc#1089343).
- x86/cpu/topology: Provide detect_extended_topology_early()
  (bsc#1089343).
- x86/cpu/intel: Evaluate smp_num_siblings early (bsc#1089343).
- x86/CPU/AMD: Do not check CPUID max ext level before parsing
  SMP info (bsc#1089343).
- x86/cpu/AMD: Evaluate smp_num_siblings early (bsc#1089343).
- x86/apic: Ignore secondary threads if nosmt=force (bsc#1089343).
- x86/CPU/AMD: Move TOPOEXT reenablement before reading
  smp_num_siblings (bsc#1089343).
- Refresh patches.xen/xen-x86-no-lapic.
- Refresh patches.xen/xen3-patch-2.6.28.
- commit 5d33b03
* Tue Jun 26 2018 brogers@suse.com
- kvm: x86: add support for L1D flush MSR (bnc#1089343,
  CVE-2018-3646).
- kvm: x86: mitigation for L1 cache terminal fault vulnerabilities
  (bnc#1089343, CVE-2018-3646).
- KVM: add kvm_arch_sched_in (bnc#1089343, CVE-2018-3646).
- commit 076e1b5
* Tue Jun 26 2018 jroedel@suse.de
- x86-32/kaiser: Add CPL check for CR3 switch before iret (bsc#1098408).
- commit 49841db
* Tue Jun 26 2018 jthumshirn@suse.de
- nvme: add device id's with intel stripe quirk (bsc#1097562).
- commit 10f2139
* Mon Jun 25 2018 dbueso@suse.de
- Delete patches.fixes/0001-ipc-shm-Fix-shmat-mmap-nil-page-protection.patch (bsc#
  1090078)
- commit cb0bc6d
* Wed Jun 20 2018 oneukum@suse.com
- usbip: usbip_host: fix bad unlock balance during stub_probe()
  (bsc#1096480 CVE-2018-5814).
- commit b0f60e7
* Wed Jun 20 2018 mhocko@suse.com
- x86, l1tf: Increase 32bit PAE __PHYSICAL_PAGE_MASK (bnc#1087081,
  CVE-2018-3620).
- x86, l1tf: Protect swap entries against L1TF (bnc#1087081,
  CVE-2018-3620).
- x86, l1tf: Protect PROT_NONE PTEs against speculation
  (bnc#1087081, CVE-2018-3620).
- x86, l1tf: Make sure the first page is always reserved
  (bnc#1087081, CVE-2018-3620).
- x86, l1tf: Add sysfs report for l1tf (bnc#1087081,
  CVE-2018-3620).
- x86, l1tf: Limit swap file size to MAX_PA/2 (bnc#1087081,
  CVE-2018-3620).
- mm, l1tf: Disallow non privileged high MMIO PROT_NONE mappings
  (bnc#1087081, CVE-2018-3620).
- Refresh patches.xen/xen3-patch-2.6.26.
- commit e25d854
* Tue Jun 19 2018 nborisov@suse.com
- jfs: Fix inconsistency between memory allocation and
  ea_buf->max_size (bsc#1097234, CVE-2018-12233).
- Delete patches.suse/jfs-Fix-buffer-overrun-in-ea_get.patch.
- commit 762984a
* Mon Jun 18 2018 jslaby@suse.cz
- Refresh
  patches.arch/14.1-x86-retpoline-fill-rsb-on-context-switch-for-affected-cpus.patch.
  Fix bnc#1097948.
- commit f2f2370
* Mon Jun 18 2018 nborisov@suse.com
- jfs: Fix buffer overrun in ea_get (bsc#1097234, CVE-2018-12233).
- commit 114be45
* Fri Jun 15 2018 jslaby@suse.cz
- KVM: x86: remove code for lazy FPU handling (bsc#1095241,
  CVE-2018-3665).
- commit 4ac4c46
* Thu Jun 14 2018 jkosina@suse.cz
- Xen counterparts of eager FPU implementation.
- xen/i387: use 'restore_fpu_checking()' directly in task
  switching code (bnc#1087086 CVE-2018-3665).
- xen: x86-non-upstream-eager-fpu (bnc#1087086 CVE-2018-3665).
- Refresh
  patches.xen/xen3-x86_amd_interlagos_mem_alignment_perf_improve_2_4.patch.
- commit 7550adf
* Thu Jun 14 2018 jdelvare@suse.de
- perf/x86/intel: Handle Broadwell family processors
  (bsc#1093183).
- commit fab6706
* Thu Jun 14 2018 jslaby@suse.cz
- x86-non-upstream-eager-fpu 32bit fix (bnc#1087086
  CVE-2018-3665).
- commit 027b03e
* Wed Jun 13 2018 mbenes@suse.cz
- blacklist.conf: Blacklist API doc commit
  4c11628a1650 ("tracepoints: API doc update to data argument")
- commit 5d8972e
* Wed Jun 13 2018 mbenes@suse.cz
- module: Fix locking in symbol_put_addr() (bsc#1097445).
- commit c2ba773
* Wed Jun 13 2018 mbenes@suse.cz
- trace: module: Maintain a valid user count (bsc#1097443).
- commit ed6515e
* Tue Jun 12 2018 oneukum@suse.com
- usbip: usbip_host: fix NULL-ptr deref and use-after-free errors
  (bsc#1096480 CVE-2018-5814).
- commit 6b687d1
* Tue Jun 12 2018 oneukum@suse.com
- staging: usbip: stub_main.c: code cleanup (bsc#1096480 CVE-2018-5814).
- commit db6b7d3
* Tue Jun 12 2018 jroedel@suse.de
- KVM: x86: Sync back MSR_IA32_SPEC_CTRL to VCPU data structure (bsc#1096242, bsc#1096281).
- commit c148d6e
* Mon Jun 11 2018 vbabka@suse.cz
- mm, page_alloc: do not break __GFP_THISNODE by zonelist reset
  (bsc#1079152, VM Functionality).
- commit 02cc045
* Mon Jun 11 2018 mwilck@suse.com
- Refresh
  patches.drivers/0001-qla2xxx-Mask-off-Scope-bits-in-retry-delay.patch.
- commit 5e9ab9a
* Mon Jun 11 2018 jthumshirn@suse.de
- scsi: sg: allocate with __GFP_ZERO in sg_build_indirect()
  (bsc#1096728 CVE-2018-1000204).
- commit e4e6a0d
* Mon Jun 11 2018 jthumshirn@suse.de
- kernel: Fix memory leak on EP11 target list processing
  (bnc#1096746, LTC#168596).
- s390/dasd: fix failing path verification (bnc#1096746,
  LTC#167649).
- s390/cpum_sf: ensure sample frequency of perf event attributes
  is non-zero (bnc#1096746, LTC#168035).
- commit 77e0b24
* Fri Jun  8 2018 mcgrof@suse.com
- xfs: avoid xfs_buf hang in lookup node directory corruption
  (bsc#989401).
- commit de1501a
* Fri Jun  8 2018 mcgrof@suse.com
- xfs: only update the last_sync_lsn when a transaction completes
  (bsc#989401).
- commit a791e8e
* Fri Jun  8 2018 jkosina@suse.cz
- x86/boot: Fix early command-line parsing when partial word
  matches (bsc#1096140).
- commit e5ea61f
* Fri Jun  8 2018 jkosina@suse.cz
- x86/bugs: spec_ctrl must be cleared from cpu_caps_set when
  being disabled (bsc#1096140).
- commit adb7c60
* Thu Jun  7 2018 msuchanek@suse.de
- powerpc/64s: Fix compiler store ordering to SLB shadow area
  (bsc#1094244).
- kvm/powerpc: Add new ioctl to retreive server MMU infos
  (bsc#1094244).
- commit d988150
* Wed Jun  6 2018 msuchanek@suse.de
- powerpc/pseries: Display machine check error details
  (bsc#1094244).
- powerpc/pseries: Dump and flush SLB contents on SLB MCE errors
  (bsc#1094244).
- powerpc/pseries: Define MCE error event section (bsc#1094244).
- powerpc/pseries: convert rtas_log_buf to linear allocation
  (bsc#1094244).
- powerpc/mm/hash: Add missing isync prior to kernel stack SLB
  switch (bsc#1094244).
- commit 0731c61
* Wed Jun  6 2018 mwilck@suse.com
- Refresh
  patches.drivers/0001-qla2xxx-Mask-off-Scope-bits-in-retry-delay.patch.
- commit a2be179
* Wed Jun  6 2018 jbeulich@suse.com
- Delete bogus patches.xen/0001-SSB-Xen-build-fix.patch, replaced
  by the three ones below.
- x86/bugs/AMD: Add support to disable RDS on Fam[15,16,17]h if
  requested (bsc#1087082 CVE-2018-3639).
- xen/x86/process: Allow runtime control of Speculative Store
  Bypass (bsc#1087082 CVE-2018-3639).
- xen/x86/bugs: Rename _RDS to _SSBD (bsc#1087082 CVE-2018-3639).
- commit 4c7b76b
* Wed Jun  6 2018 jbeulich@suse.com
- xen/x86/bugs/intel: Set proper CPU features and setup RDS
  (bsc#1087082 CVE-2018-3639).
- commit 5cadddf
* Wed Jun  6 2018 jbeulich@suse.com
- xen/x86/entry/64: Don't use IST entry for #BP stack
  (bsc#1087088).
- commit 9c9843b
* Wed Jun  6 2018 jbeulich@suse.com
- Replace
  patches.xen/xen-netfront.network_alloc_rx_buffers.missing_push.patch
  by proper pseudo-upstream ...
- netfront: make req_prod check properly deal with index wraps
  (bsc#1046610).
- commit 8f9421b
* Wed Jun  6 2018 jbeulich@suse.com
- balloon: don't BUG() when balloon is empty (bsc#1083347).
- commit fe3d037
* Tue Jun  5 2018 msuchanek@suse.de
- Refresh patches.suse/powerpc-64s-Add-support-for-a-store-forwarding-barri.patch.
- STF: no POWER9 support on SLE12-SP2 (CVE-2018-3639, bsc#1087082).
- commit cf039fc
* Tue Jun  5 2018 msuchanek@suse.de
- Move non-upstream patches out of patches.kernel.org
  Another fallout of merging scripts
- commit d4eab7b
* Tue Jun  5 2018 jkosina@suse.cz
- Refresh
  patches.suse/btrfs-fix-stale-dir-entries-after-removing-a-link-and-fsync.patch.
  Hide the patch pattern from changelog even more.
- commit 3e4d043
* Tue Jun  5 2018 jkosina@suse.cz
- Refresh
  patches.suse/btrfs-fix-stale-dir-entries-after-removing-a-link-and-fsync.patch.
  Remove '---' from patch comment that apparently confuses some versions of
  patch(1)
- commit 31c22eb
* Mon Jun  4 2018 msuchanek@suse.de
- Refresh powerpc nospec patches.
- Delete patches.suse/powerpc-add-gmb.patch.
- Refresh patches.suse/powerpc-64-Use-barrier_nospec-in-syscall-entry.patch.
- Refresh patches.suse/powerpc-64s-Add-barrier_nospec.patch.
- Refresh patches.suse/powerpc-64s-Add-support-for-ori-barrier_nospec-patch.patch.
- Refresh patches.suse/powerpc-64s-Enable-barrier_nospec-based-on-firmware-.patch.
- Refresh patches.suse/powerpc-64s-Enhance-the-information-in-cpu_show_spec.patch.
- Refresh patches.suse/powerpc-64s-Patch-barrier_nospec-in-modules.patch.
- Refresh patches.suse/powerpc-Use-barrier_nospec-in-copy_from_user.patch.
- commit 6119e80
* Mon Jun  4 2018 bpoirier@suse.com
- bna: integer overflow bug in debugfs (bnc#780242 FATE#313822).
- commit 359291d
* Fri Jun  1 2018 bpoirier@suse.com
- blacklist.conf:
- commit c4ac0fe
* Thu May 31 2018 dbond@suse.com
- qla2xxx: Mask off Scope bits in retry delay (bsc#1068054).
- commit a5c3d32
* Thu May 31 2018 jroedel@suse.de
- x86: Fix /proc/mtrr with base/size more than 44bits
  (bsc#1052351).
- commit a1cafb8
* Thu May 31 2018 bp@suse.de
- Refresh
  patches.arch/14.1-x86-retpoline-fill-rsb-on-context-switch-for-affected-cpus.patch.
- commit c5f46f4
* Tue May 29 2018 jkosina@suse.cz
- Refresh patches.kabi/bpf-ssbd-removal-workaround.patch: make sure the
  symbols are there even in !__GENKSYMS__ build, making the workaround
  really robust wrt. 3rd party modules possibly built against the
  kernel that already contained those.
- commit 80e6815
* Mon May 28 2018 jkosina@suse.cz
- kABI: work around BPF SSBD removal (bsc#1087082).
- commit e1d6830
* Mon May 28 2018 msuchanek@suse.de
- Update kabi files from MR#7414.
- commit c3dda1f
* Sat May 26 2018 tiwai@suse.de
- ALSA: timer: Fix pause event notification (bsc#973378).
- commit 18c5c77
* Fri May 25 2018 bpoirier@suse.com
- blacklist.conf:
- commit da44c38
* Fri May 25 2018 bpoirier@suse.com
- IB/mlx4: Convert slave port before building address-handle
  (bug#919382 FATE#317529).
- commit 437f88d
* Thu May 24 2018 jeffm@suse.com
- btrfs: use nodesize everywhere, kill leafsize (bsc#1080837).
- commit d053d8e
* Thu May 24 2018 jeffm@suse.com
- btrfs: remove parameter blocksize from read_tree_block
  (bsc#1080837).
- commit 08df5cd
* Thu May 24 2018 jeffm@suse.com
- Btrfs: fix up read_tree_block to return proper error
  (bsc#1080837).
- commit 325a402
* Thu May 24 2018 msuchanek@suse.de
- Revert "bs-upload-kernel: do not set %%opensuse_bs"
  This reverts commit e89e2b8cbef05df6c874ba70af3cb4c57f82a821.
- commit 435f6af
* Thu May 24 2018 lzhong@suse.com
- x86/kaiser: symbol kaiser_set_shadow_pgd() exported with non GPL
- commit 24fefbc
* Thu May 24 2018 jeffm@suse.com
- btrfs: initialize the seq counter in struct btrfs_device
  (bsc#1094437).
- commit 258179e
* Thu May 24 2018 jeffm@suse.com
- Btrfs: fix xattr loss after power failure (bsc#1094436).
- commit ec02171
* Wed May 23 2018 jeffm@suse.com
- Btrfs: remove deleted xattrs on fsync log replay (bsc#1089008).
- commit 88f4928
* Wed May 23 2018 jeffm@suse.com
- Btrfs: fix invalid extent maps due to hole punching
  (bsc#1094425).
- commit 57b6368
* Wed May 23 2018 jeffm@suse.com
- btrfs: Avoid truncate tailing page if fallocate range doesn't
  exceed inode size (bsc#1094424).
- commit bb4a19d
* Wed May 23 2018 jeffm@suse.com
- Btrfs: fix fsync xattr loss in the fast fsync path
  (bsc#1094423).
- commit c8cca7f
* Wed May 23 2018 jeffm@suse.com
- Btrfs: make btrfs_search_forward return with nodes unlocked
  (bsc#1094422).
- commit f5d29ec
* Wed May 23 2018 jeffm@suse.com
- Btrfs: remove unused max_key arg from btrfs_search_forward
  (bsc#1094421).
- commit 22ef763
* Wed May 23 2018 jeffm@suse.com
- config.sh: set BUGZILLA_PRODUCT for SLE11-SP4
- commit 2ce10e2
* Wed May 23 2018 jkosina@suse.cz
- Drop cBPF SSBD
  tldr: classic BPF doesn't really have a proper concept of pointers,
  and without eBPF maps the out-of-bounds access in speculative
  execution branch can't be mounted.
  Moreoever, seccomp BPF uses only such a subset of BPF that can only
  do absolute indexing, and therefore seccomp data buffer boundarier
  can't be crossed.
  Information condensed from Alexei and Kees.
- Refresh patches.arch/26-x86-bugs-rename-rds-to-ssbd.patch.
- Delete patches.arch/0001-bpf-add-enter-exit-markers.patch.
- Delete
  patches.arch/0002-bpf-track-entry-to-and-exit-from-BFP-code.patch.
- Delete
  patches.arch/0003-bpf-use-reduced-speculation-mitigations.patch.
- Delete
  patches.arch/0004-x86-bugs-centralize-SPEC_CTRL-MSR-mask-generation-FIX.patch.
- Delete
  patches.arch/0004-x86-bugs-centralize-SPEC_CTRL-MSR-mask-generation.patch.
- Delete
  patches.arch/0005-x86-implement-reduced-speculation-when-running-BPF.patch.
- commit 91eab0f
* Wed May 23 2018 msuchanek@suse.de
- powerpc: Fix /proc/cpuinfo revision for POWER9 DD2 (FATE#325713,
  bsc#1093710).
- commit bedb25b
* Wed May 23 2018 tiwai@suse.de
- KEYS: encrypted: fix buffer overread in valid_master_desc()
  (CVE-2017-13305,bsc#1094353).
- commit 506e078
* Tue May 22 2018 jack@suse.cz
- blacklist.conf: Blacklist a86b06d1ccd2
- commit 5ba9a26
* Tue May 22 2018 jack@suse.cz
- blacklist.conf: Blacklist 001ab5a67ee5
- commit b249af0
* Tue May 22 2018 jack@suse.cz
- blacklist.conf: Blacklist aac17948a7ce
- commit ef9e7ad
* Mon May 21 2018 palcantara@suse.de
- blacklist.conf: add cifs commit
  gcc8 is unsupported on SLE11-SP4.
- commit 5a604d3
* Mon May 21 2018 jkosina@suse.cz
- x86/bugs: make intel_rds_mask() honor X86_FEATURE_SSBD
  (bsc#1094019).
- commit d8775df
* Fri May 18 2018 jthumshirn@suse.de
- s390/qdio: fix access to uninitialized qdio_q fields
  (bnc#1091659, LTC#168037).
- commit 8b25ed4
* Fri May 18 2018 jthumshirn@suse.de
- s390/cio: update chpid descriptor after resource accessibility
  event (bnc#1091659, LTC#167429).
- s390/dasd: fix IO error for newly defined devices (bnc#1091659,
  LTC#167398).
- commit 8c2eead
* Fri May 18 2018 mkoutny@suse.com
- ipc/msg: Fix faulty parsing of msgctl args (bsc#1093600,bsc#1072689).
- commit ec62b3b
* Thu May 17 2018 jthumshirn@suse.de
- Refresh patches.suse/s390-fix-retpoline-build-for-31bit.patch.
- commit f6fb212
* Thu May 17 2018 mkubecek@suse.cz
- dccp: check sk for closed state in dccp_sendmsg() (CVE-2018-1130
  bsc#1092904).
- commit a28f959
* Thu May 17 2018 mkubecek@suse.cz
- netfilter: ebtables: fix erroneous reject of last rule
  (CVE-2018-1068 bsc#1085107).
- netfilter: ebtables: CONFIG_COMPAT: don't trust userland offsets
  (CVE-2018-1068 bsc#1085107).
- commit 7ae870c
* Thu May 17 2018 mkubecek@suse.cz
- sctp: verify size of a new chunk in _sctp_make_chunk()
  (CVE-2018-5803 bsc#1083900).
- commit a3b4757
* Thu May 17 2018 mkubecek@suse.cz
- rds: Fix NULL pointer dereference in __rds_rdma_map
  (CVE-2018-7492 bsc#1082962).
- commit b57e6f5
* Wed May 16 2018 jdelvare@suse.de
- x86, mce: Fix mce_start_timer semantics (bsc#1090607).
- commit 9aaf2f4
* Wed May 16 2018 jack@suse.cz
- ocfs2/dlm: Fix up kABI in dlm_ctxt (bsc#1070404).
- commit 01ab17a
* Wed May 16 2018 jack@suse.cz
- ocfs2/dlm: wait for dlm recovery done when migrating all lock
  resources (bsc#1013018).
- commit 6943c83
* Wed May 16 2018 jack@suse.cz
- fanotify: fix logic of events on child (bsc#1013018).
- commit 89258c5
* Wed May 16 2018 oneukum@suse.com
- blacklist.conf: fix something only questionable on an error path
  (why is this in stable?)
- commit 8c84d58
* Wed May 16 2018 jthumshirn@suse.de
- s390: fix retpoline build on 31bit (bsc#1089386).
- commit 413a852
* Tue May 15 2018 jthumshirn@suse.de
- Update s390 config files (bsc#1089386).
- commit 859bad9
* Tue May 15 2018 jroedel@suse.de
- KVM: SVM: Move spec control call after restore of GS
  (bsc#1087082 CVE-2018-3639).
- commit dad8c01
* Tue May 15 2018 jbeulich@suse.com
- x86/Xen: disable IBRS around CPU stopper function invocation
  (none so far).
- commit c325779
* Tue May 15 2018 jthumshirn@suse.de
- s390: correct module section names for expoline code revert
  (bsc#1089386).
- commit 3a5225b
* Tue May 15 2018 jthumshirn@suse.de
- blacklist.conf: Add 2cb370d615e9, dc24b7b49a53 and d3f468963cd6 as per bsc#1089386 comment 22.
- commit ea5ab05
* Mon May 14 2018 jeffm@suse.com
- Btrfs: fix deadlock caused by fsync when logging directory
  entries (bsc#1093194).
- commit a2d6b85
* Mon May 14 2018 jeffm@suse.com
- Btrfs: fix empty symlink after creating symlink and fsync
  parent dir (bsc#1093195).
- commit ee76629
* Mon May 14 2018 jeffm@suse.com
- Btrfs: fix file loss on log replay after renaming a file and
  fsync (bsc#1093196).
- commit 7695a74
* Mon May 14 2018 jeffm@suse.com
- Btrfs: set inode's logged_trans/last_log_commit after ranged
  fsync (bsc#1093198).
- commit 8588f07
* Mon May 14 2018 msuchanek@suse.de
- powerpc, KVM: Split HVMODE_206 cpu feature bit into separate
  HV and architecture bits (bsc#1087082).
- commit 36d386b
* Mon May 14 2018 bp@suse.de
- Fix for bsc#1092497
- Refresh
  patches.arch/07-x86-spectre-Add-boot-time-option-to-select-Spectre-v.patch.
- Refresh
  patches.arch/14.1-x86-retpoline-fill-rsb-on-context-switch-for-affected-cpus.patch.
- Refresh
  patches.arch/x86-cpu-Implement-CPU-vulnerabilites-sysfs-fu.patch.
- Delete patches.suse/x86-nospectre_v2-means-nospec-too.patch.
- commit 6c942b2
* Mon May 14 2018 jthumshirn@suse.de
- KABI protect struct _lowcore (bsc#1089386).
- commit 5e86acf
* Fri May 11 2018 jkosina@suse.cz
- x86/bugs: correctly force-disable IBRS on !SKL systems
  (bsc#1092497).
- commit f798b9e
* Thu May 10 2018 msuchanek@suse.de
- powerpc/64s: Add support for a store forwarding barrier at
  kernel entry/exit (CVE-2018-3639, bsc#1087082).
- commit 4f76782
* Thu May 10 2018 msuchanek@suse.de
- powerpc/64s: Enhance the information in cpu_show_spectre_v1()
  (bsc#1068032).
- commit a0e17b3
* Thu May 10 2018 bp@suse.de
- x86/bugs: Rename _RDS to _SSBD (bsc#1087082 CVE-2018-3639).
  Also:
- Refresh patches.xen/xen3-patch-2.6.18.
- Refresh patches.xen/xen3-patch-2.6.25.
- Refresh patches.xen/xen3-patch-2.6.28.
- Refresh patches.xen/xen3-patch-2.6.35.
- commit 5e453ad
* Wed May  9 2018 msuchanek@suse.de
- powerpc/64: Use barrier_nospec in syscall entry (bsc#1068032,
  bsc#1080157).
- powerpc: Use barrier_nospec in copy_from_user() (bsc#1068032,
  bsc#1080157).
- powerpc/64s: Enable barrier_nospec based on firmware settings
  (bsc#1068032, bsc#1080157).
- powerpc/64s: Patch barrier_nospec in modules (bsc#1068032,
  bsc#1080157).
- powerpc/64s: Add support for ori barrier_nospec patching
  (bsc#1068032, bsc#1080157).
- powerpc/64s: Add barrier_nospec (bsc#1068032, bsc#1080157).
- commit 84b1551
* Wed May  9 2018 jroedel@suse.de
- SSB: Xen build fix (bsc#1087082 CVE-2018-3639).
- commit b1722de
* Wed May  9 2018 msuchanek@suse.de
- powerpc: Move local setup.h declarations to arch includes
  (bsc#1068032, bsc#1075088, bsc#1091815).
  Refresh patches.suse/powerpc-64s-Add-support-for-RFI-flush-of-L1-D-cache.patch.
- commit b33b157
* Wed May  9 2018 jroedel@suse.de
- SSB kABI Fix (bsc#1087082 CVE-2018-3639).
- commit 71b180f
* Wed May  9 2018 jroedel@suse.de
- x86: implement reduced speculation when running BPF (bsc#1087082
  CVE-2018-3639).
- Update config files.
- x86, bugs: centralize SPEC_CTRL MSR mask generation (bsc#1087082
  CVE-2018-3639).
- bpf: use reduced speculation mitigations (bsc#1087082
  CVE-2018-3639).
- bpf: track entry to and exit from BFP code (bsc#1087082
  CVE-2018-3639).
- bpf: add enter/exit markers (bsc#1087082 CVE-2018-3639).
- commit fe1ff70
* Wed May  9 2018 msuchanek@suse.de
- tracing: Create seq_buf layer in trace_seq (bsc#1091815).
- commit 754f6a1
* Wed May  9 2018 msuchanek@suse.de
- Disable gmb() on powerpc
- commit dca669e
* Wed May  9 2018 msuchanek@suse.de
- powerpc/64s: Fix section mismatch warnings from
  setup_rfi_flush() (bsc#1068032, bsc#1075087, bsc#1091041).
- commit 9d4736c
* Wed May  9 2018 msuchanek@suse.de
- powerpc/pseries: Restore default security feature flags on setup
  (bsc#1068032, bsc#1075088, bsc#1091815).
- commit 7e39aa4
* Wed May  9 2018 msuchanek@suse.de
- powerpc: Move default security feature flags (bsc#1068032,
  bsc#1075088, bsc#1091815).
- commit 0342093
* Wed May  9 2018 msuchanek@suse.de
- powerpc/pseries: Fix clearing of security feature flags
  (bsc#1068032, bsc#1075088, bsc#1091815).
- commit 561205c
* Wed May  9 2018 msuchanek@suse.de
- powerpc/64s: Wire up cpu_show_spectre_v2() (bsc#1068032,
  bsc#1075088, bsc#1091815).
- commit 8b089d9
* Wed May  9 2018 msuchanek@suse.de
- powerpc/64s: Wire up cpu_show_spectre_v1() (bsc#1068032,
  bsc#1075088, bsc#1091815).
- commit e115f58
* Wed May  9 2018 msuchanek@suse.de
- powerpc/pseries: Use the security flags in
  pseries_setup_rfi_flush() (bsc#1068032, bsc#1075088,
  bsc#1091815).
- commit 4117c70
* Wed May  9 2018 msuchanek@suse.de
- powerpc/64s: Enhance the information in cpu_show_meltdown()
  (bsc#1068032, bsc#1075088, bsc#1091815).
- commit 172bc85
* Wed May  9 2018 msuchanek@suse.de
- powerpc/64s: Move cpu_show_meltdown() (bsc#1068032, bsc#1075088,
  bsc#1091815).
- commit 63f2b9f
* Wed May  9 2018 msuchanek@suse.de
- powerpc/pseries: Set or clear security feature flags
  (bsc#1068032, bsc#1075088, bsc#1091815).
- commit 9318eac
* Wed May  9 2018 msuchanek@suse.de
- powerpc: Add security feature flags for Spectre/Meltdown
  (bsc#1068032, bsc#1075088, bsc#1091815).
- commit 20f1410
* Wed May  9 2018 msuchanek@suse.de
- powerpc/pseries: Add new H_GET_CPU_CHARACTERISTICS flags
  (bsc#1068032, bsc#1075088, bsc#1091815).
- commit acee682
* Wed May  9 2018 msuchanek@suse.de
- powerpc/rfi-flush: Differentiate enabled and patched flush types
  (bsc#1068032, bsc#1075088, bsc#1091815).
- commit 5e85226
* Wed May  9 2018 msuchanek@suse.de
- powerpc/rfi-flush: Make it possible to call setup_rfi_flush()
  again (bsc#1068032, bsc#1075088, bsc#1091815).
- powerpc/rfi-flush: Always enable fallback flush on pseries
  (bsc#1068032, bsc#1075088, bsc#1091815).
- powerpc/rfi-flush: Call setup_rfi_flush() after LPM migration
  (bsc#1068032, bsc#1075088, bsc#1091815).
- commit 86118e0
* Wed May  9 2018 msuchanek@suse.de
- powerpc/64s: Improve RFI L1-D cache flush fallback (bsc#1068032, bsc#1075088, bsc#1091815).
  Refresh patches.suse/powerpc-pseries-rfi-flush-Call-setup_rfi_flush-after.patch.
- commit 7c7d853
* Wed May  9 2018 msuchanek@suse.de
- Delete patches.suse/powerpc-rfi-flush-Add-DEBUG_RFI-config-option.patch.
- commit 1907214
* Wed May  9 2018 msuchanek@suse.de
- Refresh patches.suse/powerpc-pseries-Support-firmware-disable-of-RFI-flus.patch.
  Refresh patches.suse/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch
- commit a4704ad
* Wed May  9 2018 msuchanek@suse.de
- Refresh patches.suse/powerpc-64s-Wire-up-cpu_show_meltdown.patch.
  Refresh patches.suse/powerpc-64s-Allow-control-of-RFI-flush-via-debugfs.patch.
- commit d7d38e3
* Tue May  8 2018 jroedel@suse.de
- x86/bugs: Read SPEC_CTRL MSR during boot and re-use reserved
  bits (bsc#1087082 CVE-2018-3639).
- x86/bugs, KVM: Support the combination of guest and host IBRS
  (bsc#1087082 CVE-2018-3639).
- x86/bugs: Expose /sys/../spec_store_bypass (bsc#1087082
  CVE-2018-3639).
- x86/cpufeatures: Add X86_FEATURE_RDS (bsc#1087082
  CVE-2018-3639).
- x86/bugs: Provide boot parameters for the
  spec_store_bypass_disable mitigation (bsc#1087082
  CVE-2018-3639).
- x86/bugs/intel: Set proper CPU features and setup RDS
  (bsc#1087082 CVE-2018-3639).
- x86/bugs: Whitelist allowed SPEC_CTRL MSR values (bsc#1087082
  CVE-2018-3639).
- x86/bugs/AMD: Add support to disable RDS on Fam[15,16,17]h if
  requested (bsc#1087082 CVE-2018-3639).
- x86/KVM/VMX: Expose SPEC_CTRL Bit(2) to the guest (bsc#1087082
  CVE-2018-3639).
- Add driver auto probing for x86 features v4 (bsc#1087082
  CVE-2018-3639).
- do not enable SSB on non-affected CPUs (bsc#1087082
  CVE-2018-3639).
- prctl: Add speculation control prctls (bsc#1087082
  CVE-2018-3639).
- x86/process: Allow runtime control of Speculative Store Bypass
  (bsc#1087082 CVE-2018-3639).
- x86/speculation: Add prctl for Speculative Store Bypass
  mitigation (bsc#1087082 CVE-2018-3639).
- nospec: Allow getting/setting on non-current task (bsc#1087082
  CVE-2018-3639).
- seccomp: Enable speculation flaw mitigations (bsc#1087082
  CVE-2018-3639).
- prctl: Add force disable speculation (bsc#1087082
  CVE-2018-3639).
- seccomp: Use PR_SPEC_FORCE_DISABLE (bsc#1087082 CVE-2018-3639).
- seccomp: Move speculation migitation control to arch code
  (bsc#1087082 CVE-2018-3639).
- x86/speculation: Make "seccomp" the default mode for Speculative
  Store Bypass (bsc#1087082 CVE-2018-3639).
- Refresh patches.xen/xen3-patch-2.6.18.
- Refresh patches.xen/xen3-patch-2.6.21.
- Refresh patches.xen/xen3-patch-2.6.25.
- Refresh patches.xen/xen3-patch-2.6.26.
- Refresh patches.xen/xen3-patch-2.6.28.
- Refresh patches.xen/xen3-patch-2.6.35.
- Refresh patches.xen/xen3-patch-2.6.36.
- Refresh patches.xen/xen3-patch-2.6.39.
- commit 2a5662e
* Tue May  8 2018 oneukum@suse.com
- blacklist.conf: the fix silences are warning, no code change
- commit a91eed0
* Tue May  8 2018 oneukum@suse.com
- USB: hub: fix SS hub-descriptor handling (bsc#1092372).
- mmc: jz4740: Fix race condition in IRQ mask update
  (bsc#1090888).
- commit 4e5e307
* Mon May  7 2018 oneukum@suse.com
- HID: roccat: prevent an out of bounds read in
  kovaplus_profile_activated() (bsc#1087092).
- commit f7d4fb8
* Mon May  7 2018 oneukum@suse.com
- USB: Accept bulk endpoints with 1024-byte maxpacket
  (bsc#1090888).
- commit bbfa8d5
* Fri May  4 2018 jslaby@suse.cz
- series.conf: fix the header
  It was corrupted back in 2015.
- commit 4ac9fe3
* Fri May  4 2018 jslaby@suse.cz
- x86-non-upstream-eager-fpu (bnc#1087086 CVE-2018-3665).
- Refresh
  patches.arch/x86_amd_interlagos_mem_alignment_perf_improve_2_4.patch.
- x86-32, fpu: Fix DNA exception during check_fpu() (bnc#1087086
  CVE-2018-3665).
- Refresh
  patches.arch/06-x86-cpu-merge-bugs-c-and-bugs_64-c.patch.
- Refresh
  patches.arch/07-x86-spectre-Add-boot-time-option-to-select-Spectre-v.patch.
- Refresh
  patches.fixes/0002-x86-kvm-fix-kvm-s-usage-of-kernel_fpu_begin-end.
- Refresh patches.xen/xen3-patch-2.6.26.
- i387: use 'restore_fpu_checking()' directly in task switching
  code (bnc#1087086 CVE-2018-3665).
- commit a2f794c
* Thu May  3 2018 mhocko@suse.com
- perf/hwbp: Simplify the perf-hwbp code, fix documentation
  (bnc#1089895, CVE-2018-1000199).
- commit 49020d5
* Thu May  3 2018 mhocko@suse.com
- mm/mempolicy: fix use after free when calling get_mempolicy
  (bnc#1091755, CVE-2018-10675).
- commit bef54be
* Wed May  2 2018 alnovak@suse.cz
- Update config files.
  Enable retpolines for i386 build.
- commit c161339
* Wed May  2 2018 alnovak@suse.cz
- Refresh
  patches.arch/05-x86-retpoline-Add-initial-retpoline-support.patch.
  CALL_NOSPEC must be padded for the alternatives to work. This prevents
  i386 kernel from being built with CONFIG_RETPOLINE=y.
- commit 395c2a3
* Wed May  2 2018 palcantara@suse.de
- cifs: fix crash due to race in hmac(md5) handling (bsc#1091671).
- commit 3c08c8f
* Wed May  2 2018 ohering@suse.de
- xen-netfront: fix req_prod check to avoid RX hang when index
  wraps (bsc#1046610).
- commit 25a4309
* Fri Apr 27 2018 msuchanek@suse.de
- constraints: ppc64 does not build with 2.5G memory
- commit c9a4cc9
* Fri Apr 27 2018 neilb@suse.com
- Revert "NFS: allow flush-on-stat to be disabled (bsc#1065726)."
  This reverts commit 1d20ca0f05747d0db769278972dbf5405e74f2c5.
  I pushed the wrong patch.  We had settled on a mount option,
  not a module parameter.
- commit a0343f1
* Fri Apr 27 2018 lzhong@suse.com
- x86/kaiser: export symbol kaiser_set_shadow_pgd() (bsc#1090630)
- commit 8b70651
* Wed Apr 25 2018 jroedel@suse.de
- kvm/x86: fix icebp instruction handling (bsc#1087088).
- commit aa2050f
* Fri Apr 20 2018 jthumshirn@suse.de
- Update config files, add Spectre mitigation for s390x (bnc#1089386, LTC#166572).
- commit c05fc13
* Fri Apr 20 2018 jthumshirn@suse.de
- s390: correct nospec auto detection init order (bnc#1089386,
  LTC#166572).
- s390: add sysfs attributes for spectre (bnc#1089386,
  LTC#166572).
- s390: report spectre mitigation via syslog (bnc#1089386,
  LTC#166572).
- commit a22488a
* Fri Apr 20 2018 jthumshirn@suse.de
- s390: add automatic detection of the spectre defense
  (bnc#1089386, LTC#166572).
- commit 5e558e9
* Fri Apr 20 2018 jthumshirn@suse.de
- s390: move nobp parameter functions to nospec-branch.c
  (bnc#1089386, LTC#166572).
- commit 35adfe2
* Fri Apr 20 2018 jthumshirn@suse.de
- s390: do not bypass BPENTER for interrupt system calls
  (bnc#1089386, LTC#166572).
- s390: introduce execute-trampolines for branches (bnc#1089386,
  LTC#166572).
- s390: run user space and KVM guests with modified branch
  prediction (bnc#1089386, LTC#166572).
- s390: add optimized array_index_mask_nospec (bnc#1089386,
  LTC#166572).
- s390: scrub registers on kernel entry and KVM exit (bnc#1089386,
  LTC#166572).
- s390: improve cpu alternative handling for gmb and nobp
  (bnc#1089386, LTC#166572).
- commit 5ce2a40
* Fri Apr 20 2018 jthumshirn@suse.de
- s390/qeth: on channel error, reject further cmd requests
  (bnc#1088343, LTC#165985).
- commit 4f03667
* Fri Apr 20 2018 mhocko@suse.com
- kernel/signal.c: avoid undefined behaviour in
  kill_something_info (bnc1089752, CVE-2018-10124).
- commit 5984f6b
* Thu Apr 19 2018 oneukum@suse.com
- media: cpia2: Fix a couple off by one bugs (bsc#1050431).
- commit ca28708
* Thu Apr 19 2018 oneukum@suse.com
- blacklist.conf: device found only on arm
- commit 2e721e0
* Wed Apr 18 2018 msuchanek@suse.de
- powerpc/fadump: use 'fadump_reserve_mem=' when specified
  (bnc#1032084, FATE#323225).
- commit f8bfabd
* Wed Apr 18 2018 msuchanek@suse.de
- powerpc/fadump: Add a warning when 'fadump_reserve_mem='
  is used (bnc#1032084, FATE#323225).
- commit f8ee649
* Wed Apr 18 2018 msuchanek@suse.de
- powerpc/fadump: update documentation about crashkernel parameter
  reuse (bnc#1032084, FATE#323225).
- commit 7157fa5
* Wed Apr 18 2018 msuchanek@suse.de
- powerpc/fadump: reuse crashkernel parameter for fadump memory
  reservation (bnc#1032084, FATE#323225).
- commit 2bd9864
* Wed Apr 18 2018 neilb@suse.com
- blacklist.conf: add unwanted patch
- commit 8718c06
* Tue Apr 17 2018 mcgrof@suse.com
- xfs: prevent recursion in xfs_buf_iorequest (bsc#1052943).
- commit 9a5cb94
* Tue Apr 17 2018 mcgrof@suse.com
- xfs: fix buffer use after free on IO error (bsc#1052943).
- commit f87e6c9
* Mon Apr 16 2018 mhocko@suse.com
- blacklist.conf: blacklisted 9fbc1f635fd0bd28cb32550211bf095753ac637a (bnc#1089665)
- commit 0b38830
* Mon Apr 16 2018 mhocko@suse.com
- blacklist.conf: blacklisted ba4877b9ca51f80b5d30f304a46762f0509e1635
  (bnc#1089668)
- commit 5ac42e2
* Mon Apr 16 2018 mhocko@suse.com
- kernel/exit.c: avoid undefined behaviour when calling wait4()
  (bnc#1089608, CVE-2018-10087).
- commit 3aae379
* Fri Apr 13 2018 bp@suse.de
- Integrate fixes resulting from bsc#1088147
  More info in the respective commit messages.
- Refresh
  patches.arch/05-x86-retpoline-Add-initial-retpoline-support.patch.
- Refresh
  patches.arch/14.1-x86-retpoline-fill-rsb-on-context-switch-for-affected-cpus.patch.
- Refresh
  patches.suse/01-x86-feature-enable-the-x86-feature-to-control-speculation.patch.
- Refresh
  patches.suse/33-x86-microcode-Rescan-feature-flags-upon-late-loading.patch.
- commit cd63dc1
* Thu Apr 12 2018 hare@suse.de
- scsi: libsas: fix memory leak in sas_smp_get_phy_events()
  (bsc#1084536,CVE-2018-7757).
- commit 44eaa79
* Thu Apr 12 2018 jroedel@suse.de
- x86/kaiser: Hide tss_struct kabi change (bsc#1068032
  CVE-2017-5754).
- commit 0117316
* Thu Apr 12 2018 jroedel@suse.de
- x86/asm: Make ALTERNATIVE asm-macro work on 32 bit (bsc#1068032
  CVE-2017-5754).
- x86/entry: Align entry stack on 256 bytes boundary (bsc#1068032
  CVE-2017-5754).
- x86/entry/32: Use trampoline stack for kernel entry (bsc#1068032
  CVE-2017-5754).
- x86/mm: Define PUD_PAGE_MASK on 32 bit (bsc#1068032
  CVE-2017-5754).
- x86/mm: Move KAISER functions from pgtable_64.h to pgtable.h
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Makse sure only valid bits are set on top-level PAE
  page-tables (bsc#1068032 CVE-2017-5754).
- x86/head32: Align initial page-tables and make them 8k
  (bsc#1068032 CVE-2017-5754).
- x86/kaiser: Fix get_pa_from_mapping() interface (bsc#1068032
  CVE-2017-5754).
- x86/kaiser: Don't pass page-table flags as unsigned long
  (bsc#1068032 CVE-2017-5754).
- x86/kaiser: Pre-allocate Kernel-PTEs in shadow page-table for
  32 bit (bsc#1068032 CVE-2017-5754).
- x86/kaiser: Print message when KAISER is enabled (bsc#1068032
  CVE-2017-5754).
- x86/kaiser: Don't user-map the VSYSCALL page on 32 bit
  (bsc#1068032 CVE-2017-5754).
- x86/kaiser: Optimize kaiser_set_shadow_pgd() (bsc#1068032
  CVE-2017-5754).
- x86/pgtable: Populate user-page-table when KAISER is enabled
  (bsc#1068032 CVE-2017-5754).
- x86/vdso: Map compat_vdso for user-space when KAISER is enabled
  (bsc#1068032 CVE-2017-5754).
- x86/entry/32: Add CR3 switches to entry code (bsc#1068032
  CVE-2017-5754).
- KAISER: Allow on 32 bit (bsc#1068032 CVE-2017-5754).
- x86/entry/32: Use trampoline stack for kernel entry (bsc#1068032
  CVE-2017-5754).
- xen/x86/mm: Move KAISER functions from pgtable_64.h to pgtable.h
  (bsc#1068032 CVE-2017-5754).
- xen/x86/mm: Make sure only valid bits are set on top-level
  PAE page-tables (bsc#1068032 CVE-2017-5754).
- Update config files.
- Refresh patches.xen/xen-x86-pmd-handling.
- Refresh patches.xen/xen-x86_64-pgd-alloc-order.
- Refresh patches.xen/xen3-auto-arch-i386.diff.
- Update patches.xen/xen3-auto-arch-x86.diff.
- Refresh
  patches.xen/xen3-kaiser-0018-KAISER-Kernel-Address-Isolation.patch.
- Refresh patches.xen/xen3-patch-2.6.25.
- commit a234266
* Thu Apr 12 2018 vbabka@suse.cz
- cifs: fix buffer overflow in cifs_build_path_to_root()
  (bsc#1085113).
- commit 0769570
* Wed Apr 11 2018 jbeulich@suse.com
- series.conf: Re-order Xen patches, mostly to match the ordering
  of their non-Xen original counterparts.
- commit e8bfafa
* Wed Apr 11 2018 jbeulich@suse.com
- xen/x86/asm/traps: Disable tracing and kprobes in fixup_bad_iret
  and sync_regs (bsc#909077).
- commit 523b67f
* Wed Apr 11 2018 jeffm@suse.com
- Btrfs: fix log replay failure after linking special file and
  fsync (bsc#1089016).
- btrfs: handle non-fatal errors in btrfs_qgroup_inherit()
  (bsc#1089013).
- btrfs: qgroup: return EINVAL if level of parent is not higher than child's
  (bsc#1089012).
- Btrfs: fix stale dir entries after removing a link and fsync
  (bsc#1089011).
- Btrfs: avoid syncing log in the fast fsync path when not
  necessary (bsc#1089010).
- Btrfs: fix metadata inconsistencies after directory fsync
  (bsc#1093197).
- Btrfs: fix data loss in the fast fsync path (bsc#1089007).
- Btrfs: add missing inode update when punching hole
  (bsc#1089006).
- Btrfs: don't remove extents and xattrs when logging new names
  (bsc#1089005).
- commit fc497c0
* Wed Apr 11 2018 jeffm@suse.com
- housekeeping: move patches.suse/btrfs-qgroup-fix-dead-judgement-on-qgroup_rescan_leaf-return-value.patch
- commit b156e4d
* Wed Apr 11 2018 jeffm@suse.com
- Btrfs: fix fsync data loss after adding hard link to inode
  (bsc#1089004).
- commit d8f0382
* Wed Apr 11 2018 jeffm@suse.com
- Btrfs: fix fsync log replay for inodes with a mix of regular
  refs and extrefs (bsc#1089003).
- Btrfs: fix fsync when extend references are added to an inode
  (bsc#1089002).
- Btrfs: fix directory inconsistency after fsync log replay
  (bsc#1089001).
- commit 7e07c7b
* Wed Apr 11 2018 jeffm@suse.com
- Btrfs: fix fsync race leading to invalid data after log replay
  (bsc#1089000).
- commit 691fb4c
* Wed Apr 11 2018 jeffm@suse.com
- Btrfs: fix directory recovery from fsync log (bsc#1088999).
- commit 3858168
* Wed Apr 11 2018 jeffm@suse.com
- btrfs: Avoid trucating page or punching hole in a already
  existed hole (bsc#1088998).
- commit 096f851
* Wed Apr 11 2018 jeffm@suse.com
- Btrfs: make sure to copy everything if we rename (bsc#1088997).
- commit ade72dc
* Wed Apr 11 2018 jeffm@suse.com
- btrfs: fix uninitialized variable warning in __extent_writepage
  Fixes fs/btrfs/extent_io.c:2861: warning: 'ret' may be used uninitialized in this function
- commit 5434cff
* Tue Apr 10 2018 mcgrof@suse.com
- xfs: fix allocbt cursor leak in xfs_alloc_ag_vextent_near (bsc#1087762).
- commit f96cbcb
* Tue Apr 10 2018 mcgrof@suse.com
- xfs: really fix the cursor leak in xfs_alloc_ag_vextent_near (bsc#1087762).
- commit b9d9672
* Tue Apr 10 2018 mhocko@suse.com
- blacklist.conf: blacklisted f4cb767d76cf7ee72f97dd76f6cfa6c76a5edc89
  This patch is non-trivial to backport. Moreover this is VM_BUG_ON which
  is triggered and that is NOOP on our trees. So even if we have somebody
  nasty trying to fool us then it would simply shoot its own feet and
  mmap would fail later in the call chain if conflicting with an existing
  one.
- commit e8b8a14
* Tue Apr 10 2018 bp@suse.de
- Refresh bits towards getting our version of spectre closer to upstream
- Refresh
  patches.suse/22-x86-cpu-amd-add-speculative-control-support-for-amd.patch.
- Refresh
  patches.suse/23-x86-spec-check-cpuid-direclty-post-microcode-reload-to-support-ibpb-feature.patch.
- Refresh
  patches.suse/34-x86-spectre_v2-fix-ordering-in-IBRS-initialization.patch.
- commit 6ca4776
* Tue Apr 10 2018 jeffm@suse.com
- Btrfs: fix kernel oops while reading compressed data
  (bsc#1089192).
- commit fe66cd0
* Mon Apr  9 2018 oneukum@suse.com
- blacklist.conf: no cosmetic changes taken
- commit 3d81868
* Mon Apr  9 2018 oneukum@suse.com
- drm/mgag200: fix a test in mga_vga_mode_valid() (bsc#1087092).
- commit 372ab44
* Mon Apr  9 2018 oneukum@suse.com
- usbnet: Fix a race between usbnet_stop() and the BH
  (bsc#1083275).
- commit c8591bf
* Fri Apr  6 2018 mcgrof@suse.com
- xfs: check for buffer errors before waiting (bsc#1052943).
- Refresh patches.fixes/xfs-fix-re-use-of-ewouldblock-during-read-on-dm-mirror.
- commit db1928b
* Thu Apr  5 2018 tiwai@suse.de
- ALSA: seq: Fix possible UAF in snd_seq_check_queue()
  (CVE-2018-7566,bsc#1083483).
- ALSA: seq: More protection for concurrent write and ioctl races
  (CVE-2018-7566,bsc#1083483).
- commit 12c5a9e
* Thu Apr  5 2018 tiwai@suse.de
- ALSA: pcm: prevent UAF in snd_pcm_info
  (CVE-2017-0861,bsc#1088260).
- commit 9839092
* Wed Apr  4 2018 jkosina@suse.cz
- KABI: x86/kaiser: properly align trampoline stack.
- x86/kaiser: properly align trampoline stack (bsc#1087260).
- commit 86241c4
* Tue Apr  3 2018 bp@suse.de
- x86/entry/64: Don't use IST entry for #BP stack (bsc#1087088).
- Refresh patches.xen/xen3-patch-2.6.31.
- commit 2983fd3
* Thu Mar 29 2018 jslaby@suse.cz
- posix-timers: Protect posix clock array access against
  speculation (bnc#1081358).
- commit 028b198
* Wed Mar 28 2018 neilb@suse.com
- staging: ncpfs: memory corruption in ncp_read_kernel()
  (bsc#1086162, CVE-2018-8822).
- commit 506cba5
* Tue Mar 27 2018 vliaskovitis@suse.com
- Revert "USB: cdc-acm: fix broken runtime suspend" (bsc#1067912)
- commit 305d859
* Tue Mar 27 2018 mkoutny@suse.com
- x86-64: Move the "user" vsyscall segment out of the data segment
  (bsc#1082424).
- commit d5c207c
* Fri Mar 23 2018 tiwai@suse.de
- media: v4l2-compat-ioctl32.c: refactor compat ioctl32 logic
  (CVE-2017-13166,bsc#1072865).
- commit 33cc1ce
* Mon Mar 19 2018 mhocko@suse.com
- blacklist.conf: blacklisted 7edaeb6841df ("kernel/watchdog: Prevent
  false positives with turbo modes") (bnc#1063516)
- commit 3899031
* Mon Mar 19 2018 jkosina@suse.cz
- x86/retpoline: don't perform thunk calls in ring3 vsyscall code
  (bsc#1085331).
- commit 4e99a8d
* Fri Mar 16 2018 jthumshirn@suse.de
- qeth: repair SBAL elements calculation (bnc#1085513,
  LTC#165484).
- Subject: af_iucv: enable control sends in case of SEND_SHUTDOWN
  (bnc#1085513, LTC#165135).
- commit 28d6583
* Fri Mar 16 2018 neilb@suse.com
- Avoid quadratic search when freeing delegations (bsc#1084760).
- commit 3ea2b9a
* Wed Mar 14 2018 jroedel@suse.de
- x86/espfix: Fix return stack in do_double_fault() (bsc#1085279).
- commit 39516b3
* Wed Mar 14 2018 mhocko@suse.com
- Revert "KEYS: prevent KEYCTL_READ on negative key (bnc#1062840,"
  This reverts commit 3bc8b0668c2ae9af805efd9c6e5a51ca7528e803.
  The backport will be applied through standard kernel branches because
  not all branches based on cve/linux-3.0 have the original commit
  Fixes: 61ea0c0ba904 ("KEYS: Skip key state checks when checking for possession")
  which is fixed here.
- commit 1df39ea
* Wed Mar 14 2018 mhocko@suse.com
- Revert "KEYS: don't let add_key() update an uninstantiated key"
  This reverts commit d5aede8a5830e48e1e60fe3aeb337886961ea182.
  The backport will be applied through standard kernel branches because
  it conflicts with
  patches.fixes/0001-KEYS-Add-payload-preparsing-opportunity-prior-to-key.patch
  which didn't go through cve branch.
- commit 352a62c
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: let btrfs_delete_unused_bgs() to clean relocated bgs
  (FATE#325056).
- commit 691cb42
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix file/data loss caused by fsync after rename and
  new inode (bsc#1089241).
- commit 4e96047
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix unreplayable log after snapshot delete + parent
  dir fsync (bsc#1089240).
- commit 0d7d736
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix fitrim discarding device area reserved for boot
  loader's use (FATE#325056).
- commit 17df0a6
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix unprotected list move from unused_bgs to deleted_bgs
  list (FATE#325056).
- commit 8454c41
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix race between scrub and block group deletion
  (FATE#325056).
- commit a47ab1d
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix the number of transaction units needed to remove
  a block group (FATE#325056).
- commit f7bb3f7
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: use global reserve when deleting unused block group
  after ENOSPC (FATE#325056).
- commit 77cc3e9
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: Fix lost-data-profile caused by auto removing bg
  (FATE#325056).
- commit d321330
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: remove unnecessary locking of cleaner_mutex to avoid
  deadlock (FATE#325056).
- commit 65ae949
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: add missing discards when unpinning extents with -o
  discard (FATE#325056).
- commit 59aa8ba
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: explictly delete unused block groups in close_ctree
  and ro-remount (FATE#325056).
- commit 21a281d
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: iterate over unused chunk space in FITRIM (FATE#325056).
- commit e52c489
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: skip superblocks during discard (FATE#325056).
- commit 02f2d59
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: btrfs_issue_discard ensure offset/length are aligned
  to sector boundaries (FATE#325056).
- commit 6afb5f9
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: make btrfs_issue_discard return bytes discarded
  (FATE#325056).
- commit 748a724
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: Use ref_cnt for set_block_group_ro() (bsc#1089239).
- commit 2e93bcf
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix fsync data loss after append write (bsc#1089238).
- commit 3bedfe3
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix race between balance and unused block group deletion
  (bsc#1089237).
- commit c28ae78
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix -ENOSPC on block group removal (FATE#325056).
- commit cd89932
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix -ENOSPC when finishing block group creation
  (FATE#325056).
- commit a2f4072
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix chunk allocation regression leading to transaction
  abort (bsc#1089236).
- commit 6444176
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: check pending chunks when shrinking fs to avoid
  corruption (bsc#1089235).
- commit 72716e1
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix regression in raid level conversion (bsc#1089234).
- commit 3161877
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix racy system chunk allocation when setting block
  group ro (bsc#1089233).
- commit e1b87af
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: delete chunk allocation attemp when setting block group
  ro (FATE#325056).
- commit 7b7e59f
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix find_free_dev_extent() malfunction in case device
  tree has hole (bsc#1089232).
- commit 3eadbff
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: Set relative data on clear
  btrfs_block_group_cache->pinned (FATE#325056).
- commit 6c5ef66
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix BUG_ON in btrfs_orphan_add() when delete unused
  block group (FATE#325056).
- commit b0fa22a
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: Fix out-of-space bug (bsc#1089231).
- commit 2016fc9
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix race between transaction commit and empty block
  group removal (FATE#325056).
- commit 2138aa2
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: remove non-sense btrfs_error_discard_extent() function
  (bsc#1089230).
- commit 6078d2b
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: ensure deletion from pinned_chunks list is protected
  (FATE#325056).
- commit 13be91f
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix unprotected deletion from pending_chunks list
  (FATE#325056).
- commit ba5bf30
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix fs mapping extent map leak (bsc#1089229).
- commit 333b85d
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix memory leak after block remove + trimming
  (FATE#325056).
- commit 6281090
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix race between fs trimming and block group
  remove/allocation (FATE#325056).
- commit f940dd9
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix freeing used extents after removing empty block group
  (FATE#325056).
- commit 6670cd6
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix crash caused by block group removal (FATE#325056).
- commit d1aa70e
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix freeing used extent after removing empty block group
  (FATE#325056).
- commit 26068fd
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: remove empty block groups automatically (FATE#325056).
- commit e28a626
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: Fix misuse of chunk mutex (FATE#325056).
- commit c947362
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix unprotected device list access when getting the fs
  information (bsc#1089228).
- commit f236982
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix unprotected device's variants on 32bits machine
  (bsc#1089227).
- commit bf8073e
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: update free_chunk_space during allocting a new chunk
  (bsc#1089226).
- commit 6fdfa64
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix unprotected device->bytes_used update (bsc#1089225).
- commit 36b0196
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix wrong device bytes_used in the super block
  (bsc#1089224).
- commit b53fecd
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix wrong disk size when writing super blocks
  (bsc#1089223).
- commit 65e7110
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix unprotected assignment of the target device
  (bsc#1089222).
- commit 25e31e3
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix fsync data loss after a ranged fsync (bsc#1089221).
- commit 83ae432
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix NULL pointer crash when running balance and scrub
  concurrently (bsc#1089220).
- commit 8e65f45
* Tue Mar 13 2018 jeffm@suse.com
- fs: btrfs: volumes.c: Fix for possible null pointer dereference
  (bsc#1089219).
- commit dab26b7
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: remove transaction from send (bsc#1089218).
- commit 6906ba9
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix skipped error handle when log sync failed
  (bsc#1089217).
- commit 8182736
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix the skipped transaction commit during the file sync
  (bsc#1089216).
- commit d4dcc09
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix unprotected alloc list insertion during the finishing
  procedure of replace (bsc#1089215).
- commit 6d4b77b
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: don't mix the ordered extents of all files together
  during logging the inodes (bsc#1089214).
- commit 25f0a9c
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: only drop modified extents if we logged the whole inode
  (bsc#1089213).
- commit d0ed8c1
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: return an error from btrfs_wait_ordered_range
  (bsc#1089212).
- commit 7ca8267
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: eliminate races in worker stopping code (bsc#1089211).
- commit 35fa83a
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: don't leak transaction in btrfs_sync_file()
  (bsc#1089210).
- commit a554138
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: only update disk_i_size as we remove extents
  (bsc#1089209).
- commit ae8d9bc
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: stop refusing the relocation of chunk 0 (bsc#1089208).
- commit d3271c7
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: add support for asserts (bsc#1089207).
- commit ba6c4b2
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: fix race conditions in BTRFS_IOC_FS_INFO ioctl
  (bsc#1089206).
- commit 85b4494
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: add alloc_fs_devices and switch to it (bsc#1089205).
- commit 3fa61f0
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: add btrfs_alloc_device and switch to it (bsc#1089204).
- commit 3ff08b0
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: wait ordered range before doing direct io (bsc#1089203).
- commit 5b6161a
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: make the chunk allocator completely tree lockless
  (bsc#1089202).
- commit 2189b90
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: move btrfs_truncate_page to btrfs_cont_expand instead
  of btrfs_truncate (bsc#1089201).
- commit 68be2d9
* Tue Mar 13 2018 jeffm@suse.com
- Btrfs: cleanup backref search commit root flag stuff
  (bsc#1089200).
- commit cb03c64
* Tue Mar 13 2018 jeffm@suse.com
- btrfs: nuke write_super from comments (bsc#1089199).
- commit 76610f6
* Mon Mar 12 2018 jeffm@suse.com
- btrfs: fix stray unlock in btrfs_qgroup_account_ref
  patches.suse/btrfs-1308-fix-qgroup-rescan-resume-on-mount.patch was
  missing a chunk that removed the unlock during the error case.
- commit c41c6a8
* Fri Mar  9 2018 jbeulich@suse.com
- xen/x86/syscall: Sanitize syscall table de-references under
  speculation (bsc#1068032 bsc#1082860 CVE-2017-5753).
- Refresh
  patches.xen/xen3-03-x86-entry-use-ibrs-on-entry-to-kernel-space.patch.
- Refresh
  patches.xen/xen3-08-x86-retpoline-entry-Convert-entry-assembler-indirect.patch.
- commit ce41fda
* Fri Mar  9 2018 jbeulich@suse.com
- xen/x86: Implement array_index_mask_nospec (bsc#1068032
  bsc#1082860 CVE-2017-5753).
- Update and move patches.xen/xen3-0004-x86-Introduce-barrier_nospec.patch
  (bsc#1068032 bsc#1082860 CVE-2017-5753).
- commit 51698c9
* Fri Mar  9 2018 vbabka@suse.cz
- leds: do not overflow sysfs buffer in led_trigger_show
  (bsc#1080464).
- commit b15e096
* Wed Mar  7 2018 jslaby@suse.cz
- Refresh
  patches.suse/0009-x86-syscall-Sanitize-syscall-table-de-references-und.patch.
- Refresh
  patches.arch/08-x86-retpoline-entry-Convert-entry-assembler-indirect.patch.
- Refresh
  patches.suse/03-x86-entry-use-ibrs-on-entry-to-kernel-space.patch.
- Refresh patches.suse/kaiser-11-sp4-trampoline-stack-entry.patch.
  One more fix -- sbb works well only with jae.
- commit 4e333fe
* Tue Mar  6 2018 msuchanek@suse.de
- ide-cd: workaround VMware ESXi cdrom emulation bug
  (bsc#1080813).
- commit 0804aa8
* Tue Mar  6 2018 msuchanek@suse.de
- scsi: sr: workaround VMware ESXi cdrom emulation bug
  (bsc#1080813).
- commit 37c3471
* Mon Mar  5 2018 neilb@suse.com
- dm: fix race between dm_get_from_kobject() and __dm_destroy()
  (bsc#1083242, CVE-2017-18203).
- commit f932d79
* Thu Mar  1 2018 dbueso@suse.de
- ipc/msg: introduce msgctl(MSG_STAT_ANY) (bsc#1072689).
- ipc/sem: introduce semctl(SEM_STAT_ANY) (bsc#1072689).
- ipc/shm: introduce shmctl(SHM_STAT_ANY) (bsc#1072689).
- commit 23c5cc7
* Thu Mar  1 2018 oneukum@suse.com
- usbip: prevent vhci_hcd driver from leaking a socket pointer
  address (bsc#1078674 CVE-2017-16911).
- commit 2898c67
* Thu Mar  1 2018 mhocko@suse.com
- mm/madvise.c: fix madvise() infinite loop under special
  circumstances (bnc#1083494, CVE-2017-18208).
- commit 2de29c0
* Thu Mar  1 2018 tiwai@suse.de
- ALSA: seq: Fix racy pool initializations
  (CVE-2018-7566,bsc#1083483).
- commit 88c0254
* Thu Mar  1 2018 jlee@suse.com
- KEYS: don't let add_key() update an uninstantiated key
  (bnc#1063416).
- commit d5aede8
* Wed Feb 28 2018 jack@suse.cz
- blacklist.conf: Blacklist 98801506552593c9b8ac11021b0cdad12cab4f6b
- commit 527e0ca
* Wed Feb 28 2018 bp@suse.de
- media: hdpvr: Fix an error handling path in hdpvr_probe()
  (bsc#1067118 CVE-2017-16644).
- commit 33278a2
* Tue Feb 27 2018 jlee@suse.com
- KEYS: prevent creating a different user's keyrings
  (bnc#1065999).
- commit 7019940
* Mon Feb 26 2018 jslaby@suse.cz
- PCI: Use function 0 VPD for identical functions, regular VPD
  for others (bnc#943786 git-fixes).
- commit 1441f04
* Mon Feb 26 2018 msuchanek@suse.de
- powerpc/pseries: Support firmware disable of RFI flush
  (bsc#1068032, bsc#1075088).
- commit ec5c202
* Fri Feb 23 2018 jslaby@suse.cz
- crypto: more robust crypto_memneq (bsc#1068032 CVE-2017-5753).
- Documentation: Document array_index_nospec (bsc#1068032
  CVE-2017-5753).
- array_index_nospec: Sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5753).
- x86: Implement array_index_mask_nospec (bsc#1068032
  CVE-2017-5753).
- x86: Introduce barrier_nospec (bsc#1068032 CVE-2017-5753).
- x86: Introduce __uaccess_begin_nospec() and uaccess_try_nospec
  (bsc#1068032 CVE-2017-5753).
- x86/uaccess: Use __uaccess_begin_nospec() and uaccess_try_nospec
  (bsc#1068032 CVE-2017-5753).
- x86/get_user: Use pointer masking to limit speculation
  (bsc#1068032 CVE-2017-5753).
- x86/syscall: Sanitize syscall table de-references under
  speculation (bsc#1068032 CVE-2017-5753).
- vfs, fdtable: Prevent bounds-check bypass via speculative
  execution (bsc#1068032 CVE-2017-5753).
- x86/spectre: Report get_user mitigation for spectre_v1
  (bsc#1068032 CVE-2017-5753).
- xen/x86: Introduce barrier_nospec (bsc#1068032 CVE-2017-5753).
- blacklist.conf: add one more
- Refresh
  patches.arch/08-x86-retpoline-entry-Convert-entry-assembler-indirect.patch.
- Delete patches.suse/0006-fs-prevent-speculative-execution.patch.
- Delete patches.suse/sysfs-spectre_v1-is-mitigated.patch.
  Make use of the spectre v1 patches from upstream. We leave the
  non-upstream mess (the gmb barrier) for non-x86 archs around until
  they introduce the user pointer sanitization too. Note that the fs
  patch is dropped as it uses index clamping now (and that is
  implemented for all archs in this patchset).
- commit b11bd2c
* Fri Feb 23 2018 jbeulich@suse.com
- xen/x86/cpu: Fix bootup crashes by sanitizing the argument of
  the 'clearcpuid=' command-line option (bsc#1065600).
- commit 0aea410
* Fri Feb 23 2018 jbeulich@suse.com
- xen/x86/entry: Use IBRS on entry to kernel space (bsc#1068032).
- xen/x86/retpoline: Add initial retpoline support (bsc#1068032
  CVE-2017-5715).
- xen/x86/idle: Toggle IBRS when going idle (bsc#1068032).
- xen/x86/spectre: Add boot time option to select Spectre v2
  mitigation (bsc#1068032 CVE-2017-5715).
- xen/x86/retpoline/entry: Convert entry assembler indirect jumps
  (bsc#1068032 CVE-2017-5715).
- xen/x86/retpoline/ftrace: Convert ftrace assembler indirect
  jumps (bsc#1068032 CVE-2017-5715).
- xen/x86/retpoline: Fill RSB on context switch for affected CPUs
  (bsc#1068032 CVE-2017-5754).
- xen/x86/retpoline/entry: convert unwind assembly indirect jumps
  (bsc#1068032 CVE-2017-5715).
- xen/x86/CPU: Check speculation control CPUID bit (bsc#1068032).
- xen/x86/cpu: Factor out application of forced CPU caps
  (bsc#1075994 bsc#1075091).
- xen/x86/CPU: Sync CPU feature flags late (bsc#1075994
  bsc#1075091).
- Refresh / restore a few other Xen patches.
- commit f943ded
* Fri Feb 23 2018 jbeulich@suse.com
- xen/x86/kaiser: Move feature detection up (bsc#1068032).
- commit c942811
* Fri Feb 23 2018 jbeulich@suse.com
- patches.xen/xen3-kaiser-nokaiser-0005-kaiser-add-nokaiser-boot-option-using-ALTERNATIVE.patch:
  Update to avoid trying to set CR4.PGE (bsc#1068032 CVE-2017-5754).
- commit a1b85bf
* Fri Feb 23 2018 jbeulich@suse.com
- patches.xen/xen3-0001-x86-64-Give-vvars-their-own-page.patch,
  patches.xen/xen3-0001-x86-64-Map-the-HPET-NX.patch,
  patches.xen/xen3-kaiser-0009-x86-mm-sched-core-Uninline-switch_mm.patch,
  patches.xen/xen3-kaiser-0010-x86-mm-sched-core-Turn-off-IRQs-in-switch_mm.patch,
  patches.xen/xen3-kaiser-0012-x86-mm-Remove-the-UP-asm-tlbflush.h-code-always-use-.patch,
  patches.xen/xen3-kaiser-0015-x86-mm-Enable-CR4.PCIDE-on-supported-systems.patch,
  patches.xen/xen3-kaiser-0018-KAISER-Kernel-Address-Isolation.patch,
  patches.xen/xen3-kaiser-0019-x86-mm-kaiser-re-enable-vsyscalls.patch,
  patches.xen/xen3-kaiser-nokaiser-0006-kaiser-use-ALTERNATIVE-instead-of-x86_cr3_pcid_noflu.patch,
  patches.xen/xen3-kaiser-nokaiser-0007-rename-and-simplify-feature-setting.patch:
  Update references.
- commit 7aa0f5e
* Fri Feb 23 2018 jbeulich@suse.com
- xen/locking/barriers: introduce new memory barrier gmb()
  (bsc#1068032 CVE-2017-5753).
- commit a3d88dc
* Fri Feb 23 2018 jbeulich@suse.com
- x86/retpoline/entry: convert unwind assembly indirect jumps
  (bsc#1068032 CVE-2017-5715).
- commit 9011859
* Fri Feb 23 2018 jbeulich@suse.com
- x86/AMD: fix making LFENCE a serializing instruction
  (bsc#1068032 CVE-2017-5754).
- commit fcf732f
* Fri Feb 23 2018 neilb@suse.com
- blacklist.conf:
  Add unwanted patch.
- commit a4c79c7
* Fri Feb 23 2018 neilb@suse.com
- NFSv4: fix getacl head length estimation (git-fixes).
- jffs2: Fix use-after-free bug in jffs2_iget()'s error handling
  path (git-fixes).
- pipe: actually allow root to exceed the pipe buffer limits
  (git-fixes).
- commit f7456f9
* Thu Feb 22 2018 jthumshirn@suse.de
- s390/qeth: fix underestimated count of buffer elements
  (bnc#1082091, LTC#164529).
- commit 146500f
* Tue Feb 20 2018 mgalbraith@suse.de
- hrtimer: Ensure POSIX compliance (relative CLOCK_REALTIME
  hrtimers) (bnc#1013018).
- hrtimer: Reset hrtimer cpu base proper on CPU hotplug
  (bnc#1013018).
- commit 2468d22
* Mon Feb 19 2018 bp@suse.de
- x86, asm: Extend definitions of _ASM_* with a raw format
  (bsc#1068032 CVE-2017-5754).
- Refresh
  patches.arch/13.1-x86-asm-use-register-variable-to-get-stack-pointer-value.patch.
- Refresh
  patches.arch/14-x86-retpoline-Fill-return-stack-buffer-on-vmexit.patch.
- Refresh
  patches.arch/14.1-x86-retpoline-fill-rsb-on-context-switch-for-affected-cpus.patch.
- Refresh
  patches.arch/17-x86-retpoline-remove-the-esp-rsp-thunk.patch.
- Delete
  patches.arch/14.2-x86-asm-extend-definitions-of-asm_-with-a-raw-format.patch.
- Delete
  patches.arch/14.3-x86-retpoline-simplify-vmexit_fill_rsb.patch.
- commit 942b437
* Mon Feb 19 2018 hare@suse.de
- scsi: virtio_scsi: let host do exception handling
  (bsc#936530,bsc#1060682).
- Delete
  patches.fixes/0001-virtio_scsi-Implement-eh_timed_out-callback.patch.
- commit 191b8f7
* Mon Feb 19 2018 mgorman@suse.de
- mm: pin address_space before dereferencing it while isolating
  an LRU page (bnc#1081500).
- commit 0cabe05
* Mon Feb 19 2018 mgalbraith@suse.de
- blacklist.conf: blacklist 7edaeb6841dfb27e362288ab8466ebdc4972e867
- commit 3cbdd5c
* Mon Feb 19 2018 mgalbraith@suse.de
- blacklist.conf: blacklist d207af2eab3f8668b95ad02b21930481c42806fd
- commit 7c18f19
* Thu Feb 15 2018 jeffm@suse.com
- btrfs: qgroup: Fix dead judgement on qgroup_rescan_leaf()
  return value (bsc#1080685).
- commit e5b10a6
* Thu Feb 15 2018 jeffm@suse.com
- btrfs: copy fsid to super_block s_uuid (bsc#1080774).
- commit 28489e9
* Thu Feb 15 2018 jkosina@suse.cz
- patches.suse/kaiser-11-sp4-trampoline-stack-entry.patch: Fix trampoline stack
  loading issue on XEN PV
- commit 42616e5
* Thu Feb 15 2018 jkosina@suse.cz
- patches.suse/kaiser-11-sp4-trampoline-stack-entry.patch: really do switch
  away from trampoline stack to kernel stack in ia32_syscall entry (bsc#1080579)
- commit 7a7c8b6
* Wed Feb 14 2018 tiwai@suse.de
- futex: Prevent overflow by strengthen input validation
  (CVE-2018-6927,bsc#1080757).
- commit 64694bf
* Tue Feb 13 2018 jkosina@suse.cz
- patches.suse/kaiser-11-sp4-trampoline-stack-entry.patch: do not clobber ZF
  by calling ENABLE_IBRS after test and before jz
- commit 9e99948
* Tue Feb 13 2018 jkosina@suse.cz
- patches.suse/kaiser-11-sp4-trampoline-stack-entry.patch: make sure not
  to touch stack after CR3 switch in compat syscall return
- commit dbf601e
* Tue Feb 13 2018 jkosina@suse.cz
- patches.suse/kaiser-11-sp4-trampoline-stack-entry.patch: handle
  non-accessible stack in sysretl_from_sys_call properly (bsc#bsc#1080579)
- commit fc1ed5b
* Tue Feb 13 2018 jeffm@suse.com
- btrfs: qgroup: exit the rescan worker during umount
  (bsc#1080685).
- commit 846f816
* Mon Feb 12 2018 jeffm@suse.com
- Btrfs: fix two use-after-free bugs with transaction cleanup
  (FATE#325056).
- commit f92a3e1
* Mon Feb 12 2018 jeffm@suse.com
- Btrfs: stop waiting on current trans if we aborted
  (FATE#325056).
- commit d6de1b7
* Mon Feb 12 2018 jeffm@suse.com
- Btrfs: reset intwrite on transaction abort (FATE#325056).
- commit dd91eef
* Mon Feb 12 2018 jeffm@suse.com
- Btrfs: make the state of the transaction more readable
  (FATE#325056).
- commit 4346a98
* Mon Feb 12 2018 jeffm@suse.com
- Btrfs: don't wait for all the writers circularly during the
  transaction commit (FATE#325056).
- commit 01fa191
* Mon Feb 12 2018 jeffm@suse.com
- Btrfs: cleanup unnecessary assignment when cleaning up all
  the residual transaction (FATE#325056).
- commit 997ed73
* Mon Feb 12 2018 jeffm@suse.com
- Refresh patches.suse/btrfs-0795-fix-orphan-transaction-on-the-freezed-filesyst.patch
  Commit e7e7197b4a7 refreshed this patch previously but it relocated
  it into cleanup_transaction instead of btrfs_commit_transaction.  Since
  the call to sb_end_intwrite goes to an empty shim, there was no
  regression introduced.  It does affect context for later patches, though.
- commit 41c8716
* Mon Feb 12 2018 oneukum@suse.com
- usbip: fix stub_send_ret_submit() vulnerability to null
  transfer_buffer (bsc#1078669 CVE-2017-16914).
- commit 5136dd3
* Mon Feb 12 2018 jeffm@suse.com
- dm flakey: introduce "error_writes" feature (bsc#1080372).
- dm flakey: fix reads to be issued if drop_writes configured
  (bsc#1080372).
- dm flakey: error READ bios during the down_interval
  (bsc#1080372).
- dm flakey: fix crash on read when corrupt_bio_byte not set
  (bsc#1080372).
- dm flakey: add corrupt_bio_byte feature (bsc#1080372).
- dm flakey: add drop_writes (bsc#1080372).
- dm flakey: support feature args (bsc#1080372).
- dm flakey: use dm_target_offset and support discards
  (bsc#1080372).
- commit 87bf581
* Mon Feb 12 2018 jkosina@suse.cz
- patches.suse/kaiser-11-sp4-trampoline-stack-entry.patch: fix ia32 compat
  sysexit (bsc#1080579)
  sysexit_from_sys_call cannot make assumption of accessible stack after CR3
  switch, and therefore should use the SWITCH_USER_CR3_NO_STACK method to
  flip the pagetable hierarchy.
- commit 683b644
* Mon Feb 12 2018 jkosina@suse.cz
- README.BRANCH: remove Ales Novak and Michal Suchanek as temporary co-maintainers
- commit 688fa2c
* Sun Feb 11 2018 msuchanek@suse.de
- Update kabi files from previous release.
- commit 507d388
* Fri Feb  9 2018 jeffm@suse.com
- Btrfs: don't WARN() in btrfs_transaction_abort() for IO errors
  (bsc#1080363).
- commit 03c3b5a
* Fri Feb  9 2018 jeffm@suse.com
- Btrfs: set qgroup_ulist to be null after calling ulist_free()
  (bsc#1080359).
- commit fb519fc
* Fri Feb  9 2018 msuchanek@suse.de
- rfi-flush: Switch to new linear fallback flush (bsc#1068032,
  bsc#1075088).
- commit c439039
* Fri Feb  9 2018 bp@suse.de
- HID: core: prevent out-of-bound readings (bsc#1010470
  CVE-2016-7915).
- commit bcacabf
* Fri Feb  9 2018 bp@suse.de
- virtio-net: drop NETIF_F_FRAGLIST (bsc#940776 CVE-2015-5156).
- commit 89e6368
* Fri Feb  9 2018 jlee@suse.com
- KEYS: prevent KEYCTL_READ on negative key (bnc#1062840,
  CVE-2017-12192).
- commit 3bc8b06
* Fri Feb  9 2018 jthumshirn@suse.de
- fix unbalanced page refcounting in bio_map_user_iov (bsc#1062568
  CVE-2017-12190).
- commit 916ddb2
* Thu Feb  8 2018 msuchanek@suse.de
- Revert "Drop Cell support (bnc#1049128)."
  Breaks kABI so revert for now.
- commit 7705c43
* Thu Feb  8 2018 jkosina@suse.cz
- README.BRANCH: add Ales Novak for handling with kABI issues
- commit 5abd1bf
* Thu Feb  8 2018 jkosina@suse.cz
- README.BRANCH: add Michal Suchanek as temporary co-maintainer during
  my absence
- commit 60f9f87
* Thu Feb  8 2018 msuchanek@suse.de
- powerpc/perf: Fix book3s kernel to userspace backtraces
  (bsc#1080133).
- commit 56f414d
* Thu Feb  8 2018 alnovak@suse.cz
- Revert "Drop Cell support (bnc#1049128)."
  This reverts commit bee71b314907305b9a73037891bebf43319f3ddd.
- commit e465123
* Thu Feb  8 2018 alnovak@suse.cz
- Update kabi files (ppc64).
- commit 6f33884
* Thu Feb  8 2018 oneukum@suse.com
- usbip: fix stub_rx: get_pipe() to validate endpoint number
  (bsc#1078673 CVE-2017-16912).
- Refresh
  patches.fixes/0001-usbip-fix-stub_rx-harden-CMD_SUBMIT-path-to-handle-m.patch.
- commit 264631b
* Thu Feb  8 2018 alnovak@suse.cz
- Update kabi files.
- commit f25b375
* Wed Feb  7 2018 msuchanek@suse.de
- powerpc: Fix up the kdump base cap to 128M (bsc#1079917,
  bsc#1077487).
- commit 1f27ff1
* Wed Feb  7 2018 lduncan@suse.com
- scsi: libiscsi: fix shifting of DID_REQUEUE host byte
  (bsc#1078875).
- commit 13ca3d7
* Wed Feb  7 2018 jslaby@suse.cz
- x86/speculation: Fix typo IBRS_ATT, which should be IBRS_ALL
  (bsc#1068032 CVE-2017-5715).
  Just a comment fixup to have code 1:1 and also make the git-fixes
  script happy.
- commit 26af0d7
* Wed Feb  7 2018 oneukum@suse.com
- usb: add helper to extract bits 12:11 of wMaxPacketSize
  (bsc#1078672 CVE-2017-16913).
- commit f046c1c
* Tue Feb  6 2018 jeffm@suse.com
- housekeeping: reorder btrfs patchset to match upstream order
  There are no substantive code changes.
- commit 447bd54
* Tue Feb  6 2018 oneukum@suse.com
- usbip: fix stub_rx: harden CMD_SUBMIT path to handle malicious
  input (bsc#1078672 CVE-2017-16913).
- commit 6f5bc68
* Tue Feb  6 2018 mkubecek@suse.cz
- RDS: Heap OOB write in rds_message_alloc_sgs() (CVE-2018-5332
  bsc#1075621).
- commit 20dba0b
* Tue Feb  6 2018 mkubecek@suse.cz
- RDS: null pointer dereference in rds_atomic_free_op
  (CVE-2018-5333 bsc#1075617).
- commit d4c1a21
* Tue Feb  6 2018 mkubecek@suse.cz
- netfilter: xt_TCPMSS: add more sanity tests on tcph->doff
  (CVE-2017-18017 bsc#1074488).
- netfilter: xt_TCPMSS: fix handling of malformed TCP header
  and options (CVE-2017-18017 bsc#1074488).
- commit 7dbe4c0
* Mon Feb  5 2018 bp@suse.de
- blacklist.conf:
- commit 1585165
* Mon Feb  5 2018 bp@suse.de
- x86/microcode/intel: Extend BDW late-loading further with LLC
  size check (bsc#1054305).
- commit 0032298
* Mon Feb  5 2018 ghe@suse.com
- ocfs2: NFS hangs in __ocfs2_cluster_lock due to race with
  ocfs2_unblock_lock (bsc#962257).
- commit 4cf0c2a
* Mon Feb  5 2018 ghe@suse.com
- ocfs2: do not set OCFS2_LOCK_UPCONVERT_FINISHING if nonblocking
  lock can not be granted at once (bsc#1076437).
- commit de47d2f
* Mon Feb  5 2018 ghe@suse.com
- ocfs2: avoid blocking in ocfs2_mark_lockres_freeing() in
  downconvert thread (bsc#1076437).
- commit 3da66e4
* Mon Feb  5 2018 ghe@suse.com
- ocfs2: remove this patch temporarily
  since I need to back-port ocfs2 patches to fix bug 1076437,
  but this patch will impact more older patches to apply
  SLE11SP4 kernel. So, I will remove this patch temporarily,
  then get this patch back after this back-port is done.
- commit 5e132d1
* Fri Feb  2 2018 bp@suse.de
- Input: i8042 - fix crash at boot time (bsc1077922
  CVE-2017-18079).
- commit 8f7d06f
* Fri Feb  2 2018 jkosina@suse.cz
- Update config files: enable CPU vulnerabilities reporting via sysfs
- commit 1ae278d
* Fri Feb  2 2018 jkosina@suse.cz
- Move kABI fixup for retpolines to proper place.
- commit 1101679
* Fri Feb  2 2018 neilb@suse.com
- NFSv4: Keep dropped state owners on the LRU list for a while
  (bsc#1031572).
- Fix kabi break cased by NFS: Cache state owners after files
  are closed (bsc#1031572).
- NFS: Cache state owners after files are closed (bsc#1031572).
- commit 7583091
* Thu Feb  1 2018 bp@suse.de
- Refresh patches.arch/sysfs-cpu-Add-vulnerability-folder.patch.
- commit 205a1bc
* Thu Feb  1 2018 jkosina@suse.cz
- patches.suse/rats-kabi.patch: Fix kABI
- commit 15f435d
* Wed Jan 31 2018 bp@suse.de
- Update config files.
- commit cf9af36
* Wed Jan 31 2018 bp@suse.de
- Refresh patches.suse/retpolines-disable-ibrs-on-non-skl.patch.
- commit 41fd4d9
* Wed Jan 31 2018 bp@suse.de
- x86/retpolines/spec_ctrl: disable IBRS on !SKL if retpolines
  are active (bsc#1068032).
- sysfs: spectre_v2, handle spec_ctrl (bsc#1075994 bsc#1075091).
- x86/spectre_v2: nospectre_v2 means nospec too (bsc#1075994
  bsc#1075091).
- x86/boot: Fix early command-line parsing when matching at end
  (bsc#1068032).
- sysfs: spectre_v1 is mitigated (bsc#1068032 CVE-2017-5753).
- sysfs/cpu: Fix typos in vulnerability documentation
  (bnc#1012382).
- x86/cpu: Implement CPU vulnerabilites sysfs functions
  (bnc#1012382).
- sysfs/cpu: Add vulnerability folder (bnc#1012382).
- commit 12d4b3c
* Wed Jan 31 2018 msuchanek@suse.de
- Drop Cell support (bnc#1049128).
- Update config files - remove Cell support
- kabi/severities ignore Cell-specific symbols
- commit bee71b3
* Wed Jan 31 2018 bp@suse.de
- x86/vdso: Remove retpoline flags (bsc#1068032 CVE-2017-5754).
- commit 211264b
* Wed Jan 31 2018 jkosina@suse.cz
- Update patches.suse/kaiser-11-sp4-trampoline-stack-entry.patch
  (bsc#1077560) - fix references
- commit 0c3e1d8
* Wed Jan 31 2018 jkosina@suse.cz
- x86/kaiser: use trampoline stack for kernel entry.
- Delete patches.suse/kaiser-clear-thread-stack.patch: unnecessary with
  trampoline stack entry.
- Refresh patches.xen/xen3-auto-arch-x86_64.diff: context
- commit ea664c6
* Wed Jan 31 2018 tbogendoerfer@suse.de
- i40e/i40evf: Add a workaround to drop all flow control frames
  (bsc#1077355 CVE-2015-1142857).
- commit 3ad2985
* Wed Jan 31 2018 bp@suse.de
- Refresh
  patches.arch/05-x86-retpoline-Add-initial-retpoline-support.patch.
- commit 55b9a21
* Tue Jan 30 2018 bp@suse.de
- x86/retpoline: Remove the esp/rsp thunk (bsc#1068032
  CVE-2017-5754).
- commit 987a1b6
* Mon Jan 29 2018 bp@suse.de
- Update config files.
- commit 9589e9a
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/64: Convert the syscall exit path to use RFI_TO_USER/KERNEL
  (bsc#1068032, bsc#1075088).
  Refresh patches.suse/powerpc-rfi-flush.patch.
- commit 4347935
* Mon Jan 29 2018 bp@suse.de
- x86/alternatives: Add missing '\n' at end of ALTERNATIVE inline
  asm (bsc#1068032 CVE-2017-5754).
- x86/kbuild: enable modversions for symbols exported from asm
  (bsc#1068032 CVE-2017-5715).
- x86/asm: Make asm/alternative.h safe from assembly (bsc#1068032
  CVE-2017-5715).
- EXPORT_SYMBOL() for asm (bsc#1068032 CVE-2017-5715).
- kbuild: modversions for EXPORT_SYMBOL() for asm (bsc#1074621
  bsc#1068032).
- modpost: fix bogus 'exported twice' warnings (bsc#1068032
  CVE-2017-5754).
- x86/retpoline: Add initial retpoline support (bsc#1068032
  CVE-2017-5715).
- x86/cpu: Merge bugs.c and bugs_64.c (bsc#1068032 CVE-2017-5754).
- x86/spectre: Add boot time option to select Spectre v2
  mitigation (bsc#1068032 CVE-2017-5715).
- x86/retpoline/entry: Convert entry assembler indirect jumps
  (bsc#1068032 CVE-2017-5715).
- x86/retpoline/ftrace: Convert ftrace assembler indirect jumps
  (bsc#1068032 CVE-2017-5715).
- x86/retpoline/hyperv: Convert assembler indirect jumps
  (bsc#1068032 CVE-2017-5715).
- x86/retpoline/xen: Convert Xen hypercall indirect jumps
  (bsc#1068032 CVE-2017-5715).
- x86/retpoline/checksum32: Convert assembler indirect jumps
  (bsc#1068032 CVE-2017-5715).
- x86/retpoline/irq32: Convert assembler indirect jumps
  (bsc#1068032 CVE-2017-5715).
- x86/asm: Use register variable to get stack pointer value
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Fill return stack buffer on vmexit (bsc#1068032
  CVE-2017-5715).
- x86/cpu/intel: Introduce macros for Intel family numbers
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Fill RSB on context switch for affected CPUs
  (bsc#1068032 CVE-2017-5754).
- x86, asm: Extend definitions of _ASM_* with a raw format
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Simplify vmexit_fill_RSB() (bsc#1068032
  CVE-2017-5754).
- x86/retpoline: Remove compile time warning (bsc#1068032
  CVE-2017-5754).
- asm-prototypes: Clear any CPP defines before declaring the
  functions (bsc#1068032 CVE-2017-5754).
- Refresh
  patches.suse/18-x86-spec_ctrl-check-whether-ibrs-is-enabled-before-using-it.patch.
- Refresh
  patches.suse/19-x86-spec_ctrl-check-whether-ibpb-is-enabled-before-using-it.patch.
- Refresh
  patches.suse/20-x86-cpu-check-speculation-control-cpuid-bit.patch.
- Refresh patches.suse/21-x86-spec-add-nospec-chicken-bit.patch.
- Refresh
  patches.suse/22-x86-cpu-amd-add-speculative-control-support-for-amd.patch.
- Refresh
  patches.suse/23-x86-spec-check-cpuid-direclty-post-microcode-reload-to-support-ibpb-feature.patch.
- Refresh
  patches.suse/34-x86-spectre_v2-fix-ordering-in-IBRS-initialization.patch.
- Refresh patches.xen/xen3-patch-2.6.26.
- Refresh patches.xen/xen3-patch-2.6.27.
- Refresh patches.xen/xen3-patch-2.6.30.
- Delete
  patches.suse/12-x86-entry-add-a-function-to-overwrite-the-rsb.patch.
- Delete
  patches.suse/13-x86-entry-stuff-rsb-for-entry-to-kernel-for-non-smep-platform.patch.
- Delete patches.suse/17-x86-kvm-pad-rsb-on-vm-transition.patch.
- Delete patches.suse/28-x86-svm-clobber-the-rsb-on-vm-exit.patch.
- Delete patches.xen/xen3-kaiser-build-fix.patch.
- commit d188efc
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/64s: Wire up cpu_show_meltdown() (bsc#1068032).
- commit a0783ad
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/pseries: include linux/types.h in asm/hvcall.h
  (bsc#1068032, bsc#1075088).
- commit 5f430a9
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/pseries: rfi-flush: Call setup_rfi_flush() after LPM
  migration (bsc#1068032, bsc#1075088).
- Delete patches.fixes/0004-powerpc-rfi-flush-Make-setup_rfi_flush-not-__init.patch.
- Delete patches.fixes/0006-powerpc-pseries-rfi-flush-Call-setup_rfi_flush-after.patch.
- commit 72e5c9c
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/pseries: Query hypervisor for RFI flush settings (bsc#1068032,
    bsc#1075088).
  Refresh patches.suse/powerpc-rfi-flush.patch.
- commit 4502aa9
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/64s: Support disabling RFI flush with no_rfi_flush and nopti
  (bsc#1068032, bsc#1075088).
  Refresh patches.suse/powerpc-rfi-flush.patch.
- commit 493cee6
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/rfi-flush: Add DEBUG_RFI config option (bsc#1068032,
    bsc#1075088).
- powerpc/rfi-flush: Move the logic to avoid a redo into the
    sysfs code (bsc#1068032, bsc#1075088).
- powerpc/64s: Allow control of RFI flush via debugfs (bsc#1068032,
    bsc#1075088).
- Delete patches.suse/powerpc-rfi-flush.patch.
- Delete patches.suse/rfi-flush-Make-DEBUG_RFI-a-CONFIG-option.patch.
- Delete patches.fixes/0005-powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch.
- commit e286521
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/64s: Add support for RFI flush of L1-D cache
    (bsc#1068032, bsc#1075088).
- powerpc/rfi-flush: Move RFI flush fields out of the paca
    (unbreak kABI) (bsc#1068032, bsc#1075088).
- Refresh patches.suse/powerpc-rfi-flush.patch.
- Delete patches.kabi/0001-rfi-flush-Move-rfi_flush_fallback_area-to-end-of-pac.patch.
- Delete patches.kabi/0002-rfi-flush-Move-RFI-flush-fields-out-of-the-paca-unbr.patch.
- Delete patches.fixes/0003-powerpc-rfi-flush-Factor-out-init_fallback_flush.patch.
- commit f57789e
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/64s: Convert slb_miss_common to use RFI_TO_USER/KERNEL
  (bsc#1068032, bsc#1075088).
  Refresh patches.suse/powerpc-rfi-flush.patch.
- commit fecc933
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/64: Convert fast_exception_return to use
  RFI_TO_USER/KERNEL (bsc#1068032, bsc#1075088).
  Refresh patches.suse/powerpc-rfi-flush.patch.
- commit 236b8df
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/64s: Simple RFI macro conversions (bsc#1068032,
  bsc#1075088).
  Refresh patches.suse/powerpc-rfi-flush.patch.
- commit 75154e3
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/64: Add macros for annotating the destination of
  rfid/hrfid (bsc#1068032, bsc#1075088).
  Refresh patches.suse/powerpc-rfi-flush.patch.
- commit f947af6
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/pseries: Add H_GET_CPU_CHARACTERISTICS flags & wrapper
  (bsc#1068032, bsc#1075088).
- Refresh patches.fixes/0006-powerpc-pseries-rfi-flush-Call-setup_rfi_flush-after.patch.
- Refresh patches.suse/powerpc-rfi-flush.patch.
- Delete patches.fixes/0002-powerpc-pseries-rfi-flush-Drop-PVR-based-selection.patch.
- Delete patches.suse/powerpc-pseries-Introduce-H_GET_CPU_CHARACTERISTICS.patch.
- commit 6cc79e9
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/pseries: Kill all prefetch streams on context switch
  (bsc#1068032, bsc#1075088).
  Refresh patches.suse/powerpc-rfi-flush.patch.
- commit c4ce2d2
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/64s: Add EX_SIZE definition for paca exception save
  areas (bsc#1068032, bsc#1075088).
- Refresh patches.suse/powerpc-rfi-flush.patch.
- commit 12f17f6
* Mon Jan 29 2018 msuchanek@suse.de
- Refresh patches.suse/powerpc-asm-Allow-including-ppc_asm.h-in-asm-files.patch.
- commit 6ba6996
* Mon Jan 29 2018 msuchanek@suse.de
- powerpc/vdso64: Use double word compare on pointers
  (bsc#1070781).
- commit d5c5445
* Mon Jan 29 2018 jslaby@suse.cz
- Refresh
  patches.suse/0004-sk_run_filter-add-bpf_s_anc_seccomp_ld_w.patch.
- Delete
  patches.suse/0002-bpf-prevent-speculative-execution-in-eBPF-interprete.patch.
  The barrier does not make much sense, as there is no bounds checking
  around. In upstream, this is solved differently by b2157399cc9, but we
  do not need this, as we have neither tail_calls, nor array map.
- commit ae38d35
* Mon Jan 29 2018 jthumshirn@suse.de
- s390: add ppa to the idle loop (bnc#1077406, LTC#163910).
- commit 8f26117
* Sat Jan 27 2018 jkosina@suse.cz
- fork: clear thread stack upon allocation (bsc#1077560).
- commit d02dc29
* Sat Jan 27 2018 msuchanek@suse.de
- Delete patches.fixes/0001-powerpc-Mark-CONFIG_PPC_DEBUG_RFI-as-BROKEN.patch.
  Update config files.
- commit c972907
* Tue Jan 23 2018 oneukum@suse.com
- CDC-ACM: apply quirk for card reader (bsc#1060279).
- commit 66778c3
* Tue Jan 23 2018 oneukum@suse.com
- media: omap_vout: Fix a possible null pointer dereference in
  omap_vout_open() (bsc#1050431).
- commit 2ea07a5
* Tue Jan 23 2018 oneukum@suse.com
- blacklist.conf: removes an ioctl()
- commit 30e136f
* Tue Jan 23 2018 oneukum@suse.com
- blacklist.conf: IR remote controller
- commit 8f8e8ce
* Tue Jan 23 2018 oneukum@suse.com
- mISDN: fix a loop count (bsc#1077191).
- commit b8d04f2
* Tue Jan 23 2018 oneukum@suse.com
- blacklist.conf: fix for a compiler warning only
- commit 3df686f
* Tue Jan 23 2018 oneukum@suse.com
- blacklist.conf: patch only needed if we did runtime PM, which we do
  not in this old kernel for this driver
- commit bc22f46
* Mon Jan 22 2018 bp@suse.de
- x86/cpu/AMD: Make LFENCE a serializing instruction (bsc#1068032
  CVE-2017-5754).
- x86/cpu/AMD: Use LFENCE_RDTSC in preference to MFENCE_RDTSC
  (bsc#1068032 CVE-2017-5754).
- Delete
  patches.suse/30-x86-cpu-amd-make-the-lfence-instruction-serialized.patch.
- Delete
  patches.suse/31-x86-cpu-amd-remove-now-unused-definition-of-mfence_rdtsc-feature.patch.
- commit 5ca735e
* Mon Jan 22 2018 msuchanek@suse.de
- powerpc: Fix register clobbering when accumulating stolen time
  (bsc#1059174).
- commit 8aca1da
* Mon Jan 22 2018 jthumshirn@suse.de
- s390/cpuinfo: show facilities as reported by stfle (bnc#1076849,
  LTC#163741).
- commit 34852ac
* Mon Jan 22 2018 neilb@suse.com
- Delete patches.fixes/0005-NFSv4-fix-getacl-head-length-estimation.patch. (bsc#1063544)
  This patch depends on other patches that haven't been backported.
  It causes
  res->acl_data_offset = be32_to_cpup(bm_p) + 2;
  in decode_getacl() to access past the end of a buffer - bm_p can be at end.
  This confuses acl decoding.
- commit 61aea65
* Sat Jan 20 2018 jkosina@suse.cz
- Refresh
  patches.suse/kaiser-0022-set-do-not-set-nx-unconditionally.patch.
  Add proper NX hadnling for !NX-capable systems also to kaiser_add_user_map().
  (bsc#1076278).
- commit 3f19f72
* Thu Jan 18 2018 jroedel@suse.de
- KVM: Fix stack-out-of-bounds read in write_mmio (CVE-2017-17741
  bsc#1073311).
- commit 3962e79
* Thu Jan 18 2018 jkosina@suse.cz
- x86/kaiser: Populate shadow PGD with NX bit only if supported
  by platform (bsc#1076154 bsc#1076278).
- commit 4948460
* Wed Jan 17 2018 tiwai@suse.de
- crypto: algif_skcipher - Load TX SG list after waiting
  (CVE-2017-13215,bsc#1075908).
- commit e311a40
* Wed Jan 17 2018 tiwai@suse.de
- ALSA: pcm: Remove yet superfluous WARN_ON() (bsc#1045538).
- commit 56b4502
* Tue Jan 16 2018 tiwai@suse.de
- ALSA: seq: Make ioctls race-free (CVE-2018-1000004,bsc#1076017).
- commit d167029
* Tue Jan 16 2018 msuchanek@suse.de
- scsi: sr: wait for the medium to become ready (bsc#1048585).
- commit b1e0d40
* Tue Jan 16 2018 msuchanek@suse.de
- cdrom: wait for tray to close (bsc#1048585).
- commit 3effb5c
* Tue Jan 16 2018 msuchanek@suse.de
- cdrom: factor out common open_for_* code (bsc#1048585).
- commit cca18b2
* Tue Jan 16 2018 msuchanek@suse.de
- delay: add poll_event_interruptible (bsc#1048585).
- commit f28dbc2
* Tue Jan 16 2018 duwe@suse.de
- rfi-flush: Move RFI flush fields out of the paca (unbreak kABI)
  (bsc#1075088).
- rfi-flush: Move rfi_flush_fallback_area to end of paca
  (bsc#1075088).
- commit 476f519
* Tue Jan 16 2018 jkosina@suse.cz
- Refresh
  patches.suse/34-x86-spectre_v2-fix-ordering-in-IBRS-initialization.patch.
  Fix return value from ib[rs|pb]_enabled().
- commit 557d1f2
* Tue Jan 16 2018 jkosina@suse.cz
- Refresh
  patches.suse/34-x86-spectre_v2-fix-ordering-in-IBRS-initialization.patch.
  Fix mishandling of cases with MSR not being present (writing to MSR even though
  _state == -1).
- commit 1feb135
* Mon Jan 15 2018 jkosina@suse.cz
- x86/spec_ctrl: handle late setting of X86_FEATURE_SPEC_CTRL
  properly (bsc#1075994 bsc#1075091).
- x86/spectre_v2: fix ordering in IBRS initialization (bsc#1075994
  bsc#1075091).
- x86/microcode: Rescan feature flags upon late loading
  (bsc#1075994 bsc#1075091).
- x86/CPU: Sync CPU feature flags late (bsc#1075994 bsc#1075091).
- x86/cpu: Factor out application of forced CPU caps (bsc#1075994
  bsc#1075091).
- commit 2dfb670
* Sun Jan 14 2018 bp@suse.de
- x86/microcode/intel: Extend BDW late-loading with a revision
  check (bsc#1054305).
- commit 30a171f
* Fri Jan 12 2018 duwe@suse.de
- powerpc/pseries/rfi-flush: Call setup_rfi_flush() after LPM
  migration (bsc#1075088).
- Update config files.
- powerpc/rfi-flush: Move the logic to avoid a redo into the
  sysfs code (bsc#1075088).
- powerpc/rfi-flush: Make setup_rfi_flush() not __init
  (bsc#1075088).
- powerpc/rfi-flush: Factor out init_fallback_flush()
  (bsc#1075088).
- powerpc/pseries/rfi-flush: Drop PVR-based selection
  (bsc#1075088).
- powerpc: Mark CONFIG_PPC_DEBUG_RFI as BROKEN (bsc#1075088).
- commit cf5b3c8
* Thu Jan 11 2018 lduncan@suse.com
- KEYS: trusted: fix writing past end of buffer in trusted_read()
  (bsc#1074880).
- commit 6623679
* Thu Jan 11 2018 tiwai@suse.de
- ALSA: pcm: Allow aborting mutex lock at OSS read/write loops
  (bsc#1045538).
- ALSA: pcm: Abort properly at pending signal in OSS read/write
  loops (bsc#1045538).
- ALSA: aloop: Fix racy hw constraints adjustment (bsc#1045538).
- ALSA: aloop: Fix inconsistent format due to incomplete rule
  (bsc#1045538).
- ALSA: aloop: Release cable upon open error path (bsc#1045538).
- ALSA: pcm: Add missing error checks in OSS emulation plugin
  builder (bsc#1045538).
- ALSA: pcm: Remove incorrect snd_BUG_ON() usages (bsc#1045538).
- commit 05cf5e0
* Wed Jan 10 2018 ohering@suse.de
- storvsc: do not assume SG list is continuous when doing bounce
  buffers (bsc#1075410).
- commit b164164
* Tue Jan  9 2018 msuchanek@suse.de
- Enable DEBUG_RFI
- commit aa877b8
* Tue Jan  9 2018 msuchanek@suse.de
- Update patches.suse/powerpc-rfi-flush.patch (bsc#1068032,
  bsc#1075088).
- commit 3f651a9
* Tue Jan  9 2018 msuchanek@suse.de
- rfi-flush: Make DEBUG_RFI a CONFIG option (bsc#1068032,
  bsc#1075088).
- commit b5f5f2d
* Tue Jan  9 2018 msuchanek@suse.de
- powerpc/pseries: Introduce H_GET_CPU_CHARACTERISTICS
  (bsc#1068032, bsc#1075088).
- commit 25db258
* Tue Jan  9 2018 msuchanek@suse.de
- powerpc/asm: Allow including ppc_asm.h in asm files
  (bsc#1068032, bsc#1075088).
- commit 839e8ac
* Tue Jan  9 2018 jkosina@suse.cz
- Refresh patches.arch/s390-sles11sp4-99-03-nobp.patch: fix spruios nobp; update to newer
  version from IBM.
- commit f3c1b74
* Mon Jan  8 2018 jkosina@suse.cz
- Refresh patches.arch/s390-sles11sp4-99-02-gmb.patch: fix the
  static inline vs generic define conflict.
- commit 8ac2078
* Mon Jan  8 2018 msuchanek@suse.de
- powerpc/perf: Dereference BHRB entries safely (bsc#1064861,
  FATE#317619, git-fixes).
- commit e675d12
* Mon Jan  8 2018 zpetrova@novell.com
- Ext3: use unlikely to improve the efficiency of the kernel
  (bnc#1069508).
- Ext2: use unlikely to improve the efficiency of the kernel
  (bnc#1069508).
- Ext3: add necessary check in case IO error happens
  (bnc#1069508).
- Ext2: free memory allocated and forget buffer head when io
  error happens (bnc#1069508).
- commit 380f071
* Fri Jan  5 2018 jkosina@suse.cz
- PTI: unbreak EFI (bsc#1074709).
- commit 78831e4
* Mon Dec 25 2017 bp@suse.de
- x86/kaiser: Move feature detection up (bsc#1068032).
  [jkosina: 12-SP3 -> 11-SP4 backport]
- commit 1b24463
* Sun Dec 24 2017 bp@suse.de
- Refresh patches.suse/17-x86-kvm-pad-rsb-on-vm-transition.patch.
- commit af22a24
* Sat Dec 23 2017 bp@suse.de
- Disable ptrace part
- commit a5aee6e
* Fri Dec 22 2017 neilb@suse.com
- NFS: add nostatflush mount option (bsc#1065726).
- commit dfbdeb6
* Fri Dec 22 2017 bp@suse.de
- Check cmdline_find_option() retval
  Refresh
  patches.suse/kaiser-nokaiser-0009-kaiser-add_pti_cmdline_option_and_documentation.patch.
- commit 2e5486b
* Fri Dec 22 2017 bp@suse.de
- Refresh
  patches.suse/22-x86-cpu-amd-add-speculative-control-support-for-amd.patch.
- Refresh
  patches.suse/27-kvm-x86-add-speculative-control-cpuid-support-for-guests.patch.
- Refresh patches.xen/xen3-patch-2.6.36.
- commit 102a8a5
* Fri Dec 22 2017 jkosina@suse.cz
- Delete patches.suse/powerpc-rfi-flush.patch: boot failures, deleted until
  it's debugged.
- commit b091f8f
* Fri Dec 22 2017 msuchanek@suse.de
- Update patches.suse/powerpc-rfi-flush.patch (bsc#1068032).
- commit 02d77cb
* Thu Dec 21 2017 bp@suse.de
- temporary fix (bsc#1068032).
- commit a6493a7
* Thu Dec 21 2017 bp@suse.de
- x86/feature: Enable the x86 feature to control Speculation
  (bsc#1068032).
- x86/enter: Add macros to set/clear IBRS and set IBPB
  (bsc#1068032).
- x86/entry: Use IBRS on entry to kernel space (bsc#1068032).
- x86/MSR: Move native_*msr(.. u64) to msr.h (bsc#1068032).
- x86/spec: Add IBRS control functions (bsc#1068032).
- x86/idle: Toggle IBRS when going idle (bsc#1068032).
- x86/idle: Disable IBRS when offlining a CPU and re-enable on
  wakeup (bsc#1068032).
- x86/spec_ctrl: Add an Indirect Branch Predictor barrier
  (bsc#1068032).
- x86/mm: Set IBPB upon context switch (bsc#1068032).
- ptrace: Add a new thread access check (bsc#1068032).
- x86/mm: Only set IBPB when the new thread cannot ptrace current
  thread (bsc#1068032).
- x86/entry: Add a function to overwrite the RSB (bsc#1068032).
- x86/entry: Stuff RSB for entry to kernel for non-SMEP platform
  (bsc#1068032).
- x86/kvm: Add MSR_IA32_SPEC_CTRL and MSR_IA32_PRED_CMD to kvm
  (bsc#1068032).
- x86/kvm: Flush IBP when switching VMs (bsc#1068032).
- x86/kvm: Toggle IBRS on VM entry and exit (bsc#1068032).
- x86/kvm: Pad RSB on VM transition (bsc#1068032).
- x86/spec_ctrl: Check whether IBRS is enabled before using it
  (bsc#1068032).
- x86/spec_ctrl: Check whether IBPB is enabled before using it
  (bsc#1068032).
- x86/CPU: Check speculation control CPUID bit (bsc#1068032).
- x86/spec: Add "nospec" chicken bit (bsc#1068032).
- x86/CPU/AMD: Add speculative control support for AMD
  (bsc#1068032).
- x86/spec: Check CPUID direclty post microcode reload to support
  IBPB  feature (bsc#1068032).
- KVM: SVM: Do not intercept new speculative control MSRs
  (bsc#1068032).
- x86/svm: Set IBRS value on VM entry and exit (bsc#1068032).
- x86/svm: Set IBPB when running a different VCPU (bsc#1068032).
- KVM: x86: Add speculative control CPUID support for guests
  (bsc#1068032).
- x86/svm: Clobber the RSB on VM exit (bsc#1068032).
- x86/svm: Add code to clear registers on VM exit (bsc#1068032).
- x86/CPU/AMD: Make the LFENCE instruction serialized
  (bsc#1068032).
- x86/CPU/AMD: Remove now unused definition of MFENCE_RDTSC
  feature (bsc#1068032).
- Refresh patches.xen/xen3-patch-2.6.36.
- Refresh patches.xen/xen3-patch-2.6.39.
- commit d357937
* Thu Dec 21 2017 jkosina@suse.cz
- Update patches.suse/powerpc-rfi-flush.patch: boot fix from Torsten Duwe. Re-enable.
- commit 2a275fb
* Thu Dec 21 2017 jkosina@suse.cz
- Refresh patches.arch/s390-sles11sp4-99-03-nobp.patch: replace by new version from IBM
- commit 86fedd9
* Thu Dec 21 2017 jkosina@suse.cz
- patches.suse/powerpc-rfi-flush.patch: disable due to boot failure
- commit 1435fb5
* Thu Dec 21 2017 jkosina@suse.cz
- powerpc: Secure memory rfi flush (bsc#1068032).
- commit e015e47
* Thu Dec 21 2017 tiwai@suse.de
- crypto: hmac - require that the underlying hash algorithm is
  unkeyed (CVE-2017-17806,bsc#1073874).
- commit 7a0cafe
* Thu Dec 21 2017 tiwai@suse.de
- crypto: salsa20 - fix blkcipher_walk API usage
  (CVE-2017-17805,bsc#1073792).
- commit abf3b0c
* Thu Dec 21 2017 jkosina@suse.cz
- Refresh patches.arch/s390-sles11sp4-99-03-nobp.patch: fix build failure
- commit c4e47ef
* Thu Dec 21 2017 jkosina@suse.cz
- s390: add ppa to system call and program check path
  (bsc#1068032).
- s390/spinlock: add gmb memory barrier (bsc#1068032).
- s390: introduce CPU alternatives (bsc#1068032).
- commit 8043a9b
* Wed Dec 20 2017 jkosina@suse.cz
- Delete patches.arch/s390-sles11sp4-99-01-cpu-alternatives.patch.
- Delete patches.arch/s390-sles11sp4-99-02-gmb.patch.
- Delete patches.arch/s390-sles11sp4-99-03-nobp.patch.
  Drop them for now, IBM is going to provide updated version of all
  three shortly.
- commit 1791df1
* Wed Dec 20 2017 jkosina@suse.cz
- Update references.
  Update patches.suse/powerpc-add-gmb.patch (bsc#1068032
  CVE-2017-5753).
- commit 43a8b54
* Wed Dec 20 2017 jkosina@suse.cz
- Update references.
- Update
  patches.suse/0001-locking-barriers-introduce-new-memory-barrier-gmb.patch
  (bsc#1068032 CVE-2017-5753).
- Update
  patches.suse/0002-bpf-prevent-speculative-execution-in-eBPF-interprete.patch
  (bsc#1068032 CVE-2017-5753).
- Update
  patches.suse/0003-uvcvideo-prevent-speculative-execution.patch
  (bsc#1068032 CVE-2017-5753).
- Update
  patches.suse/0004-carl9170-prevent-speculative-execution.patch
  (bsc#1068032 CVE-2017-5753).
- Update patches.suse/0005-p54-prevent-speculative-execution.patch
  (bsc#1068032 CVE-2017-5753).
- Update patches.suse/0006-fs-prevent-speculative-execution.patch
  (bsc#1068032 CVE-2017-5753).
- Update patches.suse/0007-udf-prevent-speculative-execution.patch
  (bsc#1068032 CVE-2017-5753).
- commit a7acb21
* Wed Dec 20 2017 jkosina@suse.cz
- Update references.
- Update patches.kabi/kaiser-preserve-kabi.patch (bsc#1068032
  CVE-2017-5754).
- Update patches.suse/0001-x86-64-Give-vvars-their-own-page.patch
  (bsc#1068032 CVE-2017-5754).
- Update patches.suse/0001-x86-64-Map-the-HPET-NX.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/0001-x86-boot-Carve-out-early-cmdline-parsing-function.patch
  (bsc#1068032 CVE-2017-5754).
- Update patches.suse/kaiser-0002-x86-mm-Add-INVPCID-helpers.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-0003-x86-mm-Fix-INVPCID-asm-constraint.patch
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Add a 'noinvpcid' boot option to turn off (bsc#1068032
  CVE-2017-5754).
- x86/mm: If INVPCID is available, use it to flush global
  (bsc#1068032 CVE-2017-5754).
- mm/mmu_context, sched/core: Fix mmu_context.h (bsc#1068032
  CVE-2017-5754).
- sched/core: Add switch_mm_irqs_off() and use it in the
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-0008-x86-mm-Build-arch-x86-mm-tlb.c-even-on-SMP.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-0009-x86-mm-sched-core-Uninline-switch_mm.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-0010-x86-mm-sched-core-Turn-off-IRQs-in-switch_mm.patch
  (bsc#1068032 CVE-2017-5754).
- sched/core: Idle_task_exit() shouldn't use (bsc#1068032
  CVE-2017-5754).
- x86/mm: Remove the UP asm/tlbflush.h code, always use
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-0013-x86-mm-Disable-PCID-on-32-bit-kernels.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-0014-x86-mm-Add-the-nopcid-boot-option-to-turn-off-PCID.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-0015-x86-mm-Enable-CR4.PCIDE-on-supported-systems.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-0016-x86-mm-64-Fix-reboot-interaction-with-CR4.PCIDE.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-0017-x86-mm-fix-bad-backport-to-disable-PCID-on-Xen.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-0018-KAISER-Kernel-Address-Isolation.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-0019-x86-mm-kaiser-re-enable-vsyscalls.patch
  (bsc#1068032 CVE-2017-5754).
- Update patches.suse/kaiser-0020-fix-ldt-freeing.patch
  (bsc#1068032 CVE-2017-5754).
- Update patches.suse/kaiser-0021-disable-vmstat.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-nokaiser-0005-kaiser-add-nokaiser-boot-option-using-ALTERNATIVE.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-nokaiser-0006-kaiser-use-ALTERNATIVE-instead-of-x86_cr3_pcid_noflu.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-nokaiser-0007-rename-and-simplify-feature-setting.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-nokaiser-0008-x86-boot-add-early-cmdline-parsing-for-options-with-arguments.patch
  (bsc#1068032 CVE-2017-5754).
- Update
  patches.suse/kaiser-nokaiser-0009-kaiser-add_pti_cmdline_option_and_documentation.patch
  (bsc#1068032 CVE-2017-5754).
- commit 01e8538
* Wed Dec 20 2017 acho@suse.com
- Bluetooth: cmtp: cmtp_add_connection() should verify that it's
  dealing with l2cap socket (bsc#1071470 CVE-2017-15868).
- Bluetooth: bnep: bnep_add_connection() should verify that it's
  dealing with l2cap socket (bsc#1071470 CVE-2017-15868).
- Bluetooth: Access BNEP session addresses through L2CAP channel
  (bsc#1071470 CVE-2017-15868).
- Bluetooth: hidp: verify l2cap sockets (bsc#1071470
  CVE-2017-15868).
- commit 7bf2a80
* Wed Dec 20 2017 neilb@suse.com
- autofs: fix careless error in recent commit (bsc#1065180).
- commit 88b1a95
* Tue Dec 19 2017 jkosina@suse.cz
- Refresh
  patches.suse/kaiser-0018-KAISER-Kernel-Address-Isolation.patch.
  Fix build when graph tracer is enabled (make sure that irqentry
  sections are visible to kaiser).
  Refresh
  patches.suse/kaiser-nokaiser-0005-kaiser-add-nokaiser-boot-option-using-ALTERNATIVE.patch
- commit 2f9dee0
* Tue Dec 19 2017 jkosina@suse.cz
- Refresh
  patches.suse/kaiser-nokaiser-0009-kaiser-add_pti_cmdline_option_and_documentation.patch.
  Really rename "kasier" cmdline parameters to "pti"
- commit 049c149
* Tue Dec 19 2017 jkosina@suse.cz
- patches.arch/s390-sles11sp4-99-03-nobp.patch: disable for now, waiting
  for updated patch from IBM
- commit c02923e
* Tue Dec 19 2017 jkosina@suse.cz
- Update patch metadata to be up-to-date with standards of our checker.
- Refresh
  patches.suse/0001-x86-64-Give-vvars-their-own-page.patch.
- Refresh patches.suse/0001-x86-64-Map-the-HPET-NX.patch.
- Refresh
  patches.suse/kaiser-0002-x86-mm-Add-INVPCID-helpers.patch.
- Refresh
  patches.suse/kaiser-0003-x86-mm-Fix-INVPCID-asm-constraint.patch.
- Refresh
  patches.suse/kaiser-0004-x86-mm-Add-a-noinvpcid-boot-option-to-turn-off-INVPC.patch.
- Refresh
  patches.suse/kaiser-0005-x86-mm-If-INVPCID-is-available-use-it-to-flush-globa.patch.
- Refresh
  patches.suse/kaiser-0006-mm-mmu_context-sched-core-Fix-mmu_context.h-assumpti.patch.
- Refresh
  patches.suse/kaiser-0007-sched-core-Add-switch_mm_irqs_off-and-use-it-in-the-.patch.
- Refresh
  patches.suse/kaiser-0008-x86-mm-Build-arch-x86-mm-tlb.c-even-on-SMP.patch.
- Refresh
  patches.suse/kaiser-0009-x86-mm-sched-core-Uninline-switch_mm.patch.
- Refresh
  patches.suse/kaiser-0010-x86-mm-sched-core-Turn-off-IRQs-in-switch_mm.patch.
- Refresh
  patches.suse/kaiser-0011-sched-core-Idle_task_exit-shouldn-t-use-switch_mm_ir.patch.
- Refresh
  patches.suse/kaiser-0012-x86-mm-Remove-the-UP-asm-tlbflush.h-code-always-use-.patch.
- Refresh
  patches.suse/kaiser-0013-x86-mm-Disable-PCID-on-32-bit-kernels.patch.
- Refresh
  patches.suse/kaiser-0014-x86-mm-Add-the-nopcid-boot-option-to-turn-off-PCID.patch.
- Refresh
  patches.suse/kaiser-0015-x86-mm-Enable-CR4.PCIDE-on-supported-systems.patch.
- Refresh
  patches.suse/kaiser-0016-x86-mm-64-Fix-reboot-interaction-with-CR4.PCIDE.patch.
- Refresh
  patches.suse/kaiser-0017-x86-mm-fix-bad-backport-to-disable-PCID-on-Xen.patch.
- Refresh
  patches.suse/kaiser-0018-KAISER-Kernel-Address-Isolation.patch.
- Refresh
  patches.suse/kaiser-0019-x86-mm-kaiser-re-enable-vsyscalls.patch.
- Refresh patches.suse/kaiser-0020-fix-ldt-freeing.patch.
- Refresh patches.suse/kaiser-0021-disable-vmstat.patch.
- Refresh
  patches.suse/kaiser-nokaiser-0005-kaiser-add-nokaiser-boot-option-using-ALTERNATIVE.patch.
- Refresh
  patches.suse/kaiser-nokaiser-0006-kaiser-use-ALTERNATIVE-instead-of-x86_cr3_pcid_noflu.patch.
- Refresh patches.xen/xen-x86-pmd-handling.
- Refresh
  patches.xen/xen3-0001-x86-64-Give-vvars-their-own-page.patch.
- Refresh patches.xen/xen3-0001-x86-64-Map-the-HPET-NX.patch.
- Refresh
  patches.xen/xen3-kaiser-0009-x86-mm-sched-core-Uninline-switch_mm.patch.
- Refresh
  patches.xen/xen3-kaiser-0010-x86-mm-sched-core-Turn-off-IRQs-in-switch_mm.patch.
- Refresh
  patches.xen/xen3-kaiser-0012-x86-mm-Remove-the-UP-asm-tlbflush.h-code-always-use-.patch.
- Refresh
  patches.xen/xen3-kaiser-0015-x86-mm-Enable-CR4.PCIDE-on-supported-systems.patch.
- Refresh
  patches.xen/xen3-kaiser-0018-KAISER-Kernel-Address-Isolation.patch.
- Refresh
  patches.xen/xen3-kaiser-0019-x86-mm-kaiser-re-enable-vsyscalls.patch.
- Refresh
  patches.xen/xen3-kaiser-nokaiser-0005-kaiser-add-nokaiser-boot-option-using-ALTERNATIVE.patch.
- Refresh
  patches.xen/xen3-kaiser-nokaiser-0006-kaiser-use-ALTERNATIVE-instead-of-x86_cr3_pcid_noflu.patch.
- Refresh patches.xen/xen3-patch-2.6.25.
- Refresh blacklist.conf
- commit af8eaa8
* Tue Dec 19 2017 jkosina@suse.cz
- xen/kaiser: work around kABI.
- commit 619a1cb
* Tue Dec 19 2017 jkosina@suse.cz
- Refresh patches.kabi/kaiser-preserve-kabi.patch: remove pointless kABI guard
- commit ec2d573
* Tue Dec 19 2017 jkosina@suse.cz
- Refresh
  patches.suse/kaiser-nokaiser-0005-kaiser-add-nokaiser-boot-option-using-ALTERNATIVE.patch.
- Refresh
  patches.suse/kaiser-nokaiser-0006-kaiser-use-ALTERNATIVE-instead-of-x86_cr3_pcid_noflu.patch.
- Delete
  patches.suse/0001-x86-Make-alternative-instruction-pointers-relative.patch.
- Delete
  patches.suse/0002-asm-alternatives-remove-incorrect-alignment-notes.patch.
- Delete
  patches.suse/kaiser-nokaiser-0001-x86-alternatives-Cleanup-DPRINTK-macro.patch.
- Delete
  patches.suse/kaiser-nokaiser-0002-x86-alternatives-Add-instruction-padding.patch.
- Delete
  patches.suse/kaiser-nokaiser-0003-x86-alternatives-Make-JMPs-more-robust.patch.
- Delete
  patches.suse/kaiser-nokaiser-0004-x86-alternatives-Use-optimized-NOPs-for-padding.patch.
- Delete
  patches.suse/kaiser-nokaiser-0010-propagate-into-cpuinfo.patch.
- Delete
  patches.xen/xen3-kaiser-nokaiser-0002-x86-alternatives-Add-instruction-padding.patch.
  Drop the alternatives automatic insn sizing backport, as it is a kABI breaker
  for modules that apply alternatives; explicitly hand-code it in KAISER (from Boris).
- commit b050b1e
* Mon Dec 18 2017 jkosina@suse.cz
- Monster commit to enable KAISER/PTI.
  This is all squashed together in order to achieve bisectability,
  as KAISER inherently breaks both kABI and Xen; here we bring it
  all together, separated to individual patch files, but as one
  pre-KAISER and after-KAISER commit (which can then be further
  bisected on patch level (without Xen) if need be).
  Xen port courtesy of Jan Beulich.
- kaiser: work around kABI.
- x86-64: Give vvars their own page.
- x86-64: Map the HPET NX.
- x86: Make alternative instruction pointers relative.
- x86, boot: Carve out early cmdline parsing function.
- asm alternatives: remove incorrect alignment notes.
- x86/mm: Add INVPCID helpers.
- x86/mm: Fix INVPCID asm constraint.
- x86/mm: Add a 'noinvpcid' boot option to turn off INVPCID.
- x86/mm: If INVPCID is available, use it to flush global
  mappings.
- mm/mmu_context, sched/core: Fix mmu_context.h assumption.
- sched/core: Add switch_mm_irqs_off() and use it in the
  scheduler.
- x86/mm: Build arch/x86/mm/tlb.c even on !SMP.
- x86/mm, sched/core: Uninline switch_mm().
- x86/mm, sched/core: Turn off IRQs in switch_mm().
- sched/core: Idle_task_exit() shouldn't use switch_mm_irqs_off().
- x86/mm: Remove the UP asm/tlbflush.h code, always use the
  (formerly) SMP code.
- x86/mm: Disable PCID on 32-bit kernels.
- x86/mm: Add the 'nopcid' boot option to turn off PCID.
- x86/mm: Enable CR4.PCIDE on supported systems.
- x86/mm/64: Fix reboot interaction with CR4.PCIDE.
- x86/mm: fix bad backport to disable PCID on Xen.
- KAISER: Kernel Address Isolation.
- x86/mm/kaiser: re-enable vsyscalls.
- KAISER: fix ldt freeing.
- x86/kaiser: disable vmstat accounting.
- x86/alternatives: Cleanup DPRINTK macro.
- x86/alternatives: Add instruction padding.
- x86/alternatives: Make JMPs more robust.
- x86/alternatives: Use optimized NOPs for padding.
- kaiser: add "nokaiser" boot option, using ALTERNATIVE.
- kaiser: use ALTERNATIVE instead of x86_cr3_pcid_noflush.
- x86/kaiser: Rename and simplify X86_FEATURE_KAISER handling.
- x86/boot: Add early cmdline parsing for options with arguments.
- x86/kaiser: Check boottime cmdline params.
- x86/kaiser: propagate info to /proc/cpuinfo.
- xen/x86-64: Give vvars their own page.
- xen/x86-64: Map the HPET NX.
- xen: x86/mm, sched/core: Uninline switch_mm().
- xen: x86/mm, sched/core: Turn off IRQs in switch_mm().
- xen/x86/mm: Remove the UP asm/tlbflush.h code, always use the
  (formerly) SMP code.
- xen/x86/mm: Enable CR4.PCIDE on supported systems.
- xen/KAISER: Kernel Address Isolation.
- xen/x86/mm/kaiser: re-enable vsyscalls.
- xen/x86/alternatives: Add instruction padding.
- xen/kaiser: add "nokaiser" boot option, using ALTERNATIVE.
- xen/kaiser: use ALTERNATIVE instead of x86_cr3_pcid_noflush.
- xen/x86/kaiser: Rename and simplify X86_FEATURE_KAISER handling.
- Refresh patches.xen/xen-x86-pmd-handling.
- Refresh patches.xen/xen-x86_64-pgd-alloc-order.
- Refresh patches.xen/xen3-patch-2.6.25.
- Refresh patches.xen/xen3-patch-2.6.29.
- Refresh patches.xen/xen3-patch-2.6.30.
- Refresh patches.xen/xen3-patch-2.6.31.
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 0d8808d
* Mon Dec 18 2017 tiwai@suse.de
- ALSA: timer: Fix race at concurrent reads
  (CVE-2017-13167,bsc#1072876).
- ALSA: timer: Code cleanup (CVE-2017-13167,bsc#1072876).
- commit e0b82f1
* Mon Dec 18 2017 jthumshirn@suse.de
- qeth: check not more than 16 SBALEs on the completion queue
  (bnc#1072457, LTC#148203).
- s390: fix transactional execution control register handling
  (bnc#1072457, LTC#162116).
- commit 4c81d87
* Sat Dec 16 2017 jkosina@suse.cz
- s390/spinlock: add ppa to system call path.
- commit 3e72345
* Sat Dec 16 2017 jkosina@suse.cz
- s390/spinlock: add gmb memory barrier.
- commit 4105b8e
* Sat Dec 16 2017 jkosina@suse.cz
- s390: introduce CPU alternatives.
- commit 87f31db
* Sat Dec 16 2017 jkosina@suse.cz
- powerpc/barrier: add gmb.
- commit f653a47
* Fri Dec 15 2017 jdelvare@suse.de
- blacklist.conf: Add 2 false-positive dmi commits
- commit ca4c261
* Fri Dec 15 2017 jslaby@suse.cz
- udf: prevent speculative execution (bnc#1068032).
- fs: prevent speculative execution (bnc#1068032).
  [jkosina@suse.cz: hack around kABI; this should be done in separate
  patch in patches.kabi eventually]
- p54: prevent speculative execution (bnc#1068032).
- carl9170: prevent speculative execution (bnc#1068032).
- uvcvideo: prevent speculative execution (bnc#1068032).
- bpf: prevent speculative execution in eBPF interpreter (bnc#1068032).
  Refresh patches.suse/0004-sk_run_filter-add-bpf_s_anc_seccomp_ld_w.patch
- locking/barriers: introduce new memory barrier gmb() (bnc#1068032).
- commit 5eeed6c
* Thu Dec 14 2017 oneukum@suse.com
- media: dvb-usb-v2: lmedm04: Improve logic checking of warm start
  (bsc#1066569 CVE-2017-16538).
- commit caafe0d
* Thu Dec 14 2017 oneukum@suse.com
- USB: core: prevent malicious bNumInterfaces overflow
  (bsc#1072561 CVE-2017-17558).
- commit 46062f4
* Wed Dec 13 2017 oneukum@suse.com
- usb: host: fix incorrect updating of offset (bsc#1047487).
- commit 9ea0f20
* Wed Dec 13 2017 oneukum@suse.com
- [media] cx231xx-cards: fix NULL-deref at probe (bsc#1050431).
- commit 3f08983
* Tue Dec 12 2017 mkubecek@suse.cz
- netfilter: xt_osf: Add missing permission checks (CVE-2017-17450
  bsc#1071695).
- commit 775bd73
* Tue Dec 12 2017 mkubecek@suse.cz
- dccp: CVE-2017-8824: use-after-free in DCCP code (CVE-2017-8824
  bsc#1070771).
- commit 085e5bb
* Tue Dec 12 2017 mkubecek@suse.cz
- ipsec: Fix aborted xfrm policy dump crash (CVE-2017-16939
  bsc#1069702).
- commit c5a3566
* Tue Dec 12 2017 mkubecek@suse.cz
- kabi: silence spurious kabi error in net/sctp/socket.c
  (bsc#1068671).
- sctp: do not peel off an assoc from one netns to another one
  (CVE-2017-15115 bsc#1068671).
- commit 8655f0c
* Tue Dec 12 2017 bp@suse.de
- x86/microcode/AMD: Add support for fam17h microcode loading
  (bsc#1068032).
- commit c936866
* Tue Dec 12 2017 mkubecek@suse.cz
- tcp: initialize rcv_mss to TCP_MIN_MSS instead of 0
  (CVE-2017-14106 bsc#1056982).
- commit f4a395a
* Tue Dec 12 2017 mkubecek@suse.cz
- xfrm: policy: check policy direction value (CVE-2017-11600
  bsc#1050231).
- commit 19dcd7f
* Tue Dec 12 2017 bp@suse.de
- watchdog: hpwdt: add support for iLO5 (bsc#1024612).
- commit 64d55da
* Mon Dec 11 2017 oneukum@suse.com
- adm80211: return an error if adm8211_alloc_rings() fails
  (bsc#1048185).
- commit b29cc38
* Wed Dec  6 2017 oneukum@suse.com
- USB: uas: fix bug in handling of alternate settings
  (bsc#1071074).
- commit d5658cb
* Wed Dec  6 2017 tiwai@suse.de
- isa: Prevent NULL dereference in isa_bus driver callbacks
  (bsc#1045538).
- commit 5a60f5b
* Wed Dec  6 2017 tiwai@suse.de
- video: udlfb: Fix read EDID timeout (bsc#1045538).
- commit 6051958
* Wed Dec  6 2017 bp@suse.de
- watchdog/hpwdt: Check source of NMI (bsc#1024612).
- commit 1fb1f3e
* Wed Dec  6 2017 tonyj@suse.de
- Update commit/mainline info in patches.fixes/audit-fix-use-after-free-in-audit_remove_watch_rule.patch.
- commit 9ac5664
* Tue Dec  5 2017 oneukum@suse.com
- zd1211rw: fix NULL-deref at probe (bsc#1045479).
- commit b1ed4a6
* Tue Dec  5 2017 oneukum@suse.com
- blacklist.conf: udlfb is an obscure, unsupported driver- The fix does not
  touch security.
- commit b905284
* Tue Dec  5 2017 jack@suse.cz
- ecryptfs: fix dereference of NULL user_key_payload
  (bsc#1013018).
- commit 43fd93a
* Tue Dec  5 2017 jlee@suse.com
- KEYS: fix keyctl_set_reqkey_keyring() to not leak thread
  keyrings (bsc#1034862, CVE-2017-7472).
- commit 3d2f256
* Mon Dec  4 2017 hare@suse.de
- s390/disassembler: correct disassembly lines alignment
  (bnc#1066973, LTC#161577).
- commit 3576909
* Mon Dec  4 2017 hare@suse.de
- s390/disassembler: increase show_code buffer size (bnc#1066973,
  LTC#161577).
- commit 50658ab
* Mon Dec  4 2017 hare@suse.de
- scsi: zfcp: fix erp_action use-before-initialize in REC action
  trace (bnc#1066973, LTC#160081).
- commit 57e6a34
* Mon Dec  4 2017 mhocko@suse.com
- mm/madvise.c: fix madvise() infinite loop under special
  circumstances (bnc#1070964).
- commit cc338c1
* Sun Dec  3 2017 neilb@suse.com
- nfsd: don't share group_info among threads (bsc@1070623).
- commit 6e16060
* Sat Dec  2 2017 alnovak@suse.cz
- x86/acpi: Reduce code duplication in mp_override_legacy_irq()
  (bsc#1068984).
- x86/acpi: Handle SCI interrupts above legacy space gracefully
  (bsc#1068984).
- x86/acpi: Reduce code duplication in mp_override_legacy_irq()
  (bsc#1068984).
- x86/acpi: Handle SCI interrupts above legacy space gracefully
  (bsc#1068984).
- commit 66bb669
* Thu Nov 30 2017 oneukum@suse.com
- USB: fix buffer overflows with parsing CDC headers (bsc#1066693
  CVE-2017-16534).
- commit 3d52c0b
* Wed Nov 29 2017 jack@suse.cz
- eCryptfs: use after free in ecryptfs_release_messaging()
  (bsc#1013018).
- commit 7cc612d
* Wed Nov 29 2017 jack@suse.cz
- fs/9p: Compare qid.path in v9fs_test_inode (bsc#1013018).
- commit 0191f63
* Wed Nov 29 2017 jack@suse.cz
- blacklist.conf: blacklist 0fafdc9f888b
- commit 2c8298d
* Tue Nov 28 2017 sparschauer@suse.de
- scsi_scan: Exit loop if TUR to LUN0 fails with 0x05/0x25 (bsc#1063043).
  This is specific to FUJITSU ETERNUS_DX* targets. They can return
  "Illegal Request - Logical unit not supported" and processing should
  leave the timeout loop in this case.
- commit 2de4f3f
* Mon Nov 27 2017 msuchanek@suse.de
- Do not enforce patch directories yet.
- commit ef8b7e8
* Mon Nov 27 2017 jgross@suse.com
- x86/cpu: Fix bootup crashes by sanitizing the argument of the
  'clearcpuid=' command-line option (bsc#1065600).
- commit df5f120
* Fri Nov 24 2017 neilb@suse.com
- nfs: Fix ugly referral attributes (git-fixes).
- FS-Cache: fix dereference of NULL user_key_payload (git-fixes).
- commit efe9275
* Fri Nov 24 2017 neilb@suse.com
- dm bufio: fix integer overflow when limiting maximum cache size
  (git-fixes).
- commit b5a9b64
* Wed Nov 22 2017 oneukum@suse.com
- net: cdc_ether: fix divide by 0 on bad descriptors (bsc#1067085
  CVE-2017-16649).
- commit 3bc0f36
* Mon Nov 20 2017 msuchanek@suse.de
- powerpc/pseries/vio: Dispose of virq mapping on vdevice
  unregister (bsc#1067888, git-fixes f2ab6219969f).
- commit 6e0c286
* Mon Nov 20 2017 vliaskovitis@suse.com
- usb-serial:  check for NULL private data in
  pl2303_suse_disconnect (bsc#1064803).
- commit be552f8
* Mon Nov 20 2017 neilb@suse.com
- autofs: don't fail mount for transient error (bsc#1065180).
- commit 439a946
* Mon Nov 13 2017 mcgrof@suse.com
- blacklist.conf: blacklist 6bf37e5aa90f1
  Commit 2bdd713b92a9 ("mac80211: use constant time comparison with keys")
  requires crypto_memneq() added as of v3.13-rc2 via commit 6bf37e5aa90f1
  ("crypto: crypto_memneq - add equality testing of memory regions w/o
  timing leaks"). This is documented on bsc#1066471.
  Its seriously not worth backporting crypto_memneq() given that the effect
  of the time considerations for vector attacks possible are extremely
  hard to take advantage given the large amount of userspace variants in
  mid layer which also randomize the timing to make this soft of attack
  valuable.
  Also there should be much more valuable uses of crypto_memneq() in the
  kernel other than this, and if that is ever backported we can easily then
  modify net/mac80211/key.c to take advantage once that is done.
- commit da76b2c
* Mon Nov 13 2017 tiwai@suse.de
- ALSA: core: Fix unexpected error at replacing user TLV
  (bsc#1045538).
- commit 0c275f0
* Mon Nov 13 2017 hare@suse.de
- fnic: Use the local variable instead of I/O flag to acquire
  io_req_lock in fnic_queuecommand() to avoid deadloack
  (bsc#1067816).
- lpfc: check for valid scsi cmnd in lpfc_scsi_cmd_iocb_cmpl()
  (bsc#1051133).
- commit 6c8b5a1
* Fri Nov 10 2017 pmladek@suse.com
- blacklist.conf: Blacklisted commit 2b1be689f3aadcfe0 ("printk/console:
  Always disable boot consoles that use init memory before it is freed")
- commit 016bb7e
* Thu Nov  9 2017 tiwai@suse.de
- blacklist.conf: Add PCI ASPM fix to blacklist (bsc#1045538)
- commit 317aa12
* Thu Nov  9 2017 tiwai@suse.de
- ALSA: timer: Add missing mutex lock for compat ioctls
  (bsc#1045538).
- ALSA: hda/ca0132 - Fix memory leak at error path (bsc#1045538).
- commit 31d2930
* Thu Nov  9 2017 pmladek@suse.com
- asm/sections: add helpers to check for section data
  (bnc#1107735).
- commit 34ff1ef
* Thu Nov  9 2017 neilb@suse.com
- NFS: allow flush-on-stat to be disabled (bsc#1065726).
- commit 1d20ca0
* Wed Nov  8 2017 oneukum@suse.com
- Input: gtco - fix potential out-of-bound access (bsc#1067085
  CVE-2017-16649).
- commit 77c13aa
* Tue Nov  7 2017 oneukum@suse.com
- USB: core: fix out-of-bounds access bug in
  usb_get_bos_descriptor() (bsc#1066700 CVE-2017-16535).
- commit 3da6f4b
* Tue Nov  7 2017 oneukum@suse.com
- usb: misc: legousbtower: Fix NULL pointer deference (bsc#1066705
  CVE-2017-15102).
- commit b624cec
* Tue Nov  7 2017 oneukum@suse.com
- USB: fix out-of-bounds in usb_set_configuration (bsc#1066671
  CVE-2017-16531).
- commit 7ba3d5e
* Mon Nov  6 2017 tiwai@suse.de
- ALSA: usb-audio: Check out-of-bounds access by corrupted buffer
  descriptor (CVE-2017-16529 bsc#1066650).
- commit 98d47cd
* Mon Nov  6 2017 oneukum@suse.com
- USB: serial: console: fix use-after-free after failed setup
  (bsc#1066618 CVE-2017-16525).
- commit 6d7b17e
* Mon Nov  6 2017 tiwai@suse.de
- media: imon: Fix null-ptr-deref in imon_probe (CVE-2017-16537
  bsc#1066573).
- [media] cx231xx-cards: fix NULL-deref on missing association
  descriptor (CVE-2017-16536 bsc#1066606).
- commit c392e8b
* Mon Nov  6 2017 tiwai@suse.de
- ALSA: usb-audio: Kill stray URB at exiting (CVE-2017-16527
  bsc#1066625).
- commit 927832d
* Fri Nov  3 2017 mcgrof@suse.com
- mac80211: don't compare TKIP TX MIC key in reinstall prevention
  (bsc#1066472).
- commit f20e6f0
* Thu Nov  2 2017 tonyj@suse.de
- blacklist.conf: Update with non-critical perf tools (userspace) fixes
- commit 96ba585
* Thu Nov  2 2017 tonyj@suse.de
- Refresh
  patches.suse/intel-perf-event-0106-perf-x86-add-generic-intel-uncore-pmu-support.patch.
- Refresh
  patches.suse/intel-perf-event-0129-perf-x86-fix-user-kernel-tagging-of-samples-properly.patch.
- commit 1823839
* Tue Oct 24 2017 msuchanek@suse.de
- Blacklist a9f8553e935f powerpc/kprobes: Pause function_graph tracing during jprobes handling
  It depends on features we don't have.
- commit fa2f43b
* Tue Oct 24 2017 msuchanek@suse.de
- Blacklist fixes for unsupported ppc platforms
  3c29b6038828 powerpc/8xx: fix mpc8xx_get_irq() return on no irq
  8d046759f6ad powerpc/44x: Fix mask and shift to zero bug
  c65540453e15 powerpc/83xx: Use sizeof correct type when ioremapping
- commit ddd617a
* Tue Oct 24 2017 msuchanek@suse.de
- powerpc/mm: Fix check of multiple 16G pages from device tree
  (bsc#1064861, git-fixes).
- commit 41db419
* Tue Oct 24 2017 msuchanek@suse.de
- powerpc: Fix emulation of mfocrf in emulate_step() (bsc#1064861,
  git-fixes).
- commit 7e619db
* Tue Oct 24 2017 msuchanek@suse.de
- powerpc: Correct instruction code for xxlor instruction
  (bsc#1064861, git-fixes).
- commit d980e69
* Wed Oct 18 2017 mcgrof@suse.com
- Revert "mac80211: accept key reinstall without changing anything"
  This reverts commit 1def0d4e1446974356bacd9f4be06eee32b66473.
- commit e5c6cd6
* Wed Oct 18 2017 bp@suse.de
- x86/microcode/intel: Disable late loading on model 79
  (bsc#1054305).
- commit 8961445
* Tue Oct 17 2017 alnovak@suse.cz
- NFS: Remove asserts from the NFS XDR code (bsc#1063544).
- commit 68ea501
* Tue Oct 17 2017 mkubecek@suse.cz
- mac80211: accept key reinstall without changing anything
  (CVE-2017-13080 bsc#1063667).
- commit 1def0d4
* Tue Oct 17 2017 mcgrof@suse.com
- mac80211: accept key reinstall without changing anything (CVE-2017-13080 bsc#1063667).
- commit 2710843
* Mon Oct 16 2017 tabraham@suse.com
- scsi: qla2xxx: Get mutex lock before checking optrom_state
  (bsc#1053317).
- commit 2bc68bb
* Mon Oct 16 2017 mhocko@suse.cz
- blacklist.conf: blacklist pure doc update
- commit abcdf53
* Mon Oct 16 2017 mhocko@suse.cz
- blacklist.conf: blacklist bfedb589252c ("mm: Add a user_ns owner to
  mm_struct and fix ptrace permission checks") (bnc#1044228)
- commit 9d4f8b9
* Mon Oct 16 2017 msrb@suse.com
- drm/mgag200: Fixes for G200eH3. (bnc#1062842)
- commit 3a84375
* Mon Oct 16 2017 hare@suse.de
- s390/qdio: avoid reschedule of outbound tasklet once killed
  (bnc#1063301, LTC#159885).
- commit 6d7c308
* Fri Oct 13 2017 dchang@suse.com
- i40e: Initialize 64-bit statistics TX ring seqcount (bsc#909484
  FATE#317397).
- commit 677d9c5
* Thu Oct 12 2017 neilb@suse.com
- kabi fix for new hash_cred function (bsc#1012917).
- commit 78f075e
* Thu Oct 12 2017 hare@suse.de
- virtio_scsi: don't call virtqueue_add_sgs(... GFP_NOIO)
  holding spinlock (bsc#1036286).
- commit addf658
* Thu Oct 12 2017 jlee@suse.com
- KEYS: fix dereferencing NULL payload with nonzero length
  (bsc#1045327, bsc#1062471, CVE-2017-15274).
- commit 242841d
* Thu Oct 12 2017 neilb@suse.com
- nfs: improve shinking of access cache (bsc#1012917).
- commit a19642d
* Thu Oct 12 2017 neilb@suse.com
- sunrpc: use supplimental groups in auth hash (bsc#1012917).
- sunrpc: replace generic auth_cred hash with auth-specific
  function (bsc#1012917).
- sunrpc: add RPCSEC_GSS hash_cred() function (bsc#1012917).
- sunrpc: add auth_unix hash_cred() function (bsc#1012917).
- sunrpc: add generic_auth hash_cred() function (bsc#1012917).
- sunrpc: add hash_cred() function to rpc_authops struct
  (bsc#1012917).
- commit a48b603
* Thu Oct 12 2017 neilb@suse.com
- Move a patch in series.conf
  Will make it easier to add some other patches at the best place.
- commit 914e718
* Wed Oct 11 2017 mhocko@suse.cz
- fs/binfmt_elf.c:load_elf_binary(): return -EINVAL on zero-length
  mappings (bnc#1059525).
- commit 294ccfe
* Wed Oct 11 2017 tiwai@suse.de
- ALSA: seq: Fix use-after-free at creating a port
  (CVE-2017-15265, bsc#1062520).
- commit 641303f
* Tue Oct 10 2017 jbeulich@suse.com
- netback: backport from SLE12 SP1's xen3-patch-3.2 (bsc#1056504).
- netback: backport from SLE12 SP1's xen3-patch-3.3 (bsc#1056504).
- netback: backport from SLE12 SP1's xen3-patch-3.7 (bsc#1056504).
- netback: coalesce (guest) RX SKBs as needed (bsc#1056504).
- Refresh patches.xen/xen-netback-generalize.
- Refresh patches.xen/xen-netback-kernel-threads.
- Refresh patches.xen/xen-netback-multiple-tasklets.
- Refresh patches.xen/xen-netback-notify-multi.
- Delete patches.xen/xen-netback-nr-irqs.
- commit 2cd7aa2
* Mon Oct  9 2017 tbogendoerfer@suse.de
- bnx2x: prevent crash when accessing PTP with interface down
  (bsc#1060665).
- commit fe2c718
* Mon Oct  9 2017 mgorman@suse.de
- blacklist.conf: Blacklist 0f792cf949a0be506c2aa8bfac0605746b146dda
- commit ab73474
* Sat Sep 30 2017 gqjiang@suse.com
- md/bitmap: disable bitmap_resize for file-backed bitmaps
  (bsc#1061180).
- commit b2da4bc
* Fri Sep 29 2017 jroedel@suse.de
- KVM: async_pf: Fix #DF due to inject "Page not Present" and
  "Page Ready" exceptions simultaneously (bsc#1061017).
- KVM: SVM: Add a missing 'break' statement (bsc#1061017).
- commit 063ea33
* Wed Sep 27 2017 lduncan@suse.com
- scsi: scsi_transport_iscsi: fix the issue that iscsi_if_rx
  doesn't parse nlmsg properly (CVE-2017-14489, bsc#1059051).
- commit 78e6cf5
* Wed Sep 27 2017 lduncan@suse.com
- scsi: reset wait for IO completion (bsc#996376).
- commit 16f1726
* Tue Sep 26 2017 jthumshirn@suse.de
- scsi: zfcp: fix missing trace records for early returns in
  TMF eh handlers (bnc#1060245, LTC#158494).
- s390/topology: enable / disable topology dynamically
  (bnc#1060245, LTC#159177).
- s390/topology: alternative topology for topology-less machines
  (bnc#1060245, LTC#159177).
- s390/cpcmd,vmcp: avoid GFP_DMA allocations (bnc#1060245,
  LTC#159112).
- scsi: zfcp: trace HBA FSF response by default on dismiss or
  timedout late response (bnc#1060245, LTC#158494).
- scsi: zfcp: fix payload with full FCP_RSP IU in SCSI trace
  records (bnc#1060245, LTC#158494).
- scsi: zfcp: fix passing fsf_req to SCSI trace on TMF to
  correlate with HBA (bnc#1060245, LTC#158494).
- scsi: zfcp: fix capping of unsuccessful GPN_FT SAN response
  trace records (bnc#1060245, LTC#158494).
- scsi: zfcp: fix queuecommand for scsi_eh commands when DIX
  enabled (bnc#1060245, LTC#158493).
- commit f8d0e68
* Wed Sep 20 2017 mhocko@suse.cz
- fs/binfmt_elf.c: fix bug in loading of PIE binaries
  (bnc#1059525, CVE-2017-1000253).
  Conflicts:
  series.conf
- fs/binfmt_elf.c: fix bug in loading of PIE binaries
  (bnc#1059525, CVE-2017-1000253).
- commit 924c482
* Wed Sep 20 2017 oneukum@suse.com
- blacklist.conf: alledged fix is an optimization, not a bug fix
- commit d60d29b
* Tue Sep 19 2017 vliaskovitis@suse.com
- HID: usbhid: Add HID_QUIRK_NOGET for Aten CS-1758 KVM switch
  (bnc#1022967).
- commit 9267d27
* Mon Sep 18 2017 jack@suse.cz
- blacklist.conf: Add commit b5accbb0dfae
- commit 15584c0
* Fri Sep 15 2017 acho@suse.com
- Bluetooth: Properly check L2CAP config option output buffer
  length (bsc#1057389 CVE-2017-1000251).
- commit c791a76
* Thu Sep 14 2017 jlee@suse.com
- Update config files. (bsc#1057796)
  The CONFIG_MODULE_SIG_UEFI should be enabled on x86_64/xen
  architecture because xen can work with shim on x86_64. Enabling
  the following kernel config to load certificate from db/mok:
  +CONFIG_MODULE_SIG_BLACKLIST=y
  +CONFIG_MODULE_SIG_UEFI=y
- commit f3af91e
* Wed Sep 13 2017 mcgrof@suse.com
- xfs: XFS_IS_REALTIME_INODE() should be false if no rt device
  present (bsc#1058524 CVE-2017-14340).
- commit ff262b7
* Tue Sep 12 2017 msuchanek@suse.de
- rpm/kernel-docs.spec.in: make unpack scripts executable
- commit 99b8184
* Mon Sep 11 2017 mgorman@suse.de
- powerpc: Fix the corrupt r3 error during MCE handling
  (bnc#1056230).
- commit 3c65671
* Fri Sep  8 2017 neilb@suse.com
- getcwd: Close race with d_move called by lustre (bsc#1052593).
- commit 5ab92d6
* Thu Sep  7 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Expand kernel tree directly from sources (bsc#1057199)
- commit 404d787
* Thu Sep  7 2017 jack@suse.cz
- blacklist.conf: Blacklist 914cea93dd89
- commit 267456d
* Thu Sep  7 2017 jack@suse.cz
- xfs: fix inobt inode allocation search optimization
  (bsc#1013018).
- commit d8269cc
* Thu Sep  7 2017 jack@suse.cz
- blacklist.conf: Blacklist 272eda8298dc and 4acadda74ff8
- commit 61013bc
* Thu Sep  7 2017 jlee@suse.com
- lib/mpi: mpi_read_raw_data(): fix nbits calculation
  (fate#314508).
- commit 8e0090f
* Thu Sep  7 2017 jbeulich@suse.com
- Delete patches.xen/xen-xenwatch-set-pid.patch, replaced by
  upstream ...
- avoid deadlock in xenbus (bnc#1047523).
- commit 9e8673b
* Thu Sep  7 2017 jbeulich@suse.com
- Delete patches.xen/xsa216.patch, replaced by upstream ...
- blkback/blktap: don't leak stack data via response ring
  (bsc#1042863 XSA-216).
- Refresh patches.xen/xen-blkif-discard.
- Refresh patches.xen/xen-blkif-indirect.
- commit 6b10b6c
* Thu Sep  7 2017 jbeulich@suse.com
- Delete
  patches.xen/x86-mm-paravirt-Fix-vmalloc_fault-oops-during-lazy-M.patch
  (was not meant to be on this branch).
- commit 1e534e9
* Thu Sep  7 2017 jlee@suse.com
- ALSA: hda - fix Lewisburg audio issue (fate#319286).
- commit 9c1ce96
* Thu Sep  7 2017 vbabka@suse.cz
- Sanitize 'move_pages()' permission checks (CVE-2017-14140,
  bsc#1057179).
- commit 46a11b3
* Wed Sep  6 2017 msuchanek@suse.de
- powerpc/prom: Increase minimum RMA size to 512MB (bsc#984530,
  bsc#1052370).
- commit c58ebe9
* Tue Sep  5 2017 jthumshirn@suse.de
- scsi: qla2xxx: Fix an integer overflow in sysfs code
  (bsc#1056588, CVE-2017-14051).
- commit c26b365
* Mon Sep  4 2017 mgorman@suse.de
- powerpc: Make sure IPI handlers see data written by IPI senders
  (bnc#1056230).
- powerpc/xics: Harden xics hypervisor backend (bnc#1056230).
- commit b5eb091
* Fri Sep  1 2017 tabraham@suse.com
- Delete
  patches.xen/x86-mm-paravirt-Fix-vmalloc_fault-oops-during-lazy-M.patch.
  It isn't needed here. Lazy MMU updates are already suppressed by
  do_page_fault (added by xen3-patch-3.0.73-74)
- commit 2231c06
* Thu Aug 31 2017 hare@suse.de
- Refresh
  patches.arch/s390-sles11sp4-20-01-09-pci-allow-more-than-32-pci-functions.patch.
- commit 8e1944d
* Thu Aug 31 2017 hare@suse.de
- kabi/severities: Ignore zpci symbol changes (bsc#1054247)
- commit 47a1a5f
* Thu Aug 31 2017 jthumshirn@suse.de
- scsi: qla2xxx: Fix an integer overflow in sysfs code
  (bsc#1056588, CVE-2017-14051).
- commit 4f71cfb
* Sat Aug 26 2017 lma@suse.com
- blacklist.conf: 90db1043 KVM: kvm_io_bus_unregister_dev() should never fail
- commit 51fea8b
* Sat Aug 26 2017 lma@suse.com
- Drop commit 96234ae:kvm_io_bus_unregister_dev() should never fail. (bsc#1055680)
  It causes regression, it's applicable for kernel 3.4+, not for 3.0.
- commit f0ffba2
* Thu Aug 24 2017 hare@suse.de
- Fixup build warnings in drivers/scsi/scsi.c (bsc#1031358)
  Refresh
  patches.suse/scsi-close-race-when-updating-blocked-counters.patch.
- commit 692c26c
* Wed Aug 23 2017 hare@suse.de
- scsi: close race when updating blocked counters (bsc#1031358).
- scsi: avoid system stall due to host_busy race (bsc#1031358).
- commit eeb8aaa
* Tue Aug 22 2017 fliu@suse.com
- reiserfs: fix race in readdir (bsc#1039803).
- commit 0865c62
* Fri Aug 18 2017 hare@suse.de
- PCI: fix hotplug related issues (bnc#1054247, LTC#157731).
- s390/pci: provide more debug information (bnc#1054247,
  LTC#157731).
- s390/pci: fix handling of PEC 306 (bnc#1054247, LTC#157731).
- s390/pci: improve pci hotplug (bnc#1054247, LTC#157731).
- s390/pci: introduce clp_get_state (bnc#1054247, LTC#157731).
- s390/pci: improve error handling during fmb (de)registration
  (bnc#1054247, LTC#157731).
- s390/pci: improve unreg_ioat error handling (bnc#1054247,
  LTC#157731).
- s390/pci: improve error handling during interrupt deregistration
  (bnc#1054247, LTC#157731).
- s390/pci: don't cleanup in arch_setup_msi_irqs (bnc#1054247,
  LTC#157731).
- commit c40fbaf
* Fri Aug 18 2017 neilb@suse.com
- NFS: Optimize fallocate by refreshing mapping when needed
  (bsc#1053933).
- NFS: invalidate file size when taking a lock (bsc#1053933).
- NFS: Cache aggressively when file is open for writing
  (bsc#1053933).
- NFS: Don't flush caches for a getattr that races with writeback
  (bsc#1053933).
  [#] Conflicts:
  [#]	series.conf
- commit 256b7bf
* Thu Aug 17 2017 tonyj@suse.de
- audit: Fix use after free in audit_remove_watch_rule()
  (bsc#1045205).
- commit f3c2bdd
* Thu Aug 17 2017 oneukum@suse.com
- uwb: fix device quirk on big-endian hosts (bsc#1036629).
- commit 0655b05
* Thu Aug 17 2017 oneukum@suse.com
- blacklist.conf: fix made superfluous by another backport
- commit e67d509
* Thu Aug 17 2017 oneukum@suse.com
- cx231xx-audio: fix NULL-deref at probe (bsc#1050431).
- commit 69face6
* Thu Aug 17 2017 oneukum@suse.com
- cx82310_eth: use skb_cow_head() to deal with cloned skbs
  (bsc#1045154).
- commit 58dbe1d
* Thu Aug 17 2017 oneukum@suse.com
- gspca: konica: add missing endpoint sanity check (bsc#1050431).
- commit 53c493d
* Thu Aug 17 2017 jeffm@suse.com
- supported.conf: clear mistaken external support flag for cifs.ko (bsc#1053802).
- commit 4c7c498
* Thu Aug 17 2017 oneukum@suse.com
- blacklist.conf: debugging output on BE architectures only
- commit 5692aa5
* Thu Aug 17 2017 oneukum@suse.com
- media: platform: davinci: return -EINVAL for
  VPFE_CMD_S_CCDC_RAW_PARAMS ioctl (bsc#1050431).
- commit c7b8177
* Thu Aug 17 2017 lhenriques@suse.com
- af_key: do not use GFP_KERNEL in atomic contexts (bsc#1054093).
- commit cc869af
* Wed Aug 16 2017 lhenriques@suse.com
- net: Fix RCU splat in af_key (bsc#1054093).
- commit 5478680
* Wed Aug 16 2017 msuchanek@suse.de
- powerpc/slb: Force a full SLB flush when we insert for a bad EA
  (bsc#1054070).
- Refresh patches.arch/ppc64-bigmem-15-Update-kernel-VSID-range.
- Refresh patches.suse/ppc64-bigmem-introduce-CONFIG_BIGMEM.
- commit 42d45c1
* Wed Aug 16 2017 rgoldwyn@suse.com
- fuse: fix fuse_write_end() if zero bytes were copied
  (bsc#1054706).
- fuse: do not use iocb after it may have been freed
  (bsc#1054706).
- fuse: fuse_flush must check mapping->flags for errors
  (bsc#1054706).
- fuse: fsync() did not return IO errors (bsc#1054076).
- commit e3d377d
* Tue Aug 15 2017 tiwai@suse.de
- timerfd: Protect the might cancel mechanism proper
  (CVE-2017-10661 bsc#1053152).
- commit 75a7aed
* Tue Aug 15 2017 tiwai@suse.de
- isdn/i4l: fix buffer overflow (CVE-2017-12762 bsc#1053148).
- commit 9e2c13e
* Mon Aug 14 2017 neilb@suse.com
- blacklist.conf: add unwanted commit.
- commit b4d3c03
* Mon Aug 14 2017 neilb@suse.com
- blacklist.conf:  add unwanted commit
- commit dcc83b0
* Thu Aug 10 2017 msuchanek@suse.de
- powerpc/fadump: add reschedule point while releasing memory
  (bsc#1040609 bsc#1024450).
- commit 6d4da7f
* Wed Aug  9 2017 msuchanek@suse.de
- blacklist 9754d45e9970 tpm: read burstcount from TPM_STS in one 32-bit
  transaction
- commit eddde97
* Wed Aug  9 2017 msuchanek@suse.de
- tpm: fix a kernel memory leak in tpm-sysfs.c (bsc#1050381).
- commit 90df398
* Wed Aug  9 2017 msuchanek@suse.de
- powerpc/fadump: provide a helpful error message (bsc#1037669
  bsc#1037667).
- commit 82597a9
* Wed Aug  9 2017 msuchanek@suse.de
- powerpc/fadump: avoid duplicates in crash memory ranges
  (bsc#1037669 bsc#1037667).
- commit 1b61499
* Wed Aug  9 2017 tiwai@suse.de
- [media] saa7164: fix double fetch PCIe access condition
  (CVE-2017-8831 bsc#1037994).
- commit c58d542
* Tue Aug  8 2017 bpoirier@suse.com
- udp: consistently apply ufo or fragmentation (bsc#1052311
  CVE-2017-1000112).
- commit 1374c40
* Tue Aug  8 2017 tonyj@suse.de
- Refresh
  patches.suse/intel-perf-event-0134-perf-x86-disable-pebs-on-a-guest-entry.patch.
- commit ea31e11
* Mon Aug  7 2017 tonyj@suse.de
- blacklist.conf:
- commit 2f57143
* Mon Aug  7 2017 oneukum@suse.com
- ser_gigaset: return -ENOMEM on error instead of success
  (bsc#1037441).
- commit 5fbc9f1
* Mon Aug  7 2017 oneukum@suse.com
- blacklist.conf: optimization, no bug fix
- commit c8b326d
* Mon Aug  7 2017 mfleming@suse.de
- blacklist.conf: 34bf129a7f06 isn't needed because we don't build PA-RISC.
- commit 838787c
* Mon Aug  7 2017 jack@suse.cz
- blacklist.conf: Blacklist a428d314ebcf65
- commit abd5b4b
* Mon Aug  7 2017 jack@suse.cz
- blacklist.conf: Blacklist 8ba358756aa08
- Update tags:
  patches.fixes/ext4-Don-t-clear-SGID-when-inheriting-ACLs.patch.
  patches.fixes/ocfs2-Don-t-clear-SGID-when-inheriting-ACLs.patch.
- commit c963532
* Fri Aug  4 2017 neilb@suse.com
- NFS: Do drop directory dentry when error clearly requires it (bsc#1051932).
- commit e8c7768
* Thu Aug  3 2017 neilb@suse.com
- NFSD: Don't use state id of 0 - it is reserved (bsc#1049688 bsc#1051770).
- commit 6ab6dd2
* Wed Aug  2 2017 jroedel@suse.de
- blacklist.conf: Blacklist ceb75787bc75 (' PM / sleep: fix device reference leak in test_suspend')
  It fixes only a test-case.
- commit 7117fc1
* Wed Aug  2 2017 oneukum@suse.com
- smsc75xx: use skb_cow_head() to deal with cloned skbs
  (bsc#1045154).
- USB: serial: oti6858: fix NULL-deref at open (bsc#1037441).
- commit b0c3d9a
* Wed Aug  2 2017 jroedel@suse.de
- blacklist.conf: Blacklist 847fa1a6d3d0 ('ftrace/x86_32: Set ftrace_stub to weak to prevent gcc from using short jumps to it')
  The released kernels are not build with a gas new enough to
  optimize the jmps so that this patch would be required.
  (bsc#1051478)
- commit 36e2116
* Wed Aug  2 2017 jroedel@suse.de
- x86/pci-calgary: Fix iommu_free() comparison of unsigned
  expression >= 0 (bsc#1051478).
- commit f900b63
* Wed Aug  2 2017 oneukum@suse.com
- blacklist.conf: this fix is for gadgets only
- commit ad0738a
* Wed Aug  2 2017 oneukum@suse.com
- blacklist.conf: fix would change the ABI
- commit c542573
* Wed Aug  2 2017 oneukum@suse.com
- USB: serial: spcp8x5: fix NULL-deref at open (bsc#1037441).
- commit 5a6f1f7
* Wed Aug  2 2017 oneukum@suse.com
- blacklist.conf: error return in an unlikely error case of an unsupported driver
- commit d2bf279
* Wed Aug  2 2017 oneukum@suse.com
- blacklist.conf: too trivial to take
- commit d84cbf1
* Tue Aug  1 2017 oneukum@suse.com
- USB: serial: cp210x: fix tiocmget error handling (bsc#1037441).
- USB: iowarrior: fix info ioctl on big-endian hosts
  (bsc#1037441).
- Refresh
  patches.drivers/0005-USB-serial-cp210x-add-8-bit-and-32-bit-register-acce.patch.
- commit 5a3587d
* Tue Aug  1 2017 oneukum@suse.com
- blacklist.conf: no functional change
- commit fdabec1
* Tue Aug  1 2017 oneukum@suse.com
- USB: serial: io_edgeport: fix epic-descriptor handling
  (bsc#1037441).
- commit 97bfb20
* Mon Jul 31 2017 oneukum@suse.com
- libceph: potential NULL dereference in ceph_msg_data_create()
  (bsc#1051515).
- commit f87b27d
* Mon Jul 31 2017 jgross@suse.com
- xen: avoid deadlock in xenbus (bnc#1047523).
- commit fd532ee
* Mon Jul 31 2017 vliaskovitis@suse.com
- block: do not allow updates through sysfs until registration
  completes (bsc#1047027).
- commit ca5fbee
* Mon Jul 31 2017 mgorman@suse.de
- blacklist.conf: Blacklist patch that introduces a semantic change
- commit 7093468
* Fri Jul 28 2017 mkubecek@suse.cz
- ipv6: avoid overflow of offset in ip6_find_1stfragopt
  (CVE-2017-7542 bsc#1049882).
- commit 4882718
* Fri Jul 28 2017 mkubecek@suse.cz
- rxrpc: Fix several cases where a padded len isn't checked in
  ticket decode (CVE-2017-7482 bsc#1046107).
- commit 840249f
* Fri Jul 28 2017 jkosina@suse.cz
- Update patches.fixes/dentry-name-snapshots.patch (bsc#1049483
  CVE-2017-7533): update CVE reference
- commit b88d632
* Fri Jul 28 2017 jack@suse.cz
- Update patches.fixes/dentry-name-snapshots.patch (bsc#1049483
  CVE-2017-7533).
- commit 233f2d8
* Fri Jul 28 2017 vliaskovitis@suse.com
- jsm: add support for additional Neo cards (bsc#1045615).
- commit d59f154
* Thu Jul 27 2017 jslaby@suse.cz
- mqueue: fix a use-after-free in sys_mq_notify() (bnc#1048275
  CVE-2017-11176).
- commit 6372f04
* Wed Jul 26 2017 msuchanek@suse.de
- Refresh bigmem kabi symbols
- commit d5b022a
* Wed Jul 26 2017 oneukum@suse.com
- usbvision: fix NULL-deref at probe (bsc#1050431).
- commit 79d7ecc
* Wed Jul 26 2017 jack@suse.cz
- blacklist.conf: Blacklist 9bcf66c72
- commit a6e2d4e
* Wed Jul 26 2017 glin@suse.com
- blacklist.conf: 8b8642af15ed not a supported driver
- commit da8a91b
* Wed Jul 26 2017 jack@suse.cz
- udf: Fix deadlock between writeback and udf_setsize()
  (bsc#1013018).
- commit 35f6ae7
* Wed Jul 26 2017 jack@suse.cz
- isofs: Do not return EACCES for unknown filesystems
  (bsc#1013018).
- commit 660b702
* Wed Jul 26 2017 jack@suse.cz
- udf: Fix races with i_size changes during readpage
  (bsc#1013018).
- commit 85c279b
* Tue Jul 25 2017 lduncan@suse.com
- scsi: bnx2i: missing error code in bnx2i_ep_connect()
  (bsc#1048221).
- commit a212a8d
* Tue Jul 25 2017 oneukum@suse.com
- vb2: Fix an off by one error in 'vb2_plane_vaddr' (bsc#1050431).
- commit 4352515
* Tue Jul 25 2017 oneukum@suse.com
- USB: serial: ch341: fix open error handling (bsc#1037441).
- commit 8f6393c
* Tue Jul 25 2017 msrb@suse.com
- drm/mgag200: Add support for G200eH3 (bnc#1044216,
  fate#323551)
- commit ebbd329
* Mon Jul 24 2017 jack@suse.cz
- blacklist.conf: Blacklist 84969465ddc4 and c925dc162f77
- commit 976d897
* Mon Jul 24 2017 hare@suse.de
- s390/qeth: no ETH header for outbound AF_IUCV (bnc#1046715,
  LTC#156276).
- s390/qeth: size calculation outbound buffers (bnc#1046715,
  LTC#156276).
- s390/qdio: clear DSCI prior to scanning multiple input queues
  (bnc#1046715, LTC#156234).
- commit 5bb5adb
* Mon Jul 24 2017 hare@suse.de
- dm: fix ioctl retry termination with signal (bsc#1050154).
- blacklist.conf: add not applicable patch
- block: fix ext_dev_lock lockdep report (bsc#1050154).
- target/iscsi: Fix double free in lio_target_tiqn_addtpg()
  (bsc#1050154).
- scsi: fix race between simultaneous decrements of ->host_failed
  (bsc#1050154).
- scsi: mvsas: fix command_active typo (bsc#1050154).
- commit 9857356
* Mon Jul 24 2017 hare@suse.de
- scsi: qla2xxx: Fix scsi scan hang triggered if adapter fails
  during init (bsc#1050154).
- commit bec2af8
* Mon Jul 24 2017 hare@suse.de
- megaraid_sas: add missing curly braces in ioctl handler
  (bsc#1050154).
- commit 2789a5e
* Mon Jul 24 2017 jack@suse.cz
- dentry name snapshots (bsc#1049483).
- commit d120114
* Mon Jul 24 2017 mgalbraith@suse.de
- blacklist.conf: add 2aeb1883547626d82c597cce2c99f0b9c62e2425
- commit e23b78f
* Mon Jul 24 2017 mgalbraith@suse.de
- perf/core: Correct event creation with PERF_FORMAT_GROUP
  (bnc#1013018).
- hrtimer: Allow concurrent hrtimer_start() for self restarting
  timers (bnc#1013018).
- sched/topology: Fix overlapping sched_group_capacity
  (bnc#1013018).
- sched/topology: Fix overlapping sched_group_mask (bnc#1013018).
- sched/topology: Remove FORCE_SD_OVERLAP (bnc#1013018).
- sched/topology: Move comment about asymmetric node setups
  (bnc#1013018).
- sched/topology: Optimize build_group_mask() (bnc#1013018).
- sched/topology: Verify the first group matches the child domain
  (bnc#1013018).
- sched/debug: Print the scheduler topology group mask
  (bnc#1013018).
- sched/topology: Simplify build_overlap_sched_groups()
  (bnc#1013018).
- sched/topology: Fix building of overlapping sched-groups
  (bnc#1013018).
- sched/fair, cpumask: Export for_each_cpu_wrap() (bnc#1013018).
- sched/topology: Refactor function build_overlap_sched_groups()
  (bnc#1013018).
- sched: Rename a misleading variable in
  build_overlap_sched_groups() (bnc#1013018).
- sched: Always initialize cpu-power (bnc#1013018).
- sched: Fix domain iteration (bnc#1013018).
- sched: Fix SD_OVERLAP (bnc#1013018).
- commit 580bd99
* Fri Jul 21 2017 jroedel@suse.de
- x86/acpi: Prevent out of bound access caused by broken ACPI
  tables (CVE-2017-11473 bsc#1049603).
- commit 97c76d1
* Thu Jul 20 2017 tabraham@suse.com
- x86, mm, paravirt: Fix vmalloc_fault oops during lazy MMU
  updates (bsc#948562).
- Return short read or 0 at end of a raw device, not EIO
  (bsc#1039594).
- commit df13d1b
* Thu Jul 20 2017 jroedel@suse.de
- irq: Fix race condition (bsc#1042615).
- commit 82c1f16
* Thu Jul 20 2017 neilb@suse.com
- NFS: Make nfs_readdir revalidate less often (bsc#1048232).
- commit 611b96c
* Wed Jul 19 2017 jack@suse.cz
- ocfs2: Don't clear SGID when inheriting ACLs (bsc#1030552).
- reiserfs: Don't clear SGID when inheriting ACLs (bsc#1030552).
- btrfs: Don't clear SGID when inheriting ACLs (bsc#1030552).
- ext4: Don't clear SGID when inheriting ACLs (bsc#1030552).
- ext3: Don't clear SGID when inheriting ACLs (bsc#1030552).
- ext2: Don't clear SGID when inheriting ACLs (bsc#1030552).
- commit d3bf834
* Mon Jul 17 2017 msuchanek@suse.de
- Drop CONFIG_PPC_CELL from bigmem (bsc#1049128).
  In 2400fd822f46 powerpc/asm: Mark cr0 as clobbered in mftb()
  it is noted that the Cell workaround that emulates mftb uses an extra
  register.
  Drop Cell support to avoid the issue. Removes some Cell-specific drivers
  and Kernel ABI symbols.
- commit 5a4f14a
* Mon Jul 17 2017 nborisov@suse.com
- Refresh
  patches.fixes/0002-xfs-use-b_state-to-fix-buffer-I-O-accounting-release.patch-SLE11-SP4.
- commit 1788b14
* Sat Jul 15 2017 msuchanek@suse.de
- powerpc/mm/hash: Use context ids 1-4 for the kernel
  (fate#322495, bsc#1032471).
- commit 4936ae8
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc/mm/hash: Increase VA range to 128TB (fate#322495,
  bsc#1032471).
- commit 8932b77
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc: Remove STAB code (fate#322495, bsc#1032471).
- commit 4034322
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc: Drop support for pre-POWER4 cpus (fate#322495,
  bsc#1032471).
- commit fd34134
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc/mm: use macro PGTABLE_EADDR_SIZE instead of digital
  (fate#322495, bsc#1032471).
- commit faa2ef3
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc/mm/hash: Convert mask to unsigned long (fate#322495,
  bsc#1032471).
- commit 5c47334
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc/mm/hash: Support 68 bit VA (fate#322495, bsc#1032471).
- commit c3bfccd
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc/mm/hash: Check for non-kernel address in
  get_kernel_vsid() (fate#322495, bsc#1032471).
- commit 210f73d
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc/mm/hash: Properly mask the ESID bits when building
  proto VSID (fate#322495, bsc#1032471).
- commit 0a6dbe1
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc/mm/slice: Update slice mask printing to use bitmap
  printing (fate#322495, bsc#1032471).
- commit de3f8d2
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc/mm/slice: Move slice_mask struct definition to slice.c
  (fate#322495, bsc#1032471).
- commit bcb47af
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc/mm: Remove checks that TASK_SIZE_USER64 is too small
  (fate#322495, bsc#1032471).
- commit dd08acd
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc/mm/slice: Update the function prototype (fate#322495,
  bsc#1032471).
- commit 5e68b70
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc/mm/slice: Convert slice_mask high slice to a bitmap
  (fate#322495, bsc#1032471).
- commit fde1b38
* Fri Jul 14 2017 msuchanek@suse.de
- powerpc/mm/slice: Fix off-by-1 error when computing slice mask
  (fate#322495, bsc#1032471).
- commit be00e7e
* Tue Jul 11 2017 msuchanek@suse.de
- blacklist 03dfee6d5f82 powerpc/mm: Fix swapper_pg_dir size on 64-bit
  hash w/64K pages
  We don't need this patch because PGD_TABLE_SIZE is defined as expected.
  It was broken later by accomodating for radix.
- commit e147dff
* Tue Jul 11 2017 msuchanek@suse.de
- blacklist 92d9dfda8b54 powerpc/mm/4k: Limit 4k page size config to 64TB
  virtual address space
- commit c608de8
* Tue Jul 11 2017 oneukum@suse.com
- mwifiex: printk() overflow with 32-byte SSIDs (bsc#1048185).
- commit 43faa41
* Tue Jul 11 2017 mhocko@suse.cz
- mm/mmap.c: do not blow on PROT_NONE MAP_FIXED holes in the stack
  (bnc#1039348).
- commit e46bf1a
* Mon Jul 10 2017 msuchanek@suse.de
- Refresh bigmem patches in preparation for FATE#322495
  Refresh
  patches.arch/powerpc-pseries-Use-H-CLEAR-HPT-to-clear-MMU-hash-table-during-kexec.patch
  - add metadata and move before bigmem
  Refresh
  patches.arch/ppc64-bigmem-04-mm-Convert-virtual-address-to-vpn
  - for the move
  Refresh:
  patches.arch/ppc64-bigmem-10-mm-Update-VSID-allocation-documentation
  patches.arch/ppc64-bigmem-11-mm-Make-some-of-the-PGTABLE_RANGE-dependency-explicit
  patches.arch/ppc64-bigmem-15-Update-kernel-VSID-range
  - reduce #ifdefs inside comments
  Regenerate bigmem ifdefs
- commit 1010c98
* Mon Jul 10 2017 msuchanek@suse.de
- blacklist b50a6c584bb4 powerpc/perf: Clear MMCR2 when enabling PMU
  (bsc#1035721).
  blacklist 370f06c88528 powerpc/perf: Remove PPMU_HAS_SSLOT flag for
  Power8 (bsc#1035721).
  blacklist 99dfe80a2a24 powerpc/ptrace: Preserve previous fprs/vsrs on
  short regset write (bsc#1035777).
  b50a6c584bb4 powerpc/perf: Clear MMCR2 when enabling PMU
  requires 8dd75ccb5 powerpc: Use privileged SPR number for MMCR2
  which
  Fixes: 240686c13687 ("powerpc: Initialise PMU related regs on Power8")
  which we do not have meaning the PMU regs are NOT initialized on SLE11
  SP4 on POWER.
- commit e5bfe93
* Mon Jul 10 2017 msuchanek@suse.de
- powerpc/pseries: Release DRC when configure_connector fails
  (bsc#1035777, Pending Base Kernel Fixes).
- commit d4b9adf
* Mon Jul 10 2017 neilb@suse.com
- svcrdma: Fix send_reply() scatter/gather set-up (git-fixes).
- xprtrdma: Free the pd if ib_query_qp() fails (git-fixes).
- net: ip6mr: fix static mfc/dev leaks on table destruction
  (git-fixes).
- net: ipmr: fix static mfc/dev leaks on table destruction
  (git-fixes).
- commit 42510da
* Fri Jul  7 2017 lhenriques@suse.com
- xfrm: Oops on error in pfkey_msg2xfrm_state() (bsc#1047653).
- commit bd5e77a
* Fri Jul  7 2017 lhenriques@suse.com
- af_key: Add lock to key dump (bsc#1047653).
- commit b86c985
* Thu Jul  6 2017 oneukum@suse.com
- blacklist.conf: this is a cleanup, not a bug fix
- commit a16ab04
* Thu Jul  6 2017 oneukum@suse.com
- USB: usbip: fix nonconforming hub descriptor (bsc#1047487).
- commit 7baec2c
* Thu Jul  6 2017 oneukum@suse.com
- blacklist.conf: driver not compiled
- commit 4266c6e
* Wed Jul  5 2017 lhenriques@suse.com
- af_key: Fix slab-out-of-bounds in pfkey_compile_policy
  (bsc#1047354).
- commit 338be80
* Wed Jul  5 2017 lhenriques@suse.com
- xfrm: NULL dereference on allocation failure (bsc#1047343).
- commit bf1e0e1
* Mon Jul  3 2017 aaptel@suse.com
- cifs: small underflow in cnvrtDosUnixTm() (bsc#1043935).
- commit 680d3a7
* Mon Jul  3 2017 oneukum@suse.com
- blacklist.conf: not taking a fix for a minor performance issue
- commit 790fa0a
* Mon Jul  3 2017 oneukum@suse.com
- usb: r8a66597-hcd: select a different endpoint on timeout
  (bsc#1047053).
- commit 59c5593
* Mon Jul  3 2017 mgorman@suse.de
- mm/memory-failure.c: use compound_head() flags for huge pages
  (bnc#971975 VM -- git fixes).
- commit f431671
* Mon Jul  3 2017 neilb@suse.com
- NFS: Avoid getting confused by confused server (bsc#1045416).
- commit 60659fc
* Fri Jun 30 2017 bpoirier@suse.com
- vmxnet3: fix checks for dma mapping errors (bsc#1045356).
- Refresh
  patches.fixes/vmxnet3-avoid-calling-pskb_may_pull-with-interrupts-.patch.
- Refresh
  patches.fixes/vmxnet3-fix-lock-imbalance-in-vmxnet3_tq_xmit.patch.
- commit bce11d4
* Thu Jun 29 2017 bpoirier@suse.com
- Refresh
  patches.fixes/vmxnet3-avoid-calling-pskb_may_pull-with-interrupts-.patch.
- Refresh
  patches.fixes/vmxnet3-fix-lock-imbalance-in-vmxnet3_tq_xmit.patch.
- commit 84ce868
* Thu Jun 29 2017 scabrero@suse.de
- cifs: Timeout on SMBNegotiate request (bsc#1044913).
- commit cfe2000
* Thu Jun 29 2017 oneukum@suse.com
- blacklist.conf: pointless patch for our purposes
  The bug triggers only upon a malformed descriptor and the comparison
  is so that our buffer would be too large not too small so no overflow.
  The device would not work, but it won't anyway.
- commit ec3f9e5
* Thu Jun 29 2017 mhocko@suse.cz
- blacklist.conf: blacklist 570d8e939801
  we do not care about the code in Documentation all that much, do we?
- commit 716d893
* Wed Jun 28 2017 mhocko@suse.cz
- blacklist.conf: blacklisted 1fe89e1b6d27 (bnc#1046122)
- commit 169eb83
* Tue Jun 27 2017 tbogendoerfer@suse.de
- net/mlx4_en: Fix type mismatch for 32-bit systems (bsc#919382).
- blacklist.conf: one cosmetic, one reverted commit
- net/mlx4: Fix the check in attaching steering rules
  (bsc#919382).
- mlx4: reduce OOM risk on arches with large pages (bsc#919382).
- net/mlx4_core: Use-after-free causes a resource leak in
  flow-steering detach (bsc#919382).
- net/mlx4: Fix uninitialized fields in rule when adding
  promiscuous mode to device managed flow steering (bsc#919382).
- net/mlx4_en: fix overflow in mlx4_en_init_timestamp()
  (bsc#919382).
- net/mlx4_en: Resolve dividing by zero in 32-bit system
  (bsc#919382).
- net/mlx4_core: Get num_tc using netdev_get_num_tc (bsc#919382).
- net/mlx4_en: Change the error print to debug print (bsc#919382).
- net/mlx4_core: Prevent VF from changing port configuration
  (bsc#919382).
- net/mlx4_core: Use cq quota in SRIOV when creating completion
  EQs (bsc#919382).
- IB/mlx4: Fix port query for 56Gb Ethernet links (bsc#919382).
- net/mlx4_core: Enhance the MAD_IFC wrapper to convert VF port
  to physical (bsc#919382).
- net/mlx4_core: Fix when to save some qp context flags for
  dynamic VST to VGT transitions (bsc#919382).
- net/mlx4_en: Avoid adding steering rules with invalid ring
  (bsc#919382).
- net/mlx4_core: Eliminate warning messages for SRQ_LIMIT under
  SRIOV (bsc#919382).
- net/mlx4_core: Fix VF overwrite of module param which disables
  DMFS on new probed PFs (bsc#919382).
- IB/mlx4: Fix ib device initialization error flow (bsc#919382).
- IB/mlx4: Set traffic class in AH (bsc#919382).
- IB/mlx4: Handle well-known-gid in mad_demux processing
  (bsc#919382).
- IB/mlx4: Reduce SRIOV multicast cleanup warning message to
  debug level (bsc#919382).
- IB/mlx4: Demote mcg message from warning to debug (bsc#919382).
- commit 780a936
* Tue Jun 27 2017 oneukum@suse.com
- blacklist.conf: this changes the API to user land
  The patch disallows operations currently allowed.
- commit 84785e6
* Tue Jun 27 2017 oneukum@suse.com
- rfkill: fix rfkill_fop_read wait_event usage (bsc#1046192).
- commit 2df9521
* Tue Jun 27 2017 oneukum@suse.com
- blacklist.conf: no code change
- commit 16b3767
* Tue Jun 27 2017 oneukum@suse.com
- blacklist.conf: fixes only debugging output
- commit 8bd8189
* Tue Jun 27 2017 aaptel@suse.com
- cifs: don't compare uniqueids in cifs_prime_dcache unless
  server inode numbers are in use (bsc#1041975).
  backporting upstream commit 2f2591a34db6c9361faa316c91a6e320cb4e6aee
- commit 675a0c2
* Tue Jun 27 2017 oneukum@suse.com
- blacklist.conf: only true fixes
- commit 8c9209a
* Tue Jun 27 2017 oneukum@suse.com
- blacklist.conf: fix only for debugging output
- commit c857d32
* Tue Jun 27 2017 oneukum@suse.com
- blacklist.conf: driver not supported, fixes only an error case
- commit 01bb65b
* Tue Jun 27 2017 mhocko@suse.cz
- mm: larger stack guard gap, between vmas (bnc#1039348,
  CVE-2017-1000364). Replacement with the upstream solution.
- Refresh
  patches.fixes/mm-avoid-setting-up-anonymous-pages-into-file-mappin.patch.
- Delete patches.fixes/0001-mm-enlarge-stack-guard-gap.patch.
- Delete patches.fixes/0001-mm-enlarge-stack-guard-gap.patch-fix.
- Delete
  patches.fixes/0001-mm-mmap-do-not-blow-on-PROT_NONE-MAP_FIXED-holes-in-.patch.
- Delete
  patches.fixes/0002-mm-do-not-collapse-stack-gap-into-THP-fix.patch.
- Delete
  patches.fixes/0002-mm-do-not-collapse-stack-gap-into-THP.patch.
- commit 26533c8
* Tue Jun 27 2017 oneukum@suse.com
- blacklist.conf: blacklist driver for ARM machines only
- commit dc86015
* Tue Jun 27 2017 vliaskovitis@suse.com
- vmxnet3: fix lock imbalance in vmxnet3_tq_xmit() (bsc#1045356).
- vmxnet3: avoid calling pskb_may_pull with interrupts disabled
  (bsc#1045356).
- commit 3e2349d
* Tue Jun 27 2017 jslaby@suse.cz
- PCI: Fix devfn for VPD access through function 0 (bnc#943786
  git-fixes).
- commit 1d278fc
* Tue Jun 27 2017 jslaby@suse.cz
- Refresh
  patches.drivers/PCI-Add-VPD-function-0-quirk-for-Intel-Ethernet-devi.patch.
  Fix upstream commit ID.
- commit 164dd6a
* Tue Jun 27 2017 mhocko@suse.cz
- fs/exec.c: account for argv/envp pointers (bnc#1039354,
  CVE-2017-1000365).
- commit 69c16ba
* Mon Jun 26 2017 ydfan@suse.com
- libata: fix sff host state machine locking while polling (bsc#1045525).
- commit 65a64e4
* Fri Jun 23 2017 hare@suse.de
- md: fix a null dereference (bsc#1040351).
- commit 2ae6c9c
* Thu Jun 22 2017 neilb@suse.com
- Update patches.fixes/nfs-svc-rdma.fix (bsc#1044854).
  Fix bnc reference
- commit 812aed1
* Thu Jun 22 2017 jeffm@suse.com
- reiserfs: don't preallocate blocks for extended attributes
  (bsc#990682).
- commit 167fa9e
* Thu Jun 22 2017 jeffm@suse.com
- kabi: protect super_block->s_stack_depth (bsc#1032340
  CVE-2014-9922).
- commit 4529231
* Thu Jun 22 2017 jeffm@suse.com
- fs: limit filesystem stacking depth (bsc#1032340 CVE-2014-9922).
- commit 8b3a4cb
* Thu Jun 22 2017 oneukum@suse.com
- mmc: core: add missing pm event in mmc_pm_notify to fix hib
  restore (bsc#1045547).
- commit f8b5dde
* Thu Jun 22 2017 tiwai@suse.de
- blacklist.conf: Add a few inapplicable items (bsc#1045538).
- commit 43f2300
* Thu Jun 22 2017 tiwai@suse.de
- ALSA: off by one bug in snd_riptide_joystick_probe()
  (bsc#1045538).
- ALSA: ctxfi: Fallback DMA mask to 32bit (bsc#1045538).
- ALSA: seq: Fix snd_seq_call_port_info_ioctl in compat mode
  (bsc#1045538).
- ALSA: hda - using uninitialized data (bsc#1045538).
- ALSA: hda/realtek - Correction of fixup codes for PB V7900
  laptop (bsc#1045538).
- ALSA: hda - Fix regression of HD-audio controller fallback modes
  (bsc#1045538).
- ALSA: hda/realtek - Fix COEF widget NID for ALC260 replacer
  fixup (bsc#1045538).
- ath9k: fix buffer overrun for ar9287 (bsc#1045538).
- commit 0b71794
* Thu Jun 22 2017 mhocko@suse.cz
- mm, mmap: do not blow on PROT_NONE MAP_FIXED holes in the stack
  (bnc#1039348, bnc#1045340, bnc#1045406).
- commit cf4d269
* Thu Jun 22 2017 oneukum@suse.com
- USB: wusbcore: fix NULL-deref at probe (bsc#1045487).
- commit c26d798
* Thu Jun 22 2017 oneukum@suse.com
- Staging: vt6655-6: potential NULL dereference in
  hostap_disable_hostapd() (bsc#1045479).
- commit cecb344
* Wed Jun 21 2017 oneukum@suse.com
- blacklist.conf: PCI fix not worth the risk
  commit ea00353f36b64375518662a8ad15e39218a1f324
  Author: Lukas Wunner <lukas@wunner.de>
  Date:   Tue Apr 18 20:44:30 2017 +0200
    PCI: Freeze PME scan before suspending devices
    Laurent Pinchart reported that the Renesas R-Car H2 Lager board (r8a7790)
    crashes during suspend tests.  Geert Uytterhoeven managed to reproduce the
    issue on an M2-W Koelsch board (r8a7791):
    It occurs when the PME scan runs, once per second.  During PME scan, the
    PCI host bridge (rcar-pci) registers are accessed while its module clock
    has already been disabled, leading to the crash.
  The bug shows on uncommon hardware. Yet it introduces a common unreliability
  in WoL. Not going to take it.
- commit 6fdbfc0
* Wed Jun 21 2017 oneukum@suse.com
- blacklist.conf: we don't use the driver
- commit 21ea1d3
* Wed Jun 21 2017 oneukum@suse.com
- blacklist.conf: our driver version is hopelessly outdated
- commit 6e2c64b
* Wed Jun 21 2017 oneukum@suse.com
- blacklist.conf: blacklist patch against unused driver
- commit 8dc3fda
* Tue Jun 20 2017 jbeulich@suse.com
- blkback/blktap: don't leak stack data via response ring
  (bsc#1042863 XSA-216).
- commit cf7712f
* Tue Jun 20 2017 neilb@suse.com
- Fix soft lockup in svc_rdma_send (bsc#729329).
- commit c13c719
* Mon Jun 19 2017 bp@suse.de
- blacklist.conf: Add 609206854767 ("x86/efi: Unexport add_efi_memmap variable")
  It is in the kABI already and the patch itself is just a cleanup so
  remain conservative here.
- commit 6a1ed01
* Mon Jun 19 2017 mmarek@suse.com
- Refresh 0001-splice-Stub-splice_write_to_file.patch to make genksyms
  happy
  Copy the original declaration from <linux/splice.h> verbatim. Also, move
  the patch to patches.kabi.
- commit fa1fcfd
* Mon Jun 19 2017 nborisov@suse.com
- Revert "kabi:severeties: Add splice_write_to_file PASS"
  This reverts commit 05ecf7ab16b2ea555fadd1ce17d8177394de88f2.
- commit 7be2372
* Mon Jun 19 2017 nborisov@suse.com
- splice: Stub splice_write_to_file (bsc#1043234).
- commit 63f39e2
* Mon Jun 19 2017 mhocko@suse.cz
- sched/core: Remove false-positive warning from wake_up_process()
  (bnc#1044882).
- commit 9f59d5e
* Mon Jun 19 2017 neilb@suse.com
- net: avoid reference counter overflows on fib_rules in multicast
  forwarding (git-fixes).
- commit be544ea
* Sun Jun 18 2017 mhocko@suse.cz
- mm: do not collapse stack gap into THP (bnc#1039348,
  CVE-2017-1000364).
- Refresh
  patches.fixes/mm-avoid-setting-up-anonymous-pages-into-file-mappin.patch.
- commit f7bea08
* Fri Jun 16 2017 jack@suse.cz
- ext4: keep existing extra fields when inode expands
  (bsc#1013018).
- commit 46a18cc
* Fri Jun 16 2017 jack@suse.cz
- ext4: fix fdatasync(2) after extent manipulation operations
  (bsc#1013018).
- commit 868250c
* Fri Jun 16 2017 jack@suse.cz
- fs/xattr.c: zero out memory copied to userspace in getxattr
  (bsc#1013018).
- blacklist.conf: Added 341f741f04be and a056bdaae7a1
- commit 672b2c8
* Thu Jun 15 2017 msuchanek@wotan.suse.de
- Update kabi references.
- commit e39abd5
* Wed Jun 14 2017 mmarek@suse.cz
- drm/mgag200: Fix to always set HiPri for G200e4 (bsc#1015452,
  bsc#995542).
- commit 7c2528b
* Wed Jun 14 2017 oneukum@suse.com
- USB: serial: io_ti: fix information leak in completion handler
  (bsc#1038982, CVE-2017-8924).
- commit b990b48
* Wed Jun 14 2017 oneukum@suse.com
- USB: serial: omninet: fix reference leaks at open (bsc#1038981,
  CVE-2017-8925).
- commit 17890b9
* Wed Jun 14 2017 mhocko@suse.cz
- genirq: Prevent proc race against freeing of irq descriptors
  (bnc#1044230).
- commit f47cd77
* Wed Jun 14 2017 neilb@suse.com
- NFS: tidy up nfs_show_mountd_netid (git-fixes).
- NFSv4: fix getacl head length estimation (git-fixes).
- NFSv4: Fix the underestimation of delegation XDR space
  reservation (git-fixes).
- ipmr, ip6mr: fix scheduling while atomic and a deadlock with
  ipmr_get_route (git-fixes).
- decompress_bunzip2: off by one in get_next_block() (git-fixes).
- random32: fix off-by-one in seeding requirement (git-fixes).
- devres: fix a for loop bounds check (git-fixes).
- commit 1afc751
* Wed Jun 14 2017 neilb@suse.com
- blacklist.conf:
  blacklist uninteresting fix.
- commit a7ce78f
* Tue Jun 13 2017 tiwai@suse.de
- ALSA: timer: Fix missing queue indices reset at
  SNDRV_TIMER_IOCTL_SELECT (CVE-2017-1000380,bsc#1044125).
- ALSA: timer: Fix race between read and ioctl
  (CVE-2017-1000380,bsc#1044125).
- commit 7d9930f
* Tue Jun 13 2017 lhenriques@suse.com
- libceph: NULL deref on crush_decode() error path (bsc#1044015).
- commit c347575
* Mon Jun 12 2017 jslaby@suse.cz
- USB: serial: ark3116: fix register-accessor error handling
  (git-fixes).
- commit 286958e
* Mon Jun 12 2017 jslaby@suse.cz
- USB: serial: io_ti: fix information leak in completion handler
  (git-fixes).
- commit 2ef1d29
* Fri Jun  9 2017 nborisov@suse.com
- kabi:severeties: Add splice_write_to_file PASS
  This function is part of an xfs-specific fix which never went upstream and is
  not expected to have 3rdparty users other than xfs itself.
- commit 525b906
* Fri Jun  9 2017 nborisov@suse.com
- Remove patches causing regression (bsc#1043234)
- Delete
  patches.fixes/vfs-split-generic-splice-code-from-i_mutex-locking.patch.
- Delete
  patches.fixes/xfs-Fix-lock-ordering-in-splice-write.patch.
- Delete
  patches.fixes/xfs-Make-xfs_icdinode-di_dmstate-atomic_t.patch.
- Delete patches.fixes/xfs-kill-xfs_itruncate_start.patch.
- Delete
  patches.fixes/xfs-remove-the-i_new_size-field-in-struct-xfs_inode.patch.
- Delete
  patches.fixes/xfs-remove-the-i_size-field-in-struct-xfs_inode.patch.
- Delete patches.fixes/xfs-remove-xfs_itruncate_data.patch.
- Delete patches.fixes/xfs-split-xfs_itruncate_finish.patch.
- Delete patches.fixes/xfs-split-xfs_setattr.patch.
- Delete patches.kabi/kABI-mask-struct-xfs_icdinode-change.patch.
- commit 9691f2f
* Wed Jun  7 2017 mhocko@suse.cz
- mm: enlarge stack guard gap (bnc#1039348, CVE-2017-1000364,
  bnc#1042921).
- commit 10cc9f2
* Wed Jun  7 2017 vbabka@suse.cz
- mm/huge_memory: replace VM_NO_THP VM_BUG_ON with actual VMA
  check (VM Functionality, bsc#1042832).
- mm: hugetlb: call huge_pte_alloc() only if ptep is null (VM
  Functionality, bsc#1042832).
- commit 06d434a
* Wed Jun  7 2017 neilb@suse.com
- Refresh patches.fixes/nfs-sock-timeout.fix.
  Add git-commit headers for proper git-fixes tracking.
- commit 968b712
* Wed Jun  7 2017 mcgrof@suse.com
- module: fix memory leak on early load_module() failures
  (bsc#1043014).
- commit 2b55a93
* Tue Jun  6 2017 mkubecek@suse.cz
- ipv6: fix out of bound writes in __ip6_append_data()
  (CVE-2017-9242 bsc#1041431).
- commit a7dafef
* Mon Jun  5 2017 msuchanek@suse.de
- Remove superfluous make flags (bsc#1012422)
- commit 5a4004e
* Mon Jun  5 2017 mhocko@suse.cz
- blacklist.conf: ignore 914a051654c5 ("mm: nobootmem: move the comment of
  free_all_bootmem")
- commit 251ac04
* Mon Jun  5 2017 mhocko@suse.cz
- blacklist.conf: ignore 735f2770a770 ("kernel/fork: fix
  CLONE_CHILD_CLEARTID regression in nscd")
- commit 7fbcb83
* Mon Jun  5 2017 mhocko@suse.cz
- tracing: Fix syscall_*regfunc() vs copy_process() race
  (bnc#1042687).
- commit 2b180c1
* Mon Jun  5 2017 mhocko@suse.cz
- blacklist.conf: ignore 1195d94e006b ("ipc: always handle a new value of
  auto_msgmni")
- commit e870ffb
* Mon Jun  5 2017 mhocko@suse.cz
- blacklist.conf: ignore 2ad654bc5e2b ("cpuset: PF_SPREAD_PAGE and
  PF_SPREAD_SLAB should be atomic flags")
- commit ca23d40
* Mon Jun  5 2017 mhocko@suse.cz
- __bitmap_parselist: fix bug in empty string handling
  (bnc#1042633).
- commit de3b20a
* Mon Jun  5 2017 msuchanek@suse.de
- kernel-binary.spec: Propagate MAKE_ARGS to %%build (bsc#1012422)
- commit 030895a
* Thu Jun  1 2017 nborisov@suse.com
- xfs: use ->b_state to fix buffer I/O accounting release  race
  (bsc#1041160).
- xfs: Synchronize xfs_buf disposal routines (bsc#1041160).
- commit f66aa37
* Thu Jun  1 2017 mgalbraith@suse.de
- sched/cputime: Do not scale when utime == 0 (bnc#938352).
- sched: Use swap() macro in scale_stime() (bnc#938352).
- Revert "math64: New div64_u64_rem helper" (bnc#938352).
- sched: Avoid prev->stime underflow (bnc#938352).
- sched: Do not account bogus utime (bnc#938352).
- sched: Avoid cputime scaling overflow (bnc#938352).
- sched: Lower chances of cputime scaling overflow (bnc#938352).
- math64: New div64_u64_rem helper (bnc#938352).
- cputime: Avoid multiplication overflow on utime scaling
  (bnc#938352).
- commit 4b24014
* Thu Jun  1 2017 glin@suse.com
- blacklist.conf: add the unsupported freescale ethernet cards
- commit cc771dd
* Thu Jun  1 2017 ghe@suse.com
- ocfs2: NFS hangs in __ocfs2_cluster_lock due to race with
  ocfs2_unblock_lock (bsc#962257).
- commit ca19510
* Thu Jun  1 2017 lduncan@suse.com
- fixed invalid assignment of 64bit mask to host dma_boundary
  for scatter gather segment boundary limit (bsc#1042045).
- commit d8cca6f
* Wed May 31 2017 mhocko@suse.cz
- Update patches.fixes/0001-mm-enlarge-stack-guard-gap.patch
  (bnc#1039348, CVE-2017-1000364).
- Update
  patches.fixes/0002-mm-do-not-collapse-stack-gap-into-THP.patch
  (bnc#1039348, CVE-2017-1000364).
- commit c7dccb0
* Tue May 30 2017 hare@suse.de
- libfc: fixup locking in fc_disc_stop() (bsc#1029140).
- libfc: only restart discovery after timeout if not already
  running (bsc#1029140).
- libfc: move 'pending' and 'requested' setting (bsc#1029140).
- commit aab6fa4
* Tue May 30 2017 oneukum@suse.com
- fbdev/efifb: Fix 16 color palette entry calculation
  (bsc#1041762).
- commit e7d7f6a
* Tue May 30 2017 tbogendoerfer@suse.de
- net/mlx4_en: Wake TX queues only when there's enough room
  (bsc#1039258).
- commit a75a05a
* Mon May 29 2017 bp@suse.de
- EDAC, amd64_edac: Shift wrapping issue in
  f1x_get_norm_dct_addr() (fate#313937).
- commit 76a1ab3
* Mon May 29 2017 msuchanek@suse.de
- blacklist crypto/talitos and crypto/s5p-sss which we do not build
- commit 3a5cfcd
* Mon May 29 2017 jack@suse.cz
- blacklist.conf: Add commit f479447ad94879299b08b3f0b40f481baaff7eb7
- commit abfee81
* Mon May 29 2017 jack@suse.cz
- fuse: add missing FR_FORCE (bsc#1013018).
- Update headers
  patches.fixes/0001-block_dev-don-t-test-bdev-bd_contains-when-it-is-not.patch.
- commit cf71a8d
* Fri May 26 2017 bp@suse.de
- char: lp: fix possible integer overflow in lp_setup()
  (bsc#1039456, CVE-2017-1000363).
- commit 26004a0
* Fri May 26 2017 neilb@suse.com
- md: use separate bio_pool for metadata writes (bsc#1040351).
- commit ed956f3
* Thu May 25 2017 mkubecek@suse.cz
- ipv6/dccp: do not inherit ipv6_mc_list from parent
  (CVE-2017-9076 CVE-2017-9077 bsc#1039885 bsc#1040069).
- commit 6564c9d
* Thu May 25 2017 mkubecek@suse.cz
- sctp: do not inherit ipv6_{mc|ac|fl}_list from parent
  (CVE-2017-9075 bsc#1039883).
- commit 9c4bdb4
* Thu May 25 2017 mkubecek@suse.cz
- ipv6: Check ip6_find_1stfragopt() return value properly
  (CVE-2017-9074 bsc#1039882).
- ipv6: Prevent overrun when parsing v6 header options
  (CVE-2017-9074 bsc#1039882).
- commit 4ce26ac
* Thu May 25 2017 mkubecek@suse.cz
- ipx: call ipxitf_put() in ioctl error path (CVE-2017-7487
  bsc#1038879).
- commit 65da9cc
* Thu May 25 2017 mkubecek@suse.cz
- dccp/tcp: do not inherit mc_list from parent (CVE-2017-8890
  bsc#1038544).
- commit 5c98637
* Wed May 24 2017 dchang@suse.com
- netxen_nic: set rcode to the return status from the call to
  netxen_issue_cmd (bnc#784815 FATE#313898).
- commit 2d1efc2
* Wed May 24 2017 neilb@suse.com
- NFS: Fix another OPEN_DOWNGRADE bug (git-next).
- commit 03f4216
* Tue May 23 2017 mhocko@suse.cz
- mm: enlarge stack guard gap (bnc#1039348).
- mm: do not collapse stack gap into THP (bnc#1039348)
- Refresh
  patches.fixes/mm-avoid-setting-up-anonymous-pages-into-file-mappin.patch.
- commit e0077f4
* Tue May 23 2017 oneukum@suse.com
- 8250: use callbacks to access UART_DLL/UART_DLM.
- commit 84abb30
* Tue May 23 2017 oneukum@suse.com
- blacklist.conf: fix improves only debugging
- commit e5d9dfd
* Tue May 23 2017 oneukum@suse.com
- blacklist.conf: cleanup only
  removes dead code, no functional change
- commit 6174479
* Tue May 23 2017 aaptel@suse.com
- CIFS: backport prepath matching fix (bsc#799133).
- commit b9c892a
* Tue May 23 2017 mgalbraith@suse.de
- perf/core: Fix event inheritance on fork() (bnc#1013018).
- commit 77c2781
* Tue May 23 2017 mgalbraith@suse.de
- tracing/kprobes: Enforce kprobes teardown after testing (bnc#1013018).
- commit 9b23edb
* Fri May 19 2017 jjolly@suse.de
- initial cr0 bits (bnc#1036056, LTC#153612).
- commit 8f2a0e8
* Fri May 19 2017 duwe@suse.de
- powerpc/mm: Don't alias user region to other regions below
  PAGE_OFFSET (bsc#928138,fate#319026).
- crypto: nx - off by one bug in nx_of_update_msc()
  (fate#314588,bnc#792863).
- blacklist.conf: mark unsupprted ppc hardware variants
- Refresh patches.suse/ppc64-bigmem-introduce-CONFIG_BIGMEM.
- commit e1e4917
* Fri May 19 2017 duwe@suse.de
- hand over patch to proper maintainer, for follow-up fixes
- commit 92fe115
* Thu May 18 2017 neilb@suse.com
- NFSv4: Fix another bug in the close/open_downgrade code
  (git-fixes).
- commit e31305a
* Wed May 17 2017 neilb@suse.com
- blacklist.conf:
  updates
- commit 7a6e472
* Wed May 17 2017 neilb@suse.com
- jhash: Update jhash_[321]words functions to use correct initval
  (git-fixes).
- fs/block_dev: always invalidate cleancache in invalidate_bdev()
  (git-fixes).
- fs: fix data invalidation in the cleancache during direct IO
  (git-fixes).
- commit fc689b8
* Wed May 17 2017 neilb@suse.com
- NFS: Fix size of NFSACL SETACL operations (git-fixes).
- NFSv4: Fix problems with close in the presence of a delegation
  (git-fixes).
- SUNRPC: Fix a memory leak in the backchannel code (git-fixes).
- NFSv4: Don't call put_rpccred() under the rcu_read_lock()
  (git-fixes).
- nfs: fix nfs_size_to_loff_t (git-fixes).
- sunrpc: Update RPCBIND_MAXNETIDLEN (git-fixes).
- commit 552eb69
* Wed May 17 2017 neilb@suse.com
- md: flush ->event_work before stopping array (git-fixes).
- md: make sure GET_ARRAY_INFO ioctl reports correct "clean"
  status (git-fixes).
- md: ensure md devices are freed before module is unloaded
  (git-fixes).
- md/raid5: Fix CPU hotplug callback registration (git-fixes).
- md/raid5: don't record new size if resize_stripes fails
  (git-fixes).
- md/raid1: extend spinlock to protect raid1_end_read_request
  against inconsistencies (git-fixes).
- md/raid1: fix test for 'was read error from last working device'
  (git-fixes).
- md/raid0: apply base queue limits *before* disk_stack_limits
  (git-fixes).
- md/raid0: update queue parameter in a safer location
  (git-fixes).
- commit 2026184
* Wed May 17 2017 glin@suse.com
- blacklist.conf: add a5af83925363
  a5af83925363eb85d467933e3d6ec5a87001eb7c only fixes the gcc7 warning.
  Besides, it depends on the new API, ktime_get_real_seconds().
- commit dd62d1a
* Wed May 17 2017 lma@suse.com
- KVM: kvm_io_bus_unregister_dev() should never fail.
- commit 96234ae
* Tue May 16 2017 mgalbraith@suse.de
- Move nr_cpus_allowed into a hole in struct_sched_entity instead of
  the one below task_struct.policy.  RT fills the hole 29baa7478ba4
  used, which will screw up kABI for RT instead of curing the space
  needed problem in sched_rt_entity caused by adding ff77e4685359.
  This leaves nr_cpus_alowed in an odd spot, but safely allows the
  RT entity specific data added by ff77e4685359 to reside where it
  belongs.. nr_cpus_allowed just moves from one odd spot to another.
- commit 3c368b0
* Tue May 16 2017 jbeulich@suse.com
- patches.xen/xen3-irq_per_pci_device_msi_irq_listing-fix.patch:
  Fold back into base patch.
- commit 935bf02
* Tue May 16 2017 jbeulich@suse.com
- Xen/PCI-MSI: fix sysfs teardown in DomU (bsc#986924).
- Refresh
  patches.xen/xen3-PCI-Cache-MSI-MSI-X-capability-offsets-in-struct-pci.patch.
- commit efa5687
* Tue May 16 2017 mgalbraith@suse.de
- locking/rtmutex: Prevent dequeue vs. unlock race (bnc#1013018).
- commit 14bf6a2
* Tue May 16 2017 mgalbraith@suse.de
- sched/fair: Fix min_vruntime tracking (bnc#1013018).
- commit eddea2b
* Tue May 16 2017 mgalbraith@suse.de
- sched/rt: Fix PI handling vs. sched_setscheduler() (bnc#1013018).
  Prep for b60205c7c558 sched/fair: Fix min_vruntime tracking
- commit d0376e2
* Tue May 16 2017 mgalbraith@suse.de
- sched: Move nr_cpus_allowed out of 'struct sched_rt_entity' (bnc#1013018).
  Prep for b60205c7c558 sched/fair: Fix min_vruntime tracking
- commit 8bb8b92
* Wed May 10 2017 lduncan@suse.com
- PCI: Allow access to VPD attributes with size 0 (bsc#1018074).
- commit d86d7ba
* Mon May  8 2017 oneukum@suse.com
- blacklist.conf: we don't support USB PHYs.
- commit b75c01e
* Mon May  8 2017 jlee@suse.com
- keys: Guard against null match function in keyring_search_aux()
  (bsc#1030593, CVE-2017-2647, CVE-2017-6951).
- commit 96bbcac
* Fri May  5 2017 hare@suse.de
- fnic: Return 'DID_IMM_RETRY' if rport is not ready
  (bsc#1035920).
- scsi: fnic: Correcting rport check location in
  fnic_queuecommand_lck (bsc#1035920).
- fnic: Using rport->dd_data to check rport online instead of
  rport_lookup (bsc#1035920).
- fnic: Return 'DID_IMM_RETRY' if rport is not ready
  (bsc#1035920).
- scsi: fnic: Correcting rport check location in
  fnic_queuecommand_lck (bsc#1035920).
- fnic: Using rport->dd_data to check rport online instead of
  rport_lookup (bsc#1035920).
- commit 3bfff31
* Fri May  5 2017 mmarek@suse.com
- firmware: fix directory creation rule matching with make 3.80
  (bsc#1012422).
- firmware: fix directory creation rule matching with make 3.82
  (bsc#1012422).
- commit ff84a46
* Thu May  4 2017 jlee@suse.com
- acpi: Disable APEI error injection if securelevel is set
  (bsc#972891, bsc#1023051).
- commit 5a10a4e
* Thu May  4 2017 oneukum@suse.com
- blacklist.conf: we don't do gadgets. Exterminate
- commit fe2f089
* Thu May  4 2017 oneukum@suse.com
- USB: serial: ftdi_sio: fix line-status over-reporting
  (bsc#1037441).
- USB: serial: sierra: fix bogus alternate-setting assumption
  (bsc#1037441).
- commit 62ede2c
* Thu May  4 2017 jlee@suse.com
- KEYS: Disallow keyrings beginning with '.' to be joined as
  session keyrings (bnc#1035576).
- commit c848273
* Wed May  3 2017 oneukum@suse.com
- USB: serial: mos7840: fix another NULL-deref at open
  (bsc#1034026).
- USB: iowarrior: fix NULL-deref in write (bsc#1037359).
- net: wimax/i2400m: fix NULL-deref at probe (bsc#1037358).
- isdn/gigaset: fix NULL-deref at probe (bsc#1037356).
- uwb: hwa-rc: fix NULL-deref at probe (bsc#1037233).
- Input: hanwang - validate number of endpoints before using them
  (bsc#1037232).
- Input: yealink - validate number of endpoints before using them
  (bsc#1037227).
- Input: cm109 - validate number of endpoints before using them
  (bsc#1037193).
- commit e5fd01c
* Wed May  3 2017 oneukum@suse.com
- mmc: ushc: fix NULL-deref at probe (bsc#1037191).
- commit c742b4d
* Tue May  2 2017 msuchanek@suse.de
- Use make --output-sync feature when available (bsc#1012422).
  The mesages in make output can interleave making it impossible to
  extract warnings reliably. Since version 4 GNU Make supports
  - -output-sync flag that prints output of each sub-command atomically
  preventing this issue. Detect the flag and use it if available.
  SLE11 has make 3.81 so it is required to include make 4 in the kernel
  OBS projects to take advantege of this.
- commit 465f6ea
* Fri Apr 28 2017 mkubecek@suse.cz
- xfrm: dst_entries_init() per-net dst_ops (bsc#1030814).
- commit 968c5b1
* Fri Apr 28 2017 mkubecek@suse.cz
- series.conf: move general networking patches to the right place
  no change on expanded tree
- commit 89d041b
* Fri Apr 28 2017 neilb@suse.com
- Add CVE tag to references
- commit a01f43e
* Fri Apr 28 2017 neilb@suse.com
- nfsd: stricter decoding of write-like NFSv2/v3 ops
  (bsc#1034670).
- nfsd4: minor NFSv2/v3 write decoding cleanup (bsc#1034670).
- nfsd: check for oversized NFSv2/v3 arguments (bsc#1034670).
- commit f8ce5e0
* Thu Apr 27 2017 oneukum@suse.com
- uwb: i1480-dfu: fix NULL-deref at probe (bsc#1036629).
- commit 2700a3e
* Wed Apr 26 2017 oneukum@suse.com
- USB: usbtmc: fix probe error path (bsc#1036288).
- USB: usbtmc: add missing endpoint sanity check (bsc#1036288).
- usb: class: usbtmc: don't print on ENOMEM (bsc#1036288).
- usb: class: usbtmc: don't print error when allocating urb fails
  (bsc#1036288).
- Implement an ioctl to support the USMTMC-USB488 READ_STATUS_BYTE
  operation (bsc#1036288).
- USB: usbtmc: add device quirk for Rigol DS6104 (bsc#1036288).
- usb: class: usbtmc.c: Cleaning up uninitialized variables
  (bsc#1036288).
- USB: usbtmc: fix DMA on stack (bsc#1036288).
- USB: usbtmc: fix big-endian probe of Rigol devices
  (bsc#1036288).
- usbtmc: remove redundant braces (bsc#1036288).
- usbtmc: remove trailing spaces (bsc#1036288).
- USB: usbtmc: Change magic number to constant (bsc#1036288).
- USB: usbtmc: usbtmc_read sends multiple TMC header based on
  rigol_quirk (bsc#1036288).
- USB: usbtmc: Set rigol_quirk if device is listed (bsc#1036288).
- USB: usbtmc: TMC request code segregated from usbtmc_read
  (bsc#1036288).
- USB: usbtmc: Add flag rigol_quirk to usbtmc_device_data
  (bsc#1036288).
- commit 0d5c3e4
* Mon Apr 24 2017 msuchanek@suse.de
- powerpc/pci/rpadlpar: Fix device reference leaks (bsc#1035777
  [2017-04-24] Pending Base Kernel Fixes).
- commit 36ff3ee
* Mon Apr 24 2017 msuchanek@suse.de
- powerpc/ibmebus: Fix further device reference leaks (bsc#1035777
  [2017-04-24] Pending Base Kernel Fixes).
- commit 4cbb5e9
* Mon Apr 24 2017 msuchanek@suse.de
- powerpc/ibmebus: Fix device reference leaks in sysfs interface
  (bsc#1035777 [2017-04-24] Pending Base Kernel Fixes).
- commit 4b2ab0f
* Mon Apr 24 2017 msuchanek@suse.de
- blacklist.conf: blacklist Debian packaging script.
  blacklist 844e3be47693 powerpc/bpf/jit: Disable classic BPF JIT on ppc64le
  blacklist f775ff7d89f3 ceph: fix file open flags on ppc64
- commit 64d2b6f
* Wed Apr 19 2017 dchang@suse.com
- sfc: do not device_attach if a reset is pending (bsc#909618
  FATE#317521).
- commit 97f49dd
* Tue Apr 18 2017 neilb@suse.com
- Revert "lockd: use rpc client's cl_nodename for id encoding"
  This reverts commit 9002b12b6968eae13a3b0b26c5802dda13276179.
  Despite being marked for -stable, this patch doesn't actually
  do anything useful.  It just moves a call from one place to
  another nearby place where it will have the same problem.
  Future patch will actually fix the problem.
- commit b5bf495
* Tue Apr 18 2017 alnovak@suse.cz
- vmxnet3: segCnt can be 1 for LRO packets (bsc#988065,
  bsc#1029770).
- commit 4712c6b
* Tue Apr 18 2017 neilb@suse.com
- lockd: use init_utsname for id encoding
  (bsc#1033804).
- lockd: use rpc client's cl_nodename for id encoding
  (bsc#1033804).
- commit ce95309
* Fri Apr 14 2017 tabraham@suse.com
- [SCSI] virtio_scsi: fix memory leak on full queue condition
  (bsc#1028880).
- commit 6fb4d18
* Thu Apr 13 2017 oneukum@suse.com
- USB: serial: mos7840: fix NULL-deref at open (bsc#1034026).
- commit b6d89df
* Thu Apr 13 2017 oneukum@suse.com
- blacklist.conf: this just changes comment not even in kernel doc
- commit 99c2474
* Thu Apr 13 2017 jack@suse.cz
- ext4: reject inodes with negative size (bsc#1013018).
- commit edd8c09
* Thu Apr 13 2017 jack@suse.cz
- ext4: fix stack memory corruption with 64k block size
  (bsc#1013018).
- commit 37fc8e2
* Thu Apr 13 2017 jack@suse.cz
- ext4: fix mballoc breakage with 64k block size (bsc#1013018).
- commit 500d4ea
* Thu Apr 13 2017 jack@suse.cz
- fuse: initialize fc->release before calling it (bsc#1013018).
- commit cc01ca7
* Thu Apr 13 2017 jack@suse.cz
- ocfs2: do not write error flag to user structure we cannot
  copy from/to (bsc#1013018).
- ocfs2: fix error return code in ocfs2_info_handle_freefrag()
  (bsc#1013018).
- ocfs2: null deref on allocation error (bsc#1013018).
- commit e721bf4
* Wed Apr 12 2017 oneukum@suse.com
- USB: serial: mos7720: fix parallel probe (bsc#1033816).
- USB: serial: mos7720: fix parport use-after-free on probe errors
  (bsc#1033816).
- USB: serial: mos7720: fix use-after-free on probe errors
  (bsc#1033816).
- USB: serial: mos7720: fix NULL-deref at open (bsc#1033816).
- commit 999b272
* Wed Apr 12 2017 oneukum@suse.com
- USB: serial: iuu_phoenix: fix NULL-deref at open (bsc#1033794).
- commit a089b19
* Wed Apr 12 2017 oneukum@suse.com
- blacklist.conf: USB gadget only commit blacklisted, as the code is not included
- commit f350116
* Wed Apr 12 2017 oneukum@suse.com
- Refresh
  patches.drivers/0002-USB-serial-io_edgeport-fix-memory-leaks-in-probe-err.patch.
  Corrected copy and paster error of git ID
- commit da9808f
* Wed Apr 12 2017 oneukum@suse.com
- blacklist.conf: this fix changes things in sysfs
- commit 59e9432
* Wed Apr 12 2017 oneukum@suse.com
- USB: cdc-acm: fix runtime PM imbalance at shutdown
  (bsc#1033771).
- USB: cdc-acm: fix open and suspend race (bsc#1033771).
- USB: cdc-acm: fix potential urb leak and PM imbalance in write
  (bsc#1033771).
- USB: cdc-acm: fix shutdown and suspend race (bsc#1033771).
- USB: cdc-acm: fix runtime PM for control messages (bsc#1033771).
- USB: cdc-acm: fix broken runtime suspend (bsc#1033771).
- commit 99f7db5
* Wed Apr 12 2017 oneukum@suse.com
- USB: cdc-acm: fix write and resume race (bsc#1033771).
- commit 7bad5bf
* Wed Apr 12 2017 oneukum@suse.com
- USB: cdc-acm: fix write and suspend race (bsc#1033771).
- commit 34c18e3
* Wed Apr 12 2017 oneukum@suse.com
- blacklist.conf: fix for CDC-ACM not applicable because the part of TTY layer
  hasn't been added yet
- commit 295f7f1
* Tue Apr 11 2017 msuchanek@suse.de
- powerpc/fadump: Update fadump documentation (bsc#1032141).
- commit dc80e81
* Tue Apr 11 2017 msuchanek@suse.de
- powerpc/fadump: Reserve memory at an offset closer to bottom
  of RAM (bsc#1032141).
- commit 43cf480
* Tue Apr 11 2017 mkubecek@suse.cz
- net: socket: fix recvmmsg not returning error from sock_error
  (CVE-2016-7117 bsc#1003077).
- commit ce09a25
* Tue Apr 11 2017 mkubecek@suse.cz
- netfilter: arp_tables: fix invoking 32bit "iptable -P INPUT
  ACCEPT" failed in 64bit kernel (CVE-2016-4997 CVE-2016-4998
  bsc#986362 bsc#986365).
- commit 55ae27f
* Tue Apr 11 2017 mkubecek@suse.cz
- net/packet: fix overflow in check for tp_reserve (CVE-2017-7308
  bsc#1031579).
- net/packet: fix overflow in check for tp_frame_nr (CVE-2017-7308
  bsc#1031579).
- commit 540195f
* Tue Apr 11 2017 mkubecek@suse.cz
- ping: implement proper locking (CVE-2017-2671 bsc#1031003).
- commit 2256220
* Tue Apr 11 2017 mkubecek@suse.cz
- xfrm_user: validate XFRM_MSG_NEWAE incoming ESN size harder
  (CVE-2017-7184 bsc#1030573).
- xfrm_user: validate XFRM_MSG_NEWAE XFRMA_REPLAY_ESN_VAL
  replay_window (CVE-2017-7184 bsc#1030573).
- commit cce1525
* Tue Apr 11 2017 mkubecek@suse.cz
- ipv4: keep skb->dst around in presence of IP options
  (CVE-2017-5970 bsc#1024938).
- commit 8ea30e3
* Tue Apr 11 2017 mhocko@suse.cz
- mm/mempolicy.c: fix error handling in set_mempolicy and mbind
  (bnc#1033336, CVE-2017-7616).
- commit aa86d76
* Tue Apr 11 2017 jjolly@suse.de
- s390/zcrypt: Introduce CEX6 toleration (FATE#321782,
  LTC#147505).
- commit 30ed730
* Mon Apr 10 2017 mgalbraith@suse.de
- Blacklist e9532e69b8d1d1284e8ecf8d2586de34aec61244
  IRQ_TIME_ACCOUNTING is disabled, PARAVIRT_TIME_ACCOUNTING nonesistent.
- commit e4be84e
* Mon Apr 10 2017 mgalbraith@suse.de
- sched/core: Fix TASK_DEAD race in finish_task_switch() (bnc#1013018).
- commit 3d8ec3f
* Mon Apr 10 2017 mgalbraith@suse.de
- posix-timers: Fix stack info leak in timer_create() (bnc#1013018).
- commit de08b36
* Mon Apr 10 2017 mgalbraith@suse.de
- clocksource: Remove "weak" from clocksource_default_clock() declaration (bnc#1013018).
- commit 4408fb6
* Mon Apr 10 2017 mgalbraith@suse.de
- sched/loadavg: Fix loadavg artifacts on fully idle and on fully loaded systems (bnc#1013018).
- commit eee00be
* Thu Apr  6 2017 jkosina@suse.cz
- Refresh
  patches.drivers/drm-vmwgfx-fix-integer-overflow-in-vmw_surface_define_ioctl.patch: fix
  potential build breakage due to wrong merge conflict resolution (we're not
  building the code though).
- commit 12b2e9e
* Tue Apr  4 2017 oneukum@suse.com
- USB: iowarrior: fix NULL-deref at probe (References: bnc#970956,
  CVE-2016-2188).
- commit 500e8a0
* Tue Apr  4 2017 oneukum@suse.com
- usb: hub: Fix crash after failure to read BOS descriptor
  (FATE#317453).
- commit 967c325
* Mon Apr  3 2017 mstaudt@suse.de
- drm/vmwgfx: fix integer overflow in vmw_surface_define_ioctl()
  (boo#1031440 CVE-2017-7294).
- drm/vmwgfx: NULL pointer dereference in
  vmw_surface_define_ioctl() (boo#1031052 CVE-2017-7261).
- commit 13faa5c
* Mon Apr  3 2017 mhocko@suse.cz
- blacklist.conf: fix the blacklist for 415e3d3e90ce
  We should always blacklist the follow up fix not the original one
  that is mentioned in Fixes: tag.
- commit 5060eef
* Mon Apr  3 2017 jthumshirn@suse.de
- scsi: sg: check length passed to SG_NEXT_CMD_LEN (bsc#1030213,
  CVE-2017-7187).
- commit fca3ea0
* Fri Mar 31 2017 neilb@suse.com
- NFSD: don't risk using duplicate owner/file/delegation ids
  (bsc#1029212).
- commit d862c22
* Thu Mar 30 2017 nborisov@suse.com
- Refresh
  patches.fixes/vfs-split-generic-splice-code-from-i_mutex-locking.patch.
  Remove unused inode var in splice_write_to_file
- commit 1ec8367
* Wed Mar 29 2017 nborisov@suse.com
- kabi: Protect xfs_mount and xfs_buftarg (bsc#1024508).
- commit a4cb7ea
* Wed Mar 29 2017 nborisov@suse.com
- xfs: don't assert fail on non-async buffers on ioacct  decrement
  (bsc#1024508).
- xfs: track and serialize in-flight async buffers against
  unmount (bsc#1024508).
- xfs: exclude never-released buffers from buftarg I/O  accounting
  (bsc#1024508).
- xfs: replace global xfslogd wq with per-mount wq (bsc#1024508).
- commit ddcfa22
* Fri Mar 24 2017 bp@suse.de
- irda: Fix lockdep annotations in hashbin_delete() (bsc#1027178,
  CVE-2017-6348).
- commit 60ea1ef
* Thu Mar 23 2017 dbueso@suse.de
- ipc/shm: Fix shmat mmap nil-page protection (CVE-2017-5669
  bsc#1026914).
- commit 241aea3
* Thu Mar 23 2017 neilb@suse.com
- Use PF_LESS_THROTTLE in loop device thread (bsc#1027101).
- commit b49d682
* Wed Mar 22 2017 oneukum@suse.com
- USB: serial: kl5kusb105: fix line-state error handling
  (bsc#1021256).
- commit 5ac8c3f
* Wed Mar 22 2017 nborisov@suse.com
- kABI: mask struct xfs_icdinode change (bsc#1024788).
- xfs: Fix lock ordering in splice write (bsc#1024788).
- xfs: Make xfs_icdinode->di_dmstate atomic_t (bsc#1024788).
- vfs: split generic splice code from i_mutex locking
  (bsc#1024788).
- xfs: remove the i_new_size field in struct xfs_inode
  (bsc#1024788).
- commit 9eb8edc
* Wed Mar 22 2017 nborisov@suse.com
- xfs: remove the i_size field in struct xfs_inode (bsc#1024788).
- xfs: remove xfs_itruncate_data (bsc#1024788).
- xfs: split xfs_itruncate_finish (bsc#1024788).
- xfs: kill xfs_itruncate_start (bsc#1024788).
- xfs: split xfs_setattr (bsc#1024788).
- commit bbb8ced
* Tue Mar 21 2017 mhocko@suse.cz
- mm: avoid setting up anonymous pages into file mapping
  (bnc#979021, CVE-2015-3288).
- commit e2dcea8
* Tue Mar 21 2017 jkosina@suse.cz
- series.conf: remove duplicated patch entry
- commit 0d4c6cb
* Fri Mar 17 2017 jjolly@suse.de
- s390/vmlogrdr: fix IUCV buffer allocation (bnc#1025702,
  LTC#152144).
- s390/kmsg: add missing kmsg descriptions (bnc#1025702,
  LTC#151573).
- scsi: zfcp: fix use-after-free by not tracing WKA port
  open/close on failed send (bnc#1025702, LTC#151365).
- scsi: zfcp: fix rport unblock race with LUN recovery
  (bnc#1025702, LTC#151319).
- scsi: zfcp: do not trace pure benign residual HBA responses
  at default level (bnc#1025702, LTC#151317).
- scsi: zfcp: fix use-after-"free" in FC ingress path after TMF
  (bnc#1025702, LTC#151312).
- commit 88ca330
* Fri Mar 17 2017 nborisov@suse.com
- Revert "xfs: fix up xfs_swap_extent_forks inline extent handling (bsc#1023888)."
  I was baing my assumption of SLE11-SP4 needing this patch on an old kernel build
  (3.0.101-63). Re-testing with the latest one 3.0.101-94 shows that the issue
  is not present. Furthermore this one was causing some crashes.
  This reverts commit 16ceeac70f7286b6232861c3170ed32e39dcc68c.
- commit a3731fe
* Thu Mar 16 2017 mkubecek@suse.cz
- l2tp: fix l2tp_ip_bind() return value on SOCK_ZAPPED bailout
  (CVE-2016-10200 bsc#1028415).
- l2tp: fix racy SOCK_ZAPPED flag check in l2tp_ip{,6}_bind()
  (CVE-2016-10200 bsc#1028415).
- commit 953e9d9
* Fri Mar 10 2017 colyli@suse.de
- md/linear: shutup lockdep warnning (bsc#1018446).
- commit fda0e82
* Thu Mar  9 2017 jslaby@suse.cz
- patches.fixes/list-introduce-list_first_entry_or_null.patch:
  list: introduce list_first_entry_or_null (bnc#1027565
  CVE-2017-2636).
  Conflicts:
  patches.fixes/list-introduce-list_first_entry_or_null.patch
- patches.fixes/list-introduce-list_first_entry_or_null.patch:
  list: introduce list_first_entry_or_null (bnc#1027565
  CVE-2017-2636).
- commit 7418c75
* Thu Mar  9 2017 jslaby@suse.cz
- tty: n_hdlc: get rid of racy n_hdlc.tbuf (bnc#1027565
  CVE-2017-2636).
  Conflicts:
  series.conf
- tty: n_hdlc: get rid of racy n_hdlc.tbuf (bnc#1027565
  CVE-2017-2636).
- commit b708f71
* Wed Mar  8 2017 colyli@suse.de
- RAID1: avoid unnecessary spin locks in I/O barrier code
  (bsc#982783,bsc#1026260).
- Rename patches.fixes/0001-md-lockless-I-O-submission-for-RAID1.patch
  to patches.fixes/0001-RAID1-avoid-unnecessary-spin-locks-in-IO-barrier-code.patch
- commit 00b0501
* Fri Mar  3 2017 sndirsch@suse.de
- drm/mgag200: Add support for G200e rev 4 (bnc#995542, comment #81)
- commit 77ec727
* Fri Mar  3 2017 jbohac@suse.cz
- tipc: fix an infoleak in tipc_nl_compat_link_dump (bsc#983212,
  CVE-2016-5243).
- commit 7e3de58
* Fri Mar  3 2017 mkubecek@suse.cz
- sctp: deny peeloff operation on asocs with threads sleeping
  on it (CVE-2017-6353 bsc#1027066).
- commit a6a64f7
* Fri Mar  3 2017 mkubecek@suse.cz
- tcp: avoid infinite loop in tcp_splice_read() (CVE-2017-6214
  bsc#1026722).
- commit c78b1c1
* Wed Mar  1 2017 alnovak@suse.cz
- jbd: don't wait (forever) for stale tid caused by wraparound
  (bsc#1020229).
- commit b0dda2e
* Mon Feb 20 2017 mkubecek@suse.cz
- dccp: fix freeing skb too early for IPV6_RECVPKTINFO
  (CVE-2017-6074 bsc#1026024).
- commit 66bd6a5
* Thu Feb 16 2017 mkubecek@suse.cz
- sctp: avoid BUG_ON on sctp_wait_for_sndbuf (CVE-2017-5986
  bsc#1025235).
- commit b7b4ac8
* Tue Feb 14 2017 mcgrof@suse.com
- Refresh
  patches.fixes/xfs-fix-buffer-overflow-dm_get_dirattrs.patch.
- commit 76ed108
* Sat Feb 11 2017 mcgrof@suse.com
- xfs_dmapi: fix the debug compilation of xfs_dmapi (bsc#989056).
- commit c15d41a
* Sat Feb 11 2017 mcgrof@suse.com
- xfs: fix buffer overflow dm_get_dirattrs/dm_get_dirattrs2
  (bsc#989056).
- commit e741dd8
* Fri Feb 10 2017 jbeulich@suse.com
- xen-blkfront: correct maximum segment accounting (bsc#1018263).
- xen-blkfront: free resources if xlvbd_alloc_gendisk fails.
- xen-blkfront: don't call talk_to_blkback when already connected
  to blkback.
- commit 49c9fcf
* Fri Feb 10 2017 jbeulich@suse.com
- patches.xen/xen3-patch-2.6.35.patch: Fold back into base patch.
- commit 421ebb7
* Fri Feb 10 2017 jbeulich@suse.com
- pciback: use pci_physfn() (bsc#999245).
- pciback: only check PF if actually dealing with a VF
  (bsc#999245).
- commit 4b2291c
* Wed Feb  8 2017 ghe@suse.com
- ocfs2: fix crash caused by stale lvb with fsdlm plugin
  (bsc#1013800).
- commit 9a6f990
* Wed Feb  8 2017 nborisov@suse.com
- xfs: fix up xfs_swap_extent_forks inline extent handling (bsc#1023888).
- commit 16ceeac
* Wed Feb  8 2017 ghe@suse.com
- dlm: backport "fix lvb invalidation conditions" (bsc#1005651).
- commit b6666ee
* Wed Feb  8 2017 dchang@suse.com
- i40e: avoid null pointer dereference (bsc#909486 FATE#317393).
- commit 32ecb2b
* Wed Feb  8 2017 glin@suse.com
- enic: set skb->hash type properly (bsc#911105 FATE#317501).
- commit 7344be8
* Tue Feb  7 2017 mgalbraith@suse.de
- powerpc,cpuidle: Dont toggle CPUIDLE_FLAG_IGNORE while setting smt_snooze_delay (bsc#1023163).
- commit 0616ed2
* Sat Feb  4 2017 bpoirier@suse.com
- sfc: reduce severity of PIO buffer alloc failures (bsc#1019168).
- commit ac9fc31
* Thu Feb  2 2017 msuchanek@suse.de
- powerpc/fadump: Fix the race in crash_fadump() (bsc#1022971).
- commit 1086a85
* Thu Feb  2 2017 mgorman@suse.de
- mm/mempolicy.c: do not put mempolicy before using its nodemask
  (References: VM Performance, bnc#931620).
- commit a11cbe7
* Thu Feb  2 2017 neilb@suse.com
- kabi fix (bsc#1008893).
- rcu: Implement a variant of Peter's SRCU algorithm
  (bsc#1008893).
- commit 3f66204
* Wed Feb  1 2017 oneukum@suse.com
- usb: xhci-mem: use passed in GFP flags instead of GFP_KERNEL
  (bsc#1023014).
- commit c07a672
* Wed Feb  1 2017 jkosina@suse.cz
- Refresh
  patches.fixes/0001-md-linear-fix-a-race-between-linear_add-and-linear_c.patch: update
  references
- commit 00e4e08
* Tue Jan 31 2017 bpoirier@suse.com
- i40e: Impose a lower limit on gso size (bsc#985561).
- i40e: Limit TX descriptor count in cases where frag size is
  greater than 16K (bsc#985561).
- i40e/i40evf: Limit TSO to 7 descriptors for payload instead
  of 8 per packet (bsc#985561).
- i40e/i40evf: Rewrite logic for 8 descriptor per packet check
  (bsc#985561).
- i40e/i40evf: Break up xmit_descriptor_count from maybe_stop_tx
  (bsc#985561).
- i40e/i40evf: Fix mixed size frags and linearization
  (bsc#985561).
- i40e: Fix TSO with more than 8 frags per segment issue
  (bsc#985561).
- commit 6ac0094
* Mon Jan 30 2017 bp@suse.de
- blacklist.conf: c4597fd756836a5fb7900f2091797ab564390ad0
  To quote the commit message:
  "This code is over three years old so presumably the bug doesn't happen
  very frequently in real life or someone would have complained by now."
- commit ae80e74
* Mon Jan 30 2017 mhocko@suse.cz
- blacklist.conf: blacklist 712f4aad406bb1
- commit a8c1e92
* Sun Jan 29 2017 colyli@suse.de
- md linear: fix a race between linear_add() and
  linear_congested() (bsc#1018446).
- commit c856313
* Fri Jan 27 2017 bpoirier@suse.com
- tcp: abort orphan sockets stalling on zero window probes
  (bsc#1021913).
- commit cd3f29d
* Thu Jan 26 2017 mkubecek@suse.cz
- tcp: plug dst leak in tcp_v6_conn_request() (bsc#1010175).
- tcp: use inet6_csk_route_req() in tcp_v6_send_synack()
  (bsc#1010175).
- tcp: pass fl6 to inet6_csk_route_req() (bsc#1010175).
- tcp: fix inet6_csk_route_req() for link-local addresses
  (bsc#1010175).
- commit c499ea8
* Thu Jan 26 2017 mkubecek@suse.cz
- series.conf: move core networking patches to the right section
- commit e98760c
* Wed Jan 25 2017 duwe@suse.de
- crypto/lrw.c: protect gf128mul from NULL pointers (bsc#1008374,
  CVE-2015-8970).
- commit b885944
* Wed Jan 25 2017 neilb@suse.com
- rcu: Flip ->completed only once per SRCU grace period
  (bsc#1008893).
- rcu: Increment upper bit only for srcu_read_lock()
  (bsc#1008893).
- rcu: Remove fast check path from __synchronize_srcu()
  (bsc#1008893).
- rcu: Direct algorithmic SRCU implementation (bsc#1008893).
- commit e40d595
* Wed Jan 25 2017 neilb@suse.com
- rcu: Call out dangers of expedited RCU primitives (bsc#1008893).
- commit 77e4268
* Mon Jan 23 2017 jack@suse.cz
- tmpfs: clear S_ISGID when setting posix ACLs (bsc#1021258
  CVE-2017-5551).
- commit 389953d
* Mon Jan 23 2017 jkosina@suse.cz
- Revert "posix_acl: Clear SGID bit when setting file permissions"
  This reverts commit b64c9265c65c024606b69579b338799c824cc3a8.
  I am reverting the whole CVE-2016-7097 series of fix attempts, as
  the backport is seriously broken; the current state still contains
  unresolved mode_t vs umode_t ptr mismatch (leading to garbage being
  read from the stack), and despite the changelog referencing tmpfs
  specific fixup, I don't seem to be able to identify it in the series.
  A freshly done backport is going to be merged from Jan Kara through
  proper channel (cve-3.0 branch).
  Conflicts:
  series.conf
- commit 7222443
* Mon Jan 23 2017 jkosina@suse.cz
- Revert "Refresh patches.fixes/posix_acl-Clear-SGID-bit-when-setting-file-permissio.patch."
  This reverts commit 90ad8ac2f8bb9c5b61dfc51dda6aa925d3a056c8.
- commit acde2d9
* Mon Jan 23 2017 jkosina@suse.cz
- Revert "Update patches.fixes/posix_acl-Clear-SGID-bit-when-setting-file-permissio.patch"
  This reverts commit b23962975a769a4ea1a895f8ec2515ad0bb9641e.
- commit eacc75b
* Mon Jan 23 2017 jack@suse.cz
- posix_acl: Clear SGID bit when setting file permissions
  (CVE-2016-7097, bsc#995968).
- commit 7029ffc
* Mon Jan 23 2017 ghe@suse.com
- ocfs2: fix BUG_ON() in ocfs2_ci_checkpointed() (bnc#1019783).
- commit 8925c4b
* Thu Jan 19 2017 rgoldwyn@suse.com
- Update patches.fixes/posix_acl-Clear-SGID-bit-when-setting-file-permissio.patch
  (CVE-2016-7097, bsc#995968, bsc#1014454).
- commit b239629
* Wed Jan 18 2017 jthumshirn@suse.de
- scsi: lpfc: Set elsiocb contexts to NULL after freeing it
  (bsc#996557).
- commit d798d69
* Wed Jan 18 2017 dchang@suse.com
- bnx2x: Correct ringparam estimate when DOWN (bsc#1020214).
- commit 51cf0ff
* Wed Jan 18 2017 lidong.zhong@suse.com
- crypto: add ghash-generic in the supported.conf(bsc#1016824)
- commit 6bbb054
* Tue Jan 17 2017 jjolly@suse.de
- [BZ 149851] kernel: Fix invalid domain response handling
  (bsc#1016320,LTC149851).
- [BZ 149737] kernel: Fix hang condition on crypto card config-off
  (bsc#1016320,LTC149737).
- commit de1cea2
* Mon Jan 16 2017 msuchanek@suse.de
- Update metadata for serial fixes (bsc#1013070)
- commit 8221808
* Mon Jan 16 2017 sndirsch@suse.de
- series.conf: moved mga drm patch to the right place
  patches.drm/drm-mgag200-Add-support-for-a-new-G200eW3-chipset.patch
  has been at the wrong place.
- commit ed8654b
* Mon Jan 16 2017 jthumshirn@suse.de
- scsi: lpfc: avoid double free of resource identifiers
  (bsc#989896).
- commit e1ecfd0
* Fri Jan 13 2017 jeffm@suse.com
- reiserfs: fix race in prealloc discard (bsc#987576).
- commit 02284f9
* Wed Jan 11 2017 sndirsch@suse.de
- drm/mgag200: Added support for the new deviceID for G200eW3 (bnc#1019348)
- commit e74cee1
* Wed Jan 11 2017 msuchanek@suse.de
- ibmveth: calculate gso_segs for large packets (bsc#1019165,
  bsc#1019148).
- commit aef1666
* Wed Jan 11 2017 msuchanek@suse.de
- ibmveth: set correct gso_size and gso_type (bsc#1019165,
  bsc#1019148).
- commit f780a5b
* Wed Jan 11 2017 jthumshirn@suse.de
- NVMe: Automatic namespace rescan (bsc#1017686).
- NVMe: Metadata format support (bsc#1017686).
- commit 903fbc4
* Wed Jan 11 2017 neilb@suse.com
- dm: do not call dm_sync_table() when creating new devices
  (bnc#901809, bsc#1008893).
- commit 8514199
* Tue Jan 10 2017 jdelvare@suse.de
- crypto: aesni - Add support for 192 & 256 bit keys to AESNI
  RFC4106 (bsc#913387, #bsc1016831).
- commit 24d943b
* Tue Jan 10 2017 jthumshirn@suse.de
- sg_write()/bsg_write() is not fit to be called under KERNEL_DS
  (CVE-2016-10088 bsc#1017710).
- commit 6296f31
* Mon Jan  9 2017 hare@suse.de
- scsi_error: fixup crash in scsi_eh_reset (bsc#993832)
- commit 3079bbc
* Fri Jan  6 2017 ydfan@suse.com
- jbd: Fix oops in journal_remove_journal_head() (bsc#1017143).
- commit c2f5d38
* Thu Jan  5 2017 jbohac@suse.cz
- net: keep the non-ABI-breaking parts of CVE-2004-0230 fixes
  (bsc#969340, CVE-2004-0230).
  Does not apply to SLE11-SP3
- Update patches.kabi/0004-Revert-tcp-implement-RFC-5961-4.2.patch
- Update patches.kabi/0005-Revert-tcp-implement-RFC-5961-3.2.patch
- Delete
  patches.kabi/0001-Revert-tcp-RFC-5961-5.2-Blind-Data-Injection-Attack-.patch.
- Delete
  patches.kabi/0003-Revert-tcp-refine-SYN-handling-in-tcp_validate_incom.patch.
- commit db5164e
* Thu Jan  5 2017 neilb@suse.com
- Fix two issues with drop_caches and the sunrpc auth cache
  (bsc#1012917).
- commit fd87828
* Wed Jan  4 2017 jlee@suse.com
- mpi: Fix NULL ptr dereference in mpi_powm() [ver #3]
  (bsc#1011820).
- commit 9e055b2
* Wed Jan  4 2017 lma@suse.com
- KVM: x86: limit difference between kvmclock updates
  (bsc#989680).
- KVM: x86: Remove support for reporting coalesced APIC IRQs
  (bsc#989680).
- KVM: nVMX: Add preemption timer support (bsc#989680).
- kvm: Iterate over only vcpus that are preempted (bsc#989680).
- kvm: Record the preemption status of vcpus using preempt
  notifiers (bsc#989680).
- KVM: VMX: Pass vcpu to __vmx_complete_interrupts (bsc#989680).
- KVM: remove a wrong hack of delivery PIT intr to vcpu0
  (bsc#989680).
- KVM: Distangle eventfd code from irqchip (bsc#989680).
- KVM: make processes waiting on vcpu mutex killable (bsc#989680).
- KVM: use symbolic constant for nr interrupts (bsc#989680).
- KVM: fold kvm_pit_timer into kvm_kpit_state (bsc#989680).
- KVM: x86: Run PIT work in own kthread (bsc#989680).
- KVM: APIC: avoid instruction emulation for EOI writes
  (bsc#989680).
- commit 06c3611
* Wed Jan  4 2017 neilb@suse.com
- Refresh
  patches.kabi/0003-SUNRPC-Limit-the-reconnect-backoff-timer-to-the-max-KABI.patch.
  Move new value to a hole so that structure doesn't change size.
- commit bfeaea5
* Tue Jan  3 2017 mmarek@suse.cz
- Import kabi files from 3.0.101-91
  Also add ppc64/bigmem reference files.
- commit 36426f3
* Mon Jan  2 2017 jkosina@suse.cz
- Refresh
  patches.fixes/fuse-Propagate-dentry-down-to-inode_change_ok.patch:
  file_dentry() doesn't exist in SP4 yet, open-code it
  Refresh
  patches.fixes/xfs-fix-sgid-inheritance-for-subdirectories-inheriti.patch
  xfs_setattr() has to obtain VFS inode as it's no longer being passed to
  it. This fixes a buggy/incomplete merge conflict resolution in 0da6d89cd5
  ("Merge remote-tracking branch 'origin/cve/linux-3.0' into SLE11-SP4")
- commit 0b66f47
* Mon Jan  2 2017 jkosina@suse.cz
- Refresh
  patches.fixes/fuse-Propagate-dentry-down-to-inode_change_ok.patch:
  avoid using d_inode() helper and dereference dentry directly
- commit 0f625c3
* Mon Jan  2 2017 jkosina@suse.cz
- fuse: Propagate dentry down to inode_change_ok() (bsc#914939
  CVE-2015-1350).
  Refresh patches.fixes/fuse-Propagate-dentry-down-to-inode_change_ok.patch:
  fixup 'entry' -> 'dentry' in fuse_do_setattr()
- commit 9fea1fc
* Mon Jan  2 2017 jack@suse.cz
- ext3: Avoid premature failure of ext3_has_free_blocks()
  (bsc#1016668).
- commit 78ae3ed
* Mon Jan  2 2017 mkubecek@suse.cz
- tipc: check minimum bearer MTU (CVE-2016-8632 bsc#1008831).
- commit 54e17f0
* Mon Jan  2 2017 mkubecek@suse.cz
- series.conf: move networking fixes to the right place
- commit 18a206a
* Sat Dec 31 2016 bpoirier@suse.com
- blacklist.conf: Add c9cc599
  c9cc599 net/mlx4_core: Fix QUERY FUNC CAP flags (v4.9-rc1)
  Fixes:
  77fc29c net/mlx4_core: Preparations for 802.1ad VLAN support (v4.3-rc1)
  5cc914f mlx4_core: Added FW commands and their wrappers for supporting SRIOV (v3.3-rc1)
  Skipped, 77fc29c is not present and makes c9cc599
  inapplicable
- commit 9c4ed52
* Sat Dec 31 2016 bpoirier@suse.com
- net/mlx4_en: Fix potential deadlock in port statistics flow
  (bsc#786036 FATE#314304).
- net/mlx4_core: Do not access comm channel if it has not yet
  been initialized (bsc#924708 bsc#786036 FATE#314304).
- net/mlx4_core: Fix the resource-type enum in res tracker to
  conform to FW spec (bsc#786036 FATE#314304).
- IB/mlx4: Use correct subnet-prefix in QP1 mads under SR-IOV
  (bsc#786036 FATE#314304).
- IB/mlx4: Fix incorrect MC join state bit-masking on SR-IOV
  (bsc#786036 FATE#314304).
- net/mlx4_en: Move filters cleanup to a proper location
  (bsc#786036 FATE#314304).
- IB/mlx4: Fix memory leak if QP creation failed (bsc#786036
  FATE#314304).
- IB/mlx4: Fix error flow when sending mads under SRIOV
  (bsc#786036 FATE#314304).
- net/mlx4_en: fix spurious timestamping callbacks (bsc#919382
  FATE#317529).
- net/mlx4_core: Implement pci_resume callback (bsc#924708).
- mlx4: add missing braces in verify_qp_parameters (bsc#786036
  FATE#314304).
- net/mlx4_core: Allow resetting VF admin mac to zero (bsc#919382
  FATE#317529).
- net/mlx4_core: Do not BUG_ON during reset when PCI is offline
  (bsc#924708).
- net/mlx4_en: Choose time-stamping shift value according to HW
  frequency (bsc#919382 FATE#317529).
- net/mlx4_en: Fix HW timestamp init issue upon system startup
  (bsc#919382 FATE#317529).
- net/mlx4_en: Remove dependency between timestamping capability
  and service_task (bsc#919382 FATE#317529).
- net/mlx4_core: Avoid returning success in case of an error flow
  (bsc#786036 FATE#314304).
- net/mlx4: Copy/set only sizeof struct mlx4_eqe bytes (bsc#786036
  FATE#314304).
- IB/mlx4: Forbid using sysfs to change RoCE pkeys (bsc#786036
  FATE#314304).
- IB/mlx4: Fix potential deadlock when sending mad to wire
  (bsc#786036 FATE#314304).
- cpumask_set_cpu_local_first => cpumask_local_spread, lament
  (bug#919382 FATE#317529).
- net/mlx4_core: Fix error message deprecation for ConnectX-2
  cards (bug#919382 FATE#317529).
- net/mlx4_core: Update the HCA core clock frequency after
  INIT_PORT (bug#919382 FATE#317529).
- igb: Fix NULL assignment to incorrect variable in
  igb_reset_q_vector (bsc#795297 FATE#313656).
- commit aa0ab6c
* Fri Dec 30 2016 ptesarik@suse.cz
- kexec: add a kexec_crash_loaded() function (bsc#973691).
- commit 0cae4ed
* Thu Dec 22 2016 msuchanek@suse.de
- Fix scripts/bigmem-generate-ifdef-guard to work on all branches
- commit fe07acc
* Thu Dec 22 2016 jbohac@suse.cz
- net: ping: check minimum size on ICMP header length
  (bsc#1014746, CVE-2016-8399).
- commit c9e5f75
* Wed Dec 21 2016 oneukum@suse.com
- memstick: mspro_block: add missing curly braces (bsc#1016688).
- commit 73b469b
* Tue Dec 20 2016 jbohac@suse.cz
- printk/sched: Introduce special printk_sched() for those awkward
  (bsc#1013042, bsc#996541, bsc#1015878).
- commit e565cfb
* Tue Dec 20 2016 oneukum@suse.com
- blacklist.conf: we don't care about compilation without CONFIG_NET
- commit d9e78c2
* Tue Dec 20 2016 oneukum@suse.com
- blacklist.conf: fixes for the gadget code are not relevant for SP4
- commit 47572e0
* Tue Dec 20 2016 oneukum@suse.com
- blacklist.conf: gspca fix only relevant for compilation without CONFIG_INPUT
- commit 9857b2d
* Tue Dec 20 2016 oneukum@suse.com
- blacklist.conf: blacklist fix for usb: f_fs as gadget code is not used
- commit 661be46
* Tue Dec 20 2016 oneukum@suse.com
- USB: serial: keyspan: fix use-after-free in probe error path
  (bsc#1016520).
- commit d798a26
* Tue Dec 20 2016 oneukum@suse.com
- USB: serial: io_edgeport: fix memory leaks in probe error path
  (bsc#1016505).
- USB: serial: io_edgeport: fix memory leaks in attach error path
  (bsc#1016505).
- commit fd34774
* Tue Dec 20 2016 msuchanek@suse.de
- blacklist ppc fixes (bsc#1016489)
  arch/powerpc/platforms/powernv
  powerpc/64s: relocation, register save fixes for system reset interrupt
  fb479e44a9e240a23c2d208c2ace23542a47f41c
  powerpc: Fix build warning on 32-bit PPC
  8ae679c4bc2ea2d16d92620da8e3e9332fa4039f
  powerpc: Convert cmp to cmpd in idle enter sequence
  80f23935cadb1c654e81951f5a8b7ceae0acc1b4
- commit a8a982e
* Tue Dec 20 2016 msuchanek@suse.de
- powerpc/vdso64: Use double word compare on pointers
  (bsc#1016489).
- commit 5dd0a43
* Tue Dec 20 2016 msuchanek@suse.de
- powerpc/nvram: Fix an incorrect partition merge (bsc#1016489).
- commit acecd47
* Tue Dec 20 2016 oneukum@suse.com
- USB: serial: cp210x: fix hardware flow-control disable
  (bsc#1015932).
- USB: serial: cp210x: add new access functions for large
  registers (bsc#1015932).
- USB: serial: cp210x: add 8-bit and 32-bit register access
  functions (bsc#1015932).
- USB: serial: cp210x: add 16-bit register access functions
  (bsc#1015932).
- USB: cp210x: work around cp2108 GET_LINE_CTL bug (bsc#1015932).
- USB: cp210x: relocate private data from USB interface to port
  (bsc#1015932).
- usb: cp210x: Corrected USB request type definitions
  (bsc#1015932).
- commit 35c9967
* Tue Dec 20 2016 mkubecek@suse.cz
- net: avoid signed overflows for SO_{SND|RCV}BUFFORCE
  (CVE-2016-9793 bsc#1013531).
- net: cleanups in sock_setsockopt() (CVE-2012-6704 bsc#1013542).
- commit 20b5d34
* Mon Dec 19 2016 rgoldwyn@suse.com
- Refresh patches.fixes/posix_acl-Clear-SGID-bit-when-setting-file-permissio.patch.
  bsc#1014454 inode-i_mode was not set for reiserfs.
- commit 90ad8ac
* Fri Dec 16 2016 jdelvare@suse.de
- __ptrace_may_access() should not deny sub-threads (bsc#1012851).
- commit 30d6987
* Thu Dec 15 2016 oneukum@suse.com
- blacklist.conf: usbtest is not compiled, blacklist fixes
- commit f09a226
* Thu Dec 15 2016 oneukum@suse.com
- USB: ipaq.c: fix a timeout loop (bsc#1015848).
- commit 0dc29f3
* Thu Dec 15 2016 oneukum@suse.com
- usblp: do not set TASK_INTERRUPTIBLE before lock (bsc#1015844).
- commit ff3296e
* Thu Dec 15 2016 oneukum@suse.com
- blacklist.conf: musb: driver is not compiled, fixes can be ignored
- commit d41bdda
* Thu Dec 15 2016 oneukum@suse.com
- USB: serial: fix potential use-after-free after failed probe
  (bsc#1015828).
- commit 1385677
* Thu Dec 15 2016 oneukum@suse.com
- USB: console: fix potential use after free (bsc#1015817).
- USB: console: fix uninitialised ldisc semaphore (bsc#1015817).
- commit 7c72c03
* Thu Dec 15 2016 oneukum@suse.com
- blacklist.conf: blacklisted fixes for the gadget code, which we don't compile in SP4
- commit 9f22e87
* Thu Dec 15 2016 oneukum@suse.com
- blacklist.conf: adutux blacklisting bogus commit
  The fixes tag points at the commit creating the file.
  Obviously bogus.
- commit 4af9a49
* Thu Dec 15 2016 oneukum@suse.com
- blacklist.conf: ssu100 fix breaking ABI blacklisted
  Yes, it behaves strangely and arguably incorrectly, but this
  is visible even to user space
- commit 21d9d1e
* Thu Dec 15 2016 oneukum@suse.com
- blacklist.conf: ignore renesas usb gadget stuff
  We don't compile the gadget code in SP4
- commit 5a9f5ec
* Thu Dec 15 2016 oneukum@suse.com
- USB: opticon: fix non-atomic allocation in write path
  (bsc#1015803).
- commit a8e3c51
* Thu Dec 15 2016 oneukum@suse.com
- blacklist.conf: fusb300_udc is not built, not use taking fixes
- commit bb0f9f2
* Thu Dec 15 2016 oneukum@suse.com
- USB: ftdi_sio: fix null deref at port probe (bsc#1015796).
- commit dbe3f6f
* Thu Dec 15 2016 oneukum@suse.com
- USB: usb_wwan: fix potential blocked I/O after resume
  (bsc#1015760).
- USB: usb_wwan: fix urb leak at shutdown (bsc#1015760).
- USB: usb_wwan: fix write and suspend race (bsc#1015760).
- USB: usb_wwan: fix race between write and resume (bsc#1015760).
- USB: usb_wwan: fix urb leak in write error path (bsc#1015760).
- commit a09b1b6
* Thu Dec 15 2016 oneukum@suse.com
- blacklist.conf: not taking a fix for usb_wwan which depends on features not present
- commit ea6c849
* Thu Dec 15 2016 oneukum@suse.com
- USB: option: fix runtime PM handling (bsc#1015752).
- commit 4778511
* Thu Dec 15 2016 oneukum@suse.com
- USB: sierra: fix remote wakeup (bsc#1015561).
- USB: sierra: fix urb and memory leak on disconnect
  (bsc#1015561).
- USB: sierra: fix urb and memory leak in resume error path
  (bsc#1015561).
- USB: sierra: fix use after free at suspend/resume (bsc#1015561).
- USB: sierra: fix AA deadlock in open error path (bsc#1015561).
- commit 125d671
* Thu Dec 15 2016 neilb@suse.com
- NFSv4: Cap the transport reconnection timer at 1/2 lease period
  (bsc#1014410).
- NFSv4: Cleanup the setting of the nfs4 lease period
  (bsc#1014410).
- KABI fix (bsc#1014410).
- SUNRPC: Limit the reconnect backoff timer to the max RPC
  message timeout (bsc#1014410).
- SUNRPC: Fix reconnection timeouts (bsc#1014410).
- NFSv4: Handle timeouts correctly when probing for lease validity
  (bsc#1014410).
- commit 9096da5
* Wed Dec 14 2016 neilb@suse.com
- SUNRPC: Clean up the slot table allocation (bsc#1013862).
- SUNRPC: Initalise the struct xprt upon allocation (bsc#1013862).
- commit 833566a
* Mon Dec 12 2016 bpoirier@suse.com
- blacklist.conf:
  45f13df be2net: Enable Wake-On-LAN from shutdown for Skyhawk (v4.8-rc1)
  Fixes:
  028991e be2net: Enabling Wake-on-LAN is not supported in S5 state (v3.8-rc1)
  depends on
  6b085ba be2net: get rid of be_get_initial_config() call from be_probe() (v4.1-rc1)
  skipped, this "fix" re-enables a feature.
- commit 090c705
* Mon Dec 12 2016 bpoirier@suse.com
- qlcnic: use the correct ring in
  qlcnic_83xx_process_rcv_ring_diag() (bnc#800999 FATE#313899).
- be2net: Don't leak iomapped memory on removal (bug#925065).
- tg3: Fix temperature reporting (bnc#790588 FATE#313912).
- commit 334f6fa
* Mon Dec 12 2016 bp@suse.de
- KVM: x86: drop error recovery in em_jmp_far and em_ret_far
  (bsc#1013038 CVE-2016-9756).
- commit f5cf151
* Fri Dec  9 2016 jthumshirn@suse.de
- splice: introduce FMODE_SPLICE_READ and FMODE_SPLICE_WRITE
  (CVE-2016-9576, bsc#1013604).
  Conflicts:
  series.conf
- splice: introduce FMODE_SPLICE_READ and FMODE_SPLICE_WRITE
  (CVE-2016-9576, bsc#1013604).
- commit 544b9d1
* Thu Dec  8 2016 neilb@suse.com
- SUNRPC: Enforce an upper limit on the number of cached
  credentials (bsc#1012917).
- commit f5dfe96
* Thu Dec  8 2016 msuchanek@suse.de
- 8250_pci: Fix potential use-after-free in error path
  (bsc#1013070).
- commit 6b0ac9f
* Wed Dec  7 2016 neilb@suse.com
- block_dev: don't test bdev->bd_contains when it is not stable
  (bsc#1008557).
- commit 917ef21
* Tue Dec  6 2016 oneukum@suse.com
- rt2x00: fix rfkill regression on rt2500pci (bnc#748806).
- commit bfe803f
* Tue Dec  6 2016 dbueso@suse.de
- futex: Acknowledge a new waiter in counter before plist
  (bsc#851603).
- futex: Drop refcount if requeue_pi() acquired the rtmutex
  (bsc#851603).
- commit 9fd1e93
* Sat Dec  3 2016 tiwai@suse.de
- ALSA: pcm : Call kill_fasync() in stream lock (CVE-2016-9794
  bsc#1013533).
  Conflicts:
  series.conf
- ALSA: pcm : Call kill_fasync() in stream lock (CVE-2016-9794
  bsc#1013533).
- commit 2cc745f
* Sat Dec  3 2016 jbohac@suse.cz
- ipv6: sctp: clone options to avoid use after free (bsc#992566,
  CVE-2016-3841).
- commit 10196c3
* Fri Dec  2 2016 jeffm@suse.com
- apparmor: fix IRQ stack overflow during free_profile
  (bsc#1009875).
- commit 4ee3638
* Thu Dec  1 2016 dbueso@suse.de
- locking/mutex: Explicitly mark task as running after wakeup (bsc#1012411).
- commit 9a98ede
* Thu Dec  1 2016 msuchanek@suse.de
- serial: 8250_pci: Detach low-level driver during PCI error
  recovery (bsc#1013070).
- commit 6590d21
* Thu Dec  1 2016 jack@suse.cz
- ext4: fix reference counting bug on block allocation error
  (bsc#1013018).
- commit 1773a06
* Thu Dec  1 2016 jack@suse.cz
- Fix up Git-commit tag in
  patches.fixes/fsnotify-Fix-handling-of-renames-in-audit.patch.
- commit 8fd5cde
* Thu Dec  1 2016 jack@suse.cz
- ext4: don't leave i_crtime.tv_sec uninitialized (bsc#1013018).
- commit 66d1523
* Thu Dec  1 2016 tiwai@suse.de
- hpilo: Add support for iLO5 (bsc#999101).
- commit 3f0fea5
* Thu Dec  1 2016 mcgrof@suse.com
- Refresh
  patches.fixes/xfs-fix-two-memory-leaks-in-xfs_attr_list.c-error-pa.patch.
- commit fe49785
* Thu Dec  1 2016 mcgrof@suse.com
- xfs: fix two memory leaks in xfs_attr_list.c error paths (bsc#1012832, CVE-2016-9685).
- commit db1f17e
* Wed Nov 30 2016 jack@suse.cz
- fs: Avoid premature clearing of capabilities (bsc#914939
  CVE-2015-1350).
- commit 422f015
* Wed Nov 30 2016 jack@suse.cz
- fs: Give dentry to inode_change_ok() instead of inode
  (bsc#914939 CVE-2015-1350).
- Refresh patches.suse/nfs4acl-ext3.diff
- Refresh patches.fixes/reiserfs-locking-handle-nested-locks-properly
- commit f0c5991
* Wed Nov 30 2016 jack@suse.cz
- xfs: Propagate dentry down to inode_change_ok() (bsc#914939
  CVE-2015-1350).
- Refresh patches.suse/xfs-dmapi-xfs-enable.
- Refresh patches.suse/xfs-nfsd-dmapi-aware.
- commit 8026eee
* Wed Nov 30 2016 glin@suse.com
- libata: remove n_tags to avoid kABI breakage (bsc#871728).
- commit f6b4311
* Wed Nov 30 2016 glin@suse.com
- libata: introduce ata_host->n_tags to avoid oops on SAS
  controllers (bsc#871728).
- commit 5cde71b
* Tue Nov 29 2016 pmladek@suse.com
- blacklist.conf: negligible compile optimization of pr_debug() and pr_devel()
- commit e0825b7
* Tue Nov 29 2016 mmarek@suse.cz
- rpm/constraints.in: Bump ppc64 disk requirements to fix OBS builds again
- commit 49d4208
* Mon Nov 28 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Export a make-stderr.log file (bsc#1012422)
- commit 6a4e9e6
* Fri Nov 25 2016 jthumshirn@suse.de
- sg: Fix double-free when drives detach during SG_IO
  (CVE-2015-8962 bsc#1010501).
- commit ce9fc48
* Thu Nov 24 2016 mkubecek@suse.cz
- sctp: validate chunk len before actually using it (CVE-2016-9555
  bsc#1011685).
- commit 7c13355
* Wed Nov 23 2016 jthumshirn@suse.de
- block: fix use-after-free in seq file (CVE-2016-7910
  bsc#1010716).
- commit 36543e3
* Wed Nov 23 2016 jthumshirn@suse.de
- block: fix use-after-free in sys_ioprio_get() (CVE-2016-7911
  bsc#1010711).
- commit bc9d5f7
* Wed Nov 23 2016 glin@suse.com
- qlcnic: fix a loop exit condition better (bsc#909350 FATE#317546).
- commit bc408e6
* Wed Nov 23 2016 neilb@suse.com
- Refresh
  patches.fixes/0001-md-fix-problem-when-adding-device-to-read-only-array.patch.
- Refresh patches.fixes/nfs-lock-recovery.fix.
  Add "No-Fix" tags
- commit 737ba2f
* Tue Nov 22 2016 bp@suse.de
- KVM: x86: fix missed SRCU usage in kvm_lapic_set_vapic_addr
  (bnc#853052 CVE-2013-6368).
- blacklist.conf: update
- commit af98710
* Tue Nov 22 2016 mhocko@suse.cz
- blacklist.conf: added commits which are not worth bothering
- commit e47b67d
* Mon Nov 21 2016 alnovak@suse.cz
- libfc: Fixup disc_mutex handling (bsc#962846).
- commit 1ab51a8
* Fri Nov 18 2016 vbabka@suse.cz
- mremap: enforce rmap src/dst vma ordering in case of vma_merge()
  succeeding in copy_vma() (VM Functionality, bsc#1008645).
- commit 96927f0
* Fri Nov 18 2016 jslaby@suse.cz
- tty: Prevent ldisc drivers from re-using stale tty fields
  (bnc#1010507 CVE-2015-8964).
- commit 33aff97
* Wed Nov 16 2016 tiwai@suse.de
- Revert "proc: prevent accessing /proc/<PID>/environ until it's ready (CVE-2016-7916 bsc#1010467)"
  This patch was bogus, not applicable to 3.0.x kernel.
- commit 67a57a5
* Wed Nov 16 2016 tiwai@suse.de
- proc: prevent accessing /proc/<PID>/environ until it's ready
  (CVE-2016-7916 bsc#1010467).
- commit 26f7351
* Tue Nov 15 2016 tiwai@suse.de
- crypto: algif_hash - Only export and import on sockets with data
  (CVE-2016-8646,bsc#1010150).
- commit 6ea02c6
* Mon Nov 14 2016 bp@suse.de
- firewire: net: guard against rx buffer overflows (bsc#1008833,
  CVE-2016-8633).
- commit 4d2b592
* Thu Nov 10 2016 dchang@suse.com
- igb: Unpair the queues when changing the number of queues
  (bsc#909491 FATE#317388).
- igb: Remove unnecessary flag setting in
  igb_set_flag_queue_pairs() (bsc#909491 FATE#317388).
- igb: Fix oops caused by missing queue pairing (bsc#909491
  FATE#317388).
- igb: Enable SR-IOV configuration via PCI sysfs interface
  (bsc#909491 FATE#317388).
- igb: Fix oops on changing number of rings (bsc#909491
  FATE#317388).
- commit ed4c8a7
* Thu Nov 10 2016 bpoirier@suse.com
- bna: Add synchronization for tx ring (bsc#993739).
- commit 2a75efa
* Wed Nov  9 2016 mgorman@suse.com
- mm/memory_hotplug.c: check for missing sections in
  test_pages_in_a_zone() (bnc#961589).
- commit 235448d
* Tue Nov  8 2016 jbeulich@suse.com
- netfront: don't truncate grant references.
- commit d66fe41
* Tue Nov  8 2016 jbeulich@suse.com
- xenbus: don't invoke ->is_ready() for most device states
  (bsc#987333).
- Update patches.xen/xen3-patch-2.6.24 (n/a).
- commit 7a2544a
* Mon Nov  7 2016 oneukum@suse.com
- usbhid: add ATEN CS962 to list of quirky devices (bsc#1007615).
- Refresh
  patches.drivers/HID-multitouch-Advanced-Silicon-2149-36b1.
- Refresh
  patches.drivers/HID-multitouch-add-support-for-Atmel-212c.
- Refresh
  patches.drivers/HID-multitouch-add-support-for-Quanta-3027.
- Refresh patches.drivers/HID-use-multi-input-quirk-for-22b9-2968.
- commit 1ea7279
* Fri Nov  4 2016 jjolly@suse.de
- scsi: zfcp: spin_lock_irqsave() is not nestable
  (bsc#1003677,LTC#147374).
- commit 3ea2a9c
* Fri Nov  4 2016 jjolly@suse.de
- s390/cio: fix accidental interrupt enabling during resume
  (bnc#1003677, LTC#147606).
- zfcp: trace full payload of all SAN records (req,resp,iels)
  (bnc#1003677, LTC#144312).
- zfcp: fix payload trace length for SAN request&response
  (bnc#1003677, LTC#144312).
- zfcp: fix D_ID field with actual value on tracing SAN responses
  (bnc#1003677, LTC#144312).
- zfcp: restore tracing of handle for port and LUN with HBA
  records (bnc#1003677, LTC#144312).
- zfcp: trace on request for open and close of WKA port
  (bnc#1003677, LTC#144312).
- zfcp: restore: Dont use 0 to indicate invalid LUN in rec trace
  (bnc#1003677, LTC#144312).
- zfcp: retain trace level for SCSI and HBA FSF response records
  (bnc#1003677, LTC#144312).
- zfcp: close window with unblocked rport during rport gone
  (bnc#1003677, LTC#144310).
- zfcp: fix ELS/GS request&response length for hardware data
  router (bnc#1003677, LTC#144308).
- s390/time: LPAR offset handling (bnc#1003677, LTC#146920).
- s390/time: move PTFF definitions (bnc#1003677, LTC#146920).
- commit 6b3b219
* Thu Nov  3 2016 jlee@suse.com
- KEYS: Fix short sprintf buffer in /proc/keys show function
  (bsc#1004517, CVE-2016-7042).
- commit 0d4d88c
* Thu Nov  3 2016 neilb@suse.com
- move the call of __d_drop(anon) into
  __d_materialise_unique(dentry, anon) (bsc#984194).
- Delete patches.fixes/vfs-fix-dentry-crash.
- commit 63d74a9
* Thu Nov  3 2016 neilb@suse.com
- nfs4: reset states to use open_stateid when returning delegation
  voluntarily (bsc#1007944).
- commit 4a58aa8
* Wed Nov  2 2016 duwe@suse.de
- Move patches that create ppc64-bigmem to the powerpc section.
  Add comments that outline the procedure and warn the unsuspecting.
- commit 52cbb69
* Mon Oct 31 2016 rgoldwyn@suse.com
- posix_acl: Clear SGID bit when setting file permissions
  (CVE-2016-7097, bsc#995968).
- commit b64c926
* Fri Oct 28 2016 colyli@suse.de
- md: check command validity early in md_ioctl() (bsc#1004520).
- commit 64cc640
* Thu Oct 27 2016 ohering@suse.de
- Drivers: hv: vmbus: handle various crash scenarios (bnc#986337).
- Drivers: hv: vmbus: remove code duplication in message handling
  (bnc#986337).
- Drivers: hv: vmbus: avoid wait_for_completion() on crash
  (bnc#986337).
- Drivers: hv: vmbus: don't loose HVMSG_TIMER_EXPIRED messages
  (bnc#986337).
- Drivers: hv: vmbus: avoid scheduling in interrupt context in
  vmbus_initiate_unload() (bnc#986337).
- Drivers: hv: vss: run only on supported host versions
  (bnc#986337).
- mshyperv: fix recognition of Hyper-V guest crash MSR's
  (bnc#986337).
- Drivers: hv: vmbus: don't send CHANNELMSG_UNLOAD on
  pre-Win2012R2 hosts (bnc#986337).
- commit 58159d8
* Thu Oct 27 2016 ohering@suse.de
- netvsc: fix incorrect receive checksum offloading (bnc#1006917).
- commit 53ebd83
* Thu Oct 27 2016 ohering@suse.de
- hv: do not lose pending heartbeat vmbus packets (bnc#1006919).
- commit 94e22b3
* Thu Oct 27 2016 neilb@suse.com
- md: Drop sending a change uevent when stopping (bsc#1003568).
- commit 992c1d2
* Thu Oct 27 2016 bpoirier@suse.com
- vmxnet3: Wake queue from reset work (bsc#999907).
- commit 2fb20b5
* Wed Oct 26 2016 msuchanek@suse.de
- powerpc/pseries: Use H_CLEAR_HPT to clear MMU hash table during
  kexec (bsc#1003813).
- commit 7060b7d
* Wed Oct 26 2016 duwe@suse.de
- scripts/bigmem-generate-ifdef-guard:
  make executable
- commit 70d1c03
* Wed Oct 26 2016 duwe@suse.de
- powerpc/mm: Change the swap encoding in pte (bsc#973203).
- Refresh patches.suse/ppc64-bigmem-introduce-CONFIG_BIGMEM.
- commit 4b95948
* Wed Oct 26 2016 msuchanek@suse.de
- powerpc: scan_features() updates incorrect bits for REAL_LE
  (bsc#1010201, [2016-10-04] Pending Base Kernel Fixes).
- commit 149ee63
* Wed Oct 26 2016 msuchanek@suse.de
- powerpc/mm/hash64: Fix subpage protection with 4K HPTE config
  (bsc#1010201, [2016-10-04] Pending Base Kernel Fixes).
- commit 03af6fb
* Wed Oct 26 2016 duwe@suse.de
- make "autogenerated" note
- commit babbc67
* Wed Oct 26 2016 duwe@suse.de
- remove problematic preprocessor constructs
  (bsc#928138,fate#319026).
- Refresh
  patches.arch/ppc64-bigmem-04-mm-Convert-virtual-address-to-vpn.
- Refresh patches.suse/ppc64-bigmem-introduce-CONFIG_BIGMEM.
- scripts/bigmem-generate-ifdef-guard:
  auto-regen patches.suse/ppc64-bigmem-introduce-CONFIG_BIGMEM
- commit 86d585a
* Wed Oct 26 2016 msuchanek@suse.de
- powerpc/numa: Fix multiple bugs in memory_hotplug_max()
  (bsc#1010201, [2016-10-04] Pending Base Kernel Fixes).
- commit cf076e7
* Wed Oct 26 2016 duwe@suse.de
- scripts/bigmem-generate-ifdef-guard:
  Include this script to regenerate
  patches.suse/ppc64-bigmem-introduce-CONFIG_BIGMEM
- Refresh
  patches.arch/ppc64-bigmem-04-mm-Convert-virtual-address-to-vpn.
- Refresh
  patches.arch/ppc64-bigmem-05-mm-Make-KERN_VIRT_SIZE-not-dependend-on-PGTABLE_RANGE.
- Refresh
  patches.arch/ppc64-bigmem-11-mm-Make-some-of-the-PGTABLE_RANGE-dependency-explicit.
- Refresh patches.suse/ppc64-bigmem-introduce-CONFIG_BIGMEM.
- rpm/package-descriptions:
  add -bigmem description
- commit 9b5bc12
* Wed Oct 26 2016 msuchanek@suse.de
- powerpc/MSI: Fix race condition in tearing down MSI interrupts
  (bsc#1010201, [2016-10-04] Pending Base Kernel Fixes).
- commit 2ecd29c
* Wed Oct 26 2016 msuchanek@suse.de
- Refresh patch metadata with commit id
- commit c9978e2
* Wed Oct 26 2016 hare@suse.de
- scsi_error: count medium access timeout only once per EH run (bsc#993832).
- Fix erratic device offline during EH (bsc#993832).
- commit 376c392
* Wed Oct 26 2016 msuchanek@suse.de
- powerpc: fix typo 'CONFIG_PPC_CPU'
  (bsc#1010201, [2016-10-04] Pending Base Kernel Fixes).
- commit 58a055a
* Tue Oct 25 2016 msuchanek@suse.de
- powerpc: blacklist fixes for unsupported subarchitectures
  ppc32 only:
  6e0fdf9af216 powerpc: fix typo 'CONFIG_PMAC'
  obscure hardware:
  f7e9e3583625 powerpc: Fix missing L2 cache size in /sys/devices/system/cpu
- commit 19faec1
* Mon Oct 24 2016 msuchanek@suse.de
- powerpc/64: Fix incorrect return value from __copy_tofrom_user
  (bsc#1005896).
- commit 2aaddf8
* Fri Oct 21 2016 duwe@suse.de
- Update config files.
- Refresh patches.suse/ppc64-Kconfig-CONFIG_BIGMEM.
- commit f9a6c12
* Fri Oct 21 2016 duwe@suse.de
- Add switch to configure bigmem patches (bsc#928138,fate#319026).
- Make bigmem patches configurable (bsc#928138,fate#319026).
- Update config files.
- Refresh patches.arch/ppc64-bigmem-15-Update-kernel-VSID-range.
- commit bbf9ecd
* Fri Oct 21 2016 neilb@suse.com
- Backport assorted patches with "Fixes" tags
- md: fix problem when adding device to read-only array with
  bitmap (bnc#771065).
- md/raid10: Fix memory leak when raid10 reshape completes
  (fate#311379).
- NFSv4.1: Fix an NFSv4.1 state renewal regression (bnc#863873).
- md/raid10: always set reshape_safe when initializing
  reshape_position (fate#311379).
- sunrpc/cache: drop reference when sunrpc_cache_pipe_upcall()
  detects a race (bnc#803320).
- Refresh
  patches.fixes/0001-NFSv4-Recovery-of-recalled-read-delegations-is-broke.patch.
- commit 697b207
* Thu Oct 20 2016 bp@suse.de
- pci_ids: Add PCI device ID functions 3 and 4 for newer F15h
  models (fate#321400).
- x86, amd_nb: Clarify F15h, model 30h GART and L3 support
  (fate#321400).
- x86/cpu/amd: Set X86_FEATURE_EXTD_APICID for future processors
  (fate#321400).
- x86/gart: Check for GART support before accessing GART registers
  (fate#321400).
- Refresh patches.arch/x86_amd_numa_node_info_fam_15.patch.
- Update patches.xen/xen3-patch-2.6.27 (n/a).
- Update patches.xen/xen3-patch-2.6.31 (n/a).
- commit cb68f48
* Thu Oct 20 2016 duwe@suse.de
- Update config file (localversion = package name).
- commit b3255bc
* Thu Oct 20 2016 duwe@suse.de
- config.conf:
  add bigmem flavour on ppc64
- commit 97ce77e
* Thu Oct 20 2016 duwe@suse.de
- Update config files.
- powerpc/mm: Replace open coded CONTEXT_BITS value
  (bsc#928138,fate#319026).
- powerpc/mm: Use hpt_va to compute virtual address
  (bsc#928138,fate#319026).
- powerpc/mm: Simplify hpte_decode (bsc#928138,fate#319026).
- powerpc/mm: Convert virtual address to vpn
  (bsc#928138,fate#319026).
- powerpc/mm: Make KERN_VIRT_SIZE not dependend on PGTABLE_RANGE
  (bsc#928138,fate#319026).
- powerpc/mm: Increase the slice range to 64TB
  (bsc#928138,fate#319026).
- powerpc/mm: Use the required number of VSID bits in slbmte
  (bsc#928138,fate#319026).
- powerpc/mm: Use 32bit array for slb cache
  (bsc#928138,fate#319026).
- powerpc/mm: Add 64TB support (bsc#928138,fate#319026).
- powerpc/mm: Update VSID allocation documentation
  (bsc#928138,fate#319026).
- powerpc/mm: Make some of the PGTABLE_RANGE dependency explicit
  (bsc#928138,fate#319026).
- powerpc: Build fix for powerpc KVM (bsc#928138,fate#319026).
- powerpc/mm: Fix hash computation function
  (bsc#928138,fate#319026).
- powerpc: Make VSID_BITS* dependency explicit
  (bsc#928138,fate#319026).
- powerpc: Update kernel VSID range (bsc#928138,fate#319026).
- powerpc: Rename USER_ESID_BITS* to ESID_BITS*
  (bsc#928138,fate#319026).
- commit ab32748
* Thu Oct 20 2016 mhocko@suse.cz
- mm/memory.c: actually remap enough memory (bnc#1005903).
- commit 3672be2
* Thu Oct 20 2016 bp@suse.de
- kvm: x86: only channel 0 of the i8254 is linked to the HPET
  (bsc#960689).
- commit 38b3d21
* Thu Oct 20 2016 mhocko@suse.cz
- mm: fix crashes from mbind() merging vmas (bnc#1005877).
- commit 0141223
* Thu Oct 20 2016 bp@suse.de
- x86/asm/traps: Disable tracing and kprobes in fixup_bad_iret
  and sync_regs (bsc#909077).
- commit f92042d
* Thu Oct 20 2016 mhocko@suse.cz
- mm: fix sleeping function warning from __put_anon_vma
  (bnc#1005857).
- commit f3cfc44
* Thu Oct 20 2016 acho@suse.com
- Bluetooth: Fix potential NULL dereference in RFCOMM bind
  callback (bsc#1003925, CVE-2015-8956).
- commit e8b293a
* Thu Oct 20 2016 neilb@suse.com
- NFS: Fix an LOCK/OPEN race when unlinking an open file
  (bsc#956514).
- commit e5aa6c2
* Thu Oct 20 2016 neilb@suse.com
- dm thin: fix race condition when destroying thin pool workqueue
  (FATE#313903).
- dm space map metadata: fix sm_bootstrap_get_nr_blocks()
  (FATE#313903).
- commit ec30974
* Thu Oct 20 2016 neilb@suse.com
- NFSv4: enhance nfs4_copy_lock_stateid to use a flock stateid
  if there is one (bnc#998689).
- NFSv4: change nfs4_select_rw_stateid to take a lock_context
  inplace of lock_owner (bnc#998689).
- NFSv4: change nfs4_do_setattr to take an open_context instead
  of a nfs4_state (bnc#998689).
- kabi-fix for flock_owner addition (bsc#998689).
- NFSv4: add flock_owner to open context (bnc#998689).
- commit 2e067bc
* Wed Oct 19 2016 jslaby@suse.cz
- tty: Signal SIGHUP before hanging up ldisc (bnc#989764).
- commit 9f1afd0
* Tue Oct 18 2016 mhocko@suse.cz
- mm, gup: close FOLL MAP_PRIVATE race (bnc#1004418, CVE-2016-5195).
- commit 5362afb
* Mon Oct 17 2016 bp@suse.de
- x86/MCE/intel: Cleanup CMCI storm logic (bsc#929141).
- Update patches.xen/xen3-auto-arch-x86.diff (bsc#929141, a.o.).
- Refresh patches.xen/xen3-x86-mce-Cleanup-timer-mess.patch.
- commit 5a97eb4
* Mon Oct 17 2016 mhocko@suse.cz
- oom: print nodemask in the oom report (bnc#1003866).
- lib/vsprintf: implement bitmap printing through '%%*pb[l]'
  (bnc#1003866).
- cpumask, nodemask: implement cpumask/nodemask_pr_args()
  (bnc1003866).
- commit 30aea7a
* Fri Oct 14 2016 msuchanek@suse.de
- powerpc: Move kdump default base address to half RMO size on
  64bit (bsc#1003344).
- commit 50e54d0
* Thu Oct 13 2016 acho@suse.com
- bnx2x: fix lockdep splat (bsc#908684 FATE#317539).
- tg3: Avoid NULL pointer dereference in tg3_io_error_detected()
  (bsc#908458 FATE#317507).
- commit 56049c0
* Thu Oct 13 2016 mkubecek@suse.cz
- net: Fix use after free in the recvmmsg exit path (CVE-2016-7117
  bsc#1003077).
- commit d507018
* Thu Oct 13 2016 mkubecek@suse.cz
- blacklist.conf: add pointless networking follow-up fixes
- commit ba5622b
* Thu Oct 13 2016 mkubecek@suse.cz
- ipv6: replacing a rt6_info needs to purge possible propagated
  rt6_infos too (bsc#865783).
- commit 3596d8b
* Thu Oct 13 2016 mkubecek@suse.cz
- netfilter: ipv4: defrag: set local_df flag on defragmented skb
  (bsc#907611).
- commit 7d2ff55
* Thu Oct 13 2016 vbabka@suse.cz
- Refresh
  patches.fixes/mm-thp-respect-mpol_preferred-policy-with-non-local-node.patch.
- commit 09b816f
* Thu Oct 13 2016 vbabka@suse.cz
- Refresh
  patches.fixes/fs-select-add-vmalloc-fallback-for-select2.patch.
- commit 32a003d
* Thu Oct 13 2016 dchang@suse.com
- sfc: on MC reset, clear PIO buffer linkage in TXQs (bsc#909618
  FATE#317521).
- commit ebe2528
* Thu Oct 13 2016 dchang@suse.com
- i40e: fix an uninitialized variable bug (bsc#909484
  FATE#317397).
- commit d2880e6
* Wed Oct 12 2016 glin@suse.com
- libata: support the ata host which implements a queue depth less than 32 (bsc#871728)
- commit 70f3bea
* Wed Oct 12 2016 glin@suse.com
- qlcnic: fix a timeout loop (bsc#909350 FATE#317546)
- commit d89ae45
* Wed Oct 12 2016 jgross@suse.com
- Add commit 0d430e3fb3f7cdc13c0d22078b820f682821b45a to header
- commit aa34a84
* Tue Oct 11 2016 jroedel@suse.de
- PM / hibernate: Fix rtree_next_node() to avoid walking off
  list ends (bnc#860441).
- commit ea9ee0b
* Tue Oct 11 2016 aaptel@suse.com
- REVERT fs/cifs: fix wrongly prefixed path to root (bsc#963655, bsc#979681)
- commit 5f338a5
* Tue Oct 11 2016 aaptel@suse.com
- fs/cifs: cifs_get_root shouldn't use path with tree name (bsc#963655,
  bsc#979681).
- commit 35d13ad
* Mon Oct 10 2016 oneukum@suse.com
- blacklist.conf:
  dd5f5006d1035547559c8a90781a7e249787a7a2 isn't needed due to a different hub handling
- commit 6d2ed6a
* Mon Oct 10 2016 oneukum@suse.com
- blacklist.conf:
  bb86cf569bbd7ad4dce581a37c7fbd748057e9dc is not need, as a later patch removes
  the whole function it fixes
- commit 449471d
* Mon Oct 10 2016 oneukum@suse.com
- usb: hub: Fix unbalanced reference count/memory leak/deadlocks
  (bsc#968010).
- Refresh
  patches.drivers/0001-USB-fix-invalid-memory-access-in-hub_activate.patch.
- commit d152e94
* Mon Oct 10 2016 mhocko@suse.cz
- mm, vmscan: Do not wait for page writeback for GFP_NOFS
  allocations (bnc#763198).
- Refresh
  patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback.patch.
- commit aa175df
* Mon Oct 10 2016 oneukum@suse.com
- usb: hub: Fix auto-remount of safely removed or ejected USB-3
  devices (bsc#922634).
- Refresh patches.suse/0001-xhci-silence-TD-warning.patch.
- commit 6275b78
* Fri Oct  7 2016 jdelvare@suse.de
- sched: Fix possible divide by zero in avg_atom() calculation
  (bsc#996329).
- commit a0d8288
* Fri Oct  7 2016 jroedel@suse.de
- blacklist.conf: Blacklist unsupported architectures
- commit 719b9f8
* Fri Oct  7 2016 jroedel@suse.de
- Update blacklisting documentation to contain path-blacklisting
- README.blacklist:
- blacklist.conf:
- commit 945e72c
* Fri Oct  7 2016 mgalbraith@suse.de
- sched/core: Fix an SMP ordering race in try_to_wake_up() vs.  schedule() (bnc#1001419).
- commit 4dd9242
* Thu Oct  6 2016 bp@suse.de
- pagemap: do not leak physical addresses to non-privileged
  userspace (bsc#994759 CVE-2016-0823).
- commit 8fe5c97
* Thu Oct  6 2016 hare@suse.de
- scsi_scan: Send TEST UNIT READY to LUN0 before LUN scanning
  (bnc#843236,bsc#989779).
- commit f2b3ae0
* Wed Oct  5 2016 aaptel@suse.com
- fs/cifs: Fix regression which breaks DFS mounting (bsc#799133).
- commit b40e16c
* Wed Oct  5 2016 aaptel@suse.com
- fs/cifs: Move check for prefix path to within cifs_get_root()
  (bsc#799133).
- commit 7cb2240
* Wed Oct  5 2016 aaptel@suse.com
- fs/cifs: Compare prepaths when comparing superblocks (bsc#799133).
- commit 27cd7f4
* Wed Oct  5 2016 aaptel@suse.com
- fs/cifs: Fix memory leaks in cifs_do_mount() (bsc#799133).
- commit 01a9674
* Wed Oct  5 2016 aaptel@suse.com
- fs/cifs: make share unaccessible at root level mountable
  (bsc#799133).
- commit 3fb5dc1
* Wed Oct  5 2016 mgalbraith@suse.de
- Correct blacklist format
- commit d26d40a
* Wed Oct  5 2016 mgalbraith@suse.de
- Blacklist patches.fixes/sched-Consider-pi-boosting-in-setscheduler.patch
- commit 64e40a6
* Wed Oct  5 2016 mgorman@suse.com
- Refresh
  patches.fixes/mm-make-page-pfmemalloc-check-more-robust.patch.
- commit dd61a9f
* Wed Oct  5 2016 mgorman@suse.com
- net: add pfmemalloc check in sk_add_backlog() (bnc#920016).
- include/linux/mmdebug.h: should include linux/bug.h (bnc#971975
  VM performance -- git fixes).
- commit ed6942c
* Tue Oct  4 2016 msuchanek@suse.de
- powerpc: Make the vdso32 also build big-endian (bsc#967716).
- commit 9d8298d
* Tue Oct  4 2016 msuchanek@suse.de
- powerpc: Fix 64 bit builds with binutils 2.24 (bsc#967716).
- powerpc: Don't build assembly files with ABIv2 (bsc#967716).
- powerpc: Fix error when cross building TAGS & cscope
  (bsc#967716).
- powerpc: Don't use ELFv2 ABI to build the kernel (bsc#967716).
- powerpc: Add ability to build little endian kernels
  (bsc#967716).
- powerpc: Avoid load of static chain register when calling
  nested functions through a pointer on 64bit (bsc#967716).
- powerpc: dtc is required to build dtb files (bsc#967716).
- powerpc: Remove altivec fix for gcc versions before 4.0
  (bsc#967716).
- powerpc: Require gcc 4.0 on 64-bit (bsc#967716).
- arch/powerpc: Remove duplicate/redundant Altivec entries
  (bsc#967716).
- powerpc: Remove buggy 9-year-old test for binutils < 2.12.1
  (bsc#967716).
- commit 7025d09
* Tue Oct  4 2016 jroedel@suse.de
- Document the process to blacklist upstream commit-ids
- README.blacklist:
- blacklist.conf:
- commit 32c2c85
* Tue Oct  4 2016 mgalbraith@suse.de
- sched/core: Fix a race between try_to_wake_up() and a woken up task (bnc#1002165).
- commit fd57262
* Fri Sep 30 2016 mmarek@suse.com
- Set CONFIG_DEBUG_INFO=y and CONFIG_DEBUG_INFO_REDUCED=n on all platforms
  The specfile adjusts the config if necessary, but a new version of
  run_oldconfig.sh requires the settings to be present in the repository.
- commit ab1112c
* Thu Sep 29 2016 msuchanek@suse.de
- increase CONFIG_NR_IRQS 512 -> 2048
  reportedly irq error with multiple nvme and tg3 in the same machine is resolved
  by increasing CONFIG_NR_IRQS
  (bsc#998399)
- commit f811f82
* Thu Sep 29 2016 mkubecek@suse.cz
- vlan: mask vlan prio bits (bsc#979514).
- vlan: don't deliver frames for unknown vlans to protocols
  (bsc#979514).
- commit 212a226
* Thu Sep 29 2016 vbabka@suse.cz
- fs/select: add vmalloc fallback for select(2) (bsc#1000189).
- introduce SIZE_MAX (bsc#1000189).
- Refresh patches.fixes/slab-introduce-kmalloc_array.patch.
- commit 4825815
* Thu Sep 29 2016 mkubecek@suse.cz
- Delete
  patches.fixes/net-fix-crash-due-to-wrong-dev-in-calling.patch. (bsc#979514)
- Update
  patches.drivers/fcoe-0102-fcoe-ensure-that-skb-placed-on-the-fip_recv_list-are.patch
  (add bsc#732582 reference).
- commit 8333eb2
* Thu Sep 29 2016 neilb@suse.com
- NFS: Refresh open-owner id when server says SEQID is bad
  (bsc#989261).
- NFS: Don't disconnect open-owner on NFS4ERR_BAD_SEQID
  (bsc#989261).
- commit 5e704f2
* Wed Sep 28 2016 hare@suse.de
- scsi_dh_rdac: retry inquiry for UNIT ATTENTION (bsc#934760).
- commit f6e1df0
* Tue Sep 27 2016 jbeulich@suse.com
- patches.xen/xen-netback-generalize.patch: Fold back into
  base patch.
- commit cee051b
* Tue Sep 27 2016 jbeulich@suse.com
- netback: fix flipping mode (bsc#996664).
- commit f236416
* Tue Sep 27 2016 jbeulich@suse.com
- patches.xen/xen3-patch-2.6.31.patch: Fold back into base patch.
- commit 253a559
* Tue Sep 27 2016 jbeulich@suse.com
- netback: fix flipping mode (bsc#996664).
- Refresh patches.xen/xen-netback-generalize.
- commit 0fe632f
* Tue Sep 27 2016 oneukum@suse.com
- cdc-acm: added sanity checking for probe() (bsc#993891).
- commit fdaea82
* Tue Sep 27 2016 jbeulich@suse.com
- blktap2: eliminate race from deferred work queue handling
  (bsc#911687).
- blktap2: eliminate deadlock potential from shutdown path
  (bsc#909994).
- commit 6149a89
* Tue Sep 27 2016 jbeulich@suse.com
- pciback: return proper values during BAR sizing.
- Refresh patches.xen/xen3-patch-2.6.27.
- commit a29cf41
* Sun Sep 25 2016 bp@suse.de
- scsi: arcmsr: Buffer overflow in arcmsr_iop_message_xfer()
  (bsc#999932 CVE-2016-7425).
- commit 6ad9bef
* Fri Sep 23 2016 jeffm@suse.com
- NFS: Don't write enable new pages while an invalidation is
  proceeding (bsc#999584).
- NFS: Fix writeback performance issue on cache invalidation
  (bsc#999584).
- NFS: Fix a regression in the read() syscall (bsc#999584).
- NFS: Fix races in nfs_revalidate_mapping (bsc#999584).
- NFS: fix the handling of NFS_INO_INVALID_DATA flag in
  nfs_revalidate_mapping (bsc#999584).
- commit 78a761f
* Wed Sep 21 2016 jeffm@suse.com
- btrfs: ensure that file descriptor used with subvol ioctls is
  a dir (bsc#999600).
- commit 3cea421
* Thu Sep 15 2016 jdelvare@suse.de
- tmpfs: change final i_blocks BUG to WARNING (bsc#991923).
- commit 46fbed7
* Wed Sep 14 2016 alnovak@suse.cz
- libfc: do not send ABTS when resetting exchanges (bsc#962846).
- libfc: reset exchange manager during LOGO handling (bsc#962846).
- libfc: send LOGO for PLOGI failure (bsc#962846).
- libfc: Issue PRLI after a PRLO has been received (bsc#962846).
- libfc: Revisit kref handling (bnc#990245).
- commit 1b332fc
* Wed Sep 14 2016 hare@suse.de
- libfc: fixup locking of ptp_setup() (bsc#962846).
- libfc: Do not take rdata->rp_mutex when processing a
  - FC_EX_CLOSED ELS response (bsc#962846).
- commit 61c8216
* Mon Sep 12 2016 sparschauer@suse.de
- scsi: ibmvfc: Fix I/O hang when port is not mapped (bsc#971989)
- commit 1fa8412
* Mon Sep 12 2016 hare@suse.de
- scsi: do not print 'reservation conflict' for TEST UNIT READY
  (bsc#984102).
- commit 7c0a186
* Fri Sep  9 2016 alnovak@suse.cz
- posix-timers: Remove remaining uses of tasklist_lock
  (bnc#997401).
- commit 6cc7334
* Fri Sep  9 2016 jthumshirn@suse.de
- mpt2sas, mpt3sas: Fix panic when aer correct error occurred (bsc#997708).
- commit 479b15b
* Fri Sep  9 2016 jthumshirn@suse.de
- powerpc: add kernel parameter iommu_alloc_quiet (bsc#994926).
- commit ad44cea
* Fri Sep  9 2016 mgalbraith@suse.de
- posix-timers: Use sighand lock instead of tasklist_lock on timer deletion (bnc#997401).
- posix-timers: Use sighand lock instead of tasklist_lock for task clock sample (bnc#997401).
- commit 5b1ac2d
* Mon Sep  5 2016 oneukum@suse.com
- USB: fix typo in wMaxPacketSize validation (bsc#991665).
- commit 0693fa8
* Fri Sep  2 2016 mmarek@suse.com
- rpm/constraints.in: Bump x86 disk space requirement to 20GB
  Clamav tends to run out of space nowadays.
- commit a189416
* Thu Sep  1 2016 jbeulich@suse.com
- xenbus: inspect the correct type in
  xenbus_dev_request_and_reply().
- pciback: fix conf_space read/write overlap check.
- commit b036810
* Thu Sep  1 2016 oneukum@suse.com
- kaweth: fix oops upon failed memory allocation (bsc#993890).
- kaweth: fix firmware download (bsc#993890).
- commit f3821ad
* Thu Sep  1 2016 jbohac@suse.cz
- ipv6: tcp: add rcu locking in tcp_v6_send_synack() (bsc#992566,
  CVE-2016-3841).
- KABI workaround for ipv6: add complete rcu protection around
  np->opt (bsc#992566, CVE-2016-3841).
- ipv6: tcp: add rcu locking in tcp_v6_send_synack() (bsc#992566,
  CVE-2016-3841).
- KABI workaround for ipv6: add complete rcu protection around
  np->opt (bsc#992566, CVE-2016-3841).
- commit 2718b81
* Wed Aug 31 2016 jbohac@suse.cz
- ipv6: add complete rcu protection around np->opt (bsc#992566,
  CVE-2016-3841).
- commit fdfc862
* Wed Aug 31 2016 neilb@suse.com
- NFS: Don't drop directory dentry which is in use (bsc#993127).
- commit d64ede4
* Tue Aug 30 2016 neilb@suse.com
- NFSv4: Fix range checking in __nfs4_get_acl_uncached and
  __nfs4_proc_set_acl (bsc#982218).
- commit 41a9a52
* Tue Aug 30 2016 jjolly@suse.de
- s390/dasd: fix hanging device after clear subchannel
  (bnc#994436, LTC#144640).
- commit 4831f43
* Mon Aug 29 2016 jbeulich@suse.com
- xen: x86/mm/pat, /dev/mem: Remove superfluous error message
  (bsc#974620).
- commit 52422af
* Fri Aug 26 2016 jthumshirn@suse.de
- scsi: ibmvfc: add FC Class 3 Error Recovery support
  (bsc#984992).
- scsi: ibmvfc: Set READ FCP_XFER_READY DISABLED bit in PRLI
  (bsc#984992).
- commit 14e7e8c
* Tue Aug 23 2016 oneukum@suse.com
- USB: validate wMaxPacketValue entries in endpoint descriptors
  (bnc#991665).
- commit 4612c7f
* Tue Aug 23 2016 mkubecek@suse.cz
- bonding: always set recv_probe to bond_arp_rcv in arp monitor
  (bsc#977687).
- bonding: fix bond_arp_rcv setting and arp validate desync state
  (bsc#977687).
- commit 5c604df
* Tue Aug 23 2016 mkubecek@suse.cz
- tcp: fix use after free in tcp_xmit_retransmit_queue()
  (CVE-2016-6828 bsc#994296).
- commit 9d61205
* Mon Aug 22 2016 jroedel@suse.de
- KVM: x86: SYSENTER emulation is broken (bsc#994618).
- commit 55feabf
* Fri Aug 19 2016 ohering@suse.de
- sort hyperv patches properly in series.conf
- commit ea378ea
* Fri Aug 19 2016 hare@suse.de
- libfc: sanity check cpu number extracted from xid (bsc#988440).
- commit 01555f1
* Fri Aug 19 2016 hare@suse.de
- libfc: Update rport reference counting (bsc#953233).
- commit d3ec302
* Fri Aug 19 2016 neilb@suse.com
- NFSv4: fix broken patch relating to v4 read delegations
  (bsc#956514, bsc#989261, bsc#979595).
- commit 9fcf73b
* Thu Aug 18 2016 mkubecek@suse.cz
- tcp: make challenge acks less predictable (CVE-2016-5696
  bsc#989152).
- random32: add prandom_u32_max (bsc#989152).
- commit 8ea8d4f
* Wed Aug 17 2016 vbabka@suse.cz
- mm: thp: fix SMP race condition between THP page fault and
  MADV_DONTNEED (VM Functionality, bnc#986445).
- commit 5bf6e97
* Tue Aug 16 2016 mmarek@suse.cz
- Import kabi files from 3.0.101-80
- commit 9ff28e6
* Mon Aug 15 2016 jeffm@suse.com
- btrfs: account for non-CoW'd blocks in btrfs_abort_transaction
  (bsc#983619).
- commit 42525f5
* Sun Aug 14 2016 colyli@suse.de
- md: lockless I/O submission for RAID1 (bsc#982783).
- commit 7012733
* Thu Aug 11 2016 jlee@suse.com
- ALSA: hda - Add Intel Lewisburg device IDs Audio (fate#319286).
- i2c: i801: add Intel Lewisburg device IDs (fate#319286).
- AHCI: Remove obsolete Intel Lewisburg SATA RAID device IDs
  (fate#319286).
- Adding Intel Lewisburg device IDs for SATA (fate#319286).
- ahci: Order SATA device IDs for codename Lewisburg
  (fate#319286).
- commit a1d108f
* Tue Aug  9 2016 jack@suse.cz
- xfs: Silence warnings in xfs_vm_releasepage() (bnc#915183
  bsc#987565).
- Delete patches.suse/xfs-skip-dirty-pages-in-releasepage.patch.
- commit 3e78129
* Tue Aug  9 2016 jthumshirn@suse.de
- aacraid: Check size values after double-fetch from user
  (CVE-2016-6480 bsc#991608).
- Delete
  patches.drivers/0001-aacraid-prevent-out-of-bounds-access-due-to-changing.patch.
- commit 574c4a7
* Thu Aug  4 2016 jthumshirn@suse.de
- aacraid: prevent out-of-bounds access due to changing fip
  header sizes (bsc#991608, CVE-2016-6480).
- commit 326da7b
* Wed Aug  3 2016 mkubecek@suse.cz
- Update
  patches.fixes/netfilter-arp_tables-simplify-translate_compat_table.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-ip6_tables-simplify-translate_compat_table.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-ip_tables-simplify-translate_compat_table-.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-add-and-use-xt_check_entry_offset.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-add-compat-version-of-xt_check_en.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-assert-minimum-target-size.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-check-for-bogus-target-offset.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-check-standard-target-size-too.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-do-compat-validation-via-translat.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-don-t-move-to-non-existent-next-r.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-don-t-reject-valid-target-size-on.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-kill-check_entry-helper.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-speed-up-jump-target-validation.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-validate-all-offsets-and-sizes-in.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-validate-targets-of-jumps.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.fixes/netfilter-x_tables-xt_compat_match_from_user-doesn-t.patch
  references (add CVE-2016-4998 bsc#986365).
- Update
  patches.kabi/kabi-revert-xt_compat_match_from_user-signature-chan.patch
  references (add CVE-2016-4998 bsc#986365).
- commit b723bef
* Wed Aug  3 2016 mkubecek@suse.cz
- ppp: defer netns reference release for ppp channel (bsc#980371).
- commit ecb021b
* Wed Aug  3 2016 neilb@suse.com
- avoid dentry crash triggered by NFS (bsc#984194).
- commit 556dadb
* Tue Aug  2 2016 bp@suse.de
- KVM: x86: Reload pit counters for all channels when restoring
  state (bsc#960689 CVE-2015-7513).
- commit 74288bf
* Wed Jul 27 2016 jdelvare@suse.de
- cxgb4: Set VPD size so we can read both VPD structures
  (bsc#976867).
- PCI: Add pci_set_vpd_size() to set VPD size (bsc#976867).
- commit 639b02e
* Tue Jul 26 2016 mhocko@suse.cz
- kabi, unix: properly account for FDs passed over unix sockets
  (bnc#839104).
- unix: properly account for FDs passed over unix sockets
  (bnc#839104, CVE-2013-4312).
- commit 175b45c
* Fri Jul 22 2016 mkubecek@suse.cz
- netfilter: x_tables: speed up jump target validation
  (CVE-2016-4997 bsc#986362).
- commit 13a847d
* Thu Jul 21 2016 mkubecek@suse.cz
- Update
  patches.fixes/netfilter-x_tables-do-compat-validation-via-translat.patch.
  (remove useless code duplication from the original backport)
- commit fcab878
* Wed Jul 20 2016 jack@suse.cz
- xfs: Avoid grabbing ilock when file size is not changed
  (bsc#983535).
- commit 9bdc783
* Tue Jul 19 2016 aaptel@suse.com
- fs/cifs: fix wrongly prefixed path to root (bsc#963655, bsc#979681)
- commit 32e6a35
* Mon Jul 18 2016 jthumshirn@suse.de
- lpfc: call lpfc_sli_validate_fcp_iocb() with the hbalock held (bsc#951392).
- commit 4cbfd93
* Thu Jul 14 2016 mgalbraith@suse.de
- sched: Provide update_curr callbacks for stop/idle scheduling
  classes (bnc#988498).
- sched/cputime: Fix clock_nanosleep()/clock_gettime()
  inconsistency (bnc#988498).
- sched/cputime: Fix cpu_timer_sample_group() double accounting
  (bnc#988498).
- commit 6432abd
* Thu Jul 14 2016 jjolly@suse.de
- Refresh
  patches.arch/s390-sles11sp4-13-02-fix-asce_bits-handling.patch.
- commit 93278a0
* Mon Jul 11 2016 jkosina@suse.cz
- x86/mm/pat, /dev/mem: Remove superfluous error message
  (bsc#974620).
- commit 90cc9ec
* Fri Jul  8 2016 jjolly@suse.de
- qeth: delete napi struct when removing a qeth device
  (bnc#979915, LTC#143590).
- commit fe14b3e
* Fri Jul  8 2016 jjolly@suse.de
- s390/pci: fix use after free in dma_init (bnc#979915,
  LTC#141626).
- s390: fix test_fp_ctl inline assembly contraints (bnc#979915,
  LTC#143138).
- s390/mm: fix asce_bits handling with dynamic pagetable levels
  (bnc#979915, LTC#141456).
- iucv: call skb_linearize() when needed (bnc#979915, LTC#141240).
- commit d4e736e
* Mon Jun 27 2016 jkosina@suse.cz
- Refresh patches.fixes/hid-hiddev-validate-num_values.patch: fix upstream
  references.
- commit 8c86751
* Mon Jun 27 2016 jkosina@suse.cz
- HID: hiddev: validate num_values for HIDIOCGUSAGES,
  HIDIOCSUSAGES commands (bsc#986572 CVE-2016-5829).
- commit ff60f2d
* Mon Jun 27 2016 mkubecek@suse.cz
- netfilter: x_tables: don't reject valid target size on some
  architectures (CVE-2016-4997 bsc#986362).
- commit 1d7e8ed
* Mon Jun 27 2016 mmarek@suse.cz
- Import kabi files from 3.0.101-77 and add forgotten i386/ec2
- commit fbc6312
* Mon Jun 27 2016 mhocko@suse.cz
- mm/swap.c: flush lru pvecs on compound page arrival
  (bnc#983721).
- commit 21ddadc
* Fri Jun 24 2016 mkubecek@suse.cz
- netfilter: x_tables: do compat validation via translate_table
  (CVE-2016-4997 bsc#986362).
- kabi: revert xt_compat_match_from_user signature change
  (CVE-2016-4997 bsc#986362).
- netfilter: x_tables: xt_compat_match_from_user doesn't need
  a retval (CVE-2016-4997 bsc#986362).
- netfilter: arp_tables: simplify translate_compat_table args
  (CVE-2016-4997 bsc#986362).
- netfilter: ip6_tables: simplify translate_compat_table args
  (CVE-2016-4997 bsc#986362).
- netfilter: ip_tables: simplify translate_compat_table args
  (CVE-2016-4997 bsc#986362).
- netfilter: x_tables: validate all offsets and sizes in a rule
  (CVE-2016-4997 bsc#986362).
- netfilter: x_tables: check for bogus target offset
  (CVE-2016-4997 bsc#986362).
- netfilter: x_tables: check standard target size too
  (CVE-2016-4997 bsc#986362).
- netfilter: x_tables: add compat version of
  xt_check_entry_offsets (CVE-2016-4997 bsc#986362).
- netfilter: x_tables: assert minimum target size (CVE-2016-4997
  bsc#986362).
- netfilter: x_tables: kill check_entry helper (CVE-2016-4997
  bsc#986362).
- netfilter: x_tables: add and use xt_check_entry_offsets
  (CVE-2016-4997 bsc#986362).
- netfilter: x_tables: validate targets of jumps (CVE-2016-4997
  bsc#986362).
- netfilter: x_tables: don't move to non-existent next rule
  (CVE-2016-4997 bsc#986362).
- commit 52c0ad4
* Fri Jun 24 2016 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-2.6.39: Fix ia32_compat inheritance.
- Refresh
  patches.xen/xen3-08-x86-ldt-make-modify_ldt-synchronous.patch.
- commit 67b0ab0
* Fri Jun 24 2016 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-2.6.26: Fix PAT initialization.
- Refresh patches.xen/xen3-patch-2.6.32.
- commit 3f50e72
* Thu Jun 23 2016 jack@suse.cz
- mm: Fix DIF failures on ext3 filesystems (bsc#971030).
- commit 1704f5d
* Wed Jun 22 2016 neilb@suse.com
- NFSv4: don't check MAY_WRITE access bit in OPEN (bsc#985206).
- commit caa9d73
* Tue Jun 21 2016 mkubecek@suse.cz
- netfilter: bridge: Use __in6_dev_get rather than in6_dev_get
  in br_validate_ipv6 (bsc#982544).
- netfilter: bridge: don't leak skb in error paths (bsc#982544).
- kabi: prevent spurious modversion changes after bsc#982544 fix
  (bsc#982544).
- netfilter: bridge: forward IPv6 fragmented packets (bsc#982544).
- bridge: superfluous skb->nfct check in br_nf_dev_queue_xmit
  (bsc#982544).
- commit 10ffab1
* Mon Jun 20 2016 jlee@suse.com
- KEYS: potential uninitialized variable (bsc#984755,
  CVE-2016-4470).
- commit d0f8c8b
* Fri Jun 17 2016 jjolly@suse.de
- RDMA/cxgb4: Serialize CQ event upcalls with CQ destruction
  (bsc#909589).
- RDMA/cxgb4: Don't hang threads forever waiting on WR replies
  (bsc#909589).
- RDMA/cxgb4: Increase epd buff size for debug interface
  (bsc#909589).
- RDMA/cxgb4: Configure 0B MRs to match HW implementation
  (bsc#909589).
- RDMA/cxgb4: Fix locking issue in process_mpa_request
  (bsc#909589).
- RDMA/cxgb4: Limit MRs to < 8GB for T4/T5 devices (bsc#909589).
- RDMA/cxgb4: Wake up waiters after flushing the qp (bsc#909589).
- RDMA/cxgb4: Handle NET_XMIT return codes (bsc#909589).
- commit cba8230
* Thu Jun 16 2016 acho@suse.com
- net/qlge: Avoids recursive EEH error (bsc#954847).
- commit 9dd9529
* Tue Jun 14 2016 jkosina@suse.cz
- Revert "get_rock_ridge_filename(): handle malformed NM entries"
  This reverts commit cb6ce3ec7a964e56da9ba9cd3c9f0e708b5c3b2c.
  It should have never landed in the tree (we already have the patch
  via c63531c60ff that came through CVE branch), but I messed up
  the merge.
- commit a082ea6
* Tue Jun 14 2016 jeffm@suse.com
- nfs: fix memory corruption rooted in get_ih_name pointer math
  (bsc#984107).
- commit 305878c
* Tue Jun 14 2016 mkubecek@suse.cz
- ipvs: count pre-established TCP states as active (bsc#970114).
- commit ae00f5d
* Mon Jun 13 2016 dbueso@suse.de
- ipc,sem: fix use after free on IPC_RMID after a task using same semaphore set exits (bsc#967914).
- commit 674b3e2
* Fri Jun 10 2016 bp@suse.de
- rds: fix an infoleak in rds_inc_info_copy (bsc#983213
  CVE-2016-5244).
- commit 691868b
* Thu Jun  9 2016 jeffm@suse.com
- ecryptfs: don't allow mmap when the lower file system doesn't
  allow it (bsc#983143 CVE-2016-1583).
- commit d028bb3
* Tue Jun  7 2016 jeffm@suse.com
- get_rock_ridge_filename(): handle malformed NM entries
  (bsc#980725 CVE-2016-4913).
- commit c63531c
* Thu Jun  2 2016 tiwai@suse.de
- ALSA: oxygen: add Xonar DGX support (bsc#982691).
- commit 91da631
* Thu Jun  2 2016 mgalbraith@suse.de
- cgroups: don't attach task to subsystem if migration failed
  (bnc#979274).
- cgroups: more safe tasklist locking in cgroup_attach_proc
  (bnc#979274).
- commit f504e22
* Thu Jun  2 2016 neilb@suse.com
- NFSv4: OPEN must handle the NFS4ERR_IO return code correctly
  (bsc#979595).
- commit 1c07f36
* Wed Jun  1 2016 bp@suse.de
- Tidy series.conf, p5
  Only one last patch which can be moved easily. There are some more x86-related
  things left at the end but moving them won't be that trivial.
- commit 638665f
* Wed Jun  1 2016 oneukum@suse.com
- hid-elo: kill not flush the work (bnc#982532).
- commit 55c8922
* Tue May 31 2016 bp@suse.de
- Reorder series.conf, p4
  Move next batch.
- commit b8b1359
* Tue May 31 2016 bp@suse.de
- Reorder series.conf, p3
  Move the MCA pile to its proper location, some x86 and UV patches too, where they
  belong.
- commit f3923e3
* Tue May 31 2016 tiwai@suse.de
- net: fix a kernel infoleak in x25 module
  (CVE-2016-4580,bsc#981267).
- commit dfd4e55
* Tue May 31 2016 bp@suse.de
- Reorder series.conf, p2
  Move some more x86 patches into their proper location.
- commit 25b6186
* Fri May 27 2016 mkubecek@suse.cz
- ppp: take reference on channels netns (CVE-2016-4805
  bsc#980371).
- commit cdc6209
* Fri May 27 2016 mkubecek@suse.cz
- ipv4/fib: don't warn when primary address is missing if in_dev
  is dead (bsc#971360).
- commit 15a4d8b
* Fri May 27 2016 mkubecek@suse.cz
- enic: set netdev->vlan_features (bsc#966245).
- commit 4aae3ac
* Thu May 26 2016 jlee@suse.com
- KEYS: Fix ASN.1 indefinite length object parsing (bsc#979867,
  CVE-2016-0758).
- commit d8506f3
* Thu May 26 2016 dchang@suse.com
- Update
  patches.fixes/bnx2x-Alloc-4k-fragment-for-each-rx-ring-buffer-elem.patch
  (bsc#953369 bsc#975358).
- commit e21d1a9
* Thu May 26 2016 neilb@suse.com
- NFS: reduce access cache shrinker locking (bnc#866130).
- commit 72ee7b8
* Wed May 25 2016 bp@suse.de
- Reorder series.conf so that EDAC patches for bnc#798781 are in the proper section
- commit 27826f6
* Wed May 25 2016 alnovak@suse.cz
- ipv4: fix ineffective source address selection (bsc#980788).
- commit be31be0
* Tue May 24 2016 neilb@suse.com
- NFS: Don't attempt to decode missing directory entries
  (bsc#980931).
- commit 78e0cd8
* Tue May 24 2016 oneukum@suse.com
- [media] usbvision: fix crash on detecting device with invalid
  configuration (bnc#950998, CVE-2015-7833).
- commit 9379cdd
* Tue May 24 2016 mhocko@suse.cz
- Delete
  patches.drivers/nvme-0165-Split-header-file-into-user-visible-and-kernel-.patch.
  SLE11-SP4 doesn't have uapi headers so move everything back to the
  original header (bnc#981231)
- Refresh patches.drivers/nvme-0001-New-driver.patch
  add ifdef __KERNEL__ for the kernel parts for nvme.h
- Refresh
  patches.drivers/nvme-0093-Update-Identify-Controller-data-structure.patch.
- Refresh
  patches.drivers/nvme-0166-Update-nvme_id_power_state-with-latest-spec.patch.
- Refresh patches.drivers/nvme-0174-Use-normal-shutdown.patch.
- Refresh patches.drivers/nvme-0181-compat-SG_IO-ioctl.patch.
- Refresh
  patches.drivers/nvme-0186-Abort-timed-out-commands.patch.
- Refresh
  patches.drivers/nvme-0203-Make-I-O-timeout-a-module-parameter.patch.
- Refresh
  patches.drivers/nvme-0206-Retry-failed-commands-with-non-fatal-errors.patch.
- Refresh
  patches.drivers/nvme-0207-Update-copyright-headers.patch.
- Refresh
  patches.drivers/nvme-0210-Configure-support-for-block-flush.patch.
- Refresh
  patches.drivers/nvme-0220-Rename-io_timeout-to-nvme_io_timeout.patch.
- Refresh
  patches.drivers/nvme-0222-Define-Log-Page-constants.patch.
- Refresh
  patches.drivers/nvme-0226-Update-list-of-status-codes.patch.
- Refresh
  patches.drivers/nvme-0242-Passthrough-IOCTL-for-IO-commands.patch.
- Refresh patches.drivers/nvme-0243-Updates-for-1.1-spec.patch.
- Refresh
  patches.drivers/nvme-0253-Update-namespace-and-controller-identify-struct.patch.
- Refresh
  patches.drivers/nvme-0254-Update-data-structures-for-NVMe-1.2.patch.
- Refresh
  patches.drivers/nvme-0255-Update-SCSI-Inquiry-VPD-83h-translation.patch.
- Refresh
  patches.drivers/nvme-0256-Register-management-handle-under-nvme-class.patch.
- commit a645313
* Tue May 24 2016 jjolly@suse.de
- kabi/severities: Added arch/s390/pci/* PASS
- commit 2c7a996
* Thu May 19 2016 oneukum@suse.com
- Input: gtco - fix crash on detecting device without endpoints
  (bnc#971944, CVE-2016-2187).
- Input: gtco - use sign_extend32() for sign extension
  (bnc#971944, CVE-2016-2187).
- Input: gtco - fix usb_dev leak (bnc#971944, CVE-2016-2187).
- commit 0addc51
* Thu May 19 2016 neilb@suse.com
- NFSv4: Ensure that we don't drop a state owner more than once
  (bsc#979595).
- commit 77eae7a
* Wed May 18 2016 tiwai@suse.de
- Refresh
  patches.drivers/ALSA-hrtimer-Handle-start-stop-more-properly.
  Fix the build error on 32bit architectures.
- commit 7b1fc1c
* Wed May 18 2016 jthumshirn@suse.de
- Update
  patches.drivers/nvme-0265-fix-max_segments-integer-truncation.patch
  (bsc#979419).
  Fix reference.
- commit f3fc16c
* Wed May 18 2016 neilb@suse.com
- MM: increase safety margin provided by PF_LESS_THROTTLE
  (bsc#956491, FATE#320631).
- commit 24250a9
* Tue May 17 2016 tiwai@suse.de
- ALSA: hrtimer: Handle start/stop more properly (bsc#973378).
- commit 4e3a6ea
* Tue May 17 2016 oneukum@suse.com
- USB: usbfs: fix potential infoleak in devio (bnc#978401,
  CVE-2016-4482).
- commit edc35b1
* Sat May 14 2016 jlee@suse.com
- ASN.1: Fix non-match detection failure on data overrun
  (bsc#963762, CVE-2016-2053).
- commit b36dc7b
* Sat May 14 2016 bpoirier@suse.com
- IB/security: Restrict use of the write() interface (bsc#979548
  CVE-2016-4565).
- commit dfb36d0
* Fri May 13 2016 bp@suse.de
- Refresh patches.fixes/net-fix-infoleak-in-llc.patch.
  Fix Patch-mainline tag.
- commit 141c0fe
* Fri May 13 2016 bp@suse.de
- net: fix infoleak in llc (bsc#978821, CVE-2016-4485).
- commit 666352e
* Fri May 13 2016 tiwai@suse.de
- Update tags in two patches for CVE-2016-4578, bsc#979879
- commit f8fb78b
* Fri May 13 2016 alnovak@suse.cz
- virtio_scsi: Implement eh_timed_out callback (bsc#936530).
- commit f40cd52
* Thu May 12 2016 mmarek@suse.com
- rpm/modprobe-xen.conf: Revert comment change to allow parallel install (bsc#957986).
  This reverts commit 855c7ce885fd412ce2a25ccc12a46e565c83f235.
- commit 370d7d2
* Wed May 11 2016 jthumshirn@suse.de
- NVMe: Unify controller probe and resume (bsc#979347).
- commit 6b3c4bc
* Wed May 11 2016 jthumshirn@suse.de
- nvme: fix max_segments integer truncation (bsc#676471).
- commit f0c27b8
* Wed May 11 2016 tiwai@suse.de
- ALSA: timer: Fix leak in events via snd_timer_user_tinterrupt
  (CVE-2016-4569,bsc#979213).
- ALSA: timer: Fix leak in events via snd_timer_user_ccallback
  (CVE-2016-4569,bsc#979213).
- ALSA: timer: Fix leak in SNDRV_TIMER_IOCTL_PARAMS
  (CVE-2016-4569,bsc#979213).
- commit ce120c0
* Tue May 10 2016 jjolly@suse.de
- s390/pci: add extra padding to function measurement block
  (bnc#968500, LTC#139445).
- s390/pci: enforce fmb page boundary rule (bnc#968500,
  LTC#139445).
- s390/pci: extract software counters from fmb (bnc#968500,
  LTC#139445).
- s390/pci: remove pdev pointer from arch data (bnc#968500,
  LTC#139444).
- s390/pci_dma: fix DMA table corruption with > 4 TB main memory
  (bnc#968500, LTC#139401).
- s390/pci_dma: improve debugging of errors during dma map
  (bnc#968500, LTC#139442).
- s390/pci_dma: handle dma table failures (bnc#968500,
  LTC#139442).
- s390/pci_dma: unify label of invalid translation table entries
  (bnc#968500, LTC#139442).
- s390/spinlock: avoid yield to non existent cpu (bnc#968500,
  LTC#141106).
- dasd: fix hanging system after LCU changes (bnc#968500,
  LTC#136671).
- s390/dasd: prevent incorrect length error under z/VM after
  PAV changes (bnc#968500, LTC#136670).
- commit 85b6fcd
* Tue May 10 2016 mkubecek@suse.cz
- net: fix infoleak in rtnetlink (CVE-2016-4486 bsc#978822).
- commit 9fc5816
* Tue May 10 2016 mkubecek@suse.cz
- netfilter: x_tables: fix unconditional helper (CVE-2016-3134
  bsc#971126).
- netfilter: x_tables: make sure e->next_offset covers remaining
  blob size (CVE-2016-3134 bsc#971126).
- netfilter: x_tables: validate e->target_offset early
  (CVE-2016-3134 bsc#971126).
- commit de2bbc7
* Tue May 10 2016 bpoirier@suse.com
- Driver: Vmxnet3: set CHECKSUM_UNNECESSARY for IPv6 packets
  (bsc#976739).
- commit b54fa1d
* Mon May  2 2016 mmarek@suse.cz
- rpm/modprobe-xen.conf: Update comments
- commit 855c7ce
* Wed Apr 27 2016 hare@suse.de
- SCSI: Increase REPORT_LUNS timeout (bsc#971989).
- commit 8a92a18
* Wed Apr 27 2016 vbabka@suse.cz
- mm/hugetlb.c: correct missing private flag clearing (VM
  Functionality, bnc#971446).
- mm/hugetlb: fix backport of upstream commit 07443a85ad (VM
  Functionality, bnc#971446).
- commit 6d82699
* Tue Apr 26 2016 eich@suse.de
- vgaarb: Add more context to error messages (bsc#976868).
- commit 3f07141
* Fri Apr 22 2016 ohering@suse.de
- Renumber various hyperv patches to make further upstream merging easier
- commit 078e275
* Fri Apr 22 2016 ohering@suse.de
- Update a hyperv patch to use -p ab style
- commit 5f814fd
* Fri Apr 22 2016 ohering@suse.de
- Correct Patch-mainline tags in various hyperv patches
- commit b5fbc1d
* Fri Apr 22 2016 ohering@suse.de
- Remove duplicate tag from a hid-hyperv patch
- commit 920a438
* Fri Apr 22 2016 ohering@suse.de
- Assign correct ->can_queue value in hv_storvsc (bnc#969391)
- commit b7c3174
* Fri Apr 22 2016 ghe@suse.com
- ocfs2: extend enough credits for freeing one truncate record
  while replaying truncate records (bnc#971947).
- ocfs2: do not set fs read-only if rec[0] is empty while
  committing truncate (bnc#971947).
- ocfs2: extend transaction for ocfs2_remove_rightmost_path()
  and ocfs2_update_edge_lengths() before to avoid inconsistency
  between inode and et (bnc#971947).
- commit 08a0c1f
* Thu Apr 21 2016 alnovak@suse.cz
- KVM: x86: fix maintenance of guest/host xcr0 state (bsc#961518).
- x86, kvm: fix kvm's usage of kernel_fpu_begin/end()
  (bsc#961518).
- x86, kvm: use kernel_fpu_begin/end() in kvm_load/put_guest_fpu()
  (bsc#961518).
- commit 5d88349
* Thu Apr 21 2016 ydfan@suse.com
- Fix cifs_uniqueid_to_ino_t() function for s390x
  (bsc#944309)
- commit b601fff
* Wed Apr 20 2016 jbohac@suse.cz
- veth: don't modify ip_summed (bsc#969149).
- commit 786f554
* Wed Apr 20 2016 hare@suse.de
- fcoe: fix reset of fip selection time (bsc#974787).
- commit b39827b
* Tue Apr 19 2016 ptesarik@suse.cz
- cpuset: Fix potential deadlock w/ set_mems_allowed (bsc#960857,
  bsc#974646).
- commit b613baf
* Tue Apr 19 2016 oneukum@suse.com
- USB: usbip: fix potential out-of-bounds write (bnc#975945).
- commit 6669144
* Mon Apr 18 2016 mmarek@suse.cz
- Import kabi files from kernel 3.0.101-71
- commit 695cf4d
* Mon Apr 18 2016 mkubecek@suse.cz
- kabi: protect struct netns_ipv6 after FIB6 GC series
  (bsc#965319).
- ipv6: per netns FIB garbage collection (bsc#965319).
- ipv6: per netns fib6 walkers (bsc#965319).
- ipv6: make fib6 serial number per namespace (bsc#965319).
- ipv6: replace global gc_args with local variable (bsc#965319).
- commit 85e03e7
* Fri Apr 15 2016 neilb@suse.com
- NFS: avoid waiting at all in nfs_release_page when congested
  (bsc#956491, FATE#320631).
- NFS: avoid deadlocks with loop-back mounted NFS filesystems
  (bsc#956491, FATE#320631).
- mm/vmscan.c: avoid throttling reclaim for loop-back nfsd threads
  (bsc#956491, FATE#320631).
- commit 3252147
* Fri Apr 15 2016 jroedel@suse.de
- iommu/vt-d: Ratelimit fault handler (bsc#975772).
- iommu/vt-d: Improve fault handler error messages (bsc#975772).
- commit ad0f9ee
* Fri Apr 15 2016 mkubecek@suse.cz
- net/core: dev_mc_sync_multiple calls wrong helper (bsc#971433).
- net/core: __hw_addr_sync_one / _multiple broken (bsc#971433).
- net/core: __hw_addr_unsync_one "from" address not marked synced
  (bsc#971433).
- net/core: __hw_addr_create_ex does not initialize sync_cnt
  (bsc#971433).
- commit 0fd76fb
* Thu Apr 14 2016 trenn@suse.com
- Refresh patches.xen/pci-guestdev.
- commit 0f6bfb0
* Thu Apr 14 2016 neilb@suse.com
- pipe: limit the per-user amount of pages allocated in pipes
  (bsc#970948, CVE-2016-2847).
- commit f3f81ca
* Wed Apr 13 2016 trenn@suse.com
- ACPI / PCI: Account for ARI in _PRT lookups (bsc#968566).
- PCI: Move pci_ari_enabled() to global header (bsc#968566).
- Refresh patches.xen/pci-guestdev.
- commit c5102cb
* Wed Apr 13 2016 oneukum@suse.com
- USB: iowarrior: fix oops with malicious USB descriptors
  (bnc#970956, CVE-2016-2188).
- commit cb014fd
* Wed Apr 13 2016 oneukum@suse.com
- USB: cdc-acm: more sanity checking (bnc#970911, CVE-2016-3138).
- commit 8201f3a
* Tue Apr 12 2016 jdelvare@suse.de
- s390/pageattr: Do a single TLB flush for change_page_attr
  (bsc#940413).
- commit e9dcc44
* Tue Apr 12 2016 oneukum@suse.com
- USB: cypress_m8: add endpoint sanity check (bnc#970970,
  CVE-2016-3137).
- commit a7fb5f2
* Tue Apr 12 2016 mkubecek@suse.cz
- af_unix: Guard against other == sk in unix_dgram_sendmsg
  (bsc#973570).
- commit 5fd270c
* Wed Apr  6 2016 oneukum@suse.com
- USB: digi_acceleport: do sanity checking for the number of ports (bnc#970892, CVE-2016-3140).
- commit 8a939d6
* Wed Apr  6 2016 oneukum@suse.com
- Input: powermate - fix oops with malicious USB descriptors (bnc#970958, CVE-2016-2186).
- commit 54d61bb
* Wed Apr  6 2016 bpoirier@suse.com
- vmxnet3: set carrier state properly on probe (bsc#972363).
- vmxnet3: set netdev parant device before calling netdev_info
  (bsc#972363).
- commit 5016813
* Wed Apr  6 2016 neilb@suse.com
- nfsd: don't fail unchecked creates of non-special files
  (bsc#973237).
- nfsd4: return nfserr_symlink on v4 OPEN of non-regular file
  (bsc#973237).
- commit 1af5f3b
* Tue Apr  5 2016 jthumshirn@suse.de
- Fix another build error in 0001-ibmvscsi-remove-unsupported-host-config-mad.patch
  introduced with c4c802aea.
- commit f6c1d26
* Tue Apr  5 2016 oneukum@suse.com
- USB: usb_driver_claim_interface: add sanity checking
  (bnc#971124, CVE-2016-2185).
- commit cb90591
* Mon Apr  4 2016 jthumshirn@suse.de
- Fix compile error in 0001-ibmvscsi-remove-unsupported-host-config-mad.patch
  due to misapplied hunk.
- commit bccb3c2
* Mon Apr  4 2016 jthumshirn@suse.de
- ibmvscsi: Remove unsupported host config MAD (bsc#973556).
- commit c4c802a
* Fri Apr  1 2016 tiwai@suse.de
- ALSA: timer: Use mod_timer() for rearming the system timer
  (bsc#973378).
- ALSA: timer: Call notifier in the same spinlock (bsc#973378).
- ALSA: timer: Protect the whole snd_timer_close() with open race
  (bsc#973378).
- ALSA: timer: Sync timer deletion at closing the system timer
  (bsc#973378).
- commit d1c1b69
* Fri Apr  1 2016 tiwai@suse.de
- ALSA: seq: Fix incorrect sanity check at
  snd_seq_oss_synth_cleanup() (bsc#968018).
- ALSA: seq: Fix leak of pool buffer at concurrent writes
  (bsc#968018).
- ALSA: seq: Fix double port list deletion (bsc#968018).
- ALSA: seq: Fix lockdep warnings due to double mutex locks
  (bsc#968018).
- ALSA: seq: Fix yet another races among ALSA timer accesses
  (bsc#968018).
- ALSA: seq: Fix race at closing in virmidi driver (bsc#968018).
- ALSA: timer: Fix wrong instance passed to slave callbacks
  (bsc#968018).
- ALSA: timer: Fix leftover link at closing (bsc#968018).
- ALSA: timer: Fix race between stop and interrupt (bsc#968018).
- ALSA: timer: Fix link corruption due to double start or stop
  (bsc#968018).
- ALSA: timer: Code cleanup (bsc#968018).
- ALSA: rawmidi: Fix race at copying & updating the position
  (bsc#968018).
- ALSA: rawmidi: Make snd_rawmidi_transmit() race-free
  (bsc#968018).
- ALSA: pcm: Fix potential deadlock in OSS emulation (bsc#968018).
- commit 43ab03a
* Thu Mar 31 2016 hare@suse.de
- hpsa: fix issues with multilun devices (bsc#959381).
- commit 44d6a29
* Tue Mar 29 2016 jbeulich@suse.com
- pciback: Save the number of MSI-X entries to be copied later
  (bsc#957988).
- Refresh patches.xen/xen3-patch-2.6.20.
- commit aa1ad94
* Tue Mar 29 2016 jbeulich@suse.com
- pciback: check PF instead of VF for PCI_COMMAND_MEMORY
  (bsc#957990).
- commit fc5c805
* Tue Mar 29 2016 jbeulich@suse.com
- patches.xen/1303-xsa157.patch: Update references (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- patches.xen/1304-xsa157.patch: Update references (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- patches.xen/1305-xsa157.patch: Update references (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- patches.xen/1306-xsa157.patch: Update references (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- commit 7e1de40
* Tue Mar 29 2016 jbeulich@suse.com
- make vfree() safe to call from interrupt contexts (fate#316876).
- llist: Add llist_next() (fate#316876).
- commit 85c84fb
* Thu Mar 24 2016 mkubecek@suse.cz
- ipv4: Don't do expensive useless work during inetdev destroy
  (CVE-2016-3156 bsc#971360).
- commit 394738e
* Thu Mar 24 2016 lduncan@suse.com
- Remove old/incorrect PCI VPD patch:
  * patches.fixes/pci-Update-VPD-size-with-correct-length.patch.
- Update PCI VPD size patch to upstream:
  - PCI: Determine actual VPD size on first access (bsc#971729).
  - PCI: Update VPD definitions (bsc#971729).
- commit d2af5b7
* Thu Mar 17 2016 jkosina@suse.cz
- Refresh
  patches.drivers/mpt2sas-Rearrange-the-the-code-so-that-the-comp.patch: fix
  Git-commit reference.
- commit 0232712
* Thu Mar 17 2016 hare@suse.de
- [SCSI] mpt2sas: Rearrange the the code so that the completion queues are initialized prior to sending the request to controller firmware (bsc#967863).
- commit 71fd74e
* Wed Mar 16 2016 tiwai@suse.de
- ALSA: usb-audio: Add sanity checks for endpoint accesses
  (CVE-2016-2184,bsc#971125).
- ALSA: usb-audio: Fix NULL dereference in
  create_fixed_stream_quirk() (CVE-2016-2184,bsc#971125).
- commit 02ebf9f
* Tue Mar 15 2016 oneukum@suse.com
- wacom: fix crash due to missing endpoint (bnc#970909,
  CVE-2016-3139).
- commit 11621ac
* Sat Mar 12 2016 jjolly@suse.de
- s390/mm: four page table levels vs. fork (bnc#970504,
  LTC#138810, CVE-2016-2143).
- commit b6e66bd
* Fri Mar 11 2016 mhocko@suse.cz
- kabi, fs/seq_file: fallback to vmalloc allocation (bnc#968687).
- commit 07ef0a3
* Fri Mar 11 2016 mhocko@suse.cz
- fs/seq_file: fallback to vmalloc allocation (bnc#968687).
- fs, seq_file: fallback to vmalloc instead of oom kill processes
  (bnc#968687).
- fs, seqfile: always allow oom killer (bnc#968687).
- commit a74413b
* Fri Mar 11 2016 jjolly@suse.de
- s390/mm: four page table levels vs. fork (bnc#970504,
  LTC#138810, CVE-2016-2143).
- commit 1a61a61
* Thu Mar 10 2016 neilb@suse.com
- dcache: use IS_ROOT to decide where dentry is hashed
  (bsc#949752).
- commit 4d82c69
* Wed Mar  9 2016 oneukum@suse.com
- USB: visor: fix null-deref at probe (bnc#968670, CVE-2016-2782).
- commit d80b152
* Wed Mar  9 2016 oneukum@suse.com
- USB: fix invalid memory access in hub_activate() (bnc#968010,
  CVE-2015-8816).
- commit fa20fd5
* Tue Mar  8 2016 oneukum@suse.com
- USB: serial: visor: fix crash on detecting device without
  write_urbs (bnc#961512, CVE-2015-7566).
- commit 7a184d6
* Mon Mar  7 2016 oneukum@suse.com
- xhci: Workaround to get Intel xHCI reset working more reliably
  (bnc#898592).
- commit db50034
* Sat Mar  5 2016 bpoirier@suse.com
- mld, igmp: Fix reserved tailroom calculation (bsc#956852).
- ipv6: mld: fix add_grhead skb_over_panic for devs with large
  MTUs (bsc#956852).
- tcp: fix skb_availroom() (bsc#956852).
- skb: Add inline helper for getting the skb end offset from head
  (bsc#956852).
- tcp: avoid order-1 allocations on wifi and tx path (bsc#956852).
- commit 5d5eeda
* Fri Mar  4 2016 alnovak@suse.cz
- xfs: fix sgid inheritance for subdirectories inheriting default
  acls [V3] (bsc#965860).
- commit 8ccc59e
* Fri Mar  4 2016 bp@suse.de
- Revert "cuse: fix memory leak (bsc#969356, CVE-2015-1339)."
  This reverts commit cefe085a2f869a306bb23630bc02557f8bbe263e.
  This commit wasn't meant for SLE11 - it is v4.2 and onwards only.
- commit cd4eec7
* Fri Mar  4 2016 mhocko@suse.cz
- memcg: do not hang on OOM when killed by userspace OOM access
  to memory reserves (bnc#969571).
- commit 5c79557
* Fri Mar  4 2016 bp@suse.de
- cuse: fix memory leak (bsc#969356, CVE-2015-1339).
- commit cefe085
* Fri Mar  4 2016 neilb@suse.com
- NFS: use smaller allocations for 'struct idmap' (bsc#965923).
- commit cfa3782
* Thu Mar  3 2016 jbohac@suse.cz
- xfrm: don't segment UFO packets (bsc#946122).
- commit c5b5f31
* Thu Mar  3 2016 mhocko@suse.cz
- mm-memcg-print-statistics-from-live-counters-fix (bnc#969307).
- commit c62b54d
* Wed Mar  2 2016 jdelvare@suse.de
- tg3: 5715 does not link up when autoneg off (bsc#904035).
- commit a22a07e
* Wed Mar  2 2016 mmarek@suse.com
- Add /etc/modprobe.d/50-xen.conf selecting Xen frontend driver implementation
  (bsc#957986, bsc#956084, bsc#961658).
- commit c5c2734
* Wed Mar  2 2016 jbeulich@suse.com
- Update Xen config files (enable upstream block frontend).
- commit b7bd71d
* Wed Mar  2 2016 jbeulich@suse.com
- xen-blkfront: allow building in our Xen environment (bsc#961658
  fate#320200).
- supported.conf: Add xen-blkfront.
- commit 0f7158d
* Wed Mar  2 2016 jbeulich@suse.com
- xen/blkfront: Fix crash if backend doesn't follow the right
  states (bsc#961658 fate#320200).
- xen-blkfront: check for null drvdata in blkback_changed
  (XenbusStateClosing) (bsc#961658 fate#320200).
- xen-blkfront: don't add indirect pages to list when
  !feature_persistent (bsc#961658 fate#320200).
- drivers: xen-blkfront: only talk_to_blkback() when in
  XenbusStateInitialising (bsc#961658 fate#320200).
- driver: xen-blkfront: move talk_to_blkback to a more suitable
  place (bsc#961658 fate#320200).
- xen-blkfront: fix accounting of reqs when migrating (bsc#961658
  fate#320200).
- xen/blkfront: remove redundant flush_op (bsc#961658
  fate#320200).
- xen/blkfront: improve protection against issuing unsupported
  REQ_FUA (bsc#961658 fate#320200).
- xen, blkfront: factor out flush-related checks from
  do_blkif_request() (bsc#961658 fate#320200).
- xen-blkfront: remove type check from blkfront_setup_discard
  (bsc#961658 fate#320200).
- xen-blkfront: handle backend CLOSED without CLOSING (bsc#961658
  fate#320200).
- xen/pvhvm: If xen_platform_pci=0 is set don't blow up (v4)
  (bsc#961658 fate#320200).
- block: xen-blkfront: Fix possible NULL ptr dereference
  (bsc#961658 fate#320200).
- xen-blkfront: Silence pfn maybe-uninitialized warning
  (bsc#961658 fate#320200).
- xen-blkfront: restore the non-persistent data path (bsc#961658
  fate#320200).
- xen-blkfront: improve aproximation of required grants per
  request (bsc#961658 fate#320200).
- xen-blkfront: revoke foreign access for grants not mapped by
  the backend (bsc#961658 fate#320200).
- xen-blkfront: set blk_queue_max_hw_sectors correctly (bsc#961658
  fate#320200).
- xen-blkfront: Introduce a 'max' module parameter to alter the
  amount of indirect segments (bsc#961658 fate#320200).
- xen-blkfront: use a different scatterlist for each request
  (bsc#961658 fate#320200).
- xen-block: implement indirect descriptors (bsc#961658
  fate#320200).
- xen-blkfront: remove frame list from blk_shadow (bsc#961658
  fate#320200).
- xen-blkfront: pre-allocate pages for requests (bsc#961658
  fate#320200).
- xen-blkfront: switch from llist to list (bsc#961658
  fate#320200).
- xen-blkfront: drop the use of llist_for_each_entry_safe
  (bsc#961658 fate#320200).
- xen-blkfront: handle bvecs with partial data (bsc#961658
  fate#320200).
- llist/xen-blkfront: implement safe version of
  llist_for_each_entry (bsc#961658 fate#320200).
- xen-blkfront: free allocated page (bsc#961658 fate#320200).
- xen/blkback: persistent-grants fixes (bsc#961658 fate#320200).
- xen/blkback: Persistent grant maps for xen blk drivers
  (bsc#961658 fate#320200).
- xen-blkfront: make blkif_io_lock spinlock per-device (bsc#961658
  fate#320200).
- xen/blkfront: don't put bdev right after getting it (bsc#961658
  fate#320200).
- Xen: consolidate and simplify struct xenbus_driver instantiation
  (bsc#961658 fate#320200).
- xen/blk[front|back]: Enhance discard support with secure
  erasing support (bsc#961658 fate#320200).
- xen/blk[front|back]: Squash blkif_request_rw and
  blkif_request_discard together (bsc#961658 fate#320200).
- xen-blkfront: plug device number leak in xlblk_init() error path
  (bsc#961658 fate#320200).
- commit fa6d38a
* Wed Mar  2 2016 jbeulich@suse.com
- xen-blkfront: If no barrier or flush is supported, use invalid
  operation (bsc#961658 fate#320200).
- xen-blkfront: fix a deadlock while handling discard response
  (bsc#961658 fate#320200).
- xen-blkfront: Handle discard requests (bsc#961658 fate#320200).
- commit b02fc52
* Wed Mar  2 2016 jbeulich@suse.com
- xen/x86/mm: Add barriers and document switch_mm()-vs-flush
  synchronization (bnc#963767).
- Refresh patches.xen/xen-x86_64-pgd-alloc-order.
- commit dfba00c
* Wed Mar  2 2016 jbeulich@suse.com
- driver core: Add BUS_NOTIFY_REMOVED_DEVICE event (bnc#962965).
- commit f15e91e
* Wed Mar  2 2016 jbeulich@suse.com
- Replace XSA-157 fixes with proper upstream commits.
- commit fc0b1ef
* Wed Mar  2 2016 jbeulich@suse.com
- Replace XSA-155 fix with proper upstream commit.
- Refresh patches.xen/xen-blkback-discard.
- Refresh patches.xen/xen-blkback-indirect.
- Refresh patches.xen/xen-blkif-op-packet.
- Refresh patches.xen/xen3-patch-2.6.20.
- Refresh patches.xen/xen-vscsi-large-requests (refine fix and
  also address bsc#966094).
- commit 6f86597
* Wed Mar  2 2016 neilb@suse.com
- Restore kabi after lock-owner change (bnc#968141).
- nfs4: treat lock owners as opaque values (bnc#968141).
- commit 6502619
* Wed Feb 24 2016 tiwai@suse.de
- ALSA: hrtimer: Fix stall by hrtimer_cancel()
  (CVE-2016-2549,bsc#968013).
- ALSA: timer: Harden slave timer list handling
  (CVE-2016-2547,CVE-2016-2548,bsc#968011,bsc#968012).
- ALSA: timer: Fix race among timer ioctls
  (CVE-2016-2546,bsc#967975).
- ALSA: timer: Fix double unlink of active_list
  (CVE-2016-2545,bsc#967974).
- ALSA: seq: Fix race at timer setup and close
  (CVE-2016-2544,bsc#967973).
- ALSA: seq: Fix missing NULL check at remove_events ioctl
  (CVE-2016-2543,bsc#967972).
- commit 70c02a5
* Tue Feb 23 2016 tiwai@suse.de
- ALSA: hda - Apply clock gate workaround to Skylake, too
  (bsc#966137).
- ALSA: hda - disable dynamic clock gating on Broxton before reset
  (bsc#966137).
- ALSA: hda - Fix playback noise with 24/32 bit sample size on
  BXT (bsc#966137).
- commit 4560ba5
* Fri Feb 19 2016 neilb@suse.com
- Fix handling of re-write-before-commit for mmapped NFS pages
  (bsc#964201).
- commit 8c10d9c
* Thu Feb 18 2016 dchang@suse.com
- bnx2x: Add new device ids under the Qlogic vendor (bsc#964818).
- commit c5bfcd4
* Wed Feb 17 2016 jthumshirn@suse.de
- NVMe: default to 4k device page size (bsc#967042).
- commit ea1993b
* Mon Feb 15 2016 tiwai@suse.de
- ALSA: usb-audio: avoid freeing umidi object twice
  (CVE-2016-2384,bsc#966693).
- commit 72b902d
* Mon Feb 15 2016 hare@suse.de
- scsi_dh_alua: Do not block request queue if workqueue is active (bsc#960458).
- commit 9ed589f
* Fri Feb 12 2016 bp@suse.de
- iw_cxgb3: Fix incorrectly returning error on success
  (bsc#966437, CVE-2015-8812).
- commit fef10ea
* Thu Feb 11 2016 rgoldwyn@suse.com
- fuse: break infinite loop in fuse_fill_write_pages()
  (bsc#963765, CVE-2015-8785).
- commit 392a7ef
* Wed Feb 10 2016 eich@suse.de
- drm/i915: Change semantics of hw_contexts_disabled (bsc#963276).
- commit 46dfef2
* Tue Feb  9 2016 lduncan@suse.com
- Corrected patch Mainline formatting
- commit 1b022b8
* Tue Feb  9 2016 jjolly@suse.de
- qeth: initialize net_device with carrier off (bnc#958000,
  LTC#136514).
- commit da22754
* Tue Feb  9 2016 jjolly@suse.de
- s390/cio: update measurement characteristics (bnc#958000,
  LTC#136434).
- Refresh patches.arch/s390-sles11sp3-pci-06-chsc.patch.
- commit c6421e0
* Tue Feb  9 2016 jjolly@suse.de
- s390/cio: collect format 1 channel-path description data
  (bnc#958000, LTC#136434).
- s390/cio: ensure consistent measurement state (bnc#958000,
  LTC#136434).
- s390/cio: fix measurement characteristics memleak (bnc#958000,
  LTC#136434).
- commit 6d00a99
* Tue Feb  9 2016 jjolly@suse.de
- s390/sclp: Determine HSA size dynamically for zfcpdump
  (bnc#958000, LTC#136143).
- Refresh patches.arch/s390-sles11sp3-pci-07-hotplug_sclp.patch.
- Refresh
  patches.arch/s390-virtio-ccw-0001-KVM-s390-Perform-early-event-mask-processing-durin.patch.
- commit 8ad6d4a
* Tue Feb  9 2016 jjolly@suse.de
- s390/sclp: Move declarations for sclp_sdias into separate
  header file (bnc#958000, LTC#136143).
- commit 286df30
* Tue Feb  9 2016 jjolly@suse.de
- s390/dasd: fix failfast for disconnected devices (bnc#958000,
  LTC#135138).
- zfcp: fix fc_host port_type with NPIV (bnc#958000, LTC#132479).
- commit 04db7c6
* Fri Feb  5 2016 bpoirier@suse.com
- RDMA/ucma: Fix AB-BA deadlock (bsc#963998).
- commit 1d0b7fa
* Thu Feb  4 2016 mmarek@suse.cz
- Update kabi files and start tracking ec2
- commit b5abcb0
* Mon Feb  1 2016 jslaby@suse.cz
- Refresh
  patches.fixes/0001-tty-Fix-unsafe-ldisc-reference-via-ioctl-TIOCGETD.patch.
  Upstream status.
- commit 45fd4cb
* Fri Jan 29 2016 oneukum@suse.com
- pl2303: introduce private disconnect method (bnc#959649).
- pl2303: fix TIOCMIWAIT (bnc#959649).
- USB: pl2303: only wake up MSR queue on changes (bnc#959649).
- USB: pl2303: clean up line-status handling (bnc#959649).
- USB: pl2303: remove bogus delta_msr_wait wake up (bnc#959649).
- commit bd105ed
* Thu Jan 28 2016 mhocko@suse.cz
- x86/mm: Add barriers and document switch_mm()-vs-flush
  synchronization (bnc#963767, CVE-2016-2069).
- commit 1b64844
* Thu Jan 28 2016 hare@suse.de
- block: Always check queue limits for cloned requests (bsc#933782).
- commit 6557e73
* Wed Jan 27 2016 jack@suse.cz
- jbd: Fix unreclaimed pages after truncate in data=journal mode
  (bsc#961516).
- commit 884809b
* Tue Jan 26 2016 tiwai@suse.de
- ALSA: hda - Add one more node in the EAPD supporting candidate
  list (bsc#963561).
- commit 833bb67
* Tue Jan 26 2016 jslaby@suse.cz
- tty: Fix unsafe ldisc reference via ioctl(TIOCGETD) (bnc#961500
  CVE-2016-0723).
- commit 63d99ec
* Tue Jan 26 2016 dchang@suse.com
- kabi/severities: Add exception for bnx2x_schedule_sp_rtnl()
  There is no external, 3rd party modules use the symbol and the
  bnx2x_schedule_sp_rtnl symbol is only used in the bnx2x driver.
  (bsc#953369)
- commit ed1f19b
* Fri Jan 22 2016 hare@suse.de
- scsi_dh_rdac: always retry MODE SELECT on command lock violation
  (bsc#956949).
- commit ee2f5d3
* Thu Jan 21 2016 jack@suse.cz
- ext3: fix data=journal fast mount/umount hang (bsc#942082).
- ext3: NULL dereference in ext3_evict_inode() (bsc#942082).
- commit edd118c
* Thu Jan 21 2016 dchang@suse.com
- bnx2x: fix DMA API usage (bsc#953369).
- bnx2x: Alloc 4k fragment for each rx ring buffer element
  (bsc#953369).
- commit 94c3be6
* Wed Jan 20 2016 mkubecek@suse.cz
- kabi: protect struct unix_sock layout after epoll fix
  (bsc#917648 bsc#955654 CVE-2013-7446).
- unix: avoid use-after-free in ep_remove_wait_queue (bsc#917648
  bsc#955654 CVE-2013-7446).
- commit c33fa95
* Mon Jan 18 2016 mkubecek@suse.cz
- sctp: Prevent soft lockup when sctp_accept() is called during
  a timeout event (CVE-2015-8767 bsc#961509).
- commit dd53423
* Wed Jan 13 2016 jroedel@suse.de
- PCI: leave MEM and IO decoding disabled during 64-bit BAR
  sizing, too (bsc#951815).
- commit 91729ee
* Mon Jan 11 2016 oneukum@suse.com
- Input: aiptek - adjust error-handling code label (bnc#956708, CVE-2015-7515).
- commit 6a6c38b
* Fri Jan  8 2016 mmarek@suse.com
- Build the KOTD against SP4
- commit 23afb6d
* Fri Jan  8 2016 jkosina@suse.cz
- Refresh
  patches.fixes/e1000e-Do-not-write-lsc-to-ics-in-msi-x-mode.patch: fix build
  failure.
  The build failure was caused by SP3 -> SP4 merge. strcut e1000_hw *hw was
  removed from e1000_open(), but SP4 version still needs it for setting
  get_link_status flag.
- commit f410cc8
* Thu Jan  7 2016 neilb@suse.com
- NFSv4: Recovery of recalled read delegations is broken
  (bsc#956514).
- commit a9e6d02
* Tue Jan  5 2016 jroedel@suse.de
- iommu/vt-d: Don't change dma domain on dma-mask change
  (bsc#955925).
- commit 1471ab2
* Tue Jan  5 2016 mkubecek@suse.cz
- Update
  patches.fixes/ipv6-addrconf-validate-new-MTU-before-applying-it.patch
  references (add bsc#955354 CVE-2015-8215).
- commit 965412f
* Mon Jan  4 2016 mmarek@suse.com
- kbuild: create directory for dir/file.o (bsc#959312).
- commit 6b0a43a
* Mon Jan  4 2016 oneukum@suse.com
- Input: aiptek - fix crash on detecting device without endpoints (bnc#956708, CVE-2015-7515).
- commit 688a1ad
* Wed Dec 30 2015 bpoirier@suse.com
- e1000e: Fix msi-x interrupt automask (bsc#924919).
- e1000e: Do not write lsc to ics in msi-x mode (bsc#924919).
- e1000e: Do not read ICR in Other interrupt (bsc#924919).
- e1000e: Remove unreachable code (bsc#924919).
- commit 9612885
* Wed Dec 30 2015 jlee@suse.com
- KEYS: Fix race between read and revoke (bnc#958951,
  CVE-2015-7550).
- commit 00e3fc6
* Wed Dec 23 2015 mfasheh@suse.de
- Refresh patches.suse/xfs-skip-dirty-pages-in-releasepage.patch.
- commit 2241535
* Mon Dec 21 2015 bp@suse.de
- pptp: verify sockaddr_len in pptp_bind() and pptp_connect()
  (bsc#959190, CVE-2015-8569).
- commit 8b1cb51
* Fri Dec 18 2015 bp@suse.de
- bluetooth: Validate socket address length in sco_sock_bind()
  (bsc#959399, CVE-2015-8575).
- commit 058f76e
* Fri Dec 18 2015 jbohac@suse.cz
- Refresh
  patches.fixes/net-add-validation-for-the-socket-syscall-protocol-a.patch.
  Fix build error caused by missing U8_MAX.
- commit 0524508
* Fri Dec 18 2015 jbohac@suse.cz
- net: add validation for the socket syscall protocol argument
  (bsc#958886, CVE-2015-8543).
- commit 836d73b
* Fri Dec 18 2015 jbeulich@suse.com
- Refresh
  patches.xen/xen3-08-x86-ldt-make-modify_ldt-synchronous.patch (bsc#959705).
- commit ef67cd5
* Fri Dec 18 2015 jbeulich@suse.com
- Refresh
  patches.xen/xen3-08-x86-ldt-make-modify_ldt-synchronous.patch (bsc#959705).
- commit 6908161
* Fri Dec 18 2015 jthumshirn@suse.de
- nvme: Clear BIO_SEG_VALID flag in nvme_bio_split() (bsc#954992).
- commit 89aedf1
* Fri Dec 18 2015 jbeulich@suse.com
- xen/pciback: Don't allow MSI-X ops if PCI_COMMAND_MEMORY is
  not set (bsc#957990 CVE-2015-8551 CVE-2015-8552 XSA-157).
- xen/pciback: For XEN_PCI_OP_disable_msi[|x] only disable
  if device has MSI(X) enabled (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- xen/pciback: Return error on XEN_PCI_OP_enable_msix when
  device has MSI or MSI-X enabled (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- xen/pciback: Return error on XEN_PCI_OP_enable_msi when
  device has MSI or MSI-X enabled (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- guarantee one time reads of shared ring contents (bsc#957988
  CVE-2015-8550 XSA-155).
- commit f281b60
* Fri Dec 18 2015 jbeulich@suse.com
- xen/pciback: Don't allow MSI-X ops if PCI_COMMAND_MEMORY is
  not set (bsc#957990 CVE-2015-8551 CVE-2015-8552 XSA-157).
- xen/pciback: For XEN_PCI_OP_disable_msi[|x] only disable
  if device has MSI(X) enabled (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- xen/pciback: Return error on XEN_PCI_OP_enable_msix when
  device has MSI or MSI-X enabled (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- xen/pciback: Return error on XEN_PCI_OP_enable_msi when
  device has MSI or MSI-X enabled (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- guarantee one time reads of shared ring contents (bsc#957988
  CVE-2015-8550 XSA-155).
- commit b843e03
* Fri Dec 18 2015 jbeulich@suse.com
- blktap: also call blkif_disconnect() when frontend switched
  to closed (bsc#952976).
- blktap: refine mm tracking (bsc#952976).
- xen: x86: mm: only do a local tlb flush in
  ptep_set_access_flags() (bsc#948330).
- xen: x86: mm: drop TLB flush from ptep_set_access_flags
  (bsc#948330).
- xen/panic/x86: Allow cpus to save registers even if they
  (bnc#940946).
- xen/panic/x86: Fix re-entrance problem due to panic on
  (bnc#937444).
- Refresh other Xen patches.
- commit 27c63ba
* Thu Dec 17 2015 jkosina@suse.cz
- Refresh
  patches.drivers/0004-USB-ftdi_sio-remove-unnecessary-memset.patch.
  Fix git commit reference.
- commit baca336
* Thu Dec 17 2015 oneukum@suse.com
- ftdi_sio: private backport of TIOCMIWAIT (bnc#956375).
- USB: ftdi_sio: use ftdi_get_modem_status in chars_in_buffer
  (bnc#956375).
- USB: ftdi_sio: optimise chars_in_buffer (bnc#956375).
- USB: ftdi_sio: use generic chars_in_buffer (bnc#956375).
- USB: serial: export usb_serial_generic_chars_in_buffer
  (bnc#956375).
- USB: ftdi_sio: refactor modem-control status retrieval
  (bnc#956375).
- USB: ftdi_sio: fix tiocmget and tiocmset return values
  (bnc#956375).
- USB: ftdi_sio: fix tiocmget indentation (bnc#956375).
- USB: ftdi_sio: remove unnecessary memset (bnc#956375).
- usb: serial: ftdi_sio: Add missing chars_in_buffer function
  (bnc#956375).
- USB: ftdi_sio: fix race condition in TIOCMIWAIT, and abort of
  TIOCMIWAIT when the device is removed (bnc#956375).
- USB: ftdi_sio: fix status line change handling for TIOCMIWAIT
  and TIOCGICOUNT (bnc#956375).
- commit 0ac0482
* Thu Dec 17 2015 mhocko@suse.cz
- Update
  patches.fixes/mm-exclude-reserved-pages-from-dirtyable-memory-fix.patch
  (bnc#940017, bnc#949298, bnc#947128).
- commit cc37c12
* Wed Dec 16 2015 jlee@suse.com
- KEYS: Fix handling of stored error in a negatively instantiated
  user key (bnc#958463, CVE-2015-8539).
- commit 037884f
* Wed Dec 16 2015 bp@suse.com
- firmware: Simplify directory creation (bsc#959312).
- firmware: Create directories for external firmware (bsc#959312).
- Refresh
  patches.suse/0004-firmware_Install_firmware_signature_files_automatically.patch.
- commit 25b74de
* Wed Dec 16 2015 neilb@suse.com
- SUNRPC: restore fair scheduling to priority queues (bsc#955308).
- commit f1711dc
* Tue Dec 15 2015 lduncan@suse.com
- pci: Update VPD size with correct length (bsc#958906).
- commit 4a6320f
* Tue Dec 15 2015 bpoirier@suse.com
- vmxnet3: fix building without CONFIG_PCI_MSI (bsc#958912).
- vmxnet3: fix netpoll race condition (bsc#958912).
- commit 397e204
* Mon Dec 14 2015 jthumshirn@suse.de
- lpfc: Fix null ndlp dereference in target_reset_handler
  (bsc#951392).
- commit daa4cbe
* Mon Dec 14 2015 mmarek@suse.cz
- Import kabi files from rpm-3.0.101-0.47.71
- commit 9b7e3ae
* Wed Dec  2 2015 eich@suse.com
- drm/i915: Fix SRC_COPY width on 830/845g (bsc#758040).
- drm/i915: Evict CS TLBs between batches (bsc#758040).
- commit 1c400c8
* Tue Dec  1 2015 jkosina@suse.cz
- Refresh patches.suse/0001-xhci-silence-TD-warning.patch: the code
  is slightly different between SP3 and SP4, so the automatic merge
  didn't work.
- commit b52251d
* Mon Nov 30 2015 jbeulich@suse.com
- blktap: refine mm tracking (bsc#952976).
- commit 8ccb3d1
* Mon Nov 30 2015 jbeulich@suse.com
- blktap: also call blkif_disconnect() when frontend switched
  to closed (bsc#952976).
- commit c158d23
* Mon Nov 30 2015 oneukum@suse.com
- xhci: silence TD warning (bnc#939955).
- commit ef83c2b
* Mon Nov 30 2015 hare@suse.de
- lpfc: Fix cq_id masking problem (bsc#944677).
- commit 2e842af
* Fri Nov 27 2015 jack@suse.cz
- ext4: make orphan functions be no-op in no-journal mode
  (bsc#956709 CVE-2015-7509).
- commit bfb1191
* Thu Nov 26 2015 jlee@suse.com
- ahci: Add Device ID for Intel Sunrise Point PCH (bsc#953799).
- commit d0aa29b
* Wed Nov 25 2015 dvaleev@suse.com
- ipr: Fix invalid array indexing for HRRQ (bsc#940913).
- ipr: Fix incorrect trace indexing (bsc#940913).
- commit f577e43
* Fri Nov 20 2015 bpoirier@suse.com
- Driver: Vmxnet3: Fix ethtool -S to return correct rx queue stats
  (bsc#950750).
- vmxnet3: adjust ring sizes when interface is down (bsc#950750).
- vmxnet3: fix ethtool ring buffer size setting (bsc#950750).
- commit 276c80e
* Fri Nov 20 2015 jbohac@suse.cz
- netfilter: xt_recent: fix namespace destroy path (bsc#879378).
- commit 17c9cf6
* Fri Nov 20 2015 vbabka@suse.cz
- mm: fix GFP_THISNODE callers and clarify (bsc#954950, VM
  Functionality).
- mm: remove GFP_THISNODE (bsc#954950, VM Functionality).
- mm: sl[au]b: add knowledge of PFMEMALLOC reserve pages (Swap
  over NFS (fate#304949)).
- commit 9bab430
* Thu Nov 19 2015 jbohac@suse.cz
- veth: extend device features (bsc#879381).
- commit 7fefbcf
* Wed Nov 18 2015 jeffm@suse.com
- SUNRPC refactor rpcauth_checkverf error returns (bsc#955673).
- commit b59df5d
* Wed Nov 18 2015 jeffm@suse.com
- NFSv4: Fix two infinite loops in the mount code (bsc#954628).
- commit 18940d1
* Tue Nov 17 2015 jjolly@suse.de
- s390/dasd: fix list_del corruption after lcu changes
  (bnc#954984, LTC#133077).
- commit c932d19
* Tue Nov 17 2015 jjolly@suse.de
- Corrected and updated patch headers (bnc#946214)
  - patches.arch/s390-sles11sp4-09-04-mm-fix_incorrect_use_of_diag44.patch.
  - patches.arch/s390-sles11sp4-09-05-dasd-fix-invalid-PAV-assignment.patch.
- commit fb68c52
* Tue Nov 17 2015 oneukum@suse.com
- usbvision fix overflow of interfaces array (bnc#950998).
- commit 7abdd85
* Fri Nov 13 2015 jbohac@suse.cz
- ppp, slip: Validate VJ compression slot parameters completely
  (bsc#949936, CVE-2015-7799).
- commit 1f0be9b
* Fri Nov 13 2015 jbohac@suse.cz
- isdn_ppp: Add checks for allocation failure in isdn_ppp_open()
  (bsc#949936, CVE-2015-7799).
- commit 5fe19f8
* Wed Nov 11 2015 jroedel@suse.de
- KVM: svm: unconditionally intercept #DB (CVE-2015-8104
  bsc#954404).
- KVM: x86: work around infinite loop in microcode when #AC is
  delivered (CVE-2015-5307 bsc#953527).
- commit 1cd6391
* Mon Nov  9 2015 jjolly@suse.de
- kernel: fix incorrect use of DIAG44 in continue_trylock_relax()
  (bnc#946214, LTC#132100).
- s390/pci: handle events for unused functions (bnc#946214,
  LTC#130628).
- s390/pci: improve handling of hotplug event 0x301 (bnc#946214,
  LTC#130628).
- s390/pci: improve state check when processing hotplug events
  (bnc#946214, LTC#130628).
- s390/dasd: fix disconnected device with valid path mask
  (bnc#946214, LTC#132707).
- s390/dasd: fix invalid PAV assignment after suspend/resume
  (bnc#946214, LTC#132706).
- commit 4907192
* Mon Nov  9 2015 jjolly@suse.de
- af_iucv: avoid path quiesce of severed path in shutdown()
  (bnc#946214, LTC#131684).
- kernel: correct uc_sigmask of the compat signal frame
  (bnc#946214, LTC#130124).
- commit 84db3e9
* Mon Nov  9 2015 jbeulich@suse.com
- x86/evtchn: make use of PHYSDEVOP_map_pirq.
- Refresh other Xen patches.
- commit 1f997d4
* Fri Nov  6 2015 eich@suse.com
- drm/i915: add hotplug activation period to hotplug update mask
  (bsc#953980).
- commit ce3ecc9
* Fri Nov  6 2015 mkubecek@suse.cz
- ipv6: fix tunnel error handling (bsc#952579).
- commit b951448
* Fri Nov  6 2015 mkubecek@suse.cz
- Update upstream reference
  patches.fixes/netfilter-nf_conntrack_proto_sctp-minimal-multihomin.patch.
- commit d0c7534
* Fri Nov  6 2015 jlee@suse.com
- rcu: Eliminate deadlock between CPU hotplug and expedited
  grace periods (bsc#949706).
- commit 5a1b86c
* Fri Nov  6 2015 alnovak@suse.cz
- x86: mm: drop TLB flush from ptep_set_access_flags (bsc#948330).
- x86: mm: only do a local tlb flush in ptep_set_access_flags()
  (bsc#948330).
- commit c0eb0c8
* Thu Nov  5 2015 jbohac@suse.cz
- RDS: fix race condition when sending a message on unbound socket
  (bsc#952384, CVE-2015-7990).
- commit 127e3d1
* Thu Nov  5 2015 jack@suse.com
- writeback: Skip writeback for frozen filesystem (bsc#935123).
- fs: Fix deadlocks between sync and fs freezing (bsc#935123).
- cachefiles: Avoid deadlocks with fs freezing (bsc#935123).
- fs: Avoid deadlocks of fsync_bdev() and fs freezing
  (bsc#935123).
- quota: Fix deadlock with suspend and quotas (bsc#935123).
- vfs: Provide function to get superblock and wait for it to thaw
  (bsc#935123).
- commit 69ea5a3
* Wed Nov  4 2015 jslaby@suse.cz
- PCI: Refresh First VF Offset and VF Stride when updating NumVFs
  (bnc#952084).
- PCI: Clear NumVFs when disabling SR-IOV in sriov_init()
  (bnc#952084).
- PCI: Update NumVFs register when disabling SR-IOV (bnc#952084).
- PCI: set pci sriov page size before reading SRIOV BAR
  (bnc#952084).
- PCI: delay configuration of SRIOV capability (bnc#952084).
- commit 64d6f2a
* Tue Nov  3 2015 jthumshirn@suse.de
- qla2xxx: Remove decrement of sp reference count in abort handler
  (bsc#944993).
- qla2xxx: Do not reset adapter if SRB handle is in range
  (bsc#944993).
- qla2xxx: do not clear slot in outstanding cmd array
  (bsc#944993).
- commit 88d2936
* Tue Nov  3 2015 jack@suse.com
- xfs: Fix lost direct IO write in the last block (bsc#949744).
- commit 88024be
* Mon Nov  2 2015 bp@suse.de
- x86/paravirt: Replace the paravirt nop with a bona fide empty
  function (bsc#938706, CVE-2015-5157).
- x86/nmi/64: Fix a paravirt stack-clobbering bug in the NMI code
  (bsc#938706, CVE-2015-5157).
- commit d9dbc27
* Mon Nov  2 2015 alnovak@suse.cz
- xfs: use xfs_icluster_size_fsb in xfs_imap (bsc#932805).
- xfs: use xfs_icluster_size_fsb in xfs_ifree_cluster
  (bsc#932805).
- xfs: use xfs_icluster_size_fsb in xfs_ialloc_inode_init
  (bsc#932805).
- xfs: use xfs_icluster_size_fsb in xfs_bulkstat (bsc#932805).
- xfs: introduce a common helper xfs_icluster_size_fsb
  (bsc#932805).
- commit 53bd0e4
* Mon Nov  2 2015 jlee@suse.com
- KEYS: Fix crash when attempt to garbage collect an
  uninstantiated keyring (CVE-2015-7872 bsc#951440).
- KEYS: Don't permit request_key() to construct a new keyring
  (CVE-2015-7872 bsc#951440).
- KEYS: Fix race between key destruction and finding a keyring
  by name (bsc#951440).
- commit 5db2952
* Fri Oct 30 2015 jdelvare@suse.de
- drm/i915: Fix DDC probe for passive adapters (bsc#900610,
  fdo#85924).
- commit 0739d69
* Wed Oct 28 2015 glin@suse.com
- qlge: Fix qlge_update_hw_vlan_features to handle if interface is down (bsc#930835).
- commit eb0f0df
* Wed Oct 28 2015 tiwai@suse.de
- ALSA: hda - Disable 64bit address for Creative HDA controllers
  (bnc#814440).
- commit 5f8e921
* Tue Oct 27 2015 jdelvare@suse.de
- series.conf: Move ida_simple_get patches
  Move patches that introduce ida_simple_get before the patches which make
  use of it, so that the patch series can be bisected.
- commit 8543780
* Tue Oct 27 2015 jslaby@suse.cz
- PCI: Add VPD function 0 quirk for Intel Ethernet devices
  (bnc#943786).
- PCI: Add dev_flags bit to access VPD through function 0
  (bnc#943786).
- commit ba173fe
* Tue Oct 27 2015 ohering@suse.de
- xen: x86, pageattr: Prevent overflow in slow_virt_to_phys() for
  X86_PAE (fate#317533, bnc#937256).
- x86, pageattr: Prevent overflow in slow_virt_to_phys() for
  X86_PAE (fate#317533, bnc#937256).
- commit ef27f6e
* Mon Oct 26 2015 mkubecek@suse.cz
- rtnetlink: fix VF info size (bsc#950298).
- net/core: Add VF link state control policy (bsc#950298).
- rtnetlink: Fix VF IFLA policy (bsc#950298).
- commit 367e29d
* Mon Oct 26 2015 mkubecek@suse.cz
- series.conf: move generic rtnetlink patches to the front
- commit ff55a94
* Fri Oct 23 2015 jthumshirn@suse.de
- sg: fix read() error reporting (bsc#926774).
- commit 0aefaff
* Thu Oct 22 2015 neilb@suse.com
- dm-snap: avoid deadock on s->lock when a read is split
  (bsc#939826).
- commit 29c54c6
* Wed Oct 21 2015 mhocko@suse.cz
- Refresh
  patches.fixes/scsi-fix-scsi_error_handler-vs.-scsi_host_dev_releas.patch.
  update reference as the patch was merged
- commit 3a32c4c
* Tue Oct 20 2015 hare@suse.de
- dm: impose configurable deadline for dm_request_fn's merge
  heuristic (bsc#904348).
- dm: don't start current request if it would've merged with
  the previous (bsc#904348).
- dm sysfs: introduce ability to add writable attributes
  (bsc#904348).
- ktime: add ktime_after and ktime_before helpe (bsc#904348).
- pktgen: clean up ktime_t helpers (bsc#904348).
- commit 60a5b64
* Tue Oct 20 2015 oneukum@suse.com
- xhci: Add spurious wakeup quirk for LynxPoint-LP controllers
  (bnc#949981).
- commit 06372b4
* Fri Oct 16 2015 mmarek@suse.com
- Delete unused rpm/config-subst.
- commit a8f3dd4
* Fri Oct 16 2015 jdelvare@suse.de
- Update
  patches.fixes/fanotify-fix-deadlock-during-thread-exit.patch
  (bsc#935053, bsc#926709).
  Add bug reference.
- commit f3e5e0f
* Fri Oct 16 2015 rgoldwyn@suse.com
- IB/srp: Avoid skipping srp_reset_host() after a transport  error
  (bsc#904965).
- IB/srp: Fix a sporadic crash triggered by cable pulling
  (bsc#904965).
- commit 36e4bf2
* Thu Oct 15 2015 hare@suse.de
- qla2xxx: Remove unavailable firmware files (bsc#921081).
- commit 7a9a4be
* Thu Oct 15 2015 mgalbraith@suse.de
- Refresh patches.fixes/sched-core-Fix-task-and-run-queue-sched_info-run_delay-inconsistencies.patch.
- commit 8e4e277
* Thu Oct 15 2015 mgalbraith@suse.de
- Refresh patches.fixes/sched-core-Fix-task-and-run-queue-sched_info-run_delay-inconsistencies.patch.
- commit c682d3d
* Thu Oct 15 2015 mgalbraith@suse.de
- sched/core: Fix task and run queue sched_info::run_delay inconsistencies (bnc#949100).
- commit b83881c
* Tue Oct 13 2015 vbabka@suse.cz
- mm/memory-failure.c: fix wrong num_poisoned_pages in handling
  memory error on thp (bnc#947957, VM Functionality).
- hwpoison, hugetlb: lock_page/unlock_page does not match for
  handling a free hugepage (bnc#947957, VM Functionality).
- mm/memory-failure.c: recheck PageHuge() after hugetlb page
  migrate successfully (bnc#947957, VM Functionality).
- memory-failure: use num_poisoned_pages instead of mce_bad_pages
  (bnc#947957, VM Functionality).
- memory-failure: do code refactor of soft_offline_page()
  (bnc#947957, VM Functionality).
- memory-failure: fix an error of mce_bad_pages statistics
  (bnc#947957, VM Functionality).
- memory-hotplug: update mce_bad_pages when removing the memory
  (bnc#947957, VM Functionality).
- hugetlb: simplify migrate_huge_page() (bnc#947957, VM
  Functionality).
- mm/migrate.c: pair unlock_page() and lock_page() when migrating
  huge pages (bnc#947957, VM Functionality).
- commit 1139e7c
* Fri Oct  9 2015 jbohac@suse.cz
- ipvs: drop first packet to dead server (bsc#946078).
- ipvs: Fix reuse connection if real server is dead (bnc#945827).
- commit 33cc4a1
* Fri Oct  9 2015 alnovak@suse.cz
- macvlan: Support bonding events
  bsc#948521
- commit 20e3a7f
* Fri Oct  9 2015 lduncan@suse.com
- SCSI: hosts: update to use ida_simple for host_no (bsc#939926)
- commit 401e266
* Thu Oct  8 2015 oneukum@suse.com
- xhci: change xhci 1.0 only restrictions to support xhci 1.1
  (bnc#949502).
- commit 7e35a40
* Tue Oct  6 2015 oneukum@suse.com
- Delete
  patches.drivers/0004-xhci-For-streams-the-css-flag-most-be-read-from-the-.patch.
  It caused a regression. The fix had already gone it.
- commit 780b9eb
* Tue Oct  6 2015 jack@suse.com
- xfs: Fix softlockup in xfs_inode_ag_walk() (bsc#948347).
- commit 76b7cf6
* Tue Oct  6 2015 mkubecek@suse.cz
- ipv6: addrconf: validate new MTU before applying it (bsc#944296
  CVE-2015-0272).
- commit 0283702
* Fri Oct  2 2015 eich@suse.com
- Refresh
  patches.drm/drm-i915-Avoid-race-of-intel_crt_detect_hotplug-with-HPD-interrupt-v2.patch.
- commit bb3c74d
* Wed Sep 30 2015 jbeulich@suse.com
- usbback: correct copy length for partial transfers (bsc#941202).
- x86/ldt: Make modify_ldt synchronous (bsc#938706, CVE-2015-5157).
- Refresh other Xen patches.
- commit 17a1568
* Wed Sep 30 2015 eich@suse.com
- drm/i915: Avoid race of intel_crt_detect_hotplug() with HPD
  interrupt, v2 (bsc#942938).
- Delete
  patches.drm/drm-i915-Avoid-race-of-intel_crt_detect_hotplug-with-HPD-interrupt.patch.
- commit 1b46050
* Mon Sep 28 2015 bp@suse.de
- rtc: cmos: Cancel alarm timer if alarm time is equal to now+1
  seconds (bsc#930145).
- Delete
  patches.fixes/0002-rtc-restore-the-rtc-alarm-time-to-the-configured-ala.patch.
- Delete
  patches.fixes/rtc-cmos-add-an-alarm-disable-quirk-upstream_version.patch.
- Delete patches.fixes/rtc-cmos-add-more-quirks-for-TGCS.patch.
  All those quirk patches cancel each other out due to the real fix.
  So kill them all.
- commit b586792
* Mon Sep 28 2015 jbeulich@suse.com
- x86/ldt: Make modify_ldt synchronous (bsc#938706,
  CVE-2015-5157).
- Refresh patches.xen/1282-usbback-limit-copying.patch (bsc#941202).
- Refresh other Xen patches.
- commit 85bf1c9
* Mon Sep 28 2015 mgalbraith@suse.de
- Disable 0004-xhci-For-streams-the-css-flag-most-be-read-from-the-.patch
- commit 83037be
* Fri Sep 25 2015 bp@suse.de
- RDS: verify the underlying transport exists before creating
  a connection (bsc#945825, CVE-2015-6937).
- commit 72893d4
* Wed Sep 23 2015 bp@suse.de
- x86/ldt: Further fix FPU emulation (bsc#938706, CVE-2015-5157).
- x86/ldt: Correct FPU emulation access to LDT (bsc#938706,
  CVE-2015-5157).
- x86/ldt: Correct LDT access in single stepping logic
  (bsc#938706, CVE-2015-5157).
- x86/ldt: Make modify_ldt synchronous (bsc#938706,
  CVE-2015-5157).
- rcu: Move lockless_dereference() out of rcupdate.h (bsc#938706,
  CVE-2015-5157).
- x86/nmi/64: Switch stacks on userspace NMI entry (bsc#938706,
  CVE-2015-5157).
- commit 7b248d5
* Tue Sep 22 2015 oneukum@suse.com
- XHCI: use uninterruptible sleep for waiting for internal
  operations (bnc#939955).
- commit dec1ea8
* Tue Sep 22 2015 neilb@suse.com
- Make sure XPRT_CONNECTING gets cleared when needed (bsc#946309).
- commit 5742b98
* Wed Sep 16 2015 alnovak@suse.cz
- fix lpfc_send_rscn_event allocation size claims
  bnc#935757
- commit 528e1a1
* Mon Sep 14 2015 oneukum@suse.com
- xhci: For streams the css flag most be read from the stream-ctx
  on ep stop (bnc#945691).
- commit 06dfe7b
* Fri Sep 11 2015 ohering@suse.de
- Drivers: hv: vmbus: prefer 'die' notification chain to 'panic'.
- Drivers: hv: vmbus: add special crash handler (bnc#930770).
- Drivers: hv: don't do hypercalls when hypercall_page is NULL.
- Drivers: hv: vmbus: add special kexec handler.
- Drivers: hv: vmbus: remove hv_synic_free_cpu() call from
  hv_synic_cleanup().
- Drivers: hv: vmbus: kill tasklets on module unload.
- commit 739ab7d
* Fri Sep 11 2015 ohering@suse.de
- Drivers: hv: vmbus: Implement the protocol for tearing down vmbus state.
- commit 8548e21
* Fri Sep 11 2015 ohering@suse.de
- drivers: hv: vmbus: Get rid of some unused definitions.
- Drivers: hv: vmbus: unregister panic notifier on module unload.
- Drivers: hv: kvp: move poll_channel() to hyperv_vmbus.h.
- Drivers: hv: util: move kvp/vss function declarations to
  hyperv_vmbus.h.
- commit 7704a7c
* Wed Sep  9 2015 oneukum@suse.com
- usb: xhci: apply XHCI_AVOID_BEI quirk to all Intel xHCI
  controllers (bnc#944989).
- commit 65ff0e8
* Tue Sep  8 2015 oneukum@suse.com
- xhci: fix isoc endpoint dequeue from advancing too far on
  transaction error (bnc#944837).
- commit e68accc
* Tue Sep  8 2015 oneukum@suse.com
- xhci: Calculate old endpoints correctly on device reset
  (bnc#944831).
- commit 81e3ebc
* Mon Sep  7 2015 oneukum@suse.com
- ehci-pci: enable interrupt on BayTrail (bnc926007).
- commit 6354de6
* Mon Aug 31 2015 eich@suse.com
- drm/i915: WARN_ONCE() about unexpected interrupts for all
  chipsets (bsc#942938).
- drm/i915: Only print hotplug event message when hotplug bit
  is set (bsc#942938).
- drm/i915: Use an interrupt save spinlock in
  intel_hpd_irq_handler() (bsc#942938).
- drm/i915: Queue reenable timer also when
  enable_hotplug_processing is false (bsc#942938).
- drm/i915: Avoid race of intel_crt_detect_hotplug() with HPD
  interrupt (bsc#942938).
- drm/i915: Make hpd arrays big enough to avoid out of bounds
  access (bsc#942938).
- drm/i915: clear crt hotplug compare voltage field before setting
  (bsc#942938).
- drm/i915: assert_spin_locked for pipestat interrupt
  enable/disable (bsc#942938).
- drm/i915: fix hpd work vs. flush_work in the pageflip code
  deadlock (bsc#942938).
- drm/i915: fix hpd interrupt register locking (bsc#942938).
- drm/i915: fold the no-irq check into intel_hpd_irq_handler
  (bsc#942938).
- drm/i915: fold the queue_work into intel_hpd_irq_handler
  (bsc#942938).
- drm/i915: fold the hpd_irq_setup call into intel_hpd_irq_handler
  (bsc#942938).
- drm/i915: s/hotplug_irq_storm_detect/intel_hpd_irq_handler/
  (bsc#942938).
- drm/i915: close tiny race in the ilk pcu even interrupt setup
  (bsc#942938).
- drm/i915: fix locking around ironlake_enable|disable_display_irq
  (bsc#942938).
- drm/i915: Fix up sdvo hpd pins for i965g/gm (bsc#942938).
- drm/i915: Don't WARN nor handle unexpected hpd interrupts on
  gmch platforms (bsc#942938).
- drm/i915: Enable hotplug interrupts after querying hw
  capabilities (bsc#942938).
- drm/i915: Fix hotplug interrupt enabling for SDVOC (bsc#942938).
- drm/i915: fix hotplug event bit tracking (bsc#942938).
- drm/i915: Add messages useful for HPD storm detection debugging
  (v2) (bsc#942938).
- drm/i915: Only reprobe display on encoder which has received
  an HPD event (v2) (bsc#942938).
- drm/i915: Add bit field to record which pins have received
  HPD events (v3) (bsc#942938).
- drm/i915: Add Reenable Timer to turn Hotplug Detection back on
  (v4) (bsc#942938).
- drm/i915: Disable HPD interrupt on pin when irq storm is
  detected (v3) (bsc#942938).
- drm/i915: Mask out the HPD irq bits before setting them
  individually (bsc#942938).
- drm/i915: (re)init HPD interrupt storm statistics (bsc#942938).
- drm/i915: Add HPD IRQ storm detection (v5) (bsc#942938).
- DRM/i915: Get rid if the 'hotplug_supported_mask' in struct
  drm_i915_private (bsc#942938).
- DRM/i915: Remove i965_hpd_irq_setup (bsc#942938).
- drm/i915: implement ibx_hpd_irq_setup (bsc#942938).
- DRM/i915: Convert HPD interrupts to make use of HPD pin
  assignment in encoders (v2) (bsc#942938).
- DRM/I915: Add enum hpd_pin to intel_encoder (bsc#942938).
- DRM/i915: Remove valleyview_hpd_irq_setup (bsc#942938).
- drm/i915: Remove pch_rq_mask from struct drm_i915_private
  (bsc#942938).
- commit b03b267
* Fri Aug 28 2015 oneukum@suse.com
- xhci: do not report PLC when link is in internal resume state
  (bnc#933721).
- xhci: report U3 when link is in resume state (bnc#933721).
- xhci: Solve full event ring by increasing TRBS_PER_SEGMENT to
  256 (bnc#933721).
- usb: xhci: handle Config Error Change (CEC) in xhci driver
  (bnc#933721).
- xhci: Workaround for PME stuck issues in Intel xhci
  (bnc#933721).
- xhci: fix reporting of 0-sized URBs in control endpoint
  (bnc#933721).
- xhci: Allocate correct amount of scratchpad buffers
  (bnc#933721).
- USB: xhci: Reset a halted endpoint immediately when we encounter
  a stall (bnc#933721).
- USB: xhci: don't start a halted endpoint before its new dequeue
  is set (bnc#933721).
- xhci: rework cycle bit checking for new dequeue pointers
  (bnc#933721).
- xhci: Treat not finding the event_seg on COMP_STOP the same
  as COMP_STOP_INVAL (bnc#933721).
- usb: xhci: Prefer endpoint context dequeue pointer over
  stopped_trb (bnc#933721).
- xhci: Don't enable/disable RWE on bus suspend/resume
  (bnc#933721).
- commit 722469e
* Fri Aug 28 2015 mhocko@suse.cz
- scsi: fix scsi_error_handler vs. scsi_host_dev_release race
  (bnc#942204).
- commit 293a84b
* Fri Aug 28 2015 jbeulich@suse.com
- pci: Add flag indicating device has been assigned by KVM
  (bnc#777565 FATE#313819).
- x86-64: Don't apply destructive erratum workaround on unaffected
  CPUs (bsc#929076).
- Refresh other Xen patches.
- commit a9635b9
* Thu Aug 27 2015 jjolly@suse.de
- kernel: do full redraw of the 3270 screen on reconnect
  (bnc#943477, LTC#129509).
- commit 8f0fe28
* Thu Aug 27 2015 lduncan@suse.com
- Moved iscsi kabi patch to patches.kabi (bsc#923002)
- commit 7fb5059
* Thu Aug 27 2015 jbeulich@suse.com
- pci: Add flag indicating device has been assigned by KVM
  (bnc#777565 FATE#313819).
- Refresh other Xen patches.
- commit f1fc9fb
* Thu Aug 27 2015 jack@suse.com
- inotify: Fix nested sleeps in inotify_read() (bsc#940925).
- commit c87cb0b
* Thu Aug 27 2015 dchang@suse.com
- r8169: remember WOL preferences on driver load (bsc#942305).
- commit b158a4d
* Thu Aug 27 2015 mhocko@suse.cz
- igb: don't reuse pages with pfmemalloc flag fix (bnc#920016).
- commit fca89e9
* Tue Aug 25 2015 bp@suse.de
- vhost: actually track log eventfd file (bsc#942367, CVE-2015-6252).
- commit 1a485c3
* Mon Aug 24 2015 lduncan@suse.com
- Fixing wording in patch comment (bsc#923002)
- commit a7eca24
* Mon Aug 24 2015 lduncan@suse.com
- Rename kabi patch appropriately (bsc#923002)
- commit 4b938c3
* Mon Aug 24 2015 lduncan@suse.com
- SCSI: kabi: allow iscsi disocvery session support (bsc#923002).
- IB/iser: Add Discovery support (bsc#923002).
- libiscsi: Exporting new attrs for iscsi session and connection
  in sysfs (bsc#923002).
- scsi_transport_iscsi: Exporting new attrs for iscsi session
  and connection in sysfs (bsc#923002).
- IB/iser: Move informational messages from error to info level
  (bsc#923002).
- commit 2a1a592
* Mon Aug 24 2015 mhocko@suse.cz
- kabi:
  patches.fixes/mm-make-page-pfmemalloc-check-more-robust.patch
  (bnc#920016).
- mm: make page pfmemalloc check more robust (bnc#920016).
- commit 9e60ea2
* Fri Aug 21 2015 fdmanana@suse.com
- Btrfs: fix hang when failing to submit bio of directIO
  (bnc#942688).
- Btrfs: fix memory corruption on failure to submit bio for
  direct IO (bnc#942688).
- Btrfs: fix put dio bio twice when we submit dio bio fail
  (bnc#942688).
- commit e43d26c
* Fri Aug 21 2015 mkubecek@suse.cz
- ipv6: probe routes asynchronous in rt6_probe (bsc#936118).
- commit 5cd24c0
* Fri Aug 21 2015 tiwai@suse.de
- x86/tsc: Change Fast TSC calibration failed from error to info
  (bnc#942605).
- commit c618716
* Fri Aug 21 2015 mkubecek@suse.cz
- netfilter: nf_conntrack_proto_sctp: minimal multihoming support
  (bsc#932350).
- commit 989f048
* Wed Aug 19 2015 fdmanana@suse.com
- Btrfs: check if previous transaction aborted to avoid fs
  corruption (bnc#942404).
- Btrfs: deal with convert_extent_bit errors to avoid fs
  corruption (bnc#942404).
- Btrfs: be aware of btree inode write errors to avoid fs
  corruption (bnc#942404).
- commit f1b66e5
* Wed Aug 19 2015 fdmanana@suse.com
- Btrfs: check if previous transaction aborted to avoid fs
  corruption (bnc#942350).
- Btrfs: deal with convert_extent_bit errors to avoid fs
  corruption (bnc#942350).
- Btrfs: be aware of btree inode write errors to avoid fs
  corruption (bnc#942350).
- commit 265cc32
* Wed Aug 19 2015 vbabka@suse.cz
- mm, thp: fix collapsing of hugepages on madvise (VM
  Functionality).
- commit 254446a
* Wed Aug 19 2015 jack@suse.com
- [SCSI] vmw_pvscsi: Fix pvscsi_abort() function (bnc#940398
  bsc#930934).
- commit e83cd7c
* Wed Aug 19 2015 vbabka@suse.cz
- mm, thp: respect MPOL_PREFERRED policy with non-local node
  (VM Performance, bnc#931620).
- mm, thp: really limit transparent hugepage allocation to local
  node (VM Performance, bnc#931620).
- mm, THP: don't hold mmap_sem in khugepaged when allocating THP
  (VM Performance).
- mm, thp: only collapse hugepages to nodes with affinity for
  zone_reclaim_mode (VM Functionality, bnc#931620).
- mm: thp: khugepaged: add policy for finding target node (VM
  Functionality, bnc#931620).
- mm/mempolicy.c: merge alloc_hugepage_vma to alloc_pages_vma
  (VM Performance, bnc#931620).
- mm/thp: allocate transparent hugepages on local node (VM
  Performance, bnc#931620).
- mm, mempolicy: remove duplicate code (VM Functionality,
  bnc#931620).
- commit a2c94aa
* Wed Aug 19 2015 jlee@suse.com
- Update patch name and description for lock down pci register
- PCI: Lock down register access when trusted_kernel is true
  (fate#314486, bnc#884333)(bsc#923431).
- Delete
  patches.suse/0002_V3_PCI_Lock_down_BAR_access_when_module_security_is_enabled.patch.
- commit f1eb1d2
* Tue Aug 18 2015 jjolly@suse.de
- s390/dasd: fix kernel panic when alias is set offline
  (bnc#940966, LTC#128595).
- commit dec1d19
* Tue Aug 18 2015 jthumshirn@suse.de
- Update
  patches.fixes/sg_start_req-make-sure-that-there-s-not-too-many-elements-in-iovec.patch
  (bsc#940338, CVE-2015-5707).
- commit 6a941f4
* Mon Aug 17 2015 mgorman@suse.com
- exec: kill the unnecessary mm->def_flags setting in load_elf_binary() (prctl support for disabling THP (fate#317831,bnc#891116)).
- commit f90b13f
* Mon Aug 17 2015 hare@suse.de
- Drop patches.fixes/dm-table-switch-to-readonly (bsc#928801)
  * Refresh patches.fixes/0001-dm-optimize-use-SRCU-and-RCU.patch.
  * Refresh
  patches.fixes/dm-ignore-merge_bvec-for-snapshots-when-safe.patch.
  * Delete patches.fixes/dm-release-map_lock-before-set_disk_ro.
  * Delete patches.fixes/dm-table-switch-to-readonly.
- commit 6f7451f
* Fri Aug 14 2015 mhocko@suse.cz
- mm: exclude reserved pages from dirtyable memory 32b fix
  (bnc#940017, bnc#949298).
- Refresh
  patches.suse/mm-page-writeback.c-do-not-count-anon-pages-as-dirtyable-memory.patch.
- commit 35e1a4d
* Fri Aug 14 2015 jthumshirn@suse.de
- sg_start_req(): make sure that there's not too many elements
  in iovec (bsc#940338).
- commit 73e08d1
* Fri Aug 14 2015 ohering@suse.de
- hv_storvsc: use small sg_tablesize on x86 (bnc#937256).
- commit c0a1996
* Fri Aug 14 2015 dvaleev@suse.com
- ibmveth: add support for TSO6.
- commit 3a40c56
* Wed Aug 12 2015 mgalbraith@suse.de
- hrtimer: prevent timer interrupt DoS (bnc#886785).
- commit 4f4c909
* Mon Aug 10 2015 brogers@suse.com
- kabi: wrapper include file with __GENKSYMS__ check to avoid
  kabi change (bsc920110).
- PCI: Disable Bus Master only on kexec reboot (bsc#920110).
- PCI: Don't try to disable Bus Master on disconnected PCI devices
  (bsc#920110).
- PCI: Disable Bus Master unconditionally in pci_device_shutdown()
  (bsc#920110).
- PCI: disable Bus Master on PCI device shutdown (bsc#920110).
- commit ae5321b
* Fri Aug  7 2015 tonyj@suse.de
- perf, nmi: Fix unknown NMI warning (bsc#929142).
- perf/x86/intel: Move NMI clearing to end of PMI handler
  (bsc#929142).
- commit 6e27b71
* Fri Aug  7 2015 mhocko@suse.cz
- panic/x86: Allow cpus to save registers even if they (bnc#940946).
- commit f44f251
* Thu Aug  6 2015 mhocko@suse.cz
- kexec: Fix race between panic() and crash_kexec() called
  directly (bnc#937444).
- panic/x86: Fix re-entrance problem due to panic on (bnc#937444).
- commit 5b0149d
* Wed Aug  5 2015 neilb@suse.com
- NFSv4: Minor cleanups for nfs4_handle_exception and
  nfs4_async_handle_error (bsc#939910).
- commit a9c75f3
* Mon Aug  3 2015 neilb@suse.com
- md: use kzalloc() when bitmap is disabled (bsc#939994).
- commit c91ae2d
* Thu Jul 30 2015 hare@suse.de
- megaraid_sas: Use correct reset sequence in adp_reset()
  (bsc#894936).
- megaraid_sas: Use correct reset sequence in adp_reset()
  (bsc#938485).
- commit 8c50c4f
* Tue Jul 28 2015 mhocko@suse.cz
- kdump: fix crash_kexec()/smp_send_stop() race in panic()
  (bnc#937444).
- commit 64bb43b
* Tue Jul 28 2015 alnovak@suse.cz
- patches.fixes/xfs-fix-check-logbsize-is-integer-multiple-of-lsunit.patch
  this patch is not yet in upstream kernel, since the maintainer doesn't
  seem to be really interested in the problem. After discussion with
  Jan Kara, we decided to take it to our kernel though.
  (bnc#925705)
- commit c69dffb
* Fri Jul 24 2015 jkosina@suse.com
- Fix missing crypto allocation (bnc#937402).
- commit eed4350
* Fri Jul 24 2015 neilb@suse.com
- nfsd: support disabling 64bit dir cookies (bnc#937503).
- commit 815efaf
* Tue Jul 21 2015 mhocko@suse.cz
- mm: restrict access to slab files under procfs and sysfs
  (bnc#936077).
- commit ab99278
* Tue Jul 21 2015 mfasheh@suse.de
- xfs: Skip dirty pages in ->releasepage (bnc#912738, bnc#915183).
- commit fc14f8a
* Mon Jul 20 2015 mkubecek@suse.cz
- net: Fix "ip rule delete table 256" (bsc#873385).
- commit ea6ae3f
* Thu Jul 16 2015 dvaleev@suse.com
- ibmveth: Add support for Large Receive Offload (bsc#935055).
- ibmveth: Add GRO support (bsc#935055).
- ibmveth: Add support for TSO (bsc#935055).
- ibmveth: change rx buffer default allocation for CMO
  (bsc#935055).
- commit fb3606e
* Wed Jul 15 2015 neilb@suse.com
- NFSD: Fix nfsv4 opcode decoding error (bsc#935906).
- commit 5b6c9c9
* Wed Jul 15 2015 hare@suse.de
- Set hostbyte status in scsi_check_sense() (bsc#920733).
- scsi_error: add missing case statements in
  scsi_decide_disposition() (bsc#920733).
- Delete
  patches.xen/xen3-scsi_error-classify-some-ILLEGAL_REQUEST-sense-.patch.
- commit 8280eaa
* Tue Jul 14 2015 mhocko@suse.cz
- fork: reset mm->pinned_vm (bnc#937855).
- IB/core: Fix mismatch between locked and pinned pages
  (bnc#937855).
- commit 8db3bf4
* Tue Jul 14 2015 oneukum@suse.com
- usb: core: Fix USB 3.0 devices lost in NOTATTACHED state after
  a hub port reset (bnc#937641).
- commit 50a917b
* Fri Jul 10 2015 jroedel@suse.de
- x86/mm: Improve AMD Bulldozer ASLR workaround (bsc#937032).
- commit bd8b963
* Fri Jul 10 2015 jack@suse.com
- fanotify: Fix deadlock with permission events (bsc#935053).
- commit 63440e1
* Fri Jul 10 2015 bpoirier@suse.com
- vmxnet3: Bump up driver version number (bsc#936423).
- commit 657a3b7
* Tue Jul  7 2015 jbohac@suse.cz
- Update patches.fixes/udp-fix-behavior-of-wrong-checksums.patch
  (bsc#936831, CVE-2015-5364, CVE-2015-5366).
- commit 98ee143
* Sat Jul  4 2015 jjolly@suse.de
- zcrypt: Fixed reset and interrupt handling of AP queues
  (bnc#936921, LTC#126491).
- commit 03ec3ed
* Fri Jul  3 2015 jjolly@suse.de
- zcrypt: Fixed reset and interrupt handling of AP queues
  (bnc#936925, LTC#126491).
- commit 9055703
* Fri Jul  3 2015 jack@suse.com
- ext3: Fix data corruption in inodes with journalled data
  (bsc#936637).
  Refresh patches.suse/nfs4acl-ext3.diff.
- commit 9c46cc9
* Thu Jul  2 2015 jbohac@suse.cz
- udp: fix behavior of wrong checksums (bsc#936831,
  CVE-2015-5364).
- commit 0705f59
* Thu Jul  2 2015 jthumshirn@suse.de
- st: null pointer dereference panic caused by use after kref_put
  by st_open (bsc#936875).
- commit 00bbfe7
* Wed Jul  1 2015 bpoirier@suse.com
- Update
  patches.drivers/vmxnet3-Changes-for-vmxnet3-adapter-version-2-fwd.patch
  (bsc#936423).
- Update
  patches.drivers/vmxnet3-Fix-memory-leaks-in-rx-path-fwd.patch
  (bsc#936423).
- Update
  patches.drivers/vmxnet3-Register-shutdown-handler-for-device-fwd.patch
  (bsc#936423).
  s/bug#/bsc#/
- commit f8f3ed2
* Wed Jul  1 2015 bpoirier@suse.com
- vmxnet3: Changes for vmxnet3 adapter version 2 (fwd)
  (bug#936423).
- vmxnet3: Fix memory leaks in rx path (fwd) (bug#936423).
- vmxnet3: Register shutdown handler for device (fwd)
  (bug#936423).
- commit bab7abc
* Wed Jul  1 2015 mszeredi@suse.cz
- apparmor: fix file_permission if profile is updated
  (bsc#917968).
- commit b8caeba
* Wed Jul  1 2015 mszeredi@suse.cz
- vfs: read file_handle only once in handle_to_path (bsc#915517
  CVE-2015-1420).
- commit b475329
* Fri Jun 26 2015 tiwai@suse.de
- x86: bpf_jit: fix compilation of large bpf programs
  (bnc#935705,CVE-2015-4700).
- commit 66029e9
* Fri Jun 26 2015 glin@suse.com
- qlcnic: Fix NULL pointer dereference in qlcnic_hwmon_show_temp()
  (bsc#936095).
- commit a3b6c62
* Wed Jun 24 2015 jroedel@suse.de
- iommu/amd: Handle large pages correctly in free_pagetable
  (bsc#935866).
- commit 9cb6904
* Wed Jun 24 2015 jroedel@suse.de
- iommu/amd: Fix memory leak in free_pagetable (bsc#935866).
- commit ad22a6e
* Tue Jun 23 2015 jroedel@suse.de
- mlx4: Check for assigned VFs before disabling SR-IOV
  (bsc#927355).
- ixgbe: Use pci_vfs_assigned instead of ixgbe_vfs_are_assigned
  (bsc#927355).
- pci: Add SRIOV helper function to determine if VFs are assigned
  to guest (bsc#927355).
  Refreshed patches.xen/xen3-patch-2.6.31 due to conflicts
  with this patch.
- net/mlx4_core: Don't disable SRIOV if there are active VFs
  (bsc#927355).
- commit 2982205
* Mon Jun 22 2015 mkubecek@suse.cz
- net: fib6: fib6_commit_metrics: fix potential NULL pointer
  dereference (bsc#867362).
- net: ipv6: fib: don't sleep inside atomic lock (bsc#867362).
- commit 94ef691
* Mon Jun 22 2015 eich@suse.com
- drm/mgag200: do not attempt to acquire a reservation while in
  an interrupt handler (FATE#317582).
- drm/cirrus: do not attempt to acquire a reservation while in
  an interrupt handler (bsc#935572).
- drm: ast,cirrus,mgag200: use drm_can_sleep (FATE#317582, bnc#883380,
  bsc#935572).
- drm/mgag200: Don't do full cleanup if mgag200_device_init fails
  (FATE#317582).
- Update
  patches.drm/drm-mgag200-ast-cirrus-fix-regression-with-drm_can_sleep-conversion.patch
  (FATE#317582, bnc#883380, bsc#935572).
- Delete patches.drm/drm-ast-use-drm_can_sleep.patch.
- commit 6140ea3
* Thu Jun 18 2015 hare@suse.de
- Delete patches.suse/scsi-Debug-sg-tablesize-mismatch.patch (bsc#935120).
- commit 4b89d0c
* Wed Jun 17 2015 ptesarik@suse.cz
- libata: prevent HSM state change race between ISR and PIO
  (bsc#923245).
- commit 55f6abe
* Wed Jun 17 2015 hare@suse.de
- Fix typo in patches.fixes/block-Discard-bios-do-not-have-data.patch.
- commit 8e18df4
* Tue Jun 16 2015 jroedel@suse.de
- kvm: irqchip: Break up high order allocations of kvm_irq_routing_table (bnc#926953).
- commit decb135
* Tue Jun 16 2015 jack@suse.cz
- udf: Check length of extended attributes and allocation
  descriptors (bsc#933907 CVE-2015-4167).
- udf: Remove repeated loads blocksize (bsc#933907).
- commit 6b40c47
* Tue Jun 16 2015 jack@suse.cz
- Update references in
  patches.fixes/udf-Check-component-length-before-reading-it.patch
  (bsc#933904 CVE-2014-9728 CVE-2014-9730).
- Update references in
  patches.fixes/udf-Verify-i_size-when-loading-inode.patch
  (bsc#933904 CVE-2014-9728 CVE-2014-9729).
- Update references in
  patches.fixes/udf-Verify-symlink-size-before-loading-it.patch
  (bsc#933904 CVE-2014-9728).
- commit 4734813
* Tue Jun 16 2015 jack@suse.cz
- Ext4: handle SEEK_HOLE/SEEK_DATA generically (bsc#934944).
- commit 2741604
* Tue Jun 16 2015 jack@suse.cz
- Update references in
  patches.fixes/udf-Check-path-length-when-reading-symlink.patch
  (bsc#933896 CVE-2014-9731).
- commit d604fde
* Tue Jun 16 2015 mgalbraith@suse.de
- sched: fix __sched_setscheduler() vs load balancing race (bnc#921430)
- commit 7170f56
* Mon Jun 15 2015 mkubecek@suse.cz
- Update patches.fixes/kernel-add-panic_on_warn.patch references
  (bsc#934742).
- commit 829bbcb
* Mon Jun 15 2015 hare@suse.de
- block: Discard bios do not have data (bsc#928988).
- commit 4b48a90
* Mon Jun 15 2015 jbeulich@suse.com
- pciback: limit guest control of command register (bsc#919463
  CVE-2015-2150 XSA-120).
- usbback: copy only filled buffers to guest (bsc#917830
  CVE-2015-0777).
- xenbus: add proper handling of XS_ERROR from Xenbus for
  transactions.
- x86, tls, ldt: Stop checking lm in LDT_empty (bsc#920250).
- x86, tls: Interpret an all-zero struct user_desc as "no segment"
  (bsc#920250).
- x86/asm/entry/64: Remove a bogus 'ret_from_fork' optimization
  (bsc#926240, CVE-2015-2830).
- Refresh other Xen patches.
- Delete patches.xen/xen-pciback-decode.
- Delete patches.xen/xen-usbback-limit-copying.
- Delete
  patches.xen/xen3-x86-tls-interpret-an-all-zero-struct-user_desc-as-no-segment.patch.
- commit 197c925
* Mon Jun 15 2015 nfbrown@suse.de
- NFS: never queue requests with rq_cong set on the sending queue
  (bsc#932458).
- commit 5d8b9c1
* Fri Jun 12 2015 mkubecek@suse.cz
- kernel: add panic_on_warn.
- commit 6c42eda
* Fri Jun 12 2015 jbohac@suse.cz
- supported.conf: enable sch_mqprio (bsc#932882)
- commit 687a617
* Thu Jun 11 2015 mszeredi@suse.cz
- pipe: fix iov overrun for failed atomic copy (bsc#933429
  CVE-2015-1805).
- commit ea4314a
* Thu Jun 11 2015 hare@suse.de
- scsi: Debug sg tablesize mismatch (bsc#933782).
- commit cb4c719
* Wed Jun 10 2015 hare@suse.de
- iscsi_ibft: Define missing 'ibft_addr' (bsc#932047).
- commit f64b71d
* Wed Jun 10 2015 hare@suse.de
- fixup iBFT support on ia64 (bsc#932047)
  * Update config files.
  * Refresh
    patches.suse/firmware-iBFT-firmware-is-also-supported-on-EFI-mach.patch.
- commit 15d79c2
* Tue Jun  9 2015 jjolly@suse.de
- s390/pci: fix possible information leak in mmio syscalls
  (bnc#932697, LTC#125551).
- commit ce696e4
* Tue Jun  9 2015 mszeredi@suse.cz
- Revert "pipe: fix iov overrun for failed atomic copy (bsc#933429"
  This reverts commit 78ad0e0150743d08ba00865f0e5f3480c9bed132.
- commit fa66b2d
* Tue Jun  9 2015 dmueller@suse.com
- Add scsi-correctly-set-scsi-host-msg-status-bytes.patch (bnc#933936)
- commit 2942fa9
* Tue Jun  9 2015 lduncan@suse.com
- Re-arrange scsi/libiscsi kabi fix (bsc#920907)
  This commit alters 3 existing patches and adds one new one. The
  end result (the code) is the same, except that sections of
  scsi code that reference unused sysfs attributes have the
  ifdef removing them changed from "#if 0" to
  "#ifdef SYSFS_UNUSED_ATTRS".
  Changes:
- patches.drivers/ib-iser-add-discovery-support
  - rebased
- patches.drivers/libiscsi-exporting-new-attrs-for-iscsi-session-and-connection-in-sysfs, and
  patches.drivers/scsi_transport_iscsi-exporting-new-attrs-for-iscsi-session-and-connection-in-sysfs
  - removed the "#if 0"s added to remove unused sysfs fields
- patches.suse/scsi-limit-kabi-changes-to-discovery-session
  - new patch created to ifdef out unused sysfs fields, as
    well as put "#ifndef __GENKSYMS__" around kabi-sensitive
    changes
- commit 4f1ceb0
* Mon Jun  8 2015 mszeredi@suse.cz
- pipe: fix iov overrun for failed atomic copy (bsc#933429
  CVE-2015-1805).
- commit 78ad0e0
* Mon Jun  8 2015 jroedel@suse.de
- iommu/amd: Handle integer overflow in dma_ops_area_alloc
  (bsc#931538).
- commit 41c202c
* Sun Jun  7 2015 bpoirier@suse.com
- e1000e: Bump the version to 3.2.5 (bug#923242).
- e1000e: fix unit hang during loopback test (bug#923242).
- e1000e: fix systim issues (bug#923242).
- e1000e: fix legacy interrupt handling in i219 (bug#923242).
- e1000e: fix flush_desc_ring implementation (bug#923242).
- e1000e: fix logical error in flush_desc_rings (bug#923242).
- e1000e: remove call to do_div and sign mismatch warning
  (bug#923242).
- e1000e: i219 execute unit hang fix on every reset or power
  state transition (bug#923242).
- e1000e: i219 fix unit hang on reset and runtime D3 (bug#923242).
- e1000e: fix call to do_div() to use u64 arg (bug#923242).
- e1000e: Cleanup handling of VLAN_HLEN as a part of max frame
  size (bug#923242).
- e1000e: NVM write protect access removed from SPT HW
  (bug#923242).
- e1000e: call netif_carrier_off early on down (bug#923242).
- commit 8f215b6
* Fri Jun  5 2015 mhocko@suse.cz
- hugetlb, kabi: do not account hugetlb pages as NR_FILE_PAGES
  (bnc#930092).
- commit d5a0126
* Fri Jun  5 2015 noel.power@suse.com
- client MUST ignore EncryptionKeyLength if CAP_EXTENDED_SECURITY
  is set (bnc#932348).
- commit 1c52cc6
* Fri Jun  5 2015 duwe@suse.de
- kabi/severities:
  The IPMI driver subdirectory is self-contained, ignore KABI changes.
- commit 1937b91
* Fri Jun  5 2015 hare@suse.de
- firmware: iBFT firmware is also supported on EFI machines with
  ACPI (bsc#932047).
- Update config files.
- commit f79d123
* Fri Jun  5 2015 lduncan@suse.com
- Fixing kabi breakage from previous fix (bsc#920907)
  ifdefed-out non-needed parts of two patches, to minimize
  kabi changes, used ifdef to protect remaining new
  enum and struct field, and refreshed ib-iser-add-discovery-support
- commit 5d053d9
* Thu Jun  4 2015 dsterba@suse.cz
- Btrfs: fix up bounds checking in lseek (bnc#916521).
- commit 11b0058
* Wed Jun  3 2015 dvaleev@suse.com
- ipr: Increase default adapter init stage change timeout
  (bsc#930761).
- commit 31989f1
* Wed Jun  3 2015 tonyj@suse.de
- audit: keep inode pinned (bsc#851068).
- commit 09b646d
* Tue Jun  2 2015 jjolly@suse.de
- IB/iser: Enable iser when FMRs are not supported (bnc#930274).
- commit de0f520
* Tue Jun  2 2015 mmarek@suse.cz
- Import kabi files from RC2
- commit 14ecf27
* Tue Jun  2 2015 lduncan@suse.com
- IB/iser: Add Discovery support (bsc#920907).
- libiscsi: Exporting new attrs for iscsi session and connection
  in sysfs (bsc#920907).
- scsi_transport_iscsi: Exporting new attrs for iscsi session
  and connection in sysfs (bsc#920907).
- IB/iser: Move informational messages from error to info level
  (bsc#920907).
- commit da9d2fb
* Fri May 29 2015 tiwai@suse.de
- rtlwifi: rtl8192cu: Fix kernel deadlock (bnc#927786).
- commit 00ed9b1
* Thu May 28 2015 bpoirier@suse.de
- mlx4_core: Fix fallback from MSI-X to INTx (bug#930480).
- commit de81b4a
* Thu May 28 2015 bpoirier@suse.de
- be2net: implement .sriov_configure() PCI callback (bug#908322
  FATE#317535).
- be2net: re-distribute SRIOV resources allowed by FW (bug#908322
  FATE#317535).
- be2net: avoid creating the non-RSS default RXQ if FW allows to
  (bug#908322 FATE#317535).
- be2net: move interface create code to a separate routine
  (bug#908322 FATE#317535).
- commit 84dfc25
* Thu May 28 2015 mhocko@suse.cz
- Refresh patches.fixes/deal-with-deadlock-in-d_walk-fix.patch.
  based on 3.2 stable fix 20defcec264c ("dcache: Fix locking bugs in
  backported "deal with deadlock in d_walk()""). Not harmfull for regular
  SLES kernels but RT or PREEMPT kernels would see disbalance.
- commit 4d6cb73
* Wed May 27 2015 dsterba@suse.cz
- Btrfs: fix race when reusing stale extent buffers that leads
  to BUG_ON.
- Btrfs: btrfs_release_extent_buffer_page didn't free pages of
  dummy extent (bnc#930226 bnc#916521).
- commit 5e89917
* Wed May 27 2015 bp@suse.de
- x86, mce: Introduce mce_gather_info() (bsc#914987).
- x86/mce: Fix mce regression from recent cleanup (bsc#914987).
- x86/mce: Update MCE severity condition check (bsc#914987).
- commit 41e1045
* Wed May 27 2015 jslaby@suse.cz
- Update patches.arch/kvm-x86-improve-thread-safety-in-pit.patch
  (CVE-2014-3611 bnc#899192).
  Update references and upstream status.
- commit 5d40f8c
* Tue May 26 2015 jjolly@suse.de
- crypto: s390 - fix incorrect ghash icv buffer handling
  (bnc#932055, LTC#125410).
- commit b320d03
* Tue May 26 2015 hare@suse.de
- st: fix corruption of the st_modedef structures in
  st_set_options() (bnc#928333).
- commit d766098
* Sat May 23 2015 lduncan@suse.com
- iscsi_ibft: Fix finding Broadcom specific ibft sign
  (bsc#932035).
- commit f2a72c0
* Fri May 22 2015 mhocko@suse.cz
- hugetlb: do not account hugetlb pages as NR_FILE_PAGES
  (bnc#930092).
- commit ff95282
* Fri May 22 2015 hare@suse.de
- lpfc: Fix race on command completion (bnc#906027,bnc#889221).
- commit 3a86544
* Fri May 22 2015 tiwai@suse.de
- x86, kvm: Remove incorrect redundant assembly constraint (bnc#931850).
- x86, kvm: Remove incorrect redundant assembly constraint
  (bnc#931850).
- commit 3d08a51
* Thu May 21 2015 trenn@suse.de
- Refresh
  patches.arch/0001-intel_idle-Support-Intel-Atom-Processor-C2000-Produc.patch.
- commit 08985bc
* Thu May 21 2015 trenn@suse.de
- Add deep sleep (idle) support for specific Intel BDW-H CPU (bnc#925340)
  Refresh patches.arch/intel_idle-broadwell-support.patch.
- commit 6006665
* Thu May 21 2015 mszeredi@suse.cz
- Refresh patches.suse/fs-add-link-restrictions.patch. (bnc#931200)
- commit e9b71c5
* Thu May 21 2015 hare@suse.de
- Fixup
  patches.fixes/edd-support-original-Phoenix-EDD-3.0-information.patch.
- commit f83cf11
* Thu May 21 2015 hare@suse.de
- edd: support original Phoenix EDD 3.0 information
  (bnc#762285,bsc#929974).
- Delete
  patches.fixes/edd-check-for-correct-device_path_info_length.patch.
- commit 68288ee
* Thu May 21 2015 eich@suse.com
- disable: 0002-rtc-restore-the-rtc-alarm-time-to-the-configured-ala.patch
- resurrect: rtc-cmos-add-more-quirks-for-TGCS.patch
  for the time being. Per request: (bnc#930145)
- commit 910248a
* Wed May 20 2015 ohering@suse.de
- hyperv: Negotiate version with the host without waiting for
  the daemon (bnc#930821).
- commit 205fd43
* Tue May 19 2015 duwe@suse.de
- ipmi: Turn off all activity on an idle ipmi interface
  (bsc#915747).
- commit 3638b14
* Tue May 19 2015 duwe@suse.de
- crypto: aesni - fix memory usage in GCM decryption
  (bsc#927257,CVE-2015-3331).
- commit 6e25468
* Tue May 19 2015 dsterba@suse.cz
- Btrfs: fix race when reusing stale extent buffers that leads
  to BUG_ON.
- Btrfs: btrfs_release_extent_buffer_page didn't free pages of
  dummy extent (bnc#930226 bnc#916521).
- Btrfs: fix inode eviction infinite loop after extent_same ioctl
  (bnc#930224 bnc#916521).
- commit 09458b7
* Tue May 19 2015 dsterba@suse.cz
- Update patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch
  (fate#314697 fate#318556).
  Update supported features.
- commit 5754b3f
* Tue May 19 2015 dsterba@suse.cz
- Btrfs: correctly get tree level in tree_backref_for_extent.
- Btrfs: fix race that makes btrfs_lookup_extent_info miss skinny
  extent items.
- Btrfs: fix invalid leaf slot access in btrfs_lookup_extent().
- Btrfs: fix btrfs_print_leaf for skinny metadata.
- Btrfs: fix scrub_print_warning to handle skinny metadata
  extents.
- Btrfs: use correct key when repeating search for extent item.
- Btrfs: fix to search previous metadata extent item since
  skinny metadata.
- Btrfs: fix missing skinny metadata check in scrub_stripe().
- Btrfs: fix qgroup rescan to work with skinny metadata.
- Btrfs: fix extent_from_logical to deal with skinny metadata.
- btrfs: Export btrfs_prev_leaf.
- Btrfs: don't miss skinny extent items on delayed ref head
  contention.
- Btrfs: optimize btrfs_lookup_extent_info().
- Btrfs: check to see if we have an inline item properly.
- Btrfs: make backref walking code handle skinny metadata.
- Btrfs: fix not being able to find skinny extents during
  relocate.
- commit 66798bd
* Mon May 18 2015 jroedel@suse.de
- powerpc/mm: Fix mmap errno when MAP_FIXED is set and mapping
  exceeds the allowed address space (bsc#930669).
- commit 3ef84d6
* Mon May 18 2015 jkosina@suse.cz
- Revert "Update config files: 2048 CPUs on POWER (bsc#930692)"
  This reverts commit bd1aa170883f5273ef2514670ca731644f76c4d8. The
  respective bugzilla has been reopened and the issue needs to be
  reconsidered.
- commit 2d18200
* Mon May 18 2015 duwe@suse.de
- Update config files: 2048 CPUs on POWER (bsc#930692)
- commit bd1aa17
* Mon May 18 2015 eich@suse.com
- rtc: Restore the RTC alarm time to the configured alarm time
  in BIOS Setup (bnc#930145, bnc#927262).
- Delete patches.fixes/rtc-cmos-add-more-quirks-for-TGCS.patch.
- commit 26e5613
* Mon May 18 2015 ohering@suse.de
- storvsc: Set the SRB flags correctly when no data transfer is
  needed (bnc#931130).
- commit 825a958
* Mon May 18 2015 ohering@suse.de
- Delete
  patches.suse/suse-hv-hv_kvp-sles11sp2-negotiate-serveral-versions.patch.
- commit 60e9706
* Fri May 15 2015 jbohac@suse.cz
- ipv6: Don't reduce hop limit for an interface (bsc#922583,
  CVE-2015-2922).
- net: llc: use correct size for sysctl timeout entries
  (bsc#919007, CVE-2015-2041).
- ipv4: Missing sk_nulls_node_init() in ping_unhash() (bsc#929525,
  CVE-2015-3636).
- ipv6: Don't reduce hop limit for an interface (bsc#922583,
  CVE-2015-2922).
- net: llc: use correct size for sysctl timeout entries
  (bsc#919007, CVE-2015-2041).
- ipv4: Missing sk_nulls_node_init() in ping_unhash() (bsc#929525,
  CVE-2015-3636).
- commit 7b1a09b
* Fri May 15 2015 jroedel@suse.de
- iommu/amd: Correctly encode huge pages in iommu page tables
  (bsc#931014).
- iommu/amd: Optimize amd_iommu_iova_to_phys for new fetch_pte
  interface (bsc#931014).
- iommu/amd: Optimize alloc_new_range for new fetch_pte interface
  (bsc#931014).
- iommu/amd: Optimize iommu_unmap_page for new fetch_pte interface
  (bsc#931014).
- iommu/amd: Return the pte page-size in fetch_pte (bsc#931014).
- commit e004fad
* Fri May 15 2015 mhocko@suse.cz
- mm: exclude reserved pages from dirtyable memory (bnc#931015,
  bnc#930788).
- mm: fix calculation of dirtyable memory (bnc#931015,
  bnc#930788).
- mm/page-writeback.c: fix dirty_balance_reserve subtraction
  from dirtyable memory (bnc#931015, bnc#930788).
- Refresh
  patches.fixes/mm-fix-return-type-for-functions-nr_free_-_pages.patch.
- Refresh
  patches.kabi/mm-fix-return-type-for-functions-nr_free_-_pages-kabi.patch.
- Refresh
  patches.suse/mm-page-writeback.c-do-not-count-anon-pages-as-dirtyable-memory.patch.
- commit ead164e
* Fri May 15 2015 jroedel@suse.de
- x86-64: Don't apply destructive erratum workaround on unaffected CPUs (bsc#929076).
- commit d898111
* Fri May 15 2015 hare@suse.de
- Revert patch set 'dm-table-switch-to-readonly' (bsc#928801)
- Refresh
  patches.fixes/dm-ignore-merge_bvec-for-snapshots-when-safe.patch.
- Refresh patches.fixes/dm-optimize-use-SRCU-and-RCU.patch.
- Delete patches.fixes/dm-release-map_lock-before-set_disk_ro.
- Delete patches.fixes/dm-table-switch-to-readonly.
- commit b9af4d0
* Fri May 15 2015 hare@suse.de
- megaraid_sas : Modify return value of
  megasas_issue_blocked_cmd() (bsc#930925).
- commit f386a91
* Fri May 15 2015 jbeulich@suse.com
- x86/asm/entry/64: Remove a bogus 'ret_from_fork' optimization
  (bsc#926240, CVE-2015-2830).
- Refresh other Xen patches.
- commit 88ab2e7
* Fri May 15 2015 mgalbraith@suse.de
- sched: Fix potential near-infinite distribute_cfs_runtime() loop (bnc#930786)
- commit fa5efb1
* Fri May 15 2015 neilb@suse.de
- NFS: Fix a regression in nfs_file_llseek() (bnc#930401).
- commit 3fd447b
* Thu May 14 2015 jack@suse.cz
- lib/string.c: introduce memchr_inv() (bnc#930788).
- commit 50b3247
* Thu May 14 2015 jack@suse.cz
- xfs: add background scanning to clear eofblocks inodes
  (bnc#930788).
- xfs: add minimum file size filtering to eofblocks scan
  (bnc#930788).
- xfs: support multiple inode id filtering in eofblocks scan
  (bnc#930788).
- xfs: add inode id filtering to eofblocks scan (bnc#930788).
- xfs: add XFS_IOC_FREE_EOFBLOCKS ioctl (bnc#930788).
- xfs: create function to scan and clear EOFBLOCKS inodes
  (bnc#930788).
- xfs: make xfs_free_eofblocks() non-static, return EAGAIN on
  trylock failure (bnc#930788).
- xfs: create helper to check whether to free eofblocks on inode
  (bnc#930788).
- xfs: support a tag-based inode_ag_iterator (bnc#930788).
- xfs: add EOFBLOCKS inode tagging/untagging (bnc#930788).
- commit b8696ca
* Thu May 14 2015 jslaby@suse.cz
- tty: Correct tty buffer flush (bnc#929647).
- Delete
  patches.fixes/tty-hold-lock-across-tty-buffer-finding-and-buffer-f.patch.
- commit 98bbb91
* Thu May 14 2015 jslaby@suse.cz
- tty: hold lock across tty buffer finding and buffer filling
  (bnc#929647).
- commit 65d335d
* Tue May 12 2015 mgalbraith@suse.de
- Fix IA64 kernel/kthread.c build woes.
  Hide #include <linux/hardirq.h> from kABI checker.
- commit 6bc7ef5
* Tue May 12 2015 mgalbraith@suse.de
- Fix potential crash in __sched_setscheduler().
  It's illegal to call it in interrupt context, and an SLE12-RT kernel
  did that (with non-standard config, but..).  Be paranoid, guarantee
  it can't possibly happen here
- Modified:
  patches.fixes/sched-provide-rtkthreads-rtworkqueues-boot-options.patch
- commit eb3c512
* Tue May 12 2015 mhocko@suse.cz
- mm/hugetlb: check for pte NULL pointer in __page_check_address()
  (bnc#929143).
- commit 7298e23
* Tue May 12 2015 hare@suse.de
- megaraid_sas : Update threshold based reply post host index
  register (bnc#919808).
- commit 406c1c0
* Mon May 11 2015 mmarek@suse.cz
- x86/reboot: Fix a warning message triggered by stop_other_cpus()
  (bnc#930284).
- Refresh patches.suse/kdb-v4.4-3.1-x86-1.
- commit 9ff36c9
* Mon May 11 2015 jjolly@suse.de
- dasd: Fix inability to set a DASD device offline (bnc#927338,
  LTC#123905).
- dasd: Fix device having no paths after suspend/resume
  (bnc#927338, LTC#123896).
- dasd: Fix unresumed device after suspend/resume (bnc#927338,
  LTC#123892).
- af_iucv: fix AF_IUCV sendmsg() errno (bnc#927338, LTC#123304).
- commit b933f8d
* Mon May 11 2015 jjolly@suse.de
- s390/spinlock: cleanup spinlock code (bnc#925012).
- s390/spinlock: optimize spinlock code sequence (bnc#925012).
- s390/spinlock,rwlock: always to a load-and-test first
  (bnc#925012).
- s390/rwlock: add missing local_irq_restore calls (bnc#925012).
- s390/spinlock: refactor arch_spin_lock_wait[_flags]
  (bnc#925012).
- s390/spinlock: optimize spin_unlock code (bnc#925012).
- s390/time: use stck clock fast for do_account_vtime
  (bnc#925012).
- s390/kernel: use stnsm 255 instead of stosm 0 (bnc#925012).
- s390: avoid z13 cache aliasing (bnc#925012).
- s390/mm: align 64-bit PIE binaries to 4GB (bnc#925012).
- s390/memory hotplug: initialize storage keys (bnc#925012).
- s390: enable large page support with CONFIG_DEBUG_PAGEALLOC
  (bnc#925012).
- s390/facilities: cleanup PFMF and HPAGE machine facility
  detection (bnc#925012).
- s390/mm: use pfmf instruction to initialize storage keys
  (bnc#925012).
- s390/memory hotplug: use pfmf instruction to initialize storage
  keys (bnc#925012).
- s390/mm: speedup storage key initialization (bnc#925012).
- s390: z13 base performance (bnc#925012, LTC#KRN1514).
- commit 2640a5d
* Mon May 11 2015 mhocko@suse.cz
- mm, oom: fix and cleanup oom score calculations (bnc#930171).
- commit eb70d60
* Mon May 11 2015 jroedel@suse.de
- x86/apic/uv: Update the UV APIC HUB check (bsc#929145).
- x86/apic/uv: Update the UV APIC driver check (bsc#929145).
- x86/apic/uv: Update the APIC UV OEM check (bsc#929145).
- commit dc231fb
* Mon May 11 2015 mhocko@suse.cz
- deal with deadlock in d_walk fix (bnc#929148, bnc#929283).
- commit e3ca8a9
* Mon May 11 2015 dsterba@suse.cz
- Enable the EXTENT_SAME ioctl (FATE#306586)
- Refresh
  patches.suse/btrfs-1418-Introduce-extent_read_full_page_nolock.patch.
- Refresh
  patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch.
- Refresh
  patches.suse/btrfs-8283-replace-error-code-from-btrfs_drop_extents.patch.
- commit 7388ba6
* Fri May  8 2015 bpoirier@suse.de
- bnx2x: Fix kdump when iommu=on (bug#921769).
- commit eb6aa55
* Fri May  8 2015 hare@suse.de
- genhd: fix leftover might_sleep() in blk_free_devt()
  (bsc#928040).
- block: Fix dev_t minor allocation lifetime (bsc#928040).
- commit c4c55bb
* Fri May  8 2015 mfasheh@suse.de
- xfs: xfs_alloc_fix_minleft can underflow near ENOSPC
  (bnc#913080, bnc#912741).
- commit 71222b4
* Thu May  7 2015 jack@suse.cz
- Fixup kABI false positive
  patches.fixes/vfs-fix-race-between-fcntl-and-file-f_flags-checks.patch.
- commit 87cf0d3
* Thu May  7 2015 jack@suse.cz
- Fixup compiler warning in
  patches.fixes/vfs-fix-race-between-fcntl-and-file-f_flags-checks.patch.
- commit d758cc3
* Thu May  7 2015 jack@suse.cz
- Added hunks missing from the patch
  patches.fixes/vfs-fix-race-between-fcntl-and-file-f_flags-checks.patch.
- commit ae792c8
* Thu May  7 2015 hare@suse.de
- ch: fixup refcounting imbalance for SCSI devices (bsc#925443).
- ch: remove 'ch_mutex' (bnc#925443).
- commit 52c0c14
* Thu May  7 2015 jack@suse.cz
- vfs: Fix race between fcntl() and file->f_flags checks
  (bnc#900881 CVE-2014-8086).
- commit e0a018a
* Tue May  5 2015 acho@suse.com
- net/tg3: Release IRQs on permanent error (bsc#90458 FATE#317507
  bsc#925107).
- commit a419359
* Mon May  4 2015 jack@suse.cz
- xfs: prevent deadlock trying to cover an active log
  (bsc#917093).
- commit 71d9b3d
* Thu Apr 30 2015 hare@suse.de
- NVMe: Add translation for block limits (bnc#926056).
- NVMe: Initialize device list head before starting (bnc#926056).
- nvme: Fix PRP list calculation for non-4k system page size
  (bnc#926056).
- NVMe: Fix potential corruption on sync commands (bnc#926056).
- NVMe: Fix potential corruption during shutdown (bnc#926056).
- NVMe: Asynchronous controller probe (bnc#926056).
- NVMe: Register management handle under nvme class (bnc#926056).
- NVMe: Update SCSI Inquiry VPD 83h translation (bnc#926056).
- NVMe: Update data structures for NVMe 1.2 (bnc#926056).
- NVMe: Update namespace and controller identify structures to
  the 1.1a spec (bnc#926056).
- NVMe: Flush with data support (bnc#926056).
- NVMe: Add tracepoints (bnc#926056).
- commit 6a838b1
* Thu Apr 30 2015 ohering@suse.de
- hv: no rmmod for hv_vmbus and hv_utils.
- commit d4f05af
* Thu Apr 30 2015 ohering@suse.de
- Drivers: hv: hv_balloon: correctly handle num_pages>INT_MAX case
  (fate#317533).
- Drivers: hv: hv_balloon: correctly handle val.freeram<num_pages
  case (fate#317533).
- hv_vmbus: Add gradually increased delay for retries in
  vmbus_post_msg() (fate#317533).
- Drivers: hv: hv_balloon: survive ballooning request with
  num_pages=0 (fate#317533).
- Drivers: hv: hv_balloon: eliminate jumps in piecewiese linear
  floor function (fate#317533).
- Drivers: hv: hv_balloon: do not online pages in offline blocks
  (fate#317533).
- hv: remove the per-channel workqueue (fate#317533).
- hv: don't schedule new works in
  vmbus_onoffer()/vmbus_onoffer_rescind() (fate#317533).
- hv: run non-blocking message handlers in the dispatch tasklet
  (fate#317533).
- hv_netvsc: Cleanup the test for freeing skb when we use sendbuf
  mechanism (fate#317533).
- hv_netvsc: remove vmbus_are_subchannels_present() in
  rndis_filter_device_add() (fate#317533).
- Drivers: hv: vmbus: Don't wait after requesting offers
  (fate#317533).
- Drivers: hv: vmbus: Fix a siganlling host signalling issue
  (fate#317533).
- Drivers: hv: vmbus: Export the vmbus_sendpacket_pagebuffer_ctl()
  (fate#317533).
- hv: hypervvssd: call endmntent before call setmntent again
  (fate#317533).
- Drivers: hv: vmbus: Fix a bug in rescind processing in
  vmbus_close_internal() (fate#317533).
- hv: vmbus: missing curly braces in vmbus_process_offer()
  (fate#317533).
- Drivers: hv: vmbus: Correcting truncation error for constant
  HV_CRASH_CTL_CRASH_NOTIFY (fate#317533).
- Drivers: hv: hv_balloon: don't lose memory when onlining order
  is not natural (fate#317533).
- Drivers: hv: hv_balloon: keep locks balanced on add_memory()
  failure (fate#317533).
- Drivers: hv: vmbus: Perform device register in the per-channel
  work element (fate#317533).
- hyperv: hyperv_fb: match wait_for_completion_timeout return type
  (fate#317533).
- mei: bus: () can be static (fate#317533).
- Drivers: hv: vmbus: Suport an API to send packet with additional
  control (fate#317533).
- Drivers: hv: vmbus: Suport an API to send pagebuffers with
  additional control (fate#317533).
- Drivers: hv: vmbus: Use a round-robin algorithm for picking
  the outgoing channel (fate#317533).
- Drivers: hv: vmbus: Add support for VMBus panic notifier handler
  (fate#317533).
- Drivers: hv: hv_balloon: refuse to balloon below the floor
  (fate#317533).
- Drivers: hv: hv_balloon: report offline pages as being used
  (fate#317533).
- Drivers: hv: hv_balloon: eliminate the trylock path in
  acquire/release_region_mutex (fate#317533).
- Drivers: hv: vmbus: Get rid of some unnecessary messages
  (fate#317533).
- Drivers: hv: util: On device remove, close the channel after
  de-initializing the service (fate#317533).
- Drivers: hv: vmbus: Remove the channel from the channel list(s)
  on failure (fate#317533).
- Drivers: hv: vmbus: Handle both rescind and offer messages in
  the same context (fate#317533).
- Drivers: hv: vmbus: Introduce a function to remove a rescinded
  offer (fate#317533).
- Drivers: hv: vmbus: Properly handle child device remove
  (fate#317533).
- Drivers: hv: vmbus: Add support for the NetworkDirect GUID
  (fate#317533).
- Drivers: hv: vmbus: Fix a bug in the error path in vmbus_open()
  (fate#317533).
- hv: hv_balloon: match var type to return type of
  wait_for_completion (fate#317533).
- hv: channel_mgmt: match var type to return type of
  wait_for_completion (fate#317533).
- hv: channel: match var type to return type of
  wait_for_completion (fate#317533).
- hv: vmbus_open(): reset the channel state on ENOMEM
  (fate#317533).
- hv: vmbus_post_msg: retry the hypercall on some transient errors
  (fate#317533).
- hv: hv_util: move vmbus_open() to a later place (fate#317533).
- Drivers: hv: vmbus: Teardown clockevent devices on module unload
  (fate#317533).
- drivers: hv: vmbus: Teardown synthetic interrupt controllers
  on module unload (fate#317533).
- Drivers: hv: vmbus: teardown hv_vmbus_con workqueue and
  vmbus_connection pages on shutdown (fate#317533).
- Drivers: hv: vmbus: avoid double kfree for device_obj
  (fate#317533).
- Drivers: hv: vmbus: rename channel work queues (fate#317533).
- Drivers: hv: vmbus: prevent cpu offlining on newer hypervisors
  (fate#317533).
- hyperv: Implement netvsc_get_channels() ethool op (fate#317533).
- commit 280a823
* Thu Apr 30 2015 ohering@suse.de
- scsi: storvsc: Fix a bug in copy_from_bounce_buffer()
  (fate#317533 bnc#923775).
- scsi: storvsc: Don't assume that the scatterlist is not chained
  (fate#317533 bnc#923775).
- Refresh
  patches.suse/msft-hv-0807-scsi-storvsc-Set-the-tablesize-based-on-the-informat.patch.
- commit ae731e9
* Thu Apr 30 2015 hare@suse.de
- qla2xxx: Update driver version to 8.07.00.18-k (bnc#921081).
- qla2xxx: Restore physical port WWPN only, when port down
  detected for FA-WWPN port (bnc#921081).
- qla2xxx: Fix virtual port configuration, when switch port is
  disabled/enabled (bnc#921081).
- qla2xxx: Prevent multiple firmware dump collection for ISP27XX
  (bnc#921081).
- qla2xxx: Disable Interrupt handshake for ISP27XX (bnc#921081).
- qla2xxx: Add debugging info for MBX timeout (bnc#921081).
- qla2xxx: Add serdes read/write support for ISP27XX (bnc#921081).
- qla2xxx: Add udev notification to save fw dump for ISP27XX
  (bnc#921081).
- qla2xxx: Add message for sucessful FW dump collected for ISP27XX
  (bnc#921081).
- qla2xxx: Add support to load firmware from file for ISP
  26XX/27XX (bnc#921081).
- qla2xxx: Fix beacon blink for ISP27XX (bnc#921081).
- qla2xxx: Increase the wait time for firmware to be ready for
  P3P (bnc#921081).
- qla2xxx: Fix crash due to wrong casting of reg for ISP27XX
  (bnc#921081).
- qla2xxx: Fix warnings reported by static checker (bnc#921081).
- commit 3b0cf9a
* Thu Apr 30 2015 eich@suse.com
- Refresh patches.fixes/rtc-cmos-add-more-quirks-for-TGCS.patch.
  Add DMI device IDs: 'IBM CORPORATION' '4900', 'TOSHIBA' '485257',
  'TOSHIBA' '4852E7' (bnc#927262)
- commit 7f44e69
* Wed Apr 29 2015 bpoirier@suse.de
- Refresh
  patches.drivers/mlx4-Fix-tx-ring-affinity_mask-creation.patch.
- commit c581a68
* Wed Apr 29 2015 ohering@suse.de
- scsi: storvsc: Set the tablesize based on the information
  given by the host (fate#317533 bnc#923775).
- commit a6c4d66
* Wed Apr 29 2015 ohering@suse.de
- Add mainline tags to some hv_storvsc patches
- commit 0e9bc66
* Wed Apr 29 2015 dvaleev@suse.com
- Correct cpu affinity for dlpar added cpus (bsc#928970).
- commit 837c5ee
* Wed Apr 29 2015 acho@suse.com
- Refresh
  patches.drivers/bnx2x-0015-bnx2x-Support-statistics-collection-for-VFs-by-the-P.patch.
- commit 4645c45
* Tue Apr 28 2015 jjolly@suse.de
- s390: z13 base performance (bnc#926797, LTC#KRN1514).
- commit b6c24f4
* Tue Apr 28 2015 dvaleev@suse.com
- patches.arch/pseries-suppress-Trying-to-free-nonexistent-resource-warning.patch:
  (bsc#927190).
- commit 0e711d3
* Mon Apr 27 2015 mszeredi@suse.cz
- fs: take i_mutex during prepare_binprm for setid executables
  (CVE-2015-3339 bnc#928130).
- commit fa62c9e
* Fri Apr 24 2015 dvaleev@suse.com
- patches.arch/pseries-suppress-Trying-to-free-nonexistent-resource-warning.patch:
  (bsc#927190).
- commit 6971a77
* Fri Apr 24 2015 dvaleev@suse.com
- Revert "pseries/iommu: Remove DDW on kexec" (bsc#926016).
- Revert "powerpc/pseries/iommu: remove default window before
  attempting DDW manipulation" (bsc#926016).
- powerpc/perf: Cap 64bit userspace backtraces to
  PERF_MAX_STACK_DEPTH (bsc#928142).
- commit d2fe3e8
* Thu Apr 23 2015 jbohac@suse.cz
- IB/ipoib: Add missing locking when CM object is deleted
  (bsc#924340).
- IPoIB: Fix race in deleting ipoib_neigh entries (bsc#924340).
- IPoIB: Fix ipoib_neigh hashing to use the correct daddr octets
  (bsc#924340).
- IPoIB: Fix AB-BA deadlock when deleting neighbours (bsc#924340).
- IPoIB: Fix memory leak in the neigh table deletion flow
  (bsc#924340).
- IB/ipoib: Fix RCU pointer dereference of wrong object
  (bsc#924340).
- commit 7b3f291
* Wed Apr 22 2015 dsterba@suse.cz
- Btrfs updates from 3.10
- Btrfs: add a incompatible format change for smaller metadata
  extent refs.
- Btrfs: cleanup of function where fixup_low_keys() is called.
- Btrfs: remove unused argument of btrfs_extend_item().
- Btrfs: cleanup of function where btrfs_extend_item() is called.
- Btrfs: remove unused variable in the iterate_extent_inodes().
- Btrfs: delete unused parameter to btrfs_read_root_item().
- btrfs: move leak debug code to functions.
- Btrfs: handle running extent ops with skinny metadata.
- Refresh
  patches.suse/btrfs-1221-make-static-code-static-remove-dead-code.patch.
- Refresh
  patches.suse/btrfs-1307-simplify-unlink-reservations.patch.
- Refresh
  patches.suse/btrfs-8172-move-the-extent-buffer-radix-tree-into-the-fs_.patch.
- Refresh
  patches.suse/btrfs-8201-don-t-use-ram_bytes-for-uncompressed-inline-it.patch.
- Refresh
  patches.suse/btrfs-8266-remove-unused-wait-queue-in-struct-extent_buff.patch.
- Refresh
  patches.suse/btrfs-8272-fill_holes-Fix-slot-number-passed-to-hole_merg.patch.
- Refresh
  patches.suse/btrfs-8306-make-xattr-replace-operations-atomic.patch.
- Refresh
  patches.suse/btrfs-include-the-device-in-most-error-printks.patch.
- Delete patches.suse/btrfs-compat-add-btrfs_fs_incompat.patch.
- commit 5ad3d2b
* Wed Apr 22 2015 dsterba@suse.cz
- Delete patches.suse/btrfs-1338-introduce-lock_ref-unlock_ref.patch.
  Unused code.
- commit f051a5e
* Wed Apr 22 2015 dsterba@suse.cz
- Delete patches.suse/vfs-partial-new-helper-mount_subtree.patch.
- commit 23e0979
* Wed Apr 22 2015 mhocko@suse.cz
- /proc/stat: convert to single_open_size() (bnc#928122).
- new helper: single_open_size() (bnc#928122).
- proc: speed up /proc/stat handling (bnc#928122).
- commit 34e8117
* Wed Apr 22 2015 mmarek@suse.cz
- scripts/refresh: Obsoleted by refresh_patch.sh
- commit f920be8
* Wed Apr 22 2015 acho@suse.com
- bnx2x: VF can report link speed (bsc#908684 FATE#317539).
- drivers/net/ethernet/broadcom/bnx2x/bnx2x_sriov.c: remove null
  test before kfree (bsc#908684 FATE#317539).
- bnx2x: Fix failure to configure VF multicast filters (bsc#908684
  FATE#317539).
- bnx2x: Fix vlan credit issues for VFs (bsc#908684 FATE#317539).
- bnx2x: Fix possible memory leak on iov error flow (bsc#908684
  FATE#317539).
- bnx2x: Don't allow VFs to become promiscuous (bsc#908684
  FATE#317539).
- bnx2x: Remove the sriov VFOP mechanism (bsc#908684 FATE#317539).
- bnx2x: Add missing bit in default Tx switching (bsc#908684
  FATE#317539).
- bnx2x: use FW 7.8.17 (bsc#908684 FATE#317539).
- bnx2x: Add ndo_get_phys_port_id support (bsc#908684
  FATE#317539).
- commit 184b165
* Wed Apr 22 2015 tiwai@suse.de
- rtc: Add more TGCS models for alarm disable quirk (bnc#927262).
- commit 0eca425
* Tue Apr 21 2015 bpoirier@suse.de
- net/mlx4_en: Use PTYS register to set ethtool settings (Speed)
  (bug#924311).
- net/mlx4_en: Use PTYS register to query ethtool settings
  (bug#924311).
- ethtool, net/mlx4_en: Add 100M, 20G, 56G speeds ethtool
  reporting support (bug#924311).
- net/mlx4_core: Add ethernet backplane autoneg device capability
  (bug#924311).
- net/mlx4_core: Introduce ACCESS_REG CMD and eth_prot_ctrl dev
  cap (bug#924311).
- commit 10039cf
* Tue Apr 21 2015 dsterba@suse.cz
- Temporary fix for bsc#926960
  Disables the EXTENT_SAME ioctl.
- Refresh
  patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch.
- Refresh
  patches.suse/btrfs-8283-replace-error-code-from-btrfs_drop_extents.patch.
- commit 2d43a2f
* Tue Apr 21 2015 jlee@suse.com
- Refresh
  patches.suse/0004-EFI-Add-in-kernel-variable-to-determine-if-Secure-Boot-is-enabled.patch. (bsc#925222)
- commit 449313b
* Tue Apr 21 2015 jlee@suse.com
- Refresh
  patches.suse/0004-EFI-Add-in-kernel-variable-to-determine-if-Secure-Boot-is-enabled.patch. (bsc#927399)
- commit c0c4cc0
* Tue Apr 21 2015 jlee@suse.com
- Refresh patches.drivers/drm-mgag200-Implement-basic-PM-support.
  (bsc#927399)
- commit 1cf65aa
* Tue Apr 21 2015 jlee@suse.com
- Removed CAP_COMPROMISE_KERNEL and respin kms drivers (bsc#927399)
- Refresh patches.drm/3221-mgag200-kms-only-for-secure-boot.diff.
- Refresh patches.drm/3222-cirrus-kms-only-for-secure-boot.diff.
- Refresh patches.drm/3223-ast-kms-only-for-secure-boot.diff.
- Refresh
  patches.suse/0011_V3_Add_option_to_automatically_enforce_module_signatures_when_in_Secure_Boot_mode.patch.
- Delete
  patches.suse/0001_Secure_boot_Add_new_capability_v2.patch.
- Delete
  patches.suse/0007_Secure_boot_Add_a_dummy_kernel_parameter_that_will_switch_on_Secure_Boot_mode_v2.patch.
- Delete
  patches.suse/0010_SELinux_define_mapping_for_new_Secure_Boot_capability_v2.patch.
- commit 7f56b59
* Tue Apr 21 2015 jlee@suse.com
- Removed CAP_COMPROMISE_KERNEL and respin kms drivers (bsc#925222)
- Refresh patches.drm/3221-mgag200-kms-only-for-secure-boot.diff.
- Refresh patches.drm/3222-cirrus-kms-only-for-secure-boot.diff.
- Refresh patches.drm/3223-ast-kms-only-for-secure-boot.diff.
- Refresh
  patches.suse/0011_V3_Add_option_to_automatically_enforce_module_signatures_when_in_Secure_Boot_mode.patch.
- Delete
  patches.suse/0001_Secure_boot_Add_new_capability_v2.patch.
- Delete
  patches.suse/0007_Secure_boot_Add_a_dummy_kernel_parameter_that_will_switch_on_Secure_Boot_mode_v2.patch.
- Delete
  patches.suse/0010_SELinux_define_mapping_for_new_Secure_Boot_capability_v2.patch.
- commit aeba24e
* Tue Apr 21 2015 jlee@suse.com
- ACPI / sysfs: Treat the count field of counter_show() as
  unsigned (bnc#909312).
- commit 10dcf9f
* Mon Apr 20 2015 neilb@suse.de
- SUNRPC: Fix the execution time statistics in the face of RPC
  restarts (bnc#924271).
- commit 4dfcdee
* Mon Apr 20 2015 jlee@suse.com
- ACPI / osl: speedup grace period in acpi_os_map_cleanup
  (bnc#877456).
- commit b47bb67
* Mon Apr 20 2015 neilb@suse.de
- md: fix safe_mode buglet (bnc#926767).
- commit ea372ad
* Sat Apr 18 2015 jjolly@suse.de
- s390/mm: speedup storage key initialization (bnc#926797,
  LTC#KRN1514).
- s390/memory hotplug: use pfmf instruction to initialize storage
  keys (bnc#926797, LTC#KRN1514).
- s390/mm: use pfmf instruction to initialize storage keys
  (bnc#926797, LTC#KRN1514).
- s390/facilities: cleanup PFMF and HPAGE machine facility
  detection (bnc#926797, LTC#KRN1514).
- s390: enable large page support with CONFIG_DEBUG_PAGEALLOC
  (bnc#926797, LTC#KRN1514).
- s390/memory hotplug: initialize storage keys (bnc#926797,
  LTC#KRN1514).
- s390/mm: align 64-bit PIE binaries to 4GB (bnc#926797,
  LTC#KRN1514).
- s390: avoid z13 cache aliasing (bnc#926797, LTC#KRN1514).
- s390/kernel: use stnsm 255 instead of stosm 0 (bnc#926797,
  LTC#KRN1514).
- s390/time: use stck clock fast for do_account_vtime (bnc#926797,
  LTC#KRN1514).
- s390/spinlock: optimize spin_unlock code (bnc#926797,
  LTC#KRN1514).
- s390/spinlock: refactor arch_spin_lock_wait[_flags] (bnc#926797,
  LTC#KRN1514).
- s390/rwlock: add missing local_irq_restore calls (bnc#926797,
  LTC#KRN1514).
- s390/spinlock,rwlock: always to a load-and-test first
  (bnc#926797, LTC#KRN1514).
- s390/spinlock: optimize spinlock code sequence (bnc#926797,
  LTC#KRN1514).
- s390/spinlock: cleanup spinlock code (bnc#926797, LTC#KRN1514).
- commit ce207a8
* Sat Apr 18 2015 jjolly@suse.de
-  - Moved s390-20-05 patch in preparation for z13 performance
  enhancements (bnc#926797)
- commit 158157c
* Sat Apr 18 2015 jjolly@suse.de
- dasd: Fix inability to set a DASD device offline (bnc#927287,
  LTC#123905).
- dasd: Fix device having no paths after suspend/resume
  (bnc#927287, LTC#123896).
- dasd: Fix unresumed device after suspend/resume (bnc#927287,
  LTC#123892).
- af_iucv: fix AF_IUCV sendmsg() errno (bnc#927287, LTC#123304).
- commit 9abfd09
* Fri Apr 17 2015 bp@suse.de
- IB/uverbs: Prevent integer overflow in ib_umem_get address
  arithmetic (bsc#914742, CVE-2014-8159).
- commit 6545a2d
* Thu Apr 16 2015 bpoirier@suse.de
- mlx4: Fix tx ring affinity_mask creation (bug#925353).
- commit 3003d47
* Thu Apr 16 2015 bpoirier@suse.de
- supported.conf: add drop_monitor
  FATE#318825
- commit 3936873
* Thu Apr 16 2015 bpoirier@suse.de
- net/mlx4: Cache line CQE/EQE stride fixes (bug#925337).
- commit 268b3fd
* Thu Apr 16 2015 bpoirier@suse.de
- Update config files.
  Enable NET_DROP_MONITOR as a module. This is not possible for the "vanilla"
  kernel flavors since drop_monitor cannot be configured as a module without
  extra patches.
- commit d9f3962
* Thu Apr 16 2015 bpoirier@suse.de
- net: Replace get_cpu_var through this_cpu_ptr (FATE#318825).
- drop_monitor: remove unnecessary break after return
  (FATE#318825).
- net: drop_monitor: fix the value of maxattr (FATE#318825).
- drop_monitor: Add module alias to enable automatic module
  loading (FATE#318825).
- genetlink: Build a generic netlink family module alias
  (FATE#318825).
- net: add MODULE_ALIAS_NET_PF_PROTO_NAME (FATE#318825).
- genetlink: add auto module loading (FATE#318825).
- drop_monitor: convert to modular building (FATE#318825).
- net: core: Use pr_<level> (FATE#318825).
- commit 4fd43e9
* Thu Apr 16 2015 dbueso@suse.de
- eventpoll: use-after-possible-free in epoll_create1()
  (bug#917648).
- commit 65ee3a2
* Thu Apr 16 2015 bpoirier@suse.de
- net/mlx4_core: Reset flow activation upon SRIOV fatal command
  cases (bug#924708).
- net/mlx4_core: Enable device recovery flow with SRIOV
  (bug#924708).
- net/mlx4_core: Handle AER flow properly (bug#924708).
- net/mlx4_core: Manage interface state for Reset flow cases
  (bug#924708).
- net/mlx4_core: Activate reset flow upon fatal command cases
  (bug#924708).
- net/mlx4_core: Enhance the catas flow to support device reset
  (bug#924708).
- net/mlx4_core: Refactor the catas flow to work per device
  (bug#924708).
- net/mlx4_core: Set device configuration data to be persistent
  across reset (bug#924708).
- net/mlx4_core: Maintain a persistent memory for mlx4 device
  (bug#924708).
- commit 98c27a6
* Thu Apr 16 2015 bpoirier@suse.de
- Refresh
  patches.drivers/disable-catas_reset-by-default-to-avoid-problems-with-eeh.patch.
- Refresh
  patches.drivers/mlx4-0014-mlx4-Move-the-Mellanox-driver.patch.
- Refresh
  patches.drivers/mlx4-0073-mlx4_core-adjust-catas-operation-for-SRIOV-mode.patch.
- commit 18e5377
* Tue Apr 14 2015 mszeredi@suse.cz
- Limit allocation of crypto mechanisms to dialect which requires
  (bnc#925729).
- commit 9b9dd09
* Tue Apr 14 2015 glin@suse.com
- lib: cpu_rmap: avoid flushing all workqueues (bsc922339).
- commit 9e751e5
* Fri Apr 10 2015 tiwai@suse.de
- Update patches.drivers/HID-multitouch-add-support-for-Atmel-213c
  (bnc#793727,bnc#863946,bnc#924142).
  This revisited the Atmel maxTouch touchscreen support.  Now the Win8
  device entry is detected dynamically (but applied only for specified
  devices for safety reasons).
- commit 49d8c7f
* Fri Apr 10 2015 jjolly@suse.de
- mlx4_core: Disable 64b CQE EQE by default (bnc#924482
  bnc#924653).
- Refresh
  patches.drivers/mlx4-0222-net-mlx4_core-Removed-unnecessary-bit-operation-cond.patch.
- Refresh
  patches.drivers/mlx4-0270-net-mlx4_core-Enable-CQE-EQE-stride-support.patch.
- commit 25288b4
* Fri Apr 10 2015 dsterba@suse.cz
- Btrfs: move fs/btrfs/ioctl.h to include/uapi/linux/btrfs.h (bsc#925073 FATE#308234).
- Refresh
  patches.suse/btrfs-1055-add-no-file-data-flag-to-btrfs-send-ioctl.patch.
- Refresh
  patches.suse/btrfs-1070-Add-a-new-ioctl-to-get-the-label-of-a-mounted-.patch.
- Refresh
  patches.suse/btrfs-1071-set-change-the-label-of-a-mounted-file-system.patch.
- Refresh patches.suse/btrfs-1216-rescan-for-qgroups.patch.
- Refresh
  patches.suse/btrfs-1300-add-ioctl-to-wait-for-qgroup-rescan-completion.patch.
- Refresh patches.suse/btrfs-1419-offline-dedupe.patch.
- Refresh
  patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch.
- Refresh
  patches.suse/btrfs-8236-retrieve-more-info-from-FS_INFO-ioctl.patch.
- commit ab44f27
* Fri Apr 10 2015 tiwai@suse.de
- Refresh patches.drivers/HID-multitouch-add-support-for-Atmel-212c (bnc#924142).
- commit 22a6a53
* Fri Apr 10 2015 hare@suse.de
- NVMe: Return 0 from make request on ended bio (bsc#926480).
- commit b2a0b33
* Fri Apr 10 2015 acho@suse.com
- PCI: Remove spurious error for sriov_numvfs store and simplify
  flow (bsc#923260 bsc#908684 FATE#317539).
- commit 70fa093
* Fri Apr 10 2015 bpoirier@suse.de
- net/mlx4_en: Doorbell is byteswapped in Little Endian archs
  (bug#925105).
- commit fabc0d8
* Thu Apr  9 2015 jlee@suse.com
- ACPI / osl: speedup grace period in acpi_os_map_cleanup
  (bnc#877456).
- commit af38a47
* Thu Apr  9 2015 bp@suse.de
- eCryptfs: Remove buggy and unnecessary write in file name
  decode routine (bsc#918333, CVE-2014-9683).
- commit 6b8568f
* Thu Apr  9 2015 jlee@suse.com
- i2c: i801: Add DeviceIDs for SunrisePoint LP (bnc#925554).
- commit 24f73db
* Thu Apr  9 2015 mkubecek@suse.cz
- net: rds: use correct size for max unacked packets and bytes
  (bsc#919018 CVE-2015-2042).
- commit 07fbbcb
* Thu Apr  9 2015 hare@suse.de
- enclosure: handle non-unique element descriptors (bsc#925417).
- enclosure: fix WARN_ON in dual path device removing
  (bsc#925417).
- commit 6f08df3
* Thu Apr  9 2015 mhocko@suse.cz
- mm, slab: lock the correct nodelist after reenabling irqs
  (bnc#926439).
- commit 450fe7f
* Wed Apr  8 2015 bp@suse.de
- x86/asm/entry/64: Remove a bogus 'ret_from_fork' optimization
  (bsc#926240, CVE-2015-2830).
- commit d6d09f0
* Tue Apr  7 2015 lduncan@suse.com
- isci: fix breakage caused by >16byte CDB patch (bug#923943).
- commit 8ef0d91
* Tue Apr  7 2015 jjolly@suse.de
- Remove obsolete patch patches.arch/s390-sles11sp3-17-01-uverbs-kwrite-mmio.patch (bnc#924682)
  - Refresh patches.drivers/mlx5-0072-IB-core-Introduce-signature-verbs-API.patch.
  - Delete patches.arch/s390-sles11sp3-17-01-uverbs-kwrite-mmio.patch.
- commit 7216da6
* Tue Apr  7 2015 dbueso@suse.de
- ipc/shm.c: fix overly aggressive shmdt() when calls span
  multiple segments (ipc fixes).
- commit b9069a6
* Tue Apr  7 2015 mhocko@suse.cz
- pagecache limit: Do not skip over small zones that easily
  (bnc#925881).
- pagecache limit: reduce starvation due to reclaim retries
  (bnc#925903).
- Refresh
  patches.fixes/mm-vmscan-store-priority-in-struct-scan_control.patch.
- Refresh patches.suse/pagecache-limit-fix-shmem-deadlock.patch.
- Refresh
  patches.suse/pagecache-limit-fix-wrong-reclaimed-count.patch.
- Refresh patches.suse/pagecache-limit-tracepoints.patch.
- Refresh patches.suse/pagecache-limit-vmstat_counters.patch.
- commit 55f829b
* Tue Apr  7 2015 tiwai@suse.de
- ALSA: hda_intel: apply the Seperate stream_tag for Sunrise Point
  (bsc#925370).
- ALSA: hda_intel: apply the Seperate stream_tag for Skylake
  (bsc#925370).
- ALSA: hda_controller: Separate stream_tag for input and output
  streams (bsc#925370).
- commit 2bef3a6
* Mon Apr  6 2015 brogers@suse.com
- Refresh
  patches.arch/kvm-x86-distinguish-between-stack-operation-and-near-branches.patch.
- Update
  patches.arch/kvm-x86-emulator-fixes-for-eip-canonical-checks-on-near-branches.patch
  (CVE-2014-3647 bnc#899192 bsc#924721 bsc#925895).
- commit 641bc6d
* Fri Apr  3 2015 dsterba@suse.cz
- vfs: new helper: file_inode(file).
- Refresh
  patches.suse/btrfs-1131-fix-missing-qgroup-reservation-before-fallocat.patch.
- Refresh
  patches.suse/btrfs-1302-fix-estale-with-btrfs-send.patch.
- Refresh
  patches.suse/btrfs-1317-check-if-we-can-nocow-if-we-don-t-have-data-sp.patch.
- Refresh
  patches.suse/btrfs-1417-btrfs_ioctl_clone-Move-clone-code-into-it-s-own-func.patch.
- Refresh
  patches.suse/btrfs-8223-Return-EXDEV-for-cross-file-system-snapshot.patch.
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit 722d2fd
* Fri Apr  3 2015 mmarek@suse.cz
- Delete config/x86_64/bigsmp (fate#318083)
- commit 6f10cdd
* Fri Apr  3 2015 mmarek@suse.cz
- Provide/Obsolete all subpackages of old flavors (bnc#925567)
- commit 1274d22
* Fri Apr  3 2015 brogers@suse.com
- Update
  patches.arch/kvm-x86-handle-errors-when-rip-is-set-during-far-jumps.patch
  (CVE-2014-3647 bnc#899192 bsc#925895).
- commit 3b6df24
* Fri Apr  3 2015 dsterba@suse.cz
- vfs: switch open-coded instances of d_make_root() to new helper.
- commit 0290c2b
* Fri Apr  3 2015 dsterba@suse.cz
- vfs: switch a bunch of places to mnt_want_write_file().
  Partial backport.
- Refresh
  patches.suse/btrfs-0668-Push-mnt_want_write-outside-of-i_mutex.patch.
- Refresh
  patches.suse/btrfs-0894-disallow-mutually-exclusive-admin-operations-f.patch.
- Refresh
  patches.suse/btrfs-0978-fix-mutually-exclusive-op-is-running-error-cod.patch.
- Refresh
  patches.suse/btrfs-0981-reorder-locks-and-sanity-checks-in-btrfs_ioctl.patch.
- Refresh
  patches.suse/btrfs-1417-btrfs_ioctl_clone-Move-clone-code-into-it-s-own-func.patch.
- commit 5dc0bd8
* Fri Apr  3 2015 dsterba@suse.cz
- vfs: new helper: mount_subtree().
  Partial backport.
- commit 8319a6c
* Fri Apr  3 2015 dsterba@suse.cz
- Btrfs: compat vfs wapper for set_nlink
- Refresh
  patches.suse/btrfs-0496-use-i_version-instead-of-our-own-sequence.patch.
- Refresh
  patches.suse/btrfs-0694-use-printk_get_level-and-printk_skip_level-add-_printf-fix-fallout-compat.patch.
- Refresh patches.suse/btrfs-0791-extended-inode-refs.patch.
- Refresh
  patches.suse/btrfs-1122-improve-the-delayed-inode-throttling.patch.
- commit 9335b57
* Fri Apr  3 2015 dsterba@suse.cz
- btrfs: kill magical embedded struct superblock.
- Refresh
  patches.suse/0002-btrfs-Introduce-btrfs_get_maps_dev.patch.
- Refresh
  patches.suse/btrfs-0242-fix-tree-corruption-after-multi-thread-snapsho.patch.
- Refresh
  patches.suse/btrfs-0248-fix-stat-blocks-accounting.patch.
- Refresh
  patches.suse/btrfs-0662-introduce-subvol-uuids-and-times.patch.
- Refresh
  patches.suse/btrfs-0935-rename-root_times_lock-to-root_item_lock.patch.
- Refresh
  patches.suse/btrfs-1030-use-the-inode-own-lock-to-protect-its-delalloc.patch.
- Refresh
  patches.suse/btrfs-1425-fix-memory-leak-of-orphan-block-rsv.patch.
- Refresh
  patches.suse/btrfs-disk-io-__setup_root-should-return-void.
- commit 47f15ce
* Thu Apr  2 2015 vbabka@suse.cz
- pagecache limit: fix wrong nr_reclaimed count (FATE#309111,
  bnc#924701).
- pagecache limit: add tracepoints (bnc#924701).
- Refresh
  patches.fixes/mm-vmscan-do-not-stall-on-writeback-during-memory-compaction.patch.
- Refresh patches.suse/pagecache-limit-fix-shmem-deadlock.patch.
- commit bd6bffa
* Thu Apr  2 2015 mmarek@suse.cz
- Update kabi files.
- commit e37b865
* Wed Apr  1 2015 dsterba@suse.cz
- btrfs: remove the second argument of k[un]map_atomic().
  The 1-argument api is available and used already.
- Refresh
  patches.suse/btrfs-0480-change-scrub-to-support-big-blocks.patch.
- Refresh
  patches.suse/btrfs-0678-don-t-allocate-a-seperate-csums-array-for-dire.patch.
- Refresh
  patches.suse/btrfs-0879-rename-the-scrub-context-structure.patch.
- Refresh
  patches.suse/btrfs-0881-make-the-scrub-page-array-dynamically-allocate.patch.
- Refresh
  patches.suse/btrfs-1151-cleanup-unused-arguments-of-btrfs_csum_data.patch.
- Refresh
  patches.suse/btrfs-include-the-device-in-most-error-printks.patch.
- commit b6d8ec3
* Wed Apr  1 2015 mhocko@suse.cz
- pagecache limit: export debugging counters via /proc/vmstat
  (bnc#924701).
- Refresh patches.suse/pagecache-limit-fix-shmem-deadlock.patch.
- commit 5993cad
* Wed Apr  1 2015 mmarek@suse.cz
- Delete obsolete
  patches.suse/suse-hv-Drivers-hv-util-Fix-a-bug-in-util-version-negotiatio.patch
  (removed from series.conf by commit 7d878c8f)
- commit 69feeaa
* Wed Apr  1 2015 mmarek@suse.cz
- Generate rpm changelog from git
- commit d65cefb
* Wed Apr  1 2015 bpoirier@suse.de
- be2net: use PCI MMIO read instead of config read for errors
  (bug#925065).
- commit c111b4e
* Tue Mar 31 2015 neilb@suse.de
- md: don't give up looking for spares on first failure-to-add
  (bnc#908706).
- commit 68670bb
* Tue Mar 31 2015 bpoirier@suse.de
- Update
  patches.drivers/mlx4-0233-net-mlx4_en-Use-affinity-hint.patch
  (bug#919382 FATE#317529 bug#924717).
  According to the findings in bug#924717
- commit 70b84e7
* Tue Mar 31 2015 dsterba@suse.cz
- Btrfs: fix an while-loop of listxattr.
- Refresh
  patches.suse/btrfs-0629-fix-buffer-leak-in-btrfs_next_old_leaf.patch.
- Refresh
  patches.suse/btrfs-0644-add-helper-for-tree-enumeration.patch.
- commit efcaaa3
* Tue Mar 31 2015 jjolly@suse.de
- dasd: Missing partition after online processing (bnc#917120,
  LTC#120565).
- commit 63dd6b0
* Mon Mar 30 2015 dbueso@suse.de
- epoll: fix use-after-free in eventpoll_release_file (epoll
  scaling).
- commit ea7ee81
* Mon Mar 30 2015 dsterba@suse.cz
- Rename and move btrfs patches from 3.12
- Btrfs: Release uuid_mutex for shrink during device delete
  (FATE#312888).
- btrfs: fall back to global reservation when removing subvolumes
  (FATE#312888).
- Btrfs: add missing error checks to add_data_references
  (FATE#312888).
- btrfs: fix get set label blocking against balance.
- Btrfs: reset ret in record_one_backref (FATE#312888).
- Btrfs: cleanup reloc roots properly on error (FATE#312888).
- Btrfs: add sanity checks regarding to parsing mount options
  (FATE#312888).
- Btrfs: use u64 for subvolid when parsing mount options
  (FATE#312888).
- Btrfs: add missing mounting options in btrfs_show_options()
  (FATE#312888).
- Btrfs: don't bug_on when we fail when cleaning up transactions
  (FATE#312888).
- Btrfs: add missing error handling to read_tree_block
  (FATE#312888).
- Btrfs: handle errors when doing slow caching (FATE#312888).
- Btrfs: fix inode leak on kmalloc failure in tree-log.c
  (FATE#312888).
- Btrfs: don't ignore errors from btrfs_run_delayed_items
  (FATE#312888).
- Btrfs: return ENOSPC when target space is full (FATE#312888).
- Btrfs: fix possible memory leak in find_parent_nodes().
- btrfs: abtract out range locking in clone ioctl().
- btrfs_ioctl_clone: Move clone code into it's own function.
- btrfs: Introduce extent_read_full_page_nolock() (FATE#308234).
- btrfs: offline dedupe (FATE#308234).
- Btrfs: don't allow a subvol to be deleted if it is the default
  subovl (FATE#312888).
- Btrfs: fix the error handling wrt orphan items.
- Btrfs: fix oops when writing dirty qgroups to disk
  (FATE#312888).
- Btrfs: add missing error code to BTRFS_IOC_INO_LOOKUP handler
  (FATE#312888).
- Btrfs: don't miss inode ref items in BTRFS_IOC_INO_LOOKUP
  (FATE#312888).
- Btrfs: fix memory leak of orphan block rsv (FATE#312888).
- Btrfs: fix printing of non NULL terminated string (FATE#312888).
- Btrfs: do not clear our orphan item runtime flag on eexist
  (FATE#312888).
- Btrfs: remove ourselves from the cluster list under lock
  (FATE#312888).
- Btrfs: actually limit the size of delalloc range.
- Btrfs: actually log directory we are fsync()'ing.
- Btrfs: check roots last log commit when checking if an inode
  has been logged.
- Btrfs: replay dir_index items before other items.
- Btrfs: drop dir i_size when adding new names on replay.
- Revert "Btrfs: rework the overcommit logic to be based on the
  total size".
- Btrfs: fix worst case calculator for space usage.
- Btrfs: iput inode on allocation failure.
- Btrfs: btrfs_ioctl_default_subvol: Revert back to toplevel
  subvolume when arg is 0.
- btrfs: refuse to remount read-write after abort.
- btrfs: Add btrfs: prefix to kernel log output (FATE#306586).
- Btrfs: dir_inode_operations should use btrfs_update_time also.
- Btrfs: fix transid verify errors when recovering log tree.
- Btrfs: use right root when checking for hash collision.
- Refresh
  patches.suse/btrfs-8257-check-file-extent-type-before-anything-else.patch.
- Delete
  patches.suse/btrfs-8021-add-btrfs-prefix-to-kernel-log-output.patch.
- Delete
  patches.suse/btrfs-8135-Release-uuid_mutex-for-shrink-during-device-de.patch.
- Delete
  patches.suse/btrfs-8136-fall-back-to-global-reservation-when-removing-.patch.
- Delete
  patches.suse/btrfs-8137-fix-get-set-label-blocking-against-balance.patch.
- Delete
  patches.suse/btrfs-8138-reset-ret-in-record_one_backref.patch.
- Delete
  patches.suse/btrfs-8139-cleanup-reloc-roots-properly-on-error.patch.
- Delete
  patches.suse/btrfs-8140-add-sanity-checks-regarding-to-parsing-mount-o.patch.
- Delete
  patches.suse/btrfs-8141-use-u64-for-subvolid-when-parsing-mount-option.patch.
- Delete
  patches.suse/btrfs-8142-add-missing-mounting-options-in-btrfs_show_opt.patch.
- Delete
  patches.suse/btrfs-8143-don-t-bug_on-when-we-fail-when-cleaning-up-tra.patch.
- Delete
  patches.suse/btrfs-8144-return-ENOSPC-when-target-space-is-full.patch.
- Delete
  patches.suse/btrfs-8145-don-t-allow-a-subvol-to-be-deleted-if-it-is-th.patch.
- Delete
  patches.suse/btrfs-8146-fix-the-error-handling-wrt-orphan-items.patch.
- Delete
  patches.suse/btrfs-8147-add-missing-error-code-to-btrfs_IOC_INO_LOOKUP.patch.
- Delete
  patches.suse/btrfs-8148-don-t-miss-inode-ref-items-in-btrfs_IOC_INO_LO.patch.
- Delete
  patches.suse/btrfs-8149-fix-memory-leak-of-orphan-block-rsv.patch.
- Delete
  patches.suse/btrfs-8150-fix-printing-of-non-NULL-terminated-string.patch.
- Delete
  patches.suse/btrfs-8156-add-missing-error-checks-to-add_data_reference.patch.
- Delete
  patches.suse/btrfs-8158-add-missing-error-handling-to-read_tree_block.patch.
- Delete
  patches.suse/btrfs-8159-handle-errors-when-doing-slow-caching.patch.
- Delete
  patches.suse/btrfs-8160-fix-inode-leak-on-kmalloc-failure-in-tree-log..patch.
- Delete
  patches.suse/btrfs-8161-don-t-ignore-errors-from-btrfs_run_delayed_ite.patch.
- Delete
  patches.suse/btrfs-8162-fix-oops-when-writing-dirty-qgroups-to-disk.patch.
- Delete
  patches.suse/btrfs-8163-do-not-clear-our-orphan-item-runtime-flag-on-e.patch.
- Delete
  patches.suse/btrfs-8164-remove-ourselves-from-the-cluster-list-under-l.patch.
- Delete
  patches.suse/btrfs-8207-fix-possible-memory-leak-in-find_parent_nodes.patch.
- Delete
  patches.suse/btrfs-8208-actually-limit-the-size-of-delalloc-range.patch.
- Delete
  patches.suse/btrfs-8209-actually-log-directory-we-are-fsync-ing.patch.
- Delete
  patches.suse/btrfs-8210-check-roots-last-log-commit-when-checking-if-a.patch.
- Delete
  patches.suse/btrfs-8211-replay-dir_index-items-before-other-items.patch.
- Delete
  patches.suse/btrfs-8212-drop-dir-i_size-when-adding-new-names-on-repla.patch.
- Delete
  patches.suse/btrfs-8213-Revert-rework-the-overcommit-logic-to-be-based.patch.
- Delete
  patches.suse/btrfs-8214-fix-worst-case-calculator-for-space-usage.patch.
- Delete
  patches.suse/btrfs-8215-iput-inode-on-allocation-failure.patch.
- Delete
  patches.suse/btrfs-8216-btrfs_ioctl_default_subvol-Revert-back-to-topl.patch.
- Delete
  patches.suse/btrfs-8217-refuse-to-remount-read-write-after-abort.patch.
- Delete
  patches.suse/btrfs-8218-dir_inode_operations-should-use-btrfs_update_t.patch.
- Delete
  patches.suse/btrfs-8219-fix-transid-verify-errors-when-recovering-log-.patch.
- Delete
  patches.suse/btrfs-8220-use-right-root-when-checking-for-hash-collisio.patch.
- Delete
  patches.suse/btrfs-8287-Introduce-extent_read_full_page_nolock.patch.
- Delete patches.suse/btrfs-8288-offline-dedupe.patch.
- Delete
  patches.suse/btrfs-8289-btrfs_ioctl_clone-Move-clone-code-into-it-s-own-func.patch.
- Delete
  patches.suse/btrfs-8290-abtract-out-range-locking-in-clone-ioctl.patch.
- commit c8ec423
* Mon Mar 30 2015 dbueso@suse.de
- epoll: fix use-after-free in eventpoll_release_file (epoll
  scaling).
- commit efb7031
* Mon Mar 30 2015 dsterba@suse.cz
- Rename and move btrfs patches from 3.11
- Btrfs: add ioctl to wait for qgroup rescan completion
  (FATE#312888).
- Btrfs: remove useless copy in quota_ctl (FATE#312888).
- Btrfs: fix estale with btrfs send (FATE#312888).
- Btrfs: return error code in btrfs_check_trunc_cache_free_space()
  (FATE#312888).
- Btrfs: dont do log_removal in insert_new_root (FATE#312888).
- Btrfs: check if leaf's parent exists before pushing items around
  (FATE#312888).
- Btrfs: allow file data clone within a file (FATE#312888).
- Btrfs: simplify unlink reservations (FATE#312888).
- Btrfs: fix qgroup rescan resume on mount (FATE#312888).
- Btrfs: do not pin while under spin lock (FATE#312888).
- Btrfs: add some missing iput()'s in btrfs_orphan_cleanup
  (FATE#312888).
- Btrfs: put our inode if orphan cleanup fails (FATE#312888).
- Btrfs: exclude logged extents before replying when we are mixed
  (FATE#312888).
- Btrfs: fix broken nocow after balance (FATE#312888).
- Btrfs: wake up delayed ref flushing waiters on abort
  (FATE#312888).
- Btrfs: fix transaction throttling for delayed refs
  (FATE#312888).
- Btrfs: unlock extent range on enospc in compressed submit
  (FATE#312888).
- Btrfs: check if we can nocow if we don't have data space
  (FATE#312888).
- Btrfs: hold the tree mod lock in __tree_mod_log_rewind
  (FATE#312888).
- Btrfs: only do the tree_mod_log_free_eb if this is our last ref
  (FATE#312888).
- Btrfs: update drop progress before stopping snapshot dropping
  (FATE#312888).
- Btrfs: fix lock leak when resuming snapshot deletion
  (FATE#312888).
- Btrfs: re-add root to dead root list if we stop dropping it
  (FATE#312888).
- btrfs: fix file truncation if FALLOC_FL_KEEP_SIZE is specified
  (FATE#312888).
- Btrfs: fix a bug of snapshot-aware defrag to make it work on
  partial extents (FATE#312888).
- Btrfs: fix extent buffer leak after backref walking
  (FATE#312888).
- Btrfs: do not offset physical if we're compressed (FATE#312888).
- Btrfs: fix backref walking when we hit a compressed extent
  (FATE#312888).
- Btrfs: make sure the backref walker catches all refs to our
  extent (FATE#312888).
- Btrfs: release both paths before logging dir/changed extents
  (FATE#312888).
- Btrfs: remove unnecessary ->s_umount in cleaner_kthread()
  (FATE#312888).
- Btrfs: make the cleaner complete early when the fs is going
  to be umounted (FATE#312888).
- Btrfs: move the R/O check out of
  btrfs_clean_one_deleted_snapshot() (FATE#312888).
- Btrfs: make the snap/subv deletion end more early when the fs
  is R/O (FATE#312888).
- Btrfs: introduce qgroup_ulist to avoid frequently
  allocating/freeing ulist (FATE#312888).
- Btrfs: fix memory patcher through fs_info->qgroup_ulist
  (FATE#312888).
- Btrfs: avoid double free of fs_info->qgroup_ulist (FATE#312888).
- Btrfs: fix crash regarding to ulist_add_merge (FATE#312888).
- Btrfs: introduce lock_ref/unlock_ref (FATE#312888).
- btrfs: don't loop on large offsets in readdir (bnc#863300).
- Btrfs: batch the extent state operation when reading pages
  (FATE#308234).
- Refresh patches.suse/btrfs-compat-add-btrfs_fs_incompat.patch.
- Delete
  patches.suse/btrfs-8100-add-ioctl-to-wait-for-qgroup-rescan-completion.patch.
- Delete
  patches.suse/btrfs-8101-remove-useless-copy-in-quota_ctl.patch.
- Delete patches.suse/btrfs-8103-fix-estale-with-btrfs-send.patch.
- Delete
  patches.suse/btrfs-8104-return-error-code-in-btrfs_check_trunc_cache_f.patch.
- Delete
  patches.suse/btrfs-8105-dont-do-log_removal-in-insert_new_root.patch.
- Delete
  patches.suse/btrfs-8106-check-if-leaf-s-parent-exists-before-pushing-i.patch.
- Delete
  patches.suse/btrfs-8107-allow-file-data-clone-within-a-file.patch.
- Delete
  patches.suse/btrfs-8108-simplify-unlink-reservations.patch.
- Delete
  patches.suse/btrfs-8109-fix-qgroup-rescan-resume-on-mount.patch.
- Delete
  patches.suse/btrfs-8110-do-not-pin-while-under-spin-lock.patch.
- Delete
  patches.suse/btrfs-8111-add-some-missing-iput-s-in-btrfs_orphan_cleanu.patch.
- Delete
  patches.suse/btrfs-8112-put-our-inode-if-orphan-cleanup-fails.patch.
- Delete
  patches.suse/btrfs-8113-exclude-logged-extents-before-replying-when-we.patch.
- Delete
  patches.suse/btrfs-8114-fix-broken-nocow-after-balance.patch.
- Delete
  patches.suse/btrfs-8115-wake-up-delayed-ref-flushing-waiters-on-abort.patch.
- Delete
  patches.suse/btrfs-8117-fix-transaction-throttling-for-delayed-refs.patch.
- Delete
  patches.suse/btrfs-8119-unlock-extent-range-on-enospc-in-compressed-su.patch.
- Delete
  patches.suse/btrfs-8121-check-if-we-can-nocow-if-we-don-t-have-data-sp.patch.
- Delete
  patches.suse/btrfs-8122-hold-the-tree-mod-lock-in-__tree_mod_log_rewin.patch.
- Delete
  patches.suse/btrfs-8123-only-do-the-tree_mod_log_free_eb-if-this-is-ou.patch.
- Delete
  patches.suse/btrfs-8125-update-drop-progress-before-stopping-snapshot-.patch.
- Delete
  patches.suse/btrfs-8126-fix-lock-leak-when-resuming-snapshot-deletion.patch.
- Delete
  patches.suse/btrfs-8127-re-add-root-to-dead-root-list-if-we-stop-dropp.patch.
- Delete
  patches.suse/btrfs-8128-fix-file-truncation-if-FALLOC_FL_KEEP_SIZE-is-.patch.
- Delete
  patches.suse/btrfs-8129-fix-a-bug-of-snapshot-aware-defrag-to-make-it-.patch.
- Delete
  patches.suse/btrfs-8130-fix-extent-buffer-leak-after-backref-walking.patch.
- Delete
  patches.suse/btrfs-8131-do-not-offset-physical-if-we-re-compressed.patch.
- Delete
  patches.suse/btrfs-8132-fix-backref-walking-when-we-hit-a-compressed-e.patch.
- Delete
  patches.suse/btrfs-8133-make-sure-the-backref-walker-catches-all-refs-.patch.
- Delete
  patches.suse/btrfs-8134-release-both-paths-before-logging-dir-changed-.patch.
- Delete
  patches.suse/btrfs-8152-remove-unnecessary-s_umount-in-cleaner_kthread.patch.
- Delete
  patches.suse/btrfs-8153-make-the-cleaner-complete-early-when-the-fs-is.patch.
- Delete
  patches.suse/btrfs-8154-move-the-R-O-check-out-of-btrfs_clean_one_dele.patch.
- Delete
  patches.suse/btrfs-8155-make-the-snap-subv-deletion-end-more-early-whe.patch.
- Delete
  patches.suse/btrfs-8166-introduce-qgroup_ulist-to-avoid-frequently-all.patch.
- Delete
  patches.suse/btrfs-8167-fix-memory-patcher-through-fs_info-qgroup_ulis.patch.
- Delete
  patches.suse/btrfs-8168-avoid-double-free-of-fs_info-qgroup_ulist.patch.
- Delete
  patches.suse/btrfs-8169-fix-crash-regarding-to-ulist_add_merge.patch.
- Delete
  patches.suse/btrfs-8173-introduce-lock_ref-unlock_ref.patch.
- Delete
  patches.suse/btrfs-8222-don-t-loop-on-large-offsets-in-readdir.patch.
- Delete
  patches.suse/btrfs-8286-batch-the-extent-state-operation-when-reading-.patch.
- commit 11c6f1d
* Fri Mar 27 2015 brogers@suse.com
- Update
  patches.arch/kvm-x86-distinguish-between-stack-operation-and-near-branches.patch
  (CVE-2014-3647 bnc#899192 bsc#924721).
- Update
  patches.arch/kvm-x86-emulator-fixes-for-eip-canonical-checks-on-near-branches.patch
  (CVE-2014-3647 bnc#899192 bsc#924721).
- commit 5517431
* Fri Mar 27 2015 mszeredi@suse.cz
- configfs: fix race between dentry put and lookup (bnc#924333).
- commit b16ec5c
* Thu Mar 26 2015 bpoirier@suse.de
- net: relax rcvbuf limits (bug#923344).
- commit f032beb
* Thu Mar 26 2015 dvaleev@suse.com
- powerpc+sparc64/mm: Remove hack in mmap randomize layout
  (bsc#917839).
- commit f499c60
* Thu Mar 26 2015 mhocko@suse.cz
- Refresh patches.kabi/0005-kabi-invalidate-removed-field.patch.
  remove now unused headers
- commit 697bc11
* Thu Mar 26 2015 mhocko@suse.cz
- mm: fix anon_vma->degree underflow in anon_vma endless growing
  prevention (bnc#904242).
- commit e979cb3
* Thu Mar 26 2015 mhocko@suse.cz
- Refresh patches.kabi/0005-kabi-invalidate-removed-field.patch.
  Neil Brown has reported a crash caused by the poisoning because
  sysfs_notify_dirent checks s_attr.open and dereference it if
  non-NULL. s_attr and s_dir are in the same union and
  s_dir::children_unused is sharing the offset with sysfs_elem_attr::open
  so it would crash when dereferencing poison value.
  Drop the poisoning.
- commit 1fcdb56
* Wed Mar 25 2015 neilb@suse.de
- Update
  patches.fixes/0001-NFSv4-Do-not-accept-delegated-opens-when-a-delegatio.patch
  (bnc#864409, bnc#924282).
- commit 0e3c7c8
* Wed Mar 25 2015 ohering@suse.de
- xen: pv-on-hvm: skip initialization of emulated devices
  (fate#311487, bnc#922309).
- commit 81acf96
* Tue Mar 24 2015 jjolly@suse.de
- zcrypt: Early hwrng request prevent crypto devices to get online
  (bnc#923450,LTC#122974).
- commit c32c577
* Tue Mar 24 2015 jroedel@suse.de
- iommu/vt-d: Fix dmar_domain leak in iommu_attach_device
  (bsc#920960).
- iommu/vt-d: Only remove domain when device is removed
  (bnc#920960).
- driver core: Add BUS_NOTIFY_REMOVED_DEVICE event (bnc#920960).
- commit fb9e130
* Mon Mar 23 2015 ohering@suse.de
- Disable two hv_storvsc changes to avoid CDROM failures (bnc#923775)
  scsi: storvsc: Set the tablesize based on the information given by the host
  scsi: storvsc: Enable clustering
- commit 1116313
* Sat Mar 21 2015 mmarek@suse.cz
- Delete patches.kabi/* workarounds
- commit 2ff3137
* Sat Mar 21 2015 bpoirier@suse.de
- be2net: fixup TX-rate setting code for Skyhawk-R (bnc#908322
  FATE#317535).
- be2net: use -ENETDOWN error status when interface is down
  (bnc#908322 FATE#317535).
- commit 843c4d1
* Fri Mar 20 2015 jeffm@suse.com
- btrfs: cleanup orphans while looking up default subvolume
  (bsc#914818).
- commit b8d2147
* Fri Mar 20 2015 mhocko@suse.cz
- Refresh patches.kabi/0005-kabi-invalidate-removed-field.patch.
  SLE11-SP3 gcc doesn't like static initialization of unnamed unions
- commit fe1d511
* Fri Mar 20 2015 mhocko@suse.cz
- kabi: invalidate removed sys_elem_dir::children (bnc#919589).
- commit 7b4b400
* Thu Mar 19 2015 bpoirier@suse.de
- e1000e: remove calls to ioremap/unmap for NVM addr (bug#909495
  FATE#317394).
- e1000e: fix obscure comments (bug#909495 FATE#317394).
- e1000e: initial support for i219 (bug#909495 FATE#317394).
- e1000e: Fix 82572EI that has no hardware timestamp support
  (bug#909495 FATE#317394).
- ethernet/intel: Use eth_skb_pad and skb_put_padto helpers
  (bug#909495 FATE#317394).
- net: Add functions for handling padding frame and adding to
  length (bug#909495 FATE#317394).
- commit bbd4bfd
* Thu Mar 19 2015 jslaby@suse.cz
- mutex: Fix/document access-once assumption in
  mutex_can_spin_on_owner() (bnc#923099).
- Refresh
  patches.fixes/0001-locking-mcs-Add-some-needed-ACCESS_ONCE-calls.patch.
- commit b63e425
* Wed Mar 18 2015 bpoirier@suse.de
- supported.conf: Add i40e (Intel(R) Ethernet Controller XL710 Family support)
- commit df8547c
* Wed Mar 18 2015 dsterba@suse.cz
- btrfs: fix lost return value due to variable shadowing.
- Btrfs: abort the transaction if we fail to update the free
  space cache inode.
- Btrfs: fix scheduler warning when syncing log.
- btrfs: add more checks to btrfs_read_sys_array.
- btrfs: cleanup, rename a few variables in btrfs_read_sys_array.
- btrfs: add checks for sys_chunk_array sizes.
- btrfs: more superblock checks, lower bounds on devices and
  sectorsize/nodesize.
- Btrfs: fix setup_leaf_for_split() to avoid leaf corruption.
- btrfs: fix typos in btrfs_check_super_valid.
- btrfs: use macro accessors in superblock validation checks.
- btrfs: add more superblock checks.
- commit ca7ff5f
* Wed Mar 18 2015 dsterba@suse.cz
- Btrfs: avoid premature -ENOMEM in clear_extent_bit().
- Btrfs: avoid returning -ENOMEM in convert_extent_bit()
  too early.
- Btrfs: call inode_dec_link_count() on mkdir error path.
- Btrfs: fix fs corruption on transaction abort if device
  supports discard.
- Btrfs: make sure we wait on logged extents when fsycning
  two subvols.
- Btrfs: make xattr replace operations atomic.
- commit 3965eec
* Wed Mar 18 2015 jbohac@suse.cz
- net: sctp: fix slab corruption from use after free on INIT
  collisions (bsc#915577, CVE-2015-1421).
- commit 01d23ef
* Wed Mar 18 2015 ddiss@suse.de
- cifs: fix use-after-free bug in find_writable_file (bnc#909477).
- commit 54fe613
* Tue Mar 17 2015 neilb@suse.de
- Refresh patches.fixes/0001-md-plug_cnt.fix.
  Included missing hunks for RAID10 and RAID5.
  As ->plug_cnt is no longer being decremented, we must stop
  testing it altogether.
  See bug 922693
- commit 65d2a98
* Tue Mar 17 2015 mhocko@suse.cz
- kabi: fix for changes in the sysfs_dirent structure
  (bnc#919589).
- sysfs: Make sysfs_rename safe with sysfs_dirents in rbtrees
  (bnc#919589).
- sysfs: use rb-tree for inode number lookup (bnc#919589).
- sysfs: use rb-tree for name lookups (bnc919589).
- commit a69df19
* Tue Mar 17 2015 mszeredi@suse.cz
- fs/pipe.c: add ->statfs callback for pipefs (bsc#916848).
- commit d6ffc96
* Tue Mar 17 2015 hare@suse.de
- atomic: implement generic atomic_dec_if_positive()
  (bnc#913241,FATE#317338).
- commit 0f64208
* Tue Mar 17 2015 hare@suse.de
- hpsa: Bump version to 3.4.8 (bnc#913241,FATE#317338).
- commit 2b7eba6
* Tue Mar 17 2015 hare@suse.de
- hpsa: Use local workqueues instead of system workqueues
  (bnc#913241,FATE#317338).
- hpsa: add in P840ar controller model name
  (bnc#913241,FATE#317338).
- hpsa: add in gen9 controller model names
  (bnc#913241,FATE#317338).
- hpsa: detect and report failures changing controller transport
  modes (bnc#913241,FATE#317338).
- hpsa: shorten the wait for the CISS doorbell mode change ack
  (bnc#913241,FATE#317338).
- hpsa: refactor duplicated scan completion code into a new
  routine (bnc#913241,FATE#317338).
- hpsa: move SG descriptor set-up out of hpsa_scatter_gather()
  (bnc#913241,FATE#317338).
- hpsa: do not use function pointers in fast path command
  submission (bnc#913241,FATE#317338).
- hpsa: print CDBs instead of kernel virtual addresses for
  uncommon (bnc#913241,FATE#317338).
- hpsa: do not use a void pointer for scsi_cmd field of struct
  (bnc#913241,FATE#317338).
- hpsa: return failed from device reset/abort handlers
  (bnc#913241,FATE#317338).
- hpsa: check for ctlr lockup after command allocation in main
  io path (bnc#913241,FATE#317338).
- hpsa: guard against overflowing raid map array
  (bnc#913241,FATE#317338).
- hpsa: do not ack controller events on controllers that do not
  support (bnc#913241,FATE#317338).
- hpsa: remove incorrect BUG_ONs checking for raid offload enable
  (bnc#913241,FATE#317338).
- hpsa: count passthru cmds with atomics, not a spin locked int
  (bnc#913241,FATE#317338).
- hpsa: optimize cmd_alloc function by remembering last allocation
  (bnc#913241,FATE#317338).
- hpsa: fix race between abort handler and main i/o path
  (bnc#913241,FATE#317338).
- hpsa: honor queue depth of physical devices
  (bnc#913241,FATE#317338).
- hpsa: use workqueue to resubmit failed ioaccel commands
  (bnc#913241,FATE#317338).
- hpsa: factor out hpsa_ciss_submit function
  (bnc#913241,FATE#317338).
- hpsa: do not request device rescan on every ioaccel path error
  (bnc#913241,FATE#317338).
- hpsa: do not queue commands internally in driver
  (bnc#913241,FATE#317338).
- hpsa: get rid of cmd_special_alloc and cmd_special_free
  (bnc#913241,FATE#317338).
- hpsa: reserve some commands for use by driver
  (bnc#913241,FATE#317338).
- hpsa: avoid unneccesary calls to resource freeing functions
  (bnc#913241,FATE#317338).
- hpsa: fix memory leak in hpsa_alloc_cmd_pool
  (bnc#913241,FATE#317338).
- hpsa: report allocation failures while allocating SG chain
  blocks (bnc#913241,FATE#317338).
- hpsa: pass error from pci_set_consistent_dma_mask from
  hpsa_message (bnc#913241,FATE#317338).
- hpsa: rename hpsa_request_irq to hpsa_request_irqs
  (bnc#913241,FATE#317338).
- hpsa: report failure to ioremap config table
  (bnc#913241,FATE#317338).
- hpsa: trivial message and comment clean ups
  (bnc#913241,FATE#317338).
- hpsa: refactor hpsa_find_board_params() to encapsulate legacy
  test (bnc#913241,FATE#317338).
- hpsa: downgrade the Waiting for no-op print to dev_info
  (bnc#913241,FATE#317338).
- hpsa: propagate return value from board ID lookup
  (bnc#913241,FATE#317338).
- hpsa: propagate hard_reset failures in reset_devices mode
  (bnc#913241,FATE#317338).
- hpsa: remove 0x from queue depth print which is in decimal
  (bnc#913241,FATE#317338).
- hpsa: notice all request_irq errors (bnc#913241,FATE#317338).
- hpsa: Fix -Wunused-but-set-variable warning
  (bnc#913241,FATE#317338).
- hpsa: rename free_irqs to hpsa_free_irqs
  (bnc#913241,FATE#317338).
- hpsa: adjust RAID-1, RAID-1ADM, and RAID-6 names
  (bnc#913241,FATE#317338).
- hpsa: change how SA controllers are reset
  (bnc#913241,FATE#317338).
- hpsa: turn off interrupts when kdump starts
  (bnc#913241,FATE#317338).
- hpsa: fix memory leak in kdump hard reset
  (bnc#913241,FATE#317338).
- hpsa: correct endian sparse warnings (bnc#913241,FATE#317338).
- commit a7dc4cf
* Tue Mar 17 2015 jack@suse.cz
- direct-io: don't read inode->i_blkbits multiple times (bnc#919357).
- fs/buffer.c: make block-size be per-page and protected by the
  page lock (bnc#919357).
- commit 30188ad
* Mon Mar 16 2015 mhocko@suse.cz
- fork: report pid reservation failure properly (bnc#909684).
- commit 5dd51e2
* Fri Mar 13 2015 bpoirier@suse.de
- Refresh
  patches.drivers/mlx4-0241-net-mlx4_en-Don-t-use-irq_affinity_notifier-to-track.patch.
- Refresh
  patches.drivers/mlx4-0249-net-mlx4_en-cq-irq_desc-wasn-t-set-in-legacy-EQ-s.patch.
- commit 78522d1
* Fri Mar 13 2015 bpoirier@suse.de
- Refresh
  patches.drivers/mlx4-0241-net-mlx4_en-Don-t-use-irq_affinity_notifier-to-track.patch.
- commit 06fcfc6
* Fri Mar 13 2015 dchang@suse.com
- genirq: Add missing irq_to_desc export for CONFIG_SPARSE_IRQ=n
  (bug#919382 FATE#317529).
- commit f58560b
* Fri Mar 13 2015 dchang@suse.com
- genirq: export handle_edge_irq() and irq_to_desc() (bug#919382
  FATE#317529).
- commit 8a0be0f
* Fri Mar 13 2015 acho@suse.com
- bnx2x: Force fundamental reset for EEH recovery (bsc#908684
  FATE#317539).
- bnx2x: Configure device endianity on driver load and reset
  endianity on removal (bsc#908684 FATE#317539).
- bnx2x: prevent incorrect byte-swap in BE (bsc#908684
  FATE#317539).
- bnx2x: Fix sparse warnings (bsc#908684 FATE#317539).
- bnx2x: Fix static checker warning regarding `txdata_ptr'
  (bsc#908684 FATE#317539).
- bnx2x: Fix timesync endianity (bsc#908684 FATE#317539).
- bnx2x: Be more forgiving toward SW GRO (bsc#908684 FATE#317539).
- bnx2x: VF clean statistics (bsc#908684 FATE#317539).
- bnx2x: Fix stop-on-error (bsc#908684 FATE#317539).
- bnx2x: ethtool -d might cause timeout in log (bsc#908684
  FATE#317539).
- bnx2x: FW assertion changes (bsc#908684 FATE#317539).
- bnx2x: Make BP_VF more robust (bsc#908684 FATE#317539).
- bnx2x: Prevent pci_disable_sriov with assigned VFs (bsc#908684
  FATE#317539).
- bnx2x: Prevent IOV if no entries in CAM (bsc#908684
  FATE#317539).
- bnx2x: Safe bnx2x_panic_dump() (bsc#908684 FATE#317539).
- bnx2x: Update driver version to 1.710.51 (bsc#908684
  FATE#317539).
- bnx2x: Code cleanup (bsc#908684 FATE#317539).
- bnx2x: Add timestamping and PTP hardware clock support
  (bsc#908684 FATE#317539).
- bnx2x: Utilize FW 7.10.51 (bsc#908684 FATE#317539).
- net: ethernet: broadcom: bnx2x: Remove redundant #ifdef
  (bsc#908684 FATE#317539).
- bnx2x: fix set_setting for some PHYs (bsc#908684 FATE#317539).
- bnx2x: Fix the MSI flags (bsc#908684 FATE#317539).
- bnx2x: Enlarge the dorq threshold for VFs (bsc#908684
  FATE#317539).
- bnx2x: Fix 1G-baseT link (bsc#908684 FATE#317539).
- bnx2x: Fix link for KR with swapped polarity lane (bsc#908684
  FATE#317539).
- bnx2x: Remove useless return variables (bsc#908684 FATE#317539).
- bnx2x: Convert return 0 to return rc (bsc#908684 FATE#317539).
- bnx2x: fix build when BNX2X_SRIOV is not enabled (bsc#908684
  FATE#317539).
- bnx2x: Memory leak during VF removal (bsc#908684 FATE#317539).
- net: bnx2x: include irq.h for irqreturn_t definitions
  (bsc#908684 FATE#317539).
- bnx2x: Fix compilation when CONFIG_BNX2X_SRIOV is not set
  (bsc#908684 FATE#317539).
- bnx2x: Don't show port statistics for VFs (bsc#908684
  FATE#317539).
- bnx2x: Create workqueue for IOV related tasks (bsc#908684
  FATE#317539).
- bnx2x: Support mng. request for driver version (bsc#908684
  FATE#317539).
- bnx2x: Don't receive packets when the napi budget == 0
  (bsc#908684 FATE#317539).
- bnx2x: save RAM in kdump kernel by disabling TPA (bsc#908684
  FATE#317539).
- bnx2x: save RAM in kdump kernel by using a single queue
  (bsc#908684 FATE#317539).
- bnx2x: clamp num_queues to prevent passing a negative value
  (bsc#908684 FATE#317539).
- bnx2x: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bsc#908684 FATE#317539).
- bnx2x: utilize FW 7.8.19 (bsc#908684 FATE#317539).
- bnx2x: (semantic) revise scheduling of sp_rtnl (bsc#908684
  FATE#317539).
- bnx2x: Fix bnx2x_panic_dump for VFs (bsc#908684 FATE#317539).
- bnx2x: Revise IOV vlan/mac validation (bsc#908684 FATE#317539).
- bnx2x: Add support in PF driver for RSC (bsc#908684
  FATE#317539).
- bnx2x: Semantic Validate vlan/mac changes (bsc#908684
  FATE#317539).
- bnx2x: Remove unnecessary internal mem config (bsc#908684
  FATE#317539).
- bnx2x: Remove unused iov code (bsc#908684 FATE#317539).
- bnx2x: [Debug] change verbosity of some prints (bsc#908684
  FATE#317539).
- bnx2x: Allow VF rss on higher PFs (bsc#908684 FATE#317539).
- bnx2[x]: Make module parameters readable (bsc#908684
  FATE#317539).
- bnx2x: fix L2-GRE TCP issues (bsc#908684 FATE#317539).
- bnx2x: Fix generic option settings (bsc#908684 FATE#317539).
- bnx2x: More Shutdown revisions (bsc#908684 FATE#317539).
- bnx2x: Fix VF flr flow (bsc#908684 FATE#317539).
- bnx2x: Don't release PCI bars on shutdown (bsc#908684
  FATE#317539).
- bnx2x: fix sparse warning (bsc#908684 FATE#317539).
- bnx2x: Correct default Tx switching behaviour (bsc#908684
  FATE#317539).
- bnx2x: namespace and dead code cleanups (bsc#908684
  FATE#317539).
- bnx2x: fix DMA unmapping of TSO split BDs (bsc#908684
  FATE#317539).
- bnx2x: fix VLAN configuration for VFs (bsc#908684 FATE#317539).
- bnx2x: fix AFEX memory overflow (bsc#908684 FATE#317539).
- bnx2x: Clean before update RSS arrives (bsc#908684 FATE#317539).
- bnx2x: Correct number of MSI-X vectors for VFs (bsc#908684
  FATE#317539).
- bnx2x: limit number of interrupt vectors for 57711 (bsc#908684
  FATE#317539).
- bnx2x: Fix KR2 work-around detection of BCM8073 (bsc#908684
  FATE#317539).
- bnx2x: Fix incorrect link-up report (bsc#908684 FATE#317539).
- bnx2x: Fix Duplex setting for 54618se (bsc#908684 FATE#317539).
- bnx2x: Fix passive DAC cable detection (bsc#908684 FATE#317539).
- bnx2x: Fix 578xx-KR 1G link (bsc#908684 FATE#317539).
- net: bnx2x: slight optimization of addr compare (bsc#908684
  FATE#317539).
- bnx2x: Fix build with SRIOV disabled (bsc#908684 FATE#317539).
- bnx2x: add VF Multicast filters support (bsc#908684
  FATE#317539).
- bnx2x: Add num of VFs to Management statistics (bsc#908684
  FATE#317539).
- bnx2x: no error when RSS configuration fails (bsc#908684
  FATE#317539).
- bnx2x: add Big-Endian ethtool comment (bsc#908684 FATE#317539).
- bnx2x: Add AER support (missing bits) (bsc#908684 FATE#317539).
- bnx2x: downgrade "valid ME register value" message level
  (bsc#908684 FATE#317539).
- bnx2x: avoid null pointer dereference when enabling SR-IOV
  (bsc#908684 FATE#317539).
- bnx2x: Prevent "timeout waiting for state X" (bsc#908684
  FATE#317539).
- bnx2x: prevent CFC attention (bsc#908684 FATE#317539).
- bnx2x: Prevent panic during DMAE timeout (bsc#908684
  FATE#317539).
- bnx2x: Clean the sp rtnl task upon unload (bsc#908684
  FATE#317539).
- bnx2x: Disable VF access on PF removal (bsc#908684 FATE#317539).
- bnx2x: prevent FW assert on low mem during unload (bsc#908684
  FATE#317539).
- bnx2x: Set NETIF_F_HIGHDMA unconditionally (bsc#908684
  FATE#317539).
- bnx2x: Don't pretend during register dump (bsc#908684
  FATE#317539).
- bnx2x: Lock DMAE when used by statistic flow (bsc#908684
  FATE#317539).
- bnx2x: Prevent null pointer dereference on error flow
  (bsc#908684 FATE#317539).
- bnx2x: Fix config when SR-IOV and iSCSI are enabled (bsc#908684
  FATE#317539).
- bnx2x: Fix Coalescing configuration (bsc#908684 FATE#317539).
- bnx2x: Unlock VF-PF channel on MAC/VLAN config error (bsc#908684
  FATE#317539).
- bnx2x: Prevent an illegal pointer dereference during panic
  (bsc#908684 FATE#317539).
- bnx2x: Fix Maximum CoS estimation for VFs (bsc#908684
  FATE#317539).
- net: bnx2x: remove unnecessary pci_set_drvdata() (bsc#908684
  FATE#317539).
- bnx2x: record rx queue for LRO packets (bsc#908684 FATE#317539).
- net: bnx2x: Change variable type to bool (bsc#908684
  FATE#317539).
- net: skb_is_gso_v6() requires skb_is_gso() (bsc#908684
  FATE#317539).
- bnx2x: Add support for EXTPHY2 LED mode (bsc#908684
  FATE#317539).
- bnx2x: Change function prototype (bsc#908684 FATE#317539).
- bnx2x: Don't disable/enable SR-IOV when loading (bsc#908684
  FATE#317539).
- bnx2x: Correct VF driver info (bsc#908684 FATE#317539).
- bnx2x: Test nvram when interface is down (bsc#908684
  FATE#317539).
- bnx2x: handle known but unsupported VF messages (bsc#908684
  FATE#317539).
- bnx2x: prevent masked MCP parities from appearing (bsc#908684
  FATE#317539).
- bnx2x: prevent masking error from cnic (bsc#908684 FATE#317539).
- bnx2x: add missing VF resource allocation during init
  (bsc#908684 FATE#317539).
- bnx2x: Fix support for VFs on some PFs (bsc#908684 FATE#317539).
- bnx2x: Prevent mistaken hangup between driver & FW (bsc#908684
  FATE#317539).
- bnx2x: Fix 848xx duplex settings (bsc#908684 FATE#317539).
- bnx2x: Specific Active-DAC is not detected on 57810 (bsc#908684
  FATE#317539).
- bnx2x: 57840 non-external loopback test fail on 1G (bsc#908684
  FATE#317539).
- bnx2x: KR2 disablement fix (bsc#908684 FATE#317539).
- bnx2x: Generalize KR work-around (bsc#908684 FATE#317539).
- DMA-API: net: broadcom/bnx2x: replace
  dma_set_mask()+dma_set_coherent_mask() with new helper
  (bsc#908684 FATE#317539).
- net: bnx2x: Staticize local symbols (bsc#908684 FATE#317539).
- bnx2x: Use pci_dev pm_cap (bsc#908684 FATE#317539).
- bnx2x: Fix configuration of doorbell block (bsc#908684
  FATE#317539).
- bnx2x: Restore a call to config_init (bsc#908684 FATE#317539).
- bnx2x: fix broken compilation with CONFIG_BNX2X_SRIOV is not
  set (bsc#908684 FATE#317539).
- bnx2x: Add missing braces in bnx2x:bnx2x_link_initialize
  (bsc#908684 FATE#317539).
- bnx2x: VF RSS support - VF side (bsc#908684 FATE#317539).
- bnx2x: VF RSS support - PF side (bsc#908684 FATE#317539).
- bnx2x: Fix VF stats sync (bsc#908684 FATE#317539).
- bnx2x: Fix VF memory leak unload (bsc#908684 FATE#317539).
- bnx2x: Fix functionality of configuring vlan list (bsc#908684
  FATE#317539).
- bnx2x: Fix move FP memory deallocations (bsc#908684
  FATE#317539).
- bnx2x: vf mark stats started (bsc#908684 FATE#317539).
- bnx2x: set VF DMAE when first function has 0 supported VFs
  (bsc#908684 FATE#317539).
- bnx2x: Protect against VFs' ndos when SR-IOV is disabled
  (bsc#908684 FATE#317539).
- bnx2x: prevent VF benign attentions (bsc#908684 FATE#317539).
- bnx2x: Consider DCBX remote error (bsc#908684 FATE#317539).
- bnx2x: Change DCB context handling (bsc#908684 FATE#317539).
- bnx2x: dropless flow control not always functional (bsc#908684
  FATE#317539).
- bnx2x: prevent crash in shutdown flow with CNIC (bsc#908684
  FATE#317539).
- bnx2x: fix PTE write access error (bsc#908684 FATE#317539).
- bnx2x: fix memory leak in VF (bsc#908684 FATE#317539).
- bnx2x: update fairness parameters following DCB negotiation
  (bsc#908684 FATE#317539).
- bnx2x: clean up unnecessary MSI/MSI-X capability find
  (bsc#908684 FATE#317539).
- bnx2x: Revising locking scheme for MAC configuration (bsc#908684
  FATE#317539).
- bnx2x: fill in sane dump flag information (bsc#908684
  FATE#317539).
- bnx2x: fix dump flag handling (bsc#908684 FATE#317539).
- bnx2x: remove zeroing of dump data buffer (bsc#908684
  FATE#317539).
- bnx2x: Remove sparse and coccinelle warnings (bsc#908684
  FATE#317539).
- bnx2x: Fix compilation with no IOV support (bsc#908684
  FATE#317539).
- bnx2x: Fix 20G KR2 support claims (bsc#908684 FATE#317539).
- bnx2x: improve VF timings (bsc#908684 FATE#317539).
- bnx2x: VF ndo sanity (bsc#908684 FATE#317539).
- bnx2x: Improve PF behaviour toward VF (bsc#908684 FATE#317539).
- Bnx2x: remove redundant D0 power state set (bsc#908684
  FATE#317539).
- bnx2x: fix a power state test (bsc#908684 FATE#317539).
- bnx2x: semi-Semantic changes (bsc#908684 FATE#317539).
- bnx2x: Revise prints (bsc#908684 FATE#317539).
- bnx2x: Semantic removal and beautification (bsc#908684
  FATE#317539).
- bnx2x: Revise comments and alignment (bsc#908684 FATE#317539).
- bnx2x: Semantic change of empty lines (bsc#908684 FATE#317539).
- bnx2x: Implement PCI shutdown (bsc#908684 FATE#317539).
- bnx2x: Count number of possible FCoE interfaces (bsc#908684
  FATE#317539).
- bnx2x, bnx2fc: Use per port max exchange resources (bsc#908684
  FATE#317539).
- bnx2x: Ack unknown VF messages (bsc#908684 FATE#317539).
- bnx2x: Add and correct PCI link speed prints (bsc#908684
  FATE#317539).
- bnx2x: Zero VFs starting MACs (bsc#908684 FATE#317539).
- bnx2x: Enable `set_phys_id' for all functions (bsc#908684
  FATE#317539).
- bnx2x: Wait for MCP validity during AER (bsc#908684
  FATE#317539).
- bnx2x: Link-flap avoidance in switch dependent mode (bsc#908684
  FATE#317539).
- net-bnx2x: dont reload on GRO change (bsc#908684 FATE#317539).
- bnx2x: Prevent memory leak when cnic is absent (bsc#908684
  FATE#317539).
- bnx2x: correct reading of speed capabilities (bsc#908684
  FATE#317539).
- Revert "bnx2x: allow nvram test to run when device is down"
  (bsc#908684 FATE#317539).
- bnx2x: Prevent NULL pointer dereference in kdump (bsc#908684
  FATE#317539).
- bnx2x: Allow recovery from second slot reset (bsc#908684
  FATE#317539).
- bnx2x: Fix memory leak (bsc#908684 FATE#317539).
- bnx2x: Enhance MAC configuration for VFs (bsc#908684
  FATE#317539).
- bnx2x: Allow RX/TX pause control in autoneg (bsc#908684
  FATE#317539).
- bnx2x: prevent GRO false checksum claims (bsc#908684
  FATE#317539).
- bnx2x: update version to 1.78.17-0 (bsc#908684 FATE#317539).
- bnx2x: allow nvram test to run when device is down (bsc#908684
  FATE#317539).
- bnx2x: add additional regions for CRC memory test (bsc#908684
  FATE#317539).
- bnx2x: remove non-necessary assignment (bsc#908684 FATE#317539).
- bnx2x: fix byte-by-byte nvram write for BE machines (bsc#908684
  FATE#317539).
- bnx2x: refactor nvram read procedure (bsc#908684 FATE#317539).
- bnx2x: Fix status blocks configuration (bsc#908684 FATE#317539).
- bnx2x: Prevent UNDI FW illegal host access (bsc#908684
  FATE#317539).
- bnx2x: fix compilation without CONFIG_BNX2X_SRIOV (bsc#908684
  FATE#317539).
- bnx2x: Cosmetic changes (bsc#908684 FATE#317539).
- bnx2x: Prevent VF race (bsc#908684 FATE#317539).
- bnx2x: Fix VF outer vlan removal (bsc#908684 FATE#317539).
- bnx2x: Fix VF statistics (bsc#908684 FATE#317539).
- bnx2x: missing ARI should not be lethal (bsc#908684
  FATE#317539).
- bnx2x: Fix AER semaphore release (bsc#908684 FATE#317539).
- bnx2x: fix assignment of signed expression to unsigned variable
  (bsc#908684 FATE#317539).
- bnx2x: AER revised (bsc#908684 FATE#317539).
- bnx2x: fix occasional statistics off-by-4GB error (bsc#908684
  FATE#317539).
- bnx2x: add RSS capability for GRE traffic (bsc#908684
  FATE#317539).
- bnx2x: add missing napi deletion in error path (bsc#908684
  FATE#317539).
- bnx2x: use list_move instead of list_del/list_add (bsc#908684
  FATE#317539).
- bnx2x: Control number of vfs dynamically (bsc#908684
  FATE#317539).
- bnx2x: Add iproute2 support for vfs (bsc#908684 FATE#317539).
- bnx2x: Set ethtool ops for vfs (bsc#908684 FATE#317539).
- bnx2x: Fix SFP+ misconfiguration in iSCSI boot scenario
  (bsc#908684 FATE#317539).
- bnx2x: use the default NAPI weight (bsc#908684 FATE#317539).
- bnx2x: fix UDP checksum for 57710/57711 (bsc#908684
  FATE#317539).
- bnx2x: remove dead code and make local funcs static (bsc#908684
  FATE#317539).
- bnx2x: Force link UP when the interface is in LOOPBACK mode
  (bsc#908684 FATE#317539).
- bnx2x: SR-IOV version compatibility bugfix (bsc#908684
  FATE#317539).
- bnx2x: Fix compilation with stop-on-error (bsc#908684
  FATE#317539).
- bnx2x: correct memory release scheme (bsc#908684 FATE#317539).
- bnx2x: Remove many sparse warnings (bsc#908684 FATE#317539).
- bnx2x: Add missing VFs reference in macros (bsc#908684
  FATE#317539).
- bnx2x: Add additional debug information (bsc#908684
  FATE#317539).
- bnx2x: correct usleep_range usage (bsc#908684 FATE#317539).
- bnx2x: reorganization and beautification (bsc#908684
  FATE#317539).
- bnx2x: Semantic renovation (bsc#908684 FATE#317539).
- bnx2x: Introduce 2013 and advance version to 1.78.02 (bsc#908684
  FATE#317539).
- bnx2x: improve stop-on-error (bsc#908684 FATE#317539).
- bnx2x: add `ethtool -w' support (bsc#908684 FATE#317539).
- bnx2x: move debugging code before the return (bsc#908684
  FATE#317539).
- bnx2x: align define usage to satisfy static checkers (bsc#908684
  FATE#317539).
- bnx2x: NULL dereference on error in debug code (bsc#908684
  FATE#317539).
- bnx2x: Segregate SR-IOV code (bsc#908684 FATE#317539).
- bnx2x: Add VF device ids and enable feature (bsc#908684
  FATE#317539).
- bnx2x: Support PF <-> VF Bulletin Board (bsc#908684
  FATE#317539).
- bnx2x: Support VF FLR (bsc#908684 FATE#317539).
- bnx2x: Support of PF driver of a VF release request (bsc#908684
  FATE#317539).
- bnx2x: Support of PF driver of a VF close request (bsc#908684
  FATE#317539).
- bnx2x: Support of PF driver of a VF q_teardown request
  (bsc#908684 FATE#317539).
- bnx2x: Support of PF driver of a VF q_filters request
  (bsc#908684 FATE#317539).
- bnx2x: Support of PF driver of a VF setup_q request (bsc#908684
  FATE#317539).
- bnx2x: Support statistics collection for VFs by the PF
  (bsc#908684 FATE#317539).
- bnx2x: Support of PF driver of a VF init request (bsc#908684
  FATE#317539).
- bnx2x: Support of PF driver of a VF acquire request (bsc#908684
  FATE#317539).
- bnx2x: Infrastructure for VF <-> PF request on PF side
  (bsc#908684 FATE#317539).
- bnx2x: Prepare device and initialize VF database (bsc#908684
  FATE#317539).
- bnx2x: Allocate VF database in PF when VFs are present
  (bsc#908684 FATE#317539).
- bnx2x: VF fastpath (bsc#908684 FATE#317539).
- bnx2x: Support ndo_set_rxmode in VF driver (bsc#908684
  FATE#317539).
- bnx2x: Add teardown_q and close to VF <-> PF channel (bsc#908684
  FATE#317539).
- bnx2x: Add init, setup_q, set_mac to VF <-> PF channel
  (bsc#908684 FATE#317539).
- bnx2x: Separate VF and PF logic (bsc#908684 FATE#317539).
- bnx2x: Add to VF <-> PF channel the release request (bsc#908684
  FATE#317539).
- bnx2x: VF <-> PF channel 'acquire' at vf probe (bsc#908684
  FATE#317539).
- bnx2x: Support probing and removing of VF device (bsc#908684
  FATE#317539).
- bnx2x: remove __dev* attributes (bsc#908684 FATE#317539).
- commit 60da670
* Fri Mar 13 2015 bpoirier@suse.de
- net/mlx4_core: Limit count field to 24 bits in qp_alloc_res
  (bug#919382 FATE#317529).
- net/mlx4_core: Call synchronize_irq() before freeing EQ buffer
  (bug#919382 FATE#317529).
- mlx4: fix race accessing page->_count (bug#919382 FATE#317529).
- net: add netdev_txq_bql_{enqueue, complete}_prefetchw() helpers
  (bug#919382 FATE#317529).
- net/mlx4_en: remove NETDEV_TX_BUSY (bug#919382 FATE#317529).
- net/mlx4_en: Enable the compiler to make is_inline() inlined
  (bug#919382 FATE#317529).
- net/mlx4_en: tx_info->ts_requested was not cleared (bug#919382
  FATE#317529).
- net/mlx4_en: Use local var for skb_headlen(skb) (bug#919382
  FATE#317529).
- net/mlx4_en: Use local var in tx flow for skb_shinfo(skb)
  (bug#919382 FATE#317529).
- net/mlx4_en: mlx4_en_xmit() reads ring->cons once, and ahead
  of time to avoid stalls (bug#919382 FATE#317529).
- net/mlx4_en: Avoid false sharing in mlx4_en_en_process_tx_cq()
  (bug#919382 FATE#317529).
- net/mlx4_en: Use prefetch in tx path (bug#919382 FATE#317529).
- net/mlx4_en: Avoid a cache line miss in TX completion for
  single frag skb's (bug#919382 FATE#317529).
- net/mlx4_en: tx_info allocated with kmalloc() instead of
  vmalloc() (bug#919382 FATE#317529).
- nick kvfree() from apparmor (bug#919382 FATE#317529).
- apparmor: no need to delay vfree() (bug#919382 FATE#317529).
- net/mlx4_en: Avoid calling bswap in tx fast path (bug#919382
  FATE#317529).
- net/mlx4_en: Align tx path structures to cache lines (bug#919382
  FATE#317529).
- net/mlx4_en: Code cleanups in tx path (bug#919382 FATE#317529).
- net/mlx4_core: Deprecate error message at ConnectX-2 cards
  startup to debug (bug#919382 FATE#317529).
- net/mlx4_core: Protect QUERY_PORT wrapper from untrusted guests
  (bug#919382 FATE#317529).
- net/mlx4_core: New init and exit flow for mlx4_core (bug#919382
  FATE#317529).
- net/mlx4_core: Don't disable SRIOV if there are active VFs
  (bug#919382 FATE#317529).
- mellanox: Change en_print to return void (bug#919382
  FATE#317529).
- net/mlx4_en: Add mlx4_en_get_cqe helper (bug#919382
  FATE#317529).
- net/mlx4_core: Cache line EQE size support (bug#919382
  FATE#317529).
- net/mlx4_core: Enable CQE/EQE stride support (bug#919382
  FATE#317529).
- mlx4_en: Convert the normal skb free path to
  dev_consume_skb_any() (bug#919382 FATE#317529).
- net/mlx4: Use is_kdump_kernel() to detect kdump kernel
  (bug#919382 FATE#317529).
- treewide: fix errors in printk (bug#919382 FATE#317529).
- net/mlx4_core: Allow not to specify probe_vf in SRIOV IB mode
  (bug#919382 FATE#317529).
- IB/mlx4: Do not allow APM under RoCE (bug#919382 FATE#317529).
- IB/mlx4: Avoid accessing netdevice when building RoCE qp1 header
  (bug#919382 FATE#317529).
- mlx4: Fix mlx4 reg/unreg mac to work properly with 0-mac
  addresses (bug#919382 FATE#317529).
- IB/mlx4: Avoid executing gid task when device is being removed
  (bug#919382 FATE#317529).
- IB/mlx4: Fix lockdep splat for the iboe lock (bug#919382
  FATE#317529).
- IB/mlx4: Disable TSO for Connect-X rev. A0 HCAs (bug#919382
  FATE#317529).
- net/mlx4: Use the correct VSD mask in UPDATE_QP (bug#919382
  FATE#317529).
- net/mlx4: Correctly configure single ported VFs from the host
  (bug#919382 FATE#317529).
- net/mlx4_en: do not ignore autoneg in mlx4_en_set_pauseparam()
  (bug#919382 FATE#317529).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bug#919382
  FATE#317529).
- mlx4_core: Add support for secure-host and SMP firewall
  (bug#919382 FATE#317529).
- net/mlx4_en: mlx4_en_et_priv_flags() can be static (bug#919382
  FATE#317529).
- net/mlx4_en: Reduce memory consumption on kdump kernel
  (bug#919382 FATE#317529).
- net/mlx4_core: Use low memory profile on kdump kernel
  (bug#919382 FATE#317529).
- net/mlx4_en: Disable blueflame using ethtool private flags
  (bug#919382 FATE#317529).
- net/mlx4_en: current_mac isn't updated in port up (bug#919382
  FATE#317529).
- net/mlx4_en: cq->irq_desc wasn't set in legacy EQ's (bug#919382
  FATE#317529).
- net/mlx4_core: Remove MCG in case it is attached to promiscuous
  QPs only (bug#919382 FATE#317529).
- net/mlx4_core: In SR-IOV mode host should add promisc QP to
  default entry only (bug#919382 FATE#317529).
- net/mlx4_core: Make sure the max number of QPs per MCG isn't
  exceeded (bug#919382 FATE#317529).
- net/mlx4_core: Make sure that negative array index isn't used
  (bug#919382 FATE#317529).
- net/mlx4_core: Fix leakage of SW multicast entries (bug#919382
  FATE#317529).
- net/mlx4_en: Ignore budget on TX napi polling (bug#919382
  FATE#317529).
- net/mlx4_en: IRQ affinity hint is not cleared on port down
  (bug#919382 FATE#317529).
- net/mlx4_en: Don't use irq_affinity_notifier to track changes
  in IRQ affinity map (bug#919382 FATE#317529).
- net/mlx4_en: Fix mac_hash database inconsistency (bug#919382
  FATE#317529).
- net/mlx4_en: Do not count LLC/SNAP in MTU calculation
  (bug#919382 FATE#317529).
- net/mlx4_en: Do not disable vlan filter during promiscuous mode
  (bug#919382 FATE#317529).
- net/mlx4: Verify port number in __mlx4_unregister_mac
  (bug#919382 FATE#317529).
- net/mlx4_en: Run loopback test only when port is up (bug#919382
  FATE#317529).
- net/mlx4_en: Fix set port ratelimit for 40GE (bug#919382
  FATE#317529).
- net/mlx4_core: Fix the error flow when probing with invalid
  VF configuration (bug#919382 FATE#317529).
- net/mlx4_en: Use affinity hint (bug#919382 FATE#317529).
- cpumask: Utility function to set n'th cpu - local cpu first
  (bug#919382 FATE#317529).
- net/mlx4_core: Keep only one driver entry release mlx4_priv
  (bug#919382 FATE#317529).
- net/mlx4_core: Fix SRIOV free-pool management when enforcing
  resource quotas (bug#919382 FATE#317529).
- net: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate
  (bug#919382 FATE#317529).
- net/mlx4_core: Replace pr_warning() with pr_warn() (bug#919382
  FATE#317529).
- net/mlx4_core: Deprecate use_prio module parameter (bug#919382
  FATE#317529).
- net/mlx4_en: Fix uninitialized use of 'port_up' in
  mlx4_en_set_channels() (bug#919382 FATE#317529).
- net/mlx4_core: Fix inaccurate return value of mlx4_flow_attach()
  (bug#919382 FATE#317529).
- net/mlx4_en: Using positive error value for unsigned (bug#919382
  FATE#317529).
- net/mlx4_en: Protect MAC address modification with the
  state_lock mutex (bug#919382 FATE#317529).
- net/mlx4_core: Removed unnecessary bit operation condition
  (bug#919382 FATE#317529).
- net/mlx4_core: Fix smatch error - possible access to a null
  variable (bug#919382 FATE#317529).
- net/mlx4_en: Fix errors in MAC address changing when port is
  down (bug#919382 FATE#317529).
- net/mlx4_en: User prio mapping gets corrupted when changing
  number of channels (bug#919382 FATE#317529).
- net/mlx4_core: Enforce irq affinity changes immediatly
  (bug#919382 FATE#317529).
- radix-tree: fix contiguous iterator (bug#919382 FATE#317529).
- radix-tree: introduce bit-optimized iterator (bug#919382
  FATE#317529).
- net: get rid of SET_ETHTOOL_OPS (bug#919382 FATE#317529).
- mellanox: Logging message cleanups (bug#919382 FATE#317529).
- IB/mlx4: SET_PORT called by mlx4_ib_modify_port should be
  wrapped (bug#919382 FATE#317529).
- mlx4_core: Fix incorrect FLAGS1 bitmap test in
  mlx4_QUERY_FUNC_CAP (bug#919382 FATE#317529).
- mlx4_core: Fix memory leaks in SR-IOV error paths (bug#919382
  FATE#317529).
- net/mlx4_core: Don't issue PCIe speed/width checks for VFs
  (bug#919382 FATE#317529).
- net/mlx4_core: Load the Eth driver first (bug#919382
  FATE#317529).
- net/mlx4_core: Adjust port number in qp_attach wrapper when
  detaching (bug#919382 FATE#317529).
- mlx4_en: don't use napi_synchronize inside mlx4_en_netpoll
  (bug#919382 FATE#317529).
- net/mlx4_core: Preserve pci_dev_data after __mlx4_remove_one()
  (bug#919382 FATE#317529).
- mlx4_core: Make buffer larger to avoid overflow warning
  (bug#919382 FATE#317529).
- mlx4_core: Fix some indenting in mlx4_ib_add() (bug#919382
  FATE#317529).
- net/mlx4_core: pass pci_device_id.driver_data to __mlx4_init_one
  during reset (bug#919382 FATE#317529).
- mlx4: Add support for CONFIG_DEV command (bug#919382
  FATE#317529).
- net/mlx4: USe one wrapper that returns -EPERM (bug#919382
  FATE#317529).
- mlx4: Use actual number of PCI functions (PF + VFs) for alias
  GUID logic (bug#919382 FATE#317529).
- net/mlx4: Adapt num_vfs/probed_vf params for single port VF
  (bug#919382 FATE#317529).
- net/mlx4: Adapt code for N-Port VF (bug#919382 FATE#317529).
- net/mlx4: Add utils for N-Port VFs (bug#919382 FATE#317529).
- net/mlx4: Add data structures to support N-Ports per VF
  (bug#919382 FATE#317529).
- mlx4: Don't receive packets when the napi budget == 0
  (bug#919382 FATE#317529).
- net/mlx4_core: Load the IB driver when the device supports IBoE
  (bug#919382 FATE#317529).
- net/mlx4_core: Fix wrong dump of the vxlan offloads device
  capability (bug#919382 FATE#317529).
- net/mlx4_core: Fix memory access error in
  mlx4_QUERY_DEV_CAP_wrapper() (bug#919382 FATE#317529).
- net/mlx4: Support shutdown() interface (bug#919382 FATE#317529).
- mlx4: Call dev_kfree_skby_any instead of dev_kfree_skb
  (bug#919382 FATE#317529).
- net/mlx4_en: mlx4_en_verify_params() can be static (bug#919382
  FATE#317529).
- net,IB/mlx: Bump all Mellanox driver versions (bug#919382
  FATE#317529).
- net/mlx4_en: Change Connect-X description in kconfig (bug#919382
  FATE#317529).
- net/mlx4_en: Use union for BlueFlame WQE (bug#919382
  FATE#317529).
- net/mlx4_core: Fix sparse warning (bug#919382 FATE#317529).
- net/mlx4_en: Fix selftest failing on non 10G link speed
  (bug#919382 FATE#317529).
- net/mlx4: Replace mlx4_en_mac_to_u64() with mlx4_mac_to_u64()
  (bug#919382 FATE#317529).
- net/mlx4_en: Move queue stopped/waked counters to be per ring
  (bug#919382 FATE#317529).
- net/mlx4_en: Pad ethernet packets smaller than 17 bytes
  (bug#919382 FATE#317529).
- net/mlx4_en: Verify mlx4_en module parameters (bug#919382
  FATE#317529).
- net/mlx4_en: Fix UP limit in ieee_ets->prio_tc (bug#919382
  FATE#317529).
- net/mlx4_en: Fix bad use of dev_id (bug#919382 FATE#317529).
- net/mlx4_en: Expose port number through sysfs (bug#919382
  FATE#317529).
- net/mlx4: Fix limiting number of IRQ's instead of RSS queues
  (bug#919382 FATE#317529).
- net/mlx4: Set number of RX rings in a utility function
  (bug#919382 FATE#317529).
- IB: Report using RoCE IP based gids in port caps (bug#919382
  FATE#317529).
- mlx4: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bug#919382 FATE#317529).
- net/mlx4_core: Remove unnecessary validation for port number
  (bug#919382 FATE#317529).
- net/mlx4_core: clean up srq_res_start_move_to() (bug#919382
  FATE#317529).
- net/mlx4_core: clean up cq_res_start_move_to() (bug#919382
  FATE#317529).
- drivers/net: delete non-required instances of include
  <linux/init.h> (bug#919382 FATE#317529).
- mlx4_en: Select PTP_1588_CLOCK (bug#919382 FATE#317529).
- net/mlx4_core: Warn if device doesn't have enough PCI bandwidth
  (bug#919382 FATE#317529).
- PCI: Add PCIe Link Capability link speed and width names
  (bug#919382 FATE#317529).
- mlx4_en: Only cycle port if HW timestamp config changes
  (bug#919382 FATE#317529).
- mlx4_en: Add PTP hardware clock (bug#919382 FATE#317529).
- net: mlx4: slight optimization of addr compare (bug#919382
  FATE#317529).
- net/mlx4_core: Check port number for validity before accessing
  data (bug#919382 FATE#317529).
- net/mlx4_en: Add NAPI support for transmit side (bug#919382
  FATE#317529).
- net/mlx4_en: Ignore irrelevant hypervisor events (bug#919382
  FATE#317529).
- net/mlx4_core: Set CQE/EQE size to 64B by default (bug#919382
  FATE#317529).
- net/mlx4_en: Configure the XPS queue mapping on driver load
  (bug#919382 FATE#317529).
- net/mlx4_core: Expose physical port id as PF/VF capability
  (bug#919382 FATE#317529).
- net/mlx4_core: Introduce nic_info new flag in QUERY_FUNC_CAP
  (bug#919382 FATE#317529).
- net/mlx4_core: Rename QUERY_FUNC_CAP fields (bug#919382
  FATE#317529).
- net/mlx4_core: Remove zeroed out of explicit QUERY_FUNC_CAP
  fields (bug#919382 FATE#317529).
- net: mlx4 calls skb_set_hash (bug#919382 FATE#317529).
- mlx4_core: Roll back round robin bitmap allocation commit for
  CQs, SRQs, and MPTs (bug#919382 FATE#317529).
- mlx4_en: Implement the SIOCGHWTSTAMP ioctl (bug#919382
  FATE#317529).
- IB/mlx4: Fix error return code (bug#919382 FATE#317529).
- net/mlx4_core: destroy workqueue when driver fails to register
  (bug#919382 FATE#317529).
- net/mlx4_en: Remove selftest TX queues empty condition
  (bug#919382 FATE#317529).
- IB/mlx4: Fix device max capabilities check (bug#919382
  FATE#317529).
- IB/mlx4: Fix endless loop in resize CQ (bug#919382 FATE#317529).
- treewide: Fix typo in printk (bug#919382 FATE#317529).
- net/mlx4_en: Datapath structures are allocated per NUMA node
  (bug#919382 FATE#317529).
- net/mlx4_core: ICM pages are allocated on device NUMA node
  (bug#919382 FATE#317529).
- net/mlx4_en: Datapath resources allocated dynamically
  (bug#919382 FATE#317529).
- net/mlx4_core: Add immediate activate for VGT->VST->VGT
  (bug#919382 FATE#317529).
- net/mlx4_core: Initialize all mailbox buffers to zero before
  use (bug#919382 FATE#317529).
- net/mlx4_en: Add RFS support in UDP (bug#919382 FATE#317529).
- net/mlx4_en: Fixed crash when port type is changed (bug#919382
  FATE#317529).
- net/mlx4_core: Implement resource quota enforcement (bug#919382
  FATE#317529).
- net/mlx4_core: Fix quota handling in the QUERY_FUNC_CAP wrapper
  (bug#919382 FATE#317529).
- mlx4: Structures and init/teardown for VF resource quotas
  (bug#919382 FATE#317529).
- net/mlx4_core: Fix checking order in MR table init (bug#919382
  FATE#317529).
- net/mlx4_core: Don't fail reg/unreg vlan for older guests
  (bug#919382 FATE#317529).
- net/mlx4_core: Resource tracker for reg/unreg vlans (bug#919382
  FATE#317529).
- net/mlx4_en: Use vlan id instead of vlan index for
  unregistration (bug#919382 FATE#317529).
- net/mlx4_core: Fix reg/unreg vlan/mac to conform to the firmware
  spec (bug#919382 FATE#317529).
- net/mlx4_core: Fix register/unreg vlan flow (bug#919382
  FATE#317529).
- net/mlx4_core: Fix call to __mlx4_unregister_mac (bug#919382
  FATE#317529).
- net/mlx4_core: Load higher level modules according to ports type
  (bug#919382 FATE#317529).
- net/mlx4: Unused local variable in mlx4_opreq_action (bug#919382
  FATE#317529).
- net/mlx4: Fix typo, move similar defs to same location
  (bug#919382 FATE#317529).
- net/mlx4: Clean the code to eliminate trivial build warnings
  (bug#919382 FATE#317529).
- net/mlx4_en: Fix pages never dma unmapped on rx (bug#919382
  FATE#317529).
- net/mlx4_en: Rename name of mlx4_en_rx_alloc members (bug#919382
  FATE#317529).
- net/mlx4_en: Check device state when setting coalescing
  (bug#919382 FATE#317529).
- net/mlx4_en: Reduce scope of local variables in mlx4_en_xmit
  (bug#919382 FATE#317529).
- net/mlx4_en: Fix handling of dma_map failure (bug#919382
  FATE#317529).
- net/mlx4_en: Notify user when TX ring in error state (bug#919382
  FATE#317529).
- net/mlx4_en: Disable global flow control when PFC enabled
  (bug#919382 FATE#317529).
- net/mlx4_en: Coding style cleanup in mlx4_en_dcbnl_ieee_setpfc()
  (bug#919382 FATE#317529).
- net: mlx4: Staticize local functions (bug#919382 FATE#317529).
- include: Convert ethernet mac address declarations to use
  ETH_ALEN (bug#919382 FATE#317529).
- net/mlx4_core: Respond to operation request by firmware
  (bug#919382 FATE#317529).
- net/mlx4_en: Fix BlueFlame race (bug#919382 FATE#317529).
- mlx4_core: Fix XRC QPs detection in the resource tracker
  (bug#919382 FATE#317529).
- net/mlx4_core: VFs must ignore the enable_64b_cqe_eqe module
  param (bug#919382 FATE#317529).
- net/mlx4_core: Don't give VFs MAC addresses which are derived
  from the PF MAC (bug#919382 FATE#317529).
- IB/mlx4: Use default pkey when creating tunnel QPs (bug#919382
  FATE#317529).
- net/mlx4: fix small memory leak on error (bug#919382
  FATE#317529).
- net/mlx4_core: Dynamic VST to VST vlan/qos changes (bug#919382
  FATE#317529).
- net/mlx4_core: Fail device init if num_vfs is negative
  (bug#919382 FATE#317529).
- net/mlx4_core: Add warning in case of command timeouts
  (bug#919382 FATE#317529).
- net/mlx4_core: Replace sscanf() with kstrtoint() (bug#919382
  FATE#317529).
- net/mlx4_en: Add prints when TX timeout occurs (bug#919382
  FATE#317529).
- net/mlx4_en: Fix a race between napi poll function and RX ring
  cleanup (bug#919382 FATE#317529).
- net/mlx4_en: Change log level from error to debug for vlan
  related messages (bug#919382 FATE#317529).
- net/mlx4_en: Move register_netdev() to the end of initialization
  function (bug#919382 FATE#317529).
- net/mlx4_en: Do not query stats when device port is down
  (bug#919382 FATE#317529).
- net/mlx4_en: Fix resource leak in error flow (bug#919382
  FATE#317529).
- mlx4: allow order-0 memory allocations in RX path (bug#919382
  FATE#317529).
- mlx4: use __netdev_pick_tx instead of __skb_tx_hash in
  mlx4_en_select_queue (bug#919382 FATE#317529).
- net/mlx4: use one page fragment per incoming frame (bug#919382
  FATE#317529).
- treewide: Fix typo in printk (bug#919382 FATE#317529).
- net/mlx_en: Timestamping is not supported in slave mode
  (bug#919382 FATE#317529).
- net/mlx4_core: Keep VF assigned MAC in the PF admin table
  (bug#919382 FATE#317529).
- net/mlx4_en: Handle unassigned VF MAC address correctly
  (bug#919382 FATE#317529).
- net/mlx4_en: Fix adaptive moderation cq update (bug#919382
  FATE#317529).
- net/mlx4: Strengthen VLAN tags/priorities enforcement in VST
  mode (bug#919382 FATE#317529).
- net/mlx4_core: Add missing report on VST and spoof-checking
  dev caps (bug#919382 FATE#317529).
- mlx4_core: Expose a few helpers to fill DMFS HW strucutures
  (bug#919382 FATE#317529).
- mlx4_core: Directly expose fields of DMFS HW rule control
  segment (bug#919382 FATE#317529).
- mlx4_core: Change a few DMFS fields names to match firmare spec
  (bug#919382 FATE#317529).
- mlx4: Match DMFS promiscuous field names to firmware spec
  (bug#919382 FATE#317529).
- mlx4_core: Move DMFS HW structs to common header file
  (bug#919382 FATE#317529).
- IB/mlx4: Set link type for RAW PACKET QPs in the QP context
  (bug#919382 FATE#317529).
- IB/mlx4: Disable VLAN stripping for RAW PACKET QPs (bug#919382
  FATE#317529).
- mlx4_core: Reduce warning message for SRQ_LIMIT event to debug
  level (bug#919382 FATE#317529).
- mlx4_en: fix a build error on 32bit arches (bug#919382
  FATE#317529).
- net/mlx4: Add support to get VF config (bug#919382 FATE#317529).
- net/mlx4: Add VF MAC spoof checking support (bug#919382
  FATE#317529).
- net/mlx4: Add set VF default vlan ID and priority support
  (bug#919382 FATE#317529).
- net/mlx4: Add set VF mac address support (bug#919382
  FATE#317529).
- net/mlx4: Add structures to keep VF Ethernet ports information
  (bug#919382 FATE#317529).
- net/mlx4: Add reference counting to MAC registeration
  (bug#919382 FATE#317529).
- net/mlx4_en: Disable HW clock overflow check when no HW support
  (bug#919382 FATE#317529).
- net/mlx4_core: Disable HW timestamping for VFs (bug#919382
  FATE#317529).
- net/mlx4_en: Add a service task (bug#919382 FATE#317529).
- net/mlx4_en: Support software timestamping (bug#919382
  FATE#317529).
- net/mlx4_en: Add HW timestamping (TS) support (bug#919382
  FATE#317529).
- net/mlx4_core: Read HCA frequency and map internal clock
  (bug#919382 FATE#317529).
- net/mlx4_core: Add timestamping device capability (bug#919382
  FATE#317529).
- net/mlx4_en: set correct MTU in SRIOV (bug#919382 FATE#317529).
- net/mlx4_core: Translate guest B0 steering rules to DMFS
  (bug#919382 FATE#317529).
- net/mlx4_core: Add helper function to translate B0 steering
  rules to DMFS (bug#919382 FATE#317529).
- net/mlx4_en: Advertize DCB_CAP_DCBX_HOST in getdcbx (bug#919382
  FATE#317529).
- net/mlx4_en: Enable DCB ETS ops only when supported by the
  firmware (bug#919382 FATE#317529).
- net/mlx4_core: Added proper description for two device
  capabilities (bug#919382 FATE#317529).
- drivers:net: Remove dma_alloc_coherent OOM messages (bug#919382
  FATE#317529).
- drivers:net: Remove unnecessary OOM messages after
  netdev_alloc_skb (bug#919382 FATE#317529).
- mlx4: Remove driver specific fdb handlers (bug#919382
  FATE#317529).
- net/mlx4_en: Fix setting initial MAC address (bug#919382
  FATE#317529).
- net/mlx4_core: Disallow releasing VF QPs which have steering
  rules (bug#919382 FATE#317529).
- net/mlx4_core: Always use 64 bit resource ID when doing lookup
  (bug#919382 FATE#317529).
- net/mlx4_en: Remove ethtool flow steering rules before releasing
  QPs (bug#919382 FATE#317529).
- net/mlx4_core: Fix wrong order of flow steering resources
  removal (bug#919382 FATE#317529).
- net/mlx4_core: Fix wrong mask applied on EQ numbers in the
  wrapper (bug#919382 FATE#317529).
- mlx4: remove leftover idr_pre_get() call (bug#919382
  FATE#317529).
- net/mlx4_en: Disable RFS when running in SRIOV mode (bug#919382
  FATE#317529).
- net/mlx4_en: Cleanup MAC resources on module unload or port stop
  (bug#919382 FATE#317529).
- net/mlx4_en: Fix race when setting the device MAC address
  (bug#919382 FATE#317529).
- net/mlx4_core: Fix endianness bug in set_param_l (bug#919382
  FATE#317529).
- net/mlx4_core: Turn off device-managed FS bit in dev-cap
  wrapper if DMFS is not enabled (bug#919382 FATE#317529).
- net/mlx4_core: Disable mlx4_QP_ATTACH calls from guests if
  the host uses flow steering (bug#919382 FATE#317529).
- mlx4_en: fix allocation of CPU affinity reverse-map (bug#919382
  FATE#317529).
- mlx4_en: fix allocation of device tx_cq (bug#919382
  FATE#317529).
- mlx4_core: Disable memory windows for virtual functions
  (bug#919382 FATE#317529).
- IB/mlx4: Remove redundant NULL check before kfree (bug#919382
  FATE#317529).
- IB/mlx4: Fix compiler warning about uninitialized 'vlan'
  variable (bug#919382 FATE#317529).
- IB/mlx4: Convert is_xxx variables in build_mlx_header() to bool
  (bug#919382 FATE#317529).
- mlx4_core: Propagate MR deregistration failures to caller
  (bug#919382 FATE#317529).
- mlx4_core: Rename MPT-related functions to have mpt_ prefix
  (bug#919382 FATE#317529).
- IB/mlx4_ib: Remove local invalidate segment unused fields
  (bug#919382 FATE#317529).
- IB/mlx4: Adjust duplicate test (bug#919382 FATE#317529).
- IB/mlx4: Fix bug unwinding on error in mlx4_ib_init_sriov()
  (bug#919382 FATE#317529).
- treewide: Replace incomming with incoming in all comments and
  strings (bug#919382 FATE#317529).
- drivers: net: Remove remaining alloc/OOM messages (bug#919382
  FATE#317529).
- mlx4_en: Fix BQL reset TX queue call point (bug#919382
  FATE#317529).
- net/mlx4_en: Implement ndo fdb functionality (bug#919382
  FATE#317529).
- net/mlx4_en: Manage hash of MAC addresses per port (bug#919382
  FATE#317529).
- net/mlx4_en: Save previous MAC address of the port so we can
  replace it later (bug#919382 FATE#317529).
- net/mlx4: Move Ethernet related functionality from mlx4_core
  to mlx4_en (bug#919382 FATE#317529).
- net/mlx4_en: Cleanup multiline strings (bug#919382 FATE#317529).
- net/mlx4_en: Optimize Rx fast path filter checks (bug#919382
  FATE#317529).
- net/mlx4_en: Optimize loopback related checks in data path
  (bug#919382 FATE#317529).
- net/mlx4_en: Fix compilation error when CONFIG_INET isn't
  defined (bug#919382 FATE#317529).
- net/mlx4_en: Fix error propagation for ethtool helper function
  (bug#919382 FATE#317529).
- ethernet: Remove unnecessary alloc/OOM messages, alloc cleanups
  (bug#919382 FATE#317529).
- net/mlx4_en: Fix transmit timeout when driver restarts port
  (bug#919382 FATE#317529).
- net/mlx4_en: Don't reassign port mac address on firmware that
  supports it (bug#919382 FATE#317529).
- net/mlx4_core: Use firmware driven flow steering hash mode
  (bug#919382 FATE#317529).
- net/mlx4_en: Fix ethtool rules leftovers after module unloaded
  (bug#919382 FATE#317529).
- net/mlx4_en: Block insertion of ethtool steering rules while
  the interface is down (bug#919382 FATE#317529).
- net/mlx4_en: Fix vlan mask for ethtool steering rules
  (bug#919382 FATE#317529).
- net/mlx4_en: Validate VLAN IDs provided in ethtool flow steering
  rules (bug#919382 FATE#317529).
- net/mlx4_en: Fix ip/udp steering rules multicast mac when
  attached via ethtool (bug#919382 FATE#317529).
- net/mlx4_core: Set correctly allow_loopback flag (bug#919382
  FATE#317529).
- net/mlx4_core: Directly expose fields of HW flow steering rule
  control segment (bug#919382 FATE#317529).
- net/mlx4_en: Initialize RFS filters lock and list in init_netdev
  (bug#919382 FATE#317529).
- net/mlx4_en: Fix a race when closing TX queue (bug#919382
  FATE#317529).
- net/mlx4_core: Return proper error code when __mlx4_add_one
  fails (bug#919382 FATE#317529).
- net/mlx4_en: Use the correct netif lock on ndo_set_rx_mode
  (bug#919382 FATE#317529).
- net/mlx4_en: Fix traffic loss under promiscuous mode (bug#919382
  FATE#317529).
- net/mlx4_en: Issue the dump eth statistics command under lock
  (bug#919382 FATE#317529).
- net/mlx4_en: remove redundant code (bug#919382 FATE#317529).
- remove init of dev->perm_addr in drivers (bug#919382
  FATE#317529).
- commit 640feac
* Fri Mar 13 2015 bpoirier@suse.de
- Refresh
  patches.drivers/mlx5-0070-net-IB-mlx-Bump-all-Mellanox-driver-versions.patch.
  Remove mlx4 changes from that series.
- commit f01ded0
* Thu Mar 12 2015 dbueso@suse.de
- Refresh
  patches.fixes/0003-locking-Update-atomic-rmw-flags.patch.
- Refresh
  patches.suse/0015-x86-enable-have_arch_seccomp_filter.patch.
- commit 96b034e
* Thu Mar 12 2015 dbueso@suse.de
- locking: Update atomic rmw flags.
- Refresh patches.arch/000-apei_fixes.patch.
- Refresh
  patches.suse/0015-x86-enable-have_arch_seccomp_filter.patch.
- commit 0b02fd6
* Thu Mar 12 2015 jbeulich@suse.com
- Update Xen patches to c/s 1283.
- x86, tls, ldt: Stop checking lm in LDT_empty (bsc#920250).
- x86: irq: Check for valid irq descriptor
  incheck_irq_vectors_for_cpu_disable (bnc#914726).
- x86_64, switch_to(): Load TLS descriptors before switching DS
  and ES (bsc#911326, CVE-2014-9419).
- commit 91a88ba
* Thu Mar 12 2015 ptesarik@suse.cz
- kexec: fix build error when hugetlbfs is disabled (bsc#921741).
- kexec: export free_huge_page to VMCOREINFO (bsc#921741).
- Refresh
  patches.fixes/kexec-add-the-values-related-to-buddy-system-for-filtering-free-pages.patch.
- Refresh
  patches.suse/0008_V3_kexec_Disable_at_runtime_if_the_kernel_enforces_module_loading_restrictions.patch.
- commit 87648d5
* Thu Mar 12 2015 ptesarik@suse.cz
- Delete patches.suse/kdump-save-PG_compound.
- kexec: save PG_head_mask in VMCOREINFO (bsc#921741).
- Refresh
  patches.fixes/kexec-add-the-values-related-to-buddy-system-for-filtering-free-pages.patch.
- commit ebec3b1
* Thu Mar 12 2015 dsterba@suse.cz
- Btrfs support for EXTENT_SAME ioctl (FATE#308234)
- Btrfs: batch the extent state operation when reading pages
  (FATE#308234).
- btrfs: Introduce extent_read_full_page_nolock() (FATE#308234).
- btrfs: offline dedupe (FATE#308234).
- Refresh
  patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch.
- Refresh
  patches.suse/btrfs-8283-replace-error-code-from-btrfs_drop_extents.patch.
- commit c526df4
* Wed Mar 11 2015 dbueso@suse.de
- locking/mcs: Add some needed ACCESS_ONCE calls.
- locking/mutex: Disable optimistic spinning on some architectures
  (bcn#919884).
- Refresh patches.arch/000-apei_fixes.patch.
- commit 2709045
* Wed Mar 11 2015 dsterba@suse.cz
- Btrfs fixes from 3.18
- Btrfs: set error return value in btrfs_get_blocks_direct.
- Btrfs: fix off-by-one in cow_file_range_inline().
- btrfs: wake up transaction thread from SYNC_FS ioctl.
- Btrfs: fix wrong fsid check of scrub.
- Btrfs: try not to ENOSPC on log replay.
- Btrfs: fix build_backref_tree issue with multiple shared blocks.
- Btrfs: add missing end_page_writeback on submit_extent_page
  failure.
- Btrfs: fix crash of btrfs_release_extent_buffer_page.
- Btrfs: fix race in WAIT_SYNC ioctl.
- Btrfs: fix kfree on list_head in btrfs_lookup_csums_range
  error cleanup.
- Refresh
  patches.suse/btrfs-8252-fix-corruption-after-write-fsync-failure-fsync.patch.
- commit a2057fb
* Wed Mar 11 2015 ohering@suse.de
- scsi: storvsc: Enable clustering (fate#317533).
- scsi: storvsc: Set the tablesize based on the information
  given by the host (fate#317533).
- scsi: storvsc: Retrieve information about the capability of
  the target (fate#317533).
- scsi: storvsc: Always send on the selected outgoing channel
  (fate#317533).
- scsi: storvsc: Size the queue depth based on the ringbuffer size
  (fate#317533).
- scsi: storvsc: Increase the ring buffer size (fate#317533).
- commit dd6c76e
* Wed Mar 11 2015 ohering@suse.de
- hyperv: fix sparse warnings (fate#317533).
- hyperv: Fix the error processing in netvsc_send() (fate#317533).
- hyperv: match wait_for_completion_timeout return type
  (fate#317533).
- hyperv: netvsc.c: match wait_for_completion_timeout return type
  (fate#317533).
- HID: hyperv: match wait_for_completion_timeout return type
  (fate#317533).
- Drivers: hv: vmbus: hv_process_timer_expiration() can be static
  (fate#317533).
- Drivers: hv: vmbus: serialize Offer and Rescind offer
  (fate#317533).
- Drivers: hv: rename sc_lock to the more generic lock
  (fate#317533).
- Drivers: hv: check vmbus_device_create() return value in
  vmbus_process_offer() (fate#317533).
- hv: hv_fcopy: drop the obsolete message on transfer failure
  (fate#317533).
- Drivers: hv: vmbus: Support a vmbus API for efficiently sending
  page arrays (fate#317533).
- Drivers: hv: vmbus: Fix a bug in vmbus_establish_gpadl()
  (fate#317533).
- Drivers: hv: vmbus: Implement a clockevent device (fate#317533).
- Drivers: hv: hv_balloon: Don't post pressure status from
  interrupt context (fate#317533).
- Drivers: hv: hv_balloon: Fix a locking bug in the balloon driver
  (fate#317533).
- Drivers: hv: hv_balloon: Make adjustments in computing the floor
  (fate#317533).
- Tools: hv: do not add redundant '/' in hv_start_fcopy()
  (fate#317533).
- Tools: hv: address compiler warnings for hv_fcopy_daemon.c
  (fate#317533).
- Tools: hv: address compiler warnings for hv_kvp_daemon.c
  (fate#317533).
- Tools: hv: remove unused bytes_written from kvp_update_file()
  (fate#317533).
- x86, hyperv: Mark the Hyper-V clocksource as being continuous
  (fate#317533).
- tools: hv: kvp_daemon: make IPv6-only-injection work
  (fate#317533).
- Drivers: hv: vmbus: Use get_cpu() to get the current CPU
  (fate#317533).
- storvsc: force SPC-3 compliance on win8 and win8 r2 hosts
  (fate#317533).
- storvsc: fix a bug in storvsc limits (fate#317533).
- storvsc: force discovery of LUNs that may have been removed
  (fate#317533).
- storvsc: in responce to a scan event, scan the host
  (fate#317533).
- commit 5563d7c
* Wed Mar 11 2015 jlee@suse.com
- KEYS: close race between key lookup and freeing (bnc#912202, CVE-2014-9529).
- commit cb8fe1d
* Tue Mar 10 2015 ohering@suse.de
- clockevents: export clockevents_config_and_register for
  module use (fate#317533).
- commit ee9254e
* Tue Mar 10 2015 jjolly@suse.de
- net/mlx5_core: Fix configuration of log_uar_page_sz
  (bnc#921121).
- commit 25b820c
* Tue Mar 10 2015 jbeulich@suse.com
- scsifront: don't use bitfields for indicators modified under
  different locks.
- MSI: also reject resource with flags all clear.
- pvscsi: support suspend/resume (bsc#902286).
- x86: irq: Check for valid irq descriptor
  incheck_irq_vectors_for_cpu_disable (bnc#914726).
- x86_64, switch_to(): Load TLS descriptors before switching DS
  and ES (bsc#911326, CVE-2014-9419).
- Refresh other Xen patches.
- commit df9f1d8
* Tue Mar 10 2015 jbeulich@suse.com
- usbback: copy only filled buffers to guest (bsc#917830
  CVE-2015-0777).
- commit af80480
* Tue Mar 10 2015 jbeulich@suse.com
- xen-pciback: limit guest control of command register (bsc#919463
  CVE-2015-2150 XSA-120).
- commit 7f2ab0b
* Tue Mar 10 2015 ohering@suse.de
- sched: replace INIT_COMPLETION with reinit_completion
  (fate#317533).
- commit 2633cc3
* Tue Mar 10 2015 ohering@suse.de
- Rename a hv_storvsc patch to get proper patch ordering
- commit 03e148e
* Tue Mar 10 2015 hare@suse.de
- mpt2sas, mpt3sas: Fail the host reset initiated due to discovery
  (bnc#909785,FATE#317519).
- mpt2sas, mpt3sas: fix upper bound for the module parameter
  (bnc#909785,FATE#317519).
- mpt2sas, mpt3sas: Update attribution language to Avago
  (bnc#909785,FATE#317519).
- mpt2sas, mpt3sas: log exceeded temperature thresholds
  (bnc#909785,FATE#317519).
- mpt2sas, mpt3sas: set cpu affinity for each MSIX vectors
  (bnc#909785,FATE#317519).
- Refresh
  patches.drivers/mpt2sas-0093-log-exceeded-temperature-thresholds.patch.
- Refresh
  patches.drivers/mpt2sas-0094-Fail-the-host-reset-initiated-due-to.patch.
- Refresh
  patches.drivers/mpt2sas-0097-Fix-upper-bound-for-the-module-param.patch.
- Refresh
  patches.drivers/mpt2sas-0099-Update-attribution-language-to-Avago.patch.
- Refresh
  patches.drivers/mpt2sas-0100-set-cpu-affinity-for-each-MSIX-vecto.patch.
- commit 56cff2b
* Mon Mar  9 2015 hare@suse.de
- mpt3sas : Bump mpt3sas driver version to 9.100.00.00
  (bnc#909784,FATE#317520).
- mpt3sas: When device is blocked followed by unblock fails,
  unfreeze the I/Os (bnc#909784,FATE#317520).
- mpt3sas: Call dma_mapping_error() API after mapping an address
  with dma_map_single() API (bnc#909784,FATE#317520).
- mpt3sas: Use alloc_ordered_workqueue() API instead of
  create_singlethread_workqueue() API (bnc#909784,FATE#317520).
- mpt3sas: Added support for customer specific branding
  (bnc#909784,FATE#317520).
- mpt3sas: Return host busy error status to SML when DMA
  mapping of scatter gather list fails for a SCSI command
  (bnc#909784,FATE#317520).
- mpt2sas: Complete the SCSI command with DID_RESET status for
  log_info value 0x0x32010081 (bnc#909784,FATE#317520).
- mpt3sas: MPI 2.5 Rev JK (2.5.6) specifications
  (bnc#909784,FATE#317520).
- mpt3sas: Bump mpt3sas driver version to v6.100.00.00
  (bnc#909784,FATE#317520).
- mpt3sas: Add branding string support for OEM custom HBA
  (bnc#909784,FATE#317520).
- mpt3sas: Add branding string support for OEM's HBA
  (bnc#909784,FATE#317520).
- mpt3sas: MPI 2.5 Rev J (2.5.5) specification and 2.00.34 header
  files (bnc#909784,FATE#317520).
- mpt3sas: Update MPI2 strings to MPI2.5 (bnc#909784,FATE#317520).
- mpt2sas, mpt3sas: fix upper bound for the module parameter
  (bnc#909784,FATE#317520).
- mpt3sas: Provides the physical location of sas drives
  (bnc#909784,FATE#317520).
- mpt3sas: MPI 2.5 Rev I (2.5.4) specifications
  (bnc#909784,FATE#317520).
- mpt2sas, mpt3sas: Remove redundancy code while freeing the
  controller resources (bnc#909784,FATE#317520).
- mpt3sas: Added module parameter 'unblock_io' to unblock IO's
  during disk addition (bnc#909784,FATE#317520).
- mpt3sas: Get IOC_FACTS information using handshake protocol
  only after HBA card gets into READY or Operational state
  (bnc#909784,FATE#317520).
- mpt3sas: Added Combined Reply Queue feature to extend up-to
  96 MSIX vector support (bnc#909784,FATE#317520).
- commit 467edcb
* Mon Mar  9 2015 hare@suse.de
- mpt2sas: Bump driver version to 20.100.00.00
  (bnc#909785,FATE#317519).
- mpt2sas, mpt3sas: set cpu affinity for each MSIX vectors
  (bnc#909785,FATE#317519).
- mpt2sas, mpt3sas: Update attribution language to Avago
  (bnc#909785,FATE#317519).
- mpt2sas: map log_info value 0x0x32010081 to DID_RESET
  (bnc#909785,FATE#317519).
- mpt2sas, mpt3sas: fix upper bound for the module parameter
  (bnc#909785,FATE#317519).
- mpt2sas: MPI2 Rev BB (2.00.20) specification and 2.00.35 header
  files (bnc#909785,FATE#317519).
- mpt2sas: Bump driver version to 19.100.00.00
  (bnc#909785,FATE#317519).
- mpt2sas, mpt3sas: Fail the host reset initiated due to discovery
  (bnc#909785,FATE#317519).
- mpt2sas, mpt3sas: log exceeded temperature thresholds
  (bnc#909785,FATE#317519).
- mpt2sas: MPI2 Rev AA (2.00.19) specifications
  (bnc#909785,FATE#317519).
- mpt2sas: issue_reset is uninitialized (bnc#909785,FATE#317519).
- commit a774ef9
* Mon Mar  9 2015 oneukum@suse.de
- Delete
  patches.drivers/0002-xHCI-store-ring-s-last-segment-and-segment-numbers.patch.
- Delete
  patches.drivers/0003-xHCI-count-free-TRBs-on-transfer-ring.patch.
- Delete
  patches.drivers/0004-xHCI-factor-out-segments-allocation-and-free-functio.patch.
- Delete
  patches.drivers/0005-xHCI-set-cycle-state-when-allocate-rings.patch.
- Delete patches.drivers/0006-xHCI-dynamic-ring-expansion.patch.
- Delete
  patches.drivers/0007-xhci-Don-t-warn-on-empty-ring-for-suspended-devices.patch.
- Delete
  patches.drivers/0008-xhci-Fix-hang-on-back-to-back-Set-TR-Deq-Ptr-command.patch.
- Delete
  patches.drivers/0009-xHCI-check-enqueue-pointer-advance-into-dequeue-seg.patch.
- Delete
  patches.drivers/0010-xHCI-Allocate-2-segments-for-transfer-ring.patch.
- Delete patches.drivers/0011-xHCI-update-sg-tablesize.patch.
- commit 8da6550
* Mon Mar  9 2015 oneukum@suse.de
- Refresh
  patches.drivers/0001-uvc-work-on-XHCI-controllers-without-ring-expansion.patch.
- commit a852d55
* Fri Mar  6 2015 oneukum@suse.de
- Do not switch internal CDC device on IBM NeXtScale nx360 M5
  (bnc#913598).
- commit 6d479e8
* Thu Mar  5 2015 jkosina@suse.cz
- xen: x86, tls: Interpret an all-zero struct user_desc as
  "no segment" (bsc#920250): provide LDT_zero() for Xen
- commit 7d96a60
* Thu Mar  5 2015 mkubecek@suse.cz
- udp: only allow UFO for packets from SOCK_DGRAM sockets
  (bnc#909309).
- commit c4ee9ab
* Thu Mar  5 2015 bp@suse.de
- x86, tls: Interpret an all-zero struct user_desc as "no segment"
  (bsc#920250).
- x86, tls, ldt: Stop checking lm in LDT_empty (bsc#920250).
- x86, tls: Interpret an all-zero struct user_desc as "no segment"
  (bsc#920250).
- x86, tls, ldt: Stop checking lm in LDT_empty (bsc#920250).
- commit 4724938
* Thu Mar  5 2015 oneukum@suse.de
- xHCI: store ring's last segment and segment numbers
  (bnc#920620).
- xHCI: count free TRBs on transfer ring (bnc#920620).
- xHCI: factor out segments allocation and free function
  (bnc#920620).
- xHCI: set cycle state when allocate rings (bnc#920620).
- xHCI: dynamic ring expansion (bnc#920620).
- xhci: Don't warn on empty ring for suspended devices
  (bnc#920620).
- xhci: Fix hang on back-to-back Set TR Deq Ptr commands
  (bnc#920620).
- xHCI: check enqueue pointer advance into dequeue seg
  (bnc#920620).
- xHCI: Allocate 2 segments for transfer ring.
- xHCI: update sg tablesize (bnc#920620).
- USB: xhci-hcd: print URB's expected length in decimal, not hex
  (bnc#920620).
- xhci: Rate-limit XHCI_TRUST_TX_LENGTH quirk warning
  (bnc#920620).
- xhci: Fix bug after deq ptr set to link TRB (bnc#920620).
- driver core: Add dev_*_ratelimited() family (bnc#920620).
- drivers/usb/host/xhci-ring.c: removes unnecessary semicolon
  (bnc#920620).
- usb: host: xhci: remove unused trb var in xhci_irq()
  (bnc#920620).
- usb: xhci: fix build warning (bnc#920620).
- xhci: Remove BUG_ON in xhci_get_input_control_ctx (bnc#920620).
- xhci: Ensure a command structure points to the correct trb on
  the command ring (bnc#920620).
- xhci: refactor TRB_ENABLE_SLOT case into function (bnc#920620).
- xhci: refactor TRB_DISABLE_SLOT case into function (bnc#920620).
- xhci: refactor TRB_ADDR_DEV case into function (bnc#920620).
- xhci: use completion event's slot id rather than dig it out
  of command (bnc#920620).
- xhci: refactor TRB_RESET_DEV case into function (bnc#920620).
- xhci: refactor TRB_EVAL_CONTEXT case into function (bnc#920620).
- xhci: remove unused 'ep_ring' variable in
  handle_cmd_completion() (bnc#920620).
- xhci: add variable 'cmd_comp_code' in handle_cmd_completion()
  (bnc#920620).
- xhci: add variable 'cmd_trb' in handle_cmd_completion()
  (bnc#920620).
- xhci: add variable 'cmd_type' in handle_cmd_completion()
  (bnc#920620).
- xhci: replace 'xhci->cmd_ring->dequeue' with 'trb' in stop_ep
  cmd handler (bnc#920620).
- xhci: add argument 'slot_id' in stop_ep, set_deq and reset_ep
  cmd handlers (bnc#920620).
- usb: xhci: kill a conditional when toggling cycle (bnc#920620).
- usb: xhci: Link TRB must not occur within a USB payload burst
  (bnc#920620).
- xhci: convert TRB_CYCLE to le32 before using it to set Link
  TRB's cycle bit (bnc#920620).
- xhci: Avoid infinite loop when sg urb requires too many trbs
  (bnc#920620).
- xhci: Set scatter-gather limit to avoid failed block writes
  (bnc#920620).
- usbdevfs: Add a USBDEVFS_GET_CAPABILITIES ioctl (bnc#920620).
- USB: introduce usb_device_no_sg_constraint() helper
  (bnc#920620).
- xhci 1.0: Limit arbitrarily-aligned scatter gather (bnc#920620).
- Revert "xhci: Set scatter-gather limit to avoid failed block
  writes." (bnc#920620).
- Revert "xhci: Avoid infinite loop when sg urb requires too
  many trbs" (bnc#920620).
- Revert "usb: xhci: Link TRB must not occur within a USB payload
  burst" (bnc#920620).
- xhci: Rename SEGMENT_SIZE and SEGMENT_SHIFT as the former is
  used in a.out.h (bnc#920620).
- xhci: fix usb3 streams (bnc#920620).
- xhci: Remove segments from radix tree on failed insert
  (bnc#920620).
- xhci: xhci_mem_cleanup: make sure cmd_ring_reserved_trbs really
  is 0 (bnc#920620).
- xhci: The trb_address_map radix tree expects 1KB segment memory
  aligment (bnc#920620).
- Revert "xhci 1.0: Limit arbitrarily-aligned scatter
  gather." (bnc#920620).
- xhci: Use correct SLOT ID when handling a reset device command
  (bnc#920620).
- xhci: xhci_ring_device: Ring stream ring bells for endpoints
  with streams (bnc#920620).
- Update patches.drivers/0001-xHCI-store-ring-s-type.patch
  (bnc#920620).
- commit d3b8712
* Wed Mar  4 2015 dchang@suse.com
- cxgb4vf: FL Starvation Threshold needs to be larger than the
  SGE's Egress Congestion Threshold (bsc#909580 FATE#317556).
- cxgb4/cxgb4vf: For T5 use Packing and Padding Boundaries for
  SGE DMA transfers (bsc#909580 FATE#317556).
- cxgb4vf: Move fl_starv_thres into adapter->sge data structure
  (bsc#909580 FATE#317556).
- cxgb4vf: Replace repetitive pci device ID's with right ones
  (bsc#909580 FATE#317556).
- cxgb4vf: Add 40G support for cxgb4vf driver (bsc#909580
  FATE#317556).
- cxgb4/cxgb4vf: Updated the LSO transfer length in CPL_TX_PKT_LSO
  for T5 (bsc#909580 FATE#317556).
- cxgb4/cxgb4vf: Add Devicde ID for two more adapter (bsc#909580
  FATE#317556).
- cxgb4vf: Remove superfluous "idx" parameter of CH_DEVICE()
  macro (bsc#909580 FATE#317556).
- cxgb4/cxgb4vf: Add device ID for new adapter and remove for
  dbg adapter (bsc#909580 FATE#317556).
- cxgb4: Free completed tx skbs promptly (bsc#909580 FATE#317556).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#909580
  FATE#317556).
- cxgb4vf: Turn off SGE RX/TX Callback Timers and interrupts in
  PCI shutdown routine (bsc#909580 FATE#317556).
- cxgb4vf: Adds device ID for few more Chelsio T4 Adapters
  (bsc#909580 FATE#317556).
- net: get rid of SET_ETHTOOL_OPS (bsc#909580 FATE#317556).
- cxgb4vf: Check if rx checksum offload is enabled, while reading
  hardware calculated checksum (bsc#909580 FATE#317556).
- cxgb4vf: Adds device Id for few more Chelsio adapters
  (bsc#909580 FATE#317556).
- cxfb4vf: Call dev_kfree/consume_skb_any instead of
  [dev_]kfree_skb (bsc#909580 FATE#317556).
- cxgb4vf: Use pci_enable_msix_range() instead of
  pci_enable_msix() (bsc#909580 FATE#317556).
- cxgb4vf: Remove superfluous call to pci_disable_msix()
  (bsc#909580 FATE#317556).
- cxgb4: make functions static and remove dead code (bsc#909580
  FATE#317556).
- cxgb4vf: added much cleaner implementation of is_t4()
  (bsc#909580 FATE#317556).
- net: cxgb4vf: use DEFINE_PCI_DEVICE_TABLE (bsc#909580
  FATE#317556).
- net: cxgb4vf: remove unnecessary pci_set_drvdata() (bsc#909580
  FATE#317556).
- net: cxgb4vf: Staticize local symbols (bsc#909580 FATE#317556).
- cxgb4vf: Support CPL_SGE_EGR_UPDATEs encapsulated in a
  CPL_FW4_MSG (bsc#909580 FATE#317556).
- cxgb4vf: Add support for Chelsio T5 adapter (bsc#909580
  FATE#317556).
- cxgb4vf: Fix VLAN extraction counter increment (bsc#909580
  FATE#317556).
- remove init of dev->perm_addr in drivers (bsc#909580
  FATE#317556).
- chelsio: Use netdev_<level> and pr_<level> (bsc#909580
  FATE#317556).
- drivers/net: fix up function prototypes after __dev* removals
  (bsc#909580 FATE#317556).
- cxgb4vf: remove __dev* attributes (bsc#909580 FATE#317556).
- [SCSI] cxgb4/cxgb4vf: Chelsio FCoE offload driver submission
  (common header updates) (bsc#909580 FATE#317556).
- commit c1286d4
* Wed Mar  4 2015 neilb@suse.de
- md: don't wait for plug_cnt to go to zero (bnc#891641).
- commit 6f3420e
* Wed Mar  4 2015 neilb@suse.de
- xfs: introduce xfs_bmapi_read() (bnc#891641).
- xfs: factor extent map manipulations out of xfs_bmapi
  (bnc#891641).
- commit c0dfccb
* Wed Mar  4 2015 neilb@suse.de
- dm: optimize use SRCU and RCU (bnc#910517).
- commit a8f24b5
* Tue Mar  3 2015 jjolly@suse.de
- Removed creation of export.h and instead used module.h
  - Refresh
    patches.drivers/mlx5-0003-mlx5-Add-driver-for-Mellanox-Connect-IB-adapters.patch.
  - Refresh
    patches.drivers/mlx5-0034-IB-mlx5-Multithreaded-create-MR.patch.
  - Refresh
    patches.drivers/mlx5-0124-IB-mlx5-Enhance-UMR-support-to-allow-partial-page-ta.patch.
  - Refresh patches.suse/0001_V3_Add_secure_modules_call.patch.
  - Delete
    patches.drivers/mlx5-0002-module.h-split-out-the-EXPORT_SYMBOL-into-export.h.patch.
- commit 02b678d
* Tue Mar  3 2015 dchang@suse.com
- cxgb4: Fill in supported link mode for SFP modules (bsc#909577
  FATE#317550).
- cxgb4 : Fix DCB priority groups being returned in wrong order
  (bsc#909577 FATE#317550).
- cxgb4 : dcb open-lldp interop fixes (bsc#909577 FATE#317550).
- cxgb4 : Fix bug in DCB app deletion (bsc#909577 FATE#317550).
- cxgb4/cxgb4vf: For T5 use Packing and Padding Boundaries for
  SGE DMA transfers (bsc#909577 FATE#317550).
- cxgb4 : Fix missing initialization of win0_lock (bsc#909577
  FATE#317550).
- cxgb4 : Handle dcb enable correctly (bsc#909577 FATE#317550).
- cxgb4 : Improve handling of DCB negotiation or loss thereof
  (bsc#909577 FATE#317550).
- cxgb4 : Fix build failure in cxgb4 when ipv6 is disabled/not
  in-built (bsc#909577 FATE#317550).
- cxgb4: Update Kconfig to include Chelsio T5 adapter (bsc#909577
  FATE#317550).
- cxgb4: Fix FW flash logic using ethtool (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Make c4iw_wr_log_size_order static (bsc#909577
  FATE#317550).
- cxgb4: Wait for device to get ready before reading any register
  (bsc#909577 FATE#317550).
- cxgb4/cxgb4vf: Updated the LSO transfer length in CPL_TX_PKT_LSO
  for T5 (bsc#909577 FATE#317550).
- cxgb4: clean up a type issue (bsc#909577 FATE#317550).
- cxgb4: potential shift wrapping bug (bsc#909577 FATE#317550).
- cxgb4: Add support for adaptive rx (bsc#909577 FATE#317550).
- cxgb4/cxgb4vf: Add Devicde ID for two more adapter (bsc#909577
  FATE#317550).
- cxgb4: Use BAR2 Going To Sleep (GTS) for T5 and later
  (bsc#909577 FATE#317550).
- cxgb4: Don't allocate adapter structure for all PF's (bsc#909577
  FATE#317550).
- cxgb4/cxgb4vf: Add device ID for new adapter and remove for
  dbg adapter (bsc#909577 FATE#317550).
- cxgb4: Add warning msg when attaching to adapters which have
  FLASHes smaller than 2Mb (bsc#909577 FATE#317550).
- cxgb4: Fix t4_flash_erase_sectors() to throw an error
  when requested to erase sectors which aren't in the FLASH
  (bsc#909577 FATE#317550).
- cxgb4: Add support to S25FL032P flash (bsc#909577 FATE#317550).
- cxgb4: Allow T4/T5 firmware sizes up to 1MB (bsc#909577
  FATE#317550).
- cxgb4: remove bond->lock (bsc#909577 FATE#317550).
- cxgb4: Issue mbox commands on correct mbox (bsc#909577
  FATE#317550).
- cxgb4: Avoid dumping Write-only registers in register dump
  (bsc#909577 FATE#317550).
- cxgb4: Detect and display firmware reported errors (bsc#909577
  FATE#317550).
- cxgb4: Fix T5 adapter accessing T4 adapter registers (bsc#909577
  FATE#317550).
- cxgb4: Fixed the code to use correct length for part number
  (bsc#909577 FATE#317550).
- cxgb4: Fix for handling 1Gb/s SFP+ Transceiver Modules
  (bsc#909577 FATE#317550).
- cxgb4: Free completed tx skbs promptly (bsc#909577 FATE#317550).
- cxgb4: Fix race condition in cleanup (bsc#909577 FATE#317550).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#909577
  FATE#317550).
- cxgb4: IEEE fixes for DCBx state machine (bsc#909577
  FATE#317550).
- cxgb4: Update FW version string to match FW binary version
  (bsc#909577 FATE#317550).
- cxgb4: Fix for SR-IOV VF initialization (bsc#909577
  FATE#317550).
- cxgb4 : Disable recursive mailbox commands when enabling vi
  (bsc#909577 FATE#317550).
- cxgb4: only free allocated fls (bsc#909577 FATE#317550).
- RDMA/cxgb4: Only call CQ completion handler if it is armed
  (bsc#909577 FATE#317550).
- cxgb4: Fixed incorrect check for memory operation in
  t4_memory_rw (bsc#909577 FATE#317550).
- iw_cxgb4: Don't limit TPTE count to 32KB (bsc#909577
  FATE#317550).
- iw_cxgb4: advertise the correct device max attributes
  (bsc#909577 FATE#317550).
- iw_cxgb4: Support query_qp() verb (bsc#909577 FATE#317550).
- iw_cxgb4: log detailed warnings for negative advice (bsc#909577
  FATE#317550).
- cxgb4: Add the MC1 registers to read in the interrupt handler
  (bsc#909577 FATE#317550).
- include/linux/math64.h: add div64_ul() (bsc#909577 FATE#317550).
- iw_cxgb4: fix for 64-bit integer division (bsc#909577
  FATE#317550).
- cxgb4: Export symbols required by cxgb4i for ipv6 support and
  required defines (bsc#909577 FATE#317550).
- cxgb4/iw_cxgb4: Move common defines to cxgb4 (bsc#909577
  FATE#317550).
- cxgb4/iw_cxgb4: work request logging feature (bsc#909577
  FATE#317550).
- cxgb4/iw_cxgb4: display TPTE on errors (bsc#909577 FATE#317550).
- cxgb4/iw_cxgb4: use firmware ord/ird resource limits (bsc#909577
  FATE#317550).
- iw_cxgb4: Detect Ing. Padding Boundary at run-time (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Initialize the device status page (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Clean up connection on ARP error (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Fix skb_leak in reject_cr() (bsc#909577
  FATE#317550).
- drivers/net/ethernet/chelsio/cxgb4/cxgb4_main.c: remove
  unnecessary null test before debugfs_remove_recursive
  (bsc#909577 FATE#317550).
- cxgb4: Adds device ID for few more Chelsio T4 Adapters
  (bsc#909577 FATE#317550).
- cxgb4: Replaced the backdoor mechanism to access the HW memory
  with PCIe Window method (bsc#909577 FATE#317550).
- cxgb4: Use FW interface to get BAR0 value (bsc#909577
  FATE#317550).
- rdma/cxgb4: Fixes cxgb4 probe failure in VM when PF is exposed
  through PCI Passthrough (bsc#909577 FATE#317550).
- cxgb4: use dev_port to identify ports (bsc#909577 FATE#317550).
- net: Add sysfs file for port number (bsc#909577 FATE#317550).
- cxgb4: Not need to hold the adap_rcu_lock lock when read
  adap_rcu_list (bsc#909577 FATE#317550).
- cxgb4: Fix endian bug introduced in cxgb4 dcb patchset
  (bsc#909577 FATE#317550).
- cxgb4 : Update copyright year on all cxgb4 files (bsc#909577
  FATE#317550).
- cxgb4 : Makefile & Kconfig changes for DCBx support (bsc#909577 FATE#317550).
  Update config files.
  Add support Data Center Bridging (DCB) Support for Chelsio T4/T5 cards (CHELSIO_T4_DCB).
- cxgb4 : Integrate DCBx support into cxgb4 module. Register
  dbcnl_ops to give access to DCBx functions (bsc#909577
  FATE#317550).
- cxgb4 : Add DCBx support codebase and dcbnl_ops (bsc#909577
  FATE#317550).
- cxgb4 : Update fw interface file for DCBx support. Adds all
  the required fields to fw interface to communicate DCBx info
  (bsc#909577 FATE#317550).
- cxgb4: Change default Interrupt Holdoff Packet Count Threshold
  (bsc#909577 FATE#317550).
- iw_cxgb4: Allocate and use IQs specifically for indirect
  interrupts (bsc#909577 FATE#317550).
- RDMA/cxgb4: add missing padding at end of struct
  c4iw_alloc_ucontext_resp (bsc#909577 FATE#317550).
- RDMA/cxgb4: Add missing padding at end of struct
  c4iw_create_cq_resp (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix memory leaks in c4iw_alloc() error paths
  (bsc#909577 FATE#317550).
- net: get rid of SET_ETHTOOL_OPS (bsc#909577 FATE#317550).
- cxgb4: Check if rx checksum offload is enabled, while reading
  hardware calculated checksum (bsc#909577 FATE#317550).
- cxgb4: Decode the firmware port and module type a bit more
  for ethtool (bsc#909577 FATE#317550).
- cxgb4: Decode PCIe Gen3 link speed (bsc#909577 FATE#317550).
- RDMA/cxgb4: Update Kconfig to include Chelsio T5 adapter
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Only allow kernel db ringing for T4 devs (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Force T5 connections to use TAHOE congestion control
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix endpoint mutex deadlocks (bsc#909577
  FATE#317550).
- cxgb4: use the correct max size for firmware flash (bsc#909577
  FATE#317550).
- cxgb4: Save the correct mac addr for hw-loopback connections
  in the L2T (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix over-dereference when terminating (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Use uninitialized_var() (bsc#909577 FATE#317550).
- RDMA/cxgb4: Add missing debug stats (bsc#909577 FATE#317550).
- RDMA/cxgb4: Initialize reserved fields in a FW work request
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Use pr_warn_ratelimited (bsc#909577 FATE#317550).
- RDMA/cxgb4: Max fastreg depth depends on DSGL support
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: SQ flush fix (bsc#909577 FATE#317550).
- RDMA/cxgb4: rmb() after reading valid gen bit (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Endpoint timeout fixes (bsc#909577 FATE#317550).
- RDMA/cxgb4: Use the BAR2/WC path for kernel QPs and T5 devices
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Disable DSGL use by default (bsc#909577
  FATE#317550).
- RDMA/cxgb4: rx_data() needs to hold the ep mutex (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Drop RX_DATA packets if the endpoint is gone
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Lock around accept/reject downcalls (bsc#909577
  FATE#317550).
- cxgb4: Adds device ID for few more Chelsio Adapters (bsc#909577
  FATE#317550).
- RDMA/cxgb4: set error code on kmalloc() failure (bsc#909577
  FATE#317550).
- chelsio: Remove addressof casts to same type (bsc#909577
  FATE#317550).
- cxgb4: Call dev_kfree/consume_skb_any instead of [dev_]kfree_skb
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Update snd_seq when sending MPA messages (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Connect_request_upcall fixes (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Ignore read reponse type 1 CQEs (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Fix possible memory leak in RX_PKT processing
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Don't leak skb in c4iw_uld_rx_handler() (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Save the correct map length for fast_reg_page_lists
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Default peer2peer mode to 1 (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Mind the sq_sig_all/sq_sig_type QP attributes
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix incorrect BUG_ON conditions (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Always release neigh entry (bsc#909577 FATE#317550).
- RDMA/cxgb4: Cap CQ size at T4_MAX_IQ_SIZE (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Fix four byte info leak in c4iw_create_cq()
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix underflows in c4iw_create_qp() (bsc#909577
  FATE#317550).
- cxgb4/iw_cxgb4: Doorbell Drop Avoidance Bug Fixes (bsc#909577
  FATE#317550).
- cxgb4/iw_cxgb4: Treat CPL_ERR_KEEPALV_NEG_ADVICE as negative
  advice (bsc#909577 FATE#317550).
- cxgb4: Calculate len properly for LSO path (bsc#909577
  FATE#317550).
- cxgb4: Updates for T5 SGE's Egress Congestion Threshold
  (bsc#909577 FATE#317550).
- cxgb4: Rectify emitting messages about SGE Ingress DMA channels
  being potentially stuck (bsc#909577 FATE#317550).
- cxgb4: Add code to dump SGE registers when hitting idma hangs
  (bsc#909577 FATE#317550).
- cxgb4: Fix some small bugs in t4_sge_init_soft() when our Page
  Size is 64KB (bsc#909577 FATE#317550).
- net/cxgb4: use remove handler as shutdown handler (bsc#909577
  FATE#317550).
- cgxb4: Stop using ethtool SPEED_* constants (bsc#909577
  FATE#317550).
- cxgb4: Add more PCI device ids (bsc#909577 FATE#317550).
- cxgb4: Don't assume LSO only uses SGL path in t4_eth_xmit()
  (bsc#909577 FATE#317550).
- cxgb4: Remove unused registers and add missing ones (bsc#909577
  FATE#317550).
- cxgb4: Query firmware for T5 ULPTX MEMWRITE DSGL capabilities
  (bsc#909577 FATE#317550).
- cxgb4: LE-Workaround is not atomic in firmware (bsc#909577
  FATE#317550).
- cxgb4: Allow >10G ports to have multiple queues (bsc#909577
  FATE#317550).
- cxgb4: Print adapter VPD Part Number instead of Engineering
  Change field (bsc#909577 FATE#317550).
- cxgb4: Add support to recognize 40G links (bsc#909577
  FATE#317550).
- cxgb4: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Add missing neigh_release in LE-Workaround path
  (bsc#909577 FATE#317550).
- net/cxgb4: Fix referencing freed adapter (bsc#909577
  FATE#317550).
- net/cxgb4: Don't retrieve stats during recovery (bsc#909577
  FATE#317550).
- net/cxgb4: Avoid disabling PCI device for towice (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Fix gcc warning on 32-bit arch (bsc#909577
  FATE#317550).
- drivers/net: delete non-required instances of include
  <linux/init.h> (bsc#909577 FATE#317550).
- cxgb4: silence shift wrapping static checker warning (bsc#909577
  FATE#317550).
- cxgb4: Changed FW check version to match FW binary version
  (bsc#909577 FATE#317550).
- cxgb4: allow large buffer size to have page size (bsc#909577
  FATE#317550).
- cxgb4: make functions static and remove dead code (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Calculate the filter server TID properly (bsc#909577
  FATE#317550).
- cxgb4: Add API to correctly calculate tuple fields (bsc#909577
  FATE#317550).
- cxgb4: Account for stid entries properly in case of IPv6
  (bsc#909577 FATE#317550).
- cxgb4: Assign filter server TIDs properly (bsc#909577
  FATE#317550).
- cxgb4: Include TCP as protocol when creating server filters
  (bsc#909577 FATE#317550).
- cxgb4: Reserve stid 0 for T4/T5 adapters (bsc#909577
  FATE#317550).
- net: cxgb4 calls skb_set_hash (bsc#909577 FATE#317550).
- RDMA/cxgb4: Make _c4iw_write_mem_dma() static (bsc#909577
  FATE#317550).
- cxgb4: Add new scheme to update T4/T5 firmware (bsc#909577
  FATE#317550).
- cxgb4vf: added much cleaner implementation of is_t4()
  (bsc#909577 FATE#317550).
- cxgb4: Much cleaner implementation of is_t4()/is_t5()
  (bsc#909577 FATE#317550).
- IB/cxgb4: Fix formatting of physical address (bsc#909577
  FATE#317550).
- cgxb4: remove duplicate include in cxgb4.h (bsc#909577
  FATE#317550).
- net: cxgb4: remove unnecessary pci_set_drvdata() (bsc#909577
  FATE#317550).
- cxgb4: remove workqueue when driver registration fails
  (bsc#909577 FATE#317550).
- treewide: Add __GFP_NOWARN to k.alloc calls with v.alloc
  fallbacks (bsc#909577 FATE#317550).
- RDMA/cxgb4: Issue RI.FINI before closing when entering TERM
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Advertise ~0ULL as max MR size (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Always do GTS write if cidx_inc == CIDXINC_MASK
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Set arp error handler for PASS_ACCEPT_RPL messages
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix accounting for unsignaled SQ WRs to deal with
  wrap (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix QP flush logic (bsc#909577 FATE#317550).
- RDMA/cxgb4: Handle newer firmware changes (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Use correct bit shift macros for vlan filter tuples
  (bsc#909577 FATE#317550).
- cxgb4: Add CLIP support to store compressed IPv6 address
  (bsc#909577 FATE#317550).
- cxgb4: Add routines to create and remove listening IPv6 servers
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix stack info leak in c4iw_create_qp() (bsc#909577
  FATE#317550).
- cxgb4: Do not set net_device::dev_id to VI index (bsc#909577
  FATE#317550).
- cxgb3: Correct comparisons and calculations using skb->tail
  and skb-transport_header (bsc#909577 FATE#317550).
- cxgb4: Force uninitialized state if FW_ON_ADAPTER is <
  FW_VERSION and we're the MASTER_PF (bsc#909577 FATE#317550).
- cxgb4vf: Support CPL_SGE_EGR_UPDATEs encapsulated in a
  CPL_FW4_MSG (bsc#909577 FATE#317550).
- cxgb4: Support CPL_SGE_EGR_UPDATEs encapsulated in a CPL_FW4_MSG
  (bsc#909577 FATE#317550).
- cxgb4: Fix pci_device_id structure initialization with correct
  PF number (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix error return code in create_qp() (bsc#909577
  FATE#317550).
- Fix dst_neigh_lookup/dst_neigh_lookup_skb return value handling
  bug (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix onchip queue support for T5 (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Bump tcam_full stat and WR reply timeout (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Map pbl buffers for dma if using DSGL (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Use DSGLs for fastreg and adapter memory writes
  for T5 (bsc#909577 FATE#317550).
- RDMA/cxgb4: Add module_params to enable DB FC & Coalescing on T5
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Turn off db coalescing when RDMA QPs are in use
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Add Support for Chelsio T5 adapter (bsc#909577
  FATE#317550).
- cxgb4: Disable SR-IOV support for PF4-7 for T5 (bsc#909577
  FATE#317550).
- cxgb4: Update driver version and description (bsc#909577
  FATE#317550).
- cxgb4: Add T5 PCI ids (bsc#909577 FATE#317550).
- cxgb4: Add T5 debugfs support (bsc#909577 FATE#317550).
- cxgb4: Enable doorbell drop recovery only for T4 adapter
  (bsc#909577 FATE#317550).
- cxgb4: Add T5 write combining support (bsc#909577 FATE#317550).
- cxgb4: Dump T5 registers (bsc#909577 FATE#317550).
- cxgb4: Initialize T5 (bsc#909577 FATE#317550).
- cxgb4: Add macros, structures and inline functions for T5
  (bsc#909577 FATE#317550).
- cxgb4: Add register definations for T5 (bsc#909577 FATE#317550).
- cxgb4: Allow for backward compatibility with new VPD scheme
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix cast warning (bsc#909577 FATE#317550).
- RDMA/cxgb4: "cookie" can stay in host endianness (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Address sparse warnings (bsc#909577 FATE#317550).
- RDMA/cxgb4: Insert hwtid in pass_accept_req instead in
  pass_establish (bsc#909577 FATE#317550).
- RDMA/cxgb4: Don't wakeup threads for MPAv2 (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Don't reconnect on abort for mpa_rev 1 (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Fix endpoint timeout race condition (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Only log rx_data warnings if cpl status is non-zero
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Always log async errors (bsc#909577 FATE#317550).
- RDMA/cxgb4: Keep QP referenced until TID released (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Display streaming mode error only if detected in
  RTS (bsc#909577 FATE#317550).
- RDMA/cxgb4: Abort connections when moving to ERROR state
  (bsc#909577 FATE#317550).
- RDMA/cxgb4: Abort connections that receive unexpected streaming
  mode data (bsc#909577 FATE#317550).
- remove init of dev->perm_addr in drivers (bsc#909577
  FATE#317550).
- chelsio: Use netdev_<level> and pr_<level> (bsc#909577
  FATE#317550).
- RDMA/cxgb4: Fix bug for active and passive LE hash collision
  path (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix LE hash collision bug for passive open
  connection (bsc#909577 FATE#317550).
- RDMA/cxgb4: Fix LE hash collision bug for active open connection
  (bsc#909577 FATE#317550).
- cxgb4: Add LE hash collision bug fix path in LLD driver
  (bsc#909577 FATE#317550).
- cxgb4: Add T4 filter support (bsc#909577 FATE#317550).
- drivers/net: fix up function prototypes after __dev* removals
  (bsc#909577 FATE#317550).
- cxgb4: remove __dev* attributes (bsc#909577 FATE#317550).
- cxgb4/cxgb4vf: Chelsio FCoE offload driver submission (common
  header updates) (bsc#909577 FATE#317550).
- RDMA/cxgb4: use WARN (bsc#909577 FATE#317550).
- commit d4e37e3
* Mon Mar  2 2015 oneukum@suse.de
- uvc: work on XHCI controllers without ring expansion
  (bnc#915045).
- commit 3db142b
* Mon Mar  2 2015 dvaleev@suse.com
- powerpc: Make chip-id information available to userspace
  (bsc#919682).
- commit 100143c
* Mon Mar  2 2015 dvaleev@suse.com
- powerpc: Make chip-id information available to userspace
  (bsc#919682).
- commit 98a2333
* Fri Feb 27 2015 hare@suse.de
- megaraid_sas: Add back driver information (bsc#909789).
- commit 3355ce4
* Fri Feb 27 2015 hare@suse.de
- Refresh
  patches.drivers/bnx2fc-Remove-NetXtreme-II-from-source-files.patch.
- commit 3a3ab6e
* Fri Feb 27 2015 jkosina@suse.cz
- patches.drivers/Add-MODULE_ALIAS-for-autoloading-ipmi-driver-on-ACPI.patch: add
  upstream references
- commit c7cb1a9
* Fri Feb 27 2015 jkosina@suse.cz
- Add MODULE_ALIAS for autoloading ipmi driver on ACPI systems
  (FATE#317646).
- commit fea7449
* Fri Feb 27 2015 hare@suse.de
- qla2xxx: Do not crash system for sp ref count zero
  (bnc#891212,bsc#917684).
- commit 09bafbc
* Fri Feb 27 2015 hare@suse.de
- qla2xxx: Do not crash system for sp ref count zero (bnc#891212,bsc#917684).
- commit 1be44bc
* Fri Feb 27 2015 jjolly@suse.de
- supported.conf: Added mlx5_in and mlx5_core
- commit 33a8560
* Fri Feb 27 2015 jjolly@suse.de
- Update config files.
- commit 7a30cc8
* Fri Feb 27 2015 jjolly@suse.de
- Refresh patches.suse/0001_V3_Add_secure_modules_call.patch.
- commit 64076b7
* Fri Feb 27 2015 jjolly@suse.de
- net: Mellanox: Delete unnecessary checks before the function
  call "vunmap" (bnc#905015 fate#317531).
- net/mlx5_core: Move to use hex PCI device IDs (bnc#905015
  fate#317531).
- infiniband: mlx5: avoid a compile-time warning (bnc#905015
  fate#317531).
- mlx5: avoid build warnings on 32-bit (bnc#905015 fate#317531).
- mlx5_core: Re-add MLX5_DEV_CAP_FLAG_ON_DMND_PG flag (bnc#905015
  fate#317531).
- IB/mlx5: Enhance UMR support to allow partial page table update
  (bnc#905015 fate#317531).
- mlx5: Fix error flow in add_keys (bnc#905015 fate#317531).
- mlx5: Fix sparse warnings (bnc#905015 fate#317531).
- net/mlx5_core: Add more supported devices (bnc#905015
  fate#317531).
- net/mlx5_core: Clear outbox of dealloc uar (bnc#905015
  fate#317531).
- net/mlx5_core: Print resource number on QP/SRQ async events
  (bnc#905015 fate#317531).
- net/mlx5_core: Remove unused dev cap enum fields (bnc#905015
  fate#317531).
- net/mlx5_core: Fix command queue size enforcement (bnc#905015
  fate#317531).
- net/mlx5_core: Fix min vectors value in mlx5_enable_msix
  (bnc#905015 fate#317531).
- net/mlx5_core: Request the mlx5 IB module on driver load
  (bnc#905015 fate#317531).
- net/mlx5_core: Fix race on driver load (bnc#905015 fate#317531).
- net/mlx5_core: Fix race in create EQ (bnc#905015 fate#317531).
- net/mlx5_core: Call synchronize_irq() before freeing EQ buffer
  (bnc#905015 fate#317531).
- IB/mlx5: Use extended internal signature layout (bnc#905015
  fate#317531).
- IB/mlx5: Use enumerations for PI copy mask (bnc#905015
  fate#317531).
- IB/mlx5: Modify to work with arbitrary page size (bnc#905015
  fate#317531).
- IB/mlx5: Remove duplicate code from mlx5_set_path (bnc#905015
  fate#317531).
- IB/mlx5: Fix possible array overflow (bnc#905015 fate#317531).
- IB/mlx5: Improve debug prints in mlx5_ib_reg_user_mr (bnc#905015
  fate#317531).
- IB/mlx5: Clear umr resources after ib_unregister_device
  (bnc#905015 fate#317531).
- net/mlx5_core: Add ConnectX-4 to list of supported devices
  (bnc#905015 fate#317531).
- net/mlx5_core: Identify resources by their type (bnc#905015
  fate#317531).
- net/mlx5_core: use set/get macros in device caps (bnc#905015
  fate#317531).
- net/mlx5_core: Use hardware registers description header file
  (bnc#905015 fate#317531).
- net/mlx5_core: Update device capabilities handling (bnc#905015
  fate#317531).
- IB/mlx5: Use ARRAY_SIZE instead of sizeof/sizeof[0] (bnc#905015
  fate#317531).
- mlx5: Adjust events to use unsigned long param instead of void *
  (bnc#905015 fate#317531).
- mlx5: minor fixes (mainly avoidance of hidden casts) (bnc#905015
  fate#317531).
- mlx5: Move pci device handling from mlx5_ib to mlx5_core
  (bnc#905015 fate#317531).
- IB/mlx5: Enable "block multicast loopback" for kernel consumers
  (bnc#905015 fate#317531).
- mlx5_core: Fix possible race between mr tree insert/delete
  (bnc#905015 fate#317531).
- IB/mlx5: Fix warning about cast of wr_id back to pointer on
  32 bits (bnc#905015 fate#317531).
- IB/mlx5: add missing padding at end of struct mlx5_ib_create_srq
  (bnc#905015 fate#317531).
- IB/mlx5: add missing padding at end of struct mlx5_ib_create_cq
  (bnc#905015 fate#317531).
- IB/mlx5: Refactor UMR to have its own context struct (bnc#905015
  fate#317531).
- IB/mlx5: Set QP offsets and parameters for user QPs and not
  just for kernel QPs (bnc#905015 fate#317531).
- mlx5_core: Store MR attributes in mlx5_mr_core during creation
  and after UMR (bnc#905015 fate#317531).
- IB/mlx5: Add MR to radix tree in reg_mr_callback (bnc#905015
  fate#317531).
- IB/mlx5: Fix error handling in reg_umr (bnc#905015 fate#317531).
- mlx5_core: Copy DIF fields only when input and output space
  values match (bnc#905015 fate#317531).
- mlx5_core: Simplify signature handover wqe for interleaved
  buffers (bnc#905015 fate#317531).
- mlx5_core: Fix signature handover operation for interleaved
  buffers (bnc#905015 fate#317531).
- IB/mlx5: Add block multicast loopback support (bnc#905015
  fate#317531).
- IB/mlx5_core: remove unreachable function call in module init
  (bnc#905015 fate#317531).
- IB/mlx5: Expose support for signature MR feature (bnc#905015
  fate#317531).
- IB/mlx5: Collect signature error completion (bnc#905015
  fate#317531).
- IB/mlx5: Support IB_WR_REG_SIG_MR (bnc#905015 fate#317531).
- IB/mlx5: Keep mlx5 MRs in a radix tree under device (bnc#905015
  fate#317531).
- IB/mlx5: Remove MTT access mode from umr flags helper function
  (bnc#905015 fate#317531).
- IB/mlx5: Break up wqe handling into begin & finish routines
  (bnc#905015 fate#317531).
- IB/mlx5: Initialize mlx5_ib_qp signature-related members
  (bnc#905015 fate#317531).
- mlx5: Implement create_mr and destroy_mr (bnc#905015
  fate#317531).
- IB/core: Introduce signature verbs API (bnc#905015 fate#317531).
- IB/core: Introduce protected memory regions (bnc#905015
  fate#317531).
- net,IB/mlx: Bump all Mellanox driver versions (bnc#905015
  fate#317531).
- mlx5: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bnc#905015 fate#317531).
- IB/mlx5: Remove dependency on X86 (bnc#905015 fate#317531).
- mlx5: Add include of <linux/slab.h> because of kzalloc()/kfree()
  use (bnc#905015 fate#317531).
- IB/mlx5: Don't set "block multicast loopback" capability
  (bnc#905015 fate#317531).
- IB/mlx5: Fix binary compatibility with libmlx5 (bnc#905015
  fate#317531).
- IB/mlx5: Fix RC transport send queue overhead computation
  (bnc#905015 fate#317531).
- IB/mlx5: Verify reserved fields are cleared (bnc#905015
  fate#317531).
- IB/mlx5: Remove old field for create mkey mailbox (bnc#905015
  fate#317531).
- IB/mlx5: Abort driver cleanup if teardown hca fails (bnc#905015
  fate#317531).
- IB/mlx5: Allow creation of QPs with zero-length work queues
  (bnc#905015 fate#317531).
- mlx5_core: Fix PowerPC support (bnc#905015 fate#317531).
- mlx5_core: Improve debugfs readability (bnc#905015 fate#317531).
- IB/mlx5: Add support for resize CQ (bnc#905015 fate#317531).
- IB/mlx5: Implement modify CQ (bnc#905015 fate#317531).
- IB/mlx5: Make sure doorbell record is visible before doorbell
  (bnc#905015 fate#317531).
- mlx5_core: Use mlx5 core style warning (bnc#905015 fate#317531).
- IB/mlx5: Clear out struct before create QP command (bnc#905015
  fate#317531).
- mlx5_core: Fix out arg size in access_register command
  (bnc#905015 fate#317531).
- IB/mlx5: Fix micro UAR allocator (bnc#905015 fate#317531).
- mlx5_core: Remove dead code (bnc#905015 fate#317531).
- IB/mlx5: Remove unused code in mr.c (bnc#905015 fate#317531).
- IB/mlx5: Fix page shift in create CQ for userspace (bnc#905015
  fate#317531).
- IB/mlx5: Fix list_del of empty list (bnc#905015 fate#317531).
- IB/mlx5: Remove dead code (bnc#905015 fate#317531).
- mlx5: Use enum to indicate adapter page size (bnc#905015
  fate#317531).
- IB/mlx5: Update opt param mask for RTS2RTS (bnc#905015
  fate#317531).
- IB/mlx5: Remove "Always false" comparison (bnc#905015
  fate#317531).
- IB/mlx5: Remove dead code in mr.c (bnc#905015 fate#317531).
- mlx5_core: Change optimal_reclaimed_pages for better performance
  (bnc#905015 fate#317531).
- mlx5: Clear reserved area in set_hca_cap() (bnc#905015
  fate#317531).
- mlx5: Support communicating arbitrary host page size to firmware
  (bnc#905015 fate#317531).
- mlx5: Fix cleanup flow when DMA mapping fails (bnc#905015
  fate#317531).
- IB/mlx5: Fix srq free in destroy qp (bnc#905015 fate#317531).
- IB/mlx5: Simplify mlx5_ib_destroy_srq (bnc#905015 fate#317531).
- IB/mlx5: Fix overflow check in IB_WR_FAST_REG_MR (bnc#905015
  fate#317531).
- IB/mlx5: Multithreaded create MR (bnc#905015 fate#317531).
- IB/mlx5: Fix check of number of entries in create CQ (bnc#905015
  fate#317531).
- IB/mlx5: Ensure proper synchronization accessing memory
  (bnc#905015 fate#317531).
- IB/mlx5: Fix alignment of reg umr gather buffers (bnc#905015
  fate#317531).
- IB/mlx5: Fix eq names to display nicely in /proc/interrupts
  (bnc#905015 fate#317531).
- mlx5: Fix error code translation from firmware to driver
  (bnc#905015 fate#317531).
- IB/mlx5: Fix opt param mask according to firmware spec
  (bnc#905015 fate#317531).
- mlx5: Fix opt param mask for sq err to rts transition
  (bnc#905015 fate#317531).
- IB/mlx5: Disable atomic operations (bnc#905015 fate#317531).
- mlx5: Fix layout of struct mlx5_init_seg (bnc#905015
  fate#317531).
- mlx5: Keep polling to reclaim pages while any returned
  (bnc#905015 fate#317531).
- IB/mlx5: Avoid async events on invalid port number (bnc#905015
  fate#317531).
- IB/mlx5: Decrease memory consumption of mr caches (bnc#905015
  fate#317531).
- mlx5: Remove checksum on command interface commands (bnc#905015
  fate#317531).
- IB/mlx5: Fix memory leak in mlx5_ib_create_srq (bnc#905015
  fate#317531).
- IB/mlx5: Flush cache workqueue before destroying it (bnc#905015
  fate#317531).
- IB/mlx5: Fix send work queue size calculation (bnc#905015
  fate#317531).
- mlx5: remove unused MLX5_DEBUG param in Kconfig (bnc#905015
  fate#317531).
- net/mlx5_core: Support MANAGE_PAGES and QUERY_PAGES firmware
  command changes (bnc#905015 fate#317531).
- mlx5: remove health handler plugin (bnc#905015 fate#317531).
- mlx5_core: Implement new initialization sequence (bnc#905015
  fate#317531).
- IB/mlx5: Fix stack info leak in mlx5_ib_alloc_ucontext()
  (bnc#905015 fate#317531).
- IB/mlx5: Fix error return code in init_one() (bnc#905015
  fate#317531).
- mlx5: fix error return code in mlx5_alloc_uuars() (bnc#905015
  fate#317531).
- mlx5: use after free in mlx5_cmd_comp_handler() (bnc#905015
  fate#317531).
- mlx5 core: Fix __udivdi3 when compiling for 32 bit arches
  (bnc#905015 fate#317531).
- mlx5: Return -EFAULT instead of -EPERM (bnc#905015 fate#317531).
- mlx5_core: Adjust hca_cap.uar_page_sz to conform to Connect-IB
  spec (bnc#905015 fate#317531).
- mlx5_core: Fixes for sparse warnings (bnc#905015 fate#317531).
- IB/mlx5: Make profile[] static in main.c (bnc#905015
  fate#317531).
- mlx5: Fix parameter type of health_handler_t (bnc#905015
  fate#317531).
- mlx5: Add driver for Mellanox Connect-IB adapters (bnc#905015
  fate#317531).
- module.h: split out the EXPORT_SYMBOL into export.h (bnc#905015
  fate#317531).
- IB/core: Add reserved values to enums for low-level driver use
  (bnc#905015 fate#317531).
- commit 0694c8e
* Thu Feb 26 2015 mkubecek@suse.cz
- Move patches.drivers/0012-skbuff-update-struct-sk_buff-members-comments.patch
  higher in series.conf
- commit 701190e
* Thu Feb 26 2015 jjolly@suse.de
- net: sched: shrink struct qdisc_skb_cb to 28 bytes (bnc#919482).
- commit ac19475
* Thu Feb 26 2015 mkubecek@suse.cz
- netfilter: push reasm skb through instead of original frag skbs
  (bnc#780216 bnc#861980 bnc#907611).
- ip6_output: fragment outgoing reassembled skb properly
  (bnc#861980 bnc#907611).
- ipvs: SIP fragment handling (bnc#861980 bnc#907611).
- netfilter: nf_conntrack_ipv6: fix tracking of ICMPv6
  error messages containing fragments (bnc#779750 bnc#861980
  bnc#907611).
- netfilter: nf_conntrack_ipv6: improve fragmentation handling
  (bnc#861980 bnc#907611).
- ipvs: IPv6 MTU checking cleanup and bugfix (bnc#861980
  bnc#907611).
- ipv4: fix path MTU discovery with connection tracking
  (bnc#861980 bnc#907611).
- ipv6: Add fragment reporting to ipv6_skip_exthdr() (bnc#861980
  bnc#907611).
- commit f699cf6
* Thu Feb 26 2015 mkubecek@suse.cz
- Delete (obsoleted by a follow-up patch)
  patches.fixes/ipv6-xfrm-use-conntrack-reassembled-packet-for-policy-lookup.patch.
- Delete (obsoleted by a follow-up patch)
  patches.fixes/netfilter-do-not-drop-packet-on-insert-collision.patch.
- Delete (replaced by a clean cherry-pick)
  patches.fixes/nf_conntrack_ipv6-fix-tracking-of-ICMPv6-error-messages-containing-fragments.patch.
- commit bf8ece4
* Thu Feb 26 2015 ptesarik@suse.cz
- s390/vmcore: implement remap_oldmem_pfn_range for s390
  (FATE#317317).
- commit 4149c94
* Thu Feb 26 2015 ptesarik@suse.cz
- vmcore: introduce remap_oldmem_pfn_range() (FATE#317317).
- commit 32e52b4
* Thu Feb 26 2015 ptesarik@suse.cz
- s390/vmcore: use ELF header in new memory feature (FATE#317317).
- commit a940613
* Thu Feb 26 2015 ptesarik@suse.cz
- vmcore: introduce ELF header in new memory feature
  (FATE#317317).
- commit d49e498
* Thu Feb 26 2015 dchang@suse.com
- sfc: don't BUG_ON efx->max_channels == 0 in probe (bsc#909618
  FATE#317521).
- sfc: remove incorrect EFX_BUG_ON_PARANOID check (bsc#909618
  FATE#317521).
- sfc: fix addr_list_lock spinlock use before init (bsc#909618
  FATE#317521).
- sfc: Convert the normal transmit complete path to
  dev_consume_skb_any() (bsc#909618 FATE#317521).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#909618
  FATE#317521).
- sfc: Use __iowrite64_copy instead of a slightly different
  local function (bsc#909618 FATE#317521).
- sfc: Add per-queue statistics in ethtool (bsc#909618
  FATE#317521).
- sfc: add extra RX drop counters for nodesc_trunc and noskb_drop
  (bsc#909618 FATE#317521).
- sfc: Add 40G link capability decoding (bsc#909618 FATE#317521).
- sfc: Adding PCI ID for Solarflare 7000 series 40G network
  adapter (bsc#909618 FATE#317521).
- sfc: PIO:Restrict to 64bit arch and use 64-bit writes
  (bsc#909618 FATE#317521).
- net: get rid of SET_ETHTOOL_OPS (bsc#909618 FATE#317521).
- sfc: fix calling of free_irq with already free vector
  (bsc#909618 FATE#317521).
- sfc:On MCDI timeout, issue an FLR (and mark MCDI to fail-fast)
  (bsc#909618 FATE#317521).
- Call efx_set_channels() before efx->type->dimension_resources()
  (bsc#909618 FATE#317521).
- sfc: Don't receive packets when the napi budget == 0 (bsc#909618
  FATE#317521).
- sfc: Use ether_addr_copy and eth_broadcast_addr (bsc#909618
  FATE#317521).
- sfc: check for NULL efx->ptp_data in efx_ptp_event (bsc#909618
  FATE#317521).
- sfc: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bsc#909618 FATE#317521).
- sfc: Add/remove blank lines to taste (bsc#909618 FATE#317521).
- sfc: Fail self-test with -EBUSY, not -EIO, if the device is busy
  (bsc#909618 FATE#317521).
- sfc: Cosmetic changes to self-test from the out-of-tree driver
  (bsc#909618 FATE#317521).
- sfc: Update product naming (bsc#909618 FATE#317521).
- sfc: Use canonical pointer type for MAC address in
  efx_set_mac_address() (bsc#909618 FATE#317521).
- sfc: Rename 'use_options' variable in tso_start() to clearer
  'use_opt_desc' (bsc#909618 FATE#317521).
- sfc: Preserve rx_frm_trunc counters when resizing DMA rings
  (bsc#909618 FATE#317521).
- sfc: Correct comment about number of TX queues used on EF10
  (bsc#909618 FATE#317521).
- sfc: Remove unused definitions of EF10 user-mode DMA descriptors
  (bsc#909618 FATE#317521).
- sfc: Replace TSOH_OFFSET with the equivalent NET_IP_ALIGN
  (bsc#909618 FATE#317521).
- sfc: Rewrite adjustment of PPS event in a clearer way
  (bsc#909618 FATE#317521).
- sfc: Cache skb->data in local variable in efx_ptp_rx()
  (bsc#909618 FATE#317521).
- sfc: Removed adhoc scheme to rate limit PTP event queue overflow
  message (bsc#909618 FATE#317521).
- drivers/net: fix build warning in ethernet/sfc/tx.c (bsc#909618
  FATE#317521).
- sfc: Use the correct maximum TX DMA ring size for SFC9100
  (bsc#909618 FATE#317521).
- sfc: Fix transposed ptp_{under, over}size_sync_windows
  statistics (bsc#909618 FATE#317521).
- sfc: Change efx_mcdi_reset_port to use ENTITY_RESET MC command
  (bsc#909618 FATE#317521).
- sfc: fix sparse non static symbol warning (bsc#909618
  FATE#317521).
- net: sfc calls skb_set_hash (bsc#909618 FATE#317521).
- sfc: Fix RX drop filters for EF10 (bsc#909618 FATE#317521).
- sfc: Add PTP counters to ethtool stats (bsc#909618 FATE#317521).
- sfc: Changed the statistic name emerg_{fetch,wait} to
  hlb_{fetch,wait} (bsc#909618 FATE#317521).
- sfc: remove unused 'enum efx_rx_alloc_method' (bsc#909618
  FATE#317521).
- sfc: remove unused 'refcnt' from efx_rx_page_state (bsc#909618
  FATE#317521).
- sfc: Implement efx_nic_type::filter_clear_rx operation for EF10
  (bsc#909618 FATE#317521).
- sfc: Allow filter removal only with exactly matching priority
  (bsc#909618 FATE#317521).
- sfc: Don't refer to 'stack' in filter implementation (bsc#909618
  FATE#317521).
- sfc: Change priority and flags for automatic MAC filters
  (bsc#909618 FATE#317521).
- sfc: Change efx_nic_type::rx_push_indir_table to push hash
  key as well (bsc#909618 FATE#317521).
- sfc: Add more information to many warnings using WARN() and
  netdev_WARN() (bsc#909618 FATE#317521).
- sfc: Remove unnecessary condition for processing the TX
  timestamp queue (bsc#909618 FATE#317521).
- sfc: Don't clear timestamps in efx_ptp_rx() (bsc#909618
  FATE#317521).
- sfc: Enable PTP clock and timestamping for all functions on EF10
  (bsc#909618 FATE#317521).
- sfc: Associate primary and secondary functions of controller
  (bsc#909618 FATE#317521).
- sfc: Store VPD serial number at probe time (bsc#909618
  FATE#317521).
- sfc: Add RX packet timestamping for EF10 (bsc#909618
  FATE#317521).
- sfc: Copy RX prefix into skb head area in efx_rx_mk_skb()
  (bsc#909618 FATE#317521).
- sfc: split setup of hardware timestamping into NIC-type
  operation (bsc#909618 FATE#317521).
- sfc: Add support for SFC9100 timestamp format (bsc#909618
  FATE#317521).
- sfc: Tidy up PTP synchronization code (bsc#909618 FATE#317521).
- sfc: PTP - tidy up unused/useless variables (bsc#909618
  FATE#317521).
- sfc: Remove kernel-doc for efx_ptp_data fields not present in
  this version (bsc#909618 FATE#317521).
- sfc: Initialise efx_ptp_data::phc_clock_info from a static
  template (bsc#909618 FATE#317521).
- sfc: Do not use MAC address as clock name (bsc#909618
  FATE#317521).
- sfc: Store flags from MC_CMD_DRV_ATTACH for later use
  (bsc#909618 FATE#317521).
- sfc: Remove dependency of PTP on having a dedicated channel
  (bsc#909618 FATE#317521).
- sfc: Split PTP multicast filter insertion/removal out of
  efx_ptp_{start,stop}() (bsc#909618 FATE#317521).
- sfc: Return EBUSY for filter insertion on EF10, matching
  Falcon/Siena (bsc#909618 FATE#317521).
- sfc: Expose NVRAM_PARTITION_TYPE_LICENSE on EF10 (bsc#909618
  FATE#317521).
- sfc: Fold efx_flush_all() into efx_stop_port() and update
  comments (bsc#909618 FATE#317521).
- sfc: Map MCDI error MC_CMD_ERR_ENOTSUP to Linux EOPNOTSUPP
  (bsc#909618 FATE#317521).
- sfc: Log all unexpected MCDI errors (bsc#909618 FATE#317521).
- sfc: Add new sensor names (bsc#909618 FATE#317521).
- sfc: Revise sensor names to be more understandable and
  consistent (bsc#909618 FATE#317521).
- sfc: Report units in sensor warnings (bsc#909618 FATE#317521).
- sfc: Correct RX dropped count for drops while interface is down
  (bsc#909618 FATE#317521).
- sfc: Make initial fill of RX descriptors synchronous (bsc#909618
  FATE#317521).
- sfc: Tighten the check for RX merged completion events
  (bsc#909618 FATE#317521).
- sfc: Add MC BISTs to ethtool offline self test on EF10
  (bsc#909618 FATE#317521).
- net: sfc: remove unnecessary pci_set_drvdata() (bsc#909618
  FATE#317521).
- sfc: Update MCDI protocol definitions (bsc#909618 FATE#317521).
- sfc: Demote "MC Scheduler error" messages (bsc#909618
  FATE#317521).
- sfc: Poll for MCDI completion once before timeout occurs
  (bsc#909618 FATE#317521).
- sfc: Refactor efx_mcdi_poll() by introducing
  efx_mcdi_poll_once() (bsc#909618 FATE#317521).
- sfc: RX buffer allocation takes prefix size into account in
  IP header alignment (bsc#909618 FATE#317521).
- sfc: Maintain current frequency adjustment when applying a
  time offset (bsc#909618 FATE#317521).
- sfc: Stop/re-start PTP when stopping/starting the datapath
  (bsc#909618 FATE#317521).
- sfc: Rate-limit log message for PTP packets without a matching
  timestamp event (bsc#909618 FATE#317521).
- sfc: PTP: Moderate log message on event queue overflow
  (bsc#909618 FATE#317521).
- sfc: Add length checks to efx_xmit_with_hwtstamp() and
  efx_ptp_is_ptp_tx() (bsc#909618 FATE#317521).
- net: introduce skb_transport_header_was_set() (bsc#909618
  FATE#317521).
- sfc: Implement the SIOCGHWTSTAMP ioctl (bsc#909618 FATE#317521).
- sfc: Fix DMA unmapping issue with firmware assisted TSO
  (bsc#909618 FATE#317521).
- sfc: Only bind to EF10 functions with the LinkCtrl and Trusted
  flags (bsc#909618 FATE#317521).
- sfc: Add PM and RXDP drop counters to ethtool stats (bsc#909618
  FATE#317521).
- sfc: Add definitions for new stats counters and capability flag
  (bsc#909618 FATE#317521).
- sfc: Refactor EF10 stat mask code to allow for more conditional
  stats (bsc#909618 FATE#317521).
- sfc: Fix internal indices of ethtool stats for EF10 (bsc#909618
  FATE#317521).
- sfc: Add rmb() between reading stats and generation count to
  ensure consistency (bsc#909618 FATE#317521).
- sfc: Remove extern from function prototypes (bsc#909618
  FATE#317521).
- DMA-API: net: sfc/efx.c: replace
  dma_set_mask()+dma_set_coherent_mask() with new helper
  (bsc#909618 FATE#317521).
- sfc: Support ARFS for IPv6 flows (bsc#909618 FATE#317521).
- sfc: Use TX PIO for sufficiently small packets (bsc#909618
  FATE#317521).
- sfc: Introduce inline functions to simplify TX insertion
  (bsc#909618 FATE#317521).
- sfc: Separate out queue-empty check from
  efx_nic_may_push_tx_desc() (bsc#909618 FATE#317521).
- sfc: Allocate and link PIO buffers; map them with
  write-combining (bsc#909618 FATE#317521).
- sfc: Implement firmware-assisted TSO for EF10 (bsc#909618
  FATE#317521).
- sfc: Fold tso_get_head_fragment() into tso_start() (bsc#909618
  FATE#317521).
- sfc: Add EF10 registers to register dump (bsc#909618
  FATE#317521).
- sfc: efx_ef10_filter_update_rx_scatter() can be static
  (bsc#909618 FATE#317521).
- sfc: efx_ethtool_get_ts_info() can be static (bsc#909618
  FATE#317521).
- sfc: Increase MCDI status timeout to 250ms (bsc#909618
  FATE#317521).
- sfc: Wait for MC reboot to complete before scheduling driver
  reset (bsc#909618 FATE#317521).
- sfc: Reinitialise and re-validate datapath caps after MC reboot
  (bsc#909618 FATE#317521).
- sfc: Clean up validation of datapath capabilities (bsc#909618
  FATE#317521).
- sfc: Reset derived rx_bad_bytes statistic when EF10 MC is
  rebooted (bsc#909618 FATE#317521).
- sfc: Disable PTP on EF10 until we're ready to handle inline
  RX timestamps (bsc#909618 FATE#317521).
- sfc: Minimal support for 40G link speed (bsc#909618
  FATE#317521).
- sfc: check for allocation failure (bsc#909618 FATE#317521).
- drivers:net: Convert dma_alloc_coherent(...__GFP_ZERO) to
  dma_zalloc_coherent (bsc#909618 FATE#317521).
- sfc: Update copyright banners (bsc#909618 FATE#317521).
- sfc: Add support for Solarflare SFC9100 family (bsc#909618
  FATE#317521).
- etherdevice: introduce eth_broadcast_addr (bsc#909618
  FATE#317521).
- sfc: Rename implementation of ndo_set_rx_mode (bsc#909618
  FATE#317521).
- sfc: Make efx_mcdi_{init,fini}() call efx_mcdi_drv_attach()
  (bsc#909618 FATE#317521).
- sfc: Allocate NVRAM partition ID range for PHY images
  (bsc#909618 FATE#317521).
- sfc: Add EF10 register and structure definitions (bsc#909618
  FATE#317521).
- sfc: Extend struct efx_tx_buffer to allow pushing option
  descriptors (bsc#909618 FATE#317521).
- sfc: Use a global count of active queues instead of pending
  drains (bsc#909618 FATE#317521).
- sfc: Prepare for RX scatter on EF10 (bsc#909618 FATE#317521).
- sfc: Initialise IRQ moderation for all NIC types from
  efx_init_eventq() (bsc#909618 FATE#317521).
- sfc: Allow efx_nic_type::dimension_resources to fail (bsc#909618
  FATE#317521).
- sfc: Allow event queue initialisation to fail (bsc#909618
  FATE#317521).
- sfc: Document conditions for multicast replication vs filter
  replacement (bsc#909618 FATE#317521).
- sfc: Implement asynchronous MCDI requests (bsc#909618
  FATE#317521).
- sfc: Remove unnecessary use of atomic_t (bsc#909618
  FATE#317521).
- sfc: Refactor efx_mcdi_rpc_start() and efx_mcdi_copyin()
  (bsc#909618 FATE#317521).
- sfc: Add support for new board sensors (bsc#909618 FATE#317521).
- sfc: Use extended MC_CMD_SENSOR_INFO and MC_CMD_READ_SENSORS
  (bsc#909618 FATE#317521).
- sfc: Return an error code when a sensor is busy (bsc#909618
  FATE#317521).
- sfc: Add support for reading packet length from prefix
  (bsc#909618 FATE#317521).
- sfc: Generalise packet hash lookup to support EF10 RX prefix
  (bsc#909618 FATE#317521).
- sfc: Rename EFX_PAGE_BLOCK_SIZE to EFX_VI_PAGE_SIZE and adjust
  comments (bsc#909618 FATE#317521).
- sfc: Remove early call to efx_nic_type::reconfigure_mac in
  efx_reset_up() (bsc#909618 FATE#317521).
- sfc: use MCDI epoch flag to improve MC reboot detection in
  the driver (bsc#909618 FATE#317521).
- sfc: Add EF10 support for TX/RX DMA error events handling
  (bsc#909618 FATE#317521).
- sfc: Add a function pointer to abstract write of host time
  into NIC shared memory (bsc#909618 FATE#317521).
- sfc: PTP MCDI requests need to initialise periph ID field
  (bsc#909618 FATE#317521).
- sfc: Delegate MAC/NIC statistic description to efx_nic_type
  (bsc#909618 FATE#317521).
- sfc: Remove driver-local struct ethtool_string (bsc#909618
  FATE#317521).
- sfc: Remove more left-overs from Falcon GMAC support (bsc#909618
  FATE#317521).
- sfc: Move MTD operations into efx_nic_type (bsc#909618
  FATE#317521).
- sfc: Move NIC-type-specific MTD partition date into separate
  structures (bsc#909618 FATE#317521).
- sfc: Eliminate struct efx_mtd (bsc#909618 FATE#317521).
- sfc: Rename SPI stuff to show that it is Falcon-specific
  (bsc#909618 FATE#317521).
- sfc: Cleanup Falcon-arch simple MAC filter state (bsc#909618
  FATE#317521).
- sfc: Define and use MCDI_POPULATE_DWORD_{1,2,3,4,5,6,7}
  (bsc#909618 FATE#317521).
- sfc: Add flag for stack-owned RX MAC filters (bsc#909618
  FATE#317521).
- sfc: Refactor Falcon-arch filter removal (bsc#909618
  FATE#317521).
- sfc: Make most filter operations NIC-type-specific (bsc#909618
  FATE#317521).
- sfc: Refactor Falcon-arch search limit reset (bsc#909618
  FATE#317521).
- sfc: Split Falcon-arch-specific and common filter state
  (bsc#909618 FATE#317521).
- sfc: Extend and abstract efx_filter_spec to cover
  Huntington/EF10 (bsc#909618 FATE#317521).
- sfc: Name the RX drop queue ID (bsc#909618 FATE#317521).
- sfc: Rename Falcon-arch filter implementation types and
  functions (bsc#909618 FATE#317521).
- sfc: Remove unused filter_flags variables and
  efx_farch_filter_id_flags() (bsc#909618 FATE#317521).
- sfc: Do not assume efx_nic_type::ev_fini is idempotent
  (bsc#909618 FATE#317521).
- sfc: EFX_WORKAROUND_ALWAYS is really specific to
  Falcon-architecture (bsc#909618 FATE#317521).
- sfc: Get rid of per-NIC-type phys_addr_channels and mem_map_size
  (bsc#909618 FATE#317521).
- sfc: Update and improve kernel-doc for efx_mcdi_state &
  efx_mcdi_iface (bsc#909618 FATE#317521).
- sfc: Fix race in completion handling (bsc#909618 FATE#317521).
- sfc: Add support for MCDI v2 (bsc#909618 FATE#317521).
- sfc: Update MCDI protocol definitions for EF10 (bsc#909618
  FATE#317521).
- sfc: Translate MCDI error numbers received in events (bsc#909618
  FATE#317521).
- sfc: Move and rename Falcon/Siena common NIC operations
  (bsc#909618 FATE#317521).
- sfc: Refactor queue teardown sequence to allow for EF10 flush
  behaviour (bsc#909618 FATE#317521).
- sfc: Remove bogus call to efx_release_tx_buffers() (bsc#909618
  FATE#317521).
- sfc: Stop RX refill before flushing RX queues (bsc#909618
  FATE#317521).
- sfc: Limit scope of a Falcon A1 IRQ workaround (bsc#909618
  FATE#317521).
- sfc: Rework IRQ enable/disable (bsc#909618 FATE#317521).
- sfc: Remove efx_process_channel_now() (bsc#909618 FATE#317521).
- sfc: Rename Falcon-architecture register definitions (bsc#909618
  FATE#317521).
- sfc: Make struct efx_special_buffer less special (bsc#909618
  FATE#317521).
- sfc: Add GFP flags to efx_nic_alloc_buffer() and make most
  callers allow blocking (bsc#909618 FATE#317521).
- sfc: Make MCDI independent of Siena (bsc#909618 FATE#317521).
- sfc: Make efx_mcdi_init() call efx_mcdi_handle_assertion()
  (bsc#909618 FATE#317521).
- sfc: Collect all MCDI port functions into mcdi_port.c
  (bsc#909618 FATE#317521).
- sfc: Move efx_mcdi_mac_reconfigure() to siena.c and rename
  (bsc#909618 FATE#317521).
- sfc: Move siena_reset_hw() and siena_map_reset_reason() into
  MCDI module (bsc#909618 FATE#317521).
- sfc: Add and use MCDI_SET_QWORD() and MCDI_SET_ARRAY_QWORD()
  (bsc#909618 FATE#317521).
- sfc: Ensure MCDI buffers, but not lengths, are dword aligned
  (bsc#909618 FATE#317521).
- sfc: Use proper macros to declare and access MCDI arrays
  (bsc#909618 FATE#317521).
- sfc: Introduce and use MCDI_CTL_SDU_LEN_MAX_V1 macro for
  Siena-specific code (bsc#909618 FATE#317521).
- sfc: Fill out the set of MCDI accessors (bsc#909618
  FATE#317521).
- sfc: Rationalise MCDI buffer accessors (bsc#909618 FATE#317521).
- sfc: Introduce and use MCDI_DECLARE_BUF macro (bsc#909618
  FATE#317521).
- sfc: Move more Falcon-specific code and definitions into
  falcon.c (bsc#909618 FATE#317521).
- sfc: Move details of a Falcon bug workaround out of ethtool.c
  (bsc#909618 FATE#317521).
- sfc: Use efx_mcdi_mon() to find efx_mcdi_mon structure from
  efx_nic (bsc#909618 FATE#317521).
- sfc: const-qualify source pointers for MMIO write functions
  (bsc#909618 FATE#317521).
- sfc: Fix lookup of default RX MAC filters when steered using
  ethtool (bsc#909618 FATE#317521).
- sfc: Enable RX scatter for flows steered by RFS (bsc#909618
  FATE#317521).
- sfc: Fix memory leak when discarding scattered packets
  (bsc#909618 FATE#317521).
- sfc: Fix IRQ cleanup in case of a probe failure (bsc#909618
  FATE#317521).
- sfc: Do not pass non-TCP packets into GRO code (bsc#909618
  FATE#317521).
- sfc: Define and set RX buffer flag for packets parsed as TCP
  (bsc#909618 FATE#317521).
- sfc: Enable accelerated RFS on vlans (bsc#909618 FATE#317521).
- sfc: Report software timestamping capabilities (bsc#909618
  FATE#317521).
- sfc: Increase size of RX SKB header area (bsc#909618
  FATE#317521).
- sfc: Enable RX checksum offload for packets not handled by GRO
  (bsc#909618 FATE#317521).
- sfc: Fix EEH with legacy interrupts (bsc#909618 FATE#317521).
- sfc: Remove write permission from phy_type attribute (bsc#909618
  FATE#317521).
- sfc: Store port number in private data, not net_device::dev_id
  (bsc#909618 FATE#317521).
- sfc: Reduce RX scatter buffer size, and reduce alignment if
  appropriate (bsc#909618 FATE#317521).
- sfc: Delete EFX_PAGE_IP_ALIGN, equivalent to NET_IP_ALIGN
  (bsc#909618 FATE#317521).
- sfc: fix return value check in efx_ptp_probe_channel()
  (bsc#909618 FATE#317521).
- sfc: Fix Kconfig typo "----help---" (bsc#909618 FATE#317521).
- sfc: make local functions static (bsc#909618 FATE#317521).
- drivers:net: dma_alloc_coherent: use __GFP_ZERO instead of
  memset(, 0) (bsc#909618 FATE#317521).
- sfc: remove duplicated include from efx.c (bsc#909618
  FATE#317521).
- sfc: allocate more RX buffers per page (bsc#909618 FATE#317521).
- sfc: Replace efx_rx_is_last_buffer() with a flag (bsc#909618
  FATE#317521).
- sfc: reuse pages to avoid DMA mapping/unmapping costs
  (bsc#909618 FATE#317521).
- drivers/net: Add moduleparam.h to drivers as required
  (bsc#909618 FATE#317521).
- sfc: Enable RX DMA scattering where possible (bsc#909618
  FATE#317521).
- sfc: Update RX buffer address together with length (bsc#909618
  FATE#317521).
- sfc: Explicitly prefetch RX hash prefix, not just Ethernet heade
  (bsc#909618 FATE#317521).
- sfc: Replace efx_rx_buf_eh() with simpler efx_rx_buf_va()
  (bsc#909618 FATE#317521).
- sfc: Wrap __efx_rx_packet() with efx_rx_flush_packet()
  (bsc#909618 FATE#317521).
- sfc: Make RX queue descriptor counts unsigned for consistency
  (bsc#909618 FATE#317521).
- sfc: Properly distinguish RX buffer and DMA lengths (bsc#909618
  FATE#317521).
- sfc: Document current usage of efx_rx_buffer::len and
  efx_nic::rx_buffer_len (bsc#909618 FATE#317521).
- sfc: Add AER and EEH support for Siena (bsc#909618 FATE#317521).
- sfc: Disable RSS when using SR-IOV and only 1 RX queue on the PF
  (bsc#909618 FATE#317521).
- sfc: Fix replacement detection in efx_filter_insert_filter()
  (bsc#909618 FATE#317521).
- sfc: Merge efx_filter_search() into efx_filter_insert()
  (bsc#909618 FATE#317521).
- sfc: Don't use efx_filter_{build,hash,increment}() for default
  MAC filters (bsc#909618 FATE#317521).
- sfc: Remove redundant parameter to efx_filter_search()
  (bsc#909618 FATE#317521).
- sfc: More sensible semantics for efx_filter_insert_filter()
  replace flag (bsc#909618 FATE#317521).
- sfc: Remove rx_alloc_method SKB (bsc#909618 FATE#317521).
- sfc: tidy up PTP synchronize function efx_ptp_process_times()
  (bsc#909618 FATE#317521).
- sfc: PTP changes to support improved UUID filtering mode
  (bsc#909618 FATE#317521).
- sfc: Allow efx_channel_type::receive_skb() to reject a packet
  (bsc#909618 FATE#317521).
- sfc: remove __dev* attributes (bsc#909618 FATE#317521).
- drivers/net/ethernet/sfc: use standard __{clear,set}_bit_le()
  functions (bsc#909618 FATE#317521).
- commit a113674
* Thu Feb 26 2015 dchang@suse.com
- i40e/i40evf: Bump i40e/i40evf versions (bsc#909486 FATE#317393).
- i40e/i40evf: Ignore a driver perceived Tx hang if the number
  of desc pending < 4 (bsc#909486 FATE#317393).
- i40e/i40evf: add max buf len to aq debug print helper
  (bsc#909486 FATE#317393).
- i40evf: Fix TSO and hw checksums for non-accelerated vlan
  packets (bsc#909486 FATE#317393).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#909486
  FATE#317393).
- i40evf: Fixed guest OS panic when removing vf driver (bsc#909486
  FATE#317393).
- i40evf: fix memory leak on unused interfaces (bsc#909486
  FATE#317393).
- i40evf: don't leak queue vectors (bsc#909486 FATE#317393).
- i40evf: do not re-arm watchdog after remove (bsc#909486
  FATE#317393).
- i40evf: future-proof vfr_stat state check (bsc#909486
  FATE#317393).
- i40evf: fix scan warning on sprintf (bsc#909486 FATE#317393).
- i40e: always print aqtx answer (bsc#909486 FATE#317393).
- i40e/i40evf: ARQ copy desc data even for failed commands
  (bsc#909486 FATE#317393).
- i40evf: don't wait so long (bsc#909486 FATE#317393).
- i40e/i40evf: fix extension header csum logic (bsc#909486
  FATE#317393).
- i40e/i40evf: Add nvmupdate support (bsc#909486 FATE#317393).
- i40e/i40evf: Clean up code (bsc#909486 FATE#317393).
- i40evf: remove unnecessary break after goto (bsc#909486
  FATE#317393).
- i40e/i40evf: Add set_fc and init of FC settings (bsc#909486
  FATE#317393).
- i40e/i40evf: Add new HW link info variable an_enabled and
  function update_link_info (bsc#909486 FATE#317393).
- i40evf: invite vector 0 to the interrupt party (bsc#909486
  FATE#317393).
- i40e/i40evf: Force a shifted '1' to be unsigned (bsc#909486
  FATE#317393).
- i40evf: don't violate scope (bsc#909486 FATE#317393).
- i40e/i40evf: Do not free the dummy packet buffer synchronously
  (bsc#909486 FATE#317393).
- i40evf: change branding string (bsc#909486 FATE#317393).
- i40e/i40evf: initialize context descriptor (bsc#909486
  FATE#317393).
- i40e/i40evf: add ASQ write back timeout variable to AQ structure
  (bsc#909486 FATE#317393).
- i40evf: set flags before sending message (bsc#909486
  FATE#317393).
- i40e/i40evf: clear aq bah-bal on shutdown (bsc#909486
  FATE#317393).
- i40e/i40evf: Add base address registers to aq struct (bsc#909486
  FATE#317393).
- i40evf: resend FW request if no response (bsc#909486
  FATE#317393).
- i40evf: fix typo (bsc#909486 FATE#317393).
- i40evf: return more useful error information (bsc#909486
  FATE#317393).
- i40evf: don't stop watchdog if it hasn't started (bsc#909486
  FATE#317393).
- i40e/i40evf: Big endian fixes for handling HMC (bsc#909486
  FATE#317393).
- i40e/i40evf: remove reserved type (bsc#909486 FATE#317393).
- i40e/i40evf: modify debug prints to avoid seg faults (bsc#909486
  FATE#317393).
- i40e/i40evf: Update RSS configuration (bsc#909486 FATE#317393).
- i40evf: fix off-by-one (bsc#909486 FATE#317393).
- i40e/i40evf: Reset Head and Tail on AQ initialization
  (bsc#909486 FATE#317393).
- i40e/i40evf: i40e_register.h update (bsc#909486 FATE#317393).
- i40e/i40evf: Add Flow director stats to PF stats (bsc#909486
  FATE#317393).
- i40e/i40evf: remove FTYPE (bsc#909486 FATE#317393).
- i40evf: check admin queue error bits (bsc#909486 FATE#317393).
- i40e/i40evf: User ether_addr_copy instead of memcpy (bsc#909486
  FATE#317393).
- i40evf: don't go further down (bsc#909486 FATE#317393).
- i40e/i40evf: AdminQ API update for new FW (bsc#909486
  FATE#317393).
- i40e/i40evf: set headwb Tx context flags and use them
  (bsc#909486 FATE#317393).
- i40e/i40evf: add PPRS bit to error bits and fix bug in Rx
  checksum (bsc#909486 FATE#317393).
- i40evf: Fix function header (bsc#909486 FATE#317393).
- i40e/i40evf: remove deprecated device IDs (bsc#909486
  FATE#317393).
- i40e/i40evf: fix poll weight (bsc#909486 FATE#317393).
- i40e/i40evf: fix TSO accounting (bsc#909486 FATE#317393).
- i40e/i40evf: remove chatty reset messages (bsc#909486
  FATE#317393).
- i40evf: use correct format for printing MAC addresses
  (bsc#909486 FATE#317393).
- i40evf: clean up log message formatting (bsc#909486
  FATE#317393).
- i40evf: remove bogus comment (bsc#909486 FATE#317393).
- i40evf: remove unnecessary log messages (bsc#909486
  FATE#317393).
- i40e/i40evf: Clean up a few things (bsc#909486 FATE#317393).
- i40e/i40evf: Fix code to accommodate i40e_register.h changes
  (bsc#909486 FATE#317393).
- i40e/i40evf: fix rx descriptor status (bsc#909486 FATE#317393).
- i40e/i40evf: add Tx pre queue disable function (bsc#909486
  FATE#317393).
- i40e/i40evf: check AQ register for valid data (bsc#909486
  FATE#317393).
- i40evf: make messages less dire (bsc#909486 FATE#317393).
- i40e/i40evf: remove rx_errors and rx_missed (bsc#909486
  FATE#317393).
- i40e/i40evf: VEB structure added, GTIME macro update (bsc#909486
  FATE#317393).
- i40evf: fix crash when changing ring sizes (bsc#909486
  FATE#317393).
- i40evf: set descriptor multiple to 32 (bsc#909486 FATE#317393).
- i40e/i40evf: remove unused RX_LRO define (bsc#909486
  FATE#317393).
- i40evf: don't use RESETTING state during reinit (bsc#909486
  FATE#317393).
- i40e/i40evf: Change type to u32 to avoid sparse error
  (bsc#909486 FATE#317393).
- i40e/i40evf: remove storm control (bsc#909486 FATE#317393).
- i40e/i40evf: Remove reserved PCTYPE defines (bsc#909486
  FATE#317393).
- i40e/i40evf: Update check for AQ aliveness (bsc#909486
  FATE#317393).
- i40evf: Use is_multicast_ether_addr helper (bsc#909486
  FATE#317393).
- i40e,igb,ixgbe: remove usless return statements (bsc#909486
  FATE#317393).
- i40evf: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bsc#909486 FATE#317393).
- i40e/i40evf: control auto ITR through ethtool (bsc#909486
  FATE#317393).
- i40e/i40evf: set proper default for ITR registers (bsc#909486
  FATE#317393).
- i40evf: make ethtool_ops const (bsc#909486 FATE#317393).
- i40evf: don't lie to ethtool (bsc#909486 FATE#317393).
- i40evf: Use macro param for ethtool stats (bsc#909486
  FATE#317393).
- i40evf: Fix the headers and update copyright year (bsc#909486
  FATE#317393).
- i40evf: Remove unused defines (bsc#909486 FATE#317393).
- i40evf: Update AdminQ interface (bsc#909486 FATE#317393).
- net: get rid of SET_ETHTOOL_OPS (bsc#909486 FATE#317393).
- i40e/i40evf: Retrieve and store missing link config information
  (bsc#909486 FATE#317393).
- i40evf: remove debugging message (bsc#909486 FATE#317393).
- i40evf: fix panic on PF driver fail (bsc#909486 FATE#317393).
- i40e/i40evf: add driver version string to driver version command
  (bsc#909486 FATE#317393).
- i40evf: support ethtool RSS options (bsc#909486 FATE#317393).
- i40e/i40evf: update AdminQ API (bsc#909486 FATE#317393).
- i40e/i40evf: add tracking to NVM busy state (bsc#909486
  FATE#317393).
- i40e/i40evf: unhide and enable to one prefena field (bsc#909486
  FATE#317393).
- i40evf: program RSS LUT correctly (bsc#909486 FATE#317393).
- i40evf: remove open-coded skb_cow_head (bsc#909486 FATE#317393).
- i40e/i40evf: Remove addressof casts to same type (bsc#909486
  FATE#317393).
- i40e/i40evf: fix error checking path (bsc#909486 FATE#317393).
- i40e/i40evf: Add an FD message level (bsc#909486 FATE#317393).
- i40evf: remove double space after return (bsc#909486
  FATE#317393).
- i40evf: fix oops in watchdog handler (bsc#909486 FATE#317393).
- i40evf: clean up init error messages (bsc#909486 FATE#317393).
- i40evf: don't shut down admin queue on error (bsc#909486
  FATE#317393).
- i40e/i40evf: Add EEE LPI stats (bsc#909486 FATE#317393).
- i40e/i40evf: reduce context descriptors (bsc#909486
  FATE#317393).
- i40e/i40evf: enable hardware feature head write back (bsc#909486
  FATE#317393).
- i40evf: use min_t (bsc#909486 FATE#317393).
- i40evf: correctly program RSS HLUT table (bsc#909486
  FATE#317393).
- i40evf: Rename i40e_ptype_lookup i40evf_ptype_lookup (bsc#909486
  FATE#317393).
- i40e/i40evf: Use dma_set_mask_and_coherent (bsc#909486
  FATE#317393).
- i40e/i40evf: Use correct number of VF vectors (bsc#909486
  FATE#317393).
- i40e/i40evf: Some flow director HW definition fixes (bsc#909486
  FATE#317393).
- i40e/i40evf: carefully fill tx ring (bsc#909486 FATE#317393).
- i40e/i40evf: i40e implementation for skb_set_hash (bsc#909486
  FATE#317393).
- i40evf: Enable the ndo_set_features netdev op (bsc#909486
  FATE#317393).
- i40e: Change MSIX to MSI-X (bsc#909486 FATE#317393).
- i40evf: remove errant space (bsc#909486 FATE#317393).
- i40evf: update version and copyright date (bsc#909486
  FATE#317393).
- i40evf: store ring size in ring structs (bsc#909486
  FATE#317393).
- i40evf: don't guess device name (bsc#909486 FATE#317393).
- i40evf: remove bogus comment (bsc#909486 FATE#317393).
- i40evf: fix up strings in init task (bsc#909486 FATE#317393).
- i40evf: get rid of pci_using_dac (bsc#909486 FATE#317393).
- i40evf: fix multiple crashes on remove (bsc#909486 FATE#317393).
- i40evf: remove VLAN filters on close (bsc#909486 FATE#317393).
- i40evf: request reset on tx hang (bsc#909486 FATE#317393).
- net: i40evf: Remove duplicate include (bsc#909486 FATE#317393).
- i40evf: refactor reset handling (bsc#909486 FATE#317393).
- i40evf: change type of flags variable (bsc#909486 FATE#317393).
- i40evf: don't store unnecessary array of strings (bsc#909486
  FATE#317393).
- i40evf: fix bogus comment (bsc#909486 FATE#317393).
- i40evf: clean up adapter struct (bsc#909486 FATE#317393).
- i40evf: trivial fixes (bsc#909486 FATE#317393).
- i40e: spelling error (bsc#909486 FATE#317393).
- i40e: Fix device ID define names to align to standard
  (bsc#909486 FATE#317393).
- i40evf: fix s390 build failure due to implicit prefetch.h
  (bsc#909486 FATE#317393).
- i40evf: A0 silicon specific (bsc#909486 FATE#317393).
- i40evf: add driver to kernel build system (bsc#909486 FATE#317393).
  Update config files.
  Add support Intel(R) XL710 X710 Virtual Function Ethernet support (I40EVF).
- i40evf: init code and hardware support (bsc#909486 FATE#317393).
- i40evf: driver core headers (bsc#909486 FATE#317393).
- i40evf: virtual channel interface (bsc#909486 FATE#317393).
- i40evf: core ethtool functionality (bsc#909486 FATE#317393).
- i40evf: transmit and receive functionality (bsc#909486
  FATE#317393).
- i40evf: main driver core (bsc#909486 FATE#317393).
- commit 79a1eef
* Wed Feb 25 2015 dchang@suse.com
- Refresh
  patches.suse/rps-Add-flag-to-skb-to-indicate-rxhash-is-based-on-L.patch
  Refresh
  patches.drivers/netdev-FCoE-Add-new-ndo_get_fcoe_hbainfo-call.patch
- commit e01f2ff
* Wed Feb 25 2015 dchang@suse.com
- i40e: _MASK vs _SHIFT typo in i40e_handle_mdd_event()
  (bsc#909484 FATE#317397).
- i40e/igb: Convert to dev_consume_skb_any() (bsc#909484
  FATE#317397).
- i40e: use global pci_vfs_assigned() to replace local
  i40e_vfs_are_assigned() (bsc#909484 FATE#317397).
- i40e/i40evf: Bump i40e/i40evf versions (bsc#909484 FATE#317397).
- i40e: fix panic due to too-early Tx queue enable (bsc#909484
  FATE#317397).
- i40e: Fix an issue when PF reset fails (bsc#909484 FATE#317397).
- i40e: make warning less verbose (bsc#909484 FATE#317397).
- i40e: Tell OS link is going down when calling set_phy_config
  (bsc#909484 FATE#317397).
- i40e: Remove unnecessary assignment (bsc#909484 FATE#317397).
- i40e: Change wording to be more consistent (bsc#909484
  FATE#317397).
- i40e: Allow user to change link settings if link is down
  (bsc#909484 FATE#317397).
- i40e: Add dual speed module support (bsc#909484 FATE#317397).
- i40e/i40evf: Bump i40e & i40evf version (bsc#909484
  FATE#317397).
- i40e/i40evf: Ignore a driver perceived Tx hang if the number
  of desc pending < 4 (bsc#909484 FATE#317397).
- i40e: quiet complaints when removing default MAC VLAN filter
  and make set_mac reversible (bsc#909484 FATE#317397).
- i40e/i40evf: add max buf len to aq debug print helper
  (bsc#909484 FATE#317397).
- i40e: Add checks and message for Qualified Module info
  (bsc#909484 FATE#317397).
- i40e: set num_queue_pairs to num configured by VF (bsc#909484
  FATE#317397).
- i40e: Enable l2tsel bit for VLAN tag control (bsc#909484
  FATE#317397).
- i40e: Add a FD flush counter to ethtool (bsc#909484
  FATE#317397).
- i40e: ATR policy change to flush the table to clean stale ATR
  rules (bsc#909484 FATE#317397).
- i40e: Some FD message fixes (bsc#909484 FATE#317397).
- i40e: Update flow director error messages to reduce user
  confusion (bsc#909484 FATE#317397).
- i40e: Fix TSO and hw checksums for non-accelerated vlan packets
  (bsc#909484 FATE#317397).
- i40e: fix PTP bug (bsc#909484 FATE#317397).
- i40e: Fix a few potential VF dereferences (bsc#909484
  FATE#317397).
- i40e: Fix for recent kernel panic (bsc#909484 FATE#317397).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#909484
  FATE#317397).
- i40e: Cleaning up missing null-terminate in conjunction with
  strncpy (bsc#909484 FATE#317397).
- i40e: use correct structure type name in sizeof (bsc#909484
  FATE#317397).
- i40e: fix sparse non static symbol warning (bsc#909484
  FATE#317397).
- i40e: Fix missing uapi/linux/dcbnl.h include in i40e_fcoe.c
  (bsc#909484 FATE#317397).
- i40e: remove support for vf unicast promiscuous mode (bsc#909484
  FATE#317397).
- i40e: Minor comment changes (bsc#909484 FATE#317397).
- i40e: disable local loopback on vmdq vsi (bsc#909484
  FATE#317397).
- i40e: use correct vf_id offset for virtchnl message (bsc#909484
  FATE#317397).
- i40e: expose debug_write_register request (bsc#909484
  FATE#317397).
- i40e: adds FCoE to build and updates its documentation
  (bsc#909484 FATE#317397).
- i40e: Adds FCoE related code to i40e core driver (bsc#909484
  FATE#317397).
- i40e: adds FCoE code to the i40e driver (bsc#909484
  FATE#317397).
- i40e: always print aqtx answer (bsc#909484 FATE#317397).
- i40e: Give link more time after setting flow control (bsc#909484
  FATE#317397).
- i40e: Fix firmware API version errors (bsc#909484 FATE#317397).
- i40e/i40evf: ARQ copy desc data even for failed commands
  (bsc#909484 FATE#317397).
- i40e/i40evf: fix extension header csum logic (bsc#909484
  FATE#317397).
- i40e/i40evf: Add nvmupdate support (bsc#909484 FATE#317397).
- i40e: fix format mismatch in
  drivers/net/ethernet/intel/i40e/i40e_debugfs.c (bsc#909484
  FATE#317397).
- i40e: (ptp) warn when PF_ID does not match in PRTTSYN_CTL0
  (bsc#909484 FATE#317397).
- i40e/i40evf: Clean up code (bsc#909484 FATE#317397).
- i40e: fix race conditions on queuing skb for HW time stamp
  (bsc#909484 FATE#317397).
- i40e: never generate both software and hardware timestamps
  (bsc#909484 FATE#317397).
- i40e: Add ndo_get_phys_port_id() callback support (bsc#909484
  FATE#317397).
- net: add ndo to get id of physical port of the device
  (bsc#909484 FATE#317397).
- i40e: remove unnecessary break after goto (bsc#909484
  FATE#317397).
- i40e: Implement set_settings for ethtool (bsc#909484
  FATE#317397).
- i40e: Add set_pauseparam to ethtool (bsc#909484 FATE#317397).
- i40e/i40evf: Add set_fc and init of FC settings (bsc#909484
  FATE#317397).
- i40e: move nway reset (bsc#909484 FATE#317397).
- i40e/i40evf: Add new HW link info variable an_enabled and
  function update_link_info (bsc#909484 FATE#317397).
- i40e: Finish implementation of ethtool get settings (bsc#909484
  FATE#317397).
- i40e: disable TPH (bsc#909484 FATE#317397).
- i40e: Fix a boundary condition and turning off of ntuple
  (bsc#909484 FATE#317397).
- i40e: tolerate lost interrupts (bsc#909484 FATE#317397).
- i40e/i40evf: Force a shifted '1' to be unsigned (bsc#909484
  FATE#317397).
- i40e/i40evf: Do not free the dummy packet buffer synchronously
  (bsc#909484 FATE#317397).
- i40e: limit GLLAN_TXPRE_QDIS to QINDX 0-127 (bsc#909484
  FATE#317397).
- i40e/i40evf: initialize context descriptor (bsc#909484
  FATE#317397).
- i40e: FD filter replay logic bug fix (bsc#909484 FATE#317397).
- i40e/i40evf: add ASQ write back timeout variable to AQ structure
  (bsc#909484 FATE#317397).
- i40e: Correct mask assignment value (bsc#909484 FATE#317397).
- i40e: clear all queues and interrupts (bsc#909484 FATE#317397).
- i40e/i40evf: clear aq bah-bal on shutdown (bsc#909484
  FATE#317397).
- i40e/i40evf: Add base address registers to aq struct (bsc#909484
  FATE#317397).
- i40e: fix fdir programming (bsc#909484 FATE#317397).
- i40e: Add debugfs hooks to print current total FD filter count
  (bsc#909484 FATE#317397).
- i40e: Fix the FD sideband logic to detect a FD table full
  condition (bsc#909484 FATE#317397).
- i40e: Avoid adding the TCP-IPv4 filter twice (bsc#909484
  FATE#317397).
- i40e: only create PTP device node once (bsc#909484 FATE#317397).
- i40e: don't store user requested mode until we've validated it
  (bsc#909484 FATE#317397).
- i40e: break PTP hardware control from ioctl command for
  timestamp mode (bsc#909484 FATE#317397).
- i40e: rename i40e_ptp_enable to i40e_ptp_feature_enable
  (bsc#909484 FATE#317397).
- i40e/i40evf: Big endian fixes for handling HMC (bsc#909484
  FATE#317397).
- i40e: do not take NVM ownership for SR read (bsc#909484
  FATE#317397).
- i40e: Bypass timeout recovery level 0 so as to not cause MDD
  (bsc#909484 FATE#317397).
- i40e: no pf reset at pci remove (bsc#909484 FATE#317397).
- i40e: reapply LAA after reset (bsc#909484 FATE#317397).
- i40e: allow user to set LAA again (bsc#909484 FATE#317397).
- i40e: use WoL flag when setting LAA (bsc#909484 FATE#317397).
- i40e: Add ablitity to enable/disable link from
  set_link_restart_an (bsc#909484 FATE#317397).
- i40e/i40evf: remove reserved type (bsc#909484 FATE#317397).
- i40e: Fix ethtool coalesce settings (bsc#909484 FATE#317397).
- i40e: fix a stray print message (bsc#909484 FATE#317397).
- i40e: warn on newer/older firmware API rev (bsc#909484
  FATE#317397).
- i40e: Add PF reset when Malicious driver event for PF
  (bsc#909484 FATE#317397).
- i40e: make prep_for_reset void (bsc#909484 FATE#317397).
- i40e: Stop the VF device after setting its MAC address
  (bsc#909484 FATE#317397).
- i40e/i40evf: modify debug prints to avoid seg faults (bsc#909484
  FATE#317397).
- i40e/i40evf: Update RSS configuration (bsc#909484 FATE#317397).
- i40e: keep service tasks out of reset process (bsc#909484
  FATE#317397).
- i40e: clear VEB stats when pf stats are cleared (bsc#909484
  FATE#317397).
- i40e: Fix scheduling while atomic bug during NAPI (bsc#909484
  FATE#317397).
- i40e: debugfs fix to dump remote LLDPDU (bsc#909484
  FATE#317397).
- i40e: Helper routine for Rx/Tx queue enable/disable wait
  (bsc#909484 FATE#317397).
- i40e: Fix dangling ring pointers upon driver removal (bsc#909484
  FATE#317397).
- i40e/i40evf: Reset Head and Tail on AQ initialization
  (bsc#909484 FATE#317397).
- i40e: workaround NVM GLQF_HKEY (bsc#909484 FATE#317397).
- i40e/i40evf: i40e_register.h update (bsc#909484 FATE#317397).
- i40e: use stored base_queue value (bsc#909484 FATE#317397).
- i40e: Fix a bug in ethtool for FD drop packet filter action
  (bsc#909484 FATE#317397).
- i40e/i40evf: Add Flow director stats to PF stats (bsc#909484
  FATE#317397).
- i40e/i40evf: remove FTYPE (bsc#909484 FATE#317397).
- i40e/i40evf: User ether_addr_copy instead of memcpy (bsc#909484
  FATE#317397).
- i40e: Do not accept tagged packets by default (bsc#909484
  FATE#317397).
- i40e: Separate out DCB capability and enabled flags (bsc#909484
  FATE#317397).
- i40e: Change the notion of src and dst for FD_SB in ethtool
  (bsc#909484 FATE#317397).
- i40e/i40evf: AdminQ API update for new FW (bsc#909484
  FATE#317397).
- i40e/i40evf: set headwb Tx context flags and use them
  (bsc#909484 FATE#317397).
- i40e: Allow RSS table entry range and GPS to be any number,
  not necessarily power of 2 (bsc#909484 FATE#317397).
- i40e: Delete stale MAC filters after change (bsc#909484
  FATE#317397).
- i40e: Do not fall back to one queue model if the only feature
  enabled is ATR (bsc#909484 FATE#317397).
- i40e/i40evf: add PPRS bit to error bits and fix bug in Rx
  checksum (bsc#909484 FATE#317397).
- i40e: keep SR-IOV enabled in the case that RSS, VMDQ, FD_SB
  and DCB are disabled (bsc#909484 FATE#317397).
- i40e: Changes to Interrupt distribution policy (bsc#909484
  FATE#317397).
- i40e: implement anti-spoofing for VFs (bsc#909484 FATE#317397).
- i40e: don't complain about removing non-existent addresses
  (bsc#909484 FATE#317397).
- i40e: remove unused variable and memory allocation (bsc#909484
  FATE#317397).
- i40e: allow for more VSIs (bsc#909484 FATE#317397).
- i40e: add checks for AQ error status bits (bsc#909484
  FATE#317397).
- i40e/i40evf: remove deprecated device IDs (bsc#909484
  FATE#317397).
- i40e/i40evf: fix poll weight (bsc#909484 FATE#317397).
- i40e/i40evf: fix TSO accounting (bsc#909484 FATE#317397).
- i40e/i40evf: remove chatty reset messages (bsc#909484
  FATE#317397).
- i40e: not all VSIs have rings (bsc#909484 FATE#317397).
- i40e: clear pxe after adminq is rebuilt (bsc#909484
  FATE#317397).
- i40e: Fix incorrect feature configuration status (bsc#909484
  FATE#317397).
- i40e/i40evf: Clean up a few things (bsc#909484 FATE#317397).
- i40e/i40evf: Fix code to accommodate i40e_register.h changes
  (bsc#909484 FATE#317397).
- i40e/i40evf: fix rx descriptor status (bsc#909484 FATE#317397).
- i40e: remove irqs only when they are set up (bsc#909484
  FATE#317397).
- i40e: don't remove HMC that doesn't exist (bsc#909484
  FATE#317397).
- i40e: print full link message (bsc#909484 FATE#317397).
- i40e: add xcast stats for port (bsc#909484 FATE#317397).
- i40e: add vsi x-cast stats (bsc#909484 FATE#317397).
- i40e: increase reset wait time (bsc#909484 FATE#317397).
- i40e/i40evf: add Tx pre queue disable function (bsc#909484
  FATE#317397).
- i40e/i40evf: check AQ register for valid data (bsc#909484
  FATE#317397).
- i40e: print message for pre-production hardware (bsc#909484
  FATE#317397).
- i40e: add VEB stats to ethtool (bsc#909484 FATE#317397).
- i40e: set lan_veb index (bsc#909484 FATE#317397).
- i40e: add missing VSI statistics (bsc#909484 FATE#317397).
- i40e/i40evf: remove rx_errors and rx_missed (bsc#909484
  FATE#317397).
- i40e: refactor stats collection (bsc#909484 FATE#317397).
- i40e: refactor send version (bsc#909484 FATE#317397).
- i40e/i40evf: VEB structure added, GTIME macro update (bsc#909484
  FATE#317397).
- i40e: notify VF of all types of resets (bsc#909484 FATE#317397).
- i40e: clamp jumbo frame size (bsc#909484 FATE#317397).
- i40e/i40evf: remove unused RX_LRO define (bsc#909484
  FATE#317397).
- i40e: remove check for large buffer (bsc#909484 FATE#317397).
- i40e: Rework register diagnostic (bsc#909484 FATE#317397).
- i40e: don't use OR to check a value (bsc#909484 FATE#317397).
- i40e: relax the firmware API version check (bsc#909484
  FATE#317397).
- i40: disable FCoE for MFP modes (bsc#909484 FATE#317397).
- i40e: add clear_pxe AdminQ request (bsc#909484 FATE#317397).
- i40e: Clear recovery pending, if reset failed (bsc#909484
  FATE#317397).
- i40e/i40evf: Change type to u32 to avoid sparse error
  (bsc#909484 FATE#317397).
- i40e/i40evf: remove storm control (bsc#909484 FATE#317397).
- i40e: Use the new i40e_get_fd_cnt_all function in other places
  (bsc#909484 FATE#317397).
- i40e: Report cmd->data in ETHTOOL_GRXCLSRLCNT instead of
  ETHTOOL_GRXCLSRULE (bsc#909484 FATE#317397).
- i40e/i40evf: Remove reserved PCTYPE defines (bsc#909484
  FATE#317397).
- i40e: Tx/Rx rings declaration (bsc#909484 FATE#317397).
- i40e: enable descriptor prefetch for VFs (bsc#909484
  FATE#317397).
- i40e/i40evf: Update check for AQ aliveness (bsc#909484
  FATE#317397).
- i40e,igb,ixgbe: remove usless return statements (bsc#909484
  FATE#317397).
- i40e: fix passing wrong error code to i40e_open() (bsc#909484
  FATE#317397).
- i40e: Check PCI_IOV config to avoid compile error (bsc#909484
  FATE#317397).
- i40e: remove Tx work for ptp (bsc#909484 FATE#317397).
- i40e: Don't disable SR-IOV when VFs are assigned (bsc#909484
  FATE#317397).
- i40e: remove hardcode of stats struct size in ethtool
  (bsc#909484 FATE#317397).
- i40e/i40evf: control auto ITR through ethtool (bsc#909484
  FATE#317397).
- i40e/i40evf: set proper default for ITR registers (bsc#909484
  FATE#317397).
- i40e: add required include (bsc#909484 FATE#317397).
- net: get rid of SET_ETHTOOL_OPS (bsc#909484 FATE#317397).
- i40e/i40evf: Retrieve and store missing link config information
  (bsc#909484 FATE#317397).
- i40e: Update function formal parameters (bsc#909484
  FATE#317397).
- i40e: Do not expose fd-sb commands from debugfs (bsc#909484
  FATE#317397).
- i40e: Do not enable NTUPLE feature control in MFP mode
  (bsc#909484 FATE#317397).
- i40e: Change variable type to avoid typecheck failure
  (bsc#909484 FATE#317397).
- i40e: Don't stop driver probe when querying DCB config fails
  (bsc#909484 FATE#317397).
- i40e: Redistribute queue vectors after DCB reconfiguration
  (bsc#909484 FATE#317397).
- i40e/i40evf: add driver version string to driver version command
  (bsc#909484 FATE#317397).
- i40e: Use port VLAN in MAC/VLAN filter configuration (bsc#909484
  FATE#317397).
- i40e: Retain MAC filters when changing port VLAN (bsc#909484
  FATE#317397).
- i40e: remove ptp_tx_work timestamp work item (bsc#909484
  FATE#317397).
- i40e: fix Timesync Tx interrupt handler code (bsc#909484
  FATE#317397).
- i40e: report VF link state correctly (bsc#909484 FATE#317397).
- i40e: Tweak for-loop in i40e_ethtool.c (bsc#909484 FATE#317397).
- i40e: Cleanup if/else statements (bsc#909484 FATE#317397).
- i40e: rework fdir setup and teardown (bsc#909484 FATE#317397).
- i40e: use generic vsi_open to unquiesce vsi (bsc#909484
  FATE#317397).
- i40e: abstract the close path for better netdev vsis (bsc#909484
  FATE#317397).
- i40e: prep vsi_open logic for non-netdev cases (bsc#909484
  FATE#317397).
- i40e/i40evf: update AdminQ API (bsc#909484 FATE#317397).
- i40e/i40evf: add tracking to NVM busy state (bsc#909484
  FATE#317397).
- i40e: Fix an issue with displaying IPv4 FD filters (bsc#909484
  FATE#317397).
- i40e: Remove a FW workaround (bsc#909484 FATE#317397).
- i40e: Enable VF Tx bandwidth setting (bsc#909484 FATE#317397).
- i40e: Reset the VF upon conflicting VLAN configuration
  (bsc#909484 FATE#317397).
- i40e/i40evf: Bump build versions (bsc#909484 FATE#317397).
- i40e/i40evf: unhide and enable to one prefena field (bsc#909484
  FATE#317397).
- i40e: Add bridge FDB add/del/dump ops (bsc#909484 FATE#317397).
- e1000e/igb/ixgbe/i40e: fix message terminations (bsc#909484
  FATE#317397).
- i40e: fix TCP flag replication for hardware offload (bsc#909484
  FATE#317397).
- i40e: remove open-coded skb_cow_head (bsc#909484 FATE#317397).
- i40e: Remove casts of pointer to same type (bsc#909484
  FATE#317397).
- i40e/i40evf: Remove addressof casts to same type (bsc#909484
  FATE#317397).
- i40e/i40evf: fix error checking path (bsc#909484 FATE#317397).
- i40e: fix function kernel doc description (bsc#909484
  FATE#317397).
- i40e: Use DEBUG_FD message level for an FD message (bsc#909484
  FATE#317397).
- i40e/i40evf: Add an FD message level (bsc#909484 FATE#317397).
- i40e: check for netdev before debugfs use (bsc#909484
  FATE#317397).
- i40e: Add functionality for FD SB to drop packets (bsc#909484
  FATE#317397).
- i40e: Cleanup in FDIR SB ethtool code (bsc#909484 FATE#317397).
- i40e: eeprom integrity check on load and empr (bsc#909484
  FATE#317397).
- i40e: Make the alloc and free queue vector calls orthogonal
  (bsc#909484 FATE#317397).
- i40e: Delete ATR filter on RST (bsc#909484 FATE#317397).
- i40e: Fix a message string (bsc#909484 FATE#317397).
- i40e/i40evf: Add EEE LPI stats (bsc#909484 FATE#317397).
- i40e: potential array underflow in i40e_vc_process_vf_msg()
  (bsc#909484 FATE#317397).
- i40e/i40evf: reduce context descriptors (bsc#909484
  FATE#317397).
- i40e/i40evf: enable hardware feature head write back (bsc#909484
  FATE#317397).
- i40e: Refactor and cleanup i40e_open(), adding i40e_vsi_open()
  (bsc#909484 FATE#317397).
- i40e: Patch to enable Ethtool/netdev feature flag for NTUPLE
  control (bsc#909484 FATE#317397).
- i40e: support VF link state ndo (bsc#909484 FATE#317397).
- net/core: Add VF link state control (bsc#909484 FATE#317397).
- net/i40e: Avoid double setting of NETIF_F_SG for the HW
  encapsulation feature mask (bsc#909484 FATE#317397).
- i40e: Don't receive packets when the napi budget == 0
  (bsc#909484 FATE#317397).
- net: Replace u64_stats_fetch_begin_bh to
  u64_stats_fetch_begin_irq (bsc#909484 FATE#317397).
- i40e/i40evf: Use dma_set_mask_and_coherent (bsc#909484
  FATE#317397).
- i40e/i40evf: Use correct number of VF vectors (bsc#909484
  FATE#317397).
- i40e: Let MDD events be handled by MDD handler (bsc#909484
  FATE#317397).
- i40e: Bug fix for FDIR replay logic (bsc#909484 FATE#317397).
- i40e: Add code to handle FD table full condition (bsc#909484
  FATE#317397).
- i40e: Define a new state variable to keep track of feature
  auto disable (bsc#909484 FATE#317397).
- i40e: Fix function comments (bsc#909484 FATE#317397).
- i40e: simplified init string (bsc#909484 FATE#317397).
- i40e: cleanup strings (bsc#909484 FATE#317397).
- i40e: make string references to q be queue (bsc#909484
  FATE#317397).
- i40e/i40evf: Some flow director HW definition fixes (bsc#909484
  FATE#317397).
- i40e: Fix a bug in the update logic for FDIR SB filter
  (bsc#909484 FATE#317397).
- i40e: delete netdev after deleting napi and vectors (bsc#909484
  FATE#317397).
- i40e/i40evf: carefully fill tx ring (bsc#909484 FATE#317397).
- i40e: fix nvm version and remove firmware report (bsc#909484
  FATE#317397).
- i40e: Fix static checker warning (bsc#909484 FATE#317397).
- i40e: Remove a redundant filter addition (bsc#909484
  FATE#317397).
- i40e: count timeout events (bsc#909484 FATE#317397).
- i40e: Remove a FW workaround for Number of MSIX vectors
  (bsc#909484 FATE#317397).
- i40e: clean up comment style (bsc#909484 FATE#317397).
- i40e/i40evf: i40e implementation for skb_set_hash (bsc#909484
  FATE#317397).
- i40e: Prevent overflow due to kzalloc (bsc#909484 FATE#317397).
- i40e: Flow Director sideband accounting (bsc#909484
  FATE#317397).
- i40e: Change MSIX to MSI-X (bsc#909484 FATE#317397).
- i40e: tighten up ring enable/disable flow (bsc#909484
  FATE#317397).
- i40e: remove unnecessary delay (bsc#909484 FATE#317397).
- i40e: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bsc#909484 FATE#317397).
- i40e: don't handle VF reset on unload (bsc#909484 FATE#317397).
- i40e: enable extant VFs (bsc#909484 FATE#317397).
- i40e: reset VFs after PF reset (bsc#909484 FATE#317397).
- i40e: set VF state to active when reset is complete (bsc#909484
  FATE#317397).
- i40e: remove dead code (bsc#909484 FATE#317397).
- i40e: Setting i40e_down bit for tx_timeout (bsc#909484
  FATE#317397).
- i40evf: clean up memsets (bsc#909484 FATE#317397).
- i40e: Add missing braces to i40e_dcb_need_reconfig() (bsc#909484
  FATE#317397).
- i40e: Fix device ID define names to align to standard
  (bsc#909484 FATE#317397).
- i40e: add DCB option to Kconfig (bsc#909484 FATE#317397).
  Update config files.
  Add support Data Center Bridging (DCB) Support (I40E_DCB).
- i40e: add DCB and DCBNL support (bsc#909484 FATE#317397).
- i40e: implement DCB support infastructure (bsc#909484
  FATE#317397).
- i40e: refactor flow director (bsc#909484 FATE#317397).
- i40e: rename defines (bsc#909484 FATE#317397).
- i40e: whitespace fixes (bsc#909484 FATE#317397).
- i40e: Change firmware workaround (bsc#909484 FATE#317397).
- i40e: fix compile warning on checksum_local (bsc#909484
  FATE#317397).
- i40e: updates to AdminQ interface (bsc#909484 FATE#317397).
- i40e: check desc pointer before printing (bsc#909484
  FATE#317397).
- drivers/net: delete non-required instances of include
  <linux/init.h> (bsc#909484 FATE#317397).
- i40e: Retain MAC filters on port VLAN deletion (bsc#909484
  FATE#317397).
- i40e: Warn admin to reload VF driver on port VLAN configuration
  (bsc#909484 FATE#317397).
- i40e: whitespace fixes (bsc#909484 FATE#317397).
- i40e: make message meaningful (bsc#909484 FATE#317397).
- i40e: associate VMDq queue with VM type (bsc#909484
  FATE#317397).
- i40e: remove extra register write (bsc#909484 FATE#317397).
- i40e: fix log message wording (bsc#909484 FATE#317397).
- i40e: remove linux/export.h header from i40e_ptp.c (bsc#909484
  FATE#317397).
- i40e: enable PTP (bsc#909484 FATE#317397).
- i40e: call clear_pxe after adminq is initialized (bsc#909484
  FATE#317397).
- i40e: clear qtx_head before enabling Tx queue (bsc#909484
  FATE#317397).
- i40e: adjust ITR max and min values (bsc#909484 FATE#317397).
- i40e: check for possible incorrect ipv6 checksum (bsc#909484
  FATE#317397).
- i40e: allow VF to remove any MAC filter (bsc#909484
  FATE#317397).
- i40e: do not bail when disabling if Tx queue disable fails
  (bsc#909484 FATE#317397).
- i40e: Setting queue count to 1 using ethtool is valid
  (bsc#909484 FATE#317397).
- i40e: Cleanup Doxygen warnings (bsc#909484 FATE#317397).
- i40e: fix long lines (bsc#909484 FATE#317397).
- i40e: Update the Current NVM version Low value (bsc#909484
  FATE#317397).
- i40e: drop unused macros (bsc#909484 FATE#317397).
- i40e: use assignment instead of memcpy (bsc#909484 FATE#317397).
- i40e: Turn flow director off in MFP mode (bsc#909484
  FATE#317397).
- i40e: Add a dummy packet template (bsc#909484 FATE#317397).
- i40e: trivial: formatting and checkpatch fixes (bsc#909484
  FATE#317397).
- i40e: shorten wordy fields (bsc#909484 FATE#317397).
- i40e: accept pf to pf adminq messages (bsc#909484 FATE#317397).
- i40e: remove interrupt on AQ error (bsc#909484 FATE#317397).
- i40e: release NVM resource reservation on startup (bsc#909484
  FATE#317397).
- i40e: Cleanup reconfig rss path (bsc#909484 FATE#317397).
- i40e: disable packet split (bsc#909484 FATE#317397).
- i40e: add a comment on barrier and fix panic on reset
  (bsc#909484 FATE#317397).
- i40e: Fix MAC format in Write MAC address AQ cmd (bsc#909484
  FATE#317397).
- i40e: Fix GPL header (bsc#909484 FATE#317397).
- i40e: use kernel specific defines (bsc#909484 FATE#317397).
- i40e: Re-enable interrupt on ICR0 (bsc#909484 FATE#317397).
- i40e: correctly setup ARQ descriptors (bsc#909484 FATE#317397).
- i40e: remove redundant AQ enable (bsc#909484 FATE#317397).
- i40e: Enable/Disable PF switch LB on SR-IOV configure changes
  (bsc#909484 FATE#317397).
- i40e: whitespace paren and comment tweaks (bsc#909484
  FATE#317397).
- i40e: rework shadow ram read functions (bsc#909484 FATE#317397).
- i40e: check MAC type before any REG access (bsc#909484
  FATE#317397).
- i40e: move PF ID init from PF reset to SC init (bsc#909484
  FATE#317397).
- i40e: Reduce range of interrupt reg in reg test (bsc#909484
  FATE#317397).
- i40e: update firmware api to 1.1 (bsc#909484 FATE#317397).
- i40e: Add code to wait for FW to complete in reset path
  (bsc#909484 FATE#317397).
- i40e: Allow VF to set already assigned MAC address (bsc#909484
  FATE#317397).
- i40e: Stop accepting any VLAN tag on VLAN 0 filter set
  (bsc#909484 FATE#317397).
- i40e: Do not enable broadcast promiscuous by default (bsc#909484
  FATE#317397).
- i40e: Expose AQ debugfs hooks (bsc#909484 FATE#317397).
- i40e: Do not allow AQ calls from ndo-ops (bsc#909484
  FATE#317397).
- i40e: check asq alive before notify (bsc#909484 FATE#317397).
- i40e: Admin queue shutdown fixes (bsc#909484 FATE#317397).
- i40e: Hide the Port VLAN VLAN ID (bsc#909484 FATE#317397).
- i40e: use correct struct for get and update vsi params
  (bsc#909484 FATE#317397).
- i40e: Fix VF driver MAC address configuration (bsc#909484
  FATE#317397).
- i40e: support VFs on PFs other than 0 (bsc#909484 FATE#317397).
- i40e: acknowledge VFLR when disabling SR-IOV (bsc#909484
  FATE#317397).
- i40e: don't allocate zero size (bsc#909484 FATE#317397).
- i40e: use struct assign instead of memcpy (bsc#909484
  FATE#317397).
- i40e: Do not enable default port on the VEB (bsc#909484
  FATE#317397).
- i40e: avoid unnecessary register read (bsc#909484 FATE#317397).
- i40e: Fix SR-IOV VF port VLAN (bsc#909484 FATE#317397).
- i40e: Record dma buffer info for dummy packets (bsc#909484
  FATE#317397).
- i40e: remove un-necessary io-write (bsc#909484 FATE#317397).
- i40e: Remove unnecessary prototypes (bsc#909484 FATE#317397).
- i40e: I40E_FLAG_MQ_ENABLED is not used (bsc#909484 FATE#317397).
- i40e: Fix ring allocation (bsc#909484 FATE#317397).
- i40e: catch unset q_vector (bsc#909484 FATE#317397).
- i40e: keep allocated memory in structs (bsc#909484 FATE#317397).
- i40e: fix error handling when alloc of vsi array fails
  (bsc#909484 FATE#317397).
- i40e: reinit buffer size each time (bsc#909484 FATE#317397).
- i40e: use functions to enable and disable icr 0 (bsc#909484
  FATE#317397).
- i40e: add header file flag _I40E_TXRX_H_ (bsc#909484
  FATE#317397).
- i40e: guard against vf message races (bsc#909484 FATE#317397).
- i40e: fix constant cast issues (bsc#909484 FATE#317397).
- i40e: Change the ethtool NVM read method to use AQ (bsc#909484
  FATE#317397).
- i40e: fix mac address checking (bsc#909484 FATE#317397).
- i40e: Dump the whole NVM, not half (bsc#909484 FATE#317397).
- i40e: report VF MAC addresses correctly (bsc#909484
  FATE#317397).
- i40e: update led set args (bsc#909484 FATE#317397).
- i40e: make a define from a large constant (bsc#909484
  FATE#317397).
- i40e: be more informative (bsc#909484 FATE#317397).
- i40e: fix error return (bsc#909484 FATE#317397).
- i40e: remove chatty log messages (bsc#909484 FATE#317397).
- i40e: remove redundant code (bsc#909484 FATE#317397).
- i40e: refactor VF reset flow (bsc#909484 FATE#317397).
- i40e: move i40e_reset_vf (bsc#909484 FATE#317397).
- i40e: Rx checksum offload for VXLAN (bsc#909484 FATE#317397).
- net: add 802.1ad / 802.1ah / QinQ ethertypes (bsc#909484
  FATE#317397).
- i40e: Implementation of VXLAN ndo's (bsc#909484 FATE#317397).
- i40e: fix curly brace use and return type (bsc#909484
  FATE#317397).
- i40e: add wake-on-lan support (bsc#909484 FATE#317397).
- i40e: Populate and check pci bus speed and width (bsc#909484
  FATE#317397).
- pci_regs.h: Add PCI bus link speed and width defines (bsc#909484
  FATE#317397).
- i40e: Suppress HMC error to Interrupt message level (bsc#909484
  FATE#317397).
- i40e: using for_each_set_bit to simplify the code (bsc#909484
  FATE#317397).
- i40e: make functions static and remove dead code (bsc#909484
  FATE#317397).
- i40e: Fix off by one in i40e_dbg_command_write (bsc#909484
  FATE#317397).
- i40e: Fix wrong mask bits being used in misc interrupt
  (bsc#909484 FATE#317397).
- i40e: more print_hex_dump use (bsc#909484 FATE#317397).
- i40e: fix up scanf decoders (bsc#909484 FATE#317397).
- i40e: simplify error messages for dump descriptor (bsc#909484
  FATE#317397).
- i40e: prevent null pointer exception in dump descriptor
  (bsc#909484 FATE#317397).
- i40e: Fix dump output from debugfs calls (bsc#909484
  FATE#317397).
- i40e: Remove FCoE in i40e_virtchnl_pf.c code (bsc#909484
  FATE#317397).
- i40e: support for suspend and resume (bsc#909484 FATE#317397).
- i40e: rtnl_lock in reset path fixes (bsc#909484 FATE#317397).
- i40e: Add basic support for get/set channels for RSS (bsc#909484
  FATE#317397).
- i40e: function to reconfigure RSS queues and rebuild (bsc#909484
  FATE#317397).
- i40e: reinit flow for the main VSI (bsc#909484 FATE#317397).
- i40e: use same number of queues as CPUs (bsc#909484
  FATE#317397).
- i40e: trivial fixes (bsc#909484 FATE#317397).
- i40e: init flow control settings to disabled (bsc#909484
  FATE#317397).
- i40e: Tell the stack about our actual number of queues
  (bsc#909484 FATE#317397).
- i40e: fix pf reset after offline test (bsc#909484 FATE#317397).
- i40e: fix up some of the ethtool connection reporting
  (bsc#909484 FATE#317397).
- i40e: fix null dereference (bsc#909484 FATE#317397).
- i40e: remove and fix confusing define name (bsc#909484
  FATE#317397).
- i40e: complain about out-of-range descriptor request (bsc#909484
  FATE#317397).
- i40e: loopback info and set loopback fix (bsc#909484
  FATE#317397).
- i40e: restrict diag test messages (bsc#909484 FATE#317397).
- i40e: Add a new variable to track number of pf instances
  (bsc#909484 FATE#317397).
- i40e: add num_VFs message (bsc#909484 FATE#317397).
- i40e: refactor ethtool tests (bsc#909484 FATE#317397).
- i40e: clear test state bit after all ethtool tests (bsc#909484
  FATE#317397).
- i40e: only set up the rings to be used (bsc#909484 FATE#317397).
- i40e: Enable all PCTYPEs except FCOE for RSS (bsc#909484
  FATE#317397).
- i40e: refactor reset code (bsc#909484 FATE#317397).
- i40e: enable early hardware support (bsc#909484 FATE#317397).
- i40e: Add flag for L2 VEB filtering (bsc#909484 FATE#317397).
- i40e: get media type during link info (bsc#909484 FATE#317397).
- i40e: check multi-bit state correctly (bsc#909484 FATE#317397).
- i40e: separate TSYNVALID and TSYNINDX fields in Rx descriptor
  (bsc#909484 FATE#317397).
- i40e: sync header files with hardware (bsc#909484 FATE#317397).
- i40e: restrict diag test length (bsc#909484 FATE#317397).
- i40e: add support for triggering EMPR (bsc#909484 FATE#317397).
- i40e: add interrupt test (bsc#909484 FATE#317397).
- i40e: default debug mask setting (bsc#909484 FATE#317397).
- i40e: fix debugging messages (bsc#909484 FATE#317397).
- i40e: properly add VF MAC addresses (bsc#909484 FATE#317397).
- i40e: retry call on timeout (bsc#909484 FATE#317397).
- i40e: select reset counters correctly (bsc#909484 FATE#317397).
- i40e: allow one more vector for VFs (bsc#909484 FATE#317397).
- i40e: firmware version fields offsets update (bsc#909484
  FATE#317397).
- i40e: simplify aq head-tail-len setups (bsc#909484 FATE#317397).
- i40e: clear AQ head and tail registers (bsc#909484 FATE#317397).
- i40e: register file updates (bsc#909484 FATE#317397).
- i40e: set pf_id based on device and function numbers (bsc#909484
  FATE#317397).
- i40e: fix error return code in i40e_probe() (bsc#909484
  FATE#317397).
- i40e: remove unused including <linux/version.h> (bsc#909484
  FATE#317397).
- i40e: use pf_id for pf function id in qtx_ctl (bsc#909484
  FATE#317397).
- i40e: check vsi ptrs before dumping them (bsc#909484
  FATE#317397).
- i40e: reorder block declarations in debugfs (bsc#909484
  FATE#317397).
- i40e: tweaking icr0 handling for legacy irq (bsc#909484
  FATE#317397).
- i40e: refactor fdir setup function (bsc#909484 FATE#317397).
- i40e: fix sign extension issue (bsc#909484 FATE#317397).
- i40e: fix use of untrusted scalar value warning (bsc#909484
  FATE#317397).
- i40e: clamp debugfs nvm read command (bsc#909484 FATE#317397).
- i40e: debugfs fixups (bsc#909484 FATE#317397).
- i40e: fixup legacy interrupt handling (bsc#909484 FATE#317397).
- i40e: assign correct vector to VF (bsc#909484 FATE#317397).
- i40e: don't free nonexistent rings (bsc#909484 FATE#317397).
- i40e: do not flush after re-enabling interrupts (bsc#909484
  FATE#317397).
- i40e: Add support for 64 bit netstats (bsc#909484 FATE#317397).
- i40e: Move rings from pointer to array to array of pointers
  (bsc#909484 FATE#317397).
- i40e: Replace ring container array with linked list (bsc#909484
  FATE#317397).
- i40e: Move q_vectors from pointer to array to array of pointers
  (bsc#909484 FATE#317397).
- i40e: Split bytes and packets from Rx/Tx stats (bsc#909484
  FATE#317397).
- i40e: Add support for Tx byte queue limits (bsc#909484
  FATE#317397).
- i40e: Drop dead code and flags from Tx hotpath (bsc#909484
  FATE#317397).
- i40e: clean up Tx fast path (bsc#909484 FATE#317397).
- i40e: Do not directly increment Tx next_to_use (bsc#909484
  FATE#317397).
- i40e: Cleanup Tx buffer info layout (bsc#909484 FATE#317397).
- i40e: Drop unused completed stat (bsc#909484 FATE#317397).
- i40e: Link code updates (bsc#909484 FATE#317397).
- i40e: clean up coccicheck reported errors (bsc#909484
  FATE#317397).
- i40e: better return values (bsc#909484 FATE#317397).
- i40e: convert ret to aq_ret (bsc#909484 FATE#317397).
- i40e: small clean ups from review (bsc#909484 FATE#317397).
- i40e: use common failure flow (bsc#909484 FATE#317397).
- net: Add support for hardware-offloaded encapsulation
  (bsc#909484 FATE#317397).
- list: introduce list_first_entry_or_null (bsc#909484
  FATE#317397).
- i40e: include i40e in kernel proper (bsc#909484 FATE#317397).
  Update config files.
  Add support Intel(R) Ethernet Controller XL710 Family support (I40E).
- i40e: debugfs interface (bsc#909484 FATE#317397).
- i40e: init code and hardware support (bsc#909484 FATE#317397).
- i40e: implement virtual device interface (bsc#909484
  FATE#317397).
- i40e: driver core headers (bsc#909484 FATE#317397).
- i40e: driver ethtool core (bsc#909484 FATE#317397).
- i40e: transmit, receive, and NAPI (bsc#909484 FATE#317397).
- i40e: main driver core (bsc#909484 FATE#317397).
- commit b37f104
* Wed Feb 25 2015 duwe@suse.de
- patches.fixes/random-04-Fix-add_timer_randomness-throttling
  Add commit ID of superseding patch.
- commit ae2fa67
* Wed Feb 25 2015 duwe@suse.de
- patches.fixes/random-04-Fix-add_timer_randomness-throttling
  Add commit ID of superseding patch.
- commit a115ca9
* Wed Feb 25 2015 duwe@suse.de
- Fix add_timer_randomness throttling
  (bsc#904883,bsc#904901,FATE#317374).
- commit 7fa157e
* Wed Feb 25 2015 jack@suse.cz
- fsnotify: Fix handling of renames in audit (bnc#915200).
- commit 8d60f2f
* Wed Feb 25 2015 duwe@suse.de
- Refresh
  patches.fixes/random-04-Fix-add_timer_randomness-throttling.
- commit bebc954
* Wed Feb 25 2015 duwe@suse.de
- Fix add_timer_randomness throttling
  (bsc#904883,bsc#904901,FATE#317374).
- random: account for entropy loss due to overwrites
  (FATE#317374).
- random: allow fractional bits to be tracked (FATE#317374).
- random: statically compute poolbitshift, poolbytes, poolbits
  (FATE#317374).
- commit ead4ca8
* Wed Feb 25 2015 vbabka@suse.cz
- mm: vmscan: count only dirty pages as congested (VM Performance,
  bnc#910517).
- Don't trigger congestion wait on dirty-but-not-writeout pages
  (VM Performance, bnc#909093, bnc#910517).
- commit 2e91246
* Wed Feb 25 2015 bpoirier@suse.de
- Refresh
  patches.drivers/mlx4-0190-NET-IB-mlx4-Add-device-managed-flow-steering-firmwar.patch.
  Result moves away from what non-upstream
  patches.drivers/mlx4_0080_profile_parm.patch did
- Refresh
  patches.drivers/mlx4-0205-mlx4-Put-physical-GID-and-P_Key-table-sizes-in-mlx4_.patch.
  Result differs from upstream merge resolution in 5dedb9f
- Refresh
  patches.drivers/mlx4-0285-mlx4_core-Adjustments-to-Flow-Steering-activation-lo.patch.
- commit d387130
* Wed Feb 25 2015 jlee@suse.com
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (fate#317398,
  bsc#909493).
- net: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate
  (fate#317398, bsc#909493).
- i40e,igb,ixgbe: remove usless return statements (fate#317398,
  bsc#909493).
- net: get rid of SET_ETHTOOL_OPS (fate#317398, bsc#909493).
- igbvf: remove open-coded skb_cow_head (fate#317398, bsc#909493).
- igbvf: Convert uses of __constant_<foo> to <foo> (fate#317398,
  bsc#909493).
- igbvf: Use pci_enable_msix_range() instead of pci_enable_msix()
  (fate#317398, bsc#909493).
- net: igbvf: slight optimization of addr compare (fate#317398,
  bsc#909493).
- igbvf: add missing iounmap() on error in igbvf_probe()
  (fate#317398, bsc#909493).
- igbvf: integer wrapping bug setting the mtu (fate#317398,
  bsc#909493).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN
  (fate#317398, bsc#909493).
- intel: Remove extern from function prototypes (fate#317398,
  bsc#909493).
- DMA-API: net: intel/igbvf: fix 32-bit DMA mask handling
  (fate#317398, bsc#909493).
- drivers:net: dma_alloc_coherent: use __GFP_ZERO instead of
  memset(, 0) (fate#317398, bsc#909493).
- igbvf: Make next_to_watch a pointer and adjust memory barriers
  to avoid races (fate#317398, bsc#909493).
- ethernet: Remove unnecessary alloc/OOM messages, alloc cleanups
  (fate#317398).
- igbvf: be sane about random MAC addresses (fate#317398,
  bsc#909493).
- remove init of dev->perm_addr in drivers (fate#317398,
  bsc#909493).
- net: remove unnecessary NET_ADDR_RANDOM "bitclean" (fate#317398,
  bsc#909493).
- net: add address assign type "SET" (fate#317398).
- net: call add_device_randomness() only after successful mac
  change (fate#317398).
- commit 9f6d2fe
* Wed Feb 25 2015 bpoirier@suse.de
- Delete
  patches.drivers/mlx4_en-fix-allocation-of-CPU-affinity-reverse-map.patch.
- Delete
  patches.drivers/mlx4_en-fix-allocation-of-device-tx_cq.patch.
- Delete patches.drivers/mlx4_en-fix-blueflame-race.
- Delete
  patches.drivers/net-mlx4_core-load-higher-level-modules-according-to-ports.patch.
- Delete
  patches.drivers/net-mlx4_core-load-the-ib-driver-when-the-device-supports.patch.
- Delete
  patches.drivers/net-mlx4_en-Disable-RFS-when-running-in-SRIOV-mode.patch.
- Delete
  patches.fixes/mlx4-allow-order-0-memory-allocations-in-RX-path.patch.
- Delete
  patches.fixes/mlx4_core-fix-endianess-bug-in-set_param_l.patch.
- Delete
  patches.fixes/net-mlx4-use-one-page-fragment-per-incoming-frame.patch.
- Delete
  patches.fixes/net-mlx4_en-Fix-a-race-between-napi-poll-function-an.patch.
- Delete
  patches.fixes/net-mlx4_en-Fix-pages-never-dma-unmapped-on-rx.patch.
- Delete
  patches.fixes/net-mlx4_en-Fix-selftest-failing-on-non-10G-link-speed.
  They will be re-added as part of the mlx4 SP4 update.
- commit 481f2a1
* Tue Feb 24 2015 lduncan@suse.com
- removing series.conf comment left in by mistake
- commit 9fb7b6d
* Tue Feb 24 2015 bpoirier@suse.de
- e1000e: Fix TSO with non-accelerated vlans (bug#909495
  FATE#317394).
- e1000e: delete excessive space character in debug message
  (bug#909495 FATE#317394).
- e1000e: fix trivial kernel doc typos (bug#909495 FATE#317394).
- e1000e: Fix Runtime PM blocks EEE link negotiation in S5
  (bug#909495 FATE#317394).
- e1000e: Fix EEE in S5 w/ Runtime PM enabled (bug#909495
  FATE#317394).
- e1000e: Add support for EEE in Sx states (bug#909495
  FATE#317394).
- e1000e: Add code to check return values on NVM accesses
  (bug#909495 FATE#317394).
- e1000e: Fix CRC errors with jumbo traffic (bug#909495
  FATE#317394).
- e1000e: remove unnecessary break after return (bug#909495
  FATE#317394).
- net: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate
  (bug#909495 FATE#317394).
- e1000e: Out of line __ew32_prepare/__ew32 (bug#909495
  FATE#317394).
- e1000e: Fix expand setting EEE link info to all affected parts
  (bug#909495 FATE#317394).
- e1000e: Cleanup parenthesis around return value (bug#909495
  FATE#317394).
- e1000e: 82574/82583 TimeSync errata for SYSTIM read (bug#909495
  FATE#317394).
- net: get rid of SET_ETHTOOL_OPS (bug#909495 FATE#317394).
- e1000e: Restrict MDIO Slow Mode workaround to relevant parts
  (bug#909495 FATE#317394).
- e1000e: Fix issue with link flap on 82579 (bug#909495
  FATE#317394).
- e1000e: Expand workaround for 10Mb HD throughput bug (bug#909495
  FATE#317394).
- e1000e: Workaround for dropped packets in Gig/100 speeds on
  82579 (bug#909495 FATE#317394).
- e1000e: Cleanup use of deprecated DEFINE_PCI_DEVICE_TABLE
  (bug#909495 FATE#317394).
- e1000e: Cleanup checkpatch extra space (bug#909495 FATE#317394).
- e1000e: Cleanup to fix checkpatch missing blank lines
  (bug#909495 FATE#317394).
- e1000e: Cleanup return values in ethtool (bug#909495
  FATE#317394).
- e1000e/igb/ixgbe/i40e: fix message terminations (bug#909495
  FATE#317394).
- e1000e: Enclose e1000e_pm_thaw() with CONFIG_PM_SLEEP
  (bug#909495 FATE#317394).
- e1000e: Correctly include VLAN_HLEN when changing interface MTU
  (bug#909495 FATE#317394).
- e1000e: remove open-coded skb_cow_head (bug#909495 FATE#317394).
- e1000e: Fix no connectivity when driver loaded with cable out
  (bug#909495 FATE#317394).
- e1000e: remove redundant if clause from PTP work (bug#909495
  FATE#317394).
- e1000e: add timeout for TX HW time stamping work (bug#909495
  FATE#317394).
- e1000e: Fix Explicitly set Transmit Control Register (bug#909495
  FATE#317394).
- e1000e: Fix Hardware Unit Hang (bug#909495 FATE#317394).
- e1000e: fix the build error when PM is disabled (bug#909495
  FATE#317394).
- net: e1000e calls skb_set_hash (bug#909495 FATE#317394).
- e1000e: Fix SHRA register access for 82579 (bug#909495
  FATE#317394).
- e1000e: Fix ethtool offline tests for 82579 parts (bug#909495
  FATE#317394).
- e1000e: Fix not generating an error on invalid load parameter
  (bug#909495 FATE#317394).
- e1000e: Feature Enable PHY Ultra Low Power Mode (ULP)
  (bug#909495 FATE#317394).
- e1000e Refactor of Runtime Power Management (bug#909495
  FATE#317394).
- e1000e: Refactor PM flows (bug#909495 FATE#317394).
- e1000e: Add missing branding strings in ich8lan.c (bug#909495
  FATE#317394).
- e1000e: Cleanup - Update GPL header and Copyright (bug#909495
  FATE#317394).
- e1000e: Fix 82579 sets LPI too early (bug#909495 FATE#317394).
- e1000e: Resolve issues with Management Engine (ME) briefly
  blocking PHY resets (bug#909495 FATE#317394).
- e1000e: Cleanup unecessary references (bug#909495 FATE#317394).
- e1000e: PTP lock in e1000e_phc_adjustfreq (bug#909495
  FATE#317394).
- e1000e: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bug#909495 FATE#317394).
- e1000e: Fix compilation warning when !CONFIG_PM_SLEEP
  (bug#909495 FATE#317394).
- e1000e: Fix a compile flag mis-match for suspend/resume
  (bug#909495 FATE#317394).
- e1000e: fix compiler warning (maybe-unitialized variable)
  (bug#909495 FATE#317394).
- e1000e: fix compiler warnings (bug#909495 FATE#317394).
- e1000e: Implement the SIOCGHWTSTAMP ioctl (bug#909495
  FATE#317394).
- e1000e: Validate hwtstamp_config completely before applying it
  (bug#909495 FATE#317394).
- intel: Remove extern from function prototypes (bug#909495
  FATE#317394).
- DMA-API: net: intel/e1000e: fix 32-bit DMA mask handling
  (bug#909495 FATE#317394).
- e1000e: fix overrun of PHY RAR array (bug#909495 FATE#317394).
- e1000e: cleanup boolean comparison to true (bug#909495
  FATE#317394).
- e1000e: balance semaphore put/get for 82573 (bug#909495
  FATE#317394).
- e1000e: resolve checkpatch JIFFIES_COMPARISON warning
  (bug#909495 FATE#317394).
- e1000e: Avoid kernel crash during shutdown (bug#909495
  FATE#317394).
- e1000e: Add code to check for failure of pci_disable_link_state
  call (bug#909495 FATE#317394).
- e1000e: cleanup whitespace in recent commit (bug#909495
  FATE#317394).
- e1000e: fix I217/I218 PHY initialization flow (bug#909495
  FATE#317394).
- e1000e: do not resume device from RPM suspend to read PHY
  status registers (bug#909495 FATE#317394).
- e1000e: enable support for new device IDs (bug#909495
  FATE#317394).
- e1000e: ethtool unnecessarily takes device out of RPM suspend
  (bug#909495 FATE#317394).
- e1000e: Tx hang on I218 when linked at 100Half and slow response
  at 10Mbps (bug#909495 FATE#317394).
- e1000e: low throughput using 4K jumbos on I218 (bug#909495
  FATE#317394).
- e1000e: iAMT connections drop on driver unload when jumbo
  frames enabled (bug#909495 FATE#317394).
- e1000e: disable ASPM L1 on 82583 (bug#909495 FATE#317394).
- e1000e: Use marco instead of digit for defining
  e1000_rx_desc_packet_split (bug#909495 FATE#317394).
- e1000e: Remove duplicate assignment of default rx/tx ring size
  (bug#909495 FATE#317394).
- e1000e: Release mutex lock only if it has been initially
  acquired (bug#909495 FATE#317394).
- e1000e: cleanup whitespace (bug#909495 FATE#317394).
- e1000e: fix scheduling while atomic bug (bug#909495
  FATE#317394).
- e1000e: panic caused by Rx traffic arriving while interface
  going down (bug#909495 FATE#317394).
- e1000e: fix numeric overflow in phc settime method (bug#909495
  FATE#317394).
- e1000e: fix scheduling while atomic bugs (bug#909495
  FATE#317394).
- e1000e: increase driver version number (bug#909495 FATE#317394).
- e1000e: cleanup unused defines (bug#909495 FATE#317394).
- e1000e: add support for LTR on I217/I218 (bug#909495
  FATE#317394).
- e1000e: EEE capability advertisement not set/disabled as
  required (bug#909495 FATE#317394).
- e1000e: long access timeouts when I217/I218 MAC and PHY are
  out of sync (bug#909495 FATE#317394).
- e1000e: fix LED blink logic for designs with LEDs driven by
  cathode (bug#909495 FATE#317394).
- e1000e: slow performance between two 82579 connected via 10Mbit
  hub (bug#909495 FATE#317394).
- e1000e: additional error handling on PHY register accesses
  (bug#909495 FATE#317394).
- e1000e: Add missing dma_mapping_error-call in
  e1000_alloc_jumbo_rx_buffers (bug#909495 FATE#317394).
- e1000e: cleanup - move defines to appropriate header file
  (bug#909495 FATE#317394).
- e1000e: cleanup format of struct e1000_opt_list struct
  (bug#909495 FATE#317394).
- e1000e: cleanup USLEEP_RANGE checkpatch checks (bug#909495
  FATE#317394).
- e1000e: cleanup unnecessary line breaks (bug#909495
  FATE#317394).
- e1000e: cleanup formatting of static structs (bug#909495
  FATE#317394).
- e1000e: cleanup unusually placed comments (bug#909495
  FATE#317394).
- e1000e: cleanup (add/remove) blank lines where appropriate
  (bug#909495 FATE#317394).
- e1000e: cleanup SPACING checkpatch checks (bug#909495
  FATE#317394).
- e1000e: cleanup PARENTHESIS_ALIGNMENT checkpatch checks
  (bug#909495 FATE#317394).
- e1000e: cleanup LEADING_SPACE checkpatch warnings (bug#909495
  FATE#317394).
- e1000e: cleanup LONG_LINE checkpatch warnings (bug#909495
  FATE#317394).
- e1000e: cleanup SPACING checkpatch errors and warnings
  (bug#909495 FATE#317394).
- e1000e: cleanup CODE_INDENT checkpatch errors (bug#909495
  FATE#317394).
- e1000e: fix accessing to suspended device (bug#909495
  FATE#317394).
- e1000e: fix runtime power management transitions (bug#909495
  FATE#317394).
- e1000e: workaround DMA unit hang on I218 (bug#909495
  FATE#317394).
- e1000e: display a warning message when SmartSpeed works
  (bug#909495 FATE#317394).
- e1000e: cleanup checkpatch braces checks (bug#909495
  FATE#317394).
- e1000e: convert enums of register offsets and move #defines
  to regs.h (bug#909495 FATE#317394).
- e1000e: cosmetic move of #defines and prototypes to the new
  manage.h (bug#909495 FATE#317394).
- e1000e: cosmetic move of #defines and function prototypes to
  the new nvm.h (bug#909495 FATE#317394).
- e1000e: cosmetic move of #defines and function prototypes to
  the new phy.h (bug#909495 FATE#317394).
- e1000e: cosmetic move of function prototypes to the new mac.h
  (bug#909495 FATE#317394).
- e1000e: cosmetic move of #defines and prototypes to the new
  ich8lan.h (bug#909495 FATE#317394).
- e1000e: cosmetic move of #defines to the new 80003es2lan.h
  (bug#909495 FATE#317394).
- e1000e: cosmetic move of #defines and prototypes to the new
  82571.h (bug#909495 FATE#317394).
- e1000e: use generic IEEE MII definitions (bug#909495
  FATE#317394).
- e1000e: resolve -Wunused-parameter compile warnings (bug#909495
  FATE#317394).
- e1000e: update driver version string (bug#909495 FATE#317394).
- e1000e: cleanup some whitespace and indentation issues
  (bug#909495 FATE#317394).
- e1000e: cleanup: group OR'ed bit settings with parens
  (bug#909495 FATE#317394).
- e1000e: cleanup defines.h (bug#909495 FATE#317394).
- e1000e: cleanup: remove comments which are no longer applicable
  (bug#909495 FATE#317394).
- e1000e: cleanup hw.h (bug#909495 FATE#317394).
- e1000e: cleanup: remove unused #define (bug#909495 FATE#317394).
- e1000e: adjust PM QoS request (bug#909495 FATE#317394).
- e1000e: correct maximum frame size on 82579 (bug#909495
  FATE#317394).
- e1000e: cleanup: remove e1000e_commit_phy() (bug#909495
  FATE#317394).
- e1000e: cleanup: remove e1000_get_cable_length() (bug#909495
  FATE#317394).
- e1000e: cleanup: remove e1000_get_phy_cfg_done() (bug#909495
  FATE#317394).
- e1000e: cleanup: rename e1000_get_cfg_done() (bug#909495
  FATE#317394).
- e1000e: cleanup: remove e1000_force_speed_duplex() (bug#909495
  FATE#317394).
- e1000e: cleanup: remove e1000_set_d0_lplu_state() (bug#909495
  FATE#317394).
- e1000e: cleanup: do not assign a variable a value when not
  necessary (bug#909495 FATE#317394).
- e1000e: do not ignore variables which get set a value
  (bug#909495 FATE#317394).
- e1000e: cleanup: remove unnecessary function prototypes
  (bug#909495 FATE#317394).
- e1000e: add comment to spinlock_t definition (bug#909495
  FATE#317394).
- e1000e: remove definition of struct which is no longer used
  (bug#909495 FATE#317394).
- e1000e: fix PHY init workarounds for i217/i218 (bug#909495
  FATE#317394).
- e1000e: correct maximum frame size on i217/i218 (bug#909495
  FATE#317394).
- e1000e: update copyright date (bug#909495 FATE#317394).
- e1000e: remove prototype of non-existent function (bug#909495
  FATE#317394).
- e1000e: prevent hardware from automatically configuring PHY
  on I217/I218 (bug#909495 FATE#317394).
- e1000e: enable ECC on I217/I218 to catch packet buffer memory
  errors (bug#909495 FATE#317394).
- e1000e: add support for IEEE-1588 PTP (bug#909495 FATE#317394).
- e1000e: fix flow-control thresholds for jumbo frames on
  82579/I217/I218 (bug#909495 FATE#317394).
- e1000e: fix ethtool offline register test for I217 (bug#909495
  FATE#317394).
- e1000e: add support for hardware timestamping on some devices
  (bug#909495 FATE#317394).
- e1000e: Use standard #defines for PCIe Capability ASPM fields
  (bug#909495 FATE#317394).
- e1000e: merge multiple conditional statements into one
  (bug#909495 FATE#317394).
- e1000e: cleanup code duplication (bug#909495 FATE#317394).
- e1000e: cleanup magic number (bug#909495 FATE#317394).
- e1000e: cleanup unnecessary line wrap (bug#909495 FATE#317394).
- e1000e: cleanup unusual comment placement (bug#909495
  FATE#317394).
- e1000e: cleanup redundant statistics counter (bug#909495
  FATE#317394).
- e1000e: resolve checkpatch PREFER_PR_LEVEL warning (bug#909495
  FATE#317394).
- e1000e: add missing bailout on error (bug#909495 FATE#317394).
- e1000e: unexpected "Reset adapter" message when cable pulled
  (bug#909495 FATE#317394).
- e1000e: fix enabling of EEE on 82579 and I217 (bug#909495
  FATE#317394).
- e1000e: 82577: workaround for link drop issue (bug#909495
  FATE#317394).
- e1000e: helper functions for accessing EMI registers (bug#909495
  FATE#317394).
- e1000e: Invalid Image CSUM bit changed for I217 (bug#909495
  FATE#317394).
- e1000e: Acquire/release semaphore when writing each EEPROM page
  (bug#909495 FATE#317394).
- e1000e: SerDes autoneg flow control (bug#909495 FATE#317394).
- remove init of dev->perm_addr in drivers (bug#909495
  FATE#317394).
- commit c807046
* Tue Feb 24 2015 bpoirier@suse.de
- Delete
  patches.drivers/e1000e-82577-workaround-for-link-drop-issue.patch.
- Delete
  patches.drivers/e1000e-helper-functions-for-accessing-EMI-registers.patch.
- Delete
  patches.drivers/e1000e-unexpected-Reset-adapter-message-when-cable-p.patch.
- Delete
  patches.drivers/e1000e-workaround-DMA-unit-hang-on-I218.patch.
- Delete
  patches.fixes/e1000e-enable-support-for-new-device-IDs.patch.
  They will be re-added as part of the e1000e SP4 update.
- commit 153f274
* Tue Feb 24 2015 glin@suse.com
- enic: reconfigure resources for kdump crash kernel (bsc#911105
  FATE#317501).
- crash_dump: Make is_kdump_kernel() accessible from modules
  (bsc#911105 FATE#317501).
- net: ethernet: cisco: enic: enic_dev: Remove some unused
  functions (bsc#911105 FATE#317501).
- enic: add stats for dma mapping error (bsc#911105 FATE#317501).
- enic: check dma_mapping_error (bsc#911105 FATE#317501).
- net: Add net_ratelimited_function and net_<level>_ratelimited
  macros (bsc#911105 FATE#317501).
- net: add skb frag size accessors (bsc#911105 FATE#317501).
- net: use DMA_x_DEVICE and dma_mapping_error with
  skb_frag_dma_map (bsc#911105 FATE#317501).
- enic: make vnic_wq_buf doubly linked (bsc#911105 FATE#317501).
- enic: free all rq buffs when allocation fails (bsc#911105
  FATE#317501).
- enic: fix rx skb checksum (bsc#911105 FATE#317501).
- enic: use spin_lock(wq_lock) instead of
  spin_lock_irqsave(wq_lock) (bsc#911105 FATE#317501).
- enic: use napi_schedule_irqoff() (bsc#911105 FATE#317501).
- net: introduce napi_schedule_irqoff() (bsc#911105 FATE#317501).
- enic: update desc properly in rx_copybreak (bsc#911105
  FATE#317501).
- enic: handle error condition properly in enic_rq_indicate_buf
  (bsc#911105 FATE#317501).
- enic: fix possible deadlock in enic_stop/ enic_rfs_flw_tbl_free
  (bsc#911105 FATE#317501).
- drivers/net: Convert remaining uses of pr_warning to pr_warn
  (bsc#911105 FATE#317501).
- enic: implement rx_copybreak (bsc#911105 FATE#317501).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#911105
  FATE#317501).
- enic: use pci_zalloc_consistent (bsc#911105 FATE#317501).
- enic: Add ethtool support to show classifier filters added by
  the driver (bsc#911105 FATE#317501).
- enic: remove #ifdef CONFIG_RFS_ACCEL around filter structures
  (bsc#911105 FATE#317501).
- enic: fix return values in enic_set_coalesce (bsc#911105
  FATE#317501).
- enic: Make dummy rfs functions inline to fix !CONFIG_RFS_ACCEL
  build (bsc#911105 FATE#317501).
- enic: Kill unused variable in enic_rfs_flw_tbl_init()
  (bsc#911105 FATE#317501).
- enic: do tx cleanup in napi poll (bsc#911105 FATE#317501).
- enic: fix lockdep around devcmd_lock (bsc#911105 FATE#317501).
- enic: Add Accelerated RFS support (bsc#911105 FATE#317501).
- enic: alloc/free rx_cpu_rmap (bsc#911105 FATE#317501).
- enic: devcmd for adding IP 5 tuple hardware filters (bsc#911105
  FATE#317501).
- enic: fix return value in _vnic_dev_cmd (bsc#911105
  FATE#317501).
- net: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate
  (bsc#911105 FATE#317501).
- enic: Update driver to use __dev_uc/mc_sync/unsync calls
  (bsc#911105 FATE#317501).
- net: Add support for device specific address syncing (bsc#911105
  FATE#317501).
- net: add dev_uc_sync_multiple() and dev_mc_sync_multiple()
  api (bsc#911105 FATE#317501).
- net: introduce netif_addr_lock_nested() and call if when
  appropriate (bsc#911105 FATE#317501).
- enic: Fix 64 bit divide on 32bit system (bsc#911105
  FATE#317501).
- enic: Add support for adaptive interrupt coalescing (bsc#911105
  FATE#317501).
- net: get rid of SET_ETHTOOL_OPS (bsc#911105 FATE#317501).
- net: enic: include irq.h for irqreturn_t definitions (bsc#911105
  FATE#317501).
- enic: Call dev_kfree_skb_any instead of dev_kfree_skb
  (bsc#911105 FATE#317501).
- enic: Don't receive packets when the napi budget == 0
  (bsc#911105 FATE#317501).
- enic: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bsc#911105 FATE#317501).
- net: enic: slight optimization of addr compare (bsc#911105
  FATE#317501).
- net: cisco-enic calls skb_set_hash (bsc#911105 FATE#317501).
- net: enic: remove unnecessary pci_set_drvdata() (bsc#911105
  FATE#317501).
- driver/net: enic: update enic maintainers and driver (bsc#911105
  FATE#317501).
- driver/net: enic: Exposing symbols for Cisco's low latency
  driver (bsc#911105 FATE#317501).
- driver/net: enic: Try DMA 64 first, then failover to DMA
  (bsc#911105 FATE#317501).
- driver/net: enic: record q_number and rss_hash for skb
  (bsc#911105 FATE#317501).
- driver/net: enic: Add multi tx support for enic (bsc#911105
  FATE#317501).
- drivers/net: enic: Generate notification of hardware crash
  (bsc#911105 FATE#317501).
- drivers/net: enic: Add an interface for USNIC to interact with
  firmware (bsc#911105 FATE#317501).
- drivers/net: enic: Adding support for Cisco Low Latency NIC
  (bsc#911105 FATE#317501).
- drivers/net: enic: Move ethtool code to a separate file
  (bsc#911105 FATE#317501).
- drivers/net: enic: release rtnl_lock on error-path (bsc#911105
  FATE#317501).
- enic: be less verbose about non-critical firmware errors
  (bsc#911105 FATE#317501).
- enic: change sprintf() to snprintf() (bsc#911105 FATE#317501).
- drivers/net: fix up function prototypes after __dev* removals
  (bsc#911105 FATE#317501).
- enic: remove __dev* attributes (bsc#911105 FATE#317501).
- net: Remove bogus dependencies on INET (bsc#911105 FATE#317501).
- commit 2a46a0a
* Tue Feb 24 2015 lduncan@suse.com
- libceph: do not hard code max auth ticket len (FATE#318328
  bsc#917884).
- libceph: add process_one_ticket() helper (FATE#318328
  bsc#917884).
- libceph: gracefully handle large reply messages from the mon
  (FATE#318328 bsc#917884).
- libceph: take map_sem for read in handle_reply() (FATE#318328
  bsc#917884).
- libceph: factor out logic from ceph_osdc_start_request()
  (FATE#318328 bsc#917884).
- libceph: fix error handling in ceph_osdc_init() (FATE#318328
  bsc#917884).
- libceph: follow redirect replies from osds (FATE#318328
  bsc#917884).
- libceph: rename ceph_osd_request::r_{oloc,oid} to
  r_base_{oloc,oid} (FATE#318328 bsc#917884).
- libceph: follow {read,write}_tier fields on osd request
  submission (FATE#318328 bsc#917884).
- libceph: add ceph_pg_pool_by_id() (FATE#318328 bsc#917884).
- libceph: replace ceph_calc_ceph_pg() with ceph_oloc_oid_to_pg()
  (FATE#318328 bsc#917884).
- libceph: introduce and start using oid abstraction (FATE#318328
  bsc#917884).
- libceph: rename MAX_OBJ_NAME_SIZE to CEPH_MAX_OID_NAME_LEN
  (FATE#318328 bsc#917884).
- libceph: start using oloc abstraction (FATE#318328 bsc#917884).
- libceph: dout() is missing a newline (FATE#318328 bsc#917884).
- libceph: add ceph_kv{malloc,free}() and switch to them
  (FATE#318328 bsc#917884).
- libceph: fix preallocation check in get_reply() (FATE#318328
  bsc#917884).
- libceph: rename front to front_len in get_reply() (FATE#318328
  bsc#917884).
- libceph: rename ceph_msg::front_max to front_alloc_len
  (FATE#318328 bsc#917884).
- libceph: use CEPH_MON_PORT when the specified port is 0
  (FATE#318328 bsc#917884).
- crush: fix crush_choose_firstn comment (FATE#318328 bsc#917884).
- crush: attempts -> tries (FATE#318328 bsc#917884).
- crush: add set_choose_local_[fallback_]tries steps (FATE#318328
  bsc#917884).
- crush: generalize descend_once (FATE#318328 bsc#917884).
- crush: CHOOSE_LEAF -> CHOOSELEAF throughout (FATE#318328
  bsc#917884).
- crush: add SET_CHOOSE_TRIES rule step (FATE#318328 bsc#917884).
- crush: apply chooseleaf_tries to firstn mode too (FATE#318328
  bsc#917884).
- crush: new SET_CHOOSE_LEAF_TRIES command (FATE#318328
  bsc#917884).
- crush: pass parent r value for indep call (FATE#318328
  bsc#917884).
- crush: clarify numrep vs endpos (FATE#318328 bsc#917884).
- crush: strip firstn conditionals out of crush_choose, rename
  (FATE#318328 bsc#917884).
- crush: add note about r in recursive choose (FATE#318328
  bsc#917884).
- crush: use breadth-first search for indep mode (FATE#318328
  bsc#917884).
- crush: return CRUSH_ITEM_UNDEF for failed placements with indep
  (FATE#318328 bsc#917884).
- crush: eliminate CRUSH_MAX_SET result size limitation
  (FATE#318328 bsc#917884).
- crush: fix some comments (FATE#318328 bsc#917884).
- crush: reduce scope of some local variables (FATE#318328
  bsc#917884).
- crush: factor out (trivial) crush_destroy_rule() (FATE#318328
  bsc#917884).
- crush: pass weight vector size to map function (FATE#318328
  bsc#917884).
- libceph: update ceph_features.h (FATE#318328 bsc#917884).
- libceph: all features fields must be u64 (FATE#318328
  bsc#917884).
- rbd: tear down watch request if rbd_dev_device_setup() fails
  (FATE#318328 bsc#917884).
- rbd: introduce rbd_dev_header_unwatch_sync() and switch to it
  (FATE#318328 bsc#917884).
- rbd: enable extended devt in single-major mode (FATE#318328
  bsc#917884).
- rbd: add support for single-major device number allocation
  scheme (FATE#318328 bsc#917884).
- rbd: add 'minor' sysfs rbd device attribute (FATE#318328
  bsc#917884).
- rbd: switch to ida for rbd id assignments (FATE#318328
  bsc#917884).
- rbd: refactor rbd_init() a bit (FATE#318328 bsc#917884).
- rbd: tweak "loaded" message and module description (FATE#318328
  bsc#917884).
- rbd: rbd_device::dev_id is an int, format it as such
  (FATE#318328 bsc#917884).
- libceph: resend all writes after the osdmap loses the full flag
  (FATE#318328 bsc#917884).
- libceph: block I/O when PAUSE or FULL osd map flags are set
  (FATE#318328 bsc#917884).
- ceph: Add necessary clean up if invalid reply received in
  handle_reply() (FATE#318328 bsc#917884).
- net: 8021q/bluetooth/bridge/can/ceph: Remove extern from
  function prototypes (FATE#318328 bsc#917884).
- libceph: CEPH_OSD_FLAG_* enum update (FATE#318328 bsc#917884).
- libceph: create_singlethread_workqueue() doesn't return ERR_PTRs
  (FATE#318328 bsc#917884).
- libceph: call r_unsafe_callback when unsafe reply is received
  (FATE#318328 bsc#917884).
- libceph: fix safe completion (FATE#318328 bsc#917884).
- commit 092fe9b
* Tue Feb 24 2015 lduncan@suse.com
- Setting rbd and libceph as supported drivers (bsc#917884)
- commit f9c8689
* Mon Feb 23 2015 bp@suse.de
- x86, mm/ASLR: Fix stack randomization on 64-bit systems
  (bsc#917839, CVE-2015-1593).
- commit 12c730a
* Mon Feb 23 2015 mgorman@suse.de
- Refresh patches.arch/powerpc-fate317580-free_kmem.patch.
- commit 076929c
* Fri Feb 20 2015 jbohac@suse.cz
- IPoIB: Use a private hash table for path lookup in xmit path
  (bsc#907196).
- ipoib: Need to do dst_neigh_lookup_skb() outside of priv->lock
  (bsc#907196).
- ipoib: Convert over to dev_lookup_neigh_skb() (bsc#907196).
- infiniband: ipoib: Sanitize neighbour handling in ipoib_main.c
  (bsc#907196).
- commit 0932e14
* Tue Feb 17 2015 neilb@suse.de
- NFSv4: Fix another reboot recovery race (bnc#916982).
- commit 7283b0d
* Tue Feb 17 2015 neilb@suse.de
- don't do blind d_drop() in nfs_prime_dcache() (bnc#908069
  bnc#896484).
- nfs_prime_dcache needs fh to be set (bnc#908069 bnc#896484).
- commit 7c48bf0
* Tue Feb 17 2015 jroedel@suse.de
- Refresh
  patches.fixes/kvm-iommu-add-cond_resched-to-legacy-device-assignment-code.patch.
  Add upstream commit id and revision.
- commit de8924a
* Tue Feb 17 2015 bpoirier@suse.de
- be2net: avoid flashing SH-B0 UFI image on SH-P2 chip (bnc#908322
  FATE#317535).
- be2net: refactor code that checks flash file compatibility
  (bnc#908322 FATE#317535).
- commit 7d06ef2
* Mon Feb 16 2015 ptesarik@suse.cz
- Update
  patches.fixes/ipv6-fix-leaking-uninitialized-port-number-of-offender-sockaddr.patch
  (bsc#853040, CVE-2013-7263).
- commit 190dfda
* Mon Feb 16 2015 ptesarik@suse.cz
- Update
  patches.fixes/ipv6-fix-leaking-uninitialized-port-number-of-offender-sockaddr.patch
  (bsc#853040, CVE-2013-7263).
- commit 04cb79e
* Fri Feb 13 2015 lduncan@suse.com
- rbd: drop an unsafe assertion (FATE#318328 bsc#917884).
- rbd: Fix error recovery in rbd_obj_read_sync() (FATE#318328
  bsc#917884).
- rbd: use reference counts for image requests (FATE#318328
  bsc#917884).
- rbd: fix error paths in rbd_img_request_fill() (FATE#318328
  bsc#917884).
- block: replace strict_strtoul() with kstrtoul() (FATE#318328
  bsc#917884).
- rbd: fix error handling from rbd_snap_name() (FATE#318328
  bsc#917884).
- rbd: ignore unmapped snapshots that no longer exist (FATE#318328
  bsc#917884).
- rbd: fix use-after free of rbd_dev->disk (FATE#318328
  bsc#917884).
- rbd: make rbd_obj_notify_ack() synchronous (FATE#318328
  bsc#917884).
- rbd: complete notifies before cleaning up osd_client and rbd_dev
  (FATE#318328 bsc#917884).
- ceph: remove bogus extern (FATE#318328 bsc#917884).
- libceph: add function to ensure notifies are complete
  (FATE#318328 bsc#917884).
- rbd: fix null dereference in dout (FATE#318328 bsc#917884).
- rbd: fix buffer size for writes to images with snapshots
  (FATE#318328 bsc#917884).
- rbd: fix I/O error propagation for reads (FATE#318328
  bsc#917884).
- block: rbd: use NULL instead of 0 (FATE#318328 bsc#917884).
- rbd: fix a couple warnings (FATE#318328 bsc#917884).
- rbd: take a little credit (FATE#318328 bsc#917884).
- rbd: use rwsem to protect header updates (FATE#318328
  bsc#917884).
- rbd: don't hold ctl_mutex to get/put device (FATE#318328
  bsc#917884).
- rbd: protect against concurrent unmaps (FATE#318328 bsc#917884).
- rbd: set removing flag while holding list lock (FATE#318328
  bsc#917884).
- rbd: protect against duplicate client creation (FATE#318328
  bsc#917884).
- rbd: clean up a few things in the refresh path (FATE#318328
  bsc#917884).
- rbd: flush dcache after zeroing page data (FATE#318328
  bsc#917884).
- rbd: drop original request earlier for existence check
  (FATE#318328 bsc#917884).
- rbd: Use min_t() to fix comparison of distinct pointer types
  warning (FATE#318328 bsc#917884).
- rbd: send snapshot context with writes (FATE#318328 bsc#917884).
- rbd: fetch object order before using it (FATE#318328
  bsc#917884).
- rbd: use the correct length for format 2 object names
  (FATE#318328 bsc#917884).
- rbd: fix cleanup in rbd_add() (FATE#318328 bsc#917884).
- rbd: don't destroy ceph_opts in rbd_add() (FATE#318328
  bsc#917884).
- commit 55c70a5
* Fri Feb 13 2015 tiwai@suse.de
- mm/vmalloc.c: unbreak __vunmap() (bsc#916365).
- commit 226f003
* Fri Feb 13 2015 hare@suse.de
- Update patches.fixes/dm-optimize-use-SRCU-and-RCU.patch
  (bnc#917646).
- commit a35cadb
* Fri Feb 13 2015 hare@suse.de
- dm: optimize use SRCU and RCU (bnc#917701).
- commit 600a33a
* Thu Feb 12 2015 duwe@suse.de
- crypto: add missing crypto module aliases (bsc#914423).
- crypto: include crypto- module prefix in template (bsc#914423).
- crypto: prefix module autoloading with "crypto-" (bsc#914423).
- commit 65ff327
* Thu Feb 12 2015 duwe@suse.de
- crypto: add missing crypto module aliases (bsc#914423).
- crypto: include crypto- module prefix in template (bsc#914423).
- crypto: prefix module autoloading with "crypto-" (bsc#914423).
- commit 3f48ad8
* Thu Feb 12 2015 jroedel@suse.de
- x86: irq: Check for valid irq descriptor in
  check_irq_vectors_for_cpu_disable (bnc#914726).
- commit a32a321
* Thu Feb 12 2015 mkubecek@suse.cz
- netfilter: do not drop packet on insert collision (bnc#907611).
- commit eca4deb
* Thu Feb 12 2015 bpoirier@suse.de
- Refresh
  patches.drivers/ixgbe-0016-ixgbe-Implement-PCI-SR-IOV-sysfs-callback-operation.patch.
- commit 2151539
* Thu Feb 12 2015 hare@suse.de
- supported.conf: mark nvme as supported (bsc#916936)
- commit 7117881
* Thu Feb 12 2015 bpoirier@suse.de
- ixgbevf: remove useless bd_number from struct ixgbevf_adapter
  (bug#909488 FATE#317387).
- ixgbevf: Resolve missing-field-initializers warnings (bug#909488
  FATE#317387).
- ixgbevf: introduce delay for checking VFLINKS on 82599
  (bug#909488 FATE#317387).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bug#909488
  FATE#317387).
- ixgbevf: Remove unused get_supported_physical_layer pointer
  (bug#909488 FATE#317387).
- net: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate
  (bug#909488 FATE#317387).
- net: get rid of SET_ETHTOOL_OPS (bug#909488 FATE#317387).
- ixgbevf: remove 82599 from the module description (bug#909488
  FATE#317387).
- ixgbevf: remove open-coded skb_cow_head (bug#909488
  FATE#317387).
- ixgbevf: Add bit to mark work queue initialization (bug#909488
  FATE#317387).
- ixgbevf: Fix rcu warnings induced by LER (bug#909488
  FATE#317387).
- ixgbevf: Change ixgbe_read_reg to ixgbevf_read_reg (bug#909488
  FATE#317387).
- ixgbevf: Additional adapter removal checks (bug#909488
  FATE#317387).
- ixgbevf: Check for adapter removal on register writes
  (bug#909488 FATE#317387).
- ixgbevf: Check register reads for adapter removal (bug#909488
  FATE#317387).
- ixgbevf: Make the ethtool register test use accessors
  (bug#909488 FATE#317387).
- ixgbevf: Use static inlines instead of macros (bug#909488
  FATE#317387).
- ixgbevf: Convert uses of __constant_<foo> to <foo> (bug#909488
  FATE#317387).
- ixgbevf: Protect ixgbevf_down with __IXGBEVF_DOWN bit
  (bug#909488 FATE#317387).
- ixgbevf: Indicate removal state explicitly (bug#909488
  FATE#317387).
- net: Replace u64_stats_fetch_begin_bh to
  u64_stats_fetch_begin_irq (bug#909488 FATE#317387).
- ixgbevf: delete unneeded call to pci_set_power_state (bug#909488
  FATE#317387).
- ixgbevf: fix skb->pkt_type checks (bug#909488 FATE#317387).
- ixgbevf: add check for CHECKSUM_PARTIAL when doing TSO
  (bug#909488 FATE#317387).
- ixgbevf: fix handling of tx checksumming (bug#909488
  FATE#317387).
- ixgbevf: Use pci_enable_msix_range() instead of
  pci_enable_msix() (bug#909488 FATE#317387).
- ixgbevf: merge ixgbevf_tx_map and ixgbevf_tx_queue into a
  single function (bug#909488 FATE#317387).
- ixgbevf: redo dma mapping using the tx buffer info (bug#909488
  FATE#317387).
- ixgbevf: make the first tx_buffer a repository for most of
  the skb info (bug#909488 FATE#317387).
- ixgbevf: add tx counters (bug#909488 FATE#317387).
- ixgbevf: remove counters for Tx/Rx checksum offload (bug#909488
  FATE#317387).
- ixgbevf: move ring specific stats into ring specific structure
  (bug#909488 FATE#317387).
- ixgbevf: make use of the dev pointer in the ixgbevf_ring struct
  (bug#909488 FATE#317387).
- ixgbevf: bump version (bug#909488 FATE#317387).
- ixgbevf: create function for all of ring init (bug#909488
  FATE#317387).
- ixgbevf: Convert ring storage form pointer to an array to
  array of pointers (bug#909488 FATE#317387).
- ixgbevf: use pci drvdata correctly in ixgbevf_suspend()
  (bug#909488 FATE#317387).
- ixgbevf: set the disable state when ixgbevf_qv_disable is called
  (bug#909488 FATE#317387).
- ixgbevf: add DCB configuration into queue setup (bug#909488
  FATE#317387).
- ixgbe: Focus config of head, tail ntc, and ntu all into a
  single function (bug#909488 FATE#317387).
- ixgbe: cleanup IXGBE_DESC_UNUSED (bug#909488 FATE#317387).
- ixgbevf: remove redundant workaround (bug#909488 FATE#317387).
- ixgbevf: Add zero_base handler to network statistics (bug#909488
  FATE#317387).
- ixgbevf: add BP_EXTENDED_STATS for CONFIG_NET_RX_BUSY_POLL
  (bug#909488 FATE#317387).
- ixgbevf: implement CONFIG_NET_RX_BUSY_POLL (bug#909488
  FATE#317387).
- ixgbevf: have clean_rx_irq return total_rx_packets cleaned
  (bug#909488 FATE#317387).
- ixgbevf: add ixgbevf_rx_skb (bug#909488 FATE#317387).
- ixgbevf: bump driver version (bug#909488 FATE#317387).
- ixgbevf: implement ethtool get/set coalesce (bug#909488
  FATE#317387).
- ixgbevf: Adds function to set PSRTYPE register (bug#909488
  FATE#317387).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN
  (bug#909488 FATE#317387).
- ixgbevf: move API neg to reset path (bug#909488 FATE#317387).
- ixgbevf: add wait for Rx queue disable (bug#909488 FATE#317387).
- ixgbevf: cleanup redundant mailbox read failure check
  (bug#909488 FATE#317387).
- ixgbevf: do not print registers to dmesg in ixgbevf_get_regs
  (bug#909488 FATE#317387).
- intel: Remove extern from function prototypes (bug#909488
  FATE#317387).
- DMA-API: net: intel/ixgbevf: fix 32-bit DMA mask handling
  (bug#909488 FATE#317387).
- drivers/net: Convert uses of compare_ether_addr to
  ether_addr_equal (bug#909488 FATE#317387).
- ixgbevf: Adjust to handle unassigned MAC address from PF
  (bug#909488 FATE#317387).
- ixgbevf: don't release the soft entries (bug#909488
  FATE#317387).
- drivers:net: Remove dma_alloc_coherent OOM messages (bug#909488
  FATE#317387).
- ixgbevf: use PCI_DEVICE_TABLE macro (bug#909488 FATE#317387).
- ixgbevf: Make next_to_watch a pointer and adjust memory barriers
  to avoid races (bug#909488 FATE#317387).
- ixgbevf: Make sure link status and speed are fetched (bug#909488
  FATE#317387).
- ixgbevf: Fix link speed message to support 100Mbps (bug#909488
  FATE#317387).
- ixgbevf: Fix statistics corruption (bug#909488 FATE#317387).
- ixgbevf: Fix link up messages (bug#909488 FATE#317387).
- ixgbevf: Synch out of tree and in tree mailbox interrupt
  handlers (bug#909488 FATE#317387).
- remove init of dev->perm_addr in drivers (bug#909488
  FATE#317387).
- net: Check for presence of IFLA_AF_SPEC (bug#908398
  FATE#317382).
- net: Validate IFLA_BRIDGE_MODE attribute length (bug#908398
  FATE#317382).
- ixgbe: fix use after free adapter->state test in
  ixgbe_remove/ixgbe_probe (bug#908398 FATE#317382).
- ixgbe: Correctly disable VLAN filter in promiscuous mode
  (bug#908398 FATE#317382).
- ixgbe: phy: fix uninitialized status in ixgbe_setup_phy_link_tnx
  (bug#908398 FATE#317382).
- ixgbe: fix race when setting advertised speed (bug#908398
  FATE#317382).
- ixgbe: check for vfs outside of sriov_num_vfs before dereference
  (bug#908398 FATE#317382).
- ixgbe: fix race accessing page->_count (bug#908398 FATE#317382).
- ixgbe: fix setting of TXDCTL.WTRHESH when ITR is set to 0 and
  no BQL (bug#908398 FATE#317382).
- ixgbe: remove wait loop on autoneg for copper devices
  (bug#908398 FATE#317382).
- ixgbe: Convert the normal transmit complete path to
  dev_consume_skb_any() (bug#908398 FATE#317382).
- ixgbe: remove IXGBE_FLAG_MSI(X)_CAPABLE flags (bug#908398
  FATE#317382).
- ixgbe: add warnings for other disabled features without MSI-X
  support (bug#908398 FATE#317382).
- ixgbe: use e_dev_warn instead of netif_printk (bug#908398
  FATE#317382).
- ixgbe: use e_dev_warn instead of e_err for displaying warning
  (bug#908398 FATE#317382).
- ixgbe: determine vector count inside ixgbe_acquire_msix_vectors
  (bug#908398 FATE#317382).
- ixgbe: move msix_entries allocation into
  ixgbe_acquire_msix_vectors (bug#908398 FATE#317382).
- ixgbe: return integer from ixgbe_acquire_msix_vectors
  (bug#908398 FATE#317382).
- ixgbe: use e_dev_warn instead of netif_printk (bug#908398
  FATE#317382).
- ixgbe: Do not schedule an uninitialized workqueue entry
  (bug#908398 FATE#317382).
- ixgbe: remove useless bd_number from adapter struct (bug#908398
  FATE#317382).
- ixgbe: Drop Rx alloc at end of Rx cleanup (bug#908398
  FATE#317382).
- ixgbe: Resolve warnings produced in W=2 builds (bug#908398
  FATE#317382).
- ixgbe: add comment noting recalculation of queues (bug#908398
  FATE#317382).
- ixgbe: reset interface on link loss with pending Tx work from
  the VF (bug#908398 FATE#317382).
- ixgbe: Cleanup FDB handling code (bug#908398 FATE#317382).
- ixgbe: flush when in xmit_more mode and under descriptor
  pressure (bug#908398 FATE#317382).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bug#908398
  FATE#317382).
- ixgbe: Make return values more direct (bug#908398 FATE#317382).
- ixgbe: Delete a bunch of dead code (bug#908398 FATE#317382).
- ixgbe: Fix ixgbe_write_mbx error result (bug#908398
  FATE#317382).
- ixgbe: Correct X540 semaphore error (bug#908398 FATE#317382).
- ixgbe: Fix spurious release of semaphore in EEPROM access
  (bug#908398 FATE#317382).
- ixgbe: Convert some udelays to usleep_range (bug#908398
  FATE#317382).
- ixgbe: don't check minimum link when direct assigned to virtual
  machine (bug#908398 FATE#317382).
- ixgbe: fix use of list_for_each in ixgbe_enumerate_functions
  (bug#908398 FATE#317382).
- ixgbe: Change some uses of strncpy to strlcpy (bug#908398
  FATE#317382).
- ixgbe: Fix possible null-dereference in error path (bug#908398
  FATE#317382).
- ixgbe: remove unnecessary break after return (bug#908398
  FATE#317382).
- ixgbe: remove unnecessary break after goto (bug#908398
  FATE#317382).
- ixgbe: change PTP NSECS_PER_SEC to IXGBE_PTP_PPS_HALF_SECOND
  (bug#908398 FATE#317382).
- net: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate
  (bug#908398 FATE#317382).
- ixgbe: fix detection of SFP+ capable interfaces (bug#908398
  FATE#317382).
- ixgbe: avoid duplicate code in suspend and stop paths
  (bug#908398 FATE#317382).
- ixgbe: separate the PTP suspend and stop actions (bug#908398
  FATE#317382).
- ixgbe: extract PTP clock device from ptp_init (bug#908398
  FATE#317382).
- ixgbe: allow ixgbe_ptp_reset to maintain current hwtstamp config
  (bug#908398 FATE#317382).
- ixgbe: extract the hardware setup from the
  ixgbe_ptp_set_ts_config (bug#908398 FATE#317382).
- ixgbe: rename ixgbe_ptp_enable to ixgbe_ptp_feature_enable
  (bug#908398 FATE#317382).
- ixgbe: fix linking at 100Mbps on copper devices with MNG FW
  enabled (bug#908398 FATE#317382).
- igb/ixgbe: remove return statements for void functions
  (bug#908398 FATE#317382).
- ixgbe: add /* fallthrough */ comment to case statements
  (bug#908398 FATE#317382).
- ixgbe: add space between operands to & (bug#908398 FATE#317382).
- ixgbe: don't check NULL for debugfs_remove_recursive (bug#908398
  FATE#317382).
- ixgbe: add braces around else block (bug#908398 FATE#317382).
- ixgbe: fix several concatenated strings to single line
  (bug#908398 FATE#317382).
- ixgbe: fix checkpatch style of blank line after declaration
  (bug#908398 FATE#317382).
- ixgbe: fix function-like macro, remove semicolon (bug#908398
  FATE#317382).
- ixgbe: clean up checkpatch warnings about CODE_INDENT and
  LEADING_SPACE (bug#908398 FATE#317382).
- net: get rid of SET_ETHTOOL_OPS (bug#908398 FATE#317382).
- ixgbe: improve mac filter handling (bug#908398 FATE#317382).
- ixgbe: change handling of multicast filters (bug#908398
  FATE#317382).
- ixgbe: remove vlan_filter_disable and enable functions
  (bug#908398 FATE#317382).
- ixgbe: Use out-of-line function for register reads (bug#908398
  FATE#317382).
- ixgbe: convert low_water into an array (bug#908398 FATE#317382).
- e1000e/igb/ixgbe/i40e: fix message terminations (bug#908398
  FATE#317382).
- ixgbe: clean up Rx time stamping code (bug#908398 FATE#317382).
- ixgbe: remove open-coded skb_cow_head (bug#908398 FATE#317382).
- ixgbe: Add bit to mark service task initialization (bug#908398
  FATE#317382).
- ixgbe: Fix rcu warnings induced by LER (bug#908398 FATE#317382).
- ixgbe: fix ixgbe_check_reset_blocked() declaration (bug#908398
  FATE#317382).
- ixgbe: fix race conditions on queuing skb for HW time stamp
  (bug#908398 FATE#317382).
- ixgbe: never generate both software and hardware timestamps
  (bug#908398 FATE#317382).
- ixgbe: remove redundant if clause from PTP work (bug#908398
  FATE#317382).
- ixgbe: Break recursion in case of removal (bug#908398
  FATE#317382).
- ixgbe: enable tx queues after link up (bug#908398 FATE#317382).
- ixgbe: Stop cacheing if the MNG FW enabled (bug#908398
  FATE#317382).
- ixgbe: clean up ixgbe_atr_compute_perfect_hash_82599 (bug#908398
  FATE#317382).
- ixgbe: use ixgbe_read_pci_cfg_word (bug#908398 FATE#317382).
- ixgbe: remove unused media type (bug#908398 FATE#317382).
- ixgbe: fix ixgbe_setup_mac_link_82599 autoc variables
  (bug#908398 FATE#317382).
- ixgbe: fix ixgbe_stop_mac_link_on_d3_82599 to check mng
  correctly (bug#908398 FATE#317382).
- ixgbe: check Core Clock Disable bit (bug#908398 FATE#317382).
- ixgbe: fix errors related to protected AUTOC calls (bug#908398
  FATE#317382).
- ixgbe: Convert uses of __constant_<foo> to <foo> (bug#908398
  FATE#317382).
- ixgbe: add ixgbe_write_pci_cfg_word with ixgbe_removed check
  (bug#908398 FATE#317382).
- ixgbe: Don't receive packets when the napi budget == 0
  (bug#908398 FATE#317382).
- net: Replace u64_stats_fetch_begin_bh to
  u64_stats_fetch_begin_irq (bug#908398 FATE#317382).
- ixgbe: fix some multiline hw_dbg prints (bug#908398
  FATE#317382).
- ixgbe: fixup header for ixgbe_set_rxpba_82598 (bug#908398
  FATE#317382).
- ixgbe: add Linux NICS mailing list to contact info (bug#908398
  FATE#317382).
- ixgbe: move setting rx_pb_size into get_invariants (bug#908398
  FATE#317382).
- ixgbe: Fix format string in ixgbe_fcoe.c (bug#908398
  FATE#317382).
- net: ixgbe calls skb_set_hash (bug#908398 FATE#317382).
- ixgbe: implement SIOCGHWTSTAMP ioctl (bug#908398 FATE#317382).
- ixgbe: Check config reads for removal (bug#908398 FATE#317382).
- ixgbe: Fix up some ethtool results when adapter is removed
  (bug#908398 FATE#317382).
- ixgbe: Restore hw_addr in LER recovery paths (bug#908398
  FATE#317382).
- ixgbe: Add check for FW veto bit (bug#908398 FATE#317382).
- ixgbe: fix bit toggled for 82599 reset fix (bug#908398
  FATE#317382).
- ixgbe: collect all 82599 AUTOC code in one function (bug#908398
  FATE#317382).
- ixgbe: fix to use correct timeout interval for memory read
  completion (bug#908398 FATE#317382).
- ixgbe: Add WoL support for a new device (bug#908398
  FATE#317382).
- ixgbe: don't use magic size number to assign ptp_caps.name
  (bug#908398 FATE#317382).
- ixgbe: modify behavior on receiving a HW ECC error (bug#908398
  FATE#317382).
- ixgbe: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bug#908398 FATE#317382).
- ixgbe: bump version number (bug#908398 FATE#317382).
- ixgbe: set driver_max_VFs should be done before enabling SRIOV
  (bug#908398 FATE#317382).
- ixgbe: define IXGBE_MAX_VFS_DRV_LIMIT macro and cleanup const 63
  (bug#908398 FATE#317382).
- ixgbe: Fix incorrect logic for fixed fiber eeprom write
  (bug#908398 FATE#317382).
- ixgbe: reinit_locked() should be called with rtnl_lock
  (bug#908398 FATE#317382).
- ixgbe: Clear head write-back registers on VF reset (bug#908398
  FATE#317382).
- ixgbe: Force QDE via PFQDE for VFs during reset (bug#908398
  FATE#317382).
- ixgbe: Additional adapter removal checks (bug#908398
  FATE#317382).
- ixgbe: Check for adapter removal on register writes (bug#908398
  FATE#317382).
- ixgbe: Check register reads for adapter removal (bug#908398
  FATE#317382).
- ixgbe: Make ethtool register test use accessors (bug#908398
  FATE#317382).
- ixgbe: Use static inlines instead of macros (bug#908398
  FATE#317382).
- ixbge: Protect ixgbe_down with __IXGBE_DOWN bit (bug#908398
  FATE#317382).
- ixgbe: Indicate removal state explicitly (bug#908398
  FATE#317382).
- net: ixgbe: slight optimization of addr compare (bug#908398
  FATE#317382).
- ixgbe: fix for unused variable warning with certain config
  (bug#908398 FATE#317382).
- ixgbe: Start temperature sensor attribute index with 1
  (bug#908398 FATE#317382).
- ixgbe: Make ixgbe_identify_qsfp_module_generic static
  (bug#908398 FATE#317382).
- ixgbe: add warning when max_vfs is out of range (bug#908398
  FATE#317382).
- net: Explicitly initialize u64_stats_sync structures for lockdep
  (bug#908398 FATE#317382).
- ixgbe: fix inconsistent clearing of the multicast table
  (bug#908398 FATE#317382).
- ixgbe: Reduce memory consumption with larger page sizes
  (bug#908398 FATE#317382).
- ixgbe: remove unnecessary duplication of PCIe bandwidth display
  (bug#908398 FATE#317382).
- ixgbe: show <2%% for encoding loss on PCIe Gen3 (bug#908398
  FATE#317382).
- ixgbe: fix rx-usecs range checks for BQL (bug#908398
  FATE#317382).
- ixgbe: use pcie_capability_read_word() to simplify code
  (bug#908398 FATE#317382).
- ixgbe: cleanup ixgbe_enumerate_functions (bug#908398
  FATE#317382).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN
  (bug#908398 FATE#317382).
- ixgbe: Cleanup the use of tabs and spaces (bug#908398
  FATE#317382).
- ixgbe: ethtool DCB registers dump for 82599 and x540 (bug#908398
  FATE#317382).
- intel: Remove extern from function prototypes (bug#908398
  FATE#317382).
- DMA-API: net: intel/ixgbe: fix 32-bit DMA mask handling
  (bug#908398 FATE#317382).
- ixgbe: fix ethtool reporting of supported links for SFP modules
  (bug#908398 FATE#317382).
- ixgbe: limit setting speed to only one at a time for QSFP
  modules (bug#908398 FATE#317382).
- ixgbe: fix ethtool loopback diagnostic with DCB enabled
  (bug#908398 FATE#317382).
- ixgbe: fully disable hardware RSC logic when disabling RSC
  (bug#908398 FATE#317382).
- ixgbe: add support for older QSFP active DA cables (bug#908398
  FATE#317382).
- ixgbe: include QSFP PHY types in ixgbe_is_sfp() (bug#908398
  FATE#317382).
- ixgbe: add 1Gbps support for QSFP+ (bug#908398 FATE#317382).
- ixgbe: cleanup some log messages (bug#908398 FATE#317382).
- ixgbe: zero out mailbox buffer on init (bug#908398 FATE#317382).
- ixgbe: fix link test when connected to 1Gbps link partner
  (bug#908398 FATE#317382).
- ixgbe: fix incorrect limit value in ring transverse (bug#908398
  FATE#317382).
- ixgbe: Check return value on eeprom reads (bug#908398
  FATE#317382).
- ixgbe: disable link when adapter goes down (bug#908398
  FATE#317382).
- ixgbe: add support for quad-port x520 adapter (bug#908398
  FATE#317382).
- ixgbe: clear semaphore bits on timeouts (bug#908398
  FATE#317382).
- ixgbe: fix lockdep annotation issue for ptp's work item
  (bug#908398 FATE#317382).
- ixgbe: call pcie_get_mimimum_link to check if device has enough
  bandwidth (bug#908398 FATE#317382).
- PCI: Add function to obtain minimum link width and speed
  (bug#908398 FATE#317382).
- PCI: move enum pcie_link_width into pci.h (bug#908398
  FATE#317382).
- PCI: expose pcie_link_speed and pcix_bus_speed arrays
  (bug#908398 FATE#317382).
- ixgbe: fix semaphore lock for I2C read/writes on 82598
  (bug#908398 FATE#317382).
- ixgbe: bump version number (bug#908398 FATE#317382).
- ixgbe: add new media type (bug#908398 FATE#317382).
- ixgbe: fix fc autoneg ethtool reporting (bug#908398
  FATE#317382).
- ixgbe: Use pci_vfs_assigned instead of ixgbe_vfs_are_assigned
  (bug#908398 FATE#317382).
- ixgbe: Retain VLAN filtering in promiscuous + VT mode
  (bug#908398 FATE#317382).
- ixgbe: Fix Tx Hang issue with lldpad on 82598EB (bug#908398
  FATE#317382).
- IXGBE: Set the SW prio_tc values at initialization to the HW
  setting (bug#908398 FATE#317382).
- ixgbe: add mac type to the version in ethtool_regs (bug#908398
  FATE#317382).
- ixgbe: add support for disabling link at boot time on 82599
  (bug#908398 FATE#317382).
- ixgbe: cache AUTOC reads (bug#908398 FATE#317382).
- ixgbe: fix register access during ethtool loopback test
  (bug#908398 FATE#317382).
- ixgbe: fix EICR write in ixgbe_msix_other (bug#908398
  FATE#317382).
- ixgbe: add WOL support for new subdevice ID (bug#908398
  FATE#317382).
- ixgbe: add SFP+ LX module support (bug#908398 FATE#317382).
- ixgbe: rename wol_supported to more fitting wol_enabled
  (bug#908398 FATE#317382).
- ixgbe: add driver support for x520 OCP adapter (bug#908398
  FATE#317382).
- ixgbe: fix possible divide by zero in ixgbe_update_itr
  (bug#908398 FATE#317382).
- ixgbe: Remove unnecessary #ifdef CONFIG_DEBUG_FS tests
  (bug#908398 FATE#317382).
- ixgbe: Add support for WoL on 82599 SFP+ LOM (bug#908398
  FATE#317382).
- ixgbe: in shutdown, do netif_running() under rtnl_lock
  (bug#908398 FATE#317382).
- ixgbe: Fix a bug in setting VF VLAN via PF (bug#908398
  FATE#317382).
- ixgbe: bump version number (bug#908398 FATE#317382).
- ixgbe: Fix 1G link WoL (bug#908398 FATE#317382).
- ixgbe: fix MNG FW support when adapter not up (bug#908398
  FATE#317382).
- ixgbe: enable devices with internal switch to read pci parent
  (bug#908398 FATE#317382).
- ixgbe: create conversion functions from link_status to bus/speed
  (bug#908398 FATE#317382).
- ixgbe: Enable support for recognizing PCI-e Gen3 link speed
  (bug#908398 FATE#317382).
- ixgbe: Drop check for PAGE_SIZE from ixgbe_xmit_frame_ring
  (bug#908398 FATE#317382).
- ixgbe: don't do arithmetic operations on bitmasks (bug#908398
  FATE#317382).
- ixgbe: Mask off check of frag_off as we only want fragment
  offset (bug#908398 FATE#317382).
- ixgbe: fix registration order of driver and DCA nofitication
  (bug#908398 FATE#317382).
- ixgbe: Don't give VFs random MAC addresses (bug#908398
  FATE#317382).
- ixgbe: Make use of the default fdb handlers (bug#908398
  FATE#317382).
- net: generic fdb support for drivers without ndo_fdb_<op>
  (bug#908398 FATE#317382).
- ixgbe: Update DESC_NEEDED define to adjust for changes to
  MAX_SKB_FRAGS (bug#908398 FATE#317382).
- ixgbe: fix Tx timeouts with BQL (bug#908398 FATE#317382).
- ixgbe: cleanup error checking in
  ixgbe_identify_sfp_module_generic() (bug#908398 FATE#317382).
- ixgbe: fix possible data corruption in read_i2c_byte (bug#908398
  FATE#317382).
- ixgbe: Add support for set_channels ethtool operation
  (bug#908398 FATE#317382).
- ixgbe: Add support for displaying the number of Tx/Rx channels
  (bug#908398 FATE#317382).
- ixgbe: Make ixgbe_setup_tc usable even when DCB is not enabled
  (bug#908398 FATE#317382).
- ixgbe: Update ixgbe driver to use __netdev_pick_tx in
  ixgbe_select_queue (bug#908398 FATE#317382).
- net: Export __netdev_pick_tx so that it can be used in modules
  (bug#908398 FATE#317382).
- net: Split core bits of netdev_pick_tx into __netdev_pick_tx
  (bug#908398 FATE#317382).
- ixgbe: Add function for setting XPS queue mapping (bug#908398
  FATE#317382).
- ixgbe: Define FCoE and Flow director limits much sooner to
  allow for changes (bug#908398 FATE#317382).
- ixgbe: refactor initialization of feature flags (bug#908398
  FATE#317382).
- ixgbe: Only set gso_type to SKB_GSO_TCPV4 as RSC does not
  support IPv6 (bug#908398 FATE#317382).
- ixgbe: fix gso type (bug#908398 FATE#317382).
- drivers: net: Remove remaining alloc/OOM messages (bug#908398
  FATE#317382).
- ixgbe: Fix SR-IOV MTU warning (bug#908398 FATE#317382).
- ixgbe: Replace rmb in Tx cleanup with read_barrier_depends
  (bug#908398 FATE#317382).
- ixgbe: update date to 2013 (bug#908398 FATE#317382).
- ixgbe: fix return values and memcpy parameters to eliminate
  Smatch warnings (bug#908398 FATE#317382).
- ixgbe: fix potential null dereference (bug#908398 FATE#317382).
- ixgbe: allow reading of SFF-8472 data over i2c (bug#908398
  FATE#317382).
- ixgbe: autoneg variable refactoring (bug#908398 FATE#317382).
- ixgbe: removed unused variable from setup_link_speed (bug#908398
  FATE#317382).
- ixgbe: rename autoneg variables (bug#908398 FATE#317382).
- ixgbe: Fix device ref count bug (bug#908398 FATE#317382).
- ixgbe: Reset the NIC if up2tc has changed (bug#908398
  FATE#317382).
- ixgbe: Limit number of reported VFs to device specific value
  (bug#908398 FATE#317382).
- ixgbe: Implement PCI SR-IOV sysfs callback operation (bug#908398
  FATE#317382).
- ixgbe: Modularize SR-IOV enablement code (bug#908398
  FATE#317382).
- ixgbe: Make mailbox ops initialization unconditional (bug#908398
  FATE#317382).
- ixgbe: Inline Rx PTP descriptor handling (bug#908398
  FATE#317382).
- ixgbe: add warning when scheduling reset (bug#908398
  FATE#317382).
- ixgbe: Add ptp work item to poll for the Tx timestamp
  (bug#908398 FATE#317382).
- ixgbe: Use watchdog check in favor of BPF for detecting latched
  timestamp (bug#908398 FATE#317382).
- ixgbe: Update ptp_overflow check comment and jiffies (bug#908398
  FATE#317382).
- ixgbe: add missing supported filters to get_ts_info (bug#908398
  FATE#317382).
- ixgbe: ethtool ixgbe_diag_test cleanup (bug#908398 FATE#317382).
- ixgbe: Improve performance and reduce size of ixgbe_tx_map
  (bug#908398 FATE#317382).
- ixgbe: Update ixgbe Tx flags to improve code efficiency
  (bug#908398 FATE#317382).
- ixgbe: Always use context 0, even for FCoE and TSO (bug#908398
  FATE#317382).
- ixgbe: Make TSO check for CHECKSUM_PARTIAL to avoid skb_is_gso
  check (bug#908398 FATE#317382).
- ixgbe: SR-IOV: dynamic IEEE DCBx default priority changes
  (bug#908398 FATE#317382).
- remove init of dev->perm_addr in drivers (bug#908398
  FATE#317382).
- commit 4331983
* Thu Feb 12 2015 jjolly@suse.de
- dasd: Missing partition after online processing (bnc#917121,
  LTC#120565).
- commit c97d874
* Mon Feb  9 2015 jjolly@suse.de
- IB/qib: Correct reference counting in debugfs qp_stats
  (bnc#904858).
- IB/qib: Fix port in pkey change event (bnc#904858).
- IB/qib: Fix memory leak of recv context when driver fails to
  initialize (bnc#904858).
- IB/qib: Add qp_stats debug file (bnc#904858).
- IB/qib: Add per-context stats interface (bnc#904858).
- IB/qib: Modify software pma counters to use percpu variables
  (bnc#904858).
- IB/qib: Remove ib_sg_dma_address() and ib_sg_dma_len() overloads
  (bnc#904858).
- IB/qib: Fix debugfs ordering issue with multiple HCAs
  (bnc#904858).
- IB/qib: Add percpu counter replacing qib_devdata int_counter
  (bnc#904858).
- IB/qib: Fix potential buffer overrun in sending diag packet
  routine (bnc#904858).
- IB/qib: Add missing serdes init sequence (bnc#904858).
- IB/qib: Fix txselect regression (bnc#904858).
- IB/qib: Fix QP check when looping back to/from QP1 (bnc#904858).
- IB/qib: Fix checkpatch __packed warnings (bnc#904858).
- IB/qib: Convert qib_user_sdma_pin_pages() to use
  get_user_pages_fast() (bnc#904858).
- IB/qib: Improve SDMA performance (bnc#904858).
- IB/qib: Convert opcode counters to per-context (bnc#904858).
- IB/qib: Add optional NUMA affinity (bnc#904858).
- commit 151310b
* Mon Feb  9 2015 mszeredi@suse.cz
- splice: add generic_write_checks() (bnc#915322 CVE-2014-7822).
- commit c1d91c3
* Sat Feb  7 2015 bp@suse.de
- x86_64, switch_to(): Load TLS descriptors before switching DS
  and ES (bsc#911326, CVE-2014-9419).
- commit 9cf4cf7
* Fri Feb  6 2015 mszeredi@suse.cz
- fuse: clear FUSE_I_CTIME_DIRTY flag on setattr (FATE#317677).
- fuse: trust kernel i_ctime only (FATE#317677).
- fuse: remove .update_time (FATE#317677).
- fuse: allow ctime flushing to userspace (FATE#317677).
- fuse: fuse: add time_gran to INIT_OUT (FATE#317677).
- fuse: add .write_inode (FATE#317677).
- fuse: clean up fsync (FATE#317677).
- fuse: update mtime on open(O_TRUNC) in atomic_o_trunc mode
  (FATE#317677).
- fuse: update mtime on truncate(2) (FATE#317677).
- fuse: do not use uninitialized i_mode (FATE#317677).
- fuse: fix mtime update error in fsync (FATE#317677).
- fuse: Turn writeback cache on (FATE#317677).
- fuse: Fix O_DIRECT operations vs cached writeback misorder
  (FATE#317677).
- fuse: fuse_flush() should wait on writeback (FATE#317677).
- fuse: Implement write_begin/write_end callbacks (FATE#317677).
- fuse: restructure fuse_readpage() (FATE#317677).
- fuse: Flush files on wb close (FATE#317677).
- fuse: Trust kernel i_mtime only (FATE#317677).
- fuse: Trust kernel i_size only (FATE#317677).
- fuse: Connection bit for enabling writeback (FATE#317677).
- fuse: Prepare to handle short reads (FATE#317677).
- fuse: Linking file to inode helper (FATE#317677).
- fuse: don't invalidate attrs when not using atime (FATE#317677).
- fuse: writepages: protect secondary requests from fuse file
  release (FATE#317677).
- fuse: writepages: update bdi writeout when deleting secondary
  request (FATE#317677).
- fuse: writepages: crop secondary requests (FATE#317677).
- fuse: writepages: roll back changes if request not found
  (FATE#317677).
- fuse: writepage: skip already in flight (FATE#317677).
- fuse: writepages: handle same page rewrites (FATE#317677).
- fuse: writepages: fix aggregation (FATE#317677).
- fuse: fix race in fuse_writepages() (FATE#317677).
- fuse: Implement writepages callback (FATE#317677).
- fuse: don't BUG on no write file (FATE#317677).
- fuse: lock page in mkwrite (FATE#317677).
- fuse: Prepare to handle multiple pages in writeback
  (FATE#317677).
- fuse: Getting file for writeback helper (FATE#317677).
- fuse: hotfix truncate_pagecache() issue (FATE#317677).
- fuse: fix alignment in short read optimization for async_dio
  (FATE#317677).
- fuse: return -EIOCBQUEUED from fuse_direct_IO() for all async
  requests (FATE#317677).
- fuse: allocate for_background dio requests based on io->async
  state (FATE#317677).
- fuse: add flag to turn on async direct IO (FATE#317677).
- fuse: truncate file if async dio failed (FATE#317677).
- fuse: optimize short direct reads (FATE#317677).
- fuse: enable asynchronous processing direct IO (FATE#317677).
- fuse: make fuse_direct_io() aware about AIO (FATE#317677).
- fuse: add support of async IO (FATE#317677).
- fuse: move fuse_release_user_pages() up (FATE#317677).
- fuse: optimize wake_up (FATE#317677).
- fuse: implement exclusive wakeup for blocked_waitq
  (FATE#317677).
- fuse: skip blocking on allocations of synchronous requests
  (FATE#317677).
- fuse: add flag fc->initialized (FATE#317677).
- fuse: make request allocations for background processing
  explicit (FATE#317677).
- fuse: cleanup fuse_direct_io() (FATE#317677).
- fuse: optimize __fuse_direct_io() (FATE#317677).
- fuse: optimize fuse_get_user_pages() (FATE#317677).
- fuse: pass iov to fuse_get_user_pages() (FATE#317677).
- fuse: use req->page_descs for argpages cases (FATE#317677).
- fuse: add per-page descriptor <offset, length> to fuse_req
  (FATE#317677).
- fuse: rework fuse_do_ioctl() (FATE#317677).
- fuse: rework fuse_perform_write() (FATE#317677).
- fuse: rework fuse_readpages() (FATE#317677).
- fuse: rework fuse_retrieve() (FATE#317677).
- fuse: categorize fuse_get_req() (FATE#317677).
- fuse: general infrastructure for pages of variable size
  (FATE#317677).
- fuse: fix blksize calculation (FATE#317677).
- fuse: fix nlink after unlink (FATE#317677).
- fuse: O_DIRECT support for files (FATE#317677).
- fuse: delete dead .write_begin and .write_end aops
  (FATE#317677).
- mm: minor cleanup of iov_iter_single_seg_count() (FATE#317677).
- mm/page-writeback.c: add strictlimit feature (FATE#317677).
- commit 30f2845
* Fri Feb  6 2015 jslaby@suse.cz
- kABI: protect console include in consolemap.
- commit c0003a1
* Fri Feb  6 2015 jslaby@suse.cz
- vt: push the tty_lock down into the map handling (bnc#915826).
- tty: Fix memory leak in virtual console when enable unicode
  translation (bnc#916515).
- vt: push the tty_lock down into the map handling (bnc#915826).
- tty: Fix memory leak in virtual console when enable unicode
  translation (bnc#916515).
- commit 4e7a262
* Fri Feb  6 2015 neilb@suse.de
- dm raid: add region_size parameter (bnc#895841).
- commit e9d247b
* Fri Feb  6 2015 brogers@suse.com
- KVM: x86: Remove return code from enable_irq/nmi_window
  (bnc#916472).
- KVM: nVMX: Do not inject NMI vmexits when L2 has a pending
  interrupt (bnc#916472).
- KVM: nVMX: Rework interception of IRQs and NMIs (bnc#916472).
- kvm, vmx: Really fix lazy FPU on nested guest (bnc#916472).
- KVM: nVMX: Update guest activity state field on L2 exits
  (bnc#916472).
- KVM: nVMX: Fix nested_run_pending on activity state HLT
  (bnc#916472).
- KVM: nVMX: Add tracepoints for nested_vmexit and
  nested_vmexit_inject (bnc#916472).
- KVM: nVMX: Pass vmexit parameters to nested_vmx_vmexit
  (bnc#916472).
- KVM: nVMX: Add support for activity state HLT (bnc#916472).
- kvm, vmx: Fix lazy FPU on nested guest (bnc#916472).
- nVMX: Report CPU_BASED_VIRTUAL_NMI_PENDING as supported
  (bnc#916472).
- nVMX: Fix pick-up of uninjected NMIs (bnc#916472).
- KVM: nVMX: Amend nested_run_pending logic (bnc#916472).
- KVM: nVMX: Fix conditions for NMI injection (bnc#916472).
- KVM: VMX: Move vmx_nmi_allowed after vmx_set_nmi_mask
  (bnc#916472).
- KVM: Record instruction set in all vmexit tracepoints
  (bnc#916472).
- commit a3ca4f6
* Thu Feb  5 2015 oneukum@suse.de
- Refresh patches.xen/xen-x86-EFI.
- commit 14ca117
* Thu Feb  5 2015 oneukum@suse.de
- Refresh
  patches.drivers/0001-x86-efi-Add-EFI-framebuffer-earlyprintk-support.patch.
- commit 53d025f
* Thu Feb  5 2015 mmarek@suse.cz
- Fix bug number in  patches.fixes/lzo-check-for-length-overrun-in-variable-length-enco
- commit b16e03c
* Thu Feb  5 2015 jbeulich@suse.com
- Update Xen patches to c/s 1279.
- x86/efi: Add EFI framebuffer earlyprintk support (FATE#317449).
- PCI: Cache MSI/MSI-X capability offsets in struct pci_dev
  (bnc#909623,FATE#317523).
- Delete patches.xen/xen-pciback-release-VFs.
- Update Xen config files.
- commit 42f553a
* Thu Feb  5 2015 vbabka@suse.cz
- mm, vmscan: prevent kswapd livelock due to pfmemalloc-throttled
  process being killed (VM Functionality bnc#910150).
- commit 1c8173e
* Thu Feb  5 2015 jlee@suse.com
- igb: Fixes needed for surprise removal support (fate#317388,
  bsc#909491).
- igb: fix race accessing page->_count (fate#317388, bsc#909491).
- igb: don't reuse pages with pfmemalloc flag (fate#317388,
  bsc#909491).
- igb: bump version to 5.2.15 (fate#317388, bsc#909491).
- i40e/igb: Convert to dev_consume_skb_any() (fate#317388,
  bsc#909491).
- igb: remove blocking phy read from inside spinlock (fate#317388,
  bsc#909491).
- igb: bump igb version to 5.2.13 (fate#317388, bsc#909491).
- igb: Add message when malformed packets detected by hw
  (fate#317388, bsc#909491).
- igb: remove unnecessary break after return (fate#317388,
  bsc#909491).
- igb: remove unnecessary break after goto (fate#317388,
  bsc#909491).
- igb: Workaround for i210 Errata 25: Slow System Clock
  (fate#317388, bsc#909491).
- igb: bring link up when PHY is powered up (fate#317388,
  bsc#909491).
- igb: separate hardware setting from the set_ts_config ioctl
  (fate#317388, bsc#909491).
- igb: unhide invariant returns (fate#317388, bsc#909491).
- net: use ethtool_cmd_speed_set helper to set ethtool speed value
  (fate#317388, bsc#909491).
- net: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate
  (fate#317388, bsc#909491).
- igb: add defaults for i210 TX/RX PBSIZE (fate#317388,
  bsc#909491).
- igb: use mac loopback for i354 backplane (fate#317388,
  bsc#909491).
- igb: rename igb_ptp_enable to igb_ptp_feature_enable
  (fate#317388, bsc#909491).
- igb: remove redundant PHY power down register write
  (fate#317388, bsc#909491).
- i40e,igb,ixgbe: remove usless return statements (fate#317388,
  bsc#909491).
- igb/ixgbe: remove return statements for void functions
  (fate#317388, bsc#909491).
- net: get rid of SET_ETHTOOL_OPS (fate#317388, bsc#909491).
- igb: Change memcpy to struct assignment (fate#317388,
  bsc#909491).
- igb: Replace 1/0 return values with true/false (fate#317388,
  bsc#909491).
- igb: Cleanups to remove unneeded extern declaration
  (fate#317388, bsc#909491).
- igb: Cleanups to replace deprecated DEFINE_PCI_DEVICE_TABLE
  (fate#317388, bsc#909491).
- igb: Cleanups to fix static initialization (fate#317388,
  bsc#909491).
- igb: Cleanups to fix msleep warnings (fate#317388, bsc#909491).
- igb: Cleanups to fix line length warnings (fate#317388,
  bsc#909491).
- igb: Cleanups to remove return parentheses (fate#317388,
  bsc#909491).
- igb: Cleanups to fix missing break in switch statements
  (fate#317388, bsc#909491).
- igb: Cleanups to fix assignment in if error (fate#317388,
  bsc#909491).
- igb: Cleanups to change comment style on license headers
  (fate#317388, bsc#909491).
- igb: Cleanups to fix for trailing statement (fate#317388,
  bsc#909491).
- igb: Cleanups to fix pointer location error (fate#317388,
  bsc#909491).
- igb: Cleanups to fix incorrect indentation (fate#317388,
  bsc#909491).
- igb: Cleanups to fix braces location warnings (fate#317388,
  bsc#909491).
- igb: Cleanups for messaging (fate#317388, bsc#909491).
- e1000e/igb/ixgbe/i40e: fix message terminations (fate#317388,
  bsc#909491).
- igb: fix stats for i210 rx_fifo_errors (fate#317388,
  bsc#909491).
- igb: fix last_rx_timestamp usage (fate#317388, bsc#909491).
- igb: remove open-coded skb_cow_head (fate#317388, bsc#909491).
- INTEL-IGB: Convert iounmap to pci_iounmap (fate#317388,
  bsc#909491).
- igb: fix race conditions on queuing skb for HW time stamp
  (fate#317388, bsc#909491).
- igb: never generate both software and hardware timestamps
  (fate#317388, bsc#909491).
- igb: Unset IGB_FLAG_HAS_MSIX-flag when falling back to msi-only
  (fate#317388, bsc#909491).
- igb: Fix Null-pointer dereference in igb_reset_q_vector
  (fate#317388, bsc#909491).
- igb: specify phc_index of 82575 for get_ts_info (fate#317388,
  bsc#909491).
- igb: add register rd/wr for surprise removal (fate#317388,
  bsc#909491).
- igb: implement SIOCGHWTSTAMP ioctl (fate#317388, bsc#909491).
- igb: Convert uses of __constant_<foo> to <foo> (fate#317388,
  bsc#909491).
- igb: enable VLAN stripping for VMs with i350 (fate#317388,
  bsc#909491).
- igb: Add register defines needed for time sync functions
  (fate#317388, bsc#909491).
- igb: remove references to long gone command line parameters
  (fate#317388, bsc#909491).
- igb: Don't receive packets when the napi budget == 0
  (fate#317388, bsc#909491).
- net: Replace u64_stats_fetch_begin_bh to
  u64_stats_fetch_begin_irq (fate#317388, bsc#909491).
- net: igb calls skb_set_hash (fate#317388, bsc#909491).
- igb: fix warning if !CONFIG_IGB_HWMON (fate#317388, bsc#909491).
- igb: fix array size calculation (fate#317388, bsc#909491).
- igb: Update license text to remove FSF address and update
  copyright (fate#317388, bsc#909491).
- igb: make local functions static and remove dead code
  (fate#317388, bsc#909491).
- igb: Use pci_enable_msix_range() instead of pci_enable_msix()
  (fate#317388, bsc#909491).
- igb: Change to use statically allocated array for MSIx entries
  (fate#317388, bsc#909491).
- igb: Fix queue allocation method to accommodate changing during
  runtime (fate#317388, bsc#909491).
- igb: Fix for issue where values could be too high for udelay
  function (fate#317388, bsc#909491).
- igb: Start temperature sensor attribute index with 1
  (fate#317388, bsc#909491).
- igb: Add new feature Media Auto Sense for 82580 devices only
  (fate#317388, bsc#909491).
- igb: Support ports mapped in 64-bit PCI space (fate#317388,
  bsc#909491).
- igb: Add media switching feature for i354 PHY's (fate#317388,
  bsc#909491).
- igb: Fixed Wake On LAN support (fate#317388, bsc#909491).
- igb: Update link modes display in ethtool (fate#317388,
  bsc#909491).
- net: Explicitly initialize u64_stats_sync structures for lockdep
  (fate#317388, bsc#909491).
- igb: Don't let ethtool try to write to iNVM in i210/i211
  (fate#317388, bsc#909491).
- igb: Fix master/slave mode for all m88 i354 PHY's (fate#317388,
  bsc#909491).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN
  (fate#317388, bsc#909491).
- igb: Add ethtool support to configure number of channels
  (fate#317388, bsc#909491).
- igb: Add ethtool offline tests for i354 (fate#317388,
  bsc#909491).
- igb: Fix ethtool loopback test for 82580 copper (fate#317388,
  bsc#909491).
- intel: Remove extern from function prototypes (fate#317388,
  bsc#909491).
- DMA-API: net: intel/igb: fix 32-bit DMA mask handling
  (fate#317388, bsc#909491).
- igb: Read flow control for i350 from correct EEPROM section
  (fate#317388, bsc#909491).
- igb: Add additional get_phy_id call for i354 devices
  (fate#317388, bsc#909491).
- igb: Update version number (fate#317388, bsc#909491).
- igb: Implementation to report advertised/supported link on
  i354 devices (fate#317388, bsc#909491).
- igb: Get speed and duplex for 1G non_copper devices
  (fate#317388, bsc#909491).
- igb: Support to get 2_5G link status for appropriate media type
  (fate#317388, bsc#909491).
- igb: No PHPM support in i354 devices (fate#317388, bsc#909491).
- igb: M88E1543 PHY downshift implementation (fate#317388,
  bsc#909491).
- igb: New PHY_ID for i354 device (fate#317388, bsc#909491).
- igb: Implementation of 1-sec delay for i210 devices
  (fate#317388, bsc#909491).
- igb: Don't look for a PBA in the iNVM when flashless
  (fate#317388, bsc#909491).
- igb: Expose RSS indirection table for ethtool (fate#317388,
  bsc#909491).
- igb: Add macro for size of RETA indirection table (fate#317388,
  bsc#909491).
- igb: Add device support for flashless SKU of i210 device
  (fate#317388, bsc#909491).
- igb: Refactor NVM read functions to accommodate devices with
  no flash (fate#317388, bsc#909491).
- igb: Refactor of init_nvm_params (fate#317388, bsc#909491).
- igb: Update MTU so that it is always at least a standard frame
  size (fate#317388, bsc#909491).
- igb: don't allow SR-IOV without MSI-X (fate#317388, bsc#909491).
- igb: Added rcu_lock to avoid race (fate#317388, bsc#909491).
- igb: Read register for latch_on without return value
  (fate#317388, bsc#909491).
- igb: fix vlan filtering in promisc mode when not in VT mode
  (fate#317388, bsc#909491).
- treewide: relase -> release (fate#317388, bsc#909491).
- igb: Removed unused i2c function (fate#317388, bsc#909491).
- igb: Implementation of i210/i211 LED support (fate#317388,
  bsc#909491).
- igb: Fix possible panic caused by Rx traffic arrival while
  interface is down (fate#317388, bsc#909491).
- igb: Fix set_ethtool function to call update nvm for entire
  image (fate#317388, bsc#909491).
- igb: SerDes flow control setting (fate#317388, bsc#909491).
- igb: Support for SFP modules discovery (fate#317388,
  bsc#909491).
- igb: Add update to last_rx_timestamp in Rx rings (fate#317388,
  bsc#909491).
- igb: Changed LEDs blink mechanism to include designs using
  cathode (fate#317388, bsc#909491).
- igb: limit udelay for phy changes to 10000us (fate#317388,
  bsc#909491).
- igb: Bump version of driver (fate#317388, bsc#909491).
- igb: Remove id's that will not be productized for Linux
  (fate#317388, bsc#909491).
- igb: Remove dead code path (fate#317388, bsc#909491).
- igb: Retain HW VLAN filtering while in promiscuous + VT mode
  (fate#317388, bsc#909491).
- igb: display a warning message when SmartSpeed works
  (fate#317388, bsc#909491).
- igb: Use pci_vfs_assigned instead of igb_vfs_are_assigned
  (fate#317388, bsc#909491).
- igb: Add SMBI semaphore to I210/I211 (fate#317388, bsc#909491).
- igb: SERDES loopback sigdetect bit on i210 devices (fate#317388,
  bsc#909491).
- igb: Add support for i354 devices (fate#317388, bsc#909491).
- igb: add support for spoofchk config (fate#317388, bsc#909491).
- igb: Enable EEE LP advertisement (fate#317388, bsc#909491).
- igb: Fix code comments and whitespace (fate#317388, bsc#909491).
- igb: Fix sparse warnings on function pointers (fate#317388,
  bsc#909491).
- igb: Use rx/tx_itr_setting when setting up initial value of itr
  (fate#317388, bsc#909491).
- igb: Pull adapter out of main path in igb_xmit_frame_ring
  (fate#317388, bsc#909491).
- igb: Mask off check of frag_off as we only want fragment offset
  (fate#317388, bsc#909491).
- igb: random code and comments fix (fate#317388, bsc#909491).
- igb: Implement support to power sfp cage and turn on I2C
  (fate#317388, bsc#909491).
- igb: Support for 100base-fx SFP (fate#317388, bsc#909491).
- igb: make sensor info static (fate#317388, bsc#909491).
- igb: Fix null pointer dereference (fate#317388, bsc#909491).
- igb: fix i350 anti spoofing config (fate#317388, bsc#909491).
- igb: Fix for lockdep issue in igb_get_i2c_client (fate#317388,
  bsc#909491).
- igb: Fix link setup for I210 devices (fate#317388, bsc#909491).
- igb: increase timeout for ethtool offline self-test
  (fate#317388, bsc#909491).
- igb: Refractoring function pointers in igb_get_invariants
  function (fate#317388, bsc#909491).
- igb: Intialize MAC function pointers (fate#317388, bsc#909491).
- igb: Initialize NVM function pointers (fate#317388, bsc#909491).
- igb: Initialize PHY function pointers (fate#317388, bsc#909491).
- igb: Update igb to use a path similar to ixgbe to determine
  when to stop Tx (fate#317388, bsc#909491).
- igb: Refix sparse warning in igb_get_i2c_client (fate#317388,
  bsc#909491).
- igb: Fix for improper allocation flag in igb_get_i2c_client
  (fate#317388, bsc#909491).
- igb: Fix for improper exit in igb_get_i2c_client (fate#317388,
  bsc#909491).
- igb: Support using build_skb in the case that jumbo frames
  are disabled (fate#317388, bsc#909491).
- ethernet: Remove unnecessary alloc/OOM messages, alloc cleanups
  (fate#317388, bsc#909491).
- igb: Don't give VFs random MAC addresses (fate#317388,
  bsc#909491).
- igb: Copyright string update to year 2013 (fate#317388,
  bsc#909491).
- igb: Replace rmb in Tx cleanup with read_barrier_depends
  (fate#317388, bsc#909491).
- igb: Use in-kernel PTP_EV_PORT #define (fate#317388,
  bsc#909491).
- igb: Free any held skb that should have been timestamped on
  remove (fate#317388, bsc#909491).
- igb: Add mechanism for detecting latched hardware Rx timestamp
  (fate#317388, bsc#909491).
- igb: Add timeout for PTP Tx work item (fate#317388, bsc#909491).
- igb: Add support for SW timestamping (fate#317388, bsc#909491).
- igb: Enable hwmon data output for thermal sensors via I2C
  (fate#317388, bsc#909491).
- igb: Add support functions to access thermal data (fate#317388,
  bsc#909491).
- igb: Add i2c interface to igb (fate#317388, bsc#909491).
- remove init of dev->perm_addr in drivers (fate#317388,
  bsc#909491).
- net_tstamp: Add SIOCGHWTSTAMP ioctl to match SIOCSHWTSTAMP
  (fate#317388, bsc#909491).
- net_tstamp: Improve kernel-doc for struct hwtstamp_config
  (fate#317388).
- net/compat: Merge multiple implementations of ifreq::ifr_data
  conversion (fate#317388, bsc#909491).
- etherdevice: introduce help function eth_zero_addr()
  (fate#317388, bsc#909491).
- ethernet: Use eth_random_addr (fate#317388, bsc#909491).
- commit 9cba9d2
* Thu Feb  5 2015 jlee@suse.com
- Update config files.
  Set CONFIG_IGB_HWMON=y to following config:
  i386/pae
  i386/xen
  i386/trace
  i386/debug
  i386/default
  ia64/trace
  ia64/debug
  ia64/default
  ppc64/ppc64
  ppc64/trace
  ppc64/debug
  ppc64/default
  x86_64/xen
  x86_64/trace
  x86_64/debug
  x86_64/default
  x86_64/bigsmp
- commit bccafa5
* Wed Feb  4 2015 brogers@suse.com
- Refresh
  patches.arch/kvm-vmx-disable-apic-virtualization-in-nested-guests.patch.
- commit 70cbc97
* Wed Feb  4 2015 brogers@suse.com
- Refresh
  patches.arch/kvm-add-reset-restore-rtc_status-support.patch.
- Refresh
  patches.arch/kvm-add-vcpu-info-to-ioapic_update_eoi.patch.
- Refresh
  patches.arch/kvm-call-common-update-function-when-ioapic-entry-changed.patch.
- Refresh
  patches.arch/kvm-call-kvm_apic_match_dest-to-check-destination-vcpu.patch.
- Refresh
  patches.arch/kvm-force-vmexit-with-virtual-interrupt-delivery.patch.
- Refresh
  patches.arch/kvm-inject-extint-interrupt-before-apic-interrupts.patch.
- Refresh patches.arch/kvm-introduce-struct-rtc_status.patch.
- Refresh
  patches.arch/kvm-let-ioapic-know-the-irq-line-status.patch.
- Refresh patches.arch/kvm-remove-unused-variable.patch.
- Refresh
  patches.arch/kvm-return-destination-vcpu-on-interrupt-injection.patch.
- Refresh
  patches.arch/kvm-set-tmr-when-programming-ioapic-entry.patch.
- Refresh
  patches.arch/kvm-use-eoi-to-track-rtc-interrupt-delivery-status.patch.
- Refresh
  patches.arch/kvm-vmx-add-the-deliver-posted-interrupt-algorithm.patch.
- Refresh
  patches.arch/kvm-vmx-check-the-posted-interrupt-capability.patch.
- Refresh patches.arch/kvm-vmx-disable-apicv-by-default.patch.
- Refresh
  patches.arch/kvm-vmx-enable-acknowledge-interupt-on-vmexit.patch.
- Refresh
  patches.arch/kvm-vmx-register-a-new-ipi-for-posted-interrupt.patch.
- Refresh
  patches.arch/kvm-vmx-use-posted-interrupt-to-deliver-virtual-interrupt.patch.
- Refresh
  patches.arch/x86-apicv-add-apicv-register-virtualization-support.patch.
- Refresh
  patches.arch/x86-apicv-add-virtual-interrupt-delivery-support.patch.
- Refresh patches.arch/x86-apicv-add-virtual-x2apic-support.patch.
- commit e2f527b
* Wed Feb  4 2015 brogers@suse.com
- Refresh
  patches.arch/kvm-nvmx-clean-up-and-fix-pin-based-execution-controls.patch.
- commit 478c6d2
* Wed Feb  4 2015 mszeredi@suse.cz
- writeback: consolidate variable names in balance_dirty_pages().
- Refresh
  patches.fixes/mm-properly-reflect-task-dirty-limits-in-dirty_excee.patch.
- commit 6ac9fdc
* Wed Feb  4 2015 duwe@suse.de
- random: account for entropy loss due to overwrites
  (FATE#317374).
- random: allow fractional bits to be tracked (FATE#317374).
- random: statically compute poolbitshift, poolbytes, poolbits
  (FATE#317374).
- commit b088e65
* Tue Feb  3 2015 neilb@suse.de
- nfsd: fix EXDEV checking in rename (bnc#915791).
- commit 5852e68
* Tue Feb  3 2015 jjolly@suse.de
- zcrypt: Number of supported ap domains is not retrievable
  (bnc#915209, LTC#120788).
- kernel: incorrect clock_gettime result (bnc#915209, LTC#121184).
- kernel: 3215 tty close crash (bnc#915209, LTC#120873).
- commit ac7be48
* Tue Feb  3 2015 duwe@suse.de
- intel_idle: fine-tune IVT residency targets (FATE#317686).
- commit 019a1d4
* Mon Feb  2 2015 bpoirier@suse.de
- Refresh
  patches.drivers/tg3-0080-PCI-tg3-Give-up-chip-reset-and-carrier-loss-handling.patch.
- Refresh patches.xen/xen3-patch-2.6.25.
- commit c1e8c28
* Sun Feb  1 2015 jbohac@suse.cz
- netfilter: conntrack: disable generic tracking for known
  protocols (bsc#913059, CVE-2014-8160).
- commit 873fddf
* Sat Jan 31 2015 brogers@suse.com
- KVM: nVMX: Skip PF interception check when queuing during
  nested run (FATE#317460).
- KVM: x86: Rework request for immediate exit (FATE#317460).
- commit 9e2f76e
* Sat Jan 31 2015 mmarek@suse.cz
- Delete patches.kabi/* workarounds
- commit 04dabc0
* Fri Jan 30 2015 oneukum@suse.de
- Update config files.
- commit fdfceb0
* Fri Jan 30 2015 oneukum@suse.de
- Refresh patches.xen/xen-x86-EFI.
- commit ebc23ae
* Fri Jan 30 2015 oneukum@suse.de
- Refresh patches.xen/xen-x86-EFI.
- commit eb20a24
* Fri Jan 30 2015 oneukum@suse.de
- Update config files.
- commit 604da81
* Fri Jan 30 2015 oneukum@suse.de
- x86/efi: Add EFI framebuffer earlyprintk support (FATE#317449).
- x86/efi: Fix earlyprintk off-by-one bug (FATE#317449).
- x86/efi: earlyprintk=efi,keep fix (FATE#317449).
- Refresh patches.xen/xen-x86-EFI.
- Refresh patches.xen/xen-x86_64-unmapped-initrd.
- commit 5ff4cd3
* Fri Jan 30 2015 ptesarik@suse.cz
- Refresh
  patches.suse/vmcore-allocate-ELF-note-segment-in-kdump-kernel.
- commit bfdca43
* Fri Jan 30 2015 ptesarik@suse.cz
- vmcore: support mmap() on /proc/vmcore (FATE#317317).
- commit a7ccbb4
* Fri Jan 30 2015 ptesarik@suse.cz
- vmcore: calculate vmcore file size from buffer size and total
  size of vmcore objects (FATE#317317).
- commit 3ea1174
* Fri Jan 30 2015 ptesarik@suse.cz
- vmcore: allow user process to remap ELF note segment buffer
  (FATE#317317).
- commit ae60763
* Fri Jan 30 2015 ptesarik@suse.cz
- vmcore: allocate ELF note segment in the 2nd kernel vmalloc
  memory (FATE#317317).
- commit 8c0cb9e
* Fri Jan 30 2015 ptesarik@suse.cz
- vmalloc: introduce remap_vmalloc_range_partial (FATE#317317).
- commit 3f440e5
* Fri Jan 30 2015 ptesarik@suse.cz
- vmalloc: make find_vm_area check in range (FATE#317317).
- commit e34e7be
* Fri Jan 30 2015 ptesarik@suse.cz
- vmcore: treat memory chunks referenced by PT_LOAD program header
  entries in page-size boundary in vmcore_list (FATE#317317).
- commit ed5ad89
* Fri Jan 30 2015 ptesarik@suse.cz
- vmcore: allocate buffer for ELF headers on page-size alignment
  (FATE#317317).
- commit 9c3da93
* Fri Jan 30 2015 ptesarik@suse.cz
- vmcore: clean up read_vmcore() (FATE#317317).
- commit ae880b0
* Fri Jan 30 2015 ptesarik@suse.cz
- include/linux/mm.h: add PAGE_ALIGNED() helper (FATE#317317).
- commit b6a9951
* Fri Jan 30 2015 glin@suse.com
- Add CONFIG_NET_VENDOR_MARVELL to config files for s390/s390x (bsc#909566 FATE#314306)
- commit 6afd31a
* Fri Jan 30 2015 brogers@suse.com
- KVM: vmx: disable APIC virtualization in nested guests
  (FATE#317460).
- KVM: nVMX: Set success rflags when emulate VMXON/VMXOFF in
  nested virt (FATE#317460).
- KVM: nVMX: Change location of 3 functions in vmx.c
  (FATE#317460).
- KVM: nVMX: Enable and disable shadow vmcs functionality
  (FATE#317460).
- KVM: nVMX: Synchronize VMCS12 content with the shadow vmcs
  (FATE#317460).
- KVM: nVMX: Copy VMCS12 to processor-specific shadow vmcs
  (FATE#317460).
- KVM: nVMX: Copy processor-specific shadow-vmcs to VMCS12
  (FATE#317460).
- KVM: nVMX: Release shadow vmcs (FATE#317460).
- KVM: nVMX: Allocate shadow vmcs (FATE#317460).
- KVM: nVMX: Fix VMXON emulation (FATE#317460).
- KVM: nVMX: Refactor handle_vmwrite (FATE#317460).
- KVM: nVMX: Introduce vmread and vmwrite bitmaps (FATE#317460).
- KVM: nVMX: Detect shadow-vmcs capability (FATE#317460).
- KVM: nVMX: Shadow-vmcs control fields/bits (FATE#317460).
- KVM: VMX: Fix check guest state validity if a guest is in VM86
  mode (FATE#317460).
- KVM: nVMX: check vmcs12 for valid activity state (FATE#317460).
- KVM: nVMX: Rework event injection and recovery (FATE#317460).
- KVM: nVMX: Fix injection of PENDING_INTERRUPT and NMI_WINDOW
  exits to L1 (FATE#317460).
- KVM: x86: fix memory leak in vmx_init (FATE#317460).
- KVM: nVMX: Check exit control for VM_EXIT_SAVE_IA32_PAT,
  not entry controls (FATE#317460).
- KVM: nVMX: Provide EFER.LMA saving support (FATE#317460).
- KVM: nVMX: Fix setting of CR0 and CR4 in guest mode
  (FATE#317460).
- KVM: nVMX: Fix content of MSR_IA32_VMX_ENTRY/EXIT_CTLS
  (FATE#317460).
- KVM: nVMX: Reset RFLAGS on VM-exit (FATE#317460).
- KVM: nVMX: Fix switching of debug state (FATE#317460).
- KVM: nVMX: Clear segment cache after switching between L1 and L2
  (FATE#317460).
- KVM: nVMX: Fix erroneous exception bitmap check (FATE#317460).
- KVM: nVMX: Fix warning-causing idt-vectoring-info behavior
  (FATE#317460).
- KVM: nVMX: Add KVM_REQ_IMMEDIATE_EXIT (FATE#317460).
- commit 06ead11
* Thu Jan 29 2015 jbohac@suse.cz
- The bug number in
  patches.fixes/timekeeping-avoid-possible-deadlock-from-clock_was_set.patch
  changed from bsc#771619 to bsc#915335.
- commit 37d10ec
* Thu Jan 29 2015 acho@suse.com
- Refresh for cnic SP4 update (bsc#909368 FATE#317537)
- Refresh
  patches.drivers/bnx2x-cnic-bnx2i-bnx2fc-fix-bnx2i-and-bnx2fc-regressions.
- Refresh
  patches.drivers/cnic-bnx2i-bnx2fc-fix-inconsistent-use-of-page-size.
- Refresh patches.drivers/cnic-update-tcp-options-setup-for-iscsi
- commit 3730073
* Thu Jan 29 2015 acho@suse.com
- cnic: Update the rcu_access_pointer() usages (bsc#909368
  FATE#317537).
- cnic: Replace rcu_dereference() with rcu_access_pointer()
  (bsc#909368 FATE#317537).
- net: treewide use of RCU_INIT_POINTER (bsc#909368 FATE#317537).
- cnic: Rebranding cnic driver (bsc#909368 FATE#317537).
- cnic: Fix missing ISCSI_KEVENT_IF_DOWN message (bsc#909368
  FATE#317537).
- cnic: Don't take cnic_dev_lock in cnic_alloc_uio_rings()
  (bsc#909368 FATE#317537).
- cnic: Don't take rcu_read_lock in cnic_rcv_netevent()
  (bsc#909368 FATE#317537).
- cnic: Update version to 2.5.20 and copyright year (bsc#909368
  FATE#317537).
- cnic: Use proper ulp_ops for per device operations (bsc#909368
  FATE#317537).
- cnic: Add a signature to indicate valid doorbell offset.
- net:drivers/net: Miscellaneous conversions to ETH_ALEN
  (bsc#909368 FATE#317537).
- broadcom: Remove extern from function prototypes (bsc#909368
  FATE#317537).
- cnic: Fix crash in cnic_bnx2x_service_kcq() (bsc#909368
  FATE#317537).
- cnic: Update version to 2.5.18 (bsc#909368 FATE#317537).
- cnic: Eliminate local copy of pfid.
- cnic: Eliminate CNIC_PORT macro and port_mode in local struct
  (bsc#909368 FATE#317537).
- cnic: Redefine BNX2X_HW_CID using existing bnx2x macros
  (bsc#909368 FATE#317537).
- cnic: Use CHIP_NUM macros from bnx2x.h (bsc#909368 FATE#317537).
- ethernet: Convert mac address uses of 6 to ETH_ALEN (bsc#909368
  FATE#317537).
- cnic: Update version to 2.5.17 and copyright year (bsc#909368
  FATE#317537).
- cnic: Add missing error checking for RAMROD_CMD_ID_CLOSE
  (bsc#909368 FATE#317537).
- cnic: Reset tcp_flags during cnic_cm_create() (bsc#909368
  FATE#317537).
- cnic: Simplify cnic_release() (bsc#909368 FATE#317537).
- cnic: Simplify netdev events handling (bsc#909368 FATE#317537).
- bnx2x, bnx2fc: Use per port max exchange resources (bsc#909368
  FATE#317537).
- net/broadcom: remove __dev* attributes (bsc#909368 FATE#317537).
- commit 1aaa49c
* Thu Jan 29 2015 glin@suse.com
- drivers/net: Convert remaining uses of pr_warning to pr_warn (bsc#909566 FATE#314306).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#909566 FATE#314306).
- sky2: use pci_zalloc_consistent (bsc#909566 FATE#314306).
- net: get rid of SET_ETHTOOL_OPS (bsc#909566 FATE#314306).
- sky2: Call dev_kfree_skb_any instead of dev_kfree_skb (bsc#909566 FATE#314306).
- sky2: Don't receive packets when the napi budget == 0 (bsc#909566 FATE#314306).
- net: Replace u64_stats_fetch_begin_bh to u64_stats_fetch_begin_irq (bsc#909566 FATE#314306).
- sky2: allow mac to come from dt (bsc#909566 FATE#314306).
- sky2: initialize napi before registering device (bsc#909566 FATE#314306).
- net: sky2 calls skb_set_hash (bsc#909566 FATE#314306).
- net: Explicitly initialize u64_stats_sync structures for lockdep (bsc#909566 FATE#314306).
- net: sky2: remove unnecessary pci_set_drvdata() (bsc#909566 FATE#314306).
- ethernet: Remove unnecessary alloc/OOM messages, alloc cleanups (bsc#909566 FATE#314306).
- remove init of dev->perm_addr in drivers (bsc#909566 FATE#314306).
- drivers/net: fix up function prototypes after __dev* removals (bsc#909566 FATE#314306).
- skge: remove __dev* attributes (bsc#909566 FATE#314306).
- sky2: fix cleanup sequence in probe() function (bsc#909566 FATE#314306).
- drivers/net/ethernet/marvell/sky2.c: fix error return code (bsc#909566 FATE#314306).
- sky2: Added support for Optima EEE (bsc#909566 FATE#314306).
- sky2: copy received packets on inefficient unaligned architecture (bsc#909566 FATE#314306).
- sky2: fix missing register reset on error path in sky2_test_msi() (bsc#909566 FATE#314306).
- sky2: dont overwrite settings for PHY Quick link (bsc#909566 FATE#314306).
- drivers/net: Remove alloc_etherdev error messages (bsc#909566 FATE#314306).
- sky2: add bql support (bsc#909566 FATE#314306).
- Sweep away N/A fw_version dustbunnies from the .get_drvinfo routine of a number of drivers (bsc#909566 FATE#314306).
- sky2: fix hang in napi_disable (bsc#909566 FATE#314306).
- sky2: enforce minimum ring size (bsc#909566 FATE#314306).
- sky2: version 1.30 (bsc#909566 FATE#314306).
- sky2: used fixed RSS key (bsc#909566 FATE#314306).
- sky2: reduce default Tx ring size (bsc#909566 FATE#314306).
- sky2: rename up/down functions (bsc#909566 FATE#314306).
- sky2: pci posting issues (bsc#909566 FATE#314306).
- sky2: fix hang on shutdown (and other irq issues) (bsc#909566 FATE#314306).
- sweep the floors and convert some .get_drvinfo routines to strlcpy (bsc#909566 FATE#314306).
- sky2: fix regression on Yukon Optima (bsc#909566 FATE#314306).
- net: add skb frag size accessors (bsc#909566 FATE#314306).
- sky2: fix skb truesize underestimation (bsc#909566 FATE#314306).
- net: Remove unnecessary driver assignments of ethtool_ringparam fields to zero (bsc#909566 FATE#314306).
- net: use DMA_x_DEVICE and dma_mapping_error with skb_frag_dma_map (bsc#909566 FATE#314306).
- sky2: manage irq better on single port card (bsc#909566 FATE#314306).
- sky2: convert to SKB paged frag API (bsc#909566 FATE#314306).
- skge/sky2/mv643xx/pxa168: Move the Marvell Ethernet drivers (bsc#909566 FATE#314306).
- sky2: version 1.29 (bsc#909566 FATE#314306).
- sky2: support for new Optima chipsets (EXPERIMENTAL) (bsc#909566 FATE#314306).
- sky2: use correct Inter Packet Gap at 10/100mbit (bsc#909566 FATE#314306).
- sky2: force receive checksum when using RSS on some hardware (v2) (bsc#909566 FATE#314306).
- sky2: use GFP_KERNEL allocations at device setup (bsc#909566 FATE#314306).
- sky2: remove unnecessary reads of PCI_CAP_ID_EXP (bsc#909566 FATE#314306).
- net: remove interrupt.h inclusion from netdevice.h (bsc#909566 FATE#314306).
- of_net.h: Provide empty functions if OF_NET is not configured (bsc#909566 FATE#314306).
- commit 9d90f49
* Thu Jan 29 2015 acho@suse.com
- tg3: fix ring init when there are more TX than RX channels
  (bsc#908458 FATE#317507).
- tg3: prevent ifup/ifdown during PCI error recovery (bsc#908458
  FATE#317507).
- tg3: fix return value in tg3_get_stats64 (bsc#908458
  FATE#317507).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#908458
  FATE#317507).
- tg3: Modify tg3_tso_bug() to handle multiple TX rings
  (bsc#908458 FATE#317507).
- tg3: Clear NETIF_F_TSO6 flag before doing software GSO
  (bsc#908458 FATE#317507).
- tg3: Update copyright and version to 3.137 (bsc#908458
  FATE#317507).
- tg3: Prevent page allocation failure during TSO workaround
  (bsc#908458 FATE#317507).
- tg3: Don't modify ip header fields when doing GSO (bsc#908458
  FATE#317507).
- tg3: update rx_jumbo_pending ring param only when jumbo frames
  are enabled (bsc#908458 FATE#317507).
- tg3: remove open-coded skb_cow_head (bsc#908458 FATE#317507).
- tg3: remove empty MDIO bus reset function (bsc#908458
  FATE#317507).
- tg3: Call dev_kfree_skby_any instead of dev_kfree_skb
  (bsc#908458 FATE#317507).
- tg3: Support for byte queue limits (bsc#908458 FATE#317507).
- tg3: Don't check undefined error bits in RXBD (bsc#908458
  FATE#317507).
- tg3: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bsc#908458 FATE#317507).
- tg3: Fix deadlock in tg3_change_mtu() (bsc#908458 FATE#317507).
- tg3: cleanup an error path in tg3_phy_reset_5703_4_5()
  (bsc#908458 FATE#317507).
- drivers/net: delete non-required instances of include
  <linux/init.h> (bsc#908458 FATE#317507).
- tg3: Update version to 3.136 (bsc#908458 FATE#317507).
- tg3: Refactor __tg3_set_mac_addr() (bsc#908458 FATE#317507).
- tg3: Expand 4g_overflow_test workaround to skb fragments of
  any size (bsc#908458 FATE#317507).
- tg3: Initialize REG_BASE_ADDR at PCI config offset 120 to 0
  (bsc#908458 FATE#317507).
- tg3: Update version to 3.135 (bsc#908458 FATE#317507).
- tg3: Expand multicast drop counter miscounting fix to 5762
  (bsc#908458 FATE#317507).
- tg3: Fix bit definition for the nvram Auto Power Down setting
  (bsc#908458 FATE#317507).
- tg3: Add flag to disable 1G Half Duplex advertisement
  (bsc#908458 FATE#317507).
- tg3: Don't add rxbds_empty to rx_over_errors (bsc#908458
  FATE#317507).
- PCI / tg3: Give up chip reset and carrier loss handling if
  PCI device is not present (bsc#908458 FATE#317507).
- tg3: Validate hwtstamp_config completely before applying it
  (bsc#908458 FATE#317507).
- net: tg3: remove unnecessary pci_set_drvdata() (bsc#908458
  FATE#317507).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN
  (bsc#908458 FATE#317507).
- remove init of dev->perm_addr in drivers (bsc#908458
  FATE#317507).
- tg3: use phylib when robo switch is in use (bsc#908458
  FATE#317507).
- ssb: provide phy address for Gigabit Ethernet driver (bsc#908458
  FATE#317507).
- tg3: add support a phy at an address different than 01
  (bsc#908458 FATE#317507).
- tg3: Update version to 3.134 (bsc#908458 FATE#317507).
- tg3: Remove unnecessary spinlock (bsc#908458 FATE#317507).
- tg3: Appropriately classify interrupts during request_irq
  (bsc#908458 FATE#317507).
- tg3: Remove redundant if check (bsc#908458 FATE#317507).
- tg3: Remove if 0'd code (bsc#908458 FATE#317507).
- tg3: LED in shared mode does not blink during traffic
  (bsc#908458 FATE#317507).
- tg3: Add support for new 577xx device ids (bsc#908458
  FATE#317507).
- tg3: Add function tg3_phy_shdw_write() (bsc#908458 FATE#317507).
- tg3: Use pci_dev pm_cap (bsc#908458 FATE#317507).
- tg3: Expand led off fix to include 5720 (bsc#908458
  FATE#317507).
- tg3: Don't turn off led on 5719 serdes port 0 (bsc#908458
  FATE#317507).
- drivers:net: Convert dma_alloc_coherent(...__GFP_ZERO) to
  dma_zalloc_coherent (bsc#908458 FATE#317507).
- net: tg3: fix NULL pointer dereference in tg3_io_error_detected
  and tg3_io_slot_reset (bsc#908458 FATE#317507).
- tg3: clean up unnecessary MSI/MSI-X capability find (bsc#908458
  FATE#317507).
- tg3: Update version to 3.133 (bsc#908458 FATE#317507).
- tg3: Fix UDP fragments treated as RMCP (bsc#908458 FATE#317507).
- tg3: Enable support for timesync gpio output (bsc#908458
  FATE#317507).
- tg3: Implement the shutdown handler (bsc#908458 FATE#317507).
- tg3: Allow NVRAM programming when interface is down (bsc#908458
  FATE#317507).
- tg3: Remove incorrect switch to aux power (bsc#908458
  FATE#317507).
- net/tg3: Fix warning from pci_disable_device() (bsc#908458
  FATE#317507).
- net/tg3: Fix kernel crash (bsc#908458 FATE#317507).
- net/tg3: Avoid delay during MMIO access (bsc#908458
  FATE#317507).
- tg3: Wait for boot code to finish after power on (bsc#908458
  FATE#317507).
- tg3: Add read dma workaround for 5720 (bsc#908458 FATE#317507).
- tg3: remove redundant pm init code (bsc#908458 FATE#317507).
- tg3: Remove unnecessary lock around tg3_flag_set (bsc#908458
  FATE#317507).
- tg3: Fix misplaced empty line (bsc#908458 FATE#317507).
- tg3: Use descriptive label names in tg3_start (bsc#908458
  FATE#317507).
- tg3: Make tg3_rings_reset() more concise (bsc#908458
  FATE#317507).
- tg3: Simplify ring control block setup (bsc#908458 FATE#317507).
- tg3: Split APE driver state change out of boot reset signature
  update (bsc#908458 FATE#317507).
- tg3: Update version to 3.132 (bsc#908458 FATE#317507).
- tg3: Ensure boot code has completed initialization before
  accessing hardware (bsc#908458 FATE#317507).
- tg3: Fix data corruption on 5725 with TSO (bsc#908458
  FATE#317507).
- tg3: Skip powering down function 0 on certain serdes devices
  (bsc#908458 FATE#317507).
- tg3: fix to append hardware time stamping flags (bsc#908458
  FATE#317507).
- tg3: shows HW time stamping support only if ptp_capable is
  present (bsc#908458 FATE#317507).
- tg3: Remove unneeded PM_OPS definitions (bsc#908458
  FATE#317507).
- tg3: Use bool not int (bsc#908458 FATE#317507).
- tg3: Update version to 3.131 (bsc#908458 FATE#317507).
- tg3: Reset the phy to allow modified EEE settings to take effect
  (bsc#908458 FATE#317507).
- tg3: Pull the phy advertised speed and flow control settings
  on driver load (bsc#908458 FATE#317507).
- tg3: Add support for link flap avoidance (bsc#908458
  FATE#317507).
- tg3: Add SGMII phy support for 5719/5718 serdes (bsc#908458
  FATE#317507).
- tg3: Add tg3_clear_mac_status() common function (bsc#908458
  FATE#317507).
- tg3: Add a warning during link settings change if mgmt enabled
  (bsc#908458 FATE#317507).
- tg3: Remove unnecessary phy reset during ethtool commands
  (bsc#908458 FATE#317507).
- tg3: Fix NVRAM size detection for the STM45PE20 pinstrap on
  5762 devices (bsc#908458 FATE#317507).
- tg3: Fix flow control settings not propagated to hardware
  (bsc#908458 FATE#317507).
- drivers:net: dma_alloc_coherent: use __GFP_ZERO instead of
  memset(, 0) (bsc#908458 FATE#317507).
- tg3: 5715 does not link up when autoneg off (bsc#908458
  FATE#317507).
- tg3: Update link_up flag for phylib devices (bsc#908458
  FATE#317507).
- tg3: Download 57766 EEE service patch firmware (bsc#908458
  FATE#317507).
- tg3: Enhance firmware download code to support fragmented
  firmware (bsc#908458 FATE#317507).
- tg3: Cleanup firmware parsing code (bsc#908458 FATE#317507).
- tg3: Refactor the 2nd type of cpu pause (bsc#908458
  FATE#317507).
- tg3: Refactor cpu pause/resume code (bsc#908458 FATE#317507).
- tg3: Add new FW_TSO flag (bsc#908458 FATE#317507).
- tg3: Use different macros for pci_chip_rev_id accesses
  (bsc#908458 FATE#317507).
- tg3: Remove define and single use of GET_CHIP_REV_ID (bsc#908458
  FATE#317507).
- tg3: Update version to 3.130 (bsc#908458 FATE#317507).
- tg3: Set initial carrier state to off (bsc#908458 FATE#317507).
- tg3: Fix 5762 NVRAM sizing (bsc#908458 FATE#317507).
- tg3: Expand EEE support for all 5717 B0 (bsc#908458
  FATE#317507).
- tg3: add support for Ethernet core in bcm4785 (bsc#908458
  FATE#317507).
- ssb: get mac address from sprom struct for gige driver
  (bsc#908458 FATE#317507).
- tg3: make it possible to provide phy_id in ioctl (bsc#908458
  FATE#317507).
- ethernet: Remove unnecessary alloc/OOM messages, alloc cleanups
  (bsc#908458 FATE#317507).
- tg3: missing break statement in tg3_get_5720_nvram_info()
  (bsc#908458 FATE#317507).
- drivers/net: fix up function prototypes after __dev* removals
  (bsc#908458 FATE#317507).
- tg3: remove __dev* attributes (bsc#908458 FATE#317507).
- commit e02d5c7
* Thu Jan 29 2015 acho@suse.com
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#908686
  FATE#317538).
- bnx2: Rebranding bnx2 driver (bsc#908686 FATE#317538).
- net: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate
  (bsc#908686 FATE#317538).
- bnx2: Don't build unused suspend/resume functions not enabled
  (bsc#908686 FATE#317538).
- bnx2: Don't receive packets when the napi budget == 0
  (bsc#908686 FATE#317538).
- bnx2: Call dev_kfree_skby_any instead of dev_kfree_skb
  (bsc#908686 FATE#317538).
- bnx2: Fix shutdown sequence (bsc#908686 FATE#317538).
- bnx2: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bsc#908686 FATE#317538).
- bnx2[x]: Make module parameters readable (bsc#908686
  FATE#317538).
- drivers/net: delete non-required instances of include
  <linux/init.h> (bsc#908686 FATE#317538).
- bnx2: Update version to 2.2.5 (bsc#908686 FATE#317538).
- bnx2: Report MDI/MDIX status to ethtool (bsc#908686
  FATE#317538).
- bnx2: Enable auto-mdix when autoneg is disabled (bsc#908686
  FATE#317538).
- bnx2: Advertise nothing when speed is forced (bsc#908686
  FATE#317538).
- net: bnx2 calls skb_set_hash (bsc#908686 FATE#317538).
- net: bnx2: remove unnecessary pci_set_drvdata() (bsc#908686
  FATE#317538).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN
  (bsc#908686 FATE#317538).
- drivers:net: Convert dma_alloc_coherent(...__GFP_ZERO) to
  dma_zalloc_coherent (bsc#908686 FATE#317538).
- bnx2: clean up unnecessary MSI/MSI-X capability find (bsc#908686
  FATE#317538).
- bnx2: Update version to 2.2.4 (bsc#908686 FATE#317538).
- bnx2: Add pci shutdown handler (bsc#908686 FATE#317538).
- bnx2: Use SIMPLE_DEV_PM_OPS (bsc#908686 FATE#317538).
- bnx2: Refactor WoL setup into a separate function (bsc#908686
  FATE#317538).
- bnx2: Use kernel APIs for WoL and power state changes
  (bsc#908686 FATE#317538).
- bnx2: Handle error condition in ->slot_reset() (bsc#908686
  FATE#317538).
- bnx2: use pdev->pm_cap instead of pci_find_capability(..,
  PCI_CAP_ID_PM) (bsc#908686 FATE#317538).
- net/ethernet/broadcom/bnx2: Use module_pci_driver to register
  driver (bsc#908686 FATE#317538).
- bnx2: make cnic_probe static (bsc#908686 FATE#317538).
- bnx2: remove __dev* attributes (bsc#908686 FATE#317538).
- drivers:net: dma_alloc_coherent: use __GFP_ZERO instead of
  memset(, 0) (bsc#908686 FATE#317538).
- remove init of dev->perm_addr in drivers (bsc#908686
  FATE#317538).
- commit f4201b3
* Thu Jan 29 2015 glin@suse.com
- bna: fix skb->truesize underestimation (bsc#909364 FATE#317497).
- bna: allow transmit tagged frames (bsc#909364 FATE#317497).
- bna: use container_of to resolve bufdesc_ex from bufdesc (bsc#909364 FATE#317497).
- bna: Support TSO and partial checksum with non-accelerated vlans (bsc#909364 FATE#317497).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#909364 FATE#317497).
- bna: fix performance regression (bsc#909364 FATE#317497).
- bna: fill the magic in bnad_get_eeprom() instead of validating (bsc#909364 FATE#317497).
- bna: remove unnecessary break after return (bsc#909364 FATE#317497).
- net: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (bsc#909364 FATE#317497).
- net: get rid of SET_ETHTOOL_OPS (bsc#909364 FATE#317497).
- bna: remove open-coded skb_cow_head (bsc#909364 FATE#317497).
- bnad: Call dev_kfree_skb_any instead of dev_kfree_skb (bsc#909364 FATE#317497).
- brocade: Convert uses of __constant_<foo> to <foo> (bsc#909364 FATE#317497).
- bna: Replace large udelay() with mdelay() (bsc#909364 FATE#317497).
- bna: fix vlan tag stripping and implement its toggling (bsc#909364 FATE#317497).
- bna: Use pci_enable_msix_range() instead of pci_enable_msix() (bsc#909364 FATE#317497).
- bnad: code cleanup (bsc#909364 FATE#317497).
- bna: Fix build due to missing use of dma_unmap_len_set() (bsc#909364 FATE#317497).
- bna: Update the Driver Version to 3.2.23.0 (bsc#909364 FATE#317497).
- bna: Firmware Patch Simplification (bsc#909364 FATE#317497).
- bna: Embed SKB Length in TX Vector (bsc#909364 FATE#317497).
- bna: Handle the TX Setup Failures (bsc#909364 FATE#317497).
- bna: Add NULL Check Before Dereferencing TCB (bsc#909364 FATE#317497).
- bna: CQ Read Fix (bsc#909364 FATE#317497).
- bna: RX Processing and Config Changes (bsc#909364 FATE#317497).
- bna: Enable Multi Buffer RX (bsc#909364 FATE#317497).
- bnad: do vlan cleanup (bsc#909364 FATE#317497).
- bna: RX Filter Enhancements (bsc#909364 FATE#317497).
- bna: Fix Filter Add Del (bsc#909364 FATE#317497).
- bna: Set Get IOC fw State (bsc#909364 FATE#317497).
- bna: Add software timestamping support (bsc#909364 FATE#317497).
- bnad: make local variable static (bsc#909364 FATE#317497).
- net: bna: remove unnecessary pci_set_drvdata() (bsc#909364 FATE#317497).
- brocade: Remove extern from function prototypes (bsc#909364 FATE#317497).
- DMA-API: net: brocade/bna/bnad.c: fix 32-bit DMA mask handling (bsc#909364 FATE#317497).
- bna: firmware update to 3.2.1.1 (bsc#909364 FATE#317497).
- bna: Staticize local functions (bsc#909364 FATE#317497).
- lseek(fd, n, SEEK_END) does *not* go to eof - n (bsc#909364 FATE#317497).
- bna: Driver and Firmware Updated (bsc#909364 FATE#317497).
- bna: Enahncement to Identify Default IOC Function (bsc#909364 FATE#317497).
- bna: Fix Ucast Failure Handling (bsc#909364 FATE#317497).
- bna: Clear Driver Config Flags When HW Resets (bsc#909364 FATE#317497).
- bna: add missing iounmap() on error in bnad_init() (bsc#909364 FATE#317497).
- drivers:net: dma_alloc_coherent: use __GFP_ZERO instead of memset(, 0) (bsc#909364 FATE#317497).
- bna: fix declaration mismatch (bsc#909364 FATE#317497).
- commit 761a737
* Wed Jan 28 2015 dchang@suse.com
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (FATE#317396).
- net: get rid of SET_ETHTOOL_OPS (FATE#317396).
- e100: Convert uses of __constant_<foo> to <foo> (FATE#317396).
- e100: Fix "disabling already-disabled device" warning
  (FATE#317396).
- net: e100: remove unnecessary pci_set_drvdata() (FATE#317396).
- e100: dump small buffers via %%*ph (FATE#317396).
- e100: Add dma mapping error check (FATE#317396).
- remove init of dev->perm_addr in drivers (FATE#317396).
- commit 07c9cb6
* Wed Jan 28 2015 glin@suse.com
- Add the missing config QLCNIC_DCB
  also drop the updates for setapp/getapp
- Update config files.
- Refresh
  patches.drivers/qlcnic-0110-qlcnic-dcb-Query-adapter-DCB-capabilities.patch.
- Refresh
  patches.drivers/qlcnic-0228-qlcnic-Add-hwmon-interface-to-export-board-temperatu.patch.
- Delete
  patches.drivers/qlcnic-0250-Update-setapp-getapp-prototypes-in-dcbnl_rtnl_ops-to.patch.
- commit 5242af7
* Tue Jan 27 2015 mszeredi@suse.cz
- fix dcache exit scaling (bnc#876594).
- commit 080ce84
* Tue Jan 27 2015 trenn@suse.de
- Refresh
  forgot quilt refresh -> should build again now...
  patches.arch/mce-amd-check-for-userspace-agent-before-decoding.patch.
- commit 6773e08
* Tue Jan 27 2015 trenn@suse.de
- MCE, AMD: Check for userspace agent before decoding
  (bnc#871881).
- commit b2a380f
* Tue Jan 27 2015 jack@suse.cz
- Add CVE reference to
  patches.fixes/isofs-Fix-unchecked-printing-of-ER-records.patch
  (CVE-2014-9584).
- commit 0aaf2e0
* Tue Jan 27 2015 bpoirier@suse.de
- v2 of be2net sp4 backport following bug#908322c7
- be2net: add FW cmds needed for VxLAN offloads (bnc#908322
  FATE#317535).
- be2net: create optimal number of queues on SR-IOV config
  (bnc#908322 FATE#317535).
- be2net: avoid SRIOV config for BE2 chip (bnc#908322
  FATE#317535).
- be2net: ignore get/set profile FW cmd failures (bnc#908322
  FATE#317535).
- Refresh
  patches.drivers/be2net-0001-be2net-fix-be_close-to-ensure-all-events-are-ack-ed.patch.
- Refresh
  patches.drivers/be2net-0002-be2net-fix-wrong-frag_idx-reported-by-RX-CQ.patch.
- Refresh
  patches.drivers/be2net-0003-ethtool-fix-drvinfo-strings-set-in-drivers.patch.
- Refresh
  patches.drivers/be2net-0004-be2net-fix-unconditionally-returning-IRQ_HANDLED-in-.patch.
- Refresh
  patches.drivers/be2net-0006-be2net-fix-re-loaded-PF-driver-to-re-gain-control-of.patch.
- Refresh
  patches.drivers/be2net-0008-be2net-remove-BUG_ON-in-be_mcc_compl_is_new.patch.
- Refresh
  patches.drivers/be2net-0009-benet-Wait-f-w-POST-until-timeout.patch.
- Refresh
  patches.drivers/be2net-0010-be2net-use-CSR-BAR-SEMAPHORE-reg-for-BE2-BE3.patch.
- Refresh
  patches.drivers/be2net-0012-be2net-enable-interrupts-in-be_probe-RoCE-and-other-.patch.
- Refresh
  patches.drivers/be2net-0013-be2net-Use-new-F-W-mailbox-cmd-to-manipulate-interru.patch.
- Refresh
  patches.drivers/be2net-0014-drivers-net-Remove-dma_alloc_coherent-OOM-messages.patch.
- Refresh
  patches.drivers/be2net-0015-drivers-net-dma_alloc_coherent-use-__GFP_ZERO-instea.patch.
- Refresh
  patches.drivers/be2net-0016-be2net-remove-unused-variable-sge.patch.
- Refresh
  patches.drivers/be2net-0017-be2net-take-care-of-__vlan_put_tag-return-value.patch.
- Refresh
  patches.drivers/be2net-0018-be2net-Use-TXQ_CREATE_V2-cmd.patch.
- Refresh
  patches.drivers/be2net-0019-be2net-Don-t-log-Out-of-MCCQ-wrbs-error.patch.
- Refresh
  patches.drivers/be2net-0020-be2net-Avoid-flashing-BE3-UFI-on-BE3-R-chip.patch.
- Refresh
  patches.drivers/be2net-0021-be2net-Use-GET_PROFILE_CONFIG-V1-cmd-for-BE3-R.patch.
- Refresh
  patches.drivers/be2net-0022-be2net-enable-IOMMU-pass-through-for-be2net.patch.
- Refresh
  patches.drivers/be2net-0023-be2net-Remove-an-incorrect-pvid-check-in-Tx.patch.
- Refresh
  patches.drivers/be2net-0024-be2net-fix-a-Tx-stall-bug-caused-by-a-specific-ipv6-.patch.
- Refresh
  patches.drivers/be2net-0025-be2net-Fix-PVID-tag-offload-for-packets-with-inline-.patch.
- Refresh
  patches.drivers/be2net-0026-be2net-Add-support-for-setting-and-getting-rx-flow-h.patch.
- Refresh
  patches.drivers/be2net-0027-be2net-Renamed-rx_address_mismatch_errors-to-rx_addr.patch.
- Refresh
  patches.drivers/be2net-0028-be2net-Avoid-diagnostic-test-in-certain-versions-of-.patch.
- Refresh
  patches.drivers/be2net-0029-be2net-Fixed-memory-leak.patch.
- Refresh
  patches.drivers/be2net-0030-be2net-Fix-to-show-wol-disabled-enabled-state-correc.patch.
- Refresh
  patches.drivers/be2net-0031-be2net-Use-GET_FUNCTION_CONFIG-V1-cmd.patch.
- Refresh
  patches.drivers/be2net-0032-be2net-FLR-must-be-first-cmd-issued-to-Lancer-FW.patch.
- Refresh
  patches.drivers/be2net-0033-be2net-Fix-to-use-version-2-of-cq_create-for-SkyHawk.patch.
- Refresh
  patches.drivers/be2net-0034-be2net-Fix-to-use-32-bit-stats-to-report-rx_drops_no.patch.
- Refresh
  patches.drivers/be2net-0035-be2net-Fix-to-show-tx-priority-pause-counter-in-etht.patch.
- Refresh
  patches.drivers/be2net-0036-be2net-Fix-to-receive-Multicast-Packets-when-Promisc.patch.
- Refresh
  patches.drivers/be2net-0037-be2net-Fix-firmware-download-for-Lancer.patch.
- Refresh
  patches.drivers/be2net-0038-be2net-avoid-napi_disable-when-it-has-not-been-enabl.patch.
- Refresh
  patches.drivers/be2net-0039-be2net-Fix-to-fail-probe-if-MSI-X-enable-fails-for-a.patch.
- Refresh
  patches.drivers/be2net-0040-be2net-provision-VF-resources-before-enabling-SR-IOV.patch.
- Refresh
  patches.drivers/be2net-0041-be2net-fix-payload_len-value-for-GET_MAC_LIST-cmd-re.patch.
- Refresh
  patches.drivers/be2net-0042-be2net-fix-EQ-from-getting-full-while-cleaning-RX-CQ.patch.
- Refresh
  patches.drivers/be2net-0043-be2net-disable-TX-in-be_close.patch.
- Refresh
  patches.drivers/be2net-0044-be2net-Avoid-double-insertion-of-vlan-tags.patch.
- Refresh
  patches.drivers/be2net-0045-be2net-bug-fix-on-returning-an-invalid-nic-descripto.patch.
- Refresh
  patches.drivers/be2net-0046-be2net-refactor-HW-workarounds-in-be_xmit.patch.
- Refresh
  patches.drivers/be2net-0047-be2net-cleanup-be_get_drvinfo.patch.
- Refresh
  patches.drivers/be2net-0048-be2net-Pad-skb-to-meet-min-Tx-pkt-size-in-lancer.patch.
- Refresh
  patches.drivers/be2net-0049-be2net-Trim-padded-packets-for-Lancer.patch.
- Refresh
  patches.drivers/be2net-0050-be2net-Mark-checksum-fail-for-IP-fragmented-packets.patch.
- Refresh
  patches.drivers/be2net-0051-be2net-Fix-crash-on-2nd-invocation-of-PCI-AER-EEH-er.patch.
- Refresh
  patches.drivers/be2net-0052-be2net-Implement-initiate-FW-dump-feature-for-Lancer.patch.
- Refresh
  patches.drivers/be2net-0053-be2net-Fix-32-bit-DMA-Mask-handling.patch.
- Refresh
  patches.drivers/be2net-0054-be2net-use-pci_vfs_assigned-pci_num_vf-instead-of-be.patch.
- Refresh
  patches.drivers/be2net-0055-net-trivial-replace-numeric-with-standard-PM-state-m.patch.
- Refresh
  patches.drivers/be2net-0056-be2net-Fix-to-avoid-hardware-workaround-when-not-nee.patch.
- Refresh
  patches.drivers/be2net-0057-be2net-fix-MAC-address-modification-for-VF.patch.
- Refresh
  patches.drivers/be2net-0058-be2net-allow-VFs-to-program-MAC-and-VLAN-filters.patch.
- Refresh
  patches.drivers/be2net-0059-be2net-fix-pmac_id-for-BE3-VFs.patch.
- Refresh
  patches.drivers/be2net-0060-be2net-refactor-MAC-addr-setup-code.patch.
- Refresh
  patches.drivers/be2net-0061-be2net-use-SET-GET_MAC_LIST-for-SH-R.patch.
- Refresh
  patches.drivers/be2net-0062-be2net-delete-primary-MAC-address-while-unloading.patch.
- Refresh
  patches.drivers/be2net-0063-be2net-don-t-use-dev_err-when-AER-enabling-fails.patch.
- Refresh
  patches.drivers/be2net-0064-be2net-Staticize-local-functions.patch.
- Refresh
  patches.drivers/be2net-0065-be2net-Adding-more-speeds-reported-by-get_settings.patch.
- Refresh
  patches.drivers/be2net-0066-be2net-Do-not-call-get_die_temperature-cmd-for-VF.patch.
- Refresh
  patches.drivers/be2net-0067-be2net-don-t-limit-max-MAC-and-VLAN-counts.patch.
- Refresh
  patches.drivers/be2net-0068-be2net-Fix-displaying-supported-speeds-for-BE2.patch.
- Refresh
  patches.drivers/be2net-0069-be2net-fixup-log-msgs-for-async-events.patch.
- Refresh
  patches.drivers/be2net-0070-be2net-Initialize-status-in-be_cmd_get_die_temperatu.patch.
- Refresh
  patches.drivers/be2net-0072-be2net-Clear-any-capability-flags-that-driver-is-not.patch.
- Refresh
  patches.drivers/be2net-0073-be2net-fix-disabling-TX-in-be_close.patch.
- Refresh
  patches.drivers/be2net-0074-be2net-Check-for-POST-state-in-suspend-resume-sequen.patch.
- Refresh
  patches.drivers/be2net-0075-be2net-use-EQ_CREATEv2-for-SH-R.patch.
- Refresh
  patches.drivers/be2net-0076-be2net-Fixup-profile-management-routines.patch.
- Refresh
  patches.drivers/be2net-0077-be2net-refactor-be_get_resources-code.patch.
- Refresh
  patches.drivers/be2net-0078-be2net-Fix-be_cmd_if_create-to-use-MBOX-if-MCCQ-is-n.patch.
- Refresh
  patches.drivers/be2net-0079-be2net-refactor-be_setup-to-consolidate-queue-creati.patch.
- Refresh
  patches.drivers/be2net-0080-be2net-implement-ethtool-set-get_channel-hooks.patch.
- Refresh
  patches.drivers/be2net-0081-drivers-net-Convert-dma_alloc_coherent-.__GFP_ZERO-t.patch.
- Refresh
  patches.drivers/be2net-0082-be2net-set-and-query-VEB-VEPA-mode-of-the-PF-interfa.patch.
- Refresh
  patches.drivers/be2net-0083-be2net-missing-variable-initialization.patch.
- Refresh
  patches.drivers/be2net-0084-DMA-API-net-emulex-benet-replace-dma_set_mask-dma_se.patch.
- Refresh
  patches.drivers/be2net-0085-emulex-Remove-extern-from-function-prototypes.patch.
- Refresh
  patches.drivers/be2net-0086-be2net-Fix-to-prevent-Tx-stall-on-SH-R-when-packet-s.patch.
- Refresh
  patches.drivers/be2net-0087-be2net-Fix-the-size-of-be_nic_res_desc-structure.patch.
- Refresh
  patches.drivers/be2net-0088-be2net-Fix-VLAN-promiscuous-mode-programming.patch.
- Refresh
  patches.drivers/be2net-0089-be2net-Fix-number-of-VLANs-supported-in-UMC-mode-for.patch.
- Refresh
  patches.drivers/be2net-0090-be2net-Fix-to-allow-VLAN-configuration-on-VF-interfa.patch.
- Refresh
  patches.drivers/be2net-0091-be2net-Fix-to-configure-VLAN-priority-for-a-VF-inter.patch.
- Refresh
  patches.drivers/be2net-0092-be2net-Fix-to-display-the-VLAN-priority-for-a-VF.patch.
- Refresh
  patches.drivers/be2net-0093-be2net-Call-be_vf_setup-even-when-VFs-are-enbaled-fr.patch.
- Refresh
  patches.drivers/be2net-0094-be2net-pass-if_id-for-v1-and-V2-versions-of-TX_CREAT.patch.
- Refresh
  patches.drivers/be2net-0095-be2net-Create-single-TXQ-on-BE3-R-1G-ports.patch.
- Refresh
  patches.drivers/be2net-0096-be2net-call-ENABLE_VF-cmd-for-Skyhawk-R-too.patch.
- Refresh
  patches.drivers/be2net-0097-be2net-fix-adaptive-interrupt-coalescing.patch.
- Refresh
  patches.drivers/be2net-0098-be2net-add-a-counter-for-pkts-dropped-in-xmit-path.patch.
- Refresh
  patches.drivers/be2net-0099-be2net-Call-version-2-of-GET_STATS-ioctl-for-Skyhawk.patch.
- Refresh
  patches.drivers/be2net-0100-be2net-Display-RoCE-specific-counters-in-ethtool-S.patch.
- Refresh
  patches.drivers/be2net-0102-be2net-Rework-PCIe-error-report-log-messaging.patch.
- Refresh
  patches.drivers/be2net-0103-net-be2net-remove-unnecessary-pci_set_drvdata.patch.
- Refresh
  patches.drivers/be2net-0104-be2net-Warn-users-of-possible-broken-functionality-o.patch.
- Refresh
  patches.drivers/be2net-0105-net-benet-Remove-interface-type.patch.
- Refresh
  patches.drivers/be2net-0106-net-benet-Make-lancer_wait_ready-static.patch.
- Refresh
  patches.drivers/be2net-0107-net-Explicitly-initialize-u64_stats_sync-structures-.patch.
- Refresh
  patches.drivers/be2net-0108-be2net-Fix-unconditional-enabling-of-Rx-interface-op.patch.
- Refresh
  patches.drivers/be2net-0109-be2net-Delete-secondary-unicast-MAC-addresses-during.patch.
- Refresh
  patches.drivers/be2net-0110-be2net-Disabling-and-enabling-interrupts-in-suspend-.patch.
- Refresh
  patches.drivers/be2net-0111-be2net-set-coalesce-wm-in-CQ_CREATE_V2-cmd.patch.
- Refresh
  patches.drivers/be2net-0112-be2net-Avoid-programming-permenant-MAC-by-BE3-R-VFs.patch.
- Refresh
  patches.drivers/be2net-0113-be2net-Fix-Lancer-error-recovery-to-distinguish-FW-d.patch.
- Refresh
  patches.drivers/be2net-0114-be2net-Free-delete-pmacs-in-be_clear-only-if-they-ex.patch.
- Refresh
  patches.drivers/be2net-0115-net-emulex-benet-calls-skb_set_hash.patch.
- Refresh
  patches.drivers/be2net-0116-net-benet-slight-optimization-of-addr-compare.patch.
- Refresh
  patches.drivers/be2net-0117-be2net-disable-RSS-when-number-of-RXQs-is-reduced-to.patch.
- Refresh
  patches.drivers/be2net-0118-be2net-increase-the-timeout-value-for-loopback-test-.patch.
- Refresh
  patches.drivers/be2net-0119-be2net-fix-max_evt_qs-calculation-for-BE3-in-SR-IOV-.patch.
- Refresh
  patches.drivers/be2net-0120-be2net-Use-MCC_CREATE_EXT_V1-cmd-for-Skyhawk-R.patch.
- Refresh
  patches.drivers/be2net-0121-be2net-don-t-set-pport-field-when-querying-pvid.patch.
- Refresh
  patches.drivers/be2net-0122-be2net-Log-the-profile-id-used-by-FW-during-driver-i.patch.
- Refresh
  patches.drivers/be2net-0123-be2net-do-not-call-be_set-get_fw_log_level-on-Skyhaw.patch.
- Refresh
  patches.drivers/be2net-0124-be2net-ignore-mac-addr-set-call-for-an-already-progr.patch.
- Refresh
  patches.drivers/be2net-0125-be2net-fix-incorrect-setting-of-cmd_privileges-for-V.patch.
- Refresh
  patches.drivers/be2net-0127-be2net-do-not-use-frag-index-in-the-RX-compl-entry.patch.
- Refresh
  patches.drivers/be2net-0128-be2net-use-GET_MAC_LIST-cmd-to-query-mac-address-fro.patch.
- Refresh
  patches.drivers/be2net-0129-be2net-cleanup-wake-on-lan-code.patch.
- Refresh
  patches.drivers/be2net-0131-be2net-add-dma_mapping_error-check-for-dma_map_page.patch.
- Refresh
  patches.drivers/be2net-0132-be2net-Fix-be_vlan_add-rem_vid-routines.patch.
- Refresh
  patches.drivers/be2net-0133-be2net-Log-a-kernel-message-when-UE-is-detected-in-B.patch.
- Refresh
  patches.drivers/be2net-0135-be2net-refactor-multi-channel-config-code-for-Skyhaw.patch.
- Refresh
  patches.drivers/be2net-0136-benet-Use-pci_enable_msix_range-instead-of-pci_enabl.patch.
- Refresh
  patches.drivers/be2net-0137-be2net-Fix-to-reset-transparent-vlan-tagging.patch.
- Refresh
  patches.drivers/be2net-0138-be2net-clear-promiscuous-bits-in-adapter-flags-while.patch.
- Refresh
  patches.drivers/be2net-0139-be2net-Fix-skb-double-free-in-be_xmit_wrokarounds-fa.patch.
- Refresh
  patches.drivers/be2net-0140-be2net-isolate-TX-workarounds-not-applicable-to-Skyh.patch.
- Refresh
  patches.drivers/be2net-0141-be2net-dma_sync-each-RX-frag-before-passing-it-to-th.patch.
- Refresh
  patches.drivers/be2net-0142-be2net-do-external-loopback-test-only-when-it-is-req.patch.
- Refresh
  patches.drivers/be2net-0143-be2net-Use-GET_PROFILE_CONFIG-cmd-for-BE3-R-to-query.patch.
- Refresh
  patches.drivers/be2net-0144-be2net-log-LPVID-used-in-multi-channel-configs.patch.
- Refresh
  patches.drivers/be2net-0145-be2net-fix-pmac_id-allocation-size.patch.
- Refresh
  patches.drivers/be2net-0146-be2net-Create-multiple-TXQs-on-RSS-capable-multi-cha.patch.
- Refresh
  patches.drivers/be2net-0147-be2net-Fix-vlans_added-counter.patch.
- Refresh
  patches.drivers/be2net-0149-benet-Call-dev_kfree_skby_any-instead-of-kfree_skb.patch.
- Refresh
  patches.drivers/be2net-0150-net-Replace-u64_stats_fetch_begin_bh-to-u64_stats_fe.patch.
- commit 10bf758
* Tue Jan 27 2015 neilb@suse.de
- NFS: don't use STABLE writes during writeback (bnc#816099).
- commit 939cfc4
* Fri Jan 23 2015 tiwai@suse.de
- drm/cirrus: use drm_set_preferred_mode (bsc#909846).
- drm: add drm_set_preferred_mode (bsc#909846).
- commit 30a49b9
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Own the modules directory in the devel
  package (bnc#910322)
- commit 140bb08
* Fri Jan 23 2015 tonyj@suse.de
- audit: efficiency fix 2: request exclusive wait since all need
  same resource (bnc#908393).
- audit: efficiency fix 1: only wake up if queue shorter than
  backlog limit (bnc#908393).
- audit: make use of remaining sleep time from wait_for_auditd
  (bnc#908393).
- audit: reset audit backlog wait time after error recovery
  (bnc#908393).
- audit: fix endless wait in audit_log_start() (bnc#908393).
- audit: wait_for_auditd() should use TASK_UNINTERRUPTIBLE
  (bnc#908393).
- audit: refactor hold queue flush (bnc#908393).
- kernel/audit.c: avoid negative sleep durations (bnc#908393).
- commit 4526f80
* Thu Jan 22 2015 lduncan@suse.com
- Revert "libiscsi: Added new boot entries in the session sysfs"
  This reverts commit 9125c8ebf08ec8d407eab0a9fd3838fb26606964,
  which violated kABI.
- commit f91a2ee
* Thu Jan 22 2015 lduncan@suse.com
- libiscsi: Added new boot entries in the session sysfs
  (FATE#316723 bsc#914355)
- commit 9125c8e
* Thu Jan 22 2015 tiwai@suse.de
- drm/cirrus: Fix cirrus drm driver for fbdev + qemu
  (bsc#909846,bnc#856760).
- commit 10f5efb
* Thu Jan 22 2015 duwe@suse.de
- Fix POWER8 support patch set:
- powerpc/cputable: Fix oprofile_cpu_type on power8 (bsc#912129,
  FATE#317619).
- powerpc/power8: Fix oprofile and perf (bsc#912129, FATE#317619).
- Refresh patches.arch/powerpc-Add-POWER8-setup-code.
- Refresh
  patches.arch/powerpc-Add-support-for-context-switching-the-TAR-register.
- Refresh patches.arch/powerpc-Fix-context-switch-DSCR-on-POWER8.
- Refresh
  patches.arch/powerpc-Move-initial-mfspr-LPCR-out-of-__init_LPCR.
- Refresh patches.arch/powerpc-POWER8-cputable-entry.
- Refresh
  patches.arch/powerpc-Replace-CPU_FTR_BCTAR-with-CPU_FTR_ARCH_207S.
- Refresh
  patches.arch/powerpc-cputable-Advertise-support-for-ISEL-HTM-DSCR-TAR-on-POWER8.
- Refresh
  patches.arch/powerpc-make-POWER7-setup-code-name-generic.
- Refresh
  patches.arch/powerpc-perf-Add-basic-assembly-code-to-read-BHRB-entries-on-POWER8.
- Refresh patches.arch/ppc-ppr-02-enable-save-restore.
- Refresh patches.arch/ppc-ppr-04-thread_struct-add.
- Refresh patches.arch/ppc-ppr-05-save-restore-macros.
- Refresh patches.suse/powerpc-p8-facility-interrupt.
- commit d6b0c96
* Thu Jan 22 2015 jbohac@suse.cz
- timekeeping: Avoid possible deadlock from clock_was_set_delayed
  (bsc#771619).
- commit 21296ff
* Thu Jan 22 2015 bpoirier@suse.de
- Refresh patches.arch/powerpc-317607-fix_sparse_error.patch.
  A missing context line at the end caused patch to fail when invoking
  sequence-patch.sh --fast:
  patch: **** malformed patch at line 3069787: Subject: [SCSI] ipr: possible irq lock inversion dependency detected
  with
  GNU patch 2.7.1
- commit 2ddc695
* Thu Jan 22 2015 glin@suse.com
- qlcnic: Fix number of arguments in destroy tx context command (bsc#909350 FATE#317546).
- qlcnic: Fix programming number of arguments in a command (bsc#909350 FATE#317546).
- qlcnic: Fix ordering of stats in stats buffer (bsc#909350 FATE#317546).
- qlcnic: Remove __QLCNIC_DEV_UP bit check to read TX queues statistics (bsc#909350 FATE#317546).
- qlcnic: Fix memory corruption while reading stats using ethtool (bsc#909350 FATE#317546).
- qlcnic: Use qlcnic_83xx_flash_read32() API instead of lockless version of the API (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.3.62 (bsc#909350 FATE#317546).
- qlcnic: Add support to run firmware POST (bsc#909350 FATE#317546).
- qlcnic: Use usleep_range() instead of msleep() for sleep less than 20ms (bsc#909350 FATE#317546).
- qlcnic: Add support for 0x8830 device ID (bsc#909350 FATE#317546).
- qlcnic: Update Link speed and port type info for 83xx adapter (bsc#909350 FATE#317546).
- treewide: Fix typo in printk (bsc#909350 FATE#317546).
- qlcnic: Fix endianess issue in firmware load from file operation (bsc#909350 FATE#317546).
- qlcnic: Fix endianess issue in FW dump template header (bsc#909350 FATE#317546).
- qlcnic: Fix flash access interface to application (bsc#909350 FATE#317546).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#909350 FATE#317546).
- net: ethernet: qlogic: qlcnic: Remove duplicate object file from Makefile (bsc#909350 FATE#317546).
- qlcnic: Initialize dcbnl_ops before register_netdev (bsc#909350 FATE#317546).
- qlcnic: Set driver version before registering netdev (bsc#909350 FATE#317546).
- qlcnic: Fix update of ethtool stats (bsc#909350 FATE#317546).
- Update setapp/getapp prototypes in dcbnl_rtnl_ops to return int instead of u8 (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.3.61 (bsc#909350 FATE#317546).
- qlcnic: Enhance Tx timeout debug data collection (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.3.60 (bsc#909350 FATE#317546).
- qlcnic: Optimize ring count validations (bsc#909350 FATE#317546).
- qlcnic: Pre-allocate DMA buffer used for minidump collection (bsc#909350 FATE#317546).
- qlcnic: remove duplicate QLC_83XX_GET_LSO_CAPABILITY define (bsc#909350 FATE#317546).
- qlcnic: Initialize mailbox cmd structure to zero (bsc#909350 FATE#317546).
- qlcnic: info leak in qlcnic_dcb_peer_app_info() (bsc#909350 FATE#317546).
- qlogic: Use time_before() (bsc#909350 FATE#317546).
- net: get rid of SET_ETHTOOL_OPS (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.3.59 (bsc#909350 FATE#317546).
- qlcnic: Collect firmware dump using DMA on 82xx adapters (bsc#909350 FATE#317546).
- qlcnic: Add mac learning support to SR-IOV VF (bsc#909350 FATE#317546).
- qlcnic: Add support to process commands in atomic context (bsc#909350 FATE#317546).
- qlcnic: Allow SR-IOV VF probe in hypervisor (bsc#909350 FATE#317546).
- qlcnic: Set real_num_{tx|rx}_queues properly (bsc#909350 FATE#317546).
- qlcnic: Fix panic while dumping TX queues on TX timeout (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.3.58 (bsc#909350 FATE#317546).
- qlcnic: Limit vNIC support in legacy interrupt mode (bsc#909350 FATE#317546).
- qlcnic: Add driver logs in error path (bsc#909350 FATE#317546).
- qlcnic: Allow setting TX interrupt coalescing parameters from VF (bsc#909350 FATE#317546).
- qlcnic: Add hwmon interface to export board temperature (bsc#909350 FATE#317546).
- qlcnic: Optimize MAC learning code (bsc#909350 FATE#317546).
- qlcnic: Fix memory leak (bsc#909350 FATE#317546).
- qlcnic: Reset firmware API lock at driver load time (bsc#909350 FATE#317546).
- qlcnic: Fix MSI-X initialization code (bsc#909350 FATE#317546).
- qlcnic: Do not disable SR-IOV when VFs are assigned to VMs (bsc#909350 FATE#317546).
- qlcnic: Fix QLogic application/driver interface for virtual NIC configuration (bsc#909350 FATE#317546).
- qlcnic: Fix PVID configuration on eSwitch port (bsc#909350 FATE#317546).
- qlcnic: Fix max ring count calculation (bsc#909350 FATE#317546).
- qlcnic: Fix to send INIT_NIC_FUNC as first mailbox (bsc#909350 FATE#317546).
- qlcnic: Fix panic due to uninitialzed delayed_work struct in use (bsc#909350 FATE#317546).
- net: qlcnic: include irq.h for irq definitions (bsc#909350 FATE#317546).
- qlcnic: Remove casts of pointer to same type (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.3.57 (bsc#909350 FATE#317546).
- qlcnic: dcb: a couple off by one bugs (bsc#909350 FATE#317546).
- qlcnic: Fix number of rings when we fall back from msix to legacy (bsc#909350 FATE#317546).
- qlcnic: Allow any VLAN to be configured from VF (bsc#909350 FATE#317546).
- qlcnic: Fix usage of use_msi and use_msi_x module parameters (bsc#909350 FATE#317546).
- qlcnic: Fix function return error check (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.3.56 (bsc#909350 FATE#317546).
- qlcnic: Enhance semaphore lock access failure error message (bsc#909350 FATE#317546).
- qlcnic: Allow vlan0 traffic (bsc#909350 FATE#317546).
- qlcnic: Enhance driver message in failed state (bsc#909350 FATE#317546).
- qlcnic: Updates to QLogic application/driver interface for virtual NIC configuration (bsc#909350 FATE#317546).
- qlcnic: Re-factor firmware minidump template header handling (bsc#909350 FATE#317546).
- qlcnic: Use pci_enable_msix_range() instead of pci_enable_msix() (bsc#909350 FATE#317546).
- qlcnic: Cleanup qlcnic_enable_msix() return values (bsc#909350 FATE#317546).
- qlcnic: Fix loopback test failure (bsc#909350 FATE#317546).
- qlcnic: Fix tx timeout (bsc#909350 FATE#317546).
- qlcnic: Fix initialization of vlan list (bsc#909350 FATE#317546).
- qlcnic: Correct off-by-one errors in bounds checks (bsc#909350 FATE#317546).
- qlcnic: update version to 5.3.55 (bsc#909350 FATE#317546).
- qlcnic: Enhance logic to calculate msix vectors (bsc#909350 FATE#317546).
- qlcnic: Refactor interrupt coalescing code for all adapters (bsc#909350 FATE#317546).
- qlcnic: Update poll controller code path (bsc#909350 FATE#317546).
- qlcnic: Interrupt code cleanup (bsc#909350 FATE#317546).
- qlcnic: Enhance Tx timeout debugging (bsc#909350 FATE#317546).
- qlcnic: Use bool for rx_mac_learn (bsc#909350 FATE#317546).
- qlcnic: fix sparse warnings (bsc#909350 FATE#317546).
- qlcnic: remove unused code (bsc#909350 FATE#317546).
- qlcnic: make local functions static (bsc#909350 FATE#317546).
- net: qlcnic: fix warning for incorrect type in argument (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.3.54 (bsc#909350 FATE#317546).
- qlcnic: Enable IPv6 LRO even if IP address is not programmed (bsc#909350 FATE#317546).
- qlcnic: Fix SR-IOV cleanup code path (bsc#909350 FATE#317546).
- qlcnic: Enable beaconing for 83xx/84xx Series adapter (bsc#909350 FATE#317546).
- qlcnic: Do MAC learning for SRIOV PF (bsc#909350 FATE#317546).
- qlcnic: Turn on promiscous mode for SRIOV PF (bsc#909350 FATE#317546).
- qlcnic: Enable VF flood bit on PF (bsc#909350 FATE#317546).
- qlcnic: Restrict VF from configuring any VLAN mode (bsc#909350 FATE#317546).
- qlcnic: Convert vmalloc/memset to kcalloc (bsc#909350 FATE#317546).
- qlcnic: Fix ethtool statistics length calculation (bsc#909350 FATE#317546).
- qlcnic: Fix bug in TX statistics (bsc#909350 FATE#317546).
- Merge branch 'master' of git://git.kernel.org/pub/scm/linux/kernel/git/davem/net (bsc#909350 FATE#317546).
- qlcnic: Fix bug in Tx completion path (bsc#909350 FATE#317546).
- qlcnic: Fix resource allocation for TX queues (bsc#909350 FATE#317546).
- qlcnic: Fix loopback diagnostic test (bsc#909350 FATE#317546).
- net: qlcnic: slight optimization of addr compare (bsc#909350 FATE#317546).
- drivers: net: Mark functions as static in qlcnic_83xx_hw.c (bsc#909350 FATE#317546).
- drivers: net: Mark functions as static in qlcnic_io.c (bsc#909350 FATE#317546).
- qlcnic: update version to 5.3.53 (bsc#909350 FATE#317546).
- qlcnic: Support for 16 virtual NIC functions (bsc#909350 FATE#317546).
- qlcnic: VLAN enhancement for 84XX adapters (bsc#909350 FATE#317546).
- qlcnic: Allow single Tx/Rx queue for all adapters (bsc#909350 FATE#317546).
- qlcnic: Refactor initialize nic code path (bsc#909350 FATE#317546).
- qlcnic: Issue INIT_NIC command only once (bsc#909350 FATE#317546).
- qlcnic: Disable DCB operations from SR-IOV VFs (bsc#909350 FATE#317546).
- qlcnic: Dump mailbox registers when mailbox command times out (bsc#909350 FATE#317546).
- qlcnic: Fix mailbox processing during diagnostic test (bsc#909350 FATE#317546).
- qlcnic: Allow firmware dump collection when auto firmware recovery is disabled (bsc#909350 FATE#317546).
- qlcnic: Fix memory allocation (bsc#909350 FATE#317546).
- qlcnic: Fix TSS/RSS validation for 83xx/84xx series adapter (bsc#909350 FATE#317546).
- qlcnic: Fix TSS/RSS ring validation logic (bsc#909350 FATE#317546).
- qlcnic: Fix diagnostic test for all adapters (bsc#909350 FATE#317546).
- qlcnic: Fix usage of netif_tx_{wake, stop} api during link change (bsc#909350 FATE#317546).
- qlcnic: update version to 5.3.52 (bsc#909350 FATE#317546).
- qlcnic: Enable multiple Tx queue support for 83xx/84xx Series adapters (bsc#909350 FATE#317546).
- qlcnic: refactor Tx/SDS ring calculation and validation in driver (bsc#909350 FATE#317546).
- qlcnic: Enhance ethtool Statistics for Multiple Tx queue (bsc#909350 FATE#317546).
- qlcnic: Register netdev in FAILED state for 83xx/84xx (bsc#909350 FATE#317546).
- qlcnic: Do not read QLCNIC_FW_CAPABILITY_MORE_CAPS bit for 83xx adapter (bsc#909350 FATE#317546).
- qlcnic: Do not force adapter to perform LRO without destination IP check (bsc#909350 FATE#317546).
- net: qlcnic: remove unnecessary pci_set_drvdata() (bsc#909350 FATE#317546).
- qlcnic: Validate Tx queue only for 82xx adapters (bsc#909350 FATE#317546).
- qlcnic: update version to 5.3.51 (bsc#909350 FATE#317546).
- qlcnic: Skip unknown entry type while collecting firmware dump (bsc#909350 FATE#317546).
- qlcnic: dcb code cleanup and refactoring (bsc#909350 FATE#317546).
- qlcnic: Remove redundant eSwitch enable commands (bsc#909350 FATE#317546).
- qlcnic: Update ethtool standard pause settings (bsc#909350 FATE#317546).
- qlcnic: Firmware dump collection when auto recovery is disabled (bsc#909350 FATE#317546).
- qlcnic: Enhance ethtool to display ring indices and interrupt mask (bsc#909350 FATE#317546).
- qlcnic: Print informational messages only once during driver load (bsc#909350 FATE#317546).
- treewide: Fix typo in printk (bsc#909350 FATE#317546).
- qlcnic: add missing destroy_workqueue() on error path in qlcnic_probe() (bsc#909350 FATE#317546).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN (bsc#909350 FATE#317546).
- qlcnic: Fix SR-IOV configuration (bsc#909350 FATE#317546).
- qlcnic: Fix register device in FAILED state for 82xx (bsc#909350 FATE#317546).
- qlcnic: Fix VF reset recovery (bsc#909350 FATE#317546).
- qlcnic: Fix warning reported by kbuild test robot (bsc#909350 FATE#317546).
- qlcnic: use standard NAPI weights (bsc#909350 FATE#317546).
- qlcnic: remove a stray semicolon (bsc#909350 FATE#317546).
- qlcnic: Fix sparse warning (bsc#909350 FATE#317546).
- drivers/net: Convert uses of compare_ether_addr to ether_addr_equal (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.3.50 (bsc#909350 FATE#317546).
- qlcnic: Add support for per port eswitch configuration (bsc#909350 FATE#317546).
- qlcnic: Restructuring of qlc_83xx_fw_info structure (bsc#909350 FATE#317546).
- qlcnic: Add AER support for 83xx adapter (bsc#909350 FATE#317546).
- qlcnic: Add AER callback handlers (bsc#909350 FATE#317546).
- qlcnic: Store firmware dump state in CAMRAM register (bsc#909350 FATE#317546).
- qlcnic: Use firmware recommended dump capture mask as default (bsc#909350 FATE#317546).
- qlcnic: Remove inline keyword (bsc#909350 FATE#317546).
- qlcnic: Enhance PVID handling for 84xx adapters (bsc#909350 FATE#317546).
- drivers:net: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (bsc#909350 FATE#317546).
- qlcnic: underflow in qlcnic_validate_max_tx_rings() (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.3.49 (bsc#909350 FATE#317546).
- qlcnic: dcb: Add support for CEE Netlink interface (bsc#909350 FATE#317546).
- qlcnic: dcb: Register DCB AEN handler (bsc#909350 FATE#317546).
- qlcnic: dcb: Get DCB parameters from the adapter (bsc#909350 FATE#317546).
- qlcnic: dcb: Query adapter DCB capabilities (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.3.48 (bsc#909350 FATE#317546).
- qlcnic: Enable diagnostic test for multiple Tx queues (bsc#909350 FATE#317546).
- qlcnic: Enable Tx queue changes using ethtool for 82xx Series adapter (bsc#909350 FATE#317546).
- qlcnic: Multi Tx queue support for 82xx Series adapter (bsc#909350 FATE#317546).
- treewide: Fix typo in printk (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.3.47 (bsc#909350 FATE#317546).
- qlcnic: Add support for 84xx adapters to load firmware from file (bsc#909350 FATE#317546).
- qlcnic: Loopback Inter Driver Communication AEN handler (bsc#909350 FATE#317546).
- qlcnic: Add PVID support for 84xx adapters (bsc#909350 FATE#317546).
- qlcnic: Enable support for 844X adapter (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.2.46 (bsc#909350 FATE#317546).
- qlcnic: Dump mailbox command data when a command times out (bsc#909350 FATE#317546).
- qlcnic: Fix driver initialization for 83xx adapters (bsc#909350 FATE#317546).
- qlcnic: Flush mailbox command list when mailbox is not available (bsc#909350 FATE#317546).
- qlcnic: Reinitialize mailbox data structures after firmware reset (bsc#909350 FATE#317546).
- qlcnic: Fix diagnostic interrupt test for 83xx adapters (bsc#909350 FATE#317546).
- qlcnic: Fix beacon state return status handling (bsc#909350 FATE#317546).
- qlcnic: Fix set driver version command (bsc#909350 FATE#317546).
- qlcnic: Fix for flash update failure on 83xx adapter (bsc#909350 FATE#317546).
- qlcnic: Fix link speed and duplex display for 83xx adapter (bsc#909350 FATE#317546).
- qlcnic: Fix link speed display for 82xx adapter (bsc#909350 FATE#317546).
- qlcnic: Fix external loopback test (bsc#909350 FATE#317546).
- qlcnic: Removed adapter series name from warning messages (bsc#909350 FATE#317546).
- qlcnic: Free up memory in error path (bsc#909350 FATE#317546).
- qlcnic: Fix ingress MAC learning (bsc#909350 FATE#317546).
- qlcnic: Fix MAC address filter issue on 82xx adapter (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.2.45 (bsc#909350 FATE#317546).
- qlcnic: Enable mailbox interface in poll mode when interrupts are not available (bsc#909350 FATE#317546).
- qlcnic: Replace poll mode mailbox interface with interrupt based mailbox interface (bsc#909350 FATE#317546).
- qlcnic: Interrupt based driver firmware mailbox mechanism (bsc#909350 FATE#317546).
- qlcnic: Enhance diagnostic loopback error codes (bsc#909350 FATE#317546).
- qlcnic: Fix diagnostic interrupt test for 83xx adapters (bsc#909350 FATE#317546).
- qlcnic: Fix setting Guest VLAN (bsc#909350 FATE#317546).
- qlcnic: Fix operation type and command type (bsc#909350 FATE#317546).
- qlcnic: Fix initialization of work function (bsc#909350 FATE#317546).
- qlcnic: Fix guest VLAN (bsc#909350 FATE#317546).
- qlcnic: Fix releasing of Tx frag which was never mapped (bsc#909350 FATE#317546).
- qlcnic: Fix dump template version mask (bsc#909350 FATE#317546).
- qlcnic: Fix ethtool display for 83xx adapter (bsc#909350 FATE#317546).
- qlcnic: Fix panic while setting VF's MAC address (bsc#909350 FATE#317546).
- qlcnic: Fix multicast packet handling for PF and VF (bsc#909350 FATE#317546).
- qlcnic: Fix NULL pointer dereference in VF probe path (bsc#909350 FATE#317546).
- qlcnic: Set __QLCNIC_DEV_UP in adapter state before enabling interrupts (bsc#909350 FATE#317546).
- qlcnic: Fix invalid register offset calculation (bsc#909350 FATE#317546).
- qlcnic: Do not sleep while holding spinlock (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.2.44 (bsc#909350 FATE#317546).
- qlcnic: Add support for 83xx suspend and resume (bsc#909350 FATE#317546).
- qlcnic: Add support for 'set driver version' in 83XX (bsc#909350 FATE#317546).
- qlcnic: Cleanup of structure qlcnic_hardware_context (bsc#909350 FATE#317546).
- qlcnic: Add support for PEX DMA method to read memory section of adapter dump (bsc#909350 FATE#317546).
- qlcnic: Minimize sleep duration within loopback diagnostic test (bsc#909350 FATE#317546).
- qlcnic: Secondary unicast MAC address support (bsc#909350 FATE#317546).
- qlcnic: Handle qlcnic_alloc_mbx_args() failure (bsc#909350 FATE#317546).
- net: ethernet: replace strict_strtoul() with kstrtoul() (bsc#909350 FATE#317546).
- qlcnic: remove redundant D0 power state set (bsc#909350 FATE#317546).
- treewide: Fix typo in printk (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.2.43 (bsc#909350 FATE#317546).
- qlcnic: Enhance virtual NIC logging (bsc#909350 FATE#317546).
- qlcnic: qlcnic_get_board_name() function cleanup (bsc#909350 FATE#317546).
- qlcnic: Implement GET_LED_STATUS command for 82xx adapter (bsc#909350 FATE#317546).
- qlcnic: modify reset recovery path in diag mode (bsc#909350 FATE#317546).
- qlcnic: diagnostics routine changes (bsc#909350 FATE#317546).
- qlcnic: Convert nested if-else to switch-case (bsc#909350 FATE#317546).
- qlcnic: Initialize trans_work and idc_aen_work at VF probe (bsc#909350 FATE#317546).
- qlcnic: Remove qlcnic_config_npars module parameter (bsc#909350 FATE#317546).
- qlcnic: Update IRQ name for 8200 and 8300 Series adapter (bsc#909350 FATE#317546).
- qlcnic: Disable INT-x interrupt for 83xx on driver unload (bsc#909350 FATE#317546).
- qlcnic: Support spoof check config (bsc#909350 FATE#317546).
- qlcnic: Fix updating netdev->features (bsc#909350 FATE#317546).
- qlcnic: remove netdev->trans_start updates within the driver (bsc#909350 FATE#317546).
- qlcnic: Return proper error codes from probe failure paths (bsc#909350 FATE#317546).
- qlcnic: Fix validation of link event command (bsc#909350 FATE#317546).
- qlcnic: Fix mailbox response handling (bsc#909350 FATE#317546).
- qlcnic: Fix bug in diagnostics test reset recovery path (bsc#909350 FATE#317546).
- qlcnic: Fix reset recovery after transmit timeout (bsc#909350 FATE#317546).
- qlcnic: Fix ethtool supported port status for 83xx (bsc#909350 FATE#317546).
- qlcnic: Fix missing bracket in module parameter (bsc#909350 FATE#317546).
- qlcnic: Fix ethtool strings (bsc#909350 FATE#317546).
- qlcnic: Fix setting MAC address (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.2.42 (bsc#909350 FATE#317546).
- qlcnic: Add identifying string for 83xx adapter (bsc#909350 FATE#317546).
- qlcnic: Rename the IRQ description (bsc#909350 FATE#317546).
- qlcnic: Enable Interrupt Coalescing for 83xx adapter (bsc#909350 FATE#317546).
- qlcnic: Add eSwitch statistics support (bsc#909350 FATE#317546).
- qlcnic: Take EPORT out of reset sequence before disabling PAUSE (bsc#909350 FATE#317546).
- qlcnic: Enhance channel configuration logs (bsc#909350 FATE#317546).
- qlcnic: Update version to 5.2.41 (bsc#909350 FATE#317546).
- qlcnic: Support polling for mailbox events (bsc#909350 FATE#317546).
- qlcnic: Fix loopback test for SR-IOV PF (bsc#909350 FATE#317546).
- qlcnic: Support VLAN id config (bsc#909350 FATE#317546).
- qlcnic: Support MAC address, Tx rate config (bsc#909350 FATE#317546).
- qlcnic: VF reset recovery implementation (bsc#909350 FATE#317546).
- qlcnic: VF FLR implementation (bsc#909350 FATE#317546).
- qlcnic: Change 82xx adapter VLAN id endian type (bsc#909350 FATE#317546).
- qlcnic: Fix typo in logs (bsc#909350 FATE#317546).
- qlcnic: fix TSO race condition (bsc#909350 FATE#317546).
- qlcnic: Stop traffic before performing loopback test (bsc#909350 FATE#317546).
- qlcnic: fix beaconing test for 82xx adapter (bsc#909350 FATE#317546).
- qlcnic: Bump up the version to 5.2.40 (bsc#909350 FATE#317546).
- qlcnic: Fix sparse warnings (bsc#909350 FATE#317546).
- qlcnic: Fix NULL dereference in error path (bsc#909350 FATE#317546).
- qlcnic: Fix potential NULL dereference (bsc#909350 FATE#317546).
- qlcnic: Bump up the version to 5.2.39 (bsc#909350 FATE#317546).
- qlcnic: Support atomic commands (bsc#909350 FATE#317546).
- qlcnic: Support VF-PF communication channel commands (bsc#909350 FATE#317546).
- qlcnic: VF-PF communication channel implementation (bsc#909350 FATE#317546).
- qlcnic: Use shared interrupt vector for Tx and Rx (bsc#909350 FATE#317546).
- qlcnic: SR-IOV VF probe (bsc#909350 FATE#317546).
- qlcnic: Support SR-IOV enable and disable (bsc#909350 FATE#317546).
- etherdevice: Add ether_addr_equal_unaligned (bsc#909350 FATE#317546).
- commit 8373729
* Wed Jan 21 2015 mmarek@suse.cz
- Fix Module.supported handling for external modules (bnc#905304).
- commit a0c6daf
* Wed Jan 21 2015 duwe@suse.de
- powerpc: Add DSCR FSCR register bit definition (bsc#912129,
  FATE#317619).
- powerpc: Add HWCAP2 aux entry (bsc#912129, FATE#317619).
- powerpc: Add POWER8 architected mode to cputable (bsc#912129,
  FATE#317619).
- powerpc: Add POWER8 setup code (bsc#912129, FATE#317619).
- powerpc: Add new instructions for transactional memory
  (bsc#912129, FATE#317619).
- powerpc: Add second POWER8 PVR entry (bsc#912129, FATE#317619).
- powerpc: Add set_mode hcall (bsc#912129, FATE#317619).
- powerpc: Add support for context switching the TAR register
  (bsc#912129, FATE#317619).
- powerpc: Cleanup handling of the DSCR bit in the FSCR register
  (bsc#912129, FATE#317619).
- powerpc: Context switch the new EBB SPRs (bsc#912129,
  FATE#317619).
- powerpc: Emulate non privileged DSCR read and write (bsc#912129,
  FATE#317619).
- powerpc: Export PIR data through sysfs (bsc#912129,
  FATE#317619).
- powerpc: Fix context switch DSCR on POWER8 (bsc#912129,
  FATE#317619).
- powerpc: Fix regression of per-CPU DSCR setting (bsc#912129,
  FATE#317619).
- powerpc: Fix setting FSCR for HV=0 and on secondary CPUs
  (bsc#912129, FATE#317619).
- powerpc: Move initial mfspr LPCR out of __init_LPCR (bsc#912129,
  FATE#317619).
- powerpc: POWER8 cputable entry (bsc#912129, FATE#317619).
- powerpc: Replace CPU_FTR_BCTAR with CPU_FTR_ARCH_207S
  (bsc#912129, FATE#317619).
- powerpc: Set DSCR bit in FSCR setup (bsc#912129, FATE#317619).
- powerpc: Setup relocation on exceptions for bare metal systems
  (bsc#912129, FATE#317619).
- powerpc: Split __SYSFS_SPRSETUP macro (bsc#912129, FATE#317619).
- powerpc: Turn on the EBB H/FSCR bits (bsc#912129, FATE#317619).
- powerpc/cputable: Advertise DSCR support on P7/P7+ (bsc#912129,
  FATE#317619).
- powerpc/cputable: Advertise support for ISEL/HTM/DSCR/TAR on
  POWER8 (bsc#912129, FATE#317619).
- powerpc/cputable: Reserve bits in HWCAP2 for new features
  (bsc#912129, FATE#317619).
- powerpc/kernel/sysfs: Cleanup set up macros for PMC/non-PMC SPRs
  (bsc#912129, FATE#317619).
- powerpc: make POWER7 setup code name generic (bsc#912129,
  FATE#317619).
- powerpc/perf: Add Power8 cache & TLB events (bsc#912129,
  FATE#317619).
- powerpc/perf: Add basic assembly code to read BHRB entries on
  POWER8 (bsc#912129, FATE#317619).
- powerpc/perf: Add new BHRB related generic functions, data
  and flags (bsc#912129, FATE#317619).
- powerpc/perf: Add new BHRB related instructions for POWER8
  (bsc#912129, FATE#317619).
- powerpc/perf: BHRB filter configuration should follow the task
  (bsc#912129, FATE#317619).
- powerpc/perf: Define BHRB generic functions, data and flags
  for POWER8 (bsc#912129, FATE#317619).
- powerpc/perf: Enable branch stack sampling framework
  (bsc#912129, FATE#317619).
- powerpc/perf: Fix setting of "to" addresses for BHRB
  (bsc#912129, FATE#317619).
- powerpc/perf: Ignore separate BHRB privilege state filter
  request (bsc#912129, FATE#317619).
- powerpc/perf: Move BHRB code into CONFIG_PPC64 region
  (bsc#912129, FATE#317619).
- powerpc/pmu: Fix order of interpreting BHRB target entries
  (bsc#912129, FATE#317619).
- powerpc/power8: Fix secondary CPUs hanging on boot for HV=0
  (bsc#912129, FATE#317619).
- powerpc/pseries: Update ibm,architecture.vec for PAPR 2.7/POWER8
  (bsc#912129, FATE#317619).
- powerpc, pseries: Emulate H_SET_DABR/XDABR as H_SET_MODE on
  POWER8 (bsc#912129, FATE#317619).
- powerpc: Handle facility unavailable exceptions at 0xf60
  (bsc#912129, FATE#317619).
- Refresh patches.arch/powerpc-317607-fix_sparse_error.patch.
  fixes sequence-patch --fast.
- Delete patches.arch/ppc-add-POWER8-cputable-entries and
  patches.fixes/powerpc-add-power8e-cputable-entry.
  Both now replaced with their complete upstream commit.
- commit 275fd0f
* Wed Jan 21 2015 ohering@suse.de
- hyperv: Add IPv6 into the hash computation for vRSS
  (fate#317533).
- commit 44b86db
* Wed Jan 21 2015 ohering@suse.de
- flow_dissector: Use IPv6 flow label in flow_dissector
  (fate#317533).
- ipv6: add ip6_flowlabel helper (fate#317533).
- flow_dissector: add support for IPPROTO_IPV6 (fate#317533).
- ipv6: add ipv6_addr_hash() helper (fate#317533).
- ipv6: optimize ipv6 addresses compares (fate#317533).
- commit f59d34b
* Wed Jan 21 2015 ohering@suse.de
- Reorder patches.suse/ip6_tunnel-add-optional-fwmark-inherit.patch in series.conf
- commit 3e9122a
* Wed Jan 21 2015 tonyj@suse.de
- perf/x86/intel: Add model number for Avoton Silvermont
  (FATE#317406).
- perf/x86: Add Silvermont (22nm Atom) support (FATE#317406).
- perf/x86: use INTEL_UEVENT_EXTRA_REG to define MSR_OFFCORE_RSP_X
  (FATE#317406).
- perf/x86/intel/lbr: Fix LBR filter (FATE#317409).
- perf/x86/intel/lbr: Demand proper privileges for
  PERF_SAMPLE_BRANCH_KERNEL (FATE#317409).
- commit 2f17998
* Tue Jan 20 2015 trenn@suse.de
- Fix zero freq if frequency is requested too quickly in a row
  (bnc#908572).
- commit 8487a0b
* Tue Jan 20 2015 trenn@suse.de
- Fix zero freq if frequency is requested too quickly in a row
  (bnc#908572).
- commit d0be41e
* Tue Jan 20 2015 mhocko@suse.cz
- xfs: re-enable non-blocking behaviour in xfs_map_blocks
  (bnc#900279).
- commit 35eb852
* Tue Jan 20 2015 jack@suse.cz
- xfs: recheck buffer pinned status after push trylock failure
  (bnc#907338).
- xfs: remove log force from xfs_buf_trylock() (bnc#907338).
- commit 83ec907
* Tue Jan 20 2015 glin@suse.com
- config: enable CONFIG_QLCNIC_SRIOV and CONFIG_QLCNIC_HWMON
  For the updated qlcnic (bsc#909350, FATE#317546)
- commit 9a603f8
* Tue Jan 20 2015 jbeulich@suse.com
- x86-64/MCE: flip CPU and bank numbers in log message.
- scsifront: avoid acquiring same lock twice if ring is full.
- patches.xen/xen-privcmd-hcall-preemption: Fix EFLAGS.IF access.
- x86-64, espfix: Don't leak bits 31:16 of %%esp returning to
  16-bitstack (bsc#907818,CVE-2014-9090).
- x86, espfix: Make it possible to disable 16-bit support
  (bsc#907818,CVE-2014-9090).
- x86_64/entry/xen: Do not invoke espfix64 on Xen
  (bsc#907818,CVE-2014-9090).
- x86_64, traps: Fix the espfix64 #DF fixup and rewrite it in C
  (bsc#907818,CVE-2014-9090).
- x86_64, traps: Rework bad_iret (bsc#909077,CVE-2014-8133).
- x86_64, traps: Stop using IST for #SS (bsc#907818,
  CVE-2014-9090, CVE-2014-9322).
- Refresh other Xen patches.
- commit 14991f8
* Mon Jan 19 2015 bp@suse.de
- x86_64, vdso: Fix the vdso address randomization algorithm
  (bsc#912705, CVE-2014-9585).
- commit c897808
* Mon Jan 19 2015 mszeredi@suse.cz
- Refresh patches.fixes/deal-with-deadlock-in-d_walk.patch.
- Refresh
  patches.fixes/move-d_rcu-from-overlapping-d_child-to-overlapping-d.patch.
- Refresh patches.fixes/reiserfs-xattr-crash-fix.
- Refresh patches.kabi/kabi-fix-for-move-d_rcu.patch.
- Delete
  patches.suse/kdb-move-d_rcu-from-overlapping-d_child.patch.
- commit b84a230
* Mon Jan 19 2015 mszeredi@suse.cz
- Refresh patches.kabi/kabi-fix-for-move-d_rcu.patch.
- commit 0a2de8e
* Mon Jan 19 2015 hare@suse.de
- Reshuffle patches to apply.
- commit fec8617
* Mon Jan 19 2015 hare@suse.de
- sd: medium access timeout counter fails to reset (bnc#894213).
- commit 0c5ba0f
* Mon Jan 19 2015 hare@suse.de
- sd: medium access timeout counter fails to reset (bnc#894213).
- commit e436849
* Fri Jan 16 2015 ohering@suse.de
- hyperv: Add handling of IP header with option field in
  netvsc_set_hash() (fate#317533).
- commit 95b28b9
* Fri Jan 16 2015 ohering@suse.de
- hv_netvsc: include net/flow_keys.h (fate#317533).
- commit 0006acc
* Fri Jan 16 2015 mszeredi@suse.cz
- deal with deadlock in d_walk() (bnc#903640 CVE-2014-8559).
- commit de6de17
* Fri Jan 16 2015 mszeredi@suse.cz
- move d_rcu from overlapping d_child to overlapping d_alias
  (bnc#903640 CVE-2014-8559).
- kabi: fix for move of d_rcu (bnc#903640 CVE-2014-8559).
- kdb: move d_rcu from overlapping d_child to overlapping d_alias
  (bnc#903640 CVE-2014-8559).
- Refresh patches.fixes/reiserfs-xattr-crash-fix.
- commit 8ba0cef
* Fri Jan 16 2015 jkosina@suse.cz
- Refresh
  patches.drivers/lpfc-8.3.39-Fixed-driver-vector-mapping-to-CPU-xen-buildfix.patch:
  fix build
- commit 0dfd22d
* Fri Jan 16 2015 jkosina@suse.cz
- x86: lpfc: fix Xen build due to different struct cpuinfo_x86.
- Refresh
  patches.drivers/lpfc-8.3.42-Fix-crash-on-driver-load-due-to-cpu.patch.
- commit 3ea3414
* Fri Jan 16 2015 ohering@suse.de
- Reorder two patches in series.conf
- commit 677831f
* Fri Jan 16 2015 ohering@suse.de
- flow_keys: Record IP layer protocol in skb_flow_dissect()
  (fate#317533).
- net: flow_dissector: small optimizations in IPv4 dissect
  (fate#317533).
- net: flow_dissector: fail on evil iph->ihl (fate#317533).
- flow_dissector: factor out the ports extraction in
  skb_flow_get_ports (fate#317533).
- commit bedc1a8
* Fri Jan 16 2015 ohering@suse.de
- net: flow_dissector: fix thoff for IPPROTO_AH (fate#317533).
- flow.h/flow_keys.h: Remove extern from function prototypes
  (fate#317533).
- commit 9d6db8f
* Fri Jan 16 2015 ohering@suse.de
- flow_dissector: clean up IPIP case (fate#317533).
- flow_keys: include thoff into flow_keys for later usage
  (fate#317533).
- commit 63370bf
* Fri Jan 16 2015 ohering@suse.de
- flow_dissector: use a 64bit load/store (fate#317533).
- net: introduce skb_flow_dissect() (fate#317533).
- commit a992f06
* Fri Jan 16 2015 ohering@suse.de
- ip: introduce ip_is_fragment helper inline function
  (fate#317533).
- commit 3b3bea1
* Fri Jan 16 2015 dvaleev@suse.com
- ipr: Increase msi-x interrupt vectors to 16 (fate#317607).
- ipr: convert to generic DMA API (fate#317607).
- ipr: Remove extended delay bit on GSCSI reads/writes ops
  (fate#317607).
- [SCSI] ipr: Handle early EEH (fate#317607).
- ipr: fix compile failure.
- ipr: don't log error messages when applications issues illegal
  requests (fate#317607).
- ipr: Fix sparse error in ipr driver (fate#317607).
- [SCSI] ipr: Add new CCIN definition for Grand Canyon support
  (fate#317607).
- ipr: increase dump size in ipr driver (fate#317607).
- [SCSI] ipr: reorder error handling code to include iounmap
  (fate#317607).
- ipr: possible irq lock inversion dependency detected
  (fate#317607).
- ipr: wait for aborted command responses  (fate#317607).
- ipr: qc_fill_rtf() method should not store alternate status
  register (fate#317607).
- ipr: IOA Status Code(IOASC) update (fate#317607).
- [SCSI] ipr: Format HCAM overlay ID 0x21 (fate#317607).
- ipr: Add sereral new CCIN definitions for new adapters support
  (fate#317607).
- ipr: Add new CCIN definition for new hardware support
  (fate#317607).
- powerpc/crypto: Remove users of virt_to_abs() and phys_to_abs()
  in nx crypto driver (fate#317629).
- powerpc+of: Add of node/property notification chain for adds
  and removes  (fate#317629).
- Drivers: crypto: remove __dev* attributes.  (fate#317629).
- crypto: drivers - remove cra_list initialization  (fate#317629).
- drivers/crypto/nx: Fixes for multiple races and issues
  (fate#317629).
- Mainline 95ead5d7ff824a01cb07921c9211a7e29437a929 (fate#317629).
- powerpc/pseries: Add pseries update notifier for OFDT prop
  changes (fate#317629).
- crypto: nx - fix typo in nx driver config option.
- crypto: nx - fix physical addresses added to sg lists
  (fate#317629).
- crypto: nx - fix limits to sg lists for SHA-2 (fate#317629).
- crypto: nx - saves chaining value from co-processor
  (fate#317629).
- crypto: nx - fix concurrency issue (fate#317629).
- crypto: nx - fix nx-aes-gcm verification (fate#317629).
- crypto: nx - add offset to nx_build_sg_lists() (fate#317629).
- crypto: nx - fix limits to sg lists for AES-ECB (fate#317629).
- crypto: nx - fix limits to sg lists for AES-CBC (fate#317629).
- crypto: nx - fix limits to sg lists for AES-CTR (fate#317629).
- crypto: nx - fix limits to sg lists for AES-GCM (fate#317629).
- crypto: nx - fix limits to sg lists for AES-XCBC (fate#317629).
- crypto: nx - fix limits to sg lists for AES-CCM (fate#317629).
- crypto: nx - fix XCBC for zero length messages (fate#317629).
- crypto: nx - fix GCM for zero length messages (fate#317629).
- crypto: nx - fix SHA-2 for chunks bigger than block size
  (fate#317629).
- powerpc: Enable pseries hardware RNG and crypto modules
  (fate#317629).
- powerpc/crypto: rework Kconfig  (fate#317629).
- Update config files.
- Delete
  patches.arch/ppc-nxcrypt-fix-init-race-alignmasks-and-GCM-bug.
- Delete patches.arch/ppc-nxcrypt-sles11sp3-beta4-fixes2.
- commit 2ff508f
* Fri Jan 16 2015 hare@suse.de
- lpfc: update lpfc version to driver version 10.4.8000.0
  (bnc#908903,FATE#317536).
- lpfc: fix for handling unmapped ndlp in target reset handler
  (bnc#908903,FATE#317536).
- lpfc: fix low priority issues from fortify source code scan
  (bnc#908903,FATE#317536).
- lpfc: fix high priority issues from fortify source code scan
  (bnc#908903,FATE#317536).
- lpfc: fix crash from page fault caused by use after rport delete
  (bnc#908903,FATE#317536).
- lpfc: fix locking issues with abort data paths
  (bnc#908903,FATE#317536).
- lpfc: fix race between LOGO/PLOGI handling causing NULL pointer
  (bnc#908903,FATE#317536).
- lpfc: fix IP Reset processing - wait for RDY before proceeding
  (bnc#908903,FATE#317536).
- lpfc: fix quarantined XRI recovery qualifier state in link
  bounce (bnc#908903,FATE#317536).
- lpfc: fix discovery timeout during nameserver login
  (bnc#908903,FATE#317536).
- lpfc: do not feed jiffies as random seed from lpfc driver
  (bnc#908903,FATE#317536).
- lpfc: mark function as static in lpfc/lpfc_bsg.c
  (bnc#908903,FATE#317536).
- lpfc: mark functions as static in lpfc/lpfc_scsi.c
  (bnc#908903,FATE#317536).
- lpfc: mark functions as static in lpfc/lpfc_init.c
  (bnc#908903,FATE#317536).
- lpfc: mark functions as static in lpfc/lpfc_hbadisc.c
  (bnc#908903,FATE#317536).
- lpfc: mark functions as static in lpfc/lpfc_sli.c
  (bnc#908903,FATE#317536).
- lpfc: Remove superfluous call to pci_disable_msix()
  (bnc#908903,FATE#317536).
- lpfc: Update lpfc version to driver version 10.2.8001.0
  (bnc#908903,FATE#317536).
- lpfc: Fix ExpressLane priority setup (bnc#908903,FATE#317536).
- lpfc: Fix for initializing RRQ bitmap (bnc#908903,FATE#317536).
- lpfc: Fix for cleaning up stale ring flag and sp_queue_event
  entries (bnc#908903,FATE#317536).
- lpfc: Update lpfc version to driver version 10.2.8000.0
  (bnc#908903,FATE#317536).
- lpfc: Update Copyright on changed files from 8.3.45 patches
  (bnc#908903,FATE#317536).
- lpfc: Update Copyright on changed files
  (bnc#908903,FATE#317536).
- lpfc: Fixed locking for scsi task management commands
  (bnc#908903,FATE#317536).
- lpfc: Convert runtime references to old xlane cfg param to
  fof cfg (bnc#908903,FATE#317536).
- lpfc: Fix FW dump using sysfs (bnc#908903,FATE#317536).
- lpfc: Fix SLI4 s abort loop to process all FCP rings and under
  (bnc#908903,FATE#317536).
- lpfc: Fixed kernel panic in lpfc_abort_handler
  (bnc#908903,FATE#317536).
- lpfc: Fix locking for postbufq when freeing
  (bnc#908903,FATE#317536).
- lpfc: Fix locking for lpfc_hba_down_post
  (bnc#908903,FATE#317536).
- lpfc: Fix dynamic transitions of FirstBurst from on to off
  (bnc#908903,FATE#317536).
- lpfc: Add iotag memory barrier (bnc#908903,FATE#317536).
- lpfc: use NULL instead of 0 for pointer
  (bnc#908903,FATE#317536).
- lpfc: remove self-assignments (bnc#908903,FATE#317536).
- lpfc 8.3.45: Update lpfc version to driver version 8.3.45
  (bnc#908903,FATE#317536).
- lpfc 8.3.45: Fixed crash during driver unload
  (bnc#908903,FATE#317536).
- lpfc 8.3.45: Fixed driver error messages after firmware
  (bnc#908903,FATE#317536).
- lpfc 8.3.45: Fixed missing initialization for task management
  (bnc#908903,FATE#317536).
- lpfc 8.3.45: Fix sysfs buffer overrun in read of
  (bnc#908903,FATE#317536).
- lpfc 8.3.45: Incorporate changes to use reason in
  (bnc#908903,FATE#317536).
- lpfc 8.3.45: Incorporated support of a low-latency io path
  (bnc#908903,FATE#317536).
- lpfc 8.3.45: Added dport mailbox pass through support
  (bnc#908903,FATE#317536).
- lpfc 8.3.44: Update lpfc version to driver version 8.3.44
  (bnc#908903,FATE#317536).
- lpfc 8.3.44: Fixed unassigned variable in ELS timeout message
  (bnc#908903,FATE#317536).
- lpfc 8.3.44: Fixed incorrect allocation of iDiags
  (bnc#908903,FATE#317536).
- lpfc 8.3.44: Fix kernel panics from corrupted ndlp list
  (bnc#908903,FATE#317536).
- lpfc 8.3.44: Fix Crash in lpfc_els_timeout_handler
  (bnc#908903,FATE#317536).
- lpfc 8.3.44: Fixed stopped FCF discovery on failed FCF record
  (bnc#908903,FATE#317536).
- lpfc 8.3.44: Fixed IO hang when in msi mode
  (bnc#908903,FATE#317536).
- lpfc: Fix wrong assignment in lpfc_debugfs.c
  (bnc#908903,FATE#317536).
- lpfc: Fix typo on NULL assignment (bnc#908903,FATE#317536).
- lpfc 8.3.43: Update lpfc version to driver version 8.3.43
  (bnc#908903,FATE#317536).
- lpfc 8.3.43: Fixed not processing task management IOCB
  (bnc#908903,FATE#317536).
- lpfc 8.3.43: Fixed spinlock hang (bnc#908903,FATE#317536).
- lpfc 8.3.43: Fixed invalid Total_Data_Placed value received
  (bnc#908903,FATE#317536).
- lpfc 8.3.43: Fixed invalid fcp_rsp length fir FCP_ICMND
  (bnc#908903,FATE#317536).
- lpfc 8.3.43: Fixed invalid mailbox timeouts
  (bnc#908903,FATE#317536).
- lpfc 8.3.43: Fixed spinlock inversion problem
  (bnc#908903,FATE#317536).
- lpfc 8.3.43: Fix crash after xri limit is reached
  (bnc#908903,FATE#317536).
- lpfc: remove unnecessary read of PCI_CAP_ID_EXP
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Update lpfc version to driver version 8.3.42
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fixed issue of task management commands having a
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fixed inconsistent spin lock usage
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fix driver's abort loop functionality to skip IOs
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fixed failure to allocate SCSI buffer on PPC64
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fix WARN_ON when driver unloads
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Avoided making pci bar ioremap call during
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fixed driver iocbq structure's iocb_flag field
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fix crash on driver load due to cpu affinity
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fixed logging format of setting driver sysfs
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fixed back to back RSCNs discovery failure
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fixed race condition between BSG I/O dispatch and
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fixed function mode field defined too small for
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Back out data count,(residual fcfi_parm) fix for
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fixed mailbox memory leak (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fix random errors using first burst
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fixed not able to log informational messages at
  (bnc#908903,FATE#317536).
- lpfc 8.3.42: Fixed using unsafe linked list macro for walking
  (bnc#908903,FATE#317536).
- lpfc: Removed obsolete fcp_eq_count and fcp_wq_count driver
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Update lpfc version to driver version 8.3.41
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Update copyrights for 8.3.41 modifications
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Fixed the format of some log message fields
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Add first burst support to driver
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Fixed not able to perform PCI function reset when
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Fixed failure in setting SLI3 board mode
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Fixed SLI3 failing FCP write on check-condition
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Fixed support for 128 byte WQEs
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Ensure driver properly zeros unused fields in
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Fixed max value of lpfc_lun_queue_depth
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Fixed Receive Queue varied frame size handling
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Fix mailbox byteswap issue on PPC
  (bnc#908903,FATE#317536).
- lpfc 8.3.41: Fixed freeing of iocb when internal loopback
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Update lpfc version to driver version 8.3.40
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Update Copyrights to 2013 for 8.3.38, 8.3.39,
  and (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fixed a race condition between SLI host and port
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fixed issue mailbox wait routine failed to issue
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fixed system panic due to unsafe walking and
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fixed FCoE connection list vlan identifier and
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Clarified the behavior of the lpfc_max_luns
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fix to allow OCM to report FEC status
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fixed a missing return code in a logging message
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fixed some logging message fields
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fixed list corruption when lpfc_drain_tx runs
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fix starting reference tag when calculating BG
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fix inconsistent list removal causes crash
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fixed system panic during handling unsolicited
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fix BlockGuard error checking
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fixed crash during FCoE failover testing
  (bnc#908903,FATE#317536).
- lpfc 8.3.40: Fix lpfc_used_cpu to be more dynamic
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Update lpfc version for 8.3.39 driver release
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fixed driver handling of CLEAR_LA with NPIV
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Reduced tmo value set to FLOGI WQE for quick
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Add log message when completes with clean address
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fixed driver vector mapping to CPU affinity
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fixed iocb flags not being reset for scsi
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fixed system panic during EEH recovery due to
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fixed not returning FAILED status when SCSI
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fixed bad book keeping in posting els sgls to
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fixed deadlock between hbalock and nlp_lock use
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fixed BlockGuard to take advantage of
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Reduced spinlock contention on SCSI buffer list
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fixed crash when processing bsg's sg list with
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Remove lpfc_fcp_look_ahead module parameter
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fix driver issues with SCSI Host reset
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Doorbell formation information logged in
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fix driver issues with large s/g lists for
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fix driver issues with large lpfc_sg_seg_cnt
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fixed pt2pt and loop discovery problems on
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Remove driver dependency on HZ
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fixed BlockGuard error reporting
  (bnc#908903,FATE#317536).
- lpfc 8.3.39: Fixed VPI allocation issues after firmware dump
  (bnc#908903,FATE#317536).
- lpfc: fix races for miscdevice open vs. rmmod
  (bnc#908903,FATE#317536).
- lpfc: fix potential NULL pointer dereference in
  (bnc#908903,FATE#317536).
- lpfc 8.3.38: Update lpfc version for 8.3.38 driver release
  (bnc#908903,FATE#317536).
- lpfc 8.3.38: Fixed potential mis-interpretation of
  (bnc#908903,FATE#317536).
- lpfc 8.3.38: Fix default value for lpfc_enable_rrq
  (bnc#908903,FATE#317536).
- lpfc 8.3.38: Fixed circular locking dependency and
  (bnc#908903,FATE#317536).
- lpfc 8.3.38: Fixed PT2PT bring up problem for FC SLI4
  (bnc#908903,FATE#317536).
- lpfc 8.3.38: Fixed OXID reuse issue (bnc#908903,FATE#317536).
- lpfc 8.3.38: Fixed async FCF modified event to in-use FCF
  (bnc#908903,FATE#317536).
- lpfc 8.3.38: Fixed deadlock condition in FCF round robin
  (bnc#908903,FATE#317536).
- scsilpfc 8.3.38: Fixed bsg timeout handling issues that would
  (bnc#908903,FATE#317536).
- lpfc 8.3.38: Fixed degraded performance after cable pulls
  (bnc#908903,FATE#317536).
- lpfc 8.3.38: Fixed NMI watch dog panic's when resetting the
  (bnc#908903,FATE#317536).
- commit cba4e57
* Fri Jan 16 2015 hare@suse.de
- Remove non-standard patches in preparation for the lpfc update (bnc#908903,FATE#317536)
- Delete
  patches.drivers/Update-lpfc-version-for-8.3.7.7.1p-driver-release.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.1p-driver-panic-during-eeh.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.2p-Fix-driver-issues-with-SCSI-Host-reset.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.2p-Fixed-async-FCF-modified-event-to-in-use.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.2p-Fixed-bad-book-keeping-in-posting-els-sgls-to-port.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.2p-Fixed-crash-when-processing-bsg-s-sg-list-with-high-.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.2p-Fixed-deadlock-between-hbalock-and-nlp_lock-use.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.2p-Fixed-not-returning-FAILED-status-when-SCSI-invoking.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.2p-Update-lpfc-version-for-8.3.7.10.3p-driver-release.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.3p-Update-lpfc-version-for-8.3.7.10.5p-driver-release.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.3p-fix-unsafe-walking-and-delete-linked-list.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.5p-Update-lpfc-version-for-8.3.7.10.6p-driver-release.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.6p-Fix-Crash-in-lpfc_els_timeout_handler.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.6p-Fix-kernel-panic-from-corrupted-ndlp-list.patch.
- Delete
  patches.drivers/lpfc-8.3.7.10.6p-Update-lpfc-version-for-8.3.7.10.7p-driver-release.patch.
- Delete
  patches.drivers/lpfc-8.3.7.7.1p-Fix-default-value-for-lpfc_enable_rrq.patch.
- Delete
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-NMI-watch-dog-panic-s-when-resetting-the-hba.patch.
- Delete
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-OXID-reuse-issue.patch.
- Delete
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-PT2PT-bring-up-problem-for-FC-SLI4.patch.
- Delete
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-async-FCF-modified-event-to-in-use-FCF-failure.patch.
- Delete
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-bsg-timeout-handling-issues-that-would-result-.patch.
- Delete
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-circular-locking-dependency-and-inconsistent-l.patch.
- Delete
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-deadlock-condition-in-FCF-round-robin-handling.patch.
- Delete
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-degraded-performance-after-cable-pulls.patch.
- Delete
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-potential-mis-interpretation-of-READ_TOPOLOGY-.patch.
- Delete
  patches.drivers/lpfc-8.3.7.7.1p-Update-lpfc-version-for-8.3.7.10.1p-driver-release.patch.
- Delete
  patches.drivers/lpfc-8.3.7.7.1p-fix-potential-NULL-pointer-dereference-in-lpfc_sli4_.patch.
- Delete
  patches.drivers/lpfc-Fixed-SLI3-failing-FCP-write-on-che.patch.
- Delete
  patches.drivers/lpfc-Fixed-issue-of-task-management-commands-.patch.
- Delete
  patches.drivers/lpfc-revert-Fixed-async-FCF-modified-event.patch.
- commit e215634
* Fri Jan 16 2015 hare@suse.de
- hpsa: silence gcc warning (bnc#913241,FATE#317338).
- hpsa: Remove pre-production leftovers (bnc#913241,FATE#317338).
- hpsa: remove spin lock around command allocation
  (bnc#913241,FATE#317338).
- hpsa: always call pci_set_master after pci_enable_device
  (bnc#913241,FATE#317338).
- hpsa: Convert SCSI LLD ->queuecommand() for host_lock less
  operation (bnc#913241,FATE#317338).
- hpsa: do not be so noisy about check conditions
  (bnc#913241,FATE#317338).
- hpsa: use atomics for commands_outstanding
  (bnc#913241,FATE#317338).
- hpsa: get rid of type/attribute/direction bit field where
  possible (bnc#913241,FATE#317338).
- hpsa: fix endianness issue with scatter gather elements
  (bnc#913241,FATE#317338).
- hpsa: fix allocation sizes for CISS_REPORT_LUNs commands
  (bnc#913241,FATE#317338).
- hpsa: remove 'action required' phrasing
  (bnc#913241,FATE#317338).
- hpsa: correct off-by-one sizing of chained SG block
  (bnc#913241,FATE#317338).
- hpsa: remove dev_warn prints from RAID-1ADM
  (bnc#913241,FATE#317338).
- hpsa: Clean up warnings from sparse (bnc#913241,FATE#317338).
- MAINTAINERS: change hpsa and cciss maintainer
  (bnc#913241,FATE#317338).
- hpsa: add missing pci_set_master in kdump path
  (bnc#913241,FATE#317338).
- hpsa: refine the pci enable/disable handling
  (bnc#913241,FATE#317338).
- hpsa: Fallback to MSI rather than to INTx if MSI-X failed
  (bnc#913241,FATE#317338).
- hpsa: fix bad -ENOMEM return value in hpsa_big_passthru_ioctl
  (bnc#913241,FATE#317338).
- hpsa: remove online devices from offline device list
  (bnc#913241,FATE#317338).
- hpsa: fix non-x86 builds (bnc#913241,FATE#317338).
- hpsa: do not unconditionally copy sense data
  (bnc#913241,FATE#317338).
- hpsa: fix 6-byte READ/WRITE with 0 length data xfer
  (bnc#913241,FATE#317338).
- hpsa: make hpsa_init_one return -ENOMEM if allocation of
  (bnc#913241,FATE#317338).
- hpsa: fix handling of hpsa_volume_offline return value
  (bnc#913241,FATE#317338).
- hpsa: return -ENOMEM not -1 on kzalloc failure in
  hpsa_get_device_id (bnc#913241,FATE#317338).
- hpsa: remove messages about volume status VPD inquiry page not
  (bnc#913241,FATE#317338).
- hpsa: report check condition even if no sense data present for
  (bnc#913241,FATE#317338).
- hpsa: remove bad unlikely annotation from device list updating
  code (bnc#913241,FATE#317338).
- hpsa: kill annoying messages about SSD Smart Path retries
  (bnc#913241,FATE#317338).
- hpsa: define extended_report_lun_entry data structure
  (bnc#913241,FATE#317338).
- hpsa: Rearrange start_io to avoid one unlock/lock sequence in
  main io (bnc#913241,FATE#317338).
- hpsa: avoid unnecessary readl on every command submission
  (bnc#913241,FATE#317338).
- hpsa: use per-cpu variable for lockup_detected
  (bnc#913241,FATE#317338).
- hpsa: set irq affinity hints to route MSI-X vectors across CPUs
  (bnc#913241,FATE#317338).
- hpsa: allocate reply queues individually
  (bnc#913241,FATE#317338).
- hpsa: choose number of reply queues more intelligently
  (bnc#913241,FATE#317338).
- hpsa: use gcc aligned attribute instead of manually padding
  structs (bnc#913241,FATE#317338).
- hpsa: change doorbell reset delay to ten seconds
  (bnc#913241,FATE#317338).
- hpsa: remove unused fields from struct ctlr_info
  (bnc#913241,FATE#317338).
- hpsa: fix bad comparison of signed with unsigned in
  (bnc#913241,FATE#317338).
- hpsa: do not ignore failure of sense controller parameters
  command (bnc#913241,FATE#317338).
- hpsa: fix memory leak in hpsa_hba_mode_enabled
  (bnc#913241,FATE#317338).
- hpsa: add new Smart Array PCI IDs (May 2014)
  (bnc#913241,FATE#317338).
- hpsa: Checking for a NULL return from a kzalloc call
  (bnc#913241,FATE#317338).
- hpsa: fix NULL dereference in
  hpsa_put_ctlr_into_performant_mode() (bnc#913241,FATE#317338).
- hpsa: update driver version to 3.4.4-1 (bnc#913241,FATE#317338).
- hpsa: fix bad endif placement in RAID 5 mapper code
  (bnc#913241,FATE#317338).
- hpsa: Do not zero fields of ioaccel2 command structure twice
  (bnc#913241,FATE#317338).
- hpsa: Add hba mode to the hpsa driver (bnc#913241,FATE#317338).
- hpsa: increase the probability of a reported success after a
  device (bnc#913241,FATE#317338).
- hpsa: bring format-in-progress drives online when ready
  (bnc#913241,FATE#317338).
- hpsa: remove unused kthread.h header (bnc#913241,FATE#317338).
- hpsa: Add support for a few HP Storage controllers
  (bnc#913241,FATE#317338).
- hpsa: add HP/3PAR vendor id to pci_ids.h
  (bnc#913241,FATE#317338).
- hpsa add sysfs debug switch for raid map debugging messages
  (bnc#913241,FATE#317338).
- hpsa: improve error messages for driver initiated commands
  (bnc#913241,FATE#317338).
- hpsa: only do device rescan for certain events
  (bnc#913241,FATE#317338).
- hpsa: when switching out of accel mode await only accel
  (bnc#913241,FATE#317338).
- hpsa: add controller base data-at-rest encryption
  (bnc#913241,FATE#317338).
- hpsa: update source file copyrights (bnc#913241,FATE#317338).
- hpsa: retry certain ioaccel error cases on the RAID path
  (bnc#913241,FATE#317338).
- hpsa: do not inquire for unsupported ioaccel status vpd page
  (bnc#913241,FATE#317338).
- hpsa: allow VPD page zero to be queried
  (bnc#913241,FATE#317338).
- hpsa: rescan devices on ioaccel2 error (bnc#913241,FATE#317338).
- hpsa: allow user to disable accelerated i/o path
  (bnc#913241,FATE#317338).
- hpsa: complete the ioaccel raidmap code
  (bnc#913241,FATE#317338).
- hpsa: make device update copy the raid map also
  (bnc#913241,FATE#317338).
- hpsa: add task management for ioaccel mode 2
  (bnc#913241,FATE#317338).
- hpsa: teach hpsa_device_reset to do either target or lun reset
  (bnc#913241,FATE#317338).
- hpsa: get ioaccel mode 2 i/o working (bnc#913241,FATE#317338).
- hpsa: initialize controller to perform io accelerator mode 2
  (bnc#913241,FATE#317338).
- hpsa: get physical device handles for io accel mode 2 as well
  (bnc#913241,FATE#317338).
- hpsa: do ioaccel mode 2 resource allocations
  (bnc#913241,FATE#317338).
- hpsa: Acknowledge controller events in ioaccell mode 2 as well
  (bnc#913241,FATE#317338).
- hpsa: add ioaccel mode 2 structure definitions
  (bnc#913241,FATE#317338).
- hpsa: complain if physical or logical aborts are not supported
  (bnc#913241,FATE#317338).
- hpsa: add hp_ssd_smart_path_enabled sysfs attribute
  (bnc#913241,FATE#317338).
- hpsa: do not rescan controllers known to be locked up
  (bnc#913241,FATE#317338).
- hpsa: poll controller to detect device change event
  (bnc#913241,FATE#317338).
- hpsa: update raid offload status on device rescan
  (bnc#913241,FATE#317338).
- hpsa: add ioaccell mode 1 RAID offload support
  (bnc#913241,FATE#317338).
- hpsa: fix task management for mode-1 ioaccell path
  (bnc#913241,FATE#317338).
- hpsa: only allow REQ_TYPE_FS to use fast path
  (bnc#913241,FATE#317338).
- hpsa: add support for 'fastpath' i/o (bnc#913241,FATE#317338).
- hpsa: mark last scatter gather element as the last
  (bnc#913241,FATE#317338).
- hpsa: use extended report luns command for HP SSD SmartPath
  (bnc#913241,FATE#317338).
- hpsa: fixup MSI-X registration (bnc#913241,FATE#317338).
- hpsa: allow SCSI mid layer to handle unit attention
  (bnc#913241,FATE#317338).
- hpsa: do not require board "not ready" status after hard reset
  (bnc#913241,FATE#317338).
- hpsa: enable unit attention reporting (bnc#913241,FATE#317338).
- hpsa: rename scsi prefetch field (bnc#913241,FATE#317338).
- hpsa: use workqueue instead of kernel thread for lockup
  (bnc#913241,FATE#317338).
- hpsa: remove P822se PCI ID (bnc#913241,FATE#317338).
- hpsa: prevent stalled i/o (bnc#913241,FATE#317338).
- hpsa: cap CCISS_PASSTHRU at 20 concurrent commands
  (bnc#913241,FATE#317338).
- hpsa: add MSA 2040 to list of external target devices
  (bnc#913241,FATE#317338).
- hpsa: fix memory leak in CCISS_BIG_PASSTHRU ioctl
  (bnc#913241,FATE#317338).
- hpsa: remove unneeded include of seq_file.h
  (bnc#913241,FATE#317338).
- hpsa: add 5 second delay after doorbell reset
  (bnc#913241,FATE#317338).
- hpsa: do not attempt to flush the cache on locked up
  (bnc#913241,FATE#317338).
- hpsa: return 0 from driver probe function on success, not 1
  (bnc#913241,FATE#317338).
- hpsa: do not discard scsi status on aborted commands
  (bnc#913241,FATE#317338).
- hpsa: remove unused Smart Array ID (bnc#913241,FATE#317338).
- hpsa: bump driver version to reflect changes
  (bnc#913241,FATE#317338).
- hpsa: housekeeping patch for device_id and product arrays
  (bnc#913241,FATE#317338).
- hpsa: add HP Smart Array Gen8 names (bnc#913241,FATE#317338).
- hpsa: add HP Smart Array Gen9 PCI ID's (bnc#913241,FATE#317338).
- hpsa: fix warning with smp_processor_id() in preemptible
  (bnc#913241,FATE#317338).
- hpsa: remove unneeded variable (bnc#913241,FATE#317338).
- hpsa: fix a race in cmd_free/scsi_done (bnc#913241,FATE#317338).
- hpsa: check for dma_mapping_error in hpsa_passthru ioctls
  (bnc#913241,FATE#317338).
- commit 52f2a41
* Fri Jan 16 2015 lduncan@suse.com
- cxgb4i : Don't block unload/cxgb4 unload when remote closes
  TCP connection (FATE#317554 bnc#909582).
- cxgb4i: send abort_rpl correctly (FATE#317554 bnc#909582).
- cxgb4i : Fix -Wmaybe-uninitialized warning (FATE#317554
  bnc#909582).
- cxgb4i: Remove duplicate call to dst_neigh_lookup() (FATE#317554
  bnc#909582).
- cxgb4i: avoid holding mutex in interrupt context (FATE#317554
  bnc#909582).
- libcxgbi: Add ipv6 api to driver (FATE#317554 bnc#909582).
- net, scsi/csgb4i: convert skb->transport_header into
  skb_transport_header(skb) (FATE#317554 bnc#909582).
- cxgb4i: Convert over to dst_neigh_lookup() (FATE#317554
  bnc#909582).
- cxgb4i: Handle dst_get_neighbour_noref() returning NULL
  (FATE#317554 bnc#909582).
- Remove unneeded version.h includes from drivers/scsi/
  (FATE#317554 bnc#909582).
- commit b99517d
* Fri Jan 16 2015 glin@suse.com
- Add the new sky2 config to config files (bsc#909566 FATE#314306)
- commit b241eae
* Thu Jan 15 2015 jbohac@suse.cz
- udp: Add MIB counters for rcvbuferrors (bnc#909565).
- commit 9184397
* Thu Jan 15 2015 hare@suse.de
- cciss: Fallback to MSI rather than to INTx if MSI-X failed
  (bnc#913241,FATE#317338).
- drivers/block/cciss.c:cciss_init_one(): use proper errnos
  (bnc#913241,FATE#317338).
- cciss: return 0 from driver probe function on success, not 1
  (bnc#913241,FATE#317338).
- cciss: set max scatter gather entries to 32 on P600
  (bnc#913241,FATE#317338).
- commit 53e14ec
* Thu Jan 15 2015 hare@suse.de
- qla4xxx: v5.03.00.00.11.4-k0 (FATE#317545 bnc#909371).
- qla4xxx: Disable INTx interrupt for ISP82XX (FATE#317545
  bnc#909371).
- qla4xxx: Export sysfs DDBs from DPC handler (FATE#317545
  bnc#909371).
- qla4xxx: Initialize hardware queue for ISP40XX (FATE#317545
  bnc#909371).
- qla4xxx: Change default capture to firmware defined capture mask
  (FATE#317545 bnc#909371).
- qla4xxx: Do not wait for IO completion, after issuing
  stop_firmware (FATE#317545 bnc#909371).
- qla4xxx: Handle IPv6 AEN notifications (FATE#317545 bnc#909371).
- qla4xxx: Update print statements in func qla4xxx_do_dpc()
  (FATE#317545 bnc#909371).
- qla4xxx: Update print statements in func qla4xxx_eh_abort()
  (FATE#317545 bnc#909371).
- qla4xxx: Update print statements in qla4xxx_mailbox_command()
  (FATE#317545 bnc#909371).
- qla4xxx: Remove unused code from qla4xxx_set_ifcb() (FATE#317545
  bnc#909371).
- qla4xxx: Fix failure of mbox 0x31 (FATE#317545 bnc#909371).
- qla4xxx: Reduce rom-lock contention during reset recovery
  (FATE#317545 bnc#909371).
- qla4xxx: Clear DDB index map upon connection close failure
  (FATE#317545 bnc#909371).
- qla4xxx: Fix pending IO completion in reset path before
  initiating chip reset (FATE#317545 bnc#909371).
- qla4xxx: Fix processing response queue during probe (FATE#317545
  bnc#909371).
- qla4xxx: Correctly handle msleep_interruptible (FATE#317545
  bnc#909371).
- qla4xxx: Rename ACB_STATE macros with IP_ADDRSTATE macros
  (FATE#317545 bnc#909371).
- qla4xxx: Use IDC_CTRL bit1 directly instead of AF_83XX_NO_FWDUMP
  flag (FATE#317545 bnc#909371).
- qla4xxx: Fix comments in code (FATE#317545 bnc#909371).
- qla4xxx: Print WARN_ONCE() if iSCSI function presence bit
  removed (FATE#317545 bnc#909371).
- qla4xxx: ISP8xxx: Correct retry of adapter initialization
  (FATE#317545 bnc#909371).
- qla4xxx: Use offset based on adapter type to set CHAP entry
  in flash (FATE#317545 bnc#909371).
- qla4xxx: Populate local CHAP credentials for flash target
  sessions (FATE#317545 bnc#909371).
- qla4xxx: Support setting of local CHAP index for flash target
  entry (FATE#317545 bnc#909371).
- qla4xxx: Correct the check for local CHAP entry type
  (FATE#317545 bnc#909371).
- qla4xxx: Return error if minidump data collection fails
  (FATE#317545 bnc#909371).
- qla4xxx: Fix the minidump data collection check in for loop
  (FATE#317545 bnc#909371).
- qla4xxx: Only BIOS boot target entries should be at index 0
  and 1 (FATE#317545 bnc#909371).
- qla4xxx: discovery_parent_idx can be shown without any check
  (FATE#317545 bnc#909371).
- qla4xxx: Set IPv6 traffic class if device type is IPv6
  (FATE#317545 bnc#909371).
- qla4xxx: Use discovery_parent_idx instead of
  discovery_parent_type (FATE#317545 bnc#909371).
- qla4xxx: Allow removal of failed session using logout
  (FATE#317545 bnc#909371).
- commit 8da9972
* Thu Jan 15 2015 hare@suse.de
- Reshuffle patches in preparation for the qla4xxx update.
- commit 6f48b79
* Thu Jan 15 2015 hare@suse.de
- Refresh patches.drivers/fnic-BUG-sleeping-function-called-from-invalid-.patch
  Update bug description as the original was causing errors during
  patching.
- commit e751065
* Thu Jan 15 2015 hare@suse.de
- mptfusion: simplify rounding (bnc#909787,FATE#317518).
- mptfusion: tweak null pointer checks (bnc#909787,FATE#317518).
- mptfusion: combine fw_event_work and its event_data
  (bnc#909787,FATE#317518).
- mptfusion: make adapter prod_name a pointer
  (bnc#909787,FATE#317518).
- mptfusion: fix msgContext in mptctl_hp_hostinfo
  (bnc#909787,FATE#317518).
- fusion: Remove use of DEF_SCSI_QCMD (bnc#909787,FATE#317518).
- fusion: Add free msg frames to the head, not tail of list
  (bnc#909787,FATE#317518).
- drivers/message/fusion/mptscsih.c: missing break
  (bnc#909787,FATE#317518).
- Fusion MPT: disable pci device when mpt map resoures failed
  (bnc#909787,FATE#317518).
- drivers/message/fusion: use pci_dev->revision
  (bnc#909787,FATE#317518).
- fusion: ensure NUL-termination of MptCallbacksName elements
  (bnc#909787,FATE#317518).
- commit 516ef63
* Thu Jan 15 2015 hare@suse.de
- fnic: IOMMU Fault occurs when IO and abort IO is out of order
  (bnc#913219,FATE#317512).
- Fnic: Fnic Driver crashed with NULL pointer reference
  (bnc#913219,FATE#317512).
- Fnic: For Standalone C series, "sending VLAN request" message
  seen (bnc#913219,FATE#317512).
- Fnic: Improper resue of exchange Ids (bnc#913219,FATE#317512).
- Fnic: Memcopy only mimumum of data or trace buffer
  (bnc#913219,FATE#317512).
- Fnic: Not probing all the vNICS via fnic_probe on boot
  (bnc#913219,FATE#317512).
- fnic: assign FIP_ALL_FCF_MACS to fcoe_all_fcfs
  (bnc#913219,FATE#317512).
- fnic: fnic Control Path Trace Utility (bnc#913219,FATE#317512).
- fnic: Failing to queue aborts due to Q full cause terminate
  driver (bnc#913219,FATE#317512).
- fnic: NoFIP solicitation frame in NONFIP mode and changed IO
  Throttle (bnc#913219,FATE#317512).
- fnic: Incremented driver version (bnc#913219,FATE#317512).
- fnic: Fnic Statistics Collection (bnc#913219,FATE#317512).
- fnic: host reset returns nonzero value(errno) on success
  (bnc#913219,FATE#317512).
- fnic: fnic Driver Tuneables Exposed through CLI
  (bnc#913219,FATE#317512).
- fnic: Kernel panic while running sh/nosh with max lun cfg
  (bnc#913219,FATE#317512).
- fnic: Hitting BUG_ON(io_req->abts_done) in
  (bnc#913219,FATE#317512).
- fnic: Remove QUEUE_FULL handling code (bnc#913219,FATE#317512).
- fnic: On system with >1.1TB RAM, VIC fails multipath after
  (bnc#913219,FATE#317512).
- fnic: FC stat param seconds_since_last_reset not getting
  (bnc#913219,FATE#317512).
- fnic: BUG: sleeping function called from invalid context
  (bnc#913219,FATE#317512).
- fnic: potential dead lock in fnic_is_abts_pending()
  (bnc#913219,FATE#317512).
- commit bfaec22
* Thu Jan 15 2015 hare@suse.de
- Rename patches.drivers/fnic-Incremented-driver-version.patch
  Rename to avoid clashes with later updates.
- commit 3279e07
* Thu Jan 15 2015 hare@suse.de
- Reshuffle patches to apply cleanly.
- commit dad4d8c
* Thu Jan 15 2015 mmarek@suse.cz
- Refresh vanilla configs
- commit b5f9ddf
* Thu Jan 15 2015 hare@suse.de
- bnx2fc: Update version number to 2.8.1 (bnc#909367,FATE#317542).
- bnx2fc: Cleanup io_req after ABTS timeout
  (bnc#909367,FATE#317542).
- bnx2fc: Remove 'NetXtreme II' from source files
  (bnc#909367,FATE#317542).
- bnx2fc: Remove explicit logouts (bnc#909367,FATE#317542).
- bnx2fc: Fix 'bnx2fc: Fix FCP RSP residual
  parsing.' (bnc#909367,FATE#317542).
- bnx2fc: Fix FCP RSP residual parsing (bnc#909367,FATE#317542).
- bnx2fc: corrected copyright notices (bnc#909367,FATE#317542).
- bnx2fc: Set ELS transfer length correctly for middle path
  commands (bnc#909367,FATE#317542).
- bnx2fc: do not add shared skbs to the fcoe_rx_list
  (bnc#909367,FATE#317542).
- bnx2fc: fix an error code in _bnx2fc_create()
  (bnc#909367,FATE#317542).
- bnx2fc: check IS_ERR() instead of NULL (bnc#909367,FATE#317542).
- bnx2fc: fix tgt spinlock locking (bnc#909367,FATE#317542).
- bnx2fc: fix incorrect DMA memory mapping in
  bnx2fc_unmap_sg_list() (bnc#909367,FATE#317542).
- bnx2fc: Rebranding bnx2fc driver (bnc#909367,FATE#317542).
- bnx2fc: Improve stats update mechanism (bnc#909367,FATE#317542).
- bnx2fc: do not scan uninitialized lists in case of error
  (bnc#909367,FATE#317542).
- bnx2fc: fix memory leak in bnx2fc_allocate_hash_table()
  (bnc#909367,FATE#317542).
- bnx2fc: fix memory leak and potential NULL pointer dereference
  (bnc#909367,FATE#317542).
- bnx2fc: remove unused variable hash_table_size
  (bnc#909367,FATE#317542).
- bnx2fc: Updated version to 2.4.2 (bnc#909367,FATE#317542).
- bnx2fc: Fixed the handling for the SCSI retry delay
  (bnc#909367,FATE#317542).
- bnx2fc: Fixed scsi_remove_target soft lockup when rmmod bnx2x
  (bnc#909367,FATE#317542).
- bnx2fc: Bump version from 1.0.14 to 2.4.1
  (bnc#909367,FATE#317542).
- BNX2FC: hung task timeout warning observed when rmmod bnx2x
  (bnc#909367,FATE#317542).
- bnx2fc: Fixed a SCSI CMD cmpl race condition between ABTS and
  (bnc#909367,FATE#317542).
- commit 8759b55
* Thu Jan 15 2015 mhocko@suse.cz
- workqueue: Make rescuer thread process more works (bnc#900279).
- commit 98fc823
* Thu Jan 15 2015 hare@suse.de
- libfc: fix REC handling (bnc#909501,FATE#317541).
- libfcoe: Save some memory and optimize name lookups
  (bnc#909501,FATE#317541).
- libfcoe: Add fcoe_sysfs debug logging level
  (bnc#909501,FATE#317541).
- libfcoe, fcoe, bnx2fc: Add new fcoe control interface
  (bnc#909501,FATE#317541).
- fcoe: Use the fcoe_sysfs control interface
  (bnc#909501,FATE#317541).
- bnx2fc: Use the fcoe_sysfs control interface
  (bnc#909501,FATE#317541).
- libfc, libfcoe, fcoe: Convert debug_logging macros to pr_info
  (bnc#909501,FATE#317541).
- fcoe: prep work to start consolidate the usage of fcoe_netdev
  (bnc#909501,FATE#317541).
- fcoe: add support to the get_netdev() for fcoe_interface
  (bnc#909501,FATE#317541).
- libfcoe, fcoe: move fcoe_link_speed_update() to libfcoe and
  export it (bnc#909501,FATE#317541).
- libfcoe, fcoe: consolidate the fcoe_ctlr_get_lesb/fcoe_get_lesb
  (bnc#909501,FATE#317541).
- bnx2fc: add support to get_netdev for bnx2f_interface
  (bnc#909501,FATE#317541).
- bnx2fc: use fcoe_link_speed_update() from the exported symbol in
  (bnc#909501,FATE#317541).
- bnx2fc: use fcoe_get_lesb/fcoe_ctlr_get_lesb() directly from
  libfcoe (bnc#909501,FATE#317541).
- debris left by " libfcoe: Remove mutex_trylock/restart_syscall
  (bnc#909501,FATE#317541).
- fcoe: close race on link speed detection in fcoe code
  (bnc#909501,FATE#317541).
- fcoe: Fix deadlock while deleting FCoE interface with NPIV ports
  (bnc#909501,FATE#317541).
- libfc: XenServer fails to mount root filesystem
  (bnc#909501,FATE#317541).
- libfcoe: Check for unusable FCFs before looking for conflicting
  FCFs (bnc#909501,FATE#317541).
- bnx2fc: Make the fcoe_cltr the SCSI host parent
  (bnc#909501,FATE#317541).
- fcoe: Fix deadlock between create and destroy paths
  (bnc#909501,FATE#317541).
- libfc, fcoe, bnx2fc: Always use fcoe_disc_init for discovery
  layer (bnc#909501,FATE#317541).
- libfc, fcoe, bnx2fc: Split fc_disc_init into fc_disc_{init,
  config} (bnc#909501,FATE#317541).
- libfcoe: Fix fcoe_sysfs VN2VN mode (bnc#909501,FATE#317541).
- libfcoe: Fix Conflicting FCFs issue in the fabric
  (bnc#909501,FATE#317541).
- libfc: Correct check for initiator role
  (bnc#909501,FATE#317541).
- libfc: extend ex_lock to protect all of fc_seq_send
  (bnc#909501,FATE#317541).
- MAINTAINERS: Fix fcoe mailing list (bnc#909501,FATE#317541).
- libfc: Reject PLOGI from nodes with incompatible role
  (bnc#909501,FATE#317541).
- fcoe: Fix smatch warning in fcoe_fdmi_info function
  (bnc#909501,FATE#317541).
- fcoe: fix the link error status block sparse warnings
  (bnc#909501,FATE#317541).
- libfc: Remove extra space in fc_exch_timer_cancel definition
  (bnc#909501,FATE#317541).
- libfc: Differentiate echange timer cancellation debug statements
  (bnc#909501,FATE#317541).
- libfcoe: Fix meaningless log statement (bnc#909501,FATE#317541).
- fcoe: Stop fc_rport_priv structure leak
  (bnc#909501,FATE#317541).
- fcoe: Reduce number of sparse warnings (bnc#909501,FATE#317541).
- fcoe: ensure that skb placed on the fip_recv_list are unshared
  (bnc#909501,FATE#317541).
- fcoe: make sure fcoe frames are unshared prior to manipulating
  them (bnc#909501,FATE#317541).
- fcoe: cleanup return codes from fcoe_rcv
  (bnc#909501,FATE#317541).
- libfc: Source code comment spelling fixes
  (bnc#909501,FATE#317541).
- libfc: Debug code fixes (bnc#909501,FATE#317541).
- libfc: Micro-optimize fc_setup_exch_mgr()
  (bnc#909501,FATE#317541).
- libfc: Clarify fc_exch_find() (bnc#909501,FATE#317541).
- libfc: Fix a race in fc_exch_timer_set_locked()
  (bnc#909501,FATE#317541).
- libfc: Protect ep->esb_stat changes via ex_lock
  (bnc#909501,FATE#317541).
- libfc: Avoid that sending after an abort triggers a kernel
  warning (bnc#909501,FATE#317541).
- libfc: Reduce exchange lock contention in fc_exch_recv_abts()
  (bnc#909501,FATE#317541).
- libfc: Do not invoke the response handler after fc_exch_done()
  (bnc#909501,FATE#317541).
- fcp: Do not interpret check condition as underrun
  (bnc#909501,FATE#317541).
- fcoe: Declare fcoe_ctlr_mode_set() static
  (bnc#909501,FATE#317541).
- fcoe: Add missing newlines in debug messages
  (bnc#909501,FATE#317541).
- fcoe: Reduce fcoe_sysfs_fcf_add() stack usage
  (bnc#909501,FATE#317541).
- libfcoe: Make fcoe_sysfs optional / fix fnic NULL exception
  (bnc#909501,FATE#317541).
- fcoe: Fix missing mutex_unlock in fcoe_sysfs_fcf_add error path
  (bnc#909501,FATE#317541).
- fcoe: extend ethtool to FC port speed mapping
  (bnc#909501,FATE#317541).
- scsi: add defines for new FC port speeds
  (bnc#909501,FATE#317541).
- Delete
  patches.drivers/libfcoe-Make-fcoe_sysfs-optional-fix-fnic-NULL-excep.patch.
- commit 839f1e9
* Thu Jan 15 2015 bpoirier@suse.de
- Refresh
  patches.drivers/0003-tg3-set-maximal-number-of-default-RSS-queues.patch.
  corrects erroneous Git-commit tag
- commit f9b80ad
* Thu Jan 15 2015 bpoirier@suse.de
- Refresh
  patches.drivers/0003-tg3-set-maximal-number-of-default-RSS-queues.patch.
  corrects erroneous Git-commit tag
- commit b02543c
* Thu Jan 15 2015 lduncan@suse.com
- cxgb3i: Remove unneeded version.h include (bnc#909582).
- commit ada7d18
* Wed Jan 14 2015 hare@suse.de
- Reshuffle patches in preparation for the fcoe/bnx2fc update
- commit b24974e
* Wed Jan 14 2015 hare@suse.de
- ia64: export numa_slit() (bnc#913030,FATE#317455).
- commit e416529
* Wed Jan 14 2015 hare@suse.de
- powerpc/mm: fix ".__node_distance" undefined
  (bnc##913030,FATE#317455).
- commit c6e2822
* Wed Jan 14 2015 jbohac@suse.cz
- net-next: replace obsolete NLMSG_* with type safe nlmsg_*.
- net/tipc: remove depends on CONFIG_EXPERIMENTAL.
- tipc: add InfiniBand media type.
- tipc: add a bounds check in link_recv_changeover_msg().
- tipc: allow implicit connect for stream sockets.
- tipc: bump tipc_ports kconfig limit/default.
- tipc: clear 'next'-pointer of message fragments before
  reassembly.
- tipc: correctly unlink packets from deferred packet queue.
- tipc: cosmetic: clean up comments and break a long line.
- tipc: don't hold portlock during nametbl unsubscribe.
- tipc: don't reroute message fragments.
- tipc: eliminate duplicated discard_rx_queue routine.
- tipc: fix OOS packet delivery (bsc#907063).
- tipc: fix deadlock during socket release.
- tipc: fix message corruption bug for deferred packets.
- tipc: fix missing spinlock init in broadcast code.
- tipc: message reassembly using fragment chain.
- tipc: move bcast_addr from struct tipc_media to struct
  tipc_bearer.
- tipc: move datapath message rejection to workqueue (bsc#907063).
- tipc: potential divide by zero in tipc_link_recv_fragment().
- tipc: protect nodesub list with a fine grained spinlock
  (bsc#907063).
- tipc: pskb_copy() buffers when sending on more than one bearer.
- tipc: reassembly failures should cause link reset.
- tipc: remove interface state mirroring in bearer.
- tipc: remove redundant checking for the number of iovecs in
  a send.
- tipc: remove unused str2addr media callback.
- tipc: set skb->protocol in eth_media packet transmission.
- tipc: tipc_bcbearer_send(): simplify bearer selection.
- Update config files.
- commit 5aff65e
* Wed Jan 14 2015 hare@suse.de
- bfa: Cleanup bfad_setup_intr() function
  (bnc#909365,FATE#317496).
- bfa: Do not call pci_enable_msix() after it failed once
  (bnc#909365,FATE#317496).
- bfa: use ARRAY_SIZE instead of sizeof/sizeof
  (bnc#909365,FATE#317496).
- bfa: remove useless return variables (bnc#909365,FATE#317496).
- bfa: Fix undefined bit shift on big-endian architectures with
  32-bit (bnc#909365,FATE#317496).
- bfa: Use dma_zalloc_coherent (bnc#909365,FATE#317496).
- bfa: allocate memory with GFP_ATOMIC in spinlock context
  (bnc#909365,FATE#317496).
- bfa: Replace large udelay() with mdelay()
  (bnc#909365,FATE#317496).
- bfa: Fix smatch warnings (bnc#909365,FATE#317496).
- bfa: fix missing unlock on error in bfad_iocmd_cfg_trunk()
  (bnc#909365,FATE#317496).
- bfa: Driver version upgrade to 3.2.23.0
  (bnc#909365,FATE#317496).
- bfa: change FC_ELS_TOV to 20sec (bnc#909365,FATE#317496).
- bfa: Observed auto D-port mode instead of manual
  (bnc#909365,FATE#317496).
- bfa: Fix for bcu or hcm faa query hang (bnc#909365,FATE#317496).
- bfa: LUN discovery issue in direct attach mode
  (bnc#909365,FATE#317496).
- bfa: Register port with SCSI even on port init failure
  (bnc#909365,FATE#317496).
- bfa: Firmware patch simplification (bnc#909365,FATE#317496).
- bfa: Chinook quad port 16G FC HBA claim issue
  (bnc#909365,FATE#317496).
- bfa: Fix crash when symb name set for offline vport
  (bnc#909365,FATE#317496).
- bfa: Use pcie_set()/get_readrq() to simplify code
  (bnc#909365,FATE#317496).
- bfa: firmware update to 3.2.1.1 (bnc#909365,FATE#317496).
- bfa: Update the driver version to 3.2.21.1
  (bnc#909365,FATE#317496).
- bfa: dis-associate bfa path_tov with dev_loss_tmo
  (bnc#909365,FATE#317496).
- bfa: Support for chinook-quad port card
  (bnc#909365,FATE#317496).
- bfa: fix endianess issue for firmware stats
  (bnc#909365,FATE#317496).
- bfa: Fix bug_on condition in RPSC rsp handling
  (bnc#909365,FATE#317496).
- bfa: Allow rsp queue process during ioc disable
  (bnc#909365,FATE#317496).
- bfa: firmware statistics update (bnc#909365,FATE#317496).
- bfa: fru vpd date update changes (bnc#909365,FATE#317496).
- bfa: driver compatibility with 32bit libs
  (bnc#909365,FATE#317496).
- bfa: kdump fix on 815 and 825 adapters (bnc#909365,FATE#317496).
- bfa: Fix FDISC timeout handling (bnc#909365,FATE#317496).
- bfa: Fix 1860 port initialize when ATC is enabled
  (bnc#909365,FATE#317496).
- bfa: FDMI enhancements (bnc#909365,FATE#317496).
- bfa: Fix WARN_ON condition check (bnc#909365,FATE#317496).
- bfa: Add dynamic diagnostic port support
  (bnc#909365,FATE#317496).
- bfa: Forward Error Correction status query
  (bnc#909365,FATE#317496).
- bfa: Support for FC BB credit recovery (bnc#909365,FATE#317496).
- bfa: Fixes for 0-terminated strncpy and possible null pointer
  (bnc#909365,FATE#317496).
- bfa: fix strncpy() limiter in bfad_start_ops()
  (bnc#909365,FATE#317496).
- commit 5cca31f
* Wed Jan 14 2015 hare@suse.de
- mtip32xx: Fix ERO and NoSnoop values in PCIe upstream on AMD
  systems (bnc#913072,FATE#317526).
- mtip32xx: Remove dfs_parent after pci unregister
  (bnc#913072,FATE#317526).
- mtip32xx: Increase timeout for STANDBY IMMEDIATE command
  (bnc#913072,FATE#317526).
- mtip32xx: mtip_async_complete() bug fixes
  (bnc#913072,FATE#317526).
- mtip32xx: Unmap the DMA segments before completing the IO
  request (bnc#913072,FATE#317526).
- mtip32xx: Set queue bounce limit (bnc#913072,FATE#317526).
- mtip32xx: Use pci_enable_msi() instead of pci_enable_msi_range()
  (bnc#913072,FATE#317526).
- mtip32xx: fix bad use of smp_processor_id()
  (bnc#913072,FATE#317526).
- mtip32xx: Use pci_enable_msix_range() instead of
  pci_enable_msix() (bnc#913072,FATE#317526).
- mtip32xx: Remove superfluous call to pci_disable_msi()
  (bnc#913072,FATE#317526).
- mtip32xx: Reduce the number of unaligned writes to 2
  (bnc#913072,FATE#317526).
- mtip32xx: Correctly handle security locked condition
  (bnc#913072,FATE#317526).
- mtip32xx: Make SGL container per-command to eliminate high
  order dma (bnc#913072,FATE#317526).
- mtip32xx: dynamically allocate buffer in debugfs functions
  (bnc#913072,FATE#317526).
- mtip32xx: Add SRSI support (bnc#913072,FATE#317526).
- commit 5266939
* Wed Jan 14 2015 hare@suse.de
- Update patches to apply after NVMe backport (bnc#913030,FATE#317455)
- Refresh
  patches.drivers/mtip32xx-0001-Add-driver-for-Micron-RealSSD-pcie-flash-cards.patch.
- Refresh
  patches.drivers/nvme-0126-Rename-nvme.c-to-nvme-core.c.patch.
- Refresh patches.drivers/nvme-0129-Add-nvme-scsi.c.patch.
- Refresh
  patches.fixes/asm-generic-architecture-independent-readq-writeq-fo.patch.
- Refresh patches.suse/twofish-2.6.
- commit 7ea20c7
* Wed Jan 14 2015 hare@suse.de
- NVMe: fail pci initialization if the device doesn't have any
  BARs (bnc#913030,FATE#317455).
- NVMe: make setup work for devices that don't do INTx
  (bnc#913030,FATE#317455).
- NVMe: Do not over allocate for discard requests
  (bnc#913030,FATE#317455).
- NVMe: Do not open disks that are being deleted
  (bnc#913030,FATE#317455).
- NVMe: Clear QUEUE_FLAG_STACKABLE (bnc#913030,FATE#317455).
- NVMe: Fix device probe waiting on kthread
  (bnc#913030,FATE#317455).
- NVMe: Updates for 1.1 spec (bnc#913030,FATE#317455).
- NVMe: Passthrough IOCTL for IO commands
  (bnc#913030,FATE#317455).
- NVMe: Add revalidate_disk callback (bnc#913030,FATE#317455).
- NVMe: Fix nvmeq waitqueue entry initialization
  (bnc#913030,FATE#317455).
- NVMe: Translate NVMe status to errno (bnc#913030,FATE#317455).
- NVMe: Fix SG_IO status values (bnc#913030,FATE#317455).
- NVMe: Remove duplicate compat SG_IO code
  (bnc#913030,FATE#317455).
- NVMe: Reference count pci device (bnc#913030,FATE#317455).
- nvme: Replace rcu_assign_pointer() with RCU_INIT_POINTER()
  (bnc#913030,FATE#317455).
- NVMe: Correctly handle IOCTL_SUBMIT_IO when cpus > online queues
  (bnc#913030,FATE#317455).
- NVMe: Fix filesystem sync deadlock on removal
  (bnc#913030,FATE#317455).
- NVMe: Call nvme_free_queue directly (bnc#913030,FATE#317455).
- NVMe: Add shutdown timeout as module parameter
  (bnc#913030,FATE#317455).
- NVMe: Skip orderly shutdown on failed devices
  (bnc#913030,FATE#317455).
- NVMe: Handling devices incapable of I/O
  (bnc#913030,FATE#317455).
- NVMe: Change nvme_enable_ctrl to set EN and manage CC thru
  (bnc#913030,FATE#317455).
- NVMe: Mismatched host/device page size support
  (bnc#913030,FATE#317455).
- NVMe: Update list of status codes (bnc#913030,FATE#317455).
- NVMe: Async event request (bnc#913030,FATE#317455).
- NVMe: Fix START_STOP_UNIT Scsi->NVMe translation
  (bnc#913030,FATE#317455).
- NVMe: Use Log Page constants in SCSI emulation
  (bnc#913030,FATE#317455).
- NVMe: Define Log Page constants (bnc#913030,FATE#317455).
- NVMe: Fix hot cpu notification dead lock
  (bnc#913030,FATE#317455).
- NVMe: Rename io_timeout to nvme_io_timeout
  (bnc#913030,FATE#317455).
- NVMe: Use last bytes of f/w rev SCSI Inquiry
  (bnc#913030,FATE#317455).
- NVMe: Adhere to request queue block accounting enable/disable
  (bnc#913030,FATE#317455).
- NVMe: Fix nvme get/put queue semantics (bnc#913030,FATE#317455).
- NVMe: Delete NVME_GET_FEAT_TEMP_THRESH (bnc#913030,FATE#317455).
- NVMe: Make admin timeout a module parameter
  (bnc#913030,FATE#317455).
- NVMe: Make iod bio timeout a parameter (bnc#913030,FATE#317455).
- NVMe: Prevent possible NULL pointer dereference
  (bnc#913030,FATE#317455).
- NVMe: Fix the buffer size passed in GetLogPage(CDW10.NUMD)
  (bnc#913030,FATE#317455).
- NVMe: Enable BUILD_BUG_ON checks (bnc#913030,FATE#317455).
- NVMe: Configure support for block flush
  (bnc#913030,FATE#317455).
- NVMe: Protect against badly formatted CQEs
  (bnc#913030,FATE#317455).
- NVMe: Improve error messages (bnc#913030,FATE#317455).
- NVMe: Update copyright headers (bnc#913030,FATE#317455).
- NVMe: Retry failed commands with non-fatal errors
  (bnc#913030,FATE#317455).
- NVMe: Add getgeo to block ops (bnc#913030,FATE#317455).
- NVMe: Start-stop nvme_thread during device add-remove
  (bnc#913030,FATE#317455).
- NVMe: Make I/O timeout a module parameter
  (bnc#913030,FATE#317455).
- NVMe: CPU hot plug notification (bnc#913030,FATE#317455).
- NVMe: per-cpu io queues (bnc#913030,FATE#317455).
- NVMe: Replace DEFINE_PCI_DEVICE_TABLE (bnc#913030,FATE#317455).
- NVMe: Fix divide-by-zero in nvme_trans_io_get_num_cmds
  (bnc#913030,FATE#317455).
- NVMe: IOCTL path RCU protect queue access
  (bnc#913030,FATE#317455).
- NVMe: RCU protected access to io queues
  (bnc#913030,FATE#317455).
- NVMe: Initialize device reference count earlier
  (bnc#913030,FATE#317455).
- NVMe: Add CONFIG_PM_SLEEP to suspend/resume functions
  (bnc#913030,FATE#317455).
- NVMe: Namespace use after free on surprise removal
  (bnc#913030,FATE#317455).
- NVMe: Correct uses of INIT_WORK (bnc#913030,FATE#317455).
- NVMe: Include device and queue numbers in interrupt name
  (bnc#913030,FATE#317455).
- NVMe: Add a pci_driver shutdown method (bnc#913030,FATE#317455).
- NVMe: Disable admin queue on init failure
  (bnc#913030,FATE#317455).
- NVMe: Dynamically allocate partition numbers
  (bnc#913030,FATE#317455).
- NVMe: Async IO queue deletion (bnc#913030,FATE#317455).
- NVMe: Surprise removal handling (bnc#913030,FATE#317455).
- NVMe: Abort timed out commands (bnc#913030,FATE#317455).
- NVMe: Schedule reset for failed controllers
  (bnc#913030,FATE#317455).
- NVMe: Device resume error handling (bnc#913030,FATE#317455).
- NVMe: Cache dev->pci_dev in a local pointer
  (bnc#913030,FATE#317455).
- NVMe: Fix lockdep warnings (bnc#913030,FATE#317455).
- NVMe: compat SG_IO ioctl (bnc#913030,FATE#317455).
- NVMe: remove deprecated IRQF_DISABLED (bnc#913030,FATE#317455).
- NVMe: Avoid shift operation when writing cq head doorbell
  (bnc#913030,FATE#317455).
- DMA-API: block: nvme-core: replace (bnc#913030,FATE#317455).
- NVMe: Merge issue on character device bring-up
  (bnc#913030,FATE#317455).
- NVMe: Handle ioremap failure (bnc#913030,FATE#317455).
- NVMe: Add pci suspend/resume driver callbacks
  (bnc#913030,FATE#317455).
- NVMe: Use normal shutdown (bnc#913030,FATE#317455).
- NVMe: Separate controller init from disk discovery
  (bnc#913030,FATE#317455).
- NVMe: Separate queue alloc/free from create/delete
  (bnc#913030,FATE#317455).
- NVMe: Group pci related actions in functions
  (bnc#913030,FATE#317455).
- NVMe: Disk stats for read/write commands only
  (bnc#913030,FATE#317455).
- NVMe: Bring up cdev on set feature failure
  (bnc#913030,FATE#317455).
- NVMe: Fix checkpatch issues (bnc#913030,FATE#317455).
- NVMe: Namespace IDs are unsigned (bnc#913030,FATE#317455).
- NVMe: Update nvme_id_power_state with latest spec
  (bnc#913030,FATE#317455).
- NVMe: Split header file into user-visible and kernel-visible
  pieces (bnc#913030,FATE#317455).
- NVMe: Call nvme_process_cq from submission path
  (bnc#913030,FATE#317455).
- NVMe: Remove "process_cq did something" message
  (bnc#913030,FATE#317455).
- NVMe: Return correct value from interrupt handler
  (bnc#913030,FATE#317455).
- NVMe: Disk IO statistics (bnc#913030,FATE#317455).
- NVMe: Restructure MSI / MSI-X setup (bnc#913030,FATE#317455).
- NVMe: Use kzalloc instead of kmalloc+memset
  (bnc#913030,FATE#317455).
- NVMe: Add MSI support (bnc#913030,FATE#317455).
- NVMe: Use dma_set_mask() correctly (bnc#913030,FATE#317455).
- NVMe: Do not cancel command multiple times
  (bnc#913030,FATE#317455).
- NVMe: fix error return code in nvme_submit_bio_queue()
  (bnc#913030,FATE#317455).
- NVMe: check for integer overflow in nvme_map_user_pages()
  (bnc#913030,FATE#317455).
- NVMe: Fix a signedness bug in nvme_trans_modesel_get_mp
  (bnc#913030,FATE#317455).
- NVMe: Remove redundant version.h header include
  (bnc#913030,FATE#317455).
- NVMe: Use user defined admin ioctl timeout
  (bnc#913030,FATE#317455).
- NVMe: Simplify Firmware Activate code slightly
  (bnc#913030,FATE#317455).
- NVMe: Only clear the enable bit when disabling controller
  (bnc#913030,FATE#317455).
- NVMe: Wait for device to acknowledge shutdown
  (bnc#913030,FATE#317455).
- NVMe: Schedule timeout for sync commands
  (bnc#913030,FATE#317455).
- NVMe: Meta-data support in NVME_IOCTL_SUBMIT_IO
  (bnc#913030,FATE#317455).
- NVMe: Device specific stripe size handling
  (bnc#913030,FATE#317455).
- NVMe: Split non-mergeable bio requests (bnc#913030,FATE#317455).
- NVMe: Remove dead code in nvme_dev_add (bnc#913030,FATE#317455).
- NVMe: Check for NULL memory in nvme_dev_add
  (bnc#913030,FATE#317455).
- NVMe: Fix error clean-up on nvme_alloc_queue
  (bnc#913030,FATE#317455).
- NVMe: Free admin queue on request_irq error
  (bnc#913030,FATE#317455).
- NVMe: Add scsi unmap to SG_IO (bnc#913030,FATE#317455).
- NVMe: queue usage fixes in nvme-scsi (bnc#913030,FATE#317455).
- NVMe: Set TASK_INTERRUPTIBLE before processing queues
  (bnc#913030,FATE#317455).
- NVMe: Add a character device for each nvme device
  (bnc#913030,FATE#317455).
- NVMe: Fix endian-related problems in user I/O submission path
  (bnc#913030,FATE#317455).
- NVMe: Fix I/O cancellation status on big-endian machines
  (bnc#913030,FATE#317455).
- NVMe: Fix sparse warnings in scsi emulation
  (bnc#913030,FATE#317455).
- NVMe: Don't fail initialisation unnecessarily
  (bnc#913030,FATE#317455).
- NVMe: Abstract out sector to block number conversion
  (bnc#913030,FATE#317455).
- NVMe: Use round_jiffies_relative() for the periodic,
  once-per-second (bnc#913030,FATE#317455).
- NVMe: Add nvme-scsi.c (bnc#913030,FATE#317455).
- NVMe: Add definitions for format command
  (bnc#913030,FATE#317455).
- NVMe: Move structures & definitions to header file
  (bnc#913030,FATE#317455).
- NVMe: Rename nvme.c to nvme-core.c (bnc#913030,FATE#317455).
- NVMe: Add discard support for capable devices
  (bnc#913030,FATE#317455).
- NVMe: Add namespaces with no LBA range feature
  (bnc#913030,FATE#317455).
- NVMe: Initialize iod nents to 0 (bnc#913030,FATE#317455).
- NVMe: Define SMART log (bnc#913030,FATE#317455).
- NVMe: Add result to nvme_get_features (bnc#913030,FATE#317455).
- NVMe: Set result from user admin command
  (bnc#913030,FATE#317455).
- NVMe: End queued bio requests when freeing queue
  (bnc#913030,FATE#317455).
- NVMe: Free cmdid on nvme_submit_bio error
  (bnc#913030,FATE#317455).
- commit 7d6709f
* Wed Jan 14 2015 hare@suse.de
- tty: Use lockless flip buffer free list
  (bnc#913030,FATE#317455).
- llist: llist_add() can use llist_add_batch()
  (bnc#913030,FATE#317455).
- llist: fix/simplify llist_add() and llist_add_batch()
  (bnc#913030,FATE#317455).
- llist-return-whether-list-is-empty-before-adding-in-llist_add-fix
  (bnc#913030,FATE#317455).
- llist: Add back llist_add_batch() and llist_del_first()
  prototypes (bnc#913030,FATE#317455).
- commit d76f3a9
* Wed Jan 14 2015 glin@suse.com
- netxen: Fix bug in Tx completion path (bsc#909363 FATE#317549).
- netxen: Fix BUG "sleeping function called from invalid context" (bsc#909363 FATE#317549).
- drivers/net: Convert remaining uses of pr_warning to pr_warn (bsc#909363 FATE#317549).
- treewide: Fix typo in printk (bsc#909363 FATE#317549).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#909363 FATE#317549).
- qlogic: use pci_zalloc_consistent (bsc#909363 FATE#317549).
- net: get rid of SET_ETHTOOL_OPS (bsc#909363 FATE#317549).
- netxen: Use pci_enable_msix_range() instead of pci_enable_msix() (bsc#909363 FATE#317549).
- net: netxen: slight optimization of addr compare (bsc#909363 FATE#317549).
- netxen: Correct off-by-one errors in bounds checks (bsc#909363 FATE#317549).
- ethernet: Fix FSF address in file headers (bsc#909363 FATE#317549).
- net: netxen: remove unnecessary pci_set_drvdata() (bsc#909363 FATE#317549).
- netxen: clean up unnecessary MSI/MSI-X capability find (bsc#909363 FATE#317549).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN (bsc#909363 FATE#317549).
- netxen_nic: Update version to 4.0.82 (bsc#909363 FATE#317549).
- netxen_nic: Print ULA information (bsc#909363 FATE#317549).
- qlogic: Remove extern from function prototypes (bsc#909363 FATE#317549).
- netxen: lower NAPI weight (bsc#909363 FATE#317549).
- ethernet: Convert mac address uses of 6 to ETH_ALEN (bsc#909363 FATE#317549).
- net: ethernet: replace strict_strtoul() with kstrtoul() (bsc#909363 FATE#317549).
- netxen_nic: Update version to 4.0.81 (bsc#909363 FATE#317549).
- netxen_nic: Avoid mixed mode interrupts (bsc#909363 FATE#317549).
- netxen_nic: netxen_setup_intr() function code cleanup (bsc#909363 FATE#317549).
- netxen_nic: Log proper error message in case of mismatched adapter type (bsc#909363 FATE#317549).
- netxen_nic: Log driver version with firmware version (bsc#909363 FATE#317549).
- netxen: write IP address to firmware when using bonding (bsc#909363 FATE#317549).
- drivers: net: misc: Remove unused OOM variables (bsc#909363 FATE#317549).
- ethernet: Remove unnecessary alloc/OOM messages, alloc cleanups (bsc#909363 FATE#317549).
- remove init of dev->perm_addr in drivers (bsc#909363 FATE#317549).
- netxen: remove __dev* attributes (bsc#909363 FATE#317549).
- drivers: ethernet: qlogic: netxen_nic_ethtool.c: Fixed a coding style issue (bsc#909363 FATE#317549).
- netxen: explicity handle pause autoneg parameter (bsc#909363 FATE#317549).
- netdev: make pci_error_handlers const (bsc#909363 FATE#317549).
- PCI: Introduce pci_pcie_type(dev) to replace pci_dev->pcie_type (bsc#909363 FATE#317549).
- netxen: remove unnecessary setting of skb->dev (bsc#909363 FATE#317549).
- net: introduce NAPI_POLL_WEIGHT (bsc#909363 FATE#317549).
- commit 72aa2c0
* Wed Jan 14 2015 dchang@suse.com
- ethernet: Convert dev_printk(KERN_<LEVEL> to dev_<level>(
  (bsc#909575 FATE#317552).
- cxgb3: remove __dev* attributes (bsc#909575 FATE#317552).
- PCI: Add standard PCIe Capability Link ASPM field names
  (bsc#909575 FATE#317552).
- cxgb3: Use standard #defines for PCIe Capability ASPM fields
  (bsc#909575 FATE#317552).
- drivers/net: fix up function prototypes after __dev* removals
  (bsc#909575 FATE#317552).
- remove init of dev->perm_addr in drivers (bsc#909575
  FATE#317552).
- chelsio: Use netdev_<level> and pr_<level> (bsc#909575
  FATE#317552).
- cxgb3: Update VLAN extraction stats in the GRO path (bsc#909575
  FATE#317552).
- cxgb3: Fix warning about using rcu_dereference when not in a
  rcu-locked section (bsc#909575 FATE#317552).
- cxgb3: Correct comparisons and calculations using skb->tail
  and skb-transport_header (bsc#909575 FATE#317552).
- cxgb3: Correct comparisons and calculations using skb->tail
  and skb-transport_header (bsc#909575 FATE#317552).
- cxgb3: Missing rtnl lock in error recovery (bsc#909575
  FATE#317552).
- treewide: Add __GFP_NOWARN to k.alloc calls with v.alloc
  fallbacks (bsc#909575 FATE#317552).
- device-core: Ensure drvdata = NULL when no driver is bound
  (bsc#909575 FATE#317552).
- net: cxgb3: remove unnecessary pci_set_drvdata() (bsc#909575
  FATE#317552).
- chelsio: remove duplicate defines (bsc#909575 FATE#317552).
- cxgb3: Fix length calculation in write_ofld_wr() on 32-bit
  architectures (bsc#909575 FATE#317552).
- net: cxgb3: slight optimization of addr compare (bsc#909575
  FATE#317552).
- drivers/net: delete non-required instances of include
  <linux/init.h> (bsc#909575 FATE#317552).
- cxgb3: Remove superfluous call to pci_disable_msix() (bsc#909575
  FATE#317552).
- cxgb3: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bsc#909575 FATE#317552).
- cxgb3: Call dev_kfree/consume_skb_any instead of [dev_]kfree_skb
  (bsc#909575 FATE#317552).
- net: get rid of SET_ETHTOOL_OPS (bsc#909575 FATE#317552).
- net: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate
  (bsc#909575 FATE#317552).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#909575
  FATE#317552).
- Refresh
  patches.drivers/cxgb3-set-vlan_feature-on-net_device.patch.
- commit 950c553
* Wed Jan 14 2015 mgalbraith@suse.de
- config: Disable CONFIG_RCU_FAST_NO_HZ (bnc#884817)
  This option has been verified to be racy vs hotplug, and is irrelevant
  to SLE in any case.
- commit 291c65f
* Wed Jan 14 2015 mgalbraith@suse.de
- config: Disable CONFIG_RCU_FAST_NO_HZ (bnc#884817)
  This option has been verified to be racy vs hotplug, and is irrelevant
  to SLE in any case.
- commit 65e1222
* Tue Jan 13 2015 dvaleev@suse.com
- powerpc/rtas_flash: Free kmem upon module exit (fate#317580).
- powerpc/rtas_flash: New return code to indicate FW entitlement
  expiry (fate#317580).
- powerpc/rtas_flash: Update return token comments (fate#317580).
- commit 6c976e3
* Tue Jan 13 2015 hare@suse.de
- PCI: Cache MSI/MSI-X capability offsets in struct pci_dev
  (bnc#909623,FATE#317523).
- commit c856168
* Tue Jan 13 2015 hare@suse.de
- pm8001: Update nvmd response data to request buffer
  (bnc#909623,FATE#317523).
- pm8001: fix pm8001_store_update_fw (bnc#909623,FATE#317523).
- pm8001: Fix erratic calculation in update_flash
  (bnc#909623,FATE#317523).
- pm8001: Fix invalid return when request_irq() failed
  (bnc#909623,FATE#317523).
- pm8001: fix a memory leak in nvmd_resp (bnc#909623,FATE#317523).
- pm8001: fix update_flash (bnc#909623,FATE#317523).
- pm8001: fix a memory leak in flash_update
  (bnc#909623,FATE#317523).
- pm8001: Cleaning up uninitialized variables
  (bnc#909623,FATE#317523).
- pm8001: Fix to remove null pointer checks that could never
  happen (bnc#909623,FATE#317523).
- pm8001: more fixes to honor return value
  (bnc#909623,FATE#317523).
- pm8001: add a new spinlock to protect the CCB
  (bnc#909623,FATE#317523).
- pm8001: honor return value (bnc#909623,FATE#317523).
- pm8001: clean bitmap management functions
  (bnc#909623,FATE#317523).
- pm8001: Fix hibernation issue (bnc#909623,FATE#317523).
- pm8001: Fix potential null pointer dereference and memory leak
  (bnc#909623,FATE#317523).
- pm80xx : Fix missing NULL pointer checks and memory leaks
  (bnc#909623,FATE#317523).
- drivers/scsi/pm8001/pm8001_ctl.c: avoid world-writable sysfs
  files (bnc#909623,FATE#317523).
- pm80xx: fix problem of pm8001_work_fn reseting incorrect phy
  (bnc#909623,FATE#317523).
- pm80xx: no need for tag allocation when issuing the command of
  (bnc#909623,FATE#317523).
- pm80xx: Spinlock fix (bnc#909623,FATE#317523).
- pm80xx: Enable BAR shift to avoid BIOS conflict with MPI space
  (bnc#909623,FATE#317523).
- pm80xx: Read saved WWN from NVMD for ATTO pm8001 based HBAs
  (bnc#909623,FATE#317523).
- pm80xx: Fixed return value issue (bnc#909623,FATE#317523).
- pm80xx: Removing redundant code snippets
  (bnc#909623,FATE#317523).
- pm80xx: Tasklets synchronization fix (bnc#909623,FATE#317523).
- pm80xx: Resetting the phy state (bnc#909623,FATE#317523).
- pm80xx: Fix for direct attached device (bnc#909623,FATE#317523).
- pm80xx: Module author addition (bnc#909623,FATE#317523).
- pm80xx: Firmware logging support (bnc#909623,FATE#317523).
- pm80xx: Phy settings support for motherboard controller
  (bnc#909623,FATE#317523).
- pm80xx: IButton security feature support for motherboard
  (bnc#909623,FATE#317523).
- pm80xx: Print SAS address of IO failed device
  (bnc#909623,FATE#317523).
- pm80xx: 4G boundary fix (bnc#909623,FATE#317523).
- pm80xx: Queue rotation logic for inbound and outbound queues
  (bnc#909623,FATE#317523).
- pm80xx: Set device state response logic fix
  (bnc#909623,FATE#317523).
- pm80xx: Display controller BIOS version
  (bnc#909623,FATE#317523).
- pm80xx: Indirect SMP request fix (bnc#909623,FATE#317523).
- pm80xx: Device id changes to support series 8 controllers
  (bnc#909623,FATE#317523).
- pm8001: clean up unnecessary MSI/MSI-X capability find
  (bnc#909623,FATE#317523).
- pm80xx: Fix for 32 bit compilation warning
  (bnc#909623,FATE#317523).
- pm80xx: fix Adaptec 71605H hang (bnc#909623,FATE#317523).
- pm8001: use pdev->pm_cap instead of (bnc#909623,FATE#317523).
- pm80xx: remove unneeded NULL check (bnc#909623,FATE#317523).
- libsas: implement > 16 byte CDB support
  (bnc#909623,FATE#317523).
- sas: unify the pointlessly separated enums sas_dev_type and
  (bnc#909623,FATE#317523).
- pm80xx: thermal, sas controller config and error handling
  (bnc#909623,FATE#317523).
- pm80xx: NCQ error handling changes (bnc#909623,FATE#317523).
- pm80xx: WWN Modification for PM8081/88/89 controllers
  (bnc#909623,FATE#317523).
- pm80xx: Changed module name and debug messages update
  (bnc#909623,FATE#317523).
- pm80xx: Firmware flash memory free fix, with addition of new
  (bnc#909623,FATE#317523).
- pm80xx: SPC new firmware changes for device id 0x8081 alone
  (bnc#909623,FATE#317523).
- pm80xx: Added SPCv/ve specific hardware functionalities and
  (bnc#909623,FATE#317523).
- pm80xx: MSI-X implementation for using 64 interrupts
  (bnc#909623,FATE#317523).
- pm80xx: Updated common functions common for SPC and SPCv/ve
  (bnc#909623,FATE#317523).
- pm80xx: Multiple inbound/outbound queue configuration
  (bnc#909623,FATE#317523).
- pm80xx: Added SPCv/ve specific ids, variables and modify for
  (bnc#909623,FATE#317523).
- pm80xx: fix for memory region free (bnc#909623,FATE#317523).
- commit c029374
* Tue Jan 13 2015 hare@suse.de
- mpt3sas: Bump mpt3sas driver version to 04.100.00.00
  (bnc#909784,FATE#317520).
- mpt3sas: Added Reply Descriptor Post Queue (RDPQ) Array support
  (bnc#909784,FATE#317520).
- mpt3sas: Added OEM branding Strings (bnc#909784,FATE#317520).
- mpt3sas: Copyright in driver sources is updated for year the
  2014 (bnc#909784,FATE#317520).
- mpt3sas: MPI2.5 Rev H (2.5.3) specifications
  (bnc#909784,FATE#317520).
- mpt3sas: Bump mpt3sas driver version to 03.100.00.00
  (bnc#909784,FATE#317520).
- mpt3sas: Clear PFA Status on SGPIO when PFA Drive is Removed or
  (bnc#909784,FATE#317520).
- mpt3sas: MPI2.5 Rev G (2.5.2) specifications
  (bnc#909784,FATE#317520).
- mpt3sas: delay scsi_add_host call to work with scsi-mq
  (bnc#909784,FATE#317520).
- mpt3sas: Rework the MSI-X grouping code
  (bnc#909784,FATE#317520).
- mpt3sas: combine fw_event_work and its event_data
  (bnc#909784,FATE#317520).
- mpt3sas: correct scsi_{target,device} hostdata allocation
  (bnc#909784,FATE#317520).
- mpt3sas: Remove use of DEF_SCSI_QCMD (bnc#909784,FATE#317520).
- mpt3sas: Remove uses of serial_number (bnc#909784,FATE#317520).
- Allow MPT Fusion SAS 3.0 driver to be built into the kernel
  (bnc#909784,FATE#317520).
- mpt3sas: Added a driver module parameter max_msix_vectors
  (bnc#909784,FATE#317520).
- mpt3sas: fix cleanup on controller resource mapping failure
  (bnc#909784,FATE#317520).
- mpt3sas: Bump driver version to v02.100.00.00
  (bnc#909784,FATE#317520).
- mpt3sas: when async scanning is enabled then while scanning,
  (bnc#909784,FATE#317520).
- mpt3sas: MPI2.5 Rev F v2.5.1.1 specification
  (bnc#909784,FATE#317520).
- mpt3sas: Infinite loops can occur if (bnc#909784,FATE#317520).
- mpt3sas: fix for kernel panic when driver loads with HBA
  (bnc#909784,FATE#317520).
- mpt3sas: Updated the Hardware timing requirements
  (bnc#909784,FATE#317520).
- mpt3sas: 2013 source code copyright (bnc#909784,FATE#317520).
- mpt3sas: don't wank with fasync on ->release()
  (bnc#909784,FATE#317520).
- mpt3sas: remove unused variables (bnc#909784,FATE#317520).
- mpt3sas: Remove unneeded version.h header inclusion
  (bnc#909784,FATE#317520).
- mpt3sas: cut and paste bug storing trigger mpi
  (bnc#909784,FATE#317520).
- commit 6a02c8b
* Tue Jan 13 2015 hare@suse.de
- mpt2sas: fix undefined reference to `__udivdi3' compilation
  errors (bnc#909785,FATE#317519).
- commit cf846c7
* Tue Jan 13 2015 hare@suse.de
- mpt2sas: Bump mpt2sas driver version to 18.100.00.00
  (bnc#909785,FATE#317519).
- mpt2sas: Get IOC_FACTS information using handshake protocol only
  (bnc#909785,FATE#317519).
- mpt2sas: Added Reply Descriptor Post Queue (RDPQ) Array support
  (bnc#909785,FATE#317519).
- mpt2sas: Avoid type casting for direct I/O commands
  (bnc#909785,FATE#317519).
- mpt2sas: Bump mpt2sas driver version to 17.100.00.00
  (bnc#909785,FATE#317519).
- mpt2sas: Clear PFA Status on SGPIO when PFA Drive is Removed or
  (bnc#909785,FATE#317519).
- mpt2sas: Copyright in driver sources is updated for year the
  2014 (bnc#909785,FATE#317519).
- mpt2sas: MPI2 Rev Y (2.00.17) and Rev Z (2.00.18) specifications
  (bnc#909785,FATE#317519).
- mpt2sas: Added driver module parameter max_msix_vectors
  (bnc#909785,FATE#317519).
- mpt2sas: delay scsi_add_host call to work with scsi-mq
  (bnc#909785,FATE#317519).
- mpt2sas: Rework the MSI-X grouping code
  (bnc#909785,FATE#317519).
- mpt2sas: annotate ioc->reply_post_host_index as __iomem
  (bnc#909785,FATE#317519).
- mpt2sas: combine fw_event_work and its event_data
  (bnc#909785,FATE#317519).
- mpt2sas: correct scsi_{target,device} hostdata allocation
  (bnc#909785,FATE#317519).
- mpt2sas: Add free smids to the head, not tail of list
  (bnc#909785,FATE#317519).
- mpt2sas: Remove use of DEF_SCSI_QCMD (bnc#909785,FATE#317519).
- mpt2sas: Remove uses of serial_number (bnc#909785,FATE#317519).
- mpt2sas: Don't disable device twice at suspend
  (bnc#909785,FATE#317519).
- mpt2sas: Bump driver version to v16.100.00.00
  (bnc#909785,FATE#317519).
- mpt2sas: Fix for kernel panic when driver loads with HBA
  connected to (bnc#909785,FATE#317519).
- mpt2sas: when Async scanning is enabled then while scanning,
  devices (bnc#909785,FATE#317519).
- mpt2sas: Infinite loop can occur if (bnc#909785,FATE#317519).
- mpt2sas: The copyright in driver sources is updated for the
  year 2013 (bnc#909785,FATE#317519).
- mpt2sas: MPI2 Rev X (2.00.16) specifications
  (bnc#909785,FATE#317519).
- mpt2sas: Change in MPI2_RAID_ACTION_SYSTEM_SHUTDOWN_INITIATED
  (bnc#909785,FATE#317519).
- mpt2sas: Null pointer deference possibility in
  (bnc#909785,FATE#317519).
- mpt2sas: fix cleanup on controller resource mapping failure
  (bnc#909785,FATE#317519).
- mpt2sas: fix for unused variable 'event_data' warning
  (bnc#909785,FATE#317519).
- mpt2sas: Bump driver vesion to v15.100.00.00
  (bnc#909785,FATE#317519).
- mpt2sas: Calulate the Reply post queue depth calculation as
  per the (bnc#909785,FATE#317519).
- mpt2sas: Fix for device scan following host reset could get
  stuck in (bnc#909785,FATE#317519).
- mpt2sas: Update the timing requirements for issuing a Hard Reset
  (bnc#909785,FATE#317519).
- mpt2sas: MPI2 Rev W (2.00.15) specification
  (bnc#909785,FATE#317519).
- mpt2sas: Fix for issue Missing delay not getting set during
  system (bnc#909785,FATE#317519).
- mpt2sas: don't wank with fasync on ->release()
  (bnc#909785,FATE#317519).
- mpt2sas: Add support for OEM specific controller
  (bnc#909785,FATE#317519).
- mpt2sas: Add a module parameter that permits overriding
  protection (bnc#909785,FATE#317519).
- mpt2sas: Return the correct sense key for DIF errors
  (bnc#909785,FATE#317519).
- mpt2sas: fix double mutex lock in NON_BLOCKING state
  (bnc#909785,FATE#317519).
- mpt2sas: Fix for issue - Unable to boot from the drive connected
  to (bnc#909785,FATE#317519).
- commit e074eaa
* Tue Jan 13 2015 ohering@suse.de
- storvsc: ring buffer failures may result in I/O freeze
- commit fa9d51e
* Tue Jan 13 2015 hare@suse.de
- megaraid: Fail resume if MSI-X re-initialization failed
  (bnc#909789,FATE#317517).
- Delete
  patches.drivers/megaraid_sas-0071-0071-megaraid-Fail-resume-if-MSI-X-re-initialization-fail.patch.
- Delete
  patches.drivers/megaraid_sas-0072-0072-megaraid-Use-pci_enable_msix_range-instead-of-pci_en.patch.
- Delete
  patches.drivers/megaraid_sas-0089-fix-bug-in-handling-return-value-of-pci.patch.
- commit 2abecc1
* Tue Jan 13 2015 hare@suse.de
- megaraid_sas: Use correct #define for MSI-X capability
  (bnc#909789,FATE#317517).
- megaraid_sas: release lock on error path
  (bnc#909789,FATE#317517).
- megaraid_sas: Return DID_ERROR for SCSI IO, when controller
  is in (bnc#909789,FATE#317517).
- megaraid_sas: Fix the interrupt mask for Gen2 controller
  (bnc#909789,FATE#317517).
- megaraid_sas: Update balance count in driver to be in sync of
  (bnc#909789,FATE#317517).
- megaraid_sas: Free event detail memory without device ID check
  (bnc#909789,FATE#317517).
- megaraid_sas: Set IO request timeout value provided by OS
  timeout for (bnc#909789,FATE#317517).
- megaraid_sas: Add support for MegaRAID Fury (device ID-0x005f)
  12Gb/s (bnc#909789,FATE#317517).
- megaraid_sas: Add support to display Customer branding details
  in (bnc#909789,FATE#317517).
- megaraid_sas: Set IoFlags to enable Fast Path for JBODs for
  12 Gb/s (bnc#909789,FATE#317517).
- megaraid_sas: Add support for Extended MSI-x vectors for 12Gb/s
  (bnc#909789,FATE#317517).
- megaraid_sas: Add support for Uneven Span PRL11
  (bnc#909789,FATE#317517).
- megaraid_sas: Add support to differentiate between iMR vs MR
  Firmware (bnc#909789,FATE#317517).
- megaraid_sas: Changelog and driver version update
  (bnc#909789,FATE#317517).
- megaraid: minor cut and paste error fixed
  (bnc#909789,FATE#317517).
- megaraid_sas: fix a bug for 64 bit arches
  (bnc#909789,FATE#317517).
- megaraid_sas: megaraid_sas driver init fails in kdump kernel
  (bnc#909789,FATE#317517).
- megaraid_sas: Add High Availability clustering support using
  (bnc#909789,FATE#317517).
- megaraid_sas: Version and Changelog update
  (bnc#909789,FATE#317517).
- megaraid_sas: addded support for big endian architecture
  (bnc#909789,FATE#317517).
- megaraid_sas: fixes for few endianess issues
  (bnc#909789,FATE#317517).
- megaraid_sas: Fix synchronization problem between sysPD IO
  (bnc#909789,FATE#317517).
- megaraid: Use resource_size_t for PCI resources, not long
  (bnc#909789,FATE#317517).
- megaraid: missing bounds check in mimd_to_kioc()
  (bnc#909789,FATE#317517).
- megaraid_sas_fusion: correctly pass queue info pointer
  (bnc#909789,FATE#317517).
- megaraid_sas_fusion: Return correct error value in
  (bnc#909789,FATE#317517).
- megaraid_sas: check return value for megasas_get_pd_list()
  (bnc#909789,FATE#317517).
- megaraid_sas: Don't wait forever for non-IOCTL DCMDs
  (bnc#909789,FATE#317517).
- megaraid_sas: Big endian code related fixes
  (bnc#909789,FATE#317517).
- megaraid_sas: Set 32-bit DMA mask (bnc#909789,FATE#317517).
- megaraid_sas: Performance boost fixes (bnc#909789,FATE#317517).
- megaraid_sas: Load correct raid context timeout
  (bnc#909789,FATE#317517).
- megaraid_sas: Fix megasas_ioc_init_fusion
  (bnc#909789,FATE#317517).
- megaraid_sas: Return leaked MPT frames to MPT frame pool
  (bnc#909789,FATE#317517).
- megaraid_sas: Add Dell PowerEdge VRTX SR-IOV VF support
  (bnc#909789,FATE#317517).
- megaraid_sas: Version and Changelog update
  (bnc#909789,FATE#317517).
- megaraid_sas: fix a small problem when reading state value
  from hw (bnc#909789,FATE#317517).
- megaraid: Fail resume if MSI-X re-initialization failed
  (bnc#909789,FATE#317517).
- megaraid: Use pci_enable_msix_range() instead of
  pci_enable_msix() (bnc#909789,FATE#317517).
- megaraid_sas: Fix LD/VF affiliation parsing
  (bnc#909789,FATE#317517).
- megaraid_sas: Add missing initial call to
  (bnc#909789,FATE#317517).
- megaraid_sas: Remove unused variables in megasas_instance
  (bnc#909789,FATE#317517).
- megaraid_sas: Fix reset_mutex leak (bnc#909789,FATE#317517).
- megaraid_sas: Version and Changelog update
  (bnc#909789,FATE#317517).
- megaraid_sas : Do not scan non syspd drives
  (bnc#909789,FATE#317517).
- megaraid_sas : Use writeq for 64bit pci write to avoid spinlock
  (bnc#909789,FATE#317517).
- megaraid_sas : Update threshold based reply post host index
  register (bnc#909789,FATE#317517).
- megaraid_sas : Firmware crash dump feature support
  (bnc#909789,FATE#317517).
- megaraid_sas : Extended VD support (bnc#909789,FATE#317517).
- megaraid_sas : Host lock less mode to enabled asynchronous IO
  (bnc#909789,FATE#317517).
- megaraid_sas : Round down max sge supported by controller to
  power of (bnc#909789,FATE#317517).
- megaraid_sas : Add module parameter to disable IRQ-CPU affinity
  hint (bnc#909789,FATE#317517).
- megaraid_sas : N-drive primary raid level 1 load balancing
  (bnc#909789,FATE#317517).
- megaraid_sas : MFI MPT linked list corruption fix
  (bnc#909789,FATE#317517).
- megaraid_sas : Driver version update (bnc#909789,FATE#317517).
- megaraid_sas: fix bug in handling return value of
  (bnc#909789,FATE#317517).
- megaraid_sas: driver version upgrade and remove some meta data
  of (bnc#909789,FATE#317517).
- megaraid_sas: update MAINTAINERS and copyright information for
  (bnc#909789,FATE#317517).
- megaraid_sas: online Firmware upgrade support for Extended VD
  feature (bnc#909789,FATE#317517).
- megaraid_sas: make HBA operational after LD_MAP_SYNC DCMD in
  OCR path (bnc#909789,FATE#317517).
- megaraid_sas: corrected return of wait_event from abort frame
  path (bnc#909789,FATE#317517).
- megaraid_sas: dndinaness related bug fixes
  (bnc#909789,FATE#317517).
- megaraid_sas: do not process IOCTLs and SCSI commands during
  driver (bnc#909789,FATE#317517).
- megaraid_sas: endianness related bug fixes and code optimization
  (bnc#909789,FATE#317517).
- megaraid_sas: add support for secure JBOD
  (bnc#909789,FATE#317517).
- megaraid_sas: fix the problem of non-existing VD exposed to host
  (bnc#909789,FATE#317517).
- megaraid_sas: disable interrupt_mask before enabling hardware
  interrupts (bnc#909789,FATE#317517).
- megaraid_sas: complete outstanding IOCTLs before killing adapter
  (bnc#909789,FATE#317517).
- megaraid_sas: reserve commands for IOCTLs and internal DCMDs
  (bnc#909789,FATE#317517).
- megaraid_sas: remove redundant memset call
  (bnc#909789,FATE#317517).
- megaraid_sas: driver version update (bnc#909789,FATE#317517).
- Delete patches.drivers/megaraid_sas_fix_kdump.patch.
- commit 100d0a0
* Tue Jan 13 2015 glin@suse.com
- PCI: Add pci_device_type to pdev's device struct (bsc#909350,
  FATE#317546).
- PCI: SRIOV control and status via sysfs (bsc#909350,
  FATE#317546).
- pci: Set dev->dev.type in alloc_pci_dev (bsc#909350,
  FATE#317546).
- Refresh
  patches.drivers/cxgb3-0023-PCI-Make-pci_error_handlers-const.patch.
- Refresh
  patches.fixes/PCI-Provide-method-to-reduce-the-number-of-total-VFs.patch.
- commit 7fc8d46
* Tue Jan 13 2015 jjolly@suse.de
- s390/kernel: add system calls for PCI memory access
  (FATE#318094, LTC#117845).
- commit 68cbae5
* Tue Jan 13 2015 bpoirier@suse.de
- be2net: Change driver version to indicate a SUSE backport
  (bnc#908322 FATE#317535).
- commit 7abcc94
* Tue Jan 13 2015 hare@suse.de
- aacraid: kdump fix (bnc#909622,FATE#317525).
- aacraid: Fix for arrays are going offline in the system. System
  hangs (bnc#909622,FATE#317525).
- aacraid: Dual firmware image support (bnc#909622,FATE#317525).
- aacraid: suppress two GCC warnings (bnc#909622,FATE#317525).
- aacraid: 1024 max outstanding command support for Series 7
  and above (bnc#909622,FATE#317525).
- aacraid: SCSI dma mapping failure case handling
  (bnc#909622,FATE#317525).
- commit 61a1599
* Mon Jan 12 2015 hare@suse.de
- Reshuffle patches to apply
- commit bd7fc14
* Mon Jan 12 2015 jbeulich@suse.com
- PCI/MSI: Add pci_enable_msi_range() and pci_enable_msix_range()
  (bnc#908322 FATE#317535).
- x86-64, espfix: Don't leak bits 31:16 of %%esp returning to
  16-bitstack (bsc#907818,CVE-2014-9090).
- x86, espfix: Make it possible to disable 16-bit support
  (bsc#907818,CVE-2014-9090).
- x86_64/entry/xen: Do not invoke espfix64 on Xen
  (bsc#907818,CVE-2014-9090).
- x86_64, traps: Fix the espfix64 #DF fixup and rewrite it in C
  (bsc#907818,CVE-2014-9090).
- x86_64, traps: Rework bad_iret (bsc#909077,CVE-2014-8133).
- x86_64, traps: Stop using IST for #SS (bsc#907818,
  CVE-2014-9090, CVE-2014-9322).
- x86, asm: Flip RESTORE_ARGS arguments logic
  (bsc#907818,CVE-2014-9090).
- Refresh other Xen patches.
- commit ac6b8d7
* Mon Jan 12 2015 hare@suse.de
- scsi_transport_fc: Add 32Gbps speed definition
  (bnc#909372,FATE#317544).
- commit c560518
* Mon Jan 12 2015 hare@suse.de
- qla2xxx: Remove debug code that msleeps for random duration
  (bnc#909372,FATE#317544).
- qla2xxx: Integrate generic card temperature with mezz card
  (bnc#909372,FATE#317544).
- qla2xxx: Add clarifying printk to thermal access fail cases
  (bnc#909372,FATE#317544).
- qla2xxx: Enhancements to support ISPFx00
  (bnc#909372,FATE#317544).
- qla2xxx: Remove unused function (bnc#909372,FATE#317544).
- qla2xxx: fix sparse warning "large integer implicitly
  (bnc#909372,FATE#317544).
- qla2xxx: qla2x00_sp_compl can be static
  (bnc#909372,FATE#317544).
- qla2xxx: Set the index in outstanding command array to NULL
  (bnc#909372,FATE#317544).
- qla2xxx: Move qla2x00_free_device to the correct location
  (bnc#909372,FATE#317544).
- qla2xxx: Do not query FC statistics during chip reset
  (bnc#909372,FATE#317544).
- qla2xxx: Do not take a second firmware dump when intentionally
  (bnc#909372,FATE#317544).
- qla2xxx: Fix sparse warning from qla_mr.c and qla_iocb.c
  (bnc#909372,FATE#317544).
- qla2xxx: Clean up qla24xx_iidma() (bnc#909372,FATE#317544).
- qla2xxx: Clean up qla84xx_mgmt_cmd() (bnc#909372,FATE#317544).
- qla2xxx: Remove dead code in qla2x00_configure_hba()
  (bnc#909372,FATE#317544).
- qla2xxx: Remove two superfluous tests (bnc#909372,FATE#317544).
- qla2xxx: Remove a dead assignment in (bnc#909372,FATE#317544).
- qla2xxx: Remove redundant assignments (bnc#909372,FATE#317544).
- qla2xxx: Help Coverity with analyzing ct_sns_pkt
  (bnc#909372,FATE#317544).
- qla2xxx: Fix qla2xxx_check_risc_status()
  (bnc#909372,FATE#317544).
- qla2xxx: Remove an unused variable from qla2x00_remove_one()
  (bnc#909372,FATE#317544).
- qla2xxx: Fix a memory leak in an error path of
  (bnc#909372,FATE#317544).
- qla2xxx: Fix sparse warnings in qlafx00_fxdisc_iocb function
  (bnc#909372,FATE#317544).
- qla2xxx: Enable target mode support for ISP83xx
  (bnc#909372,FATE#317544).
- qla2xxx: Prevent enabling target mode for unsupported HBAs
  (bnc#909372,FATE#317544).
- qla2xxx: Add support for ISP8044 (bnc#909372,FATE#317544).
- qla2xxx: Fix incorrect test after list_for_each_entry() exits
  (bnc#909372,FATE#317544).
- qla2xxx: Correct multiqueue offset calculations
  (bnc#909372,FATE#317544).
- qla2xxx: Set factory reset recovery timeout to 10 min. for
  (bnc#909372,FATE#317544).
- qla2xxx: Perform warm reset every 2 minutes if firmware load
  (bnc#909372,FATE#317544).
- qla2xxx: Add ISPFX00 specific bus reset routine
  (bnc#909372,FATE#317544).
- qla2xxx: Remove QL_DEBUG_LEVEL_17 defines from qla_nx.c
  (bnc#909372,FATE#317544).
- qla2xxx: Add setting of driver version string for vendor
  (bnc#909372,FATE#317544).
- qla2xxx: Reconfigure thermal temperature
  (bnc#909372,FATE#317544).
- qla2xxx: Notify ISPFX00 firmware when driver is unloaded or
  (bnc#909372,FATE#317544).
- qla2xxx: Add critical temperature handling for ISPFX00
  (bnc#909372,FATE#317544).
- qla2xxx: Make log message that prints when a completion status
  (bnc#909372,FATE#317544).
- qla2xxx: Add missing FCP statistics to sysfs interface
  (bnc#909372,FATE#317544).
- qla2xxx: Add changes to support extended IOs for ISPFX00
  (bnc#909372,FATE#317544).
- qla2xxx: Add changes in initialization for ISPFX00 cards with
  (bnc#909372,FATE#317544).
- qla2xxx: Send all AENs for ISPFx00 to above layers
  (bnc#909372,FATE#317544).
- qla2xxx: Remove handling of Shutdown Requested AEN from
  (bnc#909372,FATE#317544).
- qla2xxx: Correct Interrupt Register offset for ISPFX00
  (bnc#909372,FATE#317544).
- qla2xxx: QLAFX00 make over temperature AEN handling
  (bnc#909372,FATE#317544).
- qla2xxx: Set default critical temperature value in cases when
  (bnc#909372,FATE#317544).
- qla2xxx: Add loopback IDC-TIME-EXTEND aen handling support
  (bnc#909372,FATE#317544).
- qla2xxx: Select link initialization option bits from current
  (bnc#909372,FATE#317544).
- qla2xxx: Move queue depth ramp down message to i/o debug
  (bnc#909372,FATE#317544).
- qla2xxx: Add a new interface to update versions
  (bnc#909372,FATE#317544).
- qla2xxx: Correctly print out/in mailbox registers
  (bnc#909372,FATE#317544).
- qla2xxx: Correction to message ids (bnc#909372,FATE#317544).
- qla2xxx: print MAC via %%pMR (bnc#909372,FATE#317544).
- qla2xxx: Use pcie_is_pcie() to simplify code
  (bnc#909372,FATE#317544).
- qla2xxx: Use standard PCIe Capability Link register field
  (bnc#909372,FATE#317544).
- qla2xxx: Print proper QLAFX00 product name at probe
  (bnc#909372,FATE#317544).
- qla2xxx: Honor execute firmware failures
  (bnc#909372,FATE#317544).
- qla2xxx: Disable INTx interrupt for ISP82XX
  (bnc#909372,FATE#317544).
- qla2xxx: Correctly set mailboxes for extended init control
  (bnc#909372,FATE#317544).
- qla2xxx: Add BPM support for ISP25xx (bnc#909372,FATE#317544).
- qla2xxx: Don't consider the drivers knocked out of IDC
  (bnc#909372,FATE#317544).
- Revert "qla2xxx: Ramp down queue depth for attached SCSI
  (bnc#909372,FATE#317544).
- qla2xxx: Refactor shutdown code so some functionality can be
  (bnc#909372,FATE#317544).
- qla2xxx: Disable adapter when we encounter a PCI disconnect
  (bnc#909372,FATE#317544).
- qla2xxx: Fix issue with not displaying node name after system
  (bnc#909372,FATE#317544).
- qla2xxx: Add BSG interface for read/write serdes register
  (bnc#909372,FATE#317544).
- qla2xxx: Fix undefined behavior in call to snprintf()
  (bnc#909372,FATE#317544).
- qla2xxx: Clear RISC INT reg only for an event and not always
  (bnc#909372,FATE#317544).
- qla2xxx: Add logic to abort BSG commands for ISPFX00
  (bnc#909372,FATE#317544).
- qla2xxx: Add changes to obtain ISPFX00 adapters product
  (bnc#909372,FATE#317544).
- qla2xxx: Use the correct mailbox registers when acknowledging
  (bnc#909372,FATE#317544).
- qla2xxx: Use scnprintf() instead of snprintf() in the sysfs
  (bnc#909372,FATE#317544).
- qla2xxx: Only complete dcbx_comp and lb_portup_comp for
  (bnc#909372,FATE#317544).
- qla2xxx: Reset nic_core_reset_owner on moving from COLD to
  (bnc#909372,FATE#317544).
- qla2xxx: Replace a constant with a macro definition for
  (bnc#909372,FATE#317544).
- qla2xxx: Update the driver version to 8.06.00.12-k
  (bnc#909372,FATE#317544).
- qla2xxx: Fix warning reported by smatch
  (bnc#909372,FATE#317544).
- qla2xxx: Fix scsi_host leak on qlt_lport_register callback
  failure (bnc#909372,FATE#317544).
- qla2xxx: Remove last vestiges of qla_tgt_cmd.cmd_list
  (bnc#909372,FATE#317544).
- qla2xxx: Fix kernel panic on selective retransmission request
  (bnc#909372,FATE#317544).
- qla2xxx: Fix multiqueue MSI-X registration
  (bnc#909372,FATE#317544).
- qla2xxx: Add mutex around optrom calls to serialize accesses
  (bnc#909372,FATE#317544).
- qla2xxx: Add handling for boot indication progress AENs for
  (bnc#909372,FATE#317544).
- qla2xxx: Replace constant value for IOCTL IOCB abort execution
  (bnc#909372,FATE#317544).
- qla2xxx: Use proper message for Non owner reset ACK Timeout
  (bnc#909372,FATE#317544).
- qla2xxx: Remove init control block related dead code for
  (bnc#909372,FATE#317544).
- qla2xxx: Select correct request queue for error type IOCB for
  (bnc#909372,FATE#317544).
- qla2xxx: Enable the Flash Access Control (FAC) mailbox
  (bnc#909372,FATE#317544).
- qla2xxx: Properly handle 32 bit mailbox register for ISPFX00
  (bnc#909372,FATE#317544).
- qla2xxx: Set host can_queue value based on available
  (bnc#909372,FATE#317544).
- qla2xxx: Add support for ISP2071 (bnc#909372,FATE#317544).
- qla2xxx: Remove Marker type IOCB logic for ISPFX00
  (bnc#909372,FATE#317544).
- qla2xxx: Remove ISP_ABORT_NEEDED and ISP_ABORT_RETRY checks
  (bnc#909372,FATE#317544).
- qla2xxx: Add changes in the IOCB structures to adjust driver
  (bnc#909372,FATE#317544).
- qla2xxx: Avoid poisoning in the response queue for ISPFX00
  (bnc#909372,FATE#317544).
- qla2xxx: Simplify the ISPFX00 interrupt handler code for
  (bnc#909372,FATE#317544).
- qla2xxx: Read capture firmware dump on mailbox timeout for
  (bnc#909372,FATE#317544).
- qla2xxx: Correctly set the read_optrom pointer for ISP8044
  (bnc#909372,FATE#317544).
- qla2xxx: Update the driver version to 8.07.00.02-k
  (bnc#909372,FATE#317544).
- qla2xxx: Correct the port no assignment for ISP82XX
  (bnc#909372,FATE#317544).
- qla2xxx: Fix Task Management command asynchronous handling
  (bnc#909372,FATE#317544).
- qla2xxx: Add IOCB Abort command asynchronous handling
  (bnc#909372,FATE#317544).
- qla2xxx: fix error handling of qla2x00_mem_alloc()
  (bnc#909372,FATE#317544).
- qla2xxx: Re-sync module parameter descriptions with the code
  (bnc#909372,FATE#317544).
- qla2xxx: Fix build errors related to invalid print fields on
  (bnc#909372,FATE#317544).
- qla2xxx: Wait for reset completion without lock for ISPFX00
  (bnc#909372,FATE#317544).
- qla2xxx: Do not schedule reset when one is already active when
  (bnc#909372,FATE#317544).
- qla2xxx: Correct operations for ISP27xx template types 270
  and 271 (bnc#909372,FATE#317544).
- qla2xxx: Allow ISP83XX and ISP27XX both to write req_q_out
  register (bnc#909372,FATE#317544).
- qla2xxx: Correct ISP83xx/ISP27xx mislogic in setting out_mb in
  (bnc#909372,FATE#317544).
- qla2xxx: Log when device state is moved to failed state
  (bnc#909372,FATE#317544).
- qla2xxx: Add pci device id 0x2271 (bnc#909372,FATE#317544).
- qla2xxx: Allow the next firmware dump if the previous dump
  capture (bnc#909372,FATE#317544).
- qla2xxx: Support of new firmware dump opcodes QLA8044_RDDFE(38),
  (bnc#909372,FATE#317544).
- qla2xxx: Check for peg alive counter and clear any outstanding
  (bnc#909372,FATE#317544).
- qla2xxx: Add ISP8044 serdes bsg interface
  (bnc#909372,FATE#317544).
- qla2xxx: Correction to ISP27xx template entry types 256 and 258
  (bnc#909372,FATE#317544).
- qla2xxx: Track the process when the ROM_LOCK failure happens
  (bnc#909372,FATE#317544).
- qla2xxx: Remove unnecessary delays from fw dump code path
  (bnc#909372,FATE#317544).
- qla2xxx: Introduce fw_dump_flag to track fw dump progress
  (bnc#909372,FATE#317544).
- qla2xxx: Enable fw_dump_size for ISP8044
  (bnc#909372,FATE#317544).
- qla2xxx: Update entry type 270 to match spec update
  (bnc#909372,FATE#317544).
- qla2xxx: Decrease pci access for response queue processing for
  (bnc#909372,FATE#317544).
- qla2xxx: Use proper log message for flash lock failed error
  (bnc#909372,FATE#317544).
- qla2xxx: Include <delay.h> file for msleep declartion in
  qla_nx2.c (bnc#909372,FATE#317544).
- qla2xxx: Remove unnecessary printk_ratelimited from qla_nx2.c
  (bnc#909372,FATE#317544).
- qla2xxx: ISP8044 poll ipmdio bus timeout improvement
  (bnc#909372,FATE#317544).
- qla2xxx: IOCB data should be copied to I/O mem using memcpy_toio
  (bnc#909372,FATE#317544).
- qla2xxx: Adjust adapter reset routine to the changes in firmware
  (bnc#909372,FATE#317544).
- qla2xxx: Check the QLA8044_CRB_DRV_ACTIVE_INDEX register when
  we are (bnc#909372,FATE#317544).
- qla2xxx: ISP27xx firmware dump template spec updates (including
  (bnc#909372,FATE#317544).
- qla2xxx: ISP27xx queue index shadow registers
  (bnc#909372,FATE#317544).
- qla2xxx: Delay driver unload if there is any pending activity
  going (bnc#909372,FATE#317544).
- qla2xxx: Fix beacon blink logic for ISP26xx/83xx
  (bnc#909372,FATE#317544).
- qla2xxx: Add MBC option for fast SFP data access
  (bnc#909372,FATE#317544).
- qla2xxx: Remove mapped vp index iterator macro dead code
  (bnc#909372,FATE#317544).
- qla2xxx: ABTS cause double free of qla_tgt_cmd +
  (bnc#909372,FATE#317544).
- qla2xxx: Do logins from a chip reset in DPC thread instead of
  the (bnc#909372,FATE#317544).
- qla2xxx: Remove wait for online from host reset handler
  (bnc#909372,FATE#317544).
- qla2xxx: Update the driver version to 8.07.00.08-k
  (bnc#909372,FATE#317544).
- qla2xxx: fix incorrect debug printk (bnc#909372,FATE#317544).
- qla2xxx: Use kmemdup instead of kmalloc + memcpy
  (bnc#909372,FATE#317544).
- qla2xxx: Restrict max_lun to 16-bit for older HBAs
  (bnc#909372,FATE#317544).
- qla2xxx: Use dma_zalloc_coherent (bnc#909372,FATE#317544).
- qla2xxx: Use pci_enable_msix_range() instead of
  pci_enable_msix() (bnc#909372,FATE#317544).
- qla2xxx: Move mailbox failure messages to a default debug level
  (bnc#909372,FATE#317544).
- qla2xxx: Remove restriction on starting remote device discovery
  on (bnc#909372,FATE#317544).
- qla2xxx: Fix shost use-after-free on device removal
  (bnc#909372,FATE#317544).
- qla2xxx: Use qla2x00_clear_drv_active on probe failure
  (bnc#909372,FATE#317544).
- qla2xxx: Collect PCI register checks and board_disable
  scheduling (bnc#909372,FATE#317544).
- qla2xxx: Schedule board_disable only once
  (bnc#909372,FATE#317544).
- qla2xxx: Prevent removal and board_disable race
  (bnc#909372,FATE#317544).
- qla2xxx: Prevent probe and board_disable race
  (bnc#909372,FATE#317544).
- qla2xxx: ISP27xx add tests for incomplete template
  (bnc#909372,FATE#317544).
- qla2xxx: ISP27xx optimize fwdump entry table lookup
  (bnc#909372,FATE#317544).
- qla2xxx: ISP27xx fwdump template remove high frequency debug
  logs (bnc#909372,FATE#317544).
- qla2xxx: ISP27xx fwdump template fix insertbuf() routine
  (bnc#909372,FATE#317544).
- qla2xxx: Add ISP27xx fwdump template entry T275 (insert buffer)
  (bnc#909372,FATE#317544).
- qla2xxx: Enable fast flash access for ISP83xx
  (bnc#909372,FATE#317544).
- qla2xxx: Add endianizer to max_payload_size modifier
  (bnc#909372,FATE#317544).
- qla2xxx: ISP25xx multiqueue shadow register crash fix
  (bnc#909372,FATE#317544).
- qla2xxx: ISP27xx fwdump template error print simplification
  (bnc#909372,FATE#317544).
- qla2xxx: Fix potential return count bug in
  qla2xxx_get_vpd_field() (bnc#909372,FATE#317544).
- qla2xxx: ISPFX00 avoid writing semaphore register in
  request_irqs() (bnc#909372,FATE#317544).
- qla2xxx: Incorrect debug level on mailbox command print 0x1111
  (bnc#909372,FATE#317544).
- qla2xxx: Incorrect linked list semantic in qlafx00_get_fcport()
  (bnc#909372,FATE#317544).
- qla2xxx: ISPFx00 unexpected resets during adapter boot sequence
  (bnc#909372,FATE#317544).
- qla2xxx: Add FDMI-2 functionality (bnc#909372,FATE#317544).
- qla2xxx: Add FA-WWN functionality (bnc#909372,FATE#317544).
- qla2xxx: Add diagnostic port functionality
  (bnc#909372,FATE#317544).
- qla2xxx: Fix driver version string message
  (bnc#909372,FATE#317544).
- qla2xxx: Allow user to change ql2xfdmienable value
  (bnc#909372,FATE#317544).
- qla2xxx: Unload of qla2xxx driver crashes the machine
  (bnc#909372,FATE#317544).
- qla2xxx: Add fix in driver unload for pending activity
  (bnc#909372,FATE#317544).
- qla2xxx: Declaration error cause stack corruption
  (bnc#909372,FATE#317544).
- qla2xxx: Enable diagnostic port using NVRAM parameters
  (bnc#909372,FATE#317544).
- qla2xxx: Disable laser for ISP2031 while unloading driver
  (bnc#909372,FATE#317544).
- qla2xxx: Free sysfs attributes for ISP27xx
  (bnc#909372,FATE#317544).
- qla2xxx: Force use of mailbox interface for flash access
  commands for (bnc#909372,FATE#317544).
- qla2xxx: Add missing ISP27xx checks to optrom code
  (bnc#909372,FATE#317544).
- qla2xxx: Honor FCP_RSP retry delay timer field
  (bnc#909372,FATE#317544).
- qla2xxx: Restore WWPN in case of Loop Dead
  (bnc#909372,FATE#317544).
- qla2xxx: Mark port lost when we receive an RSCN for it
  (bnc#909372,FATE#317544).
- qla2xxx: Disable PCI device in shutdown handler
  (bnc#909372,FATE#317544).
- qla2xxx: Fail adapter initialization on load ram failure
  (bnc#909372,FATE#317544).
- qla2xxx: Move warning message to debug level
  (bnc#909372,FATE#317544).
- qla2xxx: Fix sparse warning in qla_iocb.c file
  (bnc#909372,FATE#317544).
- qla2xxx: Update the driver version to 8.07.00.16-k
  (bnc#909372,FATE#317544).
- qla2xxx: Use correct offset to req-q-out for reserve calculation
  (bnc#909372,FATE#317544).
- qla2xxx: Increase room in request queue for sending priority
  packets (bnc#909372,FATE#317544).
- qla2xxx: Increase the request queue size to 8K for ISP2031
  (bnc#909372,FATE#317544).
- qla2xxx: remove redundant declaration in 'qla_gbl.h'
  (bnc#909372,FATE#317544).
- qla2xxx: fix race in handling rport deletion during recovery
  causes (bnc#909372,FATE#317544).
- qla2xxx: fix busy wait regression (bnc#909372,FATE#317544).
- Delete
  patches.drivers/qla2xxx-Set-host-can_queue-value-based-on-available.patch.
- commit cf3eaeb
* Mon Jan 12 2015 mhocko@suse.cz
- mm: fix corner case in anon_vma endless growing prevention
  (bnc#904242).
- commit bc81ecd
* Mon Jan 12 2015 mhocko@suse.cz
- Refresh
  patches.fixes/mm-prevent-endless-growth-of-anon_vma-hierarchy.
- commit bf9c9b0
* Fri Jan  9 2015 ohering@suse.de
- hyperv: Fix some variable name typos in send-buffer init/revoke
  (fate#317533).
- storvsc: ring buffer failures may result in I/O freeze
  (fate#317533).
- commit 8252d17
* Thu Jan  8 2015 glin@suse.com
- qlge: fix an "&&" vs "||" bug (bsc#912171).
- commit b976670
* Tue Jan  6 2015 jack@suse.cz
- udf: Check component length before reading it.
- udf: Check path length when reading symlink.
- udf: Verify symlink size before loading it.
- udf: Verify i_size when loading inode.
- isofs: Fix unchecked printing of ER records.
- isofs: Fix infinite looping over CE entries (bnc#911325
  CVE-2014-9420).
- commit 8872db9
* Tue Jan  6 2015 mmarek@suse.cz
- rpm/kernel-source.spec.in: Restore accidentally deleted %%source_timestamp
- commit 93fab0f
* Mon Jan  5 2015 bp@suse.de
- x86, kvm: Clear paravirt_enabled on KVM guests for espfix32's
  benefit (bsc#909078, CVE-2014-8134).
- commit 54cdab5
* Mon Jan  5 2015 jroedel@suse.de
- x86: UV BAU: Increase maximum CPUs per socket/hub (bsc#911181).
- x86: UV BAU: Avoid NULL pointer reference in ptc_seq_show
  (bsc#911181).
- commit 99e6788
* Mon Jan  5 2015 tiwai@suse.de
- mei: me: add Lynx Point Wellsburg work station device id
  (bnc#876086).
- mei: add 9 series PCH mei device ids (bnc#876086).
- mei: me: do not load the driver if the FW doesn't support MEI
  interface (bnc#876086).
- mei: limit the number of consecutive resets (bnc#876086).
- mei: ME hardware reset needs to be synchronized (bnc#876086).
- mei: me: fix hardware reset flow (bnc#876086).
- mei: add hw start callback (bnc#876086).
- mei: me: read H_CSR after asserting reset (bnc#876086).
- mei: me: clear interrupts on the resume path (bnc#876086).
- mei: cancel stall timers in mei_reset (bnc#876086).
- mei: don't have to clean the state on power up (bnc#876086).
- Delete patches.drivers/mei-ME-hardware-reset-synchronized.patch.
- Delete
  patches.drivers/mei-me-do-not-load-the-driver-if-the-FW-doesnt-support.
- commit 063d4b7
* Mon Jan  5 2015 jroedel@suse.de
- x86/uv: Update the UV3 TLB shootdown logic (bsc#909092).
- x86/UV: Fix NULL pointer dereference in uv_flush_tlb_others()
  if the 'nobau' boot option is used (bsc#909092).
- x86/uv: Work around UV2 BAU hangs (bsc#909092).
- x86/uv: Implement UV BAU runtime enable and disable control
  via /proc/sgi_uv/ (bsc#909092).
- x86/uv: Fix the UV BAU destination timeout period (bsc#909092).
- x86/uv: Fix UV2 BAU legacy mode (bsc#909092).
- commit 52e6495
* Mon Jan  5 2015 glin@suse.com
- slab: introduce kmalloc_array() (bsc#909361 FATE#317547).
- qlge: Fix compilation warning (bsc#909361 FATE#317547).
- qlge: Fix TSO for non-accelerated vlan traffic (bsc#909361 FATE#317547).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bsc#909361 FATE#317547).
- qlogic: use pci_zalloc_consistent (bsc#909361 FATE#317547).
- pci-dma-compat: add pci_zalloc_consistent helper (bsc#909361 FATE#317547).
- net: get rid of SET_ETHTOOL_OPS (bsc#909361 FATE#317547).
- qlge: Convert /n to \n (bsc#909361 FATE#317547).
- qlge: remove open-coded skb_cow_head (bsc#909361 FATE#317547).
- qlge: Do not propaged vlan tag offloads to vlans (bsc#909361 FATE#317547).
- qlge: Use pci_enable_msix_range() instead of pci_enable_msix() (bsc#909361 FATE#317547).
- qlge: Get rid of an redundant assignment (bsc#909361 FATE#317547).
- drivers/net: delete non-required instances of include <linux/init.h> (bsc#909361 FATE#317547).
- qlge: Fix vlan netdev features (bsc#909361 FATE#317547).
- qlge: make local function static (bsc#909361 FATE#317547).
- qlge: Update version to 1.00.00.34 (bsc#909361 FATE#317547).
- qlge: Allow enable/disable rx/tx vlan acceleration independently (bsc#909361 FATE#317547).
- qlge: Fix ethtool statistics (bsc#909361 FATE#317547).
- net: qlge: remove unnecessary pci_set_drvdata() (bsc#909361 FATE#317547).
- qlge: Update version to 1.00.00.33 (bsc#909361 FATE#317547).
- qlge: Enhance nested VLAN (Q-in-Q) handling (bsc#909361 FATE#317547).
- qlogic: Remove extern from function prototypes (bsc#909361 FATE#317547).
- qlge: call ql_core_dump() only if dump memory was allocated (bsc#909361 FATE#317547).
- ethernet: Convert mac address uses of 6 to ETH_ALEN (bsc#909361 FATE#317547).
- qlge: add missing free_netdev() on error in qlge_probe() (bsc#909361 FATE#317547).
- net/ethernet/qlogic/qlge/qlge_main: Use module_pci_driver to register driver (bsc#909361 FATE#317547).
- PCI: Add helper macro for pci_register_driver boilerplate (bsc#909361 FATE#317547).
- drivers:net: Remove unnecessary OOM messages after netdev_alloc_skb (bsc#909361 FATE#317547).
- drivers: net: Remove remaining alloc/OOM messages (bsc#909361 FATE#317547).
- ethernet: Remove unnecessary alloc/OOM messages, alloc cleanups (bsc#909361 FATE#317547).
- netdev: make pci_error_handlers const (bsc#909361 FATE#317547).
- qlge: fix an "&&" vs "||" bug (bsc#909361 FATE#317547).
- slab: introduce kmalloc_array() (bsc#909361 FATE#317547).
- commit 6b6576c
* Fri Jan  2 2015 bpoirier@suse.de
- Clarify directives about the "xen3-auto-*" patches
  "The rule is rather simple, [...]: Adjusting these patches for context is _of
  course_ fine. Putting into them any fixes or other code adjustments is not."
- commit 3f6fa6f
* Fri Jan  2 2015 bpoirier@suse.de
- Refresh patches.xen/xen3-auto-common.diff.
- Delete patches.xen/remove-context-for-xen3-auto-common.patch.
- Delete patches.xen/restore-context-for-xen3-auto-common.patch.
  Remove the workaround introduced in 6d183a6.
- commit 2c223a1
* Fri Jan  2 2015 dbueso@suse.de
- rpm/old-flavors: Obsolete kernel-bigsmp (fate#318083)
- commit 62430e1
* Wed Dec 31 2014 lduncan@suse.com
- libiscsi: Added new boot entries in the session sysfs
  (FATE#317527 bsc#909612).
- commit 0887c36
* Tue Dec 30 2014 mmarek@suse.cz
- Refresh
  patches.fixes/0005-NFSv4-Ensure-delegation-recall-and-byte-range-lock-r.patch.
- Delete
  patches.kabi/0001-NFSv4-Allow-the-state-manager-to-mark-an-open_owner-.patch.
- commit 6089523
* Fri Dec 26 2014 bpoirier@suse.de
- net: Add functions netif_reset_xps_queue and netif_set_xps_queue
  (bnc#909484 FATE#317397).
- xps: Add xps_queue_release function (bnc#909484 FATE#317397).
- commit 816650d
* Fri Dec 26 2014 bpoirier@suse.de
- copy of PCI/MSI: Add pci_enable_msi_range() and
  pci_enable_msix_range() (bug#908322 FATE#317535).
- commit 743b40c
* Thu Dec 25 2014 bpoirier@suse.de
- net: Check for presence of IFLA_AF_SPEC (bnc#908322
  FATE#317535).
- net: Validate IFLA_BRIDGE_MODE attribute length (bnc#908322
  FATE#317535).
- be2net: fix alignment on line wrap (bnc#908322 FATE#317535).
- be2net: remove multiple assignments on a single line (bnc#908322
  FATE#317535).
- be2net: remove space after typecasts (bnc#908322 FATE#317535).
- be2net: remove unnecessary blank lines after an open brace
  (bnc#908322 FATE#317535).
- be2net: insert a blank line after function/struct//enum
  definitions (bnc#908322 FATE#317535).
- be2net: remove multiple blank lines (bnc#908322 FATE#317535).
- be2net: add blank line after declarations (bnc#908322
  FATE#317535).
- be2net: remove return statements for void functions (bnc#908322
  FATE#317535).
- be2net: add speed reporting for 20G-KR interface (bnc#908322
  FATE#317535).
- be2net: add speed reporting for 40G/KR interface (bnc#908322
  FATE#317535).
- be2net: fix sparse warnings in be_cmd_req_port_type{}
  (bnc#908322 FATE#317535).
- be2net: fix a sparse warning in be_cmd_modify_eqd() (bnc#908322
  FATE#317535).
- be2net: enable PCIe error reporting on VFs too (bnc#908322
  FATE#317535).
- be2net: send a max of 8 EQs to be_cmd_modify_eqd() on Lancer
  (bnc#908322 FATE#317535).
- net: added support for 40GbE link (bnc#908322 FATE#317535).
- be2net: fix port-type reporting in get_settings (bnc#908322
  FATE#317535).
- be2net: add ethtool "-m" option support (bnc#908322
  FATE#317535).
- be2net: use v1 of SET_FLOW_CONTROL command (bnc#908322
  FATE#317535).
- be2net: fix RX fragment posting for jumbo frames (bnc#908322
  FATE#317535).
- be2net: replace strcpy with strlcpy (bnc#908322 FATE#317535).
- be2net: fix some log messages (bnc#908322 FATE#317535).
- be2net: query max_tx_qs for BE3 super-nic profile from FW
  (bnc#908322 FATE#317535).
- be2net: define macro for_all_tx_queues_on_eq() (bnc#908322
  FATE#317535).
- be2net: get rid of TX budget (bnc#908322 FATE#317535).
- be2net: make be_cmd_get_regs() return a status (bnc#908322
  FATE#317535).
- be2net: define BE_MAX_MTU (bnc#908322 FATE#317535).
- be2net: remove unncessary gotos (bnc#908322 FATE#317535).
- be2net: fix log messages in lancer FW download path (bnc#908322
  FATE#317535).
- be2net: Add a dma_mapping_error counter in ethtool (bnc#908322
  FATE#317535).
- be2net: Add TX completion error statistics in ethtool
  (bnc#908322 FATE#317535).
- be2net: add a description for counter
  rx_input_fifo_overflow_drop (bnc#908322 FATE#317535).
- be2net: shorten AMAP_GET/SET_BITS() macro calls (bnc#908322
  FATE#317535).
- be2net: add a few log messages (bnc#908322 FATE#317535).
- be2net: Use dev_consume_skb_any() in the non-drop path
  (bnc#908322 FATE#317535).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bnc#908322
  FATE#317535).
- be2net: support deleting FW dump via ethtool (only for Lancer)
  (bnc#908322 FATE#317535).
- be2net: ignore VF mac address setting for the same mac
  (bnc#908322 FATE#317535).
- be2net: Issue shutdown event to ocrdma driver (bnc#908322
  FATE#317535).
- be2net: update driver version to 10.4 (bnc#908322 FATE#317535).
- be2net: use adapter->flags to track SRIOV state (bnc#908322
  FATE#317535).
- be2net: use be_max_vfs() macro to access max-vfs (bnc#908322
  FATE#317535).
- be2net: use "if (!foo)" test style (bnc#908322 FATE#317535).
- be2net: remove unused structures in be_cmds.h (bnc#908322
  FATE#317535).
- be2net: reduce arguments passed to FW-cmd routines (bnc#908322
  FATE#317535).
- be2net: update UE bit description strings (bnc#908322
  FATE#317535).
- be2net: fix return status of some ndo methods (bnc#908322
  FATE#317535).
- be2net: fix return status of some ethtool methods (bnc#908322
  FATE#317535).
- be2net: return -ENOMEM for memory allocation failures
  (bnc#908322 FATE#317535).
- be2net: return -ETIMEDOUT when a FW-cmd times out (bnc#908322
  FATE#317535).
- be2net: fix error status for FW-download (bnc#908322
  FATE#317535).
- be2net: set EQ DB clear-intr bit in be_open() (bnc#908322
  FATE#317535).
- be2net: re-enable vlan filtering mode asap (bnc#908322
  FATE#317535).
- be2net: read VF's capabilities from GET_PROFILE_CONFIG cmd
  (bnc#908322 FATE#317535).
- be2net: remove be_cmd_get_profile_config_mbox/mccq() variants
  (bnc#908322 FATE#317535).
- be2net: fix qnq mode detection on VFs (bnc#908322 FATE#317535).
- be2net: cleanup MCC async event processing code (bnc#908322
  FATE#317535).
- be2net: move async cmd processing to a separate routine
  (bnc#908322 FATE#317535).
- be2net: re-factor MCCQ error status handling code (bnc#908322
  FATE#317535).
- be2net: support flashing new regions on Skyhawk-R (bnc#908322
  FATE#317535).
- be2net: skip multicast promiscuos setting in already set
  (bnc#908322 FATE#317535).
- be2net: enable interrupts in EEH resume (bnc#908322
  FATE#317535).
- net: get rid of SET_ETHTOOL_OPS (bnc#908322 FATE#317535).
- be2net: use MCCQ instead of MBOX in be_cmd_rss_config()
  (bnc#908322 FATE#317535).
- be2net: include rx-compl error counter in ethtool stats
  (bnc#908322 FATE#317535).
- be2net: remove unused code in be_cmd_vlan_config() (bnc#908322
  FATE#317535).
- be2net: covert vlan array to bit-map (bnc#908322 FATE#317535).
- be2net: fix line wrap and function call indentation in
  be_ethtool.c (bnc#908322 FATE#317535).
- be2net: fix function call indentation in be_cmds.c (bnc#908322
  FATE#317535).
- be2net: fix line wrap and function call indentation in be_main.c
  (bnc#908322 FATE#317535).
- be2net: Fix invocation of be_close() after be_clear()
  (bnc#908322 FATE#317535).
- be2net: Fix to reap TX compls till HW doesn't respond for some
  time (bnc#908322 FATE#317535).
- be2net: Add abi version between be2net and ocrdma (bnc#908322
  FATE#317535).
- net: Replace u64_stats_fetch_begin_bh to
  u64_stats_fetch_begin_irq (bnc#908322 FATE#317535).
- benet: Call dev_kfree_skby_any instead of kfree_skb (bnc#908322
  FATE#317535).
- be2net: update driver version to 10.2 (bnc#908322 FATE#317535).
- be2net: Fix vlans_added counter (bnc#908322 FATE#317535).
- be2net: Create multiple TXQs on RSS capable multi-channel
  BE3-R interfaces (bnc#908322 FATE#317535).
- be2net: fix pmac_id allocation size (bnc#908322 FATE#317535).
- be2net: log LPVID used in multi-channel configs (bnc#908322
  FATE#317535).
- be2net: Use GET_PROFILE_CONFIG cmd for BE3-R to query max-vfs
  (bnc#908322 FATE#317535).
- be2net: do external loopback test only when it is requested
  (bnc#908322 FATE#317535).
- be2net: dma_sync each RX frag before passing it to the stack
  (bnc#908322 FATE#317535).
- be2net: isolate TX workarounds not applicable to Skyhawk-R
  (bnc#908322 FATE#317535).
- be2net: Fix skb double free in be_xmit_wrokarounds() failure
  path (bnc#908322 FATE#317535).
- be2net: clear promiscuous bits in adapter->flags while disabling
  promiscuous mode (bnc#908322 FATE#317535).
- be2net: Fix to reset transparent vlan tagging (bnc#908322
  FATE#317535).
- benet: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bnc#908322 FATE#317535).
- be2net: refactor multi-channel config code for Skyhawk-R chip
  (bnc#908322 FATE#317535).
- be2net: Update copyright year (bnc#908322 FATE#317535).
- be2net: Log a kernel message when UE is detected in BE &
  Skyhawk (bnc#908322 FATE#317535).
- be2net: Fix be_vlan_add/rem_vid() routines (bnc#908322
  FATE#317535).
- be2net: add dma_mapping_error() check for dma_map_page()
  (bnc#908322 FATE#317535).
- be2net: update driver version to 10.0.x (bnc#908322
  FATE#317535).
- be2net: cleanup wake-on-lan code (bnc#908322 FATE#317535).
- be2net: use GET_MAC_LIST cmd to query mac-address from a pmac-id
  (bnc#908322 FATE#317535).
- be2net: do not use frag index in the RX-compl entry (bnc#908322
  FATE#317535).
- be2net: Remove "10Gbps" from driver description string
  (bnc#908322 FATE#317535).
- be2net: fix incorrect setting of cmd_privileges for VFs
  (bnc#908322 FATE#317535).
- be2net: ignore mac-addr set call for an already programmed
  mac-addr (bnc#908322 FATE#317535).
- be2net: do not call be_set/get_fw_log_level() on Skyhawk-R
  (bnc#908322 FATE#317535).
- be2net: Log the profile-id used by FW during driver
  initialization (bnc#908322 FATE#317535).
- be2net: don't set "pport" field when querying "pvid" (bnc#908322
  FATE#317535).
- be2net: Use MCC_CREATE_EXT_V1 cmd for Skyhawk-R (bnc#908322
  FATE#317535).
- be2net: fix max_evt_qs calculation for BE3 in SR-IOV config
  (bnc#908322 FATE#317535).
- be2net: increase the timeout value for loopback-test FW cmd
  (bnc#908322 FATE#317535).
- be2net: disable RSS when number of RXQs is reduced to 1 via
  set-channels (bnc#908322 FATE#317535).
- net: benet: slight optimization of addr compare (bnc#908322
  FATE#317535).
- net: emulex-benet calls skb_set_hash (bnc#908322 FATE#317535).
- be2net: Free/delete pmacs (in be_clear()) only if they exist
  (bnc#908322 FATE#317535).
- be2net: Fix Lancer error recovery to distinguish FW download
  (bnc#908322 FATE#317535).
- be2net: Avoid programming permenant MAC by BE3-R VFs (bnc#908322
  FATE#317535).
- be2net: set coalesce-wm in CQ_CREATE_V2 cmd (bnc#908322
  FATE#317535).
- be2net: Disabling and enabling interrupts in suspend and resume
  (bnc#908322 FATE#317535).
- be2net: Delete secondary unicast MAC addresses during be_close
  (bnc#908322 FATE#317535).
- be2net: Fix unconditional enabling of Rx interface options
  (bnc#908322 FATE#317535).
- net: Explicitly initialize u64_stats_sync structures for lockdep
  (bnc#908322 FATE#317535).
- net/benet: Make lancer_wait_ready() static (bnc#908322
  FATE#317535).
- net/benet: Remove interface type (bnc#908322 FATE#317535).
- be2net: Warn users of possible broken functionality on BE2
  cards with very old FW versions with latest driver (bnc#908322
  FATE#317535).
- net: be2net: remove unnecessary pci_set_drvdata() (bnc#908322
  FATE#317535).
- be2net: Rework PCIe error report log messaging (bnc#908322
  FATE#317535).
- be2net: change the driver version number to 4.9.224.0
  (bnc#908322 FATE#317535).
- be2net: Display RoCE specific counters in ethtool -S (bnc#908322
  FATE#317535).
- be2net: Call version 2 of GET_STATS ioctl for Skyhawk-R
  (bnc#908322 FATE#317535).
- be2net: add a counter for pkts dropped in xmit path (bnc#908322
  FATE#317535).
- be2net: fix adaptive interrupt coalescing (bnc#908322
  FATE#317535).
- be2net: call ENABLE_VF cmd for Skyhawk-R too (bnc#908322
  FATE#317535).
- be2net: Create single TXQ on BE3-R 1G ports (bnc#908322
  FATE#317535).
- be2net: pass if_id for v1 and V2 versions of TX_CREATE cmd
  (bnc#908322 FATE#317535).
- be2net: Call be_vf_setup() even when VFs are enbaled from
  previous load (bnc#908322 FATE#317535).
- be2net: Fix to display the VLAN priority for a VF (bnc#908322
  FATE#317535).
- be2net: Fix to configure VLAN priority for a VF interface
  (bnc#908322 FATE#317535).
- be2net: Fix to allow VLAN configuration on VF interfaces
  (bnc#908322 FATE#317535).
- be2net: Fix number of VLANs supported in UMC mode for BE3-R
  (bnc#908322 FATE#317535).
- be2net: Fix VLAN promiscuous mode programming (bnc#908322
  FATE#317535).
- be2net: Fix the size of be_nic_res_desc structure (bnc#908322
  FATE#317535).
- be2net: Fix to prevent Tx stall on SH-R when packet size < 32
  (bnc#908322 FATE#317535).
- emulex: Remove extern from function prototypes (bnc#908322
  FATE#317535).
- DMA-API: net: emulex/benet: replace
  dma_set_mask()+dma_set_coherent_mask() with new helper
  (bnc#908322 FATE#317535).
- be2net: missing variable initialization (bnc#908322
  FATE#317535).
- be2net: set and query VEB/VEPA mode of the PF interface
  (bnc#908322 FATE#317535).
- drivers:net: Convert dma_alloc_coherent(...__GFP_ZERO) to
  dma_zalloc_coherent (bnc#908322 FATE#317535).
- be2net: implement ethtool set/get_channel hooks (bnc#908322
  FATE#317535).
- be2net: refactor be_setup() to consolidate queue creation
  routines (bnc#908322 FATE#317535).
- be2net: Fix be_cmd_if_create() to use MBOX if MCCQ is not
  created (bnc#908322 FATE#317535).
- be2net: refactor be_get_resources() code (bnc#908322
  FATE#317535).
- be2net: Fixup profile management routines (bnc#908322
  FATE#317535).
- be2net: use EQ_CREATEv2 for SH-R (bnc#908322 FATE#317535).
- be2net: Check for POST state in suspend-resume sequence
  (bnc#908322 FATE#317535).
- be2net: fix disabling TX in be_close() (bnc#908322 FATE#317535).
- be2net: Clear any capability flags that driver is not interested
  in (bnc#908322 FATE#317535).
- be2net: update driver version (bnc#908322 FATE#317535).
- be2net: Initialize "status" in be_cmd_get_die_temperature()
  (bnc#908322 FATE#317535).
- be2net: fixup log msgs for async events (bnc#908322
  FATE#317535).
- be2net: Fix displaying supported speeds for BE2 (bnc#908322
  FATE#317535).
- be2net: don't limit max MAC and VLAN counts (bnc#908322
  FATE#317535).
- be2net: Do not call get_die_temperature cmd for VF (bnc#908322
  FATE#317535).
- be2net: Adding more speeds reported by get_settings (bnc#908322
  FATE#317535).
- be2net: Staticize local functions (bnc#908322 FATE#317535).
- be2net: don't use dev_err when AER enabling fails (bnc#908322
  FATE#317535).
- be2net: delete primary MAC address while unloading (bnc#908322
  FATE#317535).
- be2net: use SET/GET_MAC_LIST for SH-R (bnc#908322 FATE#317535).
- be2net: refactor MAC-addr setup code (bnc#908322 FATE#317535).
- be2net: fix pmac_id for BE3 VFs (bnc#908322 FATE#317535).
- be2net: allow VFs to program MAC and VLAN filters (bnc#908322
  FATE#317535).
- be2net: fix MAC address modification for VF (bnc#908322
  FATE#317535).
- be2net: Fix to avoid hardware workaround when not needed
  (bnc#908322 FATE#317535).
- net/trivial: replace numeric with standard PM state macros
  (bnc#908322 FATE#317535).
- be2net: use pci_vfs_assigned()/pci_num_vf() instead of
  be_find_vfs() (bnc#908322 FATE#317535).
- be2net: Fix 32-bit DMA Mask handling (bnc#908322 FATE#317535).
- be2net: Implement initiate FW dump feature for Lancer
  (bnc#908322 FATE#317535).
- be2net: Fix crash on 2nd invocation of PCI AER/EEH
  error_detected hook (bnc#908322 FATE#317535).
- be2net: Mark checksum fail for IP fragmented packets (bnc#908322
  FATE#317535).
- be2net: Trim padded packets for Lancer (bnc#908322 FATE#317535).
- be2net: Pad skb to meet min Tx pkt size in lancer (bnc#908322
  FATE#317535).
- be2net: cleanup be_get_drvinfo() (bnc#908322 FATE#317535).
- be2net: refactor HW workarounds in be_xmit() (bnc#908322
  FATE#317535).
- be2net: bug fix on returning an invalid nic descriptor
  (bnc#908322 FATE#317535).
- be2net: Avoid double insertion of vlan tags (bnc#908322
  FATE#317535).
- be2net: disable TX in be_close() (bnc#908322 FATE#317535).
- be2net: fix EQ from getting full while cleaning RX CQ
  (bnc#908322 FATE#317535).
- be2net: fix payload_len value for GET_MAC_LIST cmd req
  (bnc#908322 FATE#317535).
- be2net: provision VF resources before enabling SR-IOV
  (bnc#908322 FATE#317535).
- be2net: Fix to fail probe if MSI-X enable fails for a VF
  (bnc#908322 FATE#317535).
- be2net: avoid napi_disable() when it has not been enabled
  (bnc#908322 FATE#317535).
- be2net: Fix firmware download for Lancer (bnc#908322
  FATE#317535).
- be2net: Fix to receive Multicast Packets when Promiscuous mode
  is enabled on certain devices (bnc#908322 FATE#317535).
- be2net: Fix to show tx priority pause counter in ethtool -S
  (bnc#908322 FATE#317535).
- be2net: Fix to use 32-bit stats to report rx_drops_no_fragment
  (bnc#908322 FATE#317535).
- be2net: Fix to use version 2 of cq_create for SkyHawk-R devices
  (bnc#908322 FATE#317535).
- be2net: FLR must be first cmd issued to Lancer FW (bnc#908322
  FATE#317535).
- be2net: Use GET_FUNCTION_CONFIG V1 cmd (bnc#908322 FATE#317535).
- be2net: Fix to show wol disabled/enabled state correctly
  (bnc#908322 FATE#317535).
- be2net: Fixed memory leak (bnc#908322 FATE#317535).
- be2net: Avoid diagnostic test in certain versions of firmware
  to avoid NIC freeze (bnc#908322 FATE#317535).
- be2net: Renamed rx_address_mismatch_errors to
  rx_address_filtered (bnc#908322 FATE#317535).
- be2net: Add support for setting and getting rx flow hash options
  (bnc#908322 FATE#317535).
- be2net: Fix PVID tag offload for packets with inline VLAN tag
  (bnc#908322 FATE#317535).
- be2net: fix a Tx stall bug caused by a specific ipv6 packet
  (bnc#908322 FATE#317535).
- be2net: Remove an incorrect pvid check in Tx (bnc#908322
  FATE#317535).
- be2net: enable IOMMU pass through for be2net (bnc#908322
  FATE#317535).
- be2net: Use GET_PROFILE_CONFIG V1 cmd for BE3-R (bnc#908322
  FATE#317535).
- be2net: Avoid flashing BE3 UFI on BE3-R chip (bnc#908322
  FATE#317535).
- be2net: Don't log "Out of MCCQ wrbs" error (bnc#908322
  FATE#317535).
- be2net: Use TXQ_CREATE_V2 cmd (bnc#908322 FATE#317535).
- be2net: take care of __vlan_put_tag return value (bnc#908322
  FATE#317535).
- be2net: remove unused variable 'sge' (bnc#908322 FATE#317535).
- drivers:net: dma_alloc_coherent: use __GFP_ZERO instead of
  memset(, 0) (bnc#908322 FATE#317535).
- drivers:net: Remove dma_alloc_coherent OOM messages (bnc#908322
  FATE#317535).
- be2net: Use new F/W mailbox cmd to manipulate interrupts
  (bnc#908322 FATE#317535).
- be2net: enable interrupts in be_probe() (RoCE and other ULPs
  need them) (bnc#908322 FATE#317535).
- be2net: Update copyright year (bnc#908322 FATE#317535).
- be2net: use CSR-BAR SEMAPHORE reg for BE2/BE3 (bnc#908322
  FATE#317535).
- benet: Wait f/w POST until timeout (bnc#908322 FATE#317535).
- be2net: remove BUG_ON() in be_mcc_compl_is_new() (bnc#908322
  FATE#317535).
- be2net: update driver version to 4.6.x (bnc#908322 FATE#317535).
- be2net: fix re-loaded PF driver to re-gain control of its VFs
  (bnc#908322 FATE#317535).
- be2net: Updating Module Author string and log message string to
  "Emulex Corporation" (bnc#908322 FATE#317535).
- be2net: fix unconditionally returning IRQ_HANDLED in INTx
  (bnc#908322 FATE#317535).
- ethtool: fix drvinfo strings set in drivers (bnc#908322
  FATE#317535).
- be2net: fix wrong frag_idx reported by RX CQ (bnc#908322
  FATE#317535).
- be2net: fix be_close() to ensure all events are ack'ed
  (bnc#908322 FATE#317535).
- commit 03902cf
* Thu Dec 25 2014 bpoirier@suse.de
- Fix comment for e1000 sp4 driver backport
- commit 5ef6323
* Thu Dec 25 2014 bpoirier@suse.de
- Remove context for xen3-auto-common (bug#908322 FATE#317535).
- Restore context for
  PCI-MSI-Add-pci_enable_msi_range-and-pci_enable_msix.patch
  (bug#908322 FATE#317535).
- Refresh patches.xen/xen3-patch-2.6.31.
  This workaround is conspicuously awkward.
- commit 6d183a6
* Thu Dec 25 2014 bpoirier@suse.de
- PCI/MSI: Add pci_enable_msi_range() and pci_enable_msix_range()
  (bnc#908322 FATE#317535).
- PCI: Provide method to reduce the number of total VFs supported
  (bnc#908322 FATE#317535).
- PCI: Remove useless "!dev" tests (bnc#908322 FATE#317535).
- PCI: Return -ENOSYS for SR-IOV operations on non-SR-IOV devices
  (bnc#908322 FATE#317535).
- etherdevice: Use ether_addr_copy to copy an Ethernet address
  (bnc#908322 FATE#317535).
- etherdevice.h: Add ether_addr_equal (bnc#908322 FATE#317535).
- net: Explicitly initialize u64_stats_sync structures for lockdep
  (bnc#908322 FATE#317535).
- net: Replace u64_stats_fetch_begin_bh to
  u64_stats_fetch_begin_irq (bnc#908322 FATE#317535).
- net: introduce dev_consume_skb_any() (bnc#908322 FATE#317535).
- pci: Add SRIOV helper function to determine if VFs are assigned
  to guest (bnc#908322 FATE#317535).
- Refresh
  patches.drivers/0002-net-next-Add-netif_get_num_default_rss_queues.patch.
- Refresh
  patches.drivers/cxgb4vf-0003-netdevice-Kill-feature-test-macros.patch.
  Note that some of the xen patches need to be refreshed for the sequence to
  apply fully. This will be done in the next commit.
- commit 4ad625a
* Tue Dec 23 2014 lduncan@suse.com
- be2iscsi: check ip buffer before copying (FATE#317534
  bsc#908901).
- be2iscsi : Bump the driver version (FATE#317534 bsc#908901).
- be2iscsi : Fix kernel panic during reboot/shutdown (FATE#317534
  bsc#908901).
- be2iscsi: Bump the driver version (FATE#317534 bsc#908901).
- be2iscsi: Fix processing CQE before connection resources are
  freed (FATE#317534 bsc#908901).
- be2iscsi: Fix updating the boot enteries in sysfs (FATE#317534
  bsc#908901).
- be2iscsi: Fix the copyright year (FATE#317534 bsc#908901).
- be2iscsi: Fix the sparse warning introduced in previous
  submission (FATE#317534 bsc#908901).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (FATE#317534
  bsc#908901).
- be2iscsi: Fix memory leak in mgmt_set_ip() (FATE#317534
  bsc#908901).
- be2iscsi: remove potential junk pointer free (FATE#317534
  bsc#908901).
- be2iscsi: add an missing goto in error path (FATE#317534
  bsc#908901).
- Revert "be2iscsi: Fix processing cqe for cxn whose endpoint
  is freed" (FATE#317534 bsc#908901).
- be2iscsi: Bump the driver version (FATE#317534 bsc#908901).
- be2iscsi: Fix processing cqe for cxn whose endpoint is freed
  (FATE#317534 bsc#908901).
- be2iscsi: Fix destroy MCC-CQ before MCC-EQ is destroyed
  (FATE#317534 bsc#908901).
- be2iscsi: Fix memory corruption in MBX path (FATE#317534
  bsc#908901).
- be2iscsi: Fix TCP parameters while connection offloading
  (FATE#317534 bsc#908901).
- be2iscsi: Fix interrupt Coalescing mechanism (FATE#317534
  bsc#908901).
- be2iscsi: Fix exposing Host in sysfs after adapter
  initialization is complete (FATE#317534 bsc#908901).
- be2iscsi: Fix retrieving MCCQ_WRB in non-embedded Mbox path
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi : Bump the driver version (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi : Fix DMA Out of SW-IOMMU space error
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix scsi_cmnd leakage in driver (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix the session cleanup when reboot/shutdown
  happens (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix doorbell format for EQ/CQ/RQ s per SLI spec
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix port speed typo in driver (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix handling timed out MBX completion from FW
  (FATE#317534 bsc#908901).
- block: remove old blk_iopoll_enabled variable (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: fix bad if expression (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: fix memory leak in error path (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Bump driver version (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix SGL posting for unaligned ICD values
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix AER handling in driver (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Invalidate WRB in Abort/Reset Path (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix Insufficient Buffer Error returned in
  MBX Completion (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix log level for protocol specific logs
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix MSIx creation for SKH-R adapter
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Display Port Identifier for each iSCSI function
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Dispaly CID available for connection offload
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix chute cleanup during drivers unload
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix connection offload to support Dual Chute
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix CID allocation/freeing to support Dual
  chute mode (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix WRB_Q posting to support Dual Chute mode
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix SGL Initilization and posting Pages for
  Dual Chute (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix Template HDR support for Dual Chute mode
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix changes in ASYNC Path for SKH-R adapter
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Config parameters update for Dual Chute Support
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix soft lock up issue during UE or if FW
  taking time to respond (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix locking mechanism in Unsol Path
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix negotiated parameters upload to FW
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix repeated issue of MAC ADDR get IOCTL
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix the MCCQ count leakage (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix Template HDR IOCTL (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Bump the driver version to 10.0.467.0
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix issue in passing the exp_cmdsn and
  max_cmdsn (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix possible reentrancy issue in be_iopoll
  (FATE#317534 bsc#908901).
- [SCSI] be2scsi: Update copyright dates to 2013 (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix checking Adapter state while establishing
  CXN (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix dynamic CID allocation Mechanism in driver
  (FATE#317534 bsc#908901).
- be2iscsi : Fix the NOP-In handling code path (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix the Port Link Status issue (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix displaying the Active Session Count from
  driver (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix displaying the FW Version from driver
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix support for DEFQ extension (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix MACRO for checking the adapter type
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix freeing CXN specific driver resources
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix MSIX support in SKH-R to 32 (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix MBX Command issues (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix returning Failure when MBX fails with
  Insufficient buffer error (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix lack of uninitialize pattern to FW
  (FATE#317534 bsc#908901).
- treewide: Fix typo in printk and comments (FATE#317534
  bsc#908901).
- Drivers: scsi: remove __dev* attributes (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Bump the driver version (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix Unrecoverable Error Detection (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix for MBX timeout issue (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Update the copyright information (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix issue of displaying adapter family
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix Task Completion Event handling (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix session update context with V2 version
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix support for V2 version of WRB (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix support for handling CQ_CREATE V2 version
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix max EQ supported by the driver (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix driver support for Skyhawk-R adapter
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix return value and typo (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix kernel panic in blk_iopoll disable mode
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Issue an function level reset when driver is
  loaded (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Display driver name and version in device
  attribute (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix max supported EQ count to 8 (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Fix memory leak in control path of driver
  (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Display Completion Event string instead of
  Opcode (FATE#317534 bsc#908901).
- [SCSI] be2iscsi: Fix the issue with soft reset (FATE#317534
  bsc#908901).
- [SCSI] be2iscsi: Get Port State and Speed of the Adapter
  (FATE#317534 bsc#908901).
- commit a119982
* Tue Dec 23 2014 bpoirier@suse.de
- Delete post-sp3 be2net patches
  They will be re-added shortly.
- Delete
  patches.drivers/be2net-0001-be2net-Use-TXQ_CREATE_V2-cmd.patch.
- Delete
  patches.drivers/be2net-0002-be2net-Avoid-flashing-BE3-UFI-on-BE3-R-chip.patch.
- Delete
  patches.drivers/be2net-0003-be2net-Use-GET_FUNCTION_CONFIG-V1-cmd.patch.
- Delete
  patches.drivers/be2net-0004-be2net-Fix-to-use-version-2-of-cq_create-for-SkyHawk.patch.
- Delete
  patches.drivers/be2net-0005-be2net-Fix-firmware-download-for-Lancer.patch.
- Delete
  patches.drivers/be2net-0006-be2net-provision-VF-resources-before-enabling-SR-IOV.patch.
- Delete
  patches.drivers/be2net-0007-be2net-bug-fix-on-returning-an-invalid-nic-descripto.patch.
- Delete
  patches.drivers/be2net-0008-be2net-Check-for-POST-state-in-suspend-resume-sequen.patch.
- Delete
  patches.drivers/be2net-0144-Wait-f-w-POST-until-timeout.patch.
- Delete
  patches.drivers/be2net-0145-use-CSR-BAR-SEMAPHORE-reg-for-BE2-BE3.patch.
- Delete
  patches.drivers/be2net-0146-be2net-enable-interrupts-in-be_probe-RoCE-and-other-.patch.
- Delete
  patches.drivers/be2net-0147-Use-new-F-W-mailbox-cmd-to-manipulate-interru.patch.
- Delete
  patches.drivers/be2net-0148-fix-re-loaded-PF-driver-to-re-gain-control-of.patch.
- Delete
  patches.drivers/be2net-0149-Use-GET_PROFILE_CONFIG-V1-cmd-for-BE3-R.patch.
- Delete
  patches.fixes/be2net-Fix-invocation-of-be_close-after-be_clear.patch.
- Delete
  patches.fixes/be2net-add-dma_mapping_error-check-for-dma_map_page.patch.
- commit 1a0cfe1
* Mon Dec 22 2014 mmarek@suse.cz
- Import kabi files from kernel 3.0.101-0.40
- commit 6252f28
* Mon Dec 22 2014 mhocko@suse.cz
- kvm: iommu: Add cond_resched to legacy device assignment code
  (bnc#910159).
- commit 6d49fdd
* Sat Dec 20 2014 bpoirier@suse.de
- Cleanup the sp3 be2net backport
  As explained in 777565c12, most of the early v3.0..v3.2 commits were added as
  part of 722092. Most, but not all.
  dafc0fe be2net: don't create multiple TXQs in BE2 (v3.2-rc1)
  moved to proper position
  8e58613 net: make vlan ndo_vlan_rx_[add/kill]_vid return error value (v3.3-rc1)
  skipped treewide change
  80817cb be2net: fix be_vlan_add/rem_vid (v3.3-rc1)
  was missing
  eeb7fc7 be2net: Fix EEH error reset before a flash dump completes (v3.5-rc1)
  moved to proper position
  cd8f76c be2net: fix a race in be_xmit() (v3.5-rc3)
  already fixed in -stable 9e7d7c5 (v3.0.37)
- be2net: fix be_vlan_add/rem_vid (bnc#777565 FATE#313819).
- Refresh
  patches.drivers/be2net-0001-be2net-Move-the-Emulex-driver.patch.
- Refresh
  patches.drivers/be2net-0004-be2net-add-vlan-rx-mode-flow-control-config-to-be_se.patch.
- Refresh
  patches.drivers/be2net-0005-be2net-refactor-VF-setup-teardown-code-into-be_vf_se.patch.
- Refresh
  patches.drivers/be2net-0018-be2net-stop-issuing-FW-cmds-if-any-cmd-times-out.patch.
- Refresh
  patches.drivers/be2net-0036-be2net-fix-range-check-for-set_qos-for-a-VF.patch.
- Refresh
  patches.drivers/be2net-0037-be2net-query-link-status-in-be_open.patch.
- Refresh
  patches.drivers/be2net-0038-netdev-make-net_device_ops-const.patch.
- Refresh
  patches.drivers/be2net-0039-be2net-create-RSS-rings-even-in-multi-channel-config.patch.
- Refresh
  patches.drivers/be2net-0040-be2net-allocate-more-headroom-in-incoming-skbs.patch.
- Refresh
  patches.drivers/be2net-0044-be2net-Use-new-implementation-of-get-mac-list-comman.patch.
- Refresh
  patches.drivers/be2net-0045-be2net-event-queue-re-design.patch.
- Refresh
  patches.drivers/be2net-0046-be2net-cancel-be_worker-during-EEH-recovery.patch.
- Refresh
  patches.drivers/be2net-0047-be2net-fix-tx-completion-cleanup.patch.
- Refresh
  patches.drivers/be2net-0048-be2net-reset-queue-address-after-freeing.patch.
- Refresh
  patches.drivers/be2net-0051-be2net-enable-WOL-by-default-if-h-w-supports-it.patch.
- Refresh
  patches.drivers/be2net-0052-be2net-Program-secondary-UC-MAC-address-into-MAC-fil.patch.
- Refresh
  patches.drivers/be2net-0053-be2net-Fix-number-of-vlan-slots-in-flex-mode.patch.
- Refresh
  patches.drivers/be2net-0054-be2net-fix-programming-of-VLAN-tags-for-VF.patch.
- Refresh
  patches.drivers/be2net-0055-be2net-fix-ethtool-get-settings.patch.
- Refresh
  patches.drivers/be2net-0056-be2net-Fix-VLAN-multicast-packet-reception.patch.
- Refresh
  patches.drivers/be2net-0059-be2net-Fix-traffic-stall-INTx-mode.patch.
- Refresh
  patches.drivers/be2net-0062-be2net-Fix-FW-download-for-BE.patch.
- Refresh
  patches.drivers/be2net-0063-be2net-Ignore-status-of-some-ioctls-during-driver-lo.patch.
- Refresh
  patches.drivers/be2net-0067-be2net-Record-receive-queue-index-in-skb-to-aid-RPS.patch.
- Refresh
  patches.drivers/be2net-0069-be2net-Add-functionality-to-support-RoCE-driver.patch.
- Refresh
  patches.drivers/be2net-0070-be2net-avoid-disabling-sriov-while-VFs-are-assigned.patch.
- Refresh
  patches.drivers/be2net-0071-be2net-Fix-to-allow-get-set-of-debug-levels-in-the-f.patch.
- Refresh
  patches.drivers/be2net-0072-be2net-don-t-call-vid_config-when-there-s-no-vlan-co.patch.
- Refresh
  patches.drivers/be2net-0073-be2net-cleanup-be_vid_config.patch.
- Refresh
  patches.drivers/be2net-0074-be2net-do-not-modify-PCI-MaxReadReq-size.patch.
- Refresh
  patches.drivers/be2net-0075-be2net-fix-reporting-number-of-actual-rx-queues.patch.
- Refresh
  patches.drivers/be2net-0077-be2net-do-not-use-SCRATCHPAD-register.patch.
- Refresh
  patches.drivers/be2net-0078-be2net-Fix-driver-load-for-VFs-for-Lancer.patch.
- Refresh
  patches.drivers/be2net-0079-be2net-reduce-gso_max_size-setting-to-account-for-et.patch.
- Refresh
  patches.drivers/be2net-0083-be2net-Regression-bug-wherein-VFs-creation-broken-fo.patch.
- Refresh
  patches.drivers/be2net-0085-be2net-set-maximal-number-of-default-RSS-queues.patch.
- Refresh
  patches.drivers/be2net-0088-be2net-Fix-die-temperature-stat-for-Lancer.patch.
- Refresh
  patches.drivers/be2net-0089-be2net-Fix-initialization-sequence-for-Lancer.patch.
- Refresh
  patches.drivers/be2net-0090-be2net-Activate-new-FW-after-FW-download-for-Lancer.patch.
- Refresh
  patches.drivers/be2net-0091-be2net-Fix-cleanup-path-when-EQ-creation-fails.patch.
- Refresh
  patches.drivers/be2net-0092-be2net-Fix-port-name-in-message-during-driver-load.patch.
- Refresh
  patches.drivers/be2net-0095-be2net-dont-pull-too-much-data-in-skb-linear-part.patch.
- Refresh
  patches.drivers/be2net-0096-be2net-Fix-VF-driver-load-for-Lancer.patch.
- Refresh
  patches.drivers/be2net-0098-be2net-Missing-byteswap-in-be_get_fw_log_level-cause.patch.
- Refresh
  patches.drivers/be2net-0099-be2net-Fix-to-parse-RSS-hash-from-Receive-completion.patch.
- Refresh
  patches.drivers/be2net-0100-emulex-benet-Add-a-missing-CR-in-the-end-of-message.patch.
- Refresh
  patches.drivers/be2net-0101-netpoll-revert-6bdb7fe3104-and-fix-be_poll-instead.patch.
- Refresh
  patches.drivers/be2net-0102-be2net-create-RSS-rings-even-in-multi-channel-config.patch.
- Refresh
  patches.drivers/be2net-0103-be2net-fix-max-VFs-reported-by-HW.patch.
- Refresh
  patches.drivers/be2net-0104-be2net-fix-FW-default-for-VF-tx-rate.patch.
- Refresh
  patches.drivers/be2net-0105-be2net-fixup-malloc-free-of-adapter-pmac_id.patch.
- Refresh
  patches.drivers/be2net-0107-be2net-use-PCIe-AER-capability.patch.
- Refresh
  patches.drivers/be2net-0108-netdev-make-pci_error_handlers-const.patch.
- Refresh
  patches.drivers/be2net-0109-be2net-fix-vfs-enumeration.patch.
- Refresh
  patches.drivers/be2net-0110-Revert-be2net-fix-vfs-enumeration.patch.
- Refresh
  patches.drivers/be2net-0111-be2net-remove-type-argument-of-be_cmd_mac_addr_query.patch.
- Refresh
  patches.drivers/be2net-0112-be2net-fix-wrong-handling-of-be_setup-failure-in-be_.patch.
- Refresh
  patches.drivers/be2net-0113-be2net-cleanup-code-related-to-be_link_status_query.patch.
- Refresh
  patches.drivers/be2net-0114-be2net-fixup-log-messages.patch.
- Refresh
  patches.drivers/be2net-0115-be2net-fix-vfs-enumeration.patch.
- Refresh
  patches.drivers/be2net-0116-be2net-Remove-code-that-stops-further-access-to-BE-N.patch.
- Refresh
  patches.drivers/be2net-0117-be2net-Fix-driver-load-failure-for-different-FW-conf.patch.
- Refresh
  patches.drivers/be2net-0118-be2net-Fix-setting-QoS-for-VF-for-Lancer.patch.
- Refresh
  patches.drivers/be2net-0119-be2net-Fix-change-MAC-operation-for-VF-for-Lancer.patch.
- Refresh
  patches.drivers/be2net-0120-be2net-Wait-till-resources-are-available-for-VF-in-e.patch.
- Refresh
  patches.drivers/be2net-0121-be2net-Fix-configuring-VLAN-for-VF-for-Lancer.patch.
- Refresh
  patches.drivers/be2net-0122-be2net-Fix-error-messages-while-driver-load-for-VFs.patch.
- Refresh
  patches.drivers/be2net-0125-be2net-Fix-unnecessary-delay-in-PCI-EEH.patch.
- Refresh
  patches.drivers/be2net-0126-be2net-Fix-VF-driver-load-on-newer-Lancer-FW.patch.
- Refresh
  patches.drivers/be2net-0127-be2net-Enabling-Wake-on-LAN-is-not-supported-in-S5-s.patch.
- Refresh
  patches.drivers/be2net-0128-be2net-Fix-FW-flashing-on-Skyhawk-R.patch.
- Refresh
  patches.drivers/be2net-0129-be2net-Fix-skyhawk-VF-PCI-Device-ID.patch.
- Refresh
  patches.drivers/be2net-0130-be2net-Fix-smatch-warnings-in-be_main.c.patch.
- Refresh
  patches.drivers/be2net-0132-be2net-fix-wrong-usage-of-adapter-generation.patch.
- Refresh
  patches.drivers/be2net-0133-be2net-do-not-use-sli_family-to-identify-skyhawk-R-c.patch.
- Refresh
  patches.drivers/be2net-0134-be2net-re-factor-bar-mapping-code.patch.
- Refresh
  patches.drivers/be2net-0135-be2net-fix-access-to-SEMAPHORE-reg.patch.
- Refresh
  patches.drivers/be2net-0136-be2net-remove-roce-on-lancer.patch.
- Refresh
  patches.drivers/be2net-0137-be2net-remove-adapter-eq_next_idx.patch.
- Refresh
  patches.drivers/be2net-0139-be2net-fix-a-possible-events_get-race-on-BE2.patch.
- Refresh
  patches.drivers/be2net-0140-be2net-fix-INTx-ISR-for-interrupt-behaviour-on-BE2.patch.
- Refresh
  patches.drivers/be2net-0141-be2net-remove-__dev-attributes.patch.
- Refresh
  patches.drivers/be2net-0142-drivers-net-fix-up-function-prototypes-after-__dev-r.patch.
- Update
  patches.drivers/be2net-Fix-EEH-error-reset-before-a-flash-dump-compl.patch
  (bnc#777565 FATE#313819).
- commit b877ccb
* Thu Dec 18 2014 hare@suse.de
- Refresh
  patches.fixes/scsi_dh_alua-add-missing-hunk-in-alua_set_params.patch.
- commit f55bd1f
* Thu Dec 18 2014 hare@suse.de
- cciss: fix broken mutex usage in ioctl (bnc#910013).
- commit 6469517
* Thu Dec 18 2014 hare@suse.de
- Refresh
  patches.fixes/scsi_dh_alua-add-missing-hunk-in-alua_set_params.patch.
- commit 33d4272
* Thu Dec 18 2014 hare@suse.de
- scsi_dh_alua: add missing hunk in alua_set_params()
  (bnc#846656).
- commit 6d9d722
* Thu Dec 18 2014 jlee@suse.com
- ahci: Add Device IDs for Intel Wildcat Point-LP. (fate#317348)
- commit ced53d9
* Thu Dec 18 2014 neilb@suse.de
- NFSv4.1: Don't decode skipped layoutgets (bnc#864411).
- pnfs: defer release of pages in layoutget (bnc#864411).
- commit 358a8b0
* Thu Dec 18 2014 neilb@suse.de
- NFSv4.1: Fix an ABBA locking issue with session and state
  serialisation (bnc#864409).
- NFSv4.1: Fix a race in the pNFS return-on-close code
  (bnc#864409).
- NFSv4: Do not accept delegated opens when a delegation recall
  is in effect (bnc#864409).
- commit 1f3fe9e
* Thu Dec 18 2014 bpoirier@suse.de
- e1000: rename struct e1000_buffer to e1000_tx_buffer (bnc#909498
  FATE#317395).
- e1000: add and use e1000_rx_buffer info for Rx (bnc#909498
  FATE#317395).
- e1000: perform copybreak ahead of DMA unmap (bnc#909498
  FATE#317395).
- e1000: move tbi workaround code into helper function (bnc#909498
  FATE#317395).
- e1000: move e1000_tbi_adjust_stats to where its used (bnc#909498
  FATE#317395).
- e1000: e1000_ethertool.c coding style fixes (bnc#909498
  FATE#317395).
- e1000: Fix TSO for non-accelerated vlan traffic (bnc#909498
  FATE#317395).
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (bnc#909498
  FATE#317395).
- e1000: remove unnecessary break after return (bnc#909498
  FATE#317395).
- net: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate
  (bnc#909498 FATE#317395).
- e1000: Use time_after() for time comparison (bnc#909498
  FATE#317395).
- e1000: remove the check: skb->len<=0 (bnc#909498 FATE#317395).
- e1000: Use is_broadcast_ether_addr/is_multicast_ether_addr
  helpers (bnc#909498 FATE#317395).
- e1000: remove open-coded skb_cow_head (bnc#909498 FATE#317395).
- e1000: remove debug messages with function names (bnc#909498
  FATE#317395).
- drivers/net: delete non-required instances of include
  <linux/init.h> (bnc#909498 FATE#317395).
- e1000: fix possible reset_task running after adapter down
  (bnc#909498 FATE#317395).
- e1000: fix lockdep warning in e1000_reset_task (bnc#909498
  FATE#317395).
- e1000: prevent oops when adapter is being closed and reset
  simultaneously (bnc#909498 FATE#317395).
- e1000: fix wrong queue idx calculation (bnc#909498 FATE#317395).
- intel: Remove extern from function prototypes (bnc#909498
  FATE#317395).
- DMA-API: net: intel/e1000: replace
  dma_set_mask()+dma_set_coherent_mask() with new helper
  (bnc#909498 FATE#317395).
- drivers:net: Convert dma_alloc_coherent(...__GFP_ZERO) to
  dma_zalloc_coherent (bnc#909498 FATE#317395).
- e1000: ethtool: Add missing dma_mapping_error-call in
  e1000_setup_desc_rings (bnc#909498 FATE#317395).
- drivers:net: dma_alloc_coherent: use __GFP_ZERO instead of
  memset(, 0) (bnc#909498 FATE#317395).
- drivers:net: Remove dma_alloc_coherent OOM messages (bnc#909498
  FATE#317395).
- e1000: fix whitespace issues and multi-line comments (bnc#909498
  FATE#317395).
- drivers: net: Remove remaining alloc/OOM messages (bnc#909498
  FATE#317395).
- remove init of dev->perm_addr in drivers (bnc#909498
  FATE#317395).
- commit b8d4c8f
* Thu Dec 18 2014 lduncan@suse.com
- Removing patch added but not needed for bnc#909370
- commit f7049b0
* Thu Dec 18 2014 lduncan@suse.com
- Update bnx2i driver to v3.18 level (bnc#909370, FATE#317540)
- commit 816042c
* Wed Dec 17 2014 tiwai@suse.de
- Disable switching to bootsplash at oops/panic (bnc#877593).
- commit 9b5987e
* Wed Dec 17 2014 bpoirier@suse.de
- drivers:net: Convert dma_alloc_coherent(...__GFP_ZERO) to
  dma_zalloc_coherent (bug#909498 FATE#317395).
- DMA-API: provide a helper to set both DMA and coherent DMA masks
  (bug#909498 FATE#317395).
- net: init perm_addr in register_netdevice() (bug#909498
  FATE#317395).
- commit e9e9296
* Wed Dec 17 2014 jdelvare@suse.de
- Fix HDIO_DRIVE_* ioctl() regression (bnc#833588, bnc#905799)
- commit 1983136
* Wed Dec 17 2014 jkosina@suse.cz
- x86, asm, xen: Flip RESTORE_ARGS arguments logic (bnc#910251
  CVE-9322).
- commit 8356111
* Wed Dec 17 2014 jlee@suse.com
- AHCI: Add DeviceIDs for Sunrise Point-LP SATA controller. (fate#317355)
- commit 7f0c7da
* Wed Dec 17 2014 neilb@suse.de
- Refresh
  patches.fixes/0005-SUNRPC-Don-t-allow-low-priority-tasks-to-pre-empt-hi.patch.
  Restore kabi
- commit 0346984
* Wed Dec 17 2014 neilb@suse.de
- SUNRPC: When changing the queue priority, ensure that we change
  the owner (bnc#864401).
- SUNRPC: Don't allow low priority tasks to pre-empt higher
  priority ones (bnc#864401).
- NFS: Add sequence_priviliged_ops for nfs4_proc_sequence()
  (bnc#864401).
- NFSv4.1: We must release the sequence id when we fail to get
  a session slot (bnc#864401).
- NFSv4.1 handle DS stateid errors (bnc#864401).
- NFSv4: Ensure correct locking when accessing the 'lock_states'
  list (bnc#864401).
- commit b3eea7c
* Tue Dec 16 2014 oneukum@suse.de
- xhci: add the meaningful IRQ description if it is empty
  (FATE#317451).
- Refresh patches.drivers/xhci_bad_pci_irq.patch.
- commit ce4fa5f
* Tue Dec 16 2014 jkosina@suse.cz
- Refresh
  patches.fixes/x86-espfix-make-espfix64-a-kconfig-option-fix-uml.patch: disable
  on Xen (bsc#910251)
  patches.fixes/x86-espfix-make-it-possible-to-disable-16-bit-support.patch:
  disable on Xen (bsc#910251)
- commit 1cb9545
* Tue Dec 16 2014 mhocko@suse.cz
- Update patches.fixes/x86_64-traps-stop-using-ist-for-ss.patch
  (bsc#907818, CVE-2014-9090, CVE-2014-9322).
- commit ed63940
* Tue Dec 16 2014 jkosina@suse.cz
- Update config files (espfix, bsc#907818,CVE-2014-9090)
- commit e2c7a19
* Tue Dec 16 2014 oneukum@suse.de
- xhci: fix incorrect type in assignment in
  handle_device_notification() (bsc#910321).
- commit a5ebcfa
* Tue Dec 16 2014 bp@suse.de
- Refresh patches.xen/xen3-patch-2.6.31.
- commit ab6aadb
* Tue Dec 16 2014 ohering@suse.de
- hyperv: Add support for vNIC hot removal.
- hv: hv_balloon: avoid memory leak on alloc_error of 2MB
  memory block.
- tools: hv: ignore ENOBUFS and ENOMEM in the KVP daemon.
- Tools: hv: vssdaemon: skip all filesystems mounted readonly.
- Tools: hv: vssdaemon: report freeze errors.
- Drivers: hv: kvp,vss: Fast propagation of userspace
  communication failure.
- Drivers: hv: vss: Introduce timeout for communication with
  userspace.
- net: Hyper-V: Deletion of an unnecessary check before the
  function call "vfree".
- hyperv: Add processing of MTU reduced by the host.
- Drivers: hv: vmbus: Fix a race condition when unregistering
  a device.
- Drivers: hv: util: make struct hv_do_fcopy match Hyper-V
  host messages.
- tools: hv: introduce -n/--no-daemon option.
- Tools: hv: vssdaemon: ignore the EBUSY on multiple freezing
  the same partition.
- Drivers: hv: util: Properly pack the data for file copy
  functionality.
- commit c208d1d
* Tue Dec 16 2014 bp@suse.de
- x86/tls: Validate TLS entries to protect espfix
  (bsc#909077,CVE-2014-8133).
- x86_64, traps: Rework bad_iret (bsc#909077,CVE-2014-8133).
- x86/tls: Validate TLS entries to protect espfix
  (bsc#909077,CVE-2014-8133).
- x86_64, traps: Rework bad_iret (bsc#909077,CVE-2014-8133).
- commit 5356774
* Tue Dec 16 2014 bp@suse.de
- x86_64, traps: Stop using IST for #SS
  (bsc#907818,CVE-2014-9090).
- commit 7185ac9
* Tue Dec 16 2014 bp@suse.de
- x86_64, traps: Fix the espfix64 #DF fixup and rewrite it in C
  (bsc#907818,CVE-2014-9090).
- commit 6756426
* Tue Dec 16 2014 bp@suse.de
- x86_64/entry/xen: Do not invoke espfix64 on Xen
  (bsc#907818,CVE-2014-9090).
- x86, espfix: Make it possible to disable 16-bit support
  (bsc#907818,CVE-2014-9090).
- x86, espfix: Make espfix64 a Kconfig option, fix UML
  (bsc#907818,CVE-2014-9090).
- x86-64, espfix: Don't leak bits 31:16 of %%esp returning to
  16-bit stack (bsc#907818,CVE-2014-9090).
- x86, extable: Remove open-coded exception table entries in
  arch/x86/kernel/entry_64.S (bsc#907818,CVE-2014-9090).
- x86, extable: Use .pushsection ... .popsection for
  _ASM_EXTABLE() (bsc#907818,CVE-2014-9090).
- x86, asm: Flip RESTORE_ARGS arguments logic
  (bsc#907818,CVE-2014-9090).
- x86, asm: Thin down SAVE/RESTORE_* asm macros
  (bsc#907818,CVE-2014-9090).
- x86_64/entry/xen: Do not invoke espfix64 on Xen
  (bsc#907818,CVE-2014-9090).
- x86, espfix: Make it possible to disable 16-bit support
  (bsc#907818,CVE-2014-9090).
- x86, espfix: Make espfix64 a Kconfig option, fix UML
  (bsc#907818,CVE-2014-9090).
- x86-64, espfix: Don't leak bits 31:16 of %%esp returning to
  16-bit stack (bsc#907818,CVE-2014-9090).
- x86, extable: Remove open-coded exception table entries in
  arch/x86/kernel/entry_64.S (bsc#907818,CVE-2014-9090).
- x86, extable: Use .pushsection ... .popsection for
  _ASM_EXTABLE() (bsc#907818,CVE-2014-9090).
- x86, asm: Flip RESTORE_ARGS arguments logic
  (bsc#907818,CVE-2014-9090).
- x86, asm: Thin down SAVE/RESTORE_* asm macros
  (bsc#907818,CVE-2014-9090).
- commit cd635eb
* Tue Dec 16 2014 ohering@suse.de
- hv_netvsc: define RNDIS_OID_GEN_MAXIMUM_FRAME_SIZE
- commit 6f28e2c
* Mon Dec 15 2014 dbueso@suse.de
- mutex: Do not unnecessarily deal with waiters (fate#317234).
- commit 41d3e26
* Mon Dec 15 2014 dbueso@suse.de
- locking/mutex: Remove MUTEX_SPIN_USE_MCS_QUEUE (fate#317232).
- commit 53991ea
* Mon Dec 15 2014 dbueso@suse.de
- mm: unmapped page migration avoid unmap+remap overhead (MM
  scalability).
- commit cbd8e11
* Mon Dec 15 2014 mhocko@suse.cz
- swap: fix shmem swapping when more than 8 areas (bnc#903096).
- commit 3ca7af2
* Mon Dec 15 2014 ohering@suse.de
- hyperv: Fix the total_data_buflen in send path
- commit 8210ba3
* Mon Dec 15 2014 ohering@suse.de
- hyperv: Fix a bug in netvsc_start_xmit()
- commit b93ba60
* Mon Dec 15 2014 ohering@suse.de
- hyperv: Add hash value into RNDIS Per-packet info
- commit c500c29
* Mon Dec 15 2014 ohering@suse.de
- hyperv: Properly handle checksum offload
- commit f50540a
* Mon Dec 15 2014 ohering@suse.de
- Drivers: net: hyperv: Address UDP checksum issues
- commit 9e6b611
* Mon Dec 15 2014 ohering@suse.de
- Drivers: net: hyperv: Allocate memory for all possible per-pecket information
- commit b52058e
* Mon Dec 15 2014 ohering@suse.de
- Drivers: net: hyperv: Enable large send offload
- commit b0d1ca6
* Mon Dec 15 2014 ohering@suse.de
- Drivers: net: hyperv: Enable send side checksum offload
- commit e923991
* Mon Dec 15 2014 ohering@suse.de
- net: reset mac header in dev_start_xmit().
- commit 6b571ee
* Mon Dec 15 2014 mmarek@suse.cz
- Delete patches.kabi/* workarounds
- commit d88051e
* Fri Dec 12 2014 brogers@suse.com
- kvm: fix excessive pages un-pinning in kvm_iommu_map error path
  (CVE-2014-8369 bnc#902675).
- x86,kvm,vmx: Preserve CR4 across VM entry (CVE-2014-3690
  bnc#902232).
- KVM: x86: Don't report guest userspace emulation error to
  userspace (CVE-2014-7842 bnc#905312).
- commit e73641f
* Fri Dec 12 2014 tiwai@suse.de
- Refresh patches.drivers/HID-multitouch-add-support-for-Atmel-212c.
  Fix the non-working touchsreen (bnc#909740)
- commit 153a86d
* Fri Dec 12 2014 oneukum@suse.de
- usb: xhci: rework root port wake bits if controller isn't
  allowed to wakeup (bsc#909264).
- commit f11d108
* Fri Dec 12 2014 oneukum@suse.de
- Refresh
  patches.drivers/0001-usb-Fix-xHCI-host-issues-on-remote-wakeup.patch.
- Delete patches.suse/0002-xhci-hub.c-preserved-kABI.patch.
- commit 05c3210
* Thu Dec 11 2014 jbeulich@suse.com
- Update Xen patches to c/s 1272.
- xen-pciback: drop SR-IOV VFs when PF driver unloads
  (bsc#901839).
- x86, mm: Create slow_virt_to_phys() (fate#317533).
- x86, mm: Pagetable level size/shift/mask helpers (fate#317533).
- Update EC2 config files (SERIO=n).
- commit 291b79b
* Thu Dec 11 2014 jroedel@suse.de
- x86/UV: Fix conditional in gru_exit() (bsc#909095).
- commit aadfdfa
* Thu Dec 11 2014 mmarek@suse.cz
- Preserve kabi checksum of path_is_under().
- commit 1a269a2
* Thu Dec 11 2014 mmarek@suse.cz
- Delete patches.kabi/* workarounds
- commit 260c027
* Thu Dec 11 2014 jjolly@suse.de
- crypto: kernel oops at insmod of the z90crypt device driver
  (bnc#909088, LTC#119591).
- commit 5d7a0d7
* Wed Dec 10 2014 jack@suse.cz
- Fixup kABI after
  patches.fixes/writeback-do-not-sync-data-dirtied-after-sync-start.patch
  (bnc#833820).
- Refresh
  patches.fixes/writeback-do-not-sync-data-dirtied-after-sync-start.patch.
- commit 6ec581e
* Wed Dec 10 2014 mmarek@suse.cz
- series.conf: Separate SP4-only net patch from the SP3 series
- commit d560c05
* Wed Dec 10 2014 jlee@suse.com
- mfd: lpc_ich: iTCO_wdt patch for Intel Coleto Creek DeviceIDs
  (fate#317357).
- commit b4e9d9a
* Wed Dec 10 2014 jlee@suse.com
- Refresh
  patches.arch/0001-mfd-lpc_ich-Add-Device-IDs-for-Intel-Wildcat-Point-L.patch.
  Add TCO related info of  Wildcat Point-LP.
- commit 14e4f50
* Wed Dec 10 2014 jlee@suse.com
- mfd: lpc_ich: Add Device IDs for Intel Wildcat Point-LP PCH
  (fate#317348).
- commit 7d9075f
* Wed Dec 10 2014 jlee@suse.com
- intel_idle: Support Intel Atom Processor C2000 Product Family
  (fate#317428).
- commit 2cd2cee
* Wed Dec 10 2014 jlee@suse.com
- ahci: Add Device IDs for Intel Sunrise Point PCH (fate#317355).
- commit 43311c2
* Wed Dec 10 2014 neilb@suse.de
- Split out kabi fix to separate patch
- kabi fix (bnc#864404).
- Refresh
  patches.fixes/0001-NFSv4-Allow-the-state-manager-to-mark-an-open_owner-.patch.
- commit 8508c5e
* Wed Dec 10 2014 jbohac@suse.cz
- Refresh
  patches.fixes/netlink-add-privilege-check-of-socket-opener.patch.
  Fix KABI.
- commit ca5efe2
* Tue Dec  9 2014 jbohac@suse.cz
- netlink: add privilege check of socket opener (bsc#875051,
  CVE-2014-0181).
- commit c9d6294
* Tue Dec  9 2014 mmarek@suse.cz
- Delete patches.fixes/0010a-NFS-Clean-up-nfs4_select_rw_state.fix
  One more SP3 kabi workaround.
- commit 24767c6
* Tue Dec  9 2014 mmarek@suse.cz
- Delete SP3 kabi workarounds
- Delete
  patches.kabi/*
  patches.arch/paravirt-stub-kabi-for-KVM_MMU.patch.
  patches.drivers/Revert-kABI-changes-of-libfcoe-Make-fcoe_sysfs-optio.patch.
  patches.fixes/0012a-NFSv4-Resend-stateid-kabi-fix.
  patches.fixes/mm-vmscan-take-page-buffers-dirty-and-locked-state-into-account-v3-KABI-fix.patch.
  patches.fixes/mm-vmscan-take-page-buffers-dirty-and-locked-state-into-account-v3-KABI.patch.
  patches.fixes/scsi-kABI-fixes.patch.
  patches.suse/bug-853428-scsi_device-fix-kabi.patch.
  patches.suse/dcache-kABI-fixes-for-lockref-dentries.
  patches.suse/mm-hugetlb-unify-region-structure-handling-kabi.patch.
- Add patches that have been skipped in SP3 due to kabi:
  mm: redefine address_space.assoc_mapping.
  Merge branch 'for-linus' of
  git://git.kernel.org/pub/scm/linux/kernel/git/viro/vfs.
- Refresh:
  patches.fixes/af_unix-do-not-pack-creds-for-dying-process.
  patches.fixes/autofs-fix-lockref-lookup.patch.
  patches.fixes/mm-vmscan-only-defer-compaction-for-failed-order-and-higher.patch.
  patches.suse/0010-autofs4-factor-should_expire-out-of-autofs4_expire_i.patch.
  patches.suse/helper-for-reading-d_count.
  patches.suse/kdb-v4.4-3.1-common-1.
  patches.suse/mm-add-support-for-a-filesystem-to-activate-swap-files-and-use-direct_IO-for-writing-swap-pages.patch.
  patches.suse/mm-hugetlb-improve-cleanup-resv_map-parameters.patch.
  patches.suse/mm-hugetlb-use-vma_resv_map-map-types.patch.
  patches.suse/scsi-add-a-blacklist-flag-which-enables-VPD-page-inq.patch.
- commit 9a77942
* Tue Dec  9 2014 mhocko@suse.cz
- net, sunrpc: suppress allocation warning in rpc_malloc()
  (bnc#904659).
- commit 0006458
* Tue Dec  9 2014 jkosina@suse.cz
- kabi/severities: revert 751c4d18 ("kabi/severities: allow all kABI changes
  to pass, while still keeping SP3 symsets")
- Delete kabi/i386/symsets-default.tar.gz.
- Delete kabi/i386/symsets-pae.tar.gz.
- Delete kabi/i386/symsets-trace.tar.gz.
- Delete kabi/i386/symsets-xen.tar.gz.
- Delete kabi/i386/symtypes-default.
- Delete kabi/i386/symtypes-pae.
- Delete kabi/i386/symtypes-trace.
- Delete kabi/i386/symtypes-xen.
- Delete kabi/i386/symvers-default.
- Delete kabi/i386/symvers-default.fake.
- Delete kabi/i386/symvers-pae.
- Delete kabi/i386/symvers-pae.fake.
- Delete kabi/i386/symvers-trace.
- Delete kabi/i386/symvers-trace.fake.
- Delete kabi/i386/symvers-xen.
- Delete kabi/ia64/symsets-default.tar.gz.
- Delete kabi/ia64/symsets-trace.tar.gz.
- Delete kabi/ia64/symtypes-default.
- Delete kabi/ia64/symtypes-trace.
- Delete kabi/ia64/symvers-default.
- Delete kabi/ia64/symvers-trace.
- Delete kabi/ppc64/symsets-default.tar.gz.
- Delete kabi/ppc64/symsets-ppc64.tar.gz.
- Delete kabi/ppc64/symsets-trace.tar.gz.
- Delete kabi/ppc64/symtypes-default.
- Delete kabi/ppc64/symtypes-ppc64.
- Delete kabi/ppc64/symtypes-trace.
- Delete kabi/ppc64/symvers-default.
- Delete kabi/ppc64/symvers-ppc64.
- Delete kabi/ppc64/symvers-trace.
- Delete kabi/s390x/symsets-default.tar.gz.
- Delete kabi/s390x/symsets-trace.tar.gz.
- Delete kabi/s390x/symtypes-default.
- Delete kabi/s390x/symtypes-trace.
- Delete kabi/s390x/symvers-default.
- Delete kabi/s390x/symvers-trace.
- Delete kabi/x86_64/symsets-bigsmp.tar.gz.
- Delete kabi/x86_64/symsets-default.tar.gz.
- Delete kabi/x86_64/symsets-trace.tar.gz.
- Delete kabi/x86_64/symsets-xen.tar.gz.
- Delete kabi/x86_64/symtypes-bigsmp.
- Delete kabi/x86_64/symtypes-default.
- Delete kabi/x86_64/symtypes-trace.
- Delete kabi/x86_64/symtypes-xen.
- Delete kabi/x86_64/symvers-bigsmp.
- Delete kabi/x86_64/symvers-default.
- Delete kabi/x86_64/symvers-default.fake.
- Delete kabi/x86_64/symvers-trace.
- Delete kabi/x86_64/symvers-trace.fake.
- Delete kabi/x86_64/symvers-xen.
- Delete kabi/x86_64/symvers-xen.fake.
  Due to planned -bigsmp merge into -default there is not much sense in
  keeping to track it.
- commit 1be5b1e
* Mon Dec  8 2014 jjolly@suse.de
- s390: add support to start the kernel in 64 bit mode
  (bnc#902516, FATE#317622, LTC#110331).
- s390/zcrypt: add support for EP11 coprocessor cards (bnc#902514,
  FATE#317624, LTC#110335).
- qeth: Display adjacent switch attributes (bnc#902513,
  FATE#317598, LTC#110521).
- s390/cio: add condev keyword to cio_ignore (bnc#902387,
  FATE#317623, LTC#110333).
- s390/cio: add ipldev keyword to cio_ignore (bnc#902387,
  FATE#317623, LTC#110333).
- s390/perf: make print_debug_cf() static (bnc#900899,
  FATE#317698, LTC#110510).
- s390/cpum_sf: fix printk format warnings (bnc#900899,
  FATE#317698, LTC#110510).
- s390/perf: Add service level information for CPU-Measurement
  Facilities (bnc#900899, FATE#317698, LTC#110510).
- s390/cpum_sf: Add flag to process full SDBs only (bnc#900899,
  FATE#317698, LTC#110510).
- s390/cpum_sf: Add raw data sampling to support the
  diagnostic-sampling function (bnc#900899, FATE#317698,
  LTC#110510).
- s390/cpum_sf: Filter perf events based event->attr.exclude_*
  settings (bnc#900899, FATE#317698, LTC#110510).
- s390/cpum_sf: Detect KVM guest samples (bnc#900899, FATE#317698,
  LTC#110510).
- s390/cpum_sf: Add helper to read TOD from trailer entries
  (bnc#900899, FATE#317698, LTC#110510).
- s390/cpum_sf: Atomically reset trailer entry fields of
  sample-data-blocks (bnc#900899, FATE#317698, LTC#110510).
- s390/cmpxchg,percpu: implement cmpxchg_double() (bnc#900899,
  FATE#317698, LTC#110510).
- s390/cpum_sf: Dynamically extend the sampling buffer if
  overflows occur (bnc#900899, FATE#317698, LTC#110510).
- s390/perf,oprofile: Share sampling facility (bnc#900899,
  FATE#317698, LTC#110510).
- s390/perf: Improve PMU selection for PERF_COUNT_HW_CPU_CYCLES
  events (bnc#900899, FATE#317698, LTC#110510).
- s390/perf: add support for the CPU-Measurement Sampling Facility
  (bnc#900899, FATE#317698, LTC#110510).
- s390/oprofile: move hwsampler interfaces to cpu_mf.h
  (bnc#900899, FATE#317698, LTC#110510).
- s390/perf: cpum_cf: fallback to software sampling events
  (bnc#900899, FATE#317698, LTC#110510).
- s390/perf_events: compile only for CONFIG_64BIT (bnc#900899,
  FATE#317698, LTC#110510).
- s390/perf: Remove print_hex_dump_bytes() debug output
  (bnc#900899, FATE#317698, LTC#110510).
- s390/perf: fix compile error (undefined reference sie_exit)
  (bnc#900899, FATE#317698, LTC#110510).
- KVM: s390,perf: Detect if perf samples belong to KVM host or
  guest (bnc#900899, FATE#317698, LTC#110510).
- commit 61994bc
* Mon Dec  8 2014 mmarek@suse.cz
- config.conf: Do not require kernel-bigsmp-devel by kernel-syms
  The flavor will soon be merged back into -default.
- commit f87c20d
* Mon Dec  8 2014 jroedel@suse.de
- iommu/vt-d: Fix an off-by-one bug in __domain_mapping()
  (bsc#908825).
- commit 091260c
* Sun Dec  7 2014 bpoirier@suse.de
- net: sctp: fix remote memory pressure from excessive queueing
  (bnc#902351 CVE-2014-3688).
- commit 87d5fc9
* Sun Dec  7 2014 bpoirier@suse.de
- net: sctp: fix remote memory pressure from excessive queueing
  (bnc#902351 CVE-2014-3688).
- commit 8a2eadc
* Fri Dec  5 2014 mszeredi@suse.cz
- mnt: Prevent pivot_root from creating a loop in the mount tree
  (CVE-2014-7970 bnc#900644).
- vfs: more mnt_parent cleanups (CVE-2014-7970 bnc#900644).
- vfs: new internal helper: mnt_has_parent(mnt) (CVE-2014-7970
  bnc#900644).
- Refresh
  patches.suse/dcache-add-dcache_lustre_invalid-flag-for-lustre-to-handle-its-own-invalidation.
- commit ded5a46
* Fri Dec  5 2014 oneukum@suse.de
- xhci: fix oops when xhci resumes from hibernate with hw lpm
  capable devices (FATE#317453).
- usb: allow lpm (en/dis)able only if device is atleast in
  default state (FATE#317453).
- xhci: A default implementation for Ux timeout calculation and
  tier policy check (FATE#317453).
- xhci: fix wrong port number reported when setting USB2.0
  hardware LPM (FATE#317453).
- xhci: Prevent runtime pm from autosuspending during
  initialization (FATE#317453).
- usb/xhci: Change how we indicate a host supports Link PM
  (FATE#317453).
- usb: hub: usb_ext_cap_descriptor.bmAttributes is le32
  (FATE#317453).
- xhci: replace USB_MAXINTERFACES with config->desc.bNumInterface
  (FATE#317453).
- xhci: correct the usage of USB_CTRL_SET_TIMEOUT (FATE#317453).
- usb: Push USB2 LPM disable on disconnect into USB core
  (FATE#317453).
- usb: hub: modify hub driver for missing ACPI parts
  (FATE#317453).
- xhci: Enable LPM support only for hardwired or BESL devices
  (FATE#317453).
- usb: Don't enable USB 2.0 Link PM by default (FATE#317453).
- xhci: Set L1 device slot on USB2 LPM enable/disable
  (FATE#317453).
- usbcore: check usb device's state before sending a Set SEL
  control transfer (FATE#317453).
- usbcore: fix incorrect type in assignment in
  descriptors_changed() (FATE#317453).
- usbcore: compare and release one bos descriptor in
  usb_reset_and_verify_device() (FATE#317453).
- xhci: Don't enable/disable RWE on bus suspend/resume
  (FATE#317453).
- usb: add usb2 Link PM variables to sysfs and usb_device
  (FATE#317453).
- usb: xhci: add USB2 Link power management BESL support
  (FATE#317453).
- xHCI: BESL calculation based on USB2.0 LPM errata (FATE#317453).
- xhci: Use ilog2() rather than __ffs() for calculating
  SEGMENT_SHIFT (FATE#317453).
- USB: driver.c: processing failure, maching resume condition
  with suspend condition (FATE#317453).
- USB: remove CONFIG_USB_SUSPEND option (FATE#317453).
- USB: avoid error messages when a device is disconnected
  (FATE#317453).
- xhci: Report USB 2.1 link status for L1 (FATE#317453).
- usb: xhci: define port register names and use them instead of
  magic numbers (FATE#317453).
- xhci: fix port BESL LPM capability checking (FATE#317453).
- commit 52e9e5b
* Fri Dec  5 2014 tiwai@suse.de
- x86/gpu: Print the Intel graphics stolen memory range
  (bnc#908550).
- commit 1378cad
* Fri Dec  5 2014 tiwai@suse.de
- mfd: lpc_ich: Add support for Intel Bay Trail SoC
  (bnc#908012,FATE#317358).
- mfd: lpc_ich: Change Avoton to iTCO v3 (bnc#908012,FATE#317358).
- mfd: lpc_ich: Add support for iTCO v3 (bnc#908012,FATE#317358).
- watchdog: iTCO_wdt: Add support for v3 silicon
  (bnc#908012,FATE#317358).
- commit a8440ac
* Fri Dec  5 2014 tiwai@suse.de
- KEYS: Fix stale key registration at error path (bnc#908163).
- commit 1761fb7
* Fri Dec  5 2014 bpoirier@suse.de
- net: sctp: fix panic on duplicate ASCONF chunks (bnc#902349
  CVE-2014-3687).
- commit ca3113c
* Fri Dec  5 2014 bpoirier@suse.de
- net: sctp: fix panic on duplicate ASCONF chunks (bnc#902349
  CVE-2014-3687).
- commit 61b5f92
* Wed Dec  3 2014 mkubecek@suse.cz
- virtio_net: drop dst reference before transmitting a packet
  (bnc#882470).
- commit d276a14
* Wed Dec  3 2014 mkubecek@suse.cz
- ipv6: fix net reference leak in IPv6 conntrack reassembly
  (bnc#865419).
- nf_conntrack: avoid reference leak in __ipv6_conntrack_in()
  (bnc#865419).
- commit eb15acb
* Wed Dec  3 2014 dbueso@suse.de
- sched/fair: Stop searching for tasks in newidle balance if
  there are runnable tasks (FATE#317649).
- commit bca3762
* Tue Dec  2 2014 agraf@suse.de
- kvm: Don't expose MONITOR cpuid as available (bnc#887597)
- commit 40b6ebe
* Mon Dec  1 2014 mszeredi@suse.cz
- proc_sys_revalidate: fix Oops on NULL nameidata (bnc#907551).
- commit fda7acf
* Fri Nov 28 2014 jbohac@suse.cz
- net: fix neighbours after MAC change (bnc#905299).
- commit 5211998
* Fri Nov 28 2014 tiwai@suse.de
- Force native backlight for HP POS machines (bnc#908551,FATE#317933).
- commit 8f1b4a4
* Thu Nov 27 2014 jlee@suse.com
- i2c: i801: Add Device IDs for Intel Sunrise Point PCH
  (fate#317355).
- i2c: i801: Add Device IDs for Intel Wildcat Point-LP PCH
  (fate#317348).
- i2c: i801: SMBus patch for Intel Coleto Creek DeviceIDs
  (fate#317357).
- commit 9e6f3ca
* Thu Nov 27 2014 mkubecek@suse.cz
- bonding: propagate LRO disabling down to slaves (bnc#829110
  bnc#891277 bnc#904053).
- net: handle more general stacking in dev_disable_lro()
  (bnc#829110 bnc#891277 bnc#904053).
- commit 9bd4b28
* Thu Nov 27 2014 tiwai@suse.de
- ACPI idle: permit sparse C-state sub-state numbers (bnc#908550,FATE#317933).
- x86/intel: Add quirk to disable HPET for the Baytrail platform (bnc#908550,FATE#317933).
- x86/hpet: Make boot_hpet_disable extern (bnc#908550,FATE#317933).
- x86/early quirk: use gen6 stolen detection for VLV (bnc#908550,FATE#317933).
- x86: add early quirk for reserving Intel graphics stolen memory v5 (bnc#908550,FATE#317933).
- Revert "drm/i915: Calculate correct stolen size for GEN7+"
  (bnc#908550,FATE#317933).
- drm/i915: split PCI IDs out into i915_drm.h v4 (bnc#908550,FATE#317933).
- commit c4832a9
* Thu Nov 27 2014 jlee@suse.com
- dw_dmac: add support for Lynxpoint DMA controllers
  (fate#317311).
- commit ed6ddcd
* Wed Nov 26 2014 tiwai@suse.de
- Add support for AdvancedSilicon HID multitouch screen
  (2149:36b1) (FATE#317933).
- HID: use multi input quirk for 22b9:2968 (FATE#317933).
- commit c291077
* Wed Nov 26 2014 tiwai@suse.de
- ALSA: hda/hdmi - apply Valleyview fix-ups to Cherryview display
  codec (FATE#317933).
- ALSA: hda - add codec ID for Braswell display audio codec
  (FATE#317933).
- ALSA: hda - verify pin:converter connection on unsol event
  for HSW and VLV (FATE#317933).
- ALSA: hda - hdmi: Re-setup pin and infoframe on plug-in on
  all codecs (FATE#317933).
- ALSA: hda - verify pin:cvt connection on preparing a stream
  for Intel HDMI codec (FATE#317933).
- ALSA: hda/hdmi - apply all Haswell fix-ups to Broadwell display
  codec (FATE#317933).
- ALSA: hda - add codec ID for Broadwell display audio codec
  (FATE#317933).
- ALSA: hda - rename function not_share_unassigned_cvt()
  (FATE#317933).
- ALSA: hda - not choose assigned converters for unused pins of
  Valleyview (FATE#317933).
- ALSA : hda - not use assigned converters for all unused pins
  (FATE#317933).
- ALSA: hda - unmute pin amplifier in infoframe setup for Haswell
  (FATE#317933).
- ALSA: hda - define is_haswell() to check if a display audio
  codec is Haswell (FATE#317933).
- ALSA: hda - add codec ID for Valleyview2 display codec
  (FATE#317933).
- ALSA: hda_intel: Add DeviceIDs for Sunrise Point-LP
  (FATE#317347).
- ALSA: hda_intel: Add Device IDs for Intel Sunrise Point PCH
  (FATE#317347).
- ALSA: hda - add PCI IDs for Intel Braswell (FATE#317347).
- ALSA: hda - Fix onboard audio on Intel H97/Z97 chipsets
  (FATE#317347).
- ALSA: hda - Add Device IDs for Intel Wildcat Point-LP PCH
  (FATE#317347).
- ALSA: hda - add PCI IDs for Intel BayTrail (FATE#317347).
- commit 5bda7d8
* Wed Nov 26 2014 jdelvare@suse.de
- supported.conf: Sort the list
- commit cf8a204
* Wed Nov 26 2014 jdelvare@suse.de
- supported.conf: Update module paths
  Driver code has moved around in the kernel tree over time, update our
  list of supported modules accordingly.
- commit b5f589b
* Wed Nov 26 2014 mmarek@suse.cz
- rpm/constraints.in: Require 10GB disk space on POWER
  A debuginfo build currently requires about 8.5 GB on POWER. Also,
  require at least 8 CPUs, so that builds do not get accidentally
  scheduled on slow machines.
- commit cd17059
* Tue Nov 25 2014 mgorman@suse.de
- mm, thp: Add dummy definition for VM_NOHUGEPAGE where necessary
  (prctl support for disabling THP (fate#317831)).
- commit 2d1a8ee
* Tue Nov 25 2014 bp@suse.de
- mce: acpi/apei: Add a boot option to disable ff mode for
  corrected errors (fate#317438).
- mce: acpi/apei: Honour Firmware First for MCA banks listed in
  APEI HEST CMC (fate#317438).
- mce: acpi/apei: Soft-offline a page on firmware GHES
  notification (fate#317438).
- Update config files.
- commit 28f4c36
* Tue Nov 25 2014 alnovak@suse.cz
- x86, xsave: remove thread_has_fpu() bug check in
  __sanitize_i387_state() (bnc#904671).
- coredump: ensure the fpu state is flushed for proper
  multi-threaded core dump (bnc#904671).
- commit 9a038ce
* Tue Nov 25 2014 mgorman@suse.de
- mm, thp: add VM_INIT_DEF_MASK and PRCTL_THP_DISABLE (prctl
  support for disabling THP (fate#317831)).
- mm: revert "thp: make MADV_HUGEPAGE check for mm->def_flags"
  (prctl support for disabling THP (fate#317831)).
- thp: make MADV_HUGEPAGE check for mm->def_flags (prctl support
  for disabling THP (fate#317831)).
- commit 8b6da20
* Tue Nov 25 2014 mhocko@suse.cz
- mm: fix BUG in __split_huge_page_pmd (bnc#906586).
- commit 9394f8d
* Tue Nov 25 2014 ohering@suse.de
- Carry outstanding hv_netvsc patches, not applied due to crash
  They are not applied yet because they cause a crash.
- Drivers: net: hyperv: Enable send side checksum offload
  (fate#317533).
- Drivers: net: hyperv: Enable large send offload (fate#317533).
- Drivers: net: hyperv: Allocate memory for all possible
  per-pecket information (fate#317533).
- Drivers: net: hyperv: Address UDP checksum issues (fate#317533).
- hyperv: Properly handle checksum offload (fate#317533).
- hyperv: Add hash value into RNDIS Per-packet info (fate#317533).
- hyperv: Fix a bug in netvsc_start_xmit() (fate#317533).
- hyperv: Fix the total_data_buflen in send path (fate#317533).
- commit 445aff6
* Tue Nov 25 2014 mhocko@suse.cz
- kabi, mm: prevent endless growth of anon_vma hierarchy
  (bnc#904242).
- mm: prevent endless growth of anon_vma hierarchy (bnc#904242).
- commit 695231a
* Tue Nov 25 2014 jdelvare@suse.de
- supported.conf: Fix typo in cxgb4i module path
- commit 3229ee9
* Tue Nov 25 2014 jdelvare@suse.de
- supported.conf: Drop references to deleted modules
  All these modules no longer exist in our kernel tree so listing them
  in supported.conf is pointless.
- commit 6fe8dc3
* Tue Nov 25 2014 jdelvare@suse.de
- i2c: piix4: Use different message for AMD Auxiliary SMBus
  Controller (FATE#316957).
- i2c: piix4: Add support for AMD ML and CZ SMBus changes
  (FATE#316957).
- i2c: piix4: Add support for secondary SMBus on AMD SB800 and
  AMD FCH chipsets (FATE#316957).
- i2c-piix4: Add AMD CZ SMBus device ID (FATE#316957).
- i2c-piix4: Fix build failure (FATE#316957).
- i2c-piix4: Support AMD auxiliary SMBus controller (FATE#316957).
- i2c-piix4: Separate registration and probing code (FATE#316957).
- i2c-piix4: Eliminate piix4_smba global variable (FATE#316957).
- commit c137a57
* Tue Nov 25 2014 mszeredi@suse.cz
- fs: add link restrictions (FATE#314496).
- commit 8e7f2bd
* Mon Nov 24 2014 jroedel@suse.de
- iommu/vt-d: Be less pessimistic about domain coherency where
  possible (fate#317111).
- iommu/vt-d: Simplify intel_unmap_sg() and kill duplicated code
  (fate#317111).
- iommu/vt-d: Clean up and fix page table clear/free behaviour
  (fate#317111).
- commit 0939dbf
* Sun Nov 23 2014 dbueso@suse.de
- mm,vmacache: optimize overflow system-wide flushing (VM
  Performance).
- commit 850c598
* Sun Nov 23 2014 dbueso@suse.de
- mm: enable per-thread vma caching (FATE#318083).
- commit d146195
* Fri Nov 21 2014 rgoldwyn@suse.de
- ocfs2: fix NULL pointer dereference in ocfs2_duplicate_clusters_by_page
  (bnc#899843).
- Refresh
  patches.fixes/ocfs2-remove-filesize-checks-for-journal-commits.patch.
- commit 4f07b11
* Fri Nov 21 2014 oneukum@suse.de
- xhci: replace xhci_info() with xhci_dbg() (FATE#317451).
- xhci: replace printk(KERN_DEBUG ...) (FATE#317451).
- xhci: remove CONFIG_USB_XHCI_HCD_DEBUGGING and unused code
  (FATE#317451).
- Update config files.
- commit 12e59c2
* Thu Nov 20 2014 jbeulich@suse.com
- x86: use optimized ioresource lookup in ioremap function
  (Boot time optimisations (bnc#895387)).
- Refresh patches.xen/xen3-patch-2.6.37.
- commit c2cd2fc
* Thu Nov 20 2014 ptesarik@suse.cz
- vfs,proc: guarantee unique inodes in /proc (bnc#868049).
- commit 96f9010
* Thu Nov 20 2014 rgoldwyn@suse.de
- Remove filesize checks for sync I/O journal commit (bnc#800255).
- commit 627896b
* Tue Nov 18 2014 bp@suse.de
- intel_idle: Broadwell support (fate#317424).
- commit 82c1c8f
* Tue Nov 18 2014 jack@suse.cz
- block: Fix bogus partition statistics reports (bnc#885077
  bnc#891211).
- commit d841046
* Tue Nov 18 2014 hare@suse.de
- scsi_dh_alua: disable ALUA handling for non-disk devices
  (bnc#876633).
- commit 8e5e56c
* Mon Nov 17 2014 bp@suse.de
- KVM: Add x86_hyper_kvm to complete detect_hypervisor_platform
  check (FATE#314895, bsc#801138).
- x86/apic: Allow x2apic without IR on VMware platform
  (FATE#314895, bsc#801138).
- x86, kvm: Fix intialization warnings in kvm.c (FATE#314895,
  bsc#801138).
- Refresh patches.xen/xen3-patch-2.6.29.
- commit d440e7e
* Sat Nov 15 2014 bpoirier@suse.de
- net: sctp: fix skb_over_panic when receiving malformed ASCONF
  chunks (bnc#902346 CVE-2014-3673).
- commit 26373dd
* Sat Nov 15 2014 bpoirier@suse.de
- net: sctp: fix skb_over_panic when receiving malformed ASCONF
  chunks (bnc#902346 CVE-2014-3673).
- commit bf44109
* Fri Nov 14 2014 ohering@suse.de
- update two hv_vmbus patches to mainline state
- commit dfd436c
* Fri Nov 14 2014 ohering@suse.de
- hyperv: Fix a bug in netvsc_send() (fate#317533).
- Drivers: hv: vmbus: Enable interrupt driven flow control
  (fate#317533).
- Drivers: hv: vmbus: Properly protect calls to smp_processor_id()
  (fate#317533).
- Drivers: hv: vmbus: Cleanup hv_post_message() (fate#317533).
- Drivers: hv: vmbus: Cleanup vmbus_close_internal()
  (fate#317533).
- Drivers: hv: vmbus: Fix a bug in vmbus_open() (fate#317533).
- Drivers: hv: vmbus: Cleanup vmbus_establish_gpadl()
  (fate#317533).
- Drivers: hv: vmbus: Cleanup vmbus_teardown_gpadl()
  (fate#317533).
- Drivers: hv: vmbus: Cleanup vmbus_post_msg() (fate#317533).
- storvsc: get rid of overly verbose warning messages
  (fate#317533).
- hyperv: NULL dereference on error (fate#317533).
- hyperv: Increase the buffer length for netvsc_channel_cb()
  (fate#317533).
- Input: hyperv-keyboard - register as a wakeup source
  (fate#317533).
- hyperv: Adjust the size of sendbuf region to support ws2008r2
  (fate#317533).
- Drivers: net-next: hyperv: Increase the size of the sendbuf
  region (fate#317533).
- HID: hyperv: register as a wakeup source (fate#317533).
- video: hyperv: hyperv_fb: refresh the VM screen by force on
  VM panic (fate#317533).
- Drivers: add blist flags (fate#317533).
- drivers: scsi: storvsc: Correctly handle TEST_UNIT_READY failure
  (fate#317533).
- drivers: scsi: storvsc: Set srb_flags in all cases
  (fate#317533).
- Drivers: scsi: storvsc: Implement a eh_timed_out handler
  (fate#317533).
- Drivers: scsi: storvsc: Fix a bug in handling VMBUS protocol
  version (fate#317533).
- Drivers: scsi: storvsc: Filter commands based on the storage
  protocol version (fate#317533).
- Drivers: scsi: storvsc: Set cmd_per_lun to reflect value
  supported by the Host (fate#317533).
- Drivers: scsi: storvsc: Change the limits to reflect the values
  on the host (fate#317533).
- hyperv: Fix error return code in netvsc_init_buf()
  (fate#317533).
- Drivers: hv: hv_fcopy: fix a race condition for SMP guest
  (fate#317533).
- hyperv: Add netpoll support (fate#317533).
- hyperv: remove meaningless pr_err() in vmbus_recvpacket_raw()
  (fate#317533).
- Tools: hv: fix file overwriting of hv_fcopy_daemon
  (fate#317533).
- drivers/net/hyperv/netvsc.c: remove unnecessary null test
  before kfree (fate#317533).
- hyperv: Add handler for RNDIS_STATUS_NETWORK_CHANGE event
  (fate#317533).
- hyperv: fix apparent cut-n-paste error in send path teardown
  (fate#317533).
- hyper-v: make uuid_le const (fate#317533).
- hv: use correct order when freeing monitor_pages (fate#317533).
- Add support for netvsc build without CONFIG_SYSFS flag
  (fate#317533).
- Drivers: hv: balloon: Ensure pressure reports are posted
  regularly (fate#317533).
- hv: Remove unnecessary comparison of unsigned against 0
  (fate#317533).
- Drivers: hv: vmbus: Implement per-CPU mapping of relid to
  channel (fate#317533).
- Drivers: hv: Eliminate the channel spinlock in the callback path
  (fate#317533).
- hyperv: Enable sendbuf mechanism on the send path (fate#317533).
- hyperv: Simplify the send_completion variables (fate#317533).
- hyperv: Remove recv_pkt_list and lock (fate#317533).
- hyperv: Add support for virtual Receive Side Scaling (vRSS)
  (fate#317533).
- Drivers: hv: vmbus: Negotiate version 3.0 when running on
  ws2012r2 hosts (fate#317533).
- Tools: hv: Handle the case when the target file exists correctly
  (fate#317533).
- x86, irq, pic: Probe for legacy PIC and set legacy_pic
  appropriately (fate#317533).
- Drivers: net: hyperv: Negotiate suitable ndis version for
  offload support (fate#317533).
- x86, hyperv: Bypass the timer_irq_works() check (fate#317533).
- hyperv: Change the receive buffer size for legacy hosts
  (fate#317533).
- Drivers: net: hyperv: Enable receive side IP checksum offload
  (fate#317533).
- Drivers: net: hyperv: Enable offloads on the host (fate#317533).
- Drivers: net: hyperv: Cleanup the send path (fate#317533).
- Drivers: net: hyperv: Enable scatter gather I/O (fate#317533).
- Drivers: hv: vmbus: Increase the limit on the number of pfns
  we can handle (fate#317533).
- hyperv: Move state setting for link query (fate#317533).
- hyperv-fb: kick off efifb early (fate#317533).
- hyperv-fb: add support for generation 2 virtual machines
  (fate#317533).
- vmbus: use resource for hyperv mmio region (fate#317533).
- vmbus: add missing breaks (fate#317533).
- hyperv: Add latest NetVSP versions to auto negotiation
  (fate#317533).
- Drivers: hv: fcopy_open() can be static (fate#317533).
- Drivers: hv: Implement the file copy service (fate#317533).
- Drivers: net: hyperv: Cleanup the netvsc receive callback
  functio (fate#317533).
- Drivers: net: hyperv: Cleanup the receive path (fate#317533).
- Drivers: net: hyperv: Get rid of the rndis_filter_packet
  structure (fate#317533).
- HID: hyperv: make sure input buffer is big enough (fate#317533).
- hyperv: Fix the carrier status setting (fate#317533).
- Drivers: hv: Ballon: Make pressure posting thread sleep
  interruptibly (fate#317533).
- Tools: hv: vssdaemon: Ignore VFAT mounts during the Freeze
  operation (fate#317533).
- Drivers: hv: vmbus: Support per-channel driver state
  (fate#317533).
- Drivers: hv: vmbus: Cleanup the packet send path (fate#317533).
- Drivers: hv: vmbus: Extract the mmio information from DSDT
  (fate#317533).
- Drivers: hv: vmbus: Don't timeout during the initial connection
  with host (fate#317533).
- Drivers: hv: vmbus: Specify the target CPU that should receive
  notification (fate#317533).
- hyperv: Add support for physically discontinuous receive buffer
  (fate#317533).
- Input: hyperv-keyboard - pass through 0xE1 prefix (fate#317533).
- hyperv: Fix race between probe and open calls (fate#317533).
- drivers: hv: Mark the function hv_synic_free_cpu() as static
  in hv.c (fate#317533).
- netvsc: don't flush peers notifying work during setting mtu
  (fate#317533).
- Tools: hv: remove inclusion of linux/types.h (fate#317533).
- x86, hyperv: Move a variable to avoid an unused variable warning
  (fate#317533).
- x86, hyperv: Fix build error due to missing <asm/apic.h>
  include (fate#317533).
- Drivers: hv: vmbus: Fix a bug in channel rescind code
  (fate#317533).
- drivers: hv: Fix wrong check for synic_event_page (fate#317533).
- x86, hyperv: Correctly guard the local APIC calibration code
  (fate#317533).
- x86, hyperv: Get the local APIC timer frequency from the
  hypervisor (fate#317533).
- hyperv-fb: add blanking support (fate#317533).
- hyperv-fb: add pci stub (fate#317533).
- hv: vmbus: fix vmbus_recvpacket_raw() return code (fate#317533).
- Tools: hv: use single send+recv buffer (fate#317533).
- Tools: hv: cache FQDN in kvp_daemon to avoid timeouts
  (fate#317533).
- hv: make "monitor_pages" a "real" pointer array (fate#317533).
- hv: Change variable type to bool (fate#317533).
- Input: add a driver to support Hyper-V synthetic keyboard
  (fate#317533).
- Fix the VLAN_TAG_PRESENT in netvsc_recv_callback()
  (fate#317533).
- hyperv: Fix vlan_proto setting in netvsc_recv_callback()
  (fate#317533).
- commit 52c98d0
* Fri Nov 14 2014 oneukum@suse.de
- ttusb-dec: buffer overflow in ioctl (bnc#905522).
- commit 24d8848
* Fri Nov 14 2014 oneukum@suse.de
- Revert "HID: picolcd: sanity check report size in raw_event() callback"
  This reverts commit e93bc3cae41ae9345c4a56f898506ec6658d4afe.
- commit 9d53954
* Fri Nov 14 2014 oneukum@suse.de
- HID: picolcd: sanity check report size in raw_event() callback
  (bsc#896392, CVE-2014-3186) (bnc#905522).
- commit e93bc3c
* Fri Nov 14 2014 ohering@suse.de
- scsi: add a blacklist flag which enables VPD page inquiries
  (fate#317533).
- scsi_scan: Restrict sequential scan to 256 LUNs (fate#317533).
- Workaround for disks that report bad optimal transfer length
  (fate#317533).
- commit 59d0451
* Fri Nov 14 2014 tiwai@suse.de
- ALSA: hda_intel: Add DeviceIDs for Sunrise Point-LP
  (FATE#317347).
- ALSA: hda_intel: Add Device IDs for Intel Sunrise Point PCH
  (FATE#317347).
- ALSA: hda - add PCI IDs for Intel Braswell (FATE#317347).
- ALSA: hda - Fix onboard audio on Intel H97/Z97 chipsets
  (FATE#317347).
- ALSA: hda - Add Device IDs for Intel Wildcat Point-LP PCH
  (FATE#317347).
- ALSA: hda - add PCI IDs for Intel BayTrail (FATE#317347).
- commit 553c347
* Fri Nov 14 2014 dsterba@suse.cz
- Delete patches.suse/btrfs-8288-clone-don-t-create-invalid-hole-extent-map.patch.
  Enable patches.suse/btrfs-8284-fix-EIO-on-reading-file-after-ioctl-clone-work.patch.
- commit 81627a9
* Fri Nov 14 2014 ohering@suse.de
- hv: netvsc: convert to SKB paged frag API.
- net: add skb frag size accessors.
- Refresh two other hv_netvsc patches to match mainline
- commit dd3020a
* Thu Nov 13 2014 bp@suse.de
- HID: picolcd: sanity check report size in raw_event() callback
  (bsc#896392, CVE-2014-3186).
- commit 177b5b9
* Thu Nov 13 2014 ohering@suse.de
- net: Add skb_get_hash_raw (fate#317533).
- net: Add utility functions to clear rxhash (fate#317533).
- net: Add function to set the rxhash (fate#317533).
- rps: Add flag to skb to indicate rxhash is based on L4 tuple
  (fate#317533).
- commit 060b637
* Thu Nov 13 2014 ohering@suse.de
- x86, mm: Create slow_virt_to_phys() (fate#317533).
- x86, mm: Pagetable level size/shift/mask helpers (fate#317533).
- x86/apic: Allow use of lapic timer early calibration result
  (fate#317533).
- commit 325fafc
* Thu Nov 13 2014 jbohac@suse.cz
- net: sctp: fix NULL pointer dereference in af->from_addr_param
  on (bnc#905100, CVE-2014-7841).
- commit 950a520
* Thu Nov 13 2014 tiwai@suse.de
- lzo: check for length overrun in variable length encoding
  (bnc#883948,CVE-2014-4608).
- commit 1aebccc
* Thu Nov 13 2014 dsterba@suse.cz
- Btrfs: check file extent type before anything else (bnc#897694).
- commit 9b90338
* Thu Nov 13 2014 tiwai@suse.de
- mac80211: fix fragmentation code, particularly for encryption
  (bnc#904700,CVE-2014-8709).
- commit 98a4c71
* Thu Nov 13 2014 tiwai@suse.de
- USB: whiteheat: Added bounds checking for bulk command response
  (CVE-2014-3185,bnc#896391).
- commit 6842b21
* Wed Nov 12 2014 bp@suse.de
- HID: fix a couple of off-by-ones (bsc#896390, CVE-2014-3184).
- commit 3101559
* Wed Nov 12 2014 mkubecek@suse.cz
- cifs: delay super block destruction until all cifsFileInfo
  objects are gone (bnc#903653).
- commit fcc029b
* Wed Nov 12 2014 jbeulich@suse.com
- Update Xen patches to c/s 1266.
- blkback: allow using indirect request segment descriptors
  (fate#316876).
- blkfront: allow using indirect request segment descriptors
  (fate#316876).
- blkif: indirect request segment descriptors definitions
  (fate#316876).
- privcmd: actually batch hypercalls for batch ioctls.
- x86: use optimized ioresource lookup in ioremap function
  (Boot time optimisations (bnc#895387)).
- Update Xen config files.
- commit c106661
* Wed Nov 12 2014 jjolly@suse.de
- zcrypt: toleration of new crypto adapter hardware (bnc#894058,
  LTC#117041).
- zcrypt: support for extended number of ap domains (bnc#894058,
  LTC#117041).
- commit 554c1e1
* Tue Nov 11 2014 bp@suse.de
- HID: magicmouse: sanity check report size in raw_event()
  callback (bsc#896382, CVE-2014-3181).
- commit aa733ae
* Tue Nov 11 2014 mmarek@suse.cz
- Build the KOTD against the SP3 Update project
- commit 4209181
* Tue Nov 11 2014 mgorman@suse.de
- Refresh
  patches.suse/x86-use-optimized-ioresource-lookup-in-ioremap-function.patch.
- x86, ioremap: Speed up check for RAM pages
  (Boot time optimisations (bnc#895387)).
- commit cff6fb5
* Tue Nov 11 2014 oneukum@suse.de
- xhci: no switching back on non-ULT Haswell (FATE#317636).
- xhci: Switch only Intel Lynx Point-LP ports to EHCI on shutdown
  (FATE#317636).
- xhci: Switch Intel Lynx Point ports to EHCI on shutdown
  (FATE#317636).
- xhci: Prevent runtime pm from autosuspending during
  initialization (FATE#317636).
- usb: xhci: fix section mismatch in linux-next (FATE#317636).
- commit e5e1e24
* Tue Nov 11 2014 jbohac@suse.cz
- net: add WARN_ON if kernel advertises msg_namelen > sizeof(struct
  (bnc#853040).
- commit 6b96ffb
* Mon Nov 10 2014 bp@suse.de
- tracing/syscalls: Ignore numbers outside NR_syscalls' range
  (bsc#904013, CVE-2014-7826).
- commit b064be5
* Mon Nov 10 2014 neilb@suse.de
- NFSv4: nfs4_open_done first must check that GETATTR decoded
  a file type (bnc#899574).
- commit 7829aff
* Fri Nov  7 2014 bp@suse.de
- ipv6: fix leaking uninitialized port number of offender sockaddr
  (bsc#853040).
- commit 65ceabb
* Fri Nov  7 2014 mgorman@suse.de
- x86: use optimized ioresource lookup in ioremap function
  (Boot time optimisations (bnc#895387)).
- x86: optimize resource lookups for ioremap (Boot time
  optimisations (bnc#895387)).
- commit 9e9d27f
* Fri Nov  7 2014 oneukum@suse.de
- usb: Do not re-read descriptors for wired devices in
  usb_authorize_device() (bnc#904358).
- commit 1cb3909
* Fri Nov  7 2014 mkubecek@suse.cz
- netxen: Fix link event handling (bnc#873228).
- netxen: fix link notification order (bnc#873228).
- commit 7cfef2a
* Thu Nov  6 2014 jkosina@suse.cz
- Delete
  patches.suse/0001-mm-hugetlb-improve-page-fault-scalability.patch.
  It's a unused duplicate of
  patches.suse/mm-hugetlb-improve-page-fault-scalability.patch
- commit 1c7ee4f
* Thu Nov  6 2014 jkosina@suse.cz
- kabi/severities: allow all kABI changes to pass, while still keeping SP3 symsets
  We try to keep SLE11-SP4 kABI as stable as possible. This allows us
  to keep track of how kABI is changing by watching the kABI build warnings
  but do not have failing builds because of that.
  This will be removed once kABI is officially frozen and we start tracking
  it properly in our normal way.
- commit 751c4d1
* Thu Nov  6 2014 jkosina@suse.cz
- README.BRANCH:
- rpm/config.sh:
  Create SLE11-SP4 branch and update config.
- commit 4190a64
* Tue Nov  4 2014 eich@suse.com
- drm/mgag200: Add command line option to specify preferred depth
  (bnc#893040, FATE#317582).
- drm/mgag200: Remove connector in sysfs when unloading the driver
  (bnc#876238, FATE#317582).
- drm/mgag200: Implement basic PM support (bnc#872213,
  FATE#317582).
- commit bc033a7
* Tue Nov  4 2014 mgalbraith@suse.de
- Update patch header.
  futex: Fix a race condition between REQUEUE_PI and task death
  (bcn#851603 (futex scalability series)).
- commit bc2eb07
* Mon Nov  3 2014 jeffm@suse.com
- xfs: fix cil push sequence after log recovery (bsc#755743).
- xfs: Don't reference the EFI after it is freed (bsc#755743).
- xfs: don't free EFIs before the EFDs are committed (bsc#755743).
- commit eca07fc
* Mon Nov  3 2014 jack@suse.cz
- block: Fix computation of merged request priority.
- commit 080a35b
* Mon Nov  3 2014 neilb@suse.de
- nfs: fix inverted test for delegation in nfs4_reclaim_open_state
  (bnc#903331).
- NFS: remove incorrect "Lock reclaim failed!" warning
  (bnc#903331).
- commit 371f97c
* Wed Oct 29 2014 hare@suse.de
- megaraid_sas: Disable fastpath writes for non-RAID0
  (bnc#897502).
- commit 8749dfd
* Tue Oct 28 2014 neilb@suse.de
- NFS: Provide stub nfs_fscache_wait_on_invalidate() for when
  CONFIG_NFS_FSCACHE=n.
- commit 6e066a5
* Tue Oct 28 2014 bpoirier@suse.de
- be2net: Fix invocation of be_close() after be_clear()
  (bnc#895468).
- commit 11ced17
* Tue Oct 28 2014 bp@suse.de
- PCI: pciehp: Clear Data Link Layer State Changed during init
  (bnc#898295).
- PCI: pciehp: Use symbolic constants, not hard-coded bitmask
  (bnc#898295).
- commit a66f400
* Tue Oct 28 2014 jbeulich@suse.com
- usbback: don't access request fields in shared ring more
  than once.
- x86_32, entry: Store badsys error code in %%eax (bnc#883724,
  CVE-2014-4508).
- x86: Add check for number of available vectors before CPU down
  (bnc#887418).
- x86, cpu hotplug: Fix stack frame warning
  incheck_irq_vectors_for_cpu_disable() (bnc#887418).
- Refresh patches.xen/xen-blkback-multi-page-ring (bnc#897708)).
- Refresh other Xen patches.
- commit 3644416
* Tue Oct 28 2014 mgalbraith@suse.de
- futex: Fix a race condition between REQUEUE_PI and task death
  (bcn #851603 (futex scalability series)).
- commit c21fc0a
* Fri Oct 24 2014 bp@suse.de
- PCI: pciehp: Use link change notifications for hot-plug and
  removal (bnc#898295).
- PCI: pciehp: Use per-slot workqueues to avoid deadlock
  (bnc#898295).
- PCI: pciehp: Handle push button event asynchronously
  (bnc#898295).
- PCI: pciehp: Make check_link_active() non-static (bnc#898295).
- PCI: pciehp: Enable link state change notifications
  (bnc#898295).
- commit 2f37faa
* Tue Oct 21 2014 dbueso@suse.de
- futex: Ensure get_futex_key_refs() always implies a barrier
  (bcn #851603 (futex scalability series)).
- commit 01182e8
* Mon Oct 20 2014 tiwai@suse.de
- drm/i915: Flush the PTEs after updating them before suspend
  (bnc#901638).
- drm/i915: Undo gtt scratch pte unmapping again (bnc#901638).
- commit ce5f9db
* Fri Oct 17 2014 brogers@suse.com
- KVM: x86: Sysexit emulation does not mask RIP/RSP (CVE-2014-3647
  bnc#899192).
- KVM: vmx: Inject #GP on invalid PAT CR (CVE-2014-3647
  bnc#899192).
- KVM: x86: emulating descriptor load misses long-mode case
  (CVE-2014-3647 bnc#899192).
- KVM: x86: Distinguish between stack operation and near branches
  (CVE-2014-3647 bnc#899192).
- KVM: x86: Use new is_noncanonical_address in _linearize
  (CVE-2014-3647 bnc#899192).
- KVM: x86: Handle errors when RIP is set during far jumps
  (CVE-2014-3647 bnc#899192).
- KVM: x86: Emulator fixes for eip canonical checks on near
  branches (CVE-2014-3647 bnc#899192).
- KVM: x86: Fix wrong masking on relative jump/call (CVE-2014-3647
  bnc#899192).
- KVM: x86: Warn if guest virtual address space is not 48-bits
  (CVE-2014-3647 bnc#899192).
- kvm: vmx: handle invvpid vm exit gracefully (CVE-2014-3646
  bnc#899192).
- KVM/x86: Improve thread safety in pit (CVE-2014-3647
  bnc#899192).
- KVM: x86: Check non-canonical addresses upon WRMSR
  (CVE-2014-3610 bnc#899192).
- kvm: iommu: fix the third parameter of kvm_iommu_put_pages
  (CVE-2014-3601) (CVE-2014-3601 bnc#892782).
- commit bd01911
* Thu Oct 16 2014 jkosina@suse.cz
- Refresh patches.kabi/kabi-hid-usage-index.patch -- add forgotten
  patch to series.conf
- commit 654ec6c
* Thu Oct 16 2014 mhocko@suse.cz
- kmod: make __request_module() killable (bnc#778463,
  CVE-2012-4398).
- kmod: introduce call_modprobe() helper (bnc#778463,
  CVE-2012-4398).
- usermodehelper: ____call_usermodehelper() doesn't need do_exit()
  (bnc#778463, CVE-2012-4398).
- usermodehelper: implement UMH_KILLABLE (bnc#778463,
  CVE-2012-4398).
- usermodehelper: introduce umh_complete(sub_info) (bnc#778463,
  CVE-2012-4398).
- usermodehelper: use UMH_WAIT_PROC consistently (bnc#778463,
  CVE-2012-4398).
- commit 654bee1
* Wed Oct 15 2014 jkosina@suse.cz
- HID: fix kabi breakage.
- commit 7482976
* Tue Oct 14 2014 fdmanana@suse.com
- Btrfs: limit delalloc pages outside of find_delalloc_range
  (bnc#898375).
- Btrfs: fix crash of compressed writes (bnc#898375).
- commit 2828dee
* Thu Oct  9 2014 bp@suse.de
- HID: picolcd_core: validate output report details (bnc#835839
  CVE-2013-2899).
- commit c10062d
* Thu Oct  9 2014 bp@suse.de
- HID: multitouch: validate indexes details
  (bnc#835839,CVE-2013-2897).
- HID: add usage_index in struct hid_usage (bnc#835839).
- commit 063d867
* Wed Oct  8 2014 mkubecek@suse.cz
- ipv6: fix a refcnt leak with peer addr (bnc#896415).
- ipv6: add support of peer address (bnc#896415).
- commit b5a096a
* Wed Oct  8 2014 neilb@suse.de
- ext3: return 32/64-bit dir name hash according to usage type
  (bnc#898554).
- nfsd: vfs_llseek() with 32 or 64 bit offsets (hashes)
  (bnc#898554).
- nfsd: rename 'int access' to 'int may_flags' in nfsd_open()
  (bnc#898554).
- ext4: return 32/64-bit dir name hash according to usage type
  (bnc#898554).
- fs: add new FMODE flags: FMODE_32bithash and FMODE_64bithash
  (bnc#898554).
- commit bedf117
* Mon Oct  6 2014 bp@suse.de
- HID: LG: validate HID output report details
  (bnc#835839,CVE-2013-2893).
- commit fa93b31
* Sat Oct  4 2014 mfasheh@suse.de
- fix: use after free of xfs workqueues (bnc#894895).
- commit dea32bb
* Thu Oct  2 2014 jroedel@suse.de
- PM / hibernate: Iterate over set bits instead of PFNs in
  swsusp_free() (bnc#860441).
- Revert "PM / Hibernate: Iterate over set bits instead of PFNs
  in swsusp_free()" (bnc#860441).
- commit 2d51816
* Tue Sep 30 2014 oneukum@suse.de
- usbhid: add another mouse that needs QUIRK_ALWAYS_POLL
  (bnc#888607).
- commit 317008c
* Mon Sep 29 2014 mgalbraith@suse.de
- sched: Fix unreleased llc_shared_mask bit during CPU hotplug (bnc#891368).
- commit 6e0b26a
* Wed Sep 24 2014 duwe@suse.de
- powerpc: Add smp_mb() to arch_spin_is_locked() (bsc#893758).
- powerpc: Implement arch_spin_is_locked() using
  arch_spin_value_unlocked() (bsc#893758).
- powerpc: Add support for the optimised lockref implementation
  (bsc#893758).
- powerpc: Add smp_mb()s to arch_spin_unlock_wait() (bsc#893758).
- commit b01dcae
* Wed Sep 24 2014 duwe@suse.de
- mm: change __remove_pages() to call
  release_mem_region_adjustable() (bnc#891790).
- resource: add __adjust_resource() for internal use (bnc#891790).
- resource: add release_mem_region_adjustable() (bnc#891790).
- commit 054c231
* Thu Sep 18 2014 dbueso@suse.de
- futex: Unlock hb->lock in futex_wait_requeue_pi() error path
  (fix bnc#880892).
- commit 44b8c95
* Thu Sep 18 2014 mhocko@suse.cz
- pagecachelimit: reduce lru_lock congestion for heavy parallel
  reclaim fix (bnc#895680).
- commit cb9fe08
* Wed Sep 17 2014 jack@suse.cz
- Update
  patches.fixes/udf-Avoid-infinite-loop-when-processing-indirect-ICB.patch
  (bnc#896689 CVE-2014-6410).
- commit c0c3b5f
* Wed Sep 17 2014 jack@suse.cz
- udf: Avoid infinite loop when processing indirect ICBs
  (bnc#896689).
- commit 733fbd1
* Mon Sep 15 2014 eich@suse.com
- drm/ast: Actually load DP501 firmware when required (bnc#895608
  bnc#871134).
- drm/ast: initial DP501 support (v0.2) (bnc#871134).
- drm/ast: open key before detect chips (bnc#895983).
- drm/ast: AST2000 cannot be detected correctly (bnc#895983).
- commit 3254d7b
* Mon Sep 15 2014 tiwai@suse.de
- ALSA: hda - Enabling Realtek ALC 671 codec (bnc#891746).
- commit 8184816
* Fri Sep 12 2014 eich@suse.de
- drm/i915: Fix up cpt pixel multiplier enable sequence
  (bnc#879304).
- commit a708175
* Fri Sep 12 2014 jroedel@suse.de
- x86, cpu hotplug: Fix stack frame warning in
  check_irq_vectors_for_cpu_disable() (bnc#887418).
- x86: Add check for number of available vectors before CPU down
  (bnc#887418).
- commit 3e94e66
* Thu Sep 11 2014 jdelvare@suse.de
- Update x86_64 config files: re-enable SENSORS_W83627EHF (bnc#891281)
  It was only enabled in i386 long ago because a customer asked for it,
  but now we have another customer who needs it on x86_64 too.
- commit 3c97549
* Wed Sep 10 2014 jack@suse.cz
- Update
  patches.fixes/isofs-Fix-unbounded-recursion-when-processing-reloca.patch
  (bnc#892490 CVE-2014-5472 CVE-2014-5471).
- commit a22a896
* Tue Sep  9 2014 dsterba@suse.cz
- Btrfs: fix a crash of clone with inline extents's split.
- Btrfs: fix EINVAL checks in btrfs_clone.
- btrfs: replace error code from btrfs_drop_extents.
- Btrfs: fix EIO on reading file after ioctl clone works on it.
- Btrfs: ensure readers see new data after a clone operation.
- Btrfs: clone, don't create invalid hole extent map.
- btrfs_ioctl_clone: Move clone code into it's own function.
- btrfs: abtract out range locking in clone ioctl().
- Btrfs: unlock inodes in correct order in clone ioctl.
- Delete
  patches.suse/btrfs-8270-fix-crash-when-starting-transaction.patch.
- commit 18d2be7
* Tue Sep  9 2014 ptesarik@suse.cz
- memcg: do not expose uninitialized mem_cgroup_per_node to world
  (bnc#883096).
- commit ae82607
* Tue Sep  9 2014 mhocko@suse.cz
- pagecache_limit: batch large nr_to_scan targets (bnc#895221).
- Refresh
  patches.fixes/mm-vmscan-store-priority-in-struct-scan_control.patch.
- commit a0b5f23
* Mon Sep  8 2014 dsterba@suse.cz
- Btrfs: unlock extent and pages on error in cow_file_range.
- Btrfs: cache extent states in defrag code path.
- Btrfs: fix deadlock with nested trans handles.
- btrfs: always choose work from prio_head first.
- Btrfs: correctly determine if blocks are shared in
  btrfs_compare_trees.
- btrfs: filter invalid arg for btrfs resize.
- Btrfs: balance delayed inode updates.
- Btrfs: fix leaf corruption after __btrfs_drop_extents.
- Btrfs: ensure btrfs_prev_leaf doesn't miss 1 item.
- Btrfs: handle a missing extent for the first file extent.
- Btrfs: remove unused wait queue in struct extent_buffer.
- Btrfs: fix race between balance recovery and root deletion.
- Btrfs: fix hang on error (such as ENOSPC) when writing extent
  pages.
- btrfs: replace EINVAL with ERANGE for resize when ULLONG_MAX.
- Btrfs: fix crash when starting transaction.
- Btrfs: fill_holes: Fix slot number passed to hole_mergeable()
  call.
- btrfs: Return right extent when fiemap gives unaligned offset
  and len.
- Btrfs: read lock extent buffer while walking backrefs.
- Btrfs: Fix wrong device size when we are resizing the device.
- Btrfs: fix wrong extent mapping for DirectIO.
- Btrfs: do not bug_on if we try to cow a free space cache inode.
- Refresh
  patches.suse/btrfs-8018-use-irqsave-spinlocks-everywhere.patch.
- commit 4181c7e
* Mon Sep  8 2014 jack@suse.cz
- patches.fixes/writeback-do-not-sync-data-dirtied-after-sync-start.patch:
  writeback: Do not sync data dirtied after sync start (bnc#833820).
- commit a82aaab
* Mon Sep  8 2014 oneukum@suse.de
- usbhid: fix PIXART optical mouse (bnc#888607).
- HID: usbhid: enable always-poll quirk for Elan Touchscreen
  (bnc#888607).
- HID: usbhid: add always-poll quirk (bnc#888607).
- commit d95573b
* Mon Sep  8 2014 neilb@suse.de
- One more fix for kABI breakage.
- commit f39e7b7
* Mon Sep  8 2014 neilb@suse.de
- Fix more kabi breakage with recent NFS fix (bnc#888968).
- commit a85afe7
* Mon Sep  8 2014 neilb@suse.de
- Fix kabi breakage with recent NFS fix (bnc#888968).
- commit 6165239
* Sat Sep  6 2014 tonyj@suse.de
- x86/uv/nmi: Fix Sparse warnings (bnc#888847).
- x86/UV: Add kdump to UV NMI handler (bnc#888847).
- x86/UV: Add call to KGDB/KDB from NMI handler (bnc#888847).
- x86/UV: Add summary of cpu activity to UV NMI handler
  (bnc#888847).
- x86/UV: Move NMI support (bnc#888847).
- x86/UV: Update UV support for external NMI signals (bnc#888847).
- Delete patches.arch/uv-update-nmi-handler-for-uv2.patch.
- commit 3ed86eb
* Fri Sep  5 2014 mmarek@suse.cz
- Update kabi files to reflect fscache change (bnc#880344)
- commit 5058e52
* Fri Sep  5 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-0006-fix-error-check-of-btrfs_lookup_dentry.patch.
- Refresh patches.suse/btrfs-8253-unset-DCACHE_DISCONNECTED-when-mounting-defaul.patch.
- commit 4436b67
* Fri Sep  5 2014 dsterba@suse.cz
- Update  patch tags.
- Btrfs: unset DCACHE_DISCONNECTED when mounting default subvol
  (bnc#866615).
- Btrfs: fix csum tree corruption, duplicate and outdated
  checksums (bnc#891619).
- Refresh
  patches.suse/btrfs-8007-lock-and-disable-irq-during-space-alloc.patch.
- Refresh
  patches.suse/btrfs-8021-add-btrfs-prefix-to-kernel-log-output.patch.
- Refresh
  patches.suse/btrfs-8135-Release-uuid_mutex-for-shrink-during-device-de.patch.
- Refresh
  patches.suse/btrfs-8136-fall-back-to-global-reservation-when-removing-.patch.
- Refresh
  patches.suse/btrfs-8137-fix-get-set-label-blocking-against-balance.patch.
- Refresh
  patches.suse/btrfs-8138-reset-ret-in-record_one_backref.patch.
- Refresh
  patches.suse/btrfs-8139-cleanup-reloc-roots-properly-on-error.patch.
- Refresh
  patches.suse/btrfs-8140-add-sanity-checks-regarding-to-parsing-mount-o.patch.
- Refresh
  patches.suse/btrfs-8141-use-u64-for-subvolid-when-parsing-mount-option.patch.
- Refresh
  patches.suse/btrfs-8142-add-missing-mounting-options-in-btrfs_show_opt.patch.
- Refresh
  patches.suse/btrfs-8143-don-t-bug_on-when-we-fail-when-cleaning-up-tra.patch.
- Refresh
  patches.suse/btrfs-8144-return-ENOSPC-when-target-space-is-full.patch.
- Refresh
  patches.suse/btrfs-8145-don-t-allow-a-subvol-to-be-deleted-if-it-is-th.patch.
- Refresh
  patches.suse/btrfs-8146-fix-the-error-handling-wrt-orphan-items.patch.
- Refresh
  patches.suse/btrfs-8147-add-missing-error-code-to-btrfs_IOC_INO_LOOKUP.patch.
- Refresh
  patches.suse/btrfs-8148-don-t-miss-inode-ref-items-in-btrfs_IOC_INO_LO.patch.
- Refresh
  patches.suse/btrfs-8149-fix-memory-leak-of-orphan-block-rsv.patch.
- Refresh
  patches.suse/btrfs-8150-fix-printing-of-non-NULL-terminated-string.patch.
- Refresh
  patches.suse/btrfs-8169-Simplify-the-logic-in-alloc_extent_buffer-for-.patch.
- Refresh
  patches.suse/btrfs-8170-deal-with-io_tree-mapping-being-NULL.patch.
- Refresh
  patches.suse/btrfs-8171-use-a-bit-to-track-if-we-re-in-the-radix-tree.patch.
- Refresh
  patches.suse/btrfs-8172-move-the-extent-buffer-radix-tree-into-the-fs_.patch.
- btrfs: Return EXDEV for cross file system snapshot.
- Btrfs: avoid warning bomb of btrfs_invalidate_inodes.
- btrfs: wake up transaction thread upon remount.
- Btrfs: fix a possible deadlock between scrub and transaction
  committing.
- Btrfs: cancel scrub on transaction abortion.
- Btrfs: wake up @scrub_pause_wait as much as we can.
- Btrfs: return EPERM when deleting a default subvolume
  (bnc#869934).
- Btrfs: abort the transaction when we don't find our extent ref.
- Btrfs: correctly set profile flags on seqlock retry.
- btrfs: make device scan less noisy.
- Btrfs: more efficient io tree navigation on wait_extent_bit.
- btrfs: retrieve more info from FS_INFO ioctl.
- btrfs: make DEV_INFO ioctl available to anyone.
- btrfs: make FS_INFO ioctl available to anyone.
- Btrfs: output warning instead of error when loading free space
  cache failed.
- Btrfs: fix possible memory leak in btrfs_create_tree().
- Btrfs: make sure there are not any read requests before
  stopping workers.
- Btrfs: fix double free in find_lock_delalloc_range.
- btrfs: free delayed node outside of root->inode_lock
  (bnc#866864).
- Btrfs: don't check nodes for extent items.
- Btrfs: use right type to get real comparison.
- btrfs: fix use of uninit "ret" in end_extent_writepage().
- Refresh
  patches.suse/btrfs-8252-fix-corruption-after-write-fsync-failure-fsync.patch.
- Delete
  patches.fixes/Btrfs-unset-DCACHE_DISCONNECTED-when-mounting-defaul.patch.
- Delete
  patches.suse/btrfs-9000-fix-csum-tree-corruption-duplicate-and-outdate.patch.
- commit 863ae5b
* Fri Sep  5 2014 jdelvare@suse.de
- net/mlx4_core: Load higher level modules according to ports type
  (bnc#887680).
- net/mlx4_core: Load the IB driver when the device supports IBoE
  (bnc#887680).
- commit 151ad21
* Fri Sep  5 2014 mkubecek@suse.cz
- net: fix checksumming features handling in output path
  (bnc#891259).
- commit ec141f3
* Fri Sep  5 2014 mhocko@suse.cz
- Update patches.suse/mm-hugetlb-fix-race-in-region-tracking.patch
  (Hugetlb Fault Scalability (fate#317271), bnc#892790).
- commit b84fe54
* Fri Sep  5 2014 jjolly@suse.de
- kernel: sclp console tty reference counting (bnc#891087,
  LTC#115466).
- kernel: 3215 tty hang (bnc#891087, LTC#114562).
- kernel: fix data corruption when reading /proc/sysinfo
  (bnc#891087, LTC#114480).
- dasd: validate request size before building CCW/TCW (bnc#891087,
  LTC#114068).
- commit fd1088f
* Thu Sep  4 2014 jslaby@suse.cz
- Update patches.kernel.org/patch-3.0.75-76 (CVE-2013-0160
  CVE-2013-1979 bnc#797175 bnc#815745 bnc#816708).
  Add references to one more CVE.
- commit 3ef14f9
* Thu Sep  4 2014 jjolly@suse.de
- IB/iser: Add TIMEWAIT_EXIT event handling (bnc#890297).
- commit 4957bde
* Wed Sep  3 2014 ohering@suse.de
- Drivers: hv: vmbus: Fix a bug in the channel callback dispatch
  code (bnc#886840).
- Drivers: hv: util: Fix a bug in the KVP code (bnc#886840).
- commit 42a848a
* Wed Sep  3 2014 neilb@suse.de
- NFSv4: Fix the return value of nfs4_select_rw_stateid
  (bnc#888968).
- NFSv4: nfs4_stateid_is_current should return 'true' for an
  invalid stateid (bnc#888968).
- NFSv4: Resend the READ/WRITE RPC call if a stateid change
  causes an error (bnc#888968).
- NFSv4: The stateid must remain the same for replayed RPC calls
  (bnc#888968).
- NFS: Clean up helper function nfs4_select_rw_stateid()
  (bnc#888968).
- NFSv4: Clean up nfs4_select_rw_stateid() (bnc#888968).
- NFS: Don't copy read delegation stateids in setattr
  (bnc#888968).
- NFSv4: Simplify the struct nfs4_stateid (bnc#888968).
- NFSv4: Add a helper for encoding stateids (bnc#888968).
- NFSv4: Add a helper for encoding opaque data (bnc#888968).
- NFSv4: Add helpers for basic copying of stateids (bnc#888968).
- NFSv4: Rename nfs4_copy_stateid() (bnc#888968).
- Don't use a delegation to open a file when returning that
  delegation (bnc#888968, bnc#892200, bnc#893596, bnc#893496)
- NFSv4 set open access operation call flag in
  nfs4_init_opendata_res (bnc#888968, bnc#892200,
  bnc#893596, bnc#893496).
- commit cc34334
* Fri Aug 29 2014 fdmanana@suse.com
- Btrfs: fix corruption after write/fsync failure + fsync +
  log recovery (bnc#894200).
- commit 26c7cde
* Fri Aug 29 2014 eich@suse.com
- drm/i915: Only apply DPMS to the encoder if enabled
  (bnc#893064).
- commit 6408baf
* Thu Aug 28 2014 tonyj@suse.de
- x86_32, entry: Clean up sysenter_badsys declaration (bnc#883724,
  CVE-2014-4508).
- commit b6c828e
* Thu Aug 28 2014 tonyj@suse.de
- x86_32, entry: Store badsys error code in %%eax (bnc#883724,
  CVE-2014-4508).
- commit 8ed1359
* Wed Aug 27 2014 jack@suse.cz
- patches.fixes/isofs-Fix-unbounded-recursion-when-processing-reloca.patch:
  Update references
- commit 22deff5
* Tue Aug 26 2014 neilb@suse.de
- Delete
  patches.suse/0013-NFS-nfs4_do_open-should-add-negative-results-to-the-.patch.
  Not needed in SLES11 - only needed in mainline (where it is).
- commit da9b0be
* Tue Aug 26 2014 neilb@suse.de
- Update patches.fixes/nfs-mountpoint-deleted.patch (bnc#888591,
  bnc#891485).
  More complete fix for this bug.
- commit f276f01
* Mon Aug 25 2014 mhocko@suse.cz
- be2net: add dma_mapping_error() check for dma_map_page()
  (bnc#881759).
- commit 5dc79da
* Sat Aug 23 2014 eich@suse.com
- drm/ast: Add reduced non reduced mode parsing for wide screen
  mode (bnc#892723).
- drm/ast: Add missing entry to dclk_table[].
- commit b23160f
* Fri Aug 22 2014 mgalbraith@suse.de
- Delete patches.fixes/watchdog-make-disable-enable-hotplug-and-preempt-save.patch.
  kthread_stop()/kthread_create_on_node() cannot be called with preemption disabled
- commit 5ec8d9d
* Thu Aug 21 2014 jack@suse.cz
- isofs: Fix unbounded recursion when processing relocated
  directories (bnc#892490).
- commit d3aa404
* Thu Aug 21 2014 lduncan@suse.com
- target/rd: Refactor rd_build_device_space +
  rd_release_device_space (bnc#882639).
- commit 52d9ab6
* Wed Aug 20 2014 neilb@suse.de
- autofs4: make "autofs4_can_expire" idempotent (bnc#866130).
- commit a8a5e25
* Wed Aug 20 2014 neilb@suse.de
- Update
  patches.fixes/md-raid6-avoid-data-corruption-during-recovery-of-do.patch
  (bnc#892650).
  Improve comment.
- commit e3136ad
* Tue Aug 19 2014 jroedel@suse.de
- PM / Hibernate: Touch Soft Lockup Watchdog in rtree_next_node
  (bnc#860441).
- PM / Hibernate: Remove the old memory-bitmap implementation
  (bnc#860441).
- PM / Hibernate: Iterate over set bits instead of PFNs in
  swsusp_free() (bnc#860441).
- PM / Hibernate: Implement position keeping in radix tree
  (bnc#860441).
- PM / Hibernate: Add memory_rtree_find_bit function (bnc#860441).
- PM / Hibernate: Create a Radix-Tree to store memory bitmap
  (bnc#860441).
- commit 6f93dc2
* Tue Aug 19 2014 neilb@suse.de
- NFS: avoid mountpoint being " (deleted)" in /proc/mounts
  (bnc#888591).
- commit 332e140
* Mon Aug 18 2014 neilb@suse.de
- md/raid6: avoid data corruption during recovery of
  double-degraded RAID6.
- commit 7a83069
* Fri Aug 15 2014 tiwai@suse.de
- [media] media-device: fix infoleak in ioctl
  media_enum_entities() (bnc#882804,CVE-2014-1739).
- commit 4201858
* Fri Aug 15 2014 duwe@suse.de
- restore smp_mb() in unlock_new_inode() (bnc#890526).
- commit 2ce5ff3
* Wed Aug 13 2014 jbohac@suse.cz
- net/l2tp: don't fall back on UDP [get|set]sockopt (bnc#887082,
  CVE-2014-4943).
- commit 8b5563c
* Wed Aug 13 2014 duwe@suse.de
- patches.fixes/crypto-fips-only-panic-on-bad-missing-crypto-mod-signatures :
  Allow CRYPTO_FIPS without MODULE_SIGnatures. Not all archs have them,
  but some are FIPS certified, with some kernel support.
- commit a1eae33
* Wed Aug 13 2014 fdmanana@suse.com
- Btrfs: fix csum tree corruption, duplicate and outdated
  checksums (bnc#891619).
  This fixes a bug that's been around for 7 years in btrfs, as
  Chris Mason mentioned [1], so it affects a wide range of SLES
  and openSUSE releases.
  [1] http://www.spinics.net/lists/linux-btrfs/msg36525.html
- commit 5a10429
* Tue Aug 12 2014 bpoirier@suse.de
- e1000e: enable support for new device IDs (bnc#885509).
- commit 18b3ff2
* Tue Aug 12 2014 duwe@suse.de
- crypto: fips - only panic on bad/missing crypto mod signatures
  (bnc#887503).
- commit c1a9b4f
* Tue Aug 12 2014 jbohac@suse.cz
- supported.conf: support net/sched/act_police.ko (bnc#890426)
- commit eb1d46a
* Tue Aug 12 2014 tiwai@suse.de
- drm/i915: clear the FPGA_DBG_RM_NOCLAIM bit at driver init
  (bnc#869055).
- drm/i915: use FPGA_DBG for the "unclaimed register" checks
  (bnc#869055).
- drm/i915: create functions for the "unclaimed register" checks
  (bnc#869055).
- commit e0b4e08
* Mon Aug 11 2014 jroedel@suse.de
- PCI: enable MPS "performance" setting to properly handle bridge MPS (bnc#883376).
- commit f2eef9d
* Mon Aug 11 2014 neilb@suse.de
- Allow more operations in an NFSv4.1 request (bnc#890513).
- commit f6d0b39
* Fri Aug  8 2014 jbeulich@suse.com
- scsiback: correct grant page unmapping.
- scsiback: fix retry handling in __report_luns().
- scsiback: free resources after error.
- vscsi: support larger transfer sizes (bnc#774818).
- Refresh other Xen patches.
- commit 021ff16
* Thu Aug  7 2014 mhocko@suse.cz
- memcg, vmscan: Fix forced scan of anonymous pages (memory
  reclaim fix).
- Refresh
  patches.fixes/mm-vmscan-store-priority-in-struct-scan_control.patch.
- Refresh
  patches.suse/mm-vmscan-Do-not-force-reclaim-file-pages-until-it-exceeds-anon.patch.
- Refresh
  patches.suse/mm-vmscan-Update-rotated-and-scanned-when-force-reclaimed.patch.
- commit 6823cfe
* Tue Aug  5 2014 neilb@suse.de
- autofs: fix lockref lookup (bnc#888591).
- commit 69a9444
* Mon Aug  4 2014 spargaonkar@suse.com
- qla2xxx: Set host can_queue value based on available resources
  (bnc#859840).
- commit 3ccd6a7
* Mon Aug  4 2014 spargaonkar@suse.com
- qla2xxx: Issue abort command for outstanding commands during
  cleanup when only firmware is alive (bnc#859840).
- commit 9a365c5
* Mon Aug  4 2014 spargaonkar@suse.com
- qla2xxx: Avoid escalating the SCSI error handler if the command
  is not found in firmware (bnc#859840).
- commit adefe9e
* Mon Aug  4 2014 spargaonkar@suse.com
- qla2xxx: Clear loop_id for ports that are marked lost during
  fabric scanning  (bnc#859840).
- commit e41f594
* Mon Aug  4 2014 spargaonkar@suse.com
- qla2xxx: Reduce the time we wait for a command to complete
  during SCSI error handling (bnc#859840).
- commit 8585578
* Mon Aug  4 2014 spargaonkar@suse.com
- qla2xxx: Don't check for firmware hung during the
  reset context for ISP82XX (bnc#859840).
- commit ceb58c4
* Mon Aug  4 2014 spargaonkar@suse.com
- scripts/log: uses bashisms so should explicitly call bash
  scripts/log2: uses bashisms so should explicitly call bash
    On non-SUSE systems, other shells may be used as /bin/sh. This has
    been observed to cause runtime failures.
- commit e2f2cf1
* Mon Aug  4 2014 jjolly@suse.de
- [FEAT NET1222] ib_uverbs: Allow explicit mmio trigger
  (FATE#83366, ltc#83367).
- commit 5a748b8
* Mon Aug  4 2014 neilb@suse.de
- Refresh
  patches.suse/0002-NFS-prepare-for-RCU-walk-support-but-pushing-tests-l.patch.
- Refresh
  patches.suse/0005-NFS-teach-nfs_neg_need_reval-to-understand-LOOKUP_RC.patch.
  Fixes for NFS RCU-walk support in line with code going upstream
- commit c6b12b2
* Mon Aug  4 2014 neilb@suse.de
- NFS: Use FS-Cache invalidation (bnc#880344).
- commit f6ea50b
* Fri Aug  1 2014 ptesarik@suse.cz
- cpuset: Fix memory allocator deadlock (bnc#876590).
- commit aa2819e
* Fri Aug  1 2014 ptesarik@suse.cz
- block: fix race between request completion and timeout handling
  (bnc#881051).
- commit 2ade659
* Fri Aug  1 2014 hare@suse.de
- scsi_dh: use missing accessor 'scsi_device_from_queue'
  (bnc#889614).
- commit 7e46e5a
* Fri Aug  1 2014 jkosina@suse.cz
- crypto: testmgr - allow aesni-intel and ghash_clmulni-intel
  in fips mode (bnc#889451).
- commit 0f53a3f
* Thu Jul 31 2014 ohering@suse.de
- supported.conf: remove external from drivers/net/veth (bnc#889727)
- commit 456ffd4
* Thu Jul 31 2014 jkosina@suse.cz
- Refresh patches.fixes/input-add-acer-aspire-5710-to-nomux.patch: update
  upstream reference.
- commit 41e0146
* Thu Jul 31 2014 jlee@suse.com
- Update
  patches.suse/0004-EFI-Add-in-kernel-variable-to-determine-if-Secure-Boot-is-enabled.patch
  (fate#314574, bnc#884333).
- commit 4815e8e
* Thu Jul 31 2014 jlee@suse.com
- Respin xen patches for backpoprted new patches of  Lock down functions for UEFI secure boot
  Respin xen patches for backpoprted new patches of  Lock down functions
  for UEFI secure boot (fate#314486, bnc#884333).
- Refresh patches.xen/xen-x86-EFI.
- Refresh
  patches.xen/xen3-0003_x86_Lock_down_IO_port_access_in_secure_boot_environments_v2.patch.
- Refresh
  patches.xen/xen3-0004-EFI-Add-in-kernel-variable-to-determine-if-Secure-Boot-is-enabled.patch.
- Refresh
  patches.xen/xen3-0006_Restrict__dev_mem_and__dev_kmem_in_secure_boot_setups_v2.patch.
- Refresh
  patches.xen/xen3-0008_efi_Enable_secure_boot_lockdown_automatically_when_enabled_in_firmware_v2.patch.
- Refresh
  patches.xen/xen3-x86_microcode_set_comprise_kernel.patch.
- commit 60d0ce9
* Thu Jul 31 2014 jlee@suse.com
- Backpoprted new patches of  Lock down functions for UEFI secure boot
  Also updated series.conf and removed old patches.
- Add secure_modules() call (fate#314486, bnc#884333).
- PCI: Lock down BAR access when module security is enabled
  (fate#314486, bnc#884333).
- x86: Lock down IO port access when module security is enabled
  (fate#314486, bnc#884333).
- ACPI: Limit access to custom_method (fate#314486, bnc#884333).
- asus-wmi: Restrict debugfs interface when module loading is
  restricted (fate#314486, bnc#884333).
- Restrict /dev/mem and /dev/kmem when module loading is
  restricted (fate#314486, bnc#884333).
- acpi: Ignore acpi_rsdp kernel parameter when module loading
  is restricted (fate#314486, bnc#884333).
- kexec: Disable at runtime if the kernel enforces module loading
  restrictions (fate#314486, bnc#884333).
- uswsusp: Disable when module loading is restricted (fate#314486,
  bnc#884333).
- x86: Restrict MSR access when module loading is restricted
  (fate#314486, bnc#884333).
- Add option to automatically enforce module signatures when in
  Secure Boot mode (fate#314486, bnc#884333).
- hibernate: Disable in a signed modules environment (fate#314486,
  bnc#884333).
- Delete
  patches.suse/0001-modsign-Always-enforce-module-signing-in-a-Secure-Boot.patch.
- Delete
  patches.suse/0002_PCI_Lock_down_BAR_access_in_secure_boot_environments_v2.patch.
- Delete
  patches.suse/0003_x86_Lock_down_IO_port_access_in_secure_boot_environments_v2.patch.
- Delete
  patches.suse/0004_ACPI_Limit_access_to_custom_method_v2.patch.
- Delete
  patches.suse/0005_asus-wmi_Restrict_debugfs_interface_v2.patch.
- Delete
  patches.suse/0006_Restrict__dev_mem_and__dev_kmem_in_secure_boot_setups_v2.patch.
- Delete
  patches.suse/0008_efi_Enable_secure_boot_lockdown_automatically_when_enabled_in_firmware_v2.patch.
- Delete
  patches.suse/0009_acpi_Ignore_acpi_rsdp_kernel_parameter_in_a_secure_boot_environment_v2.patch.
- Delete
  patches.suse/0011-hibernate-Disable-in-a-Secure-Boot-environment.patch.
- Delete
  patches.suse/kexec-Disable-in-a-secure-boot-environment.patch.
- Delete
  patches.suse/x86-Require-CAP_COMPROMISE_KERNEL-for-MSR-writing.patch.
- Delete patches.suse/x86_microcode_set_comprise_kernel.patch.
- commit f3af2f2
* Tue Jul 29 2014 jjolly@suse.de
- s390/pci: introduce lazy IOTLB flushing for DMA unmap
  (bnc#889061, LTC#113725).
- kernel: fix kernel oops with load of fpc register (bnc#889061,
  LTC#113596).
- commit 51a83f6
* Tue Jul 29 2014 bpoirier@suse.de
- net: sctp: inherit auth_capable on INIT collisions (bnc#889173
  CVE-2014-5077).
- commit f647115
* Mon Jul 28 2014 mmarek@suse.cz
- Import kabi files for kernel-bigsmp
- commit 8ca35c8
* Mon Jul 28 2014 oneukum@suse.de
- cdc-ether: clean packet filter upon probe (bnc#876017).
- commit e59819a
* Mon Jul 28 2014 hare@suse.de
- dm-mpath: fix panic on deleting sg device (bnc#870161).
- commit a3e218d
* Mon Jul 28 2014 hare@suse.de
- dm mpath: fix race condition between multipath_dtr and
  pg_init_done (bnc#826486).
- commit 39aa039
* Mon Jul 28 2014 jjolly@suse.de
- Delete
  patches.arch/s390-sles11sp3-17-01-uverbs-kwrite-mmio.patch.
- bnc#802775
- commit f7edda2
* Fri Jul 25 2014 bpoirier@suse.de
- tg3: Change nvram command timeout value to 50ms (bnc#855657).
- tg3: Override clock, link aware and link idle mode during
  NVRAM dump (bnc#855657).
- tg3: Set the MAC clock to the fastest speed during boot code
  load (bnc#855657).
- commit 62abd53
* Fri Jul 25 2014 oneukum@suse.de
- usbcore: don't log on consecutive debounce failures of the
  same port (bnc#888105).
- commit 867a600
* Fri Jul 25 2014 mhocko@suse.cz
- mm, thp: do not allow thp faults to avoid cpuset restrictions
  (bnc#888849).
- commit 12848b1
* Fri Jul 25 2014 mkubecek@suse.cz
- ipv6: tcp: fix tcp_v6_conn_request() (bnc#887645).
- commit 1355551
* Thu Jul 24 2014 neilb@suse.de
- Fix 0006-NFS-teach-nfs_lookup_verify_inode-to-handle-LOOKUP_R.patch
  Didn't interact will with another recent patch
- commit 371255b
* Thu Jul 24 2014 vbabka@suse.cz
- shmem: fix faulting into a hole, not taking i_mutex (bnc#883518,
  CVE-2014-4171).
- shmem: fix splicing from a hole while it's punched (bnc#883518,
  CVE-2014-4171).
- Delete
  patches.fixes/shmem-fix-faulting-into-a-hole-while-its-punched-take-2.patch.
- commit 634b83f
* Thu Jul 24 2014 neilb@suse.de
- Fix kabi breakage with previous patches.
- commit 0294808
* Thu Jul 24 2014 neilb@suse.de
- NFS: nfs4_do_open should add negative results to the dcache
  (bnc#866130).
- autofs4: don't take spinlock when not needed in
  autofs4_lookup_expiring (bnc#866130).
- autofs4: avoid taking fs_lock during rcu-walk (bnc#866130).
- autofs4: factor should_expire() out of autofs4_expire_indirect
  (bnc#866130).
- autofs4: allow RCU-walk to walk through autofs4 (bnc#866130).
- autofs4: remove a redundant assignment (bnc#866130).
- NFS: allow lockless access to access_cache (bnc#866130).
- NFS: teach nfs_lookup_verify_inode to handle LOOKUP_RCU
  (bnc#866130).
- NFS: teach nfs_neg_need_reval to understand LOOKUP_RCU
  (bnc#866130).
- NFS: support RCU_WALK in nfs_permission() (bnc#866130).
- sunrpc/auth: allow lockless (rcu) lookup of credential cache
  (bnc#866130).
- NFS: prepare for RCU-walk support but pushing tests later in
  code (bnc#866130).
- NFS: nfs_open_revalidate: only evaluate parent if it will be
  used (bnc#866130).
- commit ef1de82
* Wed Jul 23 2014 duwe@suse.de
- net/mlx4_en: Fix selftest failing on non 10G link speed
  (bnc#888058).
- ibmvscsi: Add memory barriers for send / receive (bnc#885382).
- ibmvscsi: Abort init sequence during error recovery
  (bnc#885382).
- commit d93e8e3
* Thu Jul 17 2014 hare@suse.de
- scsi_transport_fc: Cap dev_loss_tmo by fast_io_fail
  (bnc#887608).
- commit 977ac64
* Wed Jul 16 2014 mgorman@suse.de
- hugetlb: don't use ERR_PTR with VM_FAULT* values
- mm, hugetlb: add VM_NORESERVE check in vma_has_reserves()
- mm, hugetlb: change variable name reservations to resv
- mm, hugetlb: decrement reserve count if VM_NORESERVE alloc page cache
- mm: hugetlb: defer freeing pages when gathering surplus pages
- mm, hugetlb: do not use a page in page cache for cow optimization
- mm, hugetlb: fix and clean-up node iteration code to alloc or free
- mm, hugetlb: fix race in region tracking
- mm, hugetlb: fix subpool accounting handling
- mm, hugetlb: improve, cleanup resv_map parameters
- mm, hugetlb: improve page-fault scalability
- mm, hugetlb: move up the code which check availability of free huge page
- mm, hugetlb: protect reserved pages when soft offlining a hugepage
- mm, hugetlb: remove decrement_hugepage_resv_vma()
- mm, hugetlb: remove redundant list_empty check in gather_surplus_pages()
- mm, hugetlb: remove resv_map_put
- mm, hugetlb: remove useless check about mapping type
- mm, hugetlb: return a reserved page to a reserved pool if failed
- mm, hugetlb: trivial commenting fix
- mm, hugetlb: unify region structure handling kabi
- mm, hugetlb: unify region structure handling
- mm, hugetlb: use vma_resv_map() map types
- mm/hugetlb.c: use long vars instead of int in region_count()
  (Hugetlb Fault Scalability (fate#317271)).
- commit 28f38bd
* Tue Jul 15 2014 bpoirier@suse.de
- net/mlx4_en: Fix a race between napi poll function and RX ring
  cleanup (bnc#863586).
- commit cfac2f9
* Mon Jul 14 2014 mkubecek@suse.cz
- kabi: hide bnc#860593 changes of struct inetpeer_addr_base
  (bnc#860593).
- inetpeer: initialize ->redirect_genid in inet_getpeer()
  (bnc#860593).
- inet: add a redirect generation id in inetpeer (bnc#860593).
- commit bdb98b5
* Thu Jul 10 2014 mgorman@suse.de
- Refresh patches.suse/perf-core-add-weighted-samples.patch for series2git.
- commit 0945cd7
* Thu Jul 10 2014 oneukum@suse.de
- USB: handle LPM errors during device suspend correctly
  (bnc#849123).
- commit 79f8b30
* Thu Jul 10 2014 jjolly@suse.de
- af_iucv: correct cleanup if listen backlog is full (bnc#885262,
  LTC#111728).
- sclp_vt220: Enable integrated ASCII console per default
  (bnc#885262, LTC#112035).
- commit e5e00e5
* Wed Jul  9 2014 mkubecek@suse.cz
- tcp: adapt selected parts of RFC 5682 and PRR logic
  (bnc#879921).
- Refresh
  patches.fixes/tcp-allow-to-disable-cwnd-moderation-in-TCP_CA_Loss-.patch.
- commit 7dd7926
* Wed Jul  9 2014 jslaby@suse.cz
- Refresh patches.fixes/dlm-abort-listening-connection.patch.
  The hunk was misplaced: nodeid was used before check.
- commit c36987d
* Tue Jul  8 2014 jbohac@suse.cz
- sctp: Fix sk_ack_backlog wrap-around problem (bnc#885422,
  CVE-2014-4667).
- commit fde331e
* Mon Jul  7 2014 oneukum@suse.de
- usb: Don't enable LPM if the exit latency is zero (bnc#832309).
- commit b43e26e
* Fri Jul  4 2014 vbabka@suse.cz
- shmem: fix faulting into a hole while it's punched, take 2
  (bnc#883518, CVE-2014-4171).
- commit df18687
* Fri Jul  4 2014 jbeulich@suse.com
- x86_32, entry: Do syscall exit work on badsys (CVE-2014-4508)
  (bnc#883724, CVE-2014-4508).
- commit e42f120
* Fri Jul  4 2014 mhocko@suse.cz
- ptrace,x86: force IRET path after a ptrace_stop() (bnc#885725,
  CVE-2014-4699).
- commit 451cc04
* Thu Jul  3 2014 mhocko@suse.cz
- Refresh
  patches.suse/pagecache-limit-reduce-zone-lrulock-bouncing.patch.
  Fixed UNINTERRUPTIBLE sleep vs. INTERRUPTIBLE wakeup
- commit f33ae02
* Thu Jul  3 2014 jdelvare@suse.de
- Add bug reference (bnc#879695)
- commit 67c18f1
* Thu Jul  3 2014 tonyj@suse.de
- x86_32, entry: Do syscall exit work on badsys (CVE-2014-4508)
  (bnc#883724, CVE-2014-4508).
- commit 0a52197
* Wed Jul  2 2014 mgalbraith@suse.de
- sched: fix the theoretical signal_wake_up() vs schedule() race (bnc#876055).
- commit 90f5625
* Wed Jul  2 2014 neilb@suse.de
- block: add cond_resched() to potentially long running ioctl
  discard loop (bnc#884725).
- commit 1a1fdb2
* Wed Jul  2 2014 neilb@suse.de
- NFSD: Don't hand out delegations for 30 seconds after recalling
  them (bnc#880370).
- commit 756294d
* Tue Jul  1 2014 eich@suse.com
- drm/mgag200: Initialize data needed to map fbdev memory
  (bnc #806990).
- Refresh
  patches.drm/drm-mgag200-Fix-framebuffer-pitch-calculation.patch.
- Delete
  patches.drm/drm-mgag200-Initialized-data-needed-to-map-fbdev-memory.patch.
- commit fef48ec
* Mon Jun 30 2014 jdelvare@suse.de
- x86 thermal: Re-enable power limit notification interrupt by
  default (bnc#882317).
- x86 thermal: Disable power limit notification interrupt by
  default (bnc#882317).
- x86 thermal: Delete power-limit-notification console messages
  (bnc#882317).
- commit 49797c6
* Mon Jun 30 2014 trenn@suse.de
- ACPI / PAD: call schedule() when need_resched() is true
  (bnc#866911).
- commit 322718e
* Mon Jun 30 2014 neilb@suse.de
- CacheFiles: Don't try to dump the index key if the cookie has
  been cleared (bnc#880344).
- FS-Cache: Don't use spin_is_locked() in assertions (bnc#880344).
- FS-Cache: The retrieval remaining-pages counter needs to be
  atomic_t (bnc#880344).
- FS-Cache: Simplify cookie retention for fscache_objects,
  fixing oops (bnc#880344).
- Fix __wait_on_atomic_t() to call the action func if the counter
  != 0 (bnc#880344).
- Add wait_on_atomic_t() and wake_up_atomic_t() (bnc#880344).
- FS-Cache: Fix object state machine to have separate work and
  wait states (bnc#880344).
- FS-Cache: Wrap checks on object state (bnc#880344).
- FS-Cache: Uninline fscache_object_init() (bnc#880344).
- FS-Cache: Don't sleep in page release if __GFP_FS is not set
  (bnc#880344).
- fs/fscache: remove spin_lock() from the condition in while()
  (bnc#880344).
- FS-Cache: Clear remaining page count on retrieval cancellation
  (bnc#880344).
- FS-Cache: Mark cancellation of in-progress operation
  (bnc#880344).
- FS-Cache: One of the write operation paths doesn't set the
  object state (bnc#880344).
- FS-Cache: Fix signal handling during waits (bnc#880344).
- FS-Cache: Add transition to handle invalidate immediately
  after lookup (bnc#880344).
- NFS: nfs_migrate_page() does not wait for FS-Cache to finish
  with a page (bnc#880344).
- FS-Cache: Exclusive op submission can BUG if there's been an
  I/O error (bnc#880344).
- FS-Cache: Limit the number of I/O error reports for a cache
  (bnc#880344).
- FS-Cache: Initialise the object event mask with the calculated
  mask (bnc#880344).
- FS-Cache: Convert the object event ID #defines into an enum
  (bnc#880344).
- CacheFiles: Add missing retrieval completions (bnc#880344).
- CacheFiles: Implement invalidation (bnc#880344).
- VFS: Make more complete truncate operation available to
  CacheFiles (bnc#880344).
- FS-Cache: Provide proper invalidation (bnc#880344).
- FS-Cache: Fix operation state management and accounting
  (bnc#880344).
- FS-Cache: Make cookie relinquishment wait for outstanding reads
  (bnc#880344).
- CacheFiles: Make some debugging statements conditional
  (bnc#880344).
- FS-Cache: Check that there are no read ops when cookie
  relinquished (bnc#880344).
- CacheFiles: Downgrade the requirements passed to the allocator
  (bnc#880344).
- CacheFiles: Fix the marking of cached pages (bnc#880344).
- commit 49fab4a
* Sun Jun 29 2014 bp@suse.de
- ACPI: Fix bug when ACPI reset register is implemented in system
  memory (bnc#882900).
- commit 95930dc
* Sat Jun 28 2014 tonyj@suse.de
- Ignore 'flags' change to event_constraint (bnc#876114,
  fate#317174).
- Reuse existing 'state' field to indicate
  PERF_X86_EVENT_PEBS_LDLAT (bnc#876114, fate#317174).
- Ignore 'data_src'/'weight' changes to perf_sample_data
  (bnc#876114, fate#317174).
- perf: Add generic memory sampling interface (bnc#876114,
  fate#317174).
- perf/core: Add weighted samples (bnc#876114, fate#317174).
- perf/x86: Add flags to event constraints (bnc#876114,
  fate#317174).
- perf/x86: Add memory profiling via PEBS Load Latency
  (bnc#876114, fate#317174).
- Refresh
  patches.fixes/perf-x86-fix-offcore_rsp-valid-mask-for-snb-ivb.patch.
- commit 30c4a1f
* Fri Jun 27 2014 mhocko@suse.cz
- mm, oom: fix badness score underflow (bnc#884582, bnc#884767).
- mm, oom: normalize oom scores to oom_score_adj scale only for
  userspace (bnc#884582, bnc#884767).
- commit cb351f4
* Thu Jun 26 2014 tiwai@suse.de
- Update references
  patches.drivers/alsa-0001-control-Protect-user-controls-against-concurren
  (CVE-2014-4652,bnc#883795)
  patches.drivers/alsa-0002-control-Fix-replacing-user-controls
  (CVE-2014-4654,CVE-2014-4655,bnc#883795)
  patches.drivers/alsa-0003-control-Don-t-access-controls-outside-of-protec
  (CVE-2014-4653,bnc#883795)
  patches.drivers/alsa-0004-control-Handle-numid-overflow
  (CVE-2014-4656,bnc#883795)
  patches.drivers/alsa-0005-control-Make-sure-that-id-index-does-not-overfl
  (CVE-2014-4656,bnc#883795)
- commit 38d0c15
* Wed Jun 25 2014 jbohac@suse.cz
- ipv6: don't set DST_NOCOUNT for remotely added routes
  (bnc#867531, CVE-2014-2309).
- commit 83968af
* Wed Jun 25 2014 mmarek@suse.cz
- rpm/config.sh: Build in the OBS against SUSE:SLE-11:SP3
- commit 9f5fcdc
* Wed Jun 25 2014 tiwai@suse.de
- Fix kABI breakage due to addition of user_ctl_lock (bnc#883795).
- ALSA: control: Make sure that id->index does not overflow
  (bnc#883795).
- ALSA: control: Handle numid overflow (bnc#883795).
- ALSA: control: Don't access controls outside of protected
  regions (bnc#883795).
- ALSA: control: Fix replacing user controls (bnc#883795).
- ALSA: control: Protect user controls against concurrent access
  (bnc#883795).
- commit cb2a85d
* Tue Jun 24 2014 jbohac@suse.cz
- drivers/rtc/interface.c: fix infinite loop in initializing
  the alarm (bnc#871676).
- commit 268aaef
* Tue Jun 24 2014 mkubecek@suse.cz
- Revert "udp: remove redundant variable" (bnc#881171).
- commit e330dcd
* Mon Jun 23 2014 duwe@suse.de
- bnx2x: Fix kernel crash and data miscompare after EEH recovery
  (bnc#881761).
- bnx2x: Adapter not recovery from EEH error injection
  (bnc#881761).
- commit 31c3af5
* Mon Jun 23 2014 eich@suse.com
- drm/ast: Fix double lock at PM resume (bnc#883380).
- drm/ast: add widescreen + rb modes from X.org driver (v2)
  (bnc#883380).
- drm/ast: deal with bo reserve fail in dirty update path
  (bnc#883380).
- drm/ast: do not attempt to acquire a reservation while in an
  interrupt handler (bnc#883380).
- drm/ast: fix the ast open key function (bnc#883380).
- drm/ast: fix value check in cbr_scan2 (bnc#883380).
- drm/ast: inline reservations (bnc#883380).
- drm/ast: invalidate page tables when pinning a BO (bnc#883380).
- drm/ast: rename the mindwm/moutdwm and deinline them
  (bnc#883380).
- drm/ast: resync the dram post code with upstream (bnc#883380).
- drm: ast: use drm_can_sleep (bnc#883380).
- drm/ast: use drm_modeset_lock_all (bnc#883380).
- drm/<drivers>: Unified handling of unimplemented
  fb->create_handle (bnc#883380).
- drm/mgag200,ast,cirrus: fix regression with drm_can_sleep
  conversion (bnc#883380).
- Update patches.drm/drm-ast-add-AST-2400-support.patch
  (bnc#883380).
- commit dc3e71b
* Mon Jun 23 2014 dsterba@suse.cz
- Btrfs: fix a crash when running balance and defrag concurrently.
- Delete patches.suse/btrfs-8165-fix-negative-qgroup-tracking-from-owher.patch.
- commit d1ad835
* Mon Jun 23 2014 mmarek@suse.cz
- dlm: keep listening connection alive with sctp mode (bnc#881939)
- commit 417dabc
* Fri Jun 20 2014 eich@suse.com
- drm/mgag200: Consolidate depth/bpp handling (bnc#882324).
- Delete
  patches.drm/drm-mgag200-on-cards-with-2MB-VRAM-default-to-16-bit.patch.
- Add
  patches.drm/drm-mgag200-Consolidate-depth-bpp-handling.patch.
- commit bf1f113
* Fri Jun 20 2014 mmarek@suse.cz
- series.conf: Clarify comment about Xen kabi adjustments (bnc#876114#c25)
- commit 02b03f7
* Fri Jun 20 2014 dsterba@suse.cz
- patches.suse/btrfs-8250-fix-use-of-uninit-ret-in-end_extent_writepage.patch:
- patches.suse/btrfs-8249-use-right-type-to-get-real-comparison.patch:
- patches.suse/btrfs-8248-don-t-check-nodes-for-extent-items.patch:
- patches.suse/btrfs-8247-free-delayed-node-outside-of-root-inode_lock.patch:
  (bnc#866864).
- patches.suse/btrfs-8245-fix-double-free-in-find_lock_delalloc_range.patch:
- patches.suse/btrfs-8242-make-sure-there-are-not-any-read-requests-befo.patch:
- patches.suse/btrfs-8241-fix-possible-memory-leak-in-btrfs_create_tree.patch:
- patches.suse/btrfs-8240-output-warning-instead-of-error-when-loading-f.patch:
- patches.suse/btrfs-8239-make-FS_INFO-ioctl-available-to-anyone.patch:
- patches.suse/btrfs-8238-make-DEV_INFO-ioctl-available-to-anyone.patch:
- patches.suse/btrfs-8236-retrieve-more-info-from-FS_INFO-ioctl.patch:
- patches.suse/btrfs-8234-more-efficient-io-tree-navigation-on-wait_exte.patch:
- patches.suse/btrfs-8233-make-device-scan-less-noisy.patch:
- patches.suse/btrfs-8231-correctly-set-profile-flags-on-seqlock-retry.patch:
- patches.suse/btrfs-8230-abort-the-transaction-when-we-don-t-find-our-e.patch:
- patches.suse/btrfs-8229-return-EPERM-when-deleting-a-default-subvolume.patch:
  (bnc#869934).
- patches.suse/btrfs-8228-wake-up-scrub_pause_wait-as-much-as-we-can.patch:
- patches.suse/btrfs-8227-cancel-scrub-on-transaction-abortion.patch:
- patches.suse/btrfs-8226-fix-a-possible-deadlock-between-scrub-and-tran.patch:
- patches.suse/btrfs-8225-wake-up-transaction-thread-upon-remount.patch:
- patches.suse/btrfs-8224-avoid-warning-bomb-of-btrfs_invalidate_inodes.patch:
- patches.suse/btrfs-8223-Return-EXDEV-for-cross-file-system-snapshot.patch:
- commit 0b65b40
* Fri Jun 20 2014 mgalbraith@suse.de
- sched: Consider pi boosting in setscheduler.
- sched: Queue RT tasks to head when prio drops.
- commit e3bccb1
* Fri Jun 20 2014 mgalbraith@suse.de
- sched: Adjust sched_reset_on_fork when nothing else changes.
- commit 96d9cc1
* Fri Jun 20 2014 mkubecek@suse.cz
- tcp: allow to disable cwnd moderation in TCP_CA_Loss state
  (bnc#879921).
- commit 1bfc39f
* Fri Jun 20 2014 mkubecek@suse.cz
- bonding: fix vlan_features computing (bnc#872634).
- vlan: more careful checksum features handling (bnc#872634).
- commit f19bb4c
* Fri Jun 20 2014 mkubecek@suse.cz
- xfrm: fix race between netns cleanup and state expire
  notification (bnc#879957).
- commit 5a08e21
* Fri Jun 20 2014 mgalbraith@suse.de
- sched: Fix clock_gettime(CLOCK__CPUTIME_ID) monotonicity (bnc#880357).
- commit 5f2a932
* Thu Jun 19 2014 bpoirier@suse.de
- skbuff: skb_segment: orphan frags before copying (bnc#867723
  CVE-2014-0131).
- commit 213221a
* Wed Jun 18 2014 jdelvare@suse.de
- Reorder APEI patches to make the patch series bisectable
- commit 765996d
* Wed Jun 18 2014 mkubecek@suse.cz
- Remove bnc#861980 fix
  (customer changed their mind and decided to wait for SLE12 instead)
- Delete
  patches.fixes/ipvs-handle-IPv6-fragments-with-one-packet-schedulin.patch.
- Delete
  patches.fixes/netfilter-reuse-skb-nfct_reasm-for-ipvs-conn-referen.patch.
- Delete
  patches.kabi/kabi-hide-modifications-of-struct-sk_buff-done-by-bn.patch.
- commit 4d3940f
* Tue Jun 17 2014 mszeredi@suse.cz
- exec/ptrace: fix get_dumpable() incorrect tests (bnc#847652,
  CVE-2013-2929).
- commit 381fa65
* Mon Jun 16 2014 eich@suse.com
- drm/ast: Initialized data needed to map fbdev memory (bnc#880007).
- Delete
  patches.drm/drm-ast-Initialized-data-needed-to-map-fbdev-memory.patch.
- commit 3705d0b
* Fri Jun 13 2014 bpoirier@suse.de
- filter: prevent nla extensions to peek beyond the end of the
  message (bnc#877257 CVE-2014-3144 CVE-2014-3145).
- commit 1884a46
* Fri Jun 13 2014 mhocko@suse.cz
- pagecachelimit: reduce lru_lock contention for heavy parallel kabi fixup:
  (bnc#878509, bnc#864464).
- pagecachelimit: reduce lru_lock contention for heavy parallel
  reclaim (bnc#878509, bnc#864464).
- Refresh
  patches.fixes/mm-vmscan-only-defer-compaction-for-failed-order-and-higher.patch.
- Refresh
  patches.fixes/mm-vmscan-store-priority-in-struct-scan_control.patch.
- Refresh patches.suse/pagecache-limit-fix-shmem-deadlock.patch.
- commit 7203b05
* Fri Jun 13 2014 tonyj@suse.de
- auditsc: audit_krule mask accesses need bounds checking
  (bnc#880484, CVE-2014-3917).
- commit 56b36f8
* Thu Jun 12 2014 eich@suse.com
- drm/ast: add AST 2400 support (bnc#880007).
- commit d03385e
* Thu Jun 12 2014 eich@suse.com
- drm/mgag200: on cards with < 2MB VRAM default to 16-bit
  (bnc#882324).
- drm/mgag200: fix typo causing bw limits to be ignored on some
  chips (bnc#882324).
- commit 2a5f6f5
* Thu Jun 12 2014 jslaby@suse.cz
- TTY: serial, cleanup include file (bnc#881571).
- TTY: serial, fix includes in some drivers (bnc#881571).
- serial_core: Fix race in uart_handle_dcd_change (bnc#881571).
- Refresh
  patches.fixes/n_tty-Fix-n_tty_write-crash-when-echoing-in-raw-mode.patch.
- commit 5d0bb33
* Wed Jun 11 2014 eich@suse.com
- drm/ast: Fix memleaks in error path in ast_fb_create().
- commit 2cb43ef
* Wed Jun 11 2014 eich@suse.com
- drm/ast: Add an crtc_disable callback to the crtc helper funcs
- drm/ast: Simplify function ast_ttm_placement().
- drm/ast: Simplify function ast_bo_unpin().
- drm/ast: Make local function ast_bo_unref() static.
- drm/ast: Initialized data needed to map fbdev memory
  (bnc#880007).
- drm/ast: Free container instead of member in
  ast_user_framebuffer_destroy().
- drm/ast: Fix memleak in error path in ast_bo_create().
- commit 70310c3
* Wed Jun 11 2014 dchang@suse.com
- vhost: fix total length when packets are too short (bnc#870576
  CVE-2014-0077).
- vhost: validate vhost_get_vq_desc return value (bnc#870173
  CVE-2014-0055).
- commit de95996
* Wed Jun 11 2014 neilb@suse.de
- Don't allow scheduler time to go backwards (bnc#880357).
- commit a834452
* Tue Jun 10 2014 jkosina@suse.cz
- Refresh
  patches.drivers/mlx4-use-GFP_NOFS-during-ipoib-tx-path.patch: update
  upstream references.
- commit bb665a3
* Tue Jun 10 2014 tonyj@suse.de
- powerpc/perf: Power8 PMU support (bnc#832710).
- powerpc/perf: Add support for SIER (bnc#832710).
- powerpc/perf: Add regs_no_sipr() (bnc#832710).
- powerpc/perf: Add an accessor for regs->result (bnc#832710).
- powerpc/perf: Convert mmcra_sipr/sihv() to regs_sipr/sihv()
  (bnc#832710).
- powerpc/perf: Add an explict flag indicating presence of SLOT
  field (bnc#832710).
- commit dff86e1
* Thu Jun  5 2014 jeffm@suse.de
- Fix missing unlock of vfsmount_lock in unlazy_walk (bnc#880437).
- commit 253abee
* Thu Jun  5 2014 jbeulich@suse.com
- swiotlb: don't assume PA 0 is invalid (bnc#865882).
- lockref: implement lockless reference count updates using
  cmpxchg() (FATE#317271).
- Delete
  patches.xen/lockref-implement-lockless-reference-count-updates-using-cmpxchg.
- Refresh other Xen patches.
- commit 4461f4d
* Thu Jun  5 2014 dchang@suse.com
- rds: prevent dereference of a NULL device in rds_iw_laddr_check
  (bnc#871561 CVE-2014-2678).
- rds: prevent dereference of a NULL device (bnc#869563
  CVE-2013-7339).
- commit cdbe806
* Wed Jun  4 2014 jkosina@suse.cz
- futex: Validate atomic acquisition in futex_lock_pi_atomic()
  (bnc#880892 CVE-2014-3153).
- futex: Forbid uaddr == uaddr2 in futex_requeue(...,
  requeue_pi=1) (bnc#880892 CVE-2014-3153).
- commit 87c5279
* Tue Jun  3 2014 jjolly@suse.de
- af_iucv: wrong mapping of sent and confirmed skbs (bnc#878407,
  LTC#110452).
- af_iucv: recvmsg problem for SOCK_STREAM sockets (bnc#878407,
  LTC#110452).
- af_iucv: fix recvmsg by replacing skb_pull() function
  (bnc#878407, LTC#110452).
- kernel: avoid page table walk on user space access (bnc#878407,
  LTC#110316).
- commit 448a5d4
* Tue Jun  3 2014 neilb@suse.de
- dm snapshot: fix data corruption (bnc#846404).
- commit c45bf67
* Mon Jun  2 2014 bpoirier@suse.de
- net: ipv4: current group_info should be put after using
  (bnc#873374 CVE-2014-2851).
- commit 38bee04
* Mon Jun  2 2014 mcgrof@suse.com
- mac80211: fix AP powersave TX vs. wakeup race (bnc#871797).
  backported for v3.0 with minor changes.
- commit b8d5bfe
* Mon Jun  2 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit c7ded11
* Fri May 30 2014 jroedel@suse.de
- KVM: ioapic: fix assignment of ioapic->rtc_status.pending_eoi (CVE-2014-0155) (bnc#872540).
- commit 88fb36c
* Tue May 27 2014 neilb@suse.de
- Don't lose sockets when nfsd shutdown races with connection
  timeout (bnc#871854).
- commit 2445a77
* Sat May 24 2014 mgorman@suse.de
- Refresh
  patches.suse/0015-vfs-use-lockref-dead-flag-to-mark-unrecoverably-dead.patch.
- commit af7f954
* Fri May 23 2014 hare@suse.de
- qla2xxx: Poll during initialization for ISP25xx and ISP83xx
  (bnc#837563).
- commit bd1c1f5
* Fri May 23 2014 hare@suse.de
- lpfc 8.3.41: Fixed SLI3 failing FCP write on check-condition
  no-sense with residual zero (bnc#850915).
- commit faf084b
* Wed May 21 2014 jeffm@suse.de
- reiserfs: call truncate_setsize under tailpack mutex
  (bnc#878115).
- commit f20c633
* Wed May 21 2014 jeffm@suse.de
- reiserfs: drop vmtruncate (bnc#878115).
- commit 2a8dc40
* Wed May 21 2014 mkubecek@suse.cz
- Update (fix build on archs with CONFIG_IP_VS && !CONFIG_IP_VS_IPV6)
  patches.fixes/ipvs-handle-IPv6-fragments-with-one-packet-schedulin.patch.
- commit da1edf0
* Wed May 21 2014 mkubecek@suse.cz
- xfrm: check peer pointer for null before calling inet_putpeer()
  (bnc#877775).
- commit ada70d1
* Wed May 21 2014 mkubecek@suse.cz
- ipvs: handle IPv6 fragments with one-packet scheduling
  (bnc#861980).
- kabi: hide modifications of struct sk_buff done by bnc#861980
  fix (bnc#861980).
- netfilter: reuse skb->nfct_reasm for ipvs conn reference
  (bnc#861980).
- commit 82d3435
* Wed May 21 2014 ptesarik@suse.cz
- [SCSI] qla2xxx: Fix request queue null dereference (bnc#859840).
- commit 8782f4c
* Wed May 21 2014 neilb@suse.de
- loop: remove the incorrect write_begin/write_end shortcut (bnc#878123).
  The removed code causes problems particularly with lustre
- commit 7c3d8ad
* Tue May 20 2014 jeffm@suse.de
- watchdog: hpwdt patch to display informative string
  (bnc#862934).
- watchdog: hpwdt: Patch to ignore auxilary iLO devices
  (bnc#862934).
- watchdog: hpwdt: Add check for UEFI bits (bnc#862934).
- watchdog: hpwdt.c: Increase version string (bnc#862934).
- commit 720bb59
* Tue May 20 2014 jeffm@suse.de
- hpilo: Correct panic when an AUX iLO is detected (bnc#837563).
- commit 808cd6e
* Mon May 19 2014 bp@suse.de
- x86/mce: Fix CMCI preemption bugs (bnc#786450).
- x86, CMCI: Add proper detection of end of CMCI storms
  (bnc#786450).
- commit c0c59b4
* Fri May 16 2014 jeffm@suse.de
- xen: disable lockref on Xen
- commit f33b8cb
* Fri May 16 2014 jeffm@suse.de
- locking/mutexes: Introduce cancelable MCS lock for adaptive
  spinning (FATE#317271).
- commit 7ee0623
* Fri May 16 2014 jeffm@suse.de
- locking/mutexes: Modify the way optimistic spinners are queued
  (FATE#317271).
- commit 94d54cf
* Fri May 16 2014 jeffm@suse.de
- locking/mutexes: Return false if task need_resched() in
  mutex_can_spin_on_owner() (FATE#317271).
- commit a6d3f89
* Fri May 16 2014 jeffm@suse.de
- mutex: Enable the queuing of mutex spinners with MCS lock (FATE#317271).
  config: disabled on all flavors
- commit f6c5150
* Fri May 16 2014 jeffm@suse.de
- mutex: Queue mutex spinners with MCS lock to reduce cacheline
  contention (FATE#317271).
- commit 7d7d1f8
* Fri May 16 2014 mhocko@suse.cz
- memcg: deprecate memory.force_empty knob (bnc#878274).
- commit 948e0e6
* Fri May 16 2014 mkubecek@suse.cz
- kabi: protect struct net from bnc#877013 changes (bnc#877013).
- netfilter: nfnetlink_queue: add net namespace support for
  nfnetlink_queue (bnc#877013).
- netfilter: make /proc/net/netfilter pernet (bnc#877013).
- commit df56997
* Fri May 16 2014 jeffm@suse.de
- mm: per-thread vma caching (FATE#317271).
  config: enable CONFIG_VMA_CACHE for x86_64/bigsmp
- commit cf33d57
* Fri May 16 2014 jeffm@suse.de
- SELinux: Increase ebitmap_node size for 64-bit configuration (FATE#317271).
- SELinux: Reduce overhead of mls_level_isvalid() function call (FATE#317271).
- commit 70b5e52
* Fri May 16 2014 jeffm@suse.de
- mutex: Fix debug_mutexes (FATE#317271).
- mutex: Fix debug checks (FATE#317271).
- locking/mutexes: Unlock the mutex without the wait_lock (FATE#317271).
- commit 5f8a063
* Fri May 16 2014 jeffm@suse.de
- mm, hugetlb: improve page-fault scalability (FATE#317271).
- commit 9bf77b9
* Fri May 16 2014 jeffm@suse.de
- epoll: do not take the nested ep->mtx on EPOLL_CTL_DEL (FATE#317271).
- epoll: do not take global 'epmutex' for simple topologies (FATE#317271).
- epoll: optimize EPOLL_CTL_DEL using rcu (FATE#317271).
- commit c827414
* Fri May 16 2014 jeffm@suse.de
- dcache: kABI fixes for lockref dentries (FATE#317271).
- vfs: make sure we don't have a stale root path if unlazy_walk() fails (FATE#317271).
- vfs: fix dentry RCU to refcounting possibly sleeping dput() (FATE#317271).
- vfs: use lockref "dead" flag to mark unrecoverably dead dentries (FATE#317271).
- vfs: reimplement d_rcu_to_refcount() using lockref_get_or_lock() (FATE#317271).
- vfs: Remove second variable named error in __dentry_path (FATE#317271).
- make prepend_name() work correctly when called with negative *buflen (FATE#317271).
- prepend_path() needs to reinitialize dentry/vfsmount on restarts (FATE#317271).
- commit a738a09
* Fri May 16 2014 jeffm@suse.de
- dcache: get/release read lock in read_seqbegin_or_lock() & friend (FATE#317271).
- seqlock: Add a new locking reader type (FATE#317271).
- dcache: Translating dentry into pathname without taking rename_lock (FATE#317271).
- commit 0decfed
* Fri May 16 2014 jeffm@suse.de
- vfs: make the dentry cache use the lockref infrastructure (FATE#317271).
- VFS: Remove dentry->d_lock locking from shrink_dcache_for_umount_subtree() (FATE#317271).
- vfs: use lockref_get_not_zero() for optimistic lockless dget_parent() (FATE#317271).
- vfs: constify dentry parameter in d_count() (FATE#317271).
- helper for reading ->d_count (FATE#317271).
- lockref: use arch_mutex_cpu_relax() in CMPXCHG_LOOP() (FATE#317271).
- lockref: allow relaxed cmpxchg64 variant for lockless updates (FATE#317271).
- lockref: use cmpxchg64 explicitly for lockless updates (FATE#317271).
- lockref: add ability to mark lockrefs "dead" (FATE#317271).
- lockref: fix docbook argument names (FATE#317271).
- lockref: Relax in cmpxchg loop (FATE#317271).
- lockref: implement lockless reference count updates using cmpxchg() (FATE#317271).
- lockref: uninline lockref helper functions (FATE#317271).
- lockref: add 'lockref_get_or_lock() helper (FATE#317271).
- Add new lockref infrastructure reference implementation (FATE#317271).
- commit 1562fef
* Fri May 16 2014 jeffm@suse.de
- config.conf: add new x86_64/bigsmp flavor with MCS locking enabled
- commit 49c7eba
* Thu May 15 2014 jdelvare@suse.de
- supported.conf: Add firewire/nosy as supported
  This driver is the replacement for the ieee1394/pcilynx driver,
  which was supported.
- commit b351c7b
* Thu May 15 2014 neilb@suse.de
- NFSv4: don't put ACCESS in OPEN compound if O_EXCL (bnc#870958).
- commit 1b1d5a9
* Wed May 14 2014 oneukum@suse.de
- Update
  patches.drivers/0001-xhci-extend-quirk-for-Renesas-cards.patch
  (bnc#877503).
- commit 261581a
* Wed May 14 2014 oneukum@suse.de
- xhci: extend quirk for Renesas cards (bnc#877497).
- commit 18b8c82
* Tue May 13 2014 jjolly@suse.de
- spinlock: fix system hang with spin_retry <= 0 (bnc#874145,
  LTC#110189).
- commit 3e29be2
* Tue May 13 2014 jjolly@suse.de
- crypto: s390 - fix aes,des ctr mode concurrency finding
  (bnc#874145, LTC#110078).
- commit 177009b
* Tue May 13 2014 jjolly@suse.de
- s390/cio: fix unlocked access of global bitmap (bnc#874145,
  LTC#109378).
- commit 296e47e
* Tue May 13 2014 jjolly@suse.de
- s390/css: stop stsch loop after cc 3 (bnc#874145, LTC#109378).
- commit bf81310
* Tue May 13 2014 jjolly@suse.de
- s390/pci: add kmsg man page (bnc#874145, LTC#109224).
- commit 2a865a5
* Tue May 13 2014 jjolly@suse.de
- qeth: postpone freeing of qdio memory (bnc#874145, LTC#107873).
- commit 8d42cf4
* Mon May 12 2014 neilb@suse.de
- Revert "NFS: revalidate on open if dcache is negative (bnc#876463)."
  This reverts commit cc3a17687b59d4bf8939c73515573644c32be832.
  It turns out this is a feature, not a bug, so it shouldn't be fixed.
  The 'lookupcache' setting can be used if revalidating negative dentries
  is required.
- commit 3429215
* Mon May 12 2014 hare@suse.de
- Fix race between starved list and device removal (bnc#861636).
- Delete
  patches.fixes/scsi-fix-race-between-starved-list-processing.patch.
- commit f6da5ee
* Mon May 12 2014 neilb@suse.de
- namei.h: include errno.h (bnc#876463).
- commit fc36754
* Mon May 12 2014 neilb@suse.de
- vfs: make lremovexattr retry once on ESTALE error (bnc#876463).
- vfs: make removexattr retry once on ESTALE (bnc#876463).
- vfs: make llistxattr retry once on ESTALE error (bnc#876463).
- vfs: make listxattr retry once on ESTALE error (bnc#876463).
- vfs: make lgetxattr retry once on ESTALE (bnc#876463).
- vfs: make getxattr retry once on an ESTALE error (bnc#876463).
- vfs: allow lsetxattr() to retry once on ESTALE errors
  (bnc#876463).
- vfs: allow setxattr to retry once on ESTALE errors (bnc#876463).
- vfs: allow utimensat() calls to retry once on an ESTALE error
  (bnc#876463).
- vfs: fix user_statfs to retry once on ESTALE errors
  (bnc#876463).
- vfs: make fchownat retry once on ESTALE errors (bnc#876463).
- vfs: make fchmodat retry once on ESTALE errors (bnc#876463).
- vfs: have chroot retry once on ESTALE error (bnc#876463).
- vfs: have chdir retry lookup and call once on ESTALE error
  (bnc#876463).
- vfs: have faccessat retry once on an ESTALE error (bnc#876463).
- vfs: have do_sys_truncate retry once on an ESTALE error
  (bnc#876463).
- vfs: fix renameat to retry on ESTALE errors (bnc#876463).
- vfs: make do_unlinkat retry once on ESTALE errors (bnc#876463).
- vfs: make do_rmdir retry once on ESTALE errors (bnc#876463).
- vfs: fix linkat to retry once on ESTALE errors (bnc#876463).
- vfs: fix symlinkat to retry on ESTALE errors (bnc#876463).
- vfs: fix mkdirat to retry once on an ESTALE error (bnc#876463).
- vfs: fix mknodat to retry on ESTALE errors (bnc#876463).
- vfs: add a flags argument to user_path_parent (bnc#876463).
- vfs: fix readlinkat to retry on ESTALE (bnc#876463).
- vfs: make fstatat retry on ESTALE errors from getattr call
  (bnc#876463).
- vfs: add a retry_estale helper function to handle retries on
  ESTALE (bnc#876463).
- NFS: revalidate on open if dcache is negative (bnc#876463).
- NFSD add module parameter to disable delegations (bnc#876463).
- commit 79fef9a
* Sat May 10 2014 tiwai@suse.de
- ALSA: hda - Implement bind mixer ctls for Conexant (bnc#872188).
- commit ab02b3b
* Fri May  9 2014 mkubecek@suse.cz
- tcp: clear xmit timers in tcp_v4_syn_recv_sock() (bnc#862429).
- net: add missing bh_unlock_sock() calls (bnc#862429).
- commit e1b4873
* Thu May  8 2014 hare@suse.de
- Re-enable
  patches.drivers/megaraid_sas-0031-fix-BUG_ON-from-incorrect-use-of-delayed-wo.patch.
- commit cb284ad
* Thu May  8 2014 bp@suse.de
- x86/UV: Set n_lshift based on GAM_GR_CONFIG MMR for UV3
  (bnc#876176).
- commit 7d0af0c
* Wed May  7 2014 bp@suse.de
- intel-iommu: fix off-by-one in pagetable freeing (bnc#874577).
- commit 16ed619
* Wed May  7 2014 jbohac@suse.cz
- net: sctp: fix sctp_sf_do_5_1D_ce to verify if we/peer is AUTH
  (bnc#866102, CVE-2014-0101).
- commit 678f785
* Wed May  7 2014 mkubecek@suse.cz
- Update Patch-mainline
  patches.fixes/netfilter-ip6t_LOG-fix-logging-of-packet-mark.patch.
- Update Patch-mainline
  patches.fixes/xfrm-fix-freed-block-size-calculation-in-xfrm_policy.patch.
- commit 428c122
* Wed May  7 2014 ptesarik@suse.cz
- [IA64] Change default PSR.ac from '1' to '0' (Fix erratum #237)
  (bnc#874108).
- Refresh patches.suse/kdb-v4.4-3.1-ia64-1.
- commit 4c39316
* Wed May  7 2014 tiwai@suse.de
- ALSA: hda - Fix invalid Auto-Mute Mode enum from cxt codecs
  (bnc#872188).
- commit 2c827d2
* Tue May  6 2014 tiwai@suse.de
- ALSA: hda - Fix conflicting Capture Source on cxt codecs
  (bnc#872188).
- commit b05a890
* Tue May  6 2014 duwe@suse.de
- powerpc: Bring all threads online prior to migration/hibernation
  (bnc#870591).
- commit 3326fed
* Tue May  6 2014 duwe@suse.de
- powerpc/pseries: Update dynamic cache nodes for suspend/resume
  operation (bnc#873463).
- powerpc/pseries: Device tree should only be updated once after
  suspend/migrate (bnc#873463).
- powerpc/pseries: Expose in kernel device tree update to drmgr
  (bnc#873463).
- powerpc: Add second POWER8 PVR entry (bnc#874440).
- commit 419d27b
* Tue May  6 2014 jkosina@suse.cz
- floppy: ignore kernel-only members in FDRAWCMD ioctl input
  (bnc#875798 CVE-2014-1737 CVE-2014-1738).
- floppy: don't write kernel-only members to FDRAWCMD ioctl output
  (bnc#875798 CVE-2014-1737 CVE-2014-1738).
- floppy: ignore kernel-only members in FDRAWCMD ioctl input
  (bnc#875798 CVE-2014-1737 CVE-2014-1738).
- floppy: don't write kernel-only members to FDRAWCMD ioctl output
  (bnc#875798 CVE-2014-1737 CVE-2014-1738).
- commit b960221
* Tue May  6 2014 vbabka@suse.cz
- mm: try_to_unmap_cluster() should lock_page() before mlocking
  (bnc#876102, CVE-2014-3122).
- commit c78feaa
* Tue May  6 2014 neilb@suse.de
- Refresh patches.fixes/md-strange-spin.fix.
  Remove some changes that could not have been relevant.
- commit 5e9bc72
* Mon May  5 2014 jack@suse.cz
- patches.fixes/writeback-do-not-sync-data-dirtied-after-sync-start.patch:
  Remove the patch since sync(2) can skip inodes with it.
- commit 01010f6
* Mon May  5 2014 mmarek@suse.cz
- Drop bogus Git-commit: headers from xhci patches
- patches.fixes/0001-Do-not-switch-webcam-for-HP-EB-8580w.patch
- patches.fixes/0001-Do-not-switch-webcams-in-some-HP-ProBooks-to-XHCI.patch
- patches.fixes/0001-Don-t-switch-camera-on-HP-EB-820-G1.patch
- patches.fixes/0001-Don-t-switch-camera-on-HP-EB-8780.patch
- patches.fixes/0001-don-t-switch-cam-port-on-HP-EliteBook-840.patch
- patches.fixes/0001-xhci-set-device-to-D3Cold-on-shutdown.patch
- patches.fixes/avoid_ehci_xhci_switch_for_BT_PB430.patch
- patches.suse/0001-xhci-directly-calling-_PS3-on-suspend.patch
- commit a320c17
* Mon May  5 2014 mmarek@suse.cz
- Fix Git-commit header in
  patches.fixes/0001-usbhid-fix-error-handling-of-not-enough-bandwidth.patch.
- commit 772751b
* Mon May  5 2014 mmarek@suse.cz
- Refresh patches.drivers/fnic-FIP-VLAN-Discovery-Feature-Support.patch
  from upstream
- Delete
  patches.drivers/fnic-Fix-memory-leak-issue-in-Vlan-Discovery.patch.
- commit 9b85326
* Mon May  5 2014 mmarek@suse.cz
- Update patches.drivers/0001-ACPI-remove-panic-in-case-hardware-has-changed-after.patch from upstream
- commit e4478d5
* Mon May  5 2014 mmarek@suse.cz
- patches.drivers/storvsc-null-pointer-dereference-fix: Updated Git-commit
  header
- commit d6f90f5
* Mon May  5 2014 jdelvare@suse.de
- supported.conf: generic_bl is supported
  Driver corgi_bl was renamed to generic_bl in kernel 2.6.29, adjust
  supported.conf accordingly.
- commit a4fe430
* Mon May  5 2014 jslaby@suse.cz
- n_tty: Fix n_tty_write crash when echoing in raw mode
  (bnc#871252 bnc#875690 CVE-2014-0196).
- commit 9ec28a0
* Mon May  5 2014 glin@suse.com
- libata/ahci: accommodate tag ordered controllers (bnc#871728)
- commit b8a5ff0
* Mon May  5 2014 neilb@suse.de
- md: try to remove cause of a spinning md thread (bnc#875386).
- commit e6234d7
* Thu May  1 2014 neilb@suse.de
- Refresh
  patches.fixes/0001-NFSv4-Allow-the-state-manager-to-mark-an-open_owner-.patch.
- Refresh
  patches.fixes/0005-NFSv4-Ensure-delegation-recall-and-byte-range-lock-r.patch.
  Fix kabi breakage.  Modules would never allocate this struct, and don't
  need to know about new fields.
- commit 69fd76f
* Thu May  1 2014 neilb@suse.de
- NFSv4: Fix a reboot recovery race when opening a file
  (bnc#864404).
- NFSv4: Ensure delegation recall and byte range lock removal
  don't conflict (bnc#864404).
- NFSv4: Fix up the return values of nfs4_open_delegation_recall
  (bnc#864404).
- NFSv4.1: Don't lose locks when a server reboots during
  delegation return (bnc#864404).
- NFSv4.1: Prevent deadlocks between state recovery and file
  locking (bnc#864404).
- NFSv4: Allow the state manager to mark an open_owner as being
  recovered (bnc#864404).
- NFS: nfs_inode_return_delegation() should always flush dirty
  data (bnc#864404).
-  NFSv4: nfs_client_return_marked_delegations can't flush data
  (bnc#864404).
- seqlock: add 'raw_seqcount_begin()' function (bnc#864404).
- commit 0b341df
* Wed Apr 30 2014 jbohac@suse.cz
- timer: Prevent overflow in apply_slack (bnc#873061).
- commit 685b42f
* Wed Apr 30 2014 pmladek@suse.cz
- Update
  patches.fixes/x86-Add-workaround-to-NMI-iret-woes.patch.
  Add proof that that page fault really might happen when dumping trace.
  Thanks to Michal Hock for the idea of the test.
- commit f9c603f
* Wed Apr 30 2014 neilb@suse.de
- NFS: avoid excessive GETATTR request when attributes expired
  but cached directory is valid (bnc#857926).
- commit 05ec2e8
* Mon Apr 28 2014 jdelvare@suse.de
- Refresh
  patches.fixes/ipmi-fix-a-race-restarting-the-timer.patch.
- Refresh
  patches.fixes/ipmi-reset-the-KCS-timeout-when-starting-error-recovery.patch.
  Add upstream references.
- commit fa3ac75
* Mon Apr 28 2014 tiwai@suse.de
- mei: me: do not load the driver if the FW doesn't support MEI
  interface (bnc#821619).
- commit 8f88be7
* Mon Apr 28 2014 mgorman@suse.de
- hugetlb: ensure hugepage access is denied if hugepages are not supported
  (PowerKVM crash when mounting hugetlbfs without hugepage support (bnc#870498)).
- commit 4894c37
* Fri Apr 25 2014 eich@suse.com
- Refresh
  patches.drm/drm-i915-Break-encoder-crtc-link-separately-in-intel_sanitize_crtc.patch.
- commit ca75f03
* Fri Apr 25 2014 eich@suse.com
- drm/i915: Break encoder->crtc link separately in
  intel_sanitize_crtc() (bnc#855126).
- commit 6096785
* Thu Apr 24 2014 neilb@suse.de
- Allow nfsdv4 to work when fips=1 (bnc#868488).
- commit 0d2a326
* Thu Apr 24 2014 neilb@suse.de
- NFSv4: Add ACCESS operation to OPEN compound (bnc#870958).
- NFSv4: Fix unnecessary delegation returns in nfs4_do_open
  (bnc#870958).
- commit a45e24f
* Wed Apr 23 2014 mkubecek@suse.cz
- netfilter: xt_hashlimit: fix proc entry leak in netns destroy
  path (bnc#871634).
- netfilter: xt_hashlimit: fix namespace destroy path
  (bnc#871634).
- commit d5551f8
* Tue Apr 22 2014 mmarek@suse.cz
- patches.fixes/linux-3.0.0-fix-strim.txt: Updated Patch-mainline header
  and patch description
- commit 990bd81
* Tue Apr 22 2014 mgorman@suse.de
- mm: vmscan: Do not throttle based on pfmemalloc reserves if node has no ZONE_NORMAL
  (bnc#870496).
- commit 0d50f31
* Thu Apr 17 2014 mhocko@suse.cz
- Refresh patches.fixes/x86-Add-workaround-to-NMI-iret-woes.patch.
  changelog clarification
- commit 4f8c4c6
* Thu Apr 17 2014 mkubecek@suse.cz
- netfilter: nf_queue: reject NF_STOLEN verdicts from userspace
  (bnc#870877).
- netfilter: avoid double free in nf_reinject (bnc#870877).
- commit 6224a68
* Wed Apr 16 2014 jdelvare@suse.de
- ipmi: Reset the KCS timeout when starting error recovery
  (bnc#870618).
- ipmi: Fix a race restarting the timer (bnc#870618).
- ipmi: increase KCS timeouts (bnc#870618).
- commit 3dc47ba
* Wed Apr 16 2014 jdelvare@suse.de
- supported.conf: Add drivers/of/of_mdio
  That was a missing dependency for mdio-gpio on ppc64.
- commit 5926199
* Wed Apr 16 2014 jdelvare@suse.de
- supported.conf: Fix mdio-gpio module name
  Module mdio-ofgpio was renamed to mdio-gpio in kernel 2.6.29, this
  should have been reflected in supported.conf.
- commit c033ed6
* Tue Apr 15 2014 ptesarik@suse.cz
- x86: Enable multiple CPUs in crash kernel (bnc#846690).
- commit f8682f7
* Tue Apr 15 2014 jdelvare@suse.de
- patches.arch/s390-18-03-linkage-stack.patch: Add CVE number
  Also add upstream reference.
- commit 7459364
* Tue Apr 15 2014 mkubecek@suse.cz
- kabi: hide modifications of struct inet_peer done by bnc#867953
  fix (bnc#867953).
- inetpeer: prevent unlinking from unused list twice (bnc#867953).
- commit cc0267c
* Tue Apr 15 2014 mgalbraith@suse.de
- sched: Make scale_rt_power() deal with backward clocks (bnc#865310).
- commit db73099
* Tue Apr 15 2014 mgalbraith@suse.de
- sched: Use CPUPRI_NR_PRIORITIES instead of MAX_RT_PRIO in cpupri check (bnc#871861).
- commit de17713
* Tue Apr 15 2014 mgalbraith@suse.de
- Update
  patches.fixes/sched-update_rq_clock-must-skip-ONE-update.patch
  (bnc#868528, bnc#869033).
- commit 3c3cb73
* Mon Apr 14 2014 mkubecek@suse.cz
- ipv6: do not overwrite inetpeer metrics prematurely
  (bnc#867362).
- commit 05bd711
* Fri Apr 11 2014 tiwai@suse.de
- Ignore selected taints for tracepoint modules (bnc#870450,
  FATE#317134).
- Use 'E' instead of 'X' for unsigned module taint flag
  (bnc#870450,FATE#317134).
- Fix: module signature vs tracepoints: add new
  TAINT_UNSIGNED_MODULE (bnc#870450,FATE#317134).
- commit adc81ba
* Fri Apr 11 2014 mgalbraith@suse.de
- futex: avoid race between requeue and wake (bnc#851603).
- commit 04ae5b9
* Wed Apr  9 2014 jbeulich@suse.com
- pciback: fix memory leak in __xen_pcibk_add_pci_dev().
- Refresh patches.xen/xen-clockevents (bnc#816446).
- Refresh other Xen patches.
- commit 347ea69
* Tue Apr  8 2014 duwe@suse.de
- virtio_balloon: don't softlockup on huge balloon changes
  (bnc#871899).
- commit 2618b9b
* Tue Apr  8 2014 hare@suse.de
- ch: add refcounting (bnc#867517).
- commit 7d00daa
* Tue Apr  8 2014 hare@suse.de
- scsi: return target failure on EMC inactive snapshot
  (bnc#840524).
- commit b7115ea
* Mon Apr  7 2014 mgorman@suse.de
- Delete patches.fixes/mm-swap-use-files-priority-order.patch.
- commit 8e350f4
* Mon Apr  7 2014 mkubecek@suse.cz
- Update
  patches.fixes/inet-Pass-inetpeer-root-into-inet_getpeer-interfaces.patch
  (bnc#864833 bnc#870801).
- Refresh
  patches.fixes/inet-Hide-route-peer-accesses-behind-helpers.patch.
- commit 172cdff
* Mon Apr  7 2014 mkubecek@suse.cz
- inet: handle rt{,6}_bind_peer() failure correctly (bnc#870801).
- commit 6e73c0e
* Thu Apr  3 2014 mgalbraith@suse.de
- sched: update_rq_clock() must skip ONE update (bnc#869033, bnc#868528).
- commit a21b155
* Thu Apr  3 2014 jdelvare@suse.de
- Update config files: disable all of Timberdale support
  Timberdale is a companion chip for Atom CPUs in embedded in-car
  infotainment systems. We don't need that in SLE, really.
- commit 44e5713
* Wed Apr  2 2014 jdelvare@suse.de
- supported.conf: Adjust radio-si470x module name
  In kernel 2.6.32, module radio-si470x was split into two distinct
  modules, radio-usb-si470x for the USB access and radio-i2c-si470x for
  I2C access. USB access is what the original module was implementing so
  we should keep supporting radio-usb-si470x. I2C access was not
  implemented before and I suspect it's only needed on embedded systems
  so we shouldn't build it at all.
- commit e44b08a
* Wed Apr  2 2014 tiwai@suse.de
- ALSA: usb-audio: Fix NULL dereference while quick replugging
  (bnc#870335).
- commit 4055206
* Tue Apr  1 2014 jdelvare@suse.de
- Update config files: CONFIG_CRYPTO_TWOFISH_COMMON=m
  Missing dependency, sorry.
- commit f62c7eb
* Tue Apr  1 2014 jdelvare@suse.de
- Update config files: re-enable twofish crypto support
  Twofish crypto support was accidentally disabled on IA64 and PPC
  since SLES11 GA. Additionally, in SLES11 SP2, the software twofish
  implementation was renamed from twofish to twofish_generic, but
  supported.conf was not updated accordingly, so S/390 was without a
  supported twofish crypto implementation as well.
  Re-enable software twofish crypto support on IA64 and PPC, and
  adjust supported.conf to reflect the name change (bnc#871325).
- commit afaafd6
* Tue Apr  1 2014 dsterba@suse.cz
- btrfs: don't loop on large offsets in readdir (bnc#863300)
- commit 1dab17d
* Wed Mar 26 2014 jbohac@suse.cz
- netfilter: ctnetlink: fix race between delete and timeout
  expiration (bnc#863410).
- commit 544208c
* Wed Mar 26 2014 neilb@suse.de
- Btrfs: unset DCACHE_DISCONNECTED when mounting default subvol
  (bnc#866615).
- commit 67a05e2
* Tue Mar 25 2014 jdelvare@suse.de
- Update ec2 config files: disable CONFIG_INPUT_FF_MEMLESS
  This helper module is useless on EC2.
- commit 950a6ce
* Mon Mar 24 2014 neilb@suse.de
- Refresh
  patches.fixes/NFSv4-The-NFSv4.0-client-must-send-RENEW-calls-if-it.patch.
- avoid kABI breakage.
- commit edb95eb
* Mon Mar 24 2014 tiwai@suse.de
- SELinux:  Fix kernel BUG on empty security contexts
  (bnc#863335,CVE-2014-1874).
- commit d91a02f
* Mon Mar 24 2014 tiwai@suse.de
- hamradio/yam: fix info leak in ioctl (bnc#858872,CVE-2014-1446).
- commit 577a380
* Mon Mar 24 2014 tiwai@suse.de
- wanxl: fix info leak in ioctl (bnc#858870,CVE-2014-1445).
- commit 26da9e8
* Mon Mar 24 2014 tiwai@suse.de
- farsync: fix info leak in ioctl (bnc#858869,CVE-2014-1444).
- commit 8301f67
* Mon Mar 24 2014 jeffm@suse.com
- netfilter: nf_conntrack_dccp: fix skb_header_pointer API usages
  (bnc#868653 CVE-2014-2523).
- commit da47896
* Mon Mar 24 2014 mgalbraith@suse.de
- Fix POWER7 futex regression stemming from bnc#851603 scalability fixes.
  futex: revert back to the explicit waiter counting code (bnc#851603).
- commit 782458f
* Mon Mar 24 2014 neilb@suse.de
- NFSv4: The NFSv4.0 client must send RENEW calls if it holds
  a delegation (bnc#863873).
- NFSv4: nfs4_proc_renew should be declared static (bnc#863873).
- commit 55baca7
* Fri Mar 21 2014 lduncan@suse.com
- storvsc: NULL pointer dereference fix (bnc#865330).
- commit 64e08f4
* Fri Mar 21 2014 tiwai@suse.de
- ath9k_htc: properly set MAC address and BSSID mask
  (bnc#851426,CVE-2013-4579).
- commit e3a1ae5
* Thu Mar 20 2014 jjolly@suse.de
- rds: prevent BUG_ON triggered on congestion update to loopback
  (bnc#767610, CVE-2012-2372).
- Delete patches.drivers/rds-no-bug-in-xmit-for-loopback.patch.
- commit 68b7666
* Thu Mar 20 2014 tiwai@suse.de
- drm/ttm: don't oops if no invalidate_caches() (bnc#869414).
- commit 2d24b2c
* Wed Mar 19 2014 neilb@suse.de
- md: fix up plugging (again) (bnc#866800).
- commit 237b08b
* Wed Mar 19 2014 jjolly@suse.de
- cio: Fix missing subchannels after CHPID configure on
  (bnc#866081, LTC#104808).
- commit ea262f1
* Wed Mar 19 2014 jjolly@suse.de
- cio: Fix process hangs during subchannel scan (bnc#866081,
  LTC#104805).
- commit e3c845d
* Wed Mar 19 2014 jjolly@suse.de
- s390/pci/dma: use correct segment boundary size (bnc#866081,
  LTC#104566).
- commit 76a736b
* Wed Mar 19 2014 jjolly@suse.de
- cio: fix unusable device (bnc#866081, LTC#104168).
- commit 12e9b6b
* Tue Mar 18 2014 mszeredi@suse.cz
- Unlock the rename_lock in dentry_path() in the case when path
  is too long (bnc#868748).
- commit d0d96e9
* Mon Mar 17 2014 tiwai@suse.de
- mm: fix off-by-one bug in print_nodes_state() (bnc#792271).
- commit 8a82cef
* Mon Mar 17 2014 hare@suse.de
- Delete
  patches.drivers/qla2xxx-0159-Only-enable-link-up-on-the-correct-inte.patch.patch(bnc#866608).
- commit db584e7
* Fri Mar 14 2014 jbeulich@suse.com
- Refresh patches.xen/xen-x86-EFI (bnc#864253).
- Refresh other Xen patches.
- commit 24fb7ef
* Thu Mar 13 2014 jack@suse.cz
- ncpfs: fix rmdir returns Device or resource busy (bnc#864880).
- commit 14493f1
* Thu Mar 13 2014 mkubecek@suse.cz
- IPv6 routing, NLM_F_* flag support: REPLACE and EXCL flags
  support, warn about missing CREATE flag (bnc#865783).
- commit ad5cf06
* Thu Mar 13 2014 mkubecek@suse.cz
- kabi: protect symbols modified by bnc#864833 fix (bnc#864833).
- inet: Avoid potential NULL peer dereference (bnc#864833).
- inet: Hide route peer accesses behind helpers (bnc#864833).
- inet: Pass inetpeer root into inet_getpeer*() interfaces
  (bnc#864833).
- commit 4c3acce
* Thu Mar 13 2014 jdelvare@suse.de
- supported.conf: Support the AD7879 touchscreen again
  ad7879 was originally a standalone driver, that could be built to
  support either I2C or SPI access. In kernel 2.6.36, it was split into a
  helper module (ad7879) and two device drivers, one for I2C access
  (ad7879-i2c) and one for SPI access (ad7879-spi.)
  So in order to fully support the AD7879 touchscreen over I2C as we used
  to, we must support both ad7879 and ad7879-i2c.
- commit 9177714
* Thu Mar 13 2014 dchang@suse.com
- inet: fix addr_len/msg->msg_namelen assignment in recv_error
  and rxpmtu functions (bnc#857643 CVE-2013-7263 CVE-2013-7264
  CVE-2013-7265).
- inet: prevent leakage of uninitialized memory to user in recv
  syscalls (bnc#857643 CVE-2013-7263 CVE-2013-7264 CVE-2013-7265).
- commit f8ad80c
* Wed Mar 12 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-page-writeback.c-do-not-count-anon-pages-as-dirtyable-memory.patch.
- commit a1d10df
* Tue Mar 11 2014 jdelvare@suse.de
- Delete patches.drivers/watchdog-get-rid-of-module_alias_miscdev-statements.patch
  This change caused more harm than good (bnc#867139, bnc#867255).
- commit 202d601
* Mon Mar 10 2014 mgorman@suse.de
- Revert "kernel/sys.c: call disable_nonboot_cpus() in
  kernel_restart()" (Reduce time to shutdown large machines
  (bnc#865442)).
- Revert "PM / reboot: call syscore_shutdown() after
  disable_nonboot_cpus()" (Reduce time to shutdown large machines
  (bnc#865442)).
- commit edd2919
* Mon Mar 10 2014 mgorman@suse.de
- mm: mempolicy: fix mbind_range() && vma_adjust() interaction
  (VM Functionality (bnc#866428)).
- mm: merging memory blocks resets mempolicy (VM Functionality
  (bnc#866428)).
- commit 8e29a82
* Sun Mar  9 2014 mgorman@suse.de
- mm/page-writeback.c: do not count anon pages as dirtyable memory
  (High memory utilisation performance (bnc#859225)).
- mm: vmscan: Do not force reclaim file pages until it exceeds
  anon (High memory utilisation performance (bnc#859225)).
- mm: vmscan: fix endless loop in kswapd balancing (High memory
  utilisation performance (bnc#859225)).
- mm: vmscan: Update rotated and scanned when force reclaimed
  (High memory utilisation performance (bnc#859225)).
- commit 2274ef6
* Fri Mar  7 2014 jbohac@suse.cz
- tcp: syncookies: reduce cookie lifetime to 128 seconds
  (bnc#833968).
- tcp: syncookies: reduce mss table to four values (bnc#833968).
- commit bf2a15b
* Fri Mar  7 2014 mmarek@suse.cz
- rpm/mkspec: Generate a per-architecture per-package _constraints file
- commit ca28bf5
* Fri Mar  7 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-8217-refuse-to-remount-read-write-after-abort.patch
- commit 871bb73
* Thu Mar  6 2014 neilb@suse.de
- NFSD/sunrpc: avoid deadlock on TCP connection due to memory
  pressure (bnc#853455).
- commit 95a9a9c
* Wed Mar  5 2014 dsterba@suse.cz
- btrfs: Add btrfs: prefix to kernel log output
- btrfs: fix get set label blocking against balance.
- Btrfs: fix possible memory leak in find_parent_nodes().
- Btrfs: actually limit the size of delalloc range.
- Btrfs: actually log directory we are fsync()'ing.
- Btrfs: check roots last log commit when checking if an inode
  has been logged.
- Btrfs: replay dir_index items before other items.
- Btrfs: drop dir i_size when adding new names on replay.
- Revert "Btrfs: rework the overcommit logic to be based on the
  total size".
- Btrfs: fix worst case calculator for space usage.
- Btrfs: iput inode on allocation failure.
- Btrfs: btrfs_ioctl_default_subvol: Revert back to toplevel
  subvolume when arg is 0.
- btrfs: refuse to remount read-write after abort.
- Btrfs: dir_inode_operations should use btrfs_update_time also.
- Btrfs: fix transid verify errors when recovering log tree.
- Btrfs: use right root when checking for hash collision.
- Btrfs: release path before starting transaction in
  can_nocow_extent.
- Refresh
  patches.suse/btrfs-8189-fix-the-wrong-nocow-range-check.patch.
- Delete
  patches.suse/btrfs-8021-Prefix-mount-messages-with-btrfs-for-clarity.patch.
- Delete
  patches.suse/btrfs-fix-get-set-label-blocking-against-balance.patch.
- commit 79ad39f
* Wed Mar  5 2014 mhocko@suse.cz
- x86: Save cr2 in NMI in case NMIs take a page fault (follow-up
  for patches.fixes/x86-Add-workaround-to-NMI-iret-woes.patch).
- Refresh patches.arch/x86_64-unwind-annotations.
- commit 2804fdf
* Tue Mar  4 2014 mgalbraith@suse.de
- Remove misguided/buggy patch  (bnc#862023).  It will come back in a
  diferent form once patchlet queued by peterz lands upstream.
- patches.fixes/sched-harden-rq-rt-usage-accounting.patch. Delete.
- commit 83d2984
* Mon Mar  3 2014 mgorman@suse.de
- Refresh patches.suse/btrfs-update-message-levels.patch.
- commit 1ce809e
* Mon Mar  3 2014 dsterba@suse.cz
- Btrfs: fix transaction abortion when remounting btrfs from RW to RO.
- commit 976b7a6
* Mon Mar  3 2014 mkubecek@suse.cz
- inet: fix possible memory corruption with UDP_CORK and UFO
  (bnc#847672 CVE-2013-4470).
- Refresh
  patches.fixes/net-add-APIs-for-manipulating-skb-page-fragments.patch.
- commit 18419b8
* Mon Mar  3 2014 mkubecek@suse.cz
- ipv6: send router reachability probe if route has an unreachable
  gateway (bnc#853162).
- commit e07311f
* Fri Feb 28 2014 hare@suse.de
- scsi_dh_alua: fixup RTPG retry delay miscalculation
  (bnc#854025).
- scsi_dh_alua: Simplify state machine (bnc#854025).
- commit 17ee596
* Fri Feb 28 2014 oneukum@suse.de
- xhci: Fix resume issues on Renesas chips in Samsung laptops
  (bnc#866253).
- commit 77716c9
* Thu Feb 27 2014 jbohac@suse.cz
- bonding: disallow enslaving a bond to itself (bnc#599263).
- commit 4cb9443
* Thu Feb 27 2014 oneukum@suse.de
- USB: hub: handle -ETIMEDOUT during enumeration (bnc#855825).
- commit a7e08ef
* Wed Feb 26 2014 dsterba@suse.cz
- Btrfs: fix max_inline mount option.
- Btrfs: setup inode location during btrfs_init_inode_locked.
- Btrfs: don't use ram_bytes for uncompressed inline items.
- Btrfs: fix btrfs_search_slot_for_read backwards iteration.
- Btrfs: fix to catch all errors when resolving indirect ref.
- Btrfs: fix protection between walking backrefs and root
  deletion.
- btrfs: fix warning while merging two adjacent extents.
- btrfs: fix defrag 32-bit integer overflow.
- btrfs: restrict snapshotting to own subvolumes.
- Btrfs: handle EAGAIN case properly in btrfs_drop_snapshot().
- Btrfs: return free space to global_rsv as much as possible.
- Btrfs: fix an oops when we fail to relocate tree blocks.
- Btrfs: fix the wrong nocow range check.
- Btrfs: fix an oops when we fail to merge reloc roots.
- fs/btrfs: Integer overflow in btrfs_ioctl_resize().
- Btrfs: improve inode hash function/inode lookup.
- Btrfs: fix extent_map block_len after merging.
- Btrfs: fix max dir item size calculation.
- Btrfs: add missing extent state caching calls.
- Btrfs: fix extent boundary check in bio_readpage_error.
- commit ef79b50
* Wed Feb 26 2014 duwe@suse.de
- powerpc: Add VDSO version of getcpu (fate#316816, bnc#854445).
- commit 5ca60b5
* Wed Feb 26 2014 hare@suse.de
- Update
  patches.fixes/dm-mpath-Do-not-stall-on-invalid-ioctls.patch
  (bnc#854025).
- commit 2ba04d0
* Wed Feb 26 2014 hare@suse.de
- dm-multipath: Do not stall on invalid ioctls (bnc#865342).
- scsi_dh_alua: endless STPG retries for a failed LUN
  (bnc#865342).
- commit 0950900
* Tue Feb 25 2014 bpoirier@suse.de
- net/mlx4_en: Fix pages never dma unmapped on rx (bnc#858604).
- commit 4e88c5b
* Tue Feb 25 2014 mgorman@suse.de
- mm: exclude memory less nodes from zone_reclaim (bnc#863526).
- commit 983cecc
* Mon Feb 24 2014 jbeulich@suse.com
- privcmd: allow preempting long running user-mode originating
  hypercalls (bnc#861093).
- Refresh patches.xen/1242-console-add-preferred.patch.
- Refresh other Xen patches.
- commit d585fc5
* Fri Feb 21 2014 tonyj@suse.de
- audit: dynamically allocate audit_names when not enough space
  is in the names array (bnc#857358).
- audit: make filetype matching consistent with other filters
  (bnc#857358).
- commit e384764
* Fri Feb 21 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit ead9a95
* Fri Feb 21 2014 bp@suse.de
- x86, cpu, amd: Add workaround for family 16h, erratum 793
  (bnc#852967 CVE-2013-6885).
- commit 55594ac
* Thu Feb 20 2014 mhocko@suse.cz
- patches.fixes/xfs-underflow-bug-in-xfs_attrlist_by_handle.patch:
  xfs: underflow bug in xfs_attrlist_by_handle() (bnc#852553,
  CVE-2013-6382).
- commit 2dfeb50
* Thu Feb 20 2014 neilb@suse.de
- FS-Cache: Handle removal of unadded object to the
  fscache_object_list rb tree (bnc#855885).
- commit a92ba96
* Mon Feb 17 2014 mszeredi@suse.cz
- cifs: ensure that uncached writes handle unmapped areas
  correctly (bnc#864025 CVE-2014-00691).
- commit fb9730e
* Mon Feb 17 2014 mhocko@suse.cz
- net: change type of virtio_chan->p9_max_pages (bnc#864058).
- vmscan: change type of vm_total_pages to unsigned long
  (bnc#864058).
- fs/nfsd: change type of max_delegations, nfsd_drc_max_mem and
  nfsd_drc_mem_used (bnc#864058).
- fs/buffer.c: change type of max_buffer_heads to unsigned long
  (bnc#864058).
- mm: fix return type for functions nr_free_*_pages kabi fixup
  (bnc#864058).
- mm: fix return type for functions nr_free_*_pages (bnc#864058).
- commit 63dfde5
* Mon Feb 17 2014 neilb@suse.de
- Refresh patches.fixes/nfs-sock-timeout.fix.
  Enhance patch to match upstream recommendations
- commit 8d7c322
* Fri Feb 14 2014 hare@suse.de
- Update patches.arch/s390-3270-asynchronous-size-sensing.patch
  (bnc#792991, LTC#87621, bnc#851597).
- commit 2c0b7a4
* Thu Feb 13 2014 mgorman@suse.de
- mm: swap: Use swapfiles in priority order
  (Use swap files in priority order (bnc#862957)).
- commit 72fb77c
* Wed Feb 12 2014 mfasheh@suse.de
- Fix return value from lockspace_busy()
  (https://bugzilla.novell.com/show_bug.cgi?id=827670#c43).
- commit eaa650c
* Wed Feb 12 2014 mkubecek@suse.cz
- ipvs: fix AF assignment in ip_vs_conn_new() (bnc#856848).
- commit 32eb20d
* Tue Feb 11 2014 neilb@suse.de
- Refresh patches.fixes/nfs-state-fix.
  add to series.conf
- commit 4b6df65
* Tue Feb 11 2014 neilb@suse.de
- patches.fixes/nfs-state-fix: NFS: don't try to use lock state
  when we hold a delegation (bnc#831029) - add to series.conf
- commit ffb87a0
* Tue Feb 11 2014 mmarek@suse.cz
- patches.fixes/nfs-reval-dot.fix: Fix patch tags
- commit 5f9363d
* Tue Feb 11 2014 mhocko@suse.cz
- arch/x86/mm/srat: Skip NUMA_NO_NODE while parsing SLIT
  (bnc#863178).
- commit acceaef
* Tue Feb 11 2014 mmarek@suse.cz
- Delete unused patches.fixes/megaraid-sas-kdump-crash-on-dell
- commit 6ae63ea
* Tue Feb 11 2014 mmarek@suse.cz
- Delete commented-out patches.fixes/nfsd-do-not-reg-v3-for-IPv6
- commit 90212fb
* Mon Feb 10 2014 jdelvare@suse.de
- patches.arch/iommu-vt-d-add-quirk-for-broken-interrupt.patch:
  Fix incorrect config symbol in #ifdef (bnc#844513).
- patches.arch/iommu-vt-d-expand-interrupt-remapping-quirk.patch:
  Refresh.
- commit d5b104b
* Mon Feb 10 2014 mgalbraith@suse.de
- Fix broken CONFIG_SCHED_DEBUG dependencies
- Refresh patches.fixes/sched-reinstate-sched_compat_yield.patch.
- Refresh patches.fixes/sched-throttle-nohz.patch.
- commit e978e4f
* Sat Feb  8 2014 mfasheh@suse.de
- Refresh
  patches.fixes/dlm-set-zero-linger-time-on-sctp-socket.patch.
- commit cb36753
* Fri Feb  7 2014 jjolly@suse.de
- crypto: s390 - fix des and des3_ede ctr concurrency issue
  (bnc#862796, LTC#103744).
- commit 8e3cc76
* Fri Feb  7 2014 jjolly@suse.de
- crypto: s390 - fix des and des3_ede cbc concurrency issue
  (bnc#862796, LTC#103743).
- commit bc439d1
* Fri Feb  7 2014 jjolly@suse.de
- kernel: oops due to linkage stack instructions (bnc#862796,
  LTC#103860).
- commit 4fa2eb7
* Fri Feb  7 2014 jjolly@suse.de
- crypto: s390 - fix concurrency issue in aes-ctr mode
  (bnc#862796, LTC#103742).
- commit e780878
* Fri Feb  7 2014 jjolly@suse.de
- dump: Fix dump memory detection (bnc#862796,LTC#103575).
- commit fd1b31f
* Fri Feb  7 2014 neilb@suse.de
- Refresh patches.fixes/nfs-lockd.fix.
  bug fix
- commit 0ab49fa
* Thu Feb  6 2014 neilb@suse.de
- Avoid occasional hang with NFS (bnc#852488).
- commit 6a4b4e2
* Thu Feb  6 2014 neilb@suse.de
- lockd: send correct lock when granting a delayed lock
  (bnc#859342).
- commit 289ba39
* Mon Feb  3 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-8173-introduce-lock_ref-unlock_ref.patch.
- commit 70e1555
* Mon Feb  3 2014 dsterba@suse.cz
- Btrfs: introduce lock_ref/unlock_ref (FATE#312888).
- Btrfs: move the extent buffer radix tree into the fs_info
  (FATE#312888).
- Btrfs: use a bit to track if we're in the radix tree
  (FATE#312888).
- Btrfs: deal with io_tree->mapping being NULL (FATE#312888).
- Btrfs: Simplify the logic in alloc_extent_buffer() for existing
  extent buffer case (FATE#312888).
- commit 3e80cc1
* Fri Jan 31 2014 dsterba@suse.cz
- Btrfs: introduce qgroup_ulist to avoid frequently
  allocating/freeing ulist (FATE#312888).
- Btrfs: fix memory patcher through fs_info->qgroup_ulist
  (FATE#312888).
- Btrfs: avoid double free of fs_info->qgroup_ulist (FATE#312888).
- Btrfs: fix crash regarding to ulist_add_merge (FATE#312888).
- Refresh
  patches.suse/btrfs-8109-fix-qgroup-rescan-resume-on-mount.patch.
- Refresh
  patches.suse/btrfs-8162-fix-oops-when-writing-dirty-qgroups-to-disk.patch.
- commit 5511b82
* Fri Jan 31 2014 dsterba@suse.cz
- Delete
  patches.suse/btrfs-8019-let-fiemap-flag-compressed-extents.patch.
- Delete
  patches.suse/btrfs-8022-forced-readonly-when-free_log_tree-fails.patch.
- Delete
  patches.suse/fs-FIEMAP-add-flag-for-compressed-extent.patch.
- commit d31147f
* Fri Jan 31 2014 ptesarik@suse.cz
- mpt2sas: Fix unsafe using smp_processor_id() in preemptible
  (bnc#853166).
- commit ed97f1b
* Thu Jan 30 2014 jbeulich@suse.com
- balloon: don't crash in HVM-with-PoD guests.
- hwmon: (coretemp) Fix truncated name of alarm attributes.
- Refresh patches.xen/1232-backends-reject-ring-overruns.patch
  (bnc#842553).
- Refresh patches.xen/xen-blkfront-discard,
  patches.xen/xen-blkfront-discard-secure (bnc#859009).
- Refresh other Xen patches.
- commit 02d1968
* Tue Jan 28 2014 eich@suse.com
- Refresh
  patches.drm/drm-mgag200-Added-resolution-and-bandwidth-limits-for-various-G200e-products.patch.
  Add mainline version.
- commit d5dc689
* Mon Jan 27 2014 jdelvare@suse.de
- NOHZ: Check for nohz active instead of nohz enabled
  (bnc#846790).
- nohz: Fix another inconsistency between CONFIG_NO_HZ=n and
  nohz=off (bnc#846790).
- commit b961729
* Fri Jan 24 2014 jdelvare@suse.de
- hwmon: (coretemp) Fix truncated name of alarm attributes
- commit e024645
* Wed Jan 22 2014 jdelvare@suse.de
- Delete patches.arch/iommu-vt-d-only-warn-on-broken-irq-remapping.patch
  This restores upstream (and SLE12) behavior when interrupt remapping
  is enabled on faulty hardware. That's what the customer wants
  (bnc#844513).
- commit 5c01f4e
* Wed Jan 22 2014 hare@suse.de
- scsi_dh_rdac: Add new IBM 1813 product id to rdac devlist
  (bnc#846654).
- commit 67a6019
* Tue Jan 21 2014 bp@suse.de
- rtc-cmos: Add an alarm disable quirk (bnc#805740).
- Delete patches.fixes/rtc-add-an-alarm-disable-quirk.patch.
  Add the backported upstream version.
- commit b26a51a
* Tue Jan 21 2014 mgalbraith@suse.de
- Add fix to futex scalability series ((bnc#851603), and update
  headers now that they're upstream.
- futexes: Fix futex_hashsize initialization (bnc#851603).
- Refresh patches.fixes/futex-Avoid-taking-the-hb-lock-if-there-is-nothing-to-wake-up.patch.
- Refresh patches.fixes/futex-Clean-up-various-details.patch.
- Refresh patches.fixes/futex-Document-multiprocessor-ordering-guarantees.patch.
- Refresh patches.fixes/futex-Increase-hash-table-size-for-better-performance.patch.
- commit ba49ee7
* Tue Jan 21 2014 neilb@suse.de
- Refresh patches.fixes/nfs-reval-dot.fix.
  fix Git-commit tag
- commit eb998d3
* Tue Jan 21 2014 neilb@suse.de
- patches.fixes/md-readd-fix: md: Change handling of
  save_raid_disk and metadata update during recovery (bnc#849364).
- commit e2e45cd
* Mon Jan 20 2014 mmarek@suse.cz
- Delete patches.drivers/libata-ahci-aspire-3810t-noncq
  This has been fixed in upstream properly, the patch just needlessly
  disables NCQ on the affected system.
- commit 6064ead
* Fri Jan 17 2014 lduncan@suse.com
- Fixed git-commit -> Git-commit, updated some
  Patch-mainline, as needed.
- commit 7b05a3c
* Fri Jan 17 2014 ddiss@suse.de
- patches.fixes/cifs-cleanup-cifs_filldir.patch
- patches.fixes/cifs-don-t-instantiate-new-dentries-in-readdir-for-i.patch
- patches.fixes/cifs-get-rid-of-blind-d_drop-in-readdir.patch
- patches.fixes/cifs-rename-cifs_readdir_lookup-to-cifs_prime_dcache.patch
- patches.fixes/cifs-revalidate-directories-instiantiated-via-FIND_-in-or.patch
  Add missing Git-commit tags.
- commit 17a91cd
* Fri Jan 17 2014 mmarek@suse.cz
- Update s390 kabi files (bnc#848335)
- commit 3c612b5
* Fri Jan 17 2014 tiwai@suse.de
- Revert "HID: multitouch: Add support for NextWindow 0340 touchscreen"
  This reverts commit 5fa212b283950fd46819cb062337f86865af7449.
  The device turned out to be incompatible with Win8 standard.
- commit 6049ed6
* Fri Jan 17 2014 mmarek@suse.cz
- S390: Avoid kabi change due to newly visible structures.
- commit e8f693f
* Fri Jan 17 2014 mmarek@suse.cz
- Import kabi files from 3.0.101-0.8
- commit bd6ba1f
* Fri Jan 17 2014 jlee@suse.com
- Refresh to v3.13 patch
- X.509: Fix certificate gathering (bnc#805114).
- Delete
  patches.fixes/0001-MODSIGN-Fix-including-certificate-twice-when-the-si.patch.
- commit 7372528
* Fri Jan 17 2014 acho@suse.com
- Update GIT commit headers.
- Refresh
  patches.fixes/bug-722429_0001-add-device-entry-for-Broadcom-Valentine-combo-card.patch
- commit d3bb2ab
* Fri Jan 17 2014 hare@suse.de
- patches.drivers/ibmvfc-fix-for-offlining-devices.patch: Update
  patch header.
- commit 3b54be6
* Fri Jan 17 2014 tiwai@suse.de
- HID: multitouch: Add support for NextWindow 0340 touchscreen
  (bnc#849855).
- HID: multitouch: Add support for Qaunta 3027 touchscreen
  (bnc#854516).
- HID: multitouch: add support for Atmel 212c touchscreen
  (bnc#793727).
- HID: multitouch: partial support of win8 devices
  (bnc#854516,bnc#793727,bnc#849855).
- HID: hid-multitouch: add support for the IDEACOM 6650 chip
  (bnc#854516,bnc#793727,bnc#849855).
- commit 5fa212b
* Thu Jan 16 2014 mmarek@suse.cz
- patches.fixes/X.509-time-h-include: Replace with upstream version
- commit eeaa6d5
* Thu Jan 16 2014 tiwai@suse.de
- Update git-commit and patch-mainline tags
  patches.arch/x86-check-for-valid-irq_cfg-pointer-in-smp_irq_move_cleanup_interrupt.patch
  patches.arch/x86-kdump-ioapic_reset-remote-IRR-in-clear_IO_APIC.patch
  patches.arch/x86-pci-Increase-the-number-of-iommus-supported-to-be-MAX_IO_APICS.patch
  patches.arch/x86_PCI-Preserve-existing-pci_bfsort-whitelist-for-Dell-systems.patch
  patches.drivers/pci-introduce-option-to-disable-ARI.patch
  patches.fixes/Documentation-fix-typo-in-freezer-subsystem_txt.patch
  patches.fixes/pci-pciehp-fix-pcied_cleanup.patch
- commit c7b8752
* Thu Jan 16 2014 oneukum@suse.de
- Refresh
  patches.fixes/0001-pciehp-By-default-handle-resume.patch.
- commit 41f1ee7
* Thu Jan 16 2014 duwe@suse.de
- Delete patches.arch/ppc-fate-312285-1.
  It only #defines PCIE_DEVICE_ID_NEO_2_OX_IBM in
  include/linux/pci_ids.h, but with linux-3.0, that definition
  has also made it into drivers/tty/serial/8250_pci.c
- commit 4f845b6
* Thu Jan 16 2014 oneukum@suse.de
- Refresh
  patches.fixes/0001-USB-sd-sd_start_stop_device-proper-error-codes.patch.
- Refresh
  patches.fixes/SCSI-sd-error-handling-in-sd_sync_cache.patch.
- commit 664d83a
* Thu Jan 16 2014 tiwai@suse.de
- Refresh patches.drivers/rt2x00-Fix-rfkill_polling-register-function.
  Update git-commit and patch-mainline tags
- commit 9c7eee6
* Thu Jan 16 2014 tiwai@suse.de
- Refresh patches.drivers/rt2x00-fix_rt3290_resuming.patch.
  Update git-commit and patch-mainline tags
- commit c169b28
* Thu Jan 16 2014 tiwai@suse.de
- Refresh patches.drivers/0017-rt2x00-Fix-PCI-interrupt-processing-race-on-SMP-syst.patch.
  Add missing commit-id tag
- commit 86c1e62
* Thu Jan 16 2014 oneukum@suse.de
- patches.drivers/0005-modify-hub-to-detect-unplugs-in-all-states.patch:
  (bnc#807560).
- Refresh
  patches.drivers/usb-storage-add-quirk-for-mandatory-READ_CAPACITY_16.patch.
- Refresh
  patches.fixes/0003-SCSI-sd-sd_start_stop_device-error-handling.patch.
- commit 0e2e43d
* Thu Jan 16 2014 oneukum@suse.de
- Refresh patches.drivers/btusb-add-mt76x0e.patch.
- commit 28b82d8
* Thu Jan 16 2014 oneukum@suse.de
- Refresh
  patches.drivers/0001-xhci-endianness-xhci_calculate_intel_u2_timeout.patch.
- commit 31f3809
* Thu Jan 16 2014 hare@suse.de
- Replaced lpfc patches with official version (bnc#818064)
- No functional change, only version update.
- Added:
  * patches.drivers/lpfc-8.3.7.10.6p-Fix-Crash-in-lpfc_els_timeout_handler.patch
  * patches.drivers/lpfc-8.3.7.10.6p-Fix-kernel-panic-from-corrupted-ndlp-list.patch
  * patches.drivers/lpfc-8.3.7.10.6p-Update-lpfc-version-for-8.3.7.10.7p-driver-release.patch
- Deleted:
  patches.drivers/lpfc-correct-an-issue-with-rrq-processing.patch.
  patches.drivers/lpfc-correct-some-issues-with-txcomplq-processing.patch.
- commit 1ab2688
* Thu Jan 16 2014 hare@suse.de
- Delete
  patches.fixes/dm-mpath-abort-all-requests-when-failing-a-path.patch.
- commit b9b9940
* Thu Jan 16 2014 neilb@suse.de
- Refresh patches.suse/md-Do-not-block-when-displaying-info.patch.
  git-commit update.
- commit ae3b485
* Wed Jan 15 2014 mmarek@suse.cz
- s390/pci: remove PCI/MSI interruption class (FATE#83037, LTC#94737).
- commit b430c5a
* Wed Jan 15 2014 duwe@suse.de
- Fill in more upstream headers.
- commit e59c904
* Wed Jan 15 2014 mgorman@suse.de
- mm: reschedule to avoid RCU stall triggering during boot of large machines
  (bnc#820434,bnc#852153).
- commit 19627ce
* Wed Jan 15 2014 oneukum@suse.de
- efifb: prevent null-deref when iterating dmi_list (bnc#848055).
- commit c8cce5f
* Wed Jan 15 2014 jslaby@suse.cz
- x86/PCI: reduce severity of host bridge window conflict warnings
  (bnc#858534).
- commit 6bcd247
* Wed Jan 15 2014 hare@suse.de
- scsi_dh_alua: fixup misplaced brace in alua_initialize()
  (bnc#858831).
- commit fc09d03
* Wed Jan 15 2014 jbeulich@suse.com
- Refresh Xen patches (bnc#807434, bnc#848652, bnc#852624).
- commit 0e621ee
* Wed Jan 15 2014 neilb@suse.de
- Update Git-commit: headers
- Refresh patches.fixes/dcache-soft-lockup.fix.
- Refresh
  patches.fixes/net-sunrpc-xpt_auth_cache-should-be-ignored-when-exp.patch.
- Refresh patches.fixes/nfs-slot-table-alloc.
- Refresh
  patches.fixes/sunrpc-cache-ensure-items-removed-from-cache-do-not-.patch.
- Refresh
  patches.fixes/sunrpc-cache-remove-races-with-queuing-an-upcall.patch.
- Refresh
  patches.fixes/sunrpc-cache-use-cache_fresh_unlocked-consistently-a.patch.
- commit 0146711
* Tue Jan 14 2014 jdelvare@suse.de
- Merge patches.arch/x86-mce-xeon75xx-fix-typo-causing-a-kernel-crash.patch,
  patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch and
  patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch into
  patches.arch/x86_mce_intel_decode_physical_address.patch.
  These are not upstream so there is no point in keeping seperate patches
  for the bugfixes.
- commit 3e653e3
* Tue Jan 14 2014 duwe@suse.de
- Add mainline tags to some IBM patches (ipr, ppc, s390).
- commit 6861613
* Tue Jan 14 2014 mgalbraith@suse.de
- Futex scalability (bnc#851603)
- futex: move user address verification up to common code (bnc#851603).
- futexes: Clean up various details (bnc#851603).
- futexes: Increase hash table size for better performance (bnc#851603).
- futexes: Document multiprocessor ordering guarantees (bnc#851603).
- futexes: Avoid taking the hb->lock if there's nothing to wake up (bnc#851603).
- commit 7943354
* Mon Jan 13 2014 bpoirier@suse.de
- Refresh
  patches.drivers/bnx2x-0003-broadcom-Move-the-Broadcom-drivers.patch.
- Delete patches.drivers/bnx2x-remove-WARN_ON.patch.
  The removed patch made it upstream in the form of the already present
  patches.drivers/bnx2x-0031-bnx2x-remove-false-warning-regarding-interrupt-numbe.patch
- commit e1210b6
* Mon Jan 13 2014 bpoirier@suse.de
- Delete
  patches.suse/drivers-net-Add-README-about-driver-re-organization.patch.
  Used to document that the network driver subdirectory reorganisation done in
  3.2 was backported to SP3. It was there to help partners do the backports I
  think. I've removed it now, as it's not really needed anymore.
- commit de8dfa9
* Mon Jan 13 2014 bpoirier@suse.de
- patches.drivers/bnx2x-remove-false-warning-regarding-interrupt-numbe.patch:
  bnx2x: remove false warning regarding interrupt number
  (bnc#769035).
- patches.drivers/bnx2x-remove-WARN_ON.patch: Delete.
- commit 735ad98
* Mon Jan 13 2014 jbeulich@suse.com
- Refresh Xen patches (bnc#807434, bnc#848652, bnc#852624).
- commit 431e4cb
* Mon Jan 13 2014 hare@suse.de
- Update patch headers with correct commit IDs
  * patches.drivers/0032-fcoe-libfcoe-Move-common-code-for-fcoe_get_lesb-to-f.patch.
  * patches.drivers/0040-be2iscsi-Fix-MSI-X-Interrupt-Names.patch.
  * patches.drivers/be2net-0146-be2net-enable-interrupts-in-be_probe-RoCE-and-other-.patch.
  * patches.drivers/be2net-0147-Use-new-F-W-mailbox-cmd-to-manipulate-interru.patch.
  * patches.drivers/fcoe-0063-libfcoe-check-for-unuseable-fcfs.patch.
  * patches.drivers/fcoe-0064-libfcoe-handle-cvl-while-waiting.patch.
  * patches.drivers/fnic-FIP-VLAN-Discovery-Feature-Support.patch.
  * patches.drivers/fnic-Fix-memory-leak-issue-in-Vlan-Discovery.patch.
  * patches.drivers/fnic-Fnic-Trace-Utility.patch.
  * patches.drivers/fnic-Incremented-driver-version.patch.
  * patches.drivers/fnic-Kernel-panic-due-to-FIP-mode-misconfiguration.patch.
  * patches.drivers/fnic-New-debug-flags-and-debug-log-messages.patch.
  * patches.drivers/fnic-fnic-driver-may-hit-BUG_ON-on-device-reset.patch.
  * patches.drivers/fnic-updated-MAINTAINERS-list.patch.
  * patches.drivers/libata-ahci-aspire-3810t-noncq.
  * patches.drivers/mpt2sas-EEH_recovery-for-sles11-sp3.patch.
  * patches.drivers/xhci_bad_pci_irq.patch.
  * block: fix max discard sectors limit (bnc#813643).
  * patches.fixes/scsi-check-host-lookup-failure.
  * patches.fixes/scsi-dh-fixup-kernel-doc.
  * patches.fixes/scsi-handle-MLQUEUE-busy-response-in-scsi_send_eh_cmnd.patch.
  * patches.fixes/sd-avoid-deadlocks-when-running-under-multipath.patch.
  * patches.suse/dasd-Abort-all-requests-from-ioctl.patch.
  * patches.suse/dasd-Clarify-comment.patch.
  * patches.suse/dasd-Disable-block-timeouts-per-default.patch.
  * patches.suse/dasd-Implement-failfast_retries.patch.
  * patches.suse/dasd-Reduce-amount-of-messages-for-specific-errors.patch.
  * patches.suse/dasd-Rename-ioctls.patch.
  * patches.suse/dasd-blk-timeout.patch.
  * patches.suse/dasd-continue-device-tasklet.patch.
  * patches.suse/dasd-detailed-io-errors.patch.
  * patches.suse/dasd-fail-all-requests-after-timeout.patch.
  * patches.suse/dasd-lock-ccw-queue-in-dasd_times_out.patch.
  * patches.suse/dasd-make-DASD_FLAG_TIMEOUT-setting-more-robust.patch.
  * patches.suse/dasd-make-number-of-retries-configurable.patch.
  * patches.suse/dasd-rename-flag-to-abortall.patch.
  * patches.suse/dasd-timeout-attribute.patch.
- commit f7a4d1e
* Mon Jan 13 2014 mgalbraith@suse.de
- patches.fixes/sched-rt-Fix-rq-cpupri-leak-while-enqueue-dequeue-child-RT.patch:
  sched/rt: Fix rq's cpupri leak while enqueue/dequeue child RT entities.
- commit ab54c42
* Mon Jan 13 2014 mgalbraith@suse.de
- patches.fixes/sched-rt-Use-root_domain-of-rt_rq-not-current-processor.patch:
  sched/rt: Use root_domain of rt_rq not current processor (bnx#857919).
- commit 7ef046e
* Mon Jan 13 2014 neilb@suse.de
- Update some git-commit headers
- commit 5924b3b
* Sat Jan 11 2014 lduncan@suse.com
- Fixing git-commit and patch-mainline tags
- commit 5c3a461
* Fri Jan 10 2014 ohering@suse.de
- Update patch headers:
  patches.arch/ppc-efika-mpc52xx-ac97.patch
  patches.arch/ppc-efika-psc-console-autodetection.patch
  patches.arch/ppc64-xmon-dmesg-printing.patch
  patches.drivers/ehea-modinfo.patch
  patches.suse/apm_setup_UP.diff
  patches.suse/mkinitrd-scsi_host_template-proc_name.patch
  patches.suse/nameif-track-rename.patch
  patches.suse/radeon-monitor-jsxx-quirk.patch
  patches.suse/suse-hv-HV_DRV_VERSION.patch
  patches.suse/suse-hv-bind-hv_blkkvsc-to-hv_storvsc.patch
  patches.suse/suse-hv-bind-hv_mouse-to-hid-hyperv.patch
  patches.suse/suse-hv-guest-os-id.patch
  patches.suse/suse-hv-hv_kvp-sles11sp2-negotiate-serveral-versions.patch
  patches.suse/suse-hv-storvsc-scsi-proc_name.patch
- commit e567845
* Fri Jan 10 2014 jeffm@suse.de
- ceph: update patch tags
  Many of the patches were missing Git-commit tags and the majority of
  the Patch-mainline tags were inaccurate.
- commit 247baaa
* Fri Jan 10 2014 jeffm@suse.de
- Fix patch header whitespace.
- commit 356dd28
* Fri Jan 10 2014 jeffm@suse.de
- Updated patch tags.
- commit 8f2f4e7
* Fri Jan 10 2014 tiwai@suse.de
- Refresh patches.drivers/hp_accel-ignore-resume-error.
- Refresh
  patches.fixes/0001-xhci-Fix-spurious-wakeups-after-S5-on-Haswell.patch.
- commit 2e5c1e6
* Fri Jan 10 2014 mmarek@suse.cz
- rpm/mkspec: Fix for older Perl
- commit 87563ea
* Fri Jan 10 2014 mmarek@suse.cz
- rpm/mkspec: Stop generating _constraints.changes
- commit c7a74fa
* Fri Jan 10 2014 tiwai@suse.de
- Refresh
  patches.drivers/alsa-sp3-0012-Re-setup-HDMI-pin-and-audio-infoframe-on-st.
- Refresh
  patches.drivers/alsa-sp3-0014-load-EQ-params-into-IDT-codec-on-HP-bNB13.
- Refresh
  patches.drm/3299-drm-i915-Disable-GGTT-PTEs-on-GEN6-suspend.
- commit 85a64b5
* Fri Jan 10 2014 ptesarik@suse.cz
- Updated patch headers
  patches.arch/fadump-01-documentation.patch
  patches.arch/fadump-02-reserve_mem.patch
  patches.arch/fadump-03-register_dump.patch
  patches.arch/fadump-04-create_elfcorehdr.patch
  patches.arch/fadump-05-read_cpudump_data.patch
  patches.arch/fadump-06-add_vmcoreinfo.patch
  patches.arch/fadump-07-vmcore_cleanup.patch
  patches.arch/fadump-08-release_mem.patch
  patches.arch/fadump-09-shutdown_cleanup.patch
  patches.arch/fadump-10-remove_phypdump.patch
  patches.arch/ia64-resvd-overlap
- commit e431578
* Fri Jan 10 2014 oneukum@suse.de
- Refresh
  patches.suse/0001-elousb-some-systems-cannot-stomach-work-around.patch.
- commit 588b110
* Fri Jan 10 2014 oneukum@suse.de
- refresh patches.suse/bug-853428-scsi_device-fix-kabi.patch
- commit 6ddecbc
* Fri Jan 10 2014 oneukum@suse.de
- Refresh patches.suse/0002-xhci-hub.c-preserved-kABI.patch.
- commit 7edee1b
* Fri Jan 10 2014 oneukum@suse.de
- Refresh
  patches.suse/0001-storage-SMI-Corporation-usb-key-added-to-READ_CAPACI.patch.
- commit 970ba1c
* Fri Jan 10 2014 oneukum@suse.de
- Refresh
  patches.drivers/0001-uvc-increase-number-of-buffers.patch.
- commit 2fa2c8c
* Fri Jan 10 2014 oneukum@suse.de
- Refresh
  patches.suse/0001-elousb-really-long-delays-for-broken-devices.patch.
- commit 83a8f59
* Fri Jan 10 2014 oneukum@suse.de
- Refresh
  patches.drivers/0001-uvc-increase-number-of-buffers.patch.
- commit f9cfb93
* Fri Jan 10 2014 jack@suse.cz
- Updated patch headers
  patches.fixes/writeback-do-not-sync-data-dirtied-after-sync-start.patch.
- commit f491dbc
* Fri Jan 10 2014 mhocko@suse.cz
- Refresh patches.fixes/mm-oom-fix-totalpages-calculation.patch.
- commit 6fddd07
* Fri Jan 10 2014 jack@suse.cz
- Updated patch header: patches.fixes/reiserfs-writeback-buffer-lock.patch.
- commit dae7e53
* Fri Jan 10 2014 jack@suse.cz
- Updated patch headers:
- Refresh
  patches.fixes/jbd-Issue-cache-flush-after-checkpointing.patch.
- Refresh patches.fixes/large-hash-dcache_init-fix.patch.
- Refresh patches.fixes/ocfs2-readpage-livelock.patch.
- Refresh patches.fixes/reiserfs-writeback-buffer-lock.patch.
- Refresh
  patches.fixes/writeback-do-not-sort-b_io-list-only-because-of-bloc.patch.
- Refresh
  patches.fixes/writeback-include-all-inodes-in-background.patch.
- Refresh
  patches.fixes/xfs-Fix-WARN_ON-delalloc-in-xfs_vm_releasepage.patch.
- Refresh patches.fixes/xfs-backward-alloc-fix.diff.
- commit 9ed16de
* Thu Jan  9 2014 lduncan@suse.com
- Corrected Git-commit and Patch-mainline patch tags
- commit 815b8bb
* Thu Jan  9 2014 bpoirier@suse.de
- patches.fixes/net-Do-not-enable-tx-nocache-copy-by-default.patch:
  net: Do not enable tx-nocache-copy by default (bnc#845378).
- commit 08ab4c3
* Thu Jan  9 2014 lduncan@suse.com
- Fixing one last patch with bogus git-commit header
- commit d393381
* Thu Jan  9 2014 lduncan@suse.com
- Fixing git-commit and related patch headers
- commit bbae9dc
* Thu Jan  9 2014 mhocko@suse.cz
- Refresh patches.suse/readahead-request-tunables.patch
  CONFIG_KERNEL_DESKTOP is not set for any kernel flavor/arch so get
  rid of ifdef-ery
- commit e2670b5
* Thu Jan  9 2014 mgorman@suse.de
- Refresh
  patches.drivers/ixgbe-0317-netvm-propagate-page-pfmemalloc-from-skb_alloc_page-.patch.
  patches.drivers/ixgbevf-0053-netvm-propagate-page-pfmemalloc-from-skb_alloc_page-.patch.
  patches.fixes/cpuset-mm-optimise-put_mems_allowed-usage.patch.
  patches.fixes/memcg-further-prevent-OOM-with-too-many-dirty-pages.patch.
  patches.fixes/mm-VFS--mount-lock-scalability-for-internal-mounts.patch.
  patches.fixes/mm-bug-completely-remove-code-generated-by-disabled-VM_BUG_ON.patch.
  patches.fixes/mm-bug-introduce-BUILD_BUG_ON_INVALID-macro.patch.
  patches.fixes/mm-compaction-Use-synchronous-compaction-for--proc-sys-vm-compact_memory.patch.
  patches.fixes/mm-consider-PageReclaim-for-sync-reclaim.patch.
  patches.fixes/mm-do-not-walk-all-of-system-ram-during-show_mem.patch.
  patches.fixes/mm-honor-min_free_kbytes-set-by-user.patch.
  patches.fixes/mm-hugetlb-flush_tlb_range-needs-page_table_lock-when-mmap_sem-is-not-held.patch.
  patches.fixes/mm-hugetlb.c-undo-change-to-page-mapcount-in-fault-handler.patch.
  patches.fixes/mm-hugetlbfs-Correctly-detect-if-page-tables-have-just-been-shared.patch.
  patches.fixes/mm-hugetlbfs-fix-use-after-free-bug-in-quota-handling.patch.
  patches.fixes/mm-link_mem_sections-touch-nmi-watchdog.patch.
  patches.fixes/mm-make-snapshotting-pages-for-stable-writes-a-per-bio-operation.patch.
  patches.fixes/mm-make-swapin-readahead-skip-over-holes.patch.
  patches.fixes/mm-mempolicy.c-fix-pgoff-in-mbind-vma-merge.patch.
  patches.fixes/mm-mempolicy.c-refix-mbind_range-vma-issue.patch.
  patches.fixes/mm-page_alloc-avoid-marking-zones-full-prematurely.patch.
  patches.fixes/mm-remove-ZAP_BLOCK_SIZE.patch.
  patches.fixes/mm-stop_machine-implement-stop_machine_from_inactive_cpu.patch.
  patches.fixes/mm-stop_machine-reorganize-stop_cpus-implementation.patch.
  patches.fixes/mm-swap-mark-pages-writeback-before-dio.patch.
  patches.fixes/mm-swap-redirty-page-if-swap-file-write-fails.patch.
  patches.fixes/mm-swap-token-makes-global-variables-to-function-local.patch.
  patches.fixes/mm-thp-minor-lock-simplification-in-__khugepaged_exit.patch.
  patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback-fix-2.patch.
  patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback-fix.patch.
  patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback.patch.
  patches.fixes/mm-vmscan-Check-if-kswapd-should-writepage-once-per-pgdat-scan.patch.
  patches.fixes/mm-vmscan-Decide-whether-to-compact-the-pgdat-based-on-reclaim-progress.patch.
  patches.fixes/mm-vmscan-Do-not-allow-kswapd-to-scan-at-maximum-priority.patch.
  patches.fixes/mm-vmscan-Flatten-kswapd-priority-loop.patch.
  patches.fixes/mm-vmscan-Have-kswapd-writeback-pages-based-on-dirty-pages-encountered-not-priority.patch.
  patches.fixes/mm-vmscan-Limit-the-number-of-pages-kswapd-reclaims-at-each-priority.patch.
  patches.fixes/mm-vmscan-Move-logic-from-balance_pgdat-to-kswapd_shrink_zone.patch.
  patches.fixes/mm-vmscan-Obey-proportional-scanning-requirements-for-kswapd.patch.
  patches.fixes/mm-vmscan-do-not-continue-if-aborted-for-compaction.patch.
  patches.fixes/mm-vmscan-drop-nr_force_scan-from-get_scan_count.patch.
  patches.fixes/mm-vmscan-move-direct-reclaim-wait_iff_congested-into-shrink_list.patch.
  patches.fixes/mm-vmscan-set-zone-flags-before-blocking.patch.
  patches.fixes/mm-vmscan-stall-page-reclaim-after-a-list-of-pages-have-been-processed-v3.patch.
  patches.fixes/mm-vmscan-stall-page-reclaim-and-writeback-pages-based-on-dirty-writepage-pages-encountered-v3.patch.
  patches.fixes/mm-vmscan-take-page-buffers-dirty-and-locked-state-into-account-v3-KABI-fix.patch.
  patches.fixes/mm-vmscan-take-page-buffers-dirty-and-locked-state-into-account-v3-KABI.patch.
  patches.fixes/mm-vmscan-take-page-buffers-dirty-and-locked-state-into-account-v3.patch.
  patches.fixes/mm-vmscan-trace-Add-file-info-to-trace_mm_vmscan_lru_isolate.patch.
  patches.fixes/mm-vmscan-treat-pages-marked-for-immediate-reclaim-as-zone-congestion.patch.
  patches.fixes/mm-x86,-mtrr-use-stop_machine-APIs-for-doing-MTRR-rendezvous.patch.
  patches.fixes/mm-x86-Serialize-SMP-bootup-CMOS-accesses-on-rtc_lock.patch.
  patches.suse/ia64-mm-wire-up-cross-memory-attach-syscalls.patch.
  patches.suse/mm-Fix-race-in-process_vm_rw_core.patch.
  patches.suse/mm-aio-vfs-cleanup-of-rw_copy_check_uvector-and-compat_rw_copy_check_uvector.patch.
  patches.suse/mm-mremap-avoid-sending-one-ipi-per-page.patch.
  patches.suse/mm-mremap-check-for-overflow-using-deltas.patch.
  patches.suse/mm-netvm-propagate-page--pfmemalloc-from-netdev_alloc_page-to-skb.patch.
  patches.suse/mm-thp-mremap-support-and-tlb-optimization.patch.
  patches.suse/mm-use-cpu_chill-in-spin_trylock_page.patch.
  patches.suse/mm-vmscan-add-customisable-shrinker-batch-size.patch.
  patches.suse/s390-fix-compact-wrappers-for-process_vm-fix.patch.
  patches.suse/s390-fix-compact-wrappers-for-process_vm.patch.
  patches.suse/s390-mm-wire-up-cross-memory-attach-syscalls.patch.
- commit e9f8aa3
* Thu Jan  9 2014 oneukum@suse.de
- Refresh
  patches.drivers/0001-USB-Add-helper-macro-for-usb_driver-boilerplate.patch.
- Refresh
  patches.drivers/0001-USB-Add-macros-for-interrupt-endpoint-types.patch.
- Refresh
  patches.drivers/0001-USB-Add-support-to-enable-disable-USB3-link-states.patch.
- Refresh
  patches.drivers/0001-USB-Adding-define-in-hub_configure-and-hcd.c-file.patch.
- Refresh
  patches.drivers/0001-USB-Allow-drivers-to-disable-hub-initiated-LPM.patch.
- Refresh
  patches.drivers/0001-USB-Calculate-USB-3.0-exit-latencies-for-LPM.patch.
- Refresh
  patches.drivers/0001-USB-Disable-USB-3.0-LPM-in-critical-sections.patch.
- Refresh
  patches.drivers/0001-USB-Disable-hub-initiated-LPM-for-comms-devices.patch.
- Refresh
  patches.drivers/0001-USB-Fix-core-compile-with-CONFIG_USB_SUSPEND-n.patch.
- Refresh
  patches.drivers/0001-USB-Make-sure-to-fetch-the-BOS-desc-for-roothubs.patch.
- Refresh
  patches.drivers/0001-USB-Refactor-code-to-set-LPM-support-flag.patch.
- Refresh
  patches.drivers/0001-USB-convert-drivers-bluetooth-to-use-module_usb_driv.patch.
- Refresh
  patches.drivers/0001-USB-convert-drivers-net-to-use-module_usb_driver.patch.
- Refresh
  patches.drivers/0001-USB-convert-some-miscellanies-drivers-to-use-module_.patch.
- Refresh
  patches.drivers/0001-USB-fix-bug-of-device-descriptor-got-from-superspeed.patch.
- Refresh patches.drivers/0001-USB-remove-BKL-comments.patch.
- Refresh
  patches.drivers/0001-driver-core-Allow-additional-parameters-for-module_d.patch.
- Refresh
  patches.drivers/0001-drivercore-Generalize-module_platform_driver.patch.
- Refresh
  patches.drivers/0001-kernel-doc-fix-new-warnings-in-device.h.patch.
- Refresh
  patches.drivers/0001-usb-Add-support-for-root-hub-port-status-CAS.patch.
- Refresh
  patches.drivers/0001-usb-ch9-define-Set-SEL-and-Set-Isoch-Delay-macros.patch.
- Refresh
  patches.drivers/0001-usb-host-xhci-Fix-Compliance-Mode-on-SN65LVPE502CP-H.patch.
- Refresh
  patches.drivers/0001-xHCI-Adding-define-values-used-for-hub-descriptor.patch.
- Refresh
  patches.drivers/0001-xHCI-Kick-khubd-when-USB3-resume-really-completes.patch.
- Refresh
  patches.drivers/0001-xhci-Add-Intel-U1-U2-timeout-policy.patch.
- Refresh
  patches.drivers/0001-xhci-Add-infrastructure-for-host-specific-LPM-polici.patch.
- Refresh
  patches.drivers/0001-xhci-Add-roothub-code-to-set-U1-U2-timeouts.patch.
- Refresh
  patches.drivers/0001-xhci-Fix-compile-with-CONFIG_USB_SUSPEND-n.patch.
- Refresh
  patches.drivers/0001-xhci-Remove-scary-warnings-about-transfer-issues.patch.
- Refresh
  patches.drivers/0001-xhci-Remove-warnings-about-MSI-and-MSI-X-capabilitie.patch.
- Refresh
  patches.drivers/0001-xhci-Reserve-one-command-for-USB3-LPM-disable.patch.
- Refresh
  patches.drivers/0001-xhci-Some-Evaluate-Context-commands-must-succeed.patch.
- Refresh
  patches.drivers/0002-USB-xhci-Enable-remote-wakeup-for-USB3-devices.patch.
- Refresh
  patches.drivers/0003-USB-Suspend-functions-before-putting-dev-into-U3.patch.
- Refresh
  patches.drivers/0004-USB-xHCI-Enable-USB-3.0-hub-remote-wakeup.patch.
- Refresh
  patches.drivers/0005-USB-Refactor-hub-remote-wake-handling.patch.
- Refresh
  patches.drivers/0006-USB-xHCI-Support-device-initiated-USB-3.0-resume.patch.
- Refresh
  patches.drivers/0007-USB-Set-wakeup-bits-for-all-children-hubs.patch.
- Refresh
  patches.drivers/0008-USB-Turn-on-auto-suspend-for-USB-3.0-hubs.patch.
- Update
  patches.drivers/usb-storage-add-quirk-for-mandatory-READ_CAPACITY_16.patch
  (bnc#853428).
- Refresh
  patches.fixes/0001-usbhid-fix-error-handling-of-not-enough-bandwidth.patch.
- commit e17fa7d
* Thu Jan  9 2014 hare@suse.de
- patches.fixes/dm-mpath-abort-all-requests-when-failing-a-path.patch:
  Delete; shouldn't be part of the update.
- commit 9d22177
* Thu Jan  9 2014 hare@suse.de
- patches.drivers/0030-scsi-Added-support-for-adapter-and-firmware-reset.patch:
  Refresh.
- patches.fixes/dm-mpath-abort-all-requests-when-failing-a-path.patch:
  dm-multipath: abort all requests when failing a path
  (bnc#798050).
- patches.fixes/scsi-Add-eh_deadline-to-limit-SCSI-EH-runtime.patch:
  scsi: Add 'eh_deadline' to limit SCSI EH runtime (bnc#798050).
- patches.fixes/scsi-Allow-error-handling-timeout-to-be-specified.patch:
  scsi: Allow error handling timeout to be specified (bnc#798050).
- patches.fixes/scsi-Fixup-compilation-warning.patch: scsi:
  Fixup compilation warning (bnc#798050).
- patches.fixes/scsi-Retry-failfast-commands-after-EH.patch:
  scsi: Retry failfast commands after EH (bnc#798050).
- patches.fixes/scsi-Warn-on-invalid-command-completion.patch:
  scsi: Warn on invalid command completion (bnc#798050).
- patches.fixes/scsi-advansys-Remove-last_reset-references.patch:
  advansys: Remove 'last_reset' references (bnc#798050).
- patches.fixes/scsi-cleanup-setting-task-state-in-scsi_error_handler.patch:
  cleanup setting task state in scsi_error_handler() (bnc#798050).
- patches.fixes/scsi-dc395-Move-last_reset-into-internal-host-structure.patch:
  dc395: Move 'last_reset' into internal host structure
  (bnc#798050).
- patches.fixes/scsi-dpt_i2o-Remove-DPTI_STATE_IOCTL.patch:
  dpt_i2o: Remove DPTI_STATE_IOCTL (bnc#798050).
- patches.fixes/scsi-dpt_i2o-return-SCSI_MLQUEUE_HOST_BUSY-when-in-reset.patch:
  dpt_i2o: return SCSI_MLQUEUE_HOST_BUSY when in reset
  (bnc#798050).
- patches.fixes/scsi-kABI-fixes.patch: scsi: kABI fixes
  (bnc#798050).
- patches.fixes/scsi-remove-check-for-resetting.patch: scsi:
  remove check for 'resetting' (bnc#798050).
- patches.fixes/scsi-tmscsim-Move-last_reset-into-host-structure.patch:
  tmscsim: Move 'last_reset' into host structure (bnc#798050).
- commit 0bdb320
* Thu Jan  9 2014 mmarek@suse.cz
- Refresh
  patches.arch/x86-apicv-add-virtual-interrupt-delivery-support.patch.
- commit 2cbcc15
* Thu Jan  9 2014 dsterba@suse.cz
- Refresh patches.fixes/crc32-0010-select-an-algorithm-via-Kconfig.patch.
- commit c44ef8e
* Thu Jan  9 2014 mgalbraith@suse.de
- Fix headers
- Refresh patches.fixes/perf-Change-and-simplify-ctx-is_active-semantics.
- Refresh patches.fixes/perf-Change-close-semantics-for-group-events.
- Refresh patches.fixes/perf-Clean-up-ctx-reference-counting.
- Refresh patches.fixes/perf-Collect-the-schedule-in-rules-in-one-function.
- Refresh patches.fixes/perf-De-schedule-a-task-context-when-removing-the-last-event.
- Refresh patches.fixes/perf-Optimize-ctx_sched_out.
- Refresh patches.fixes/perf-Optimize-event-scheduling-locking.
- Refresh patches.fixes/perf-Remove-task_ctx_sched_in.
- Refresh patches.fixes/perf-Simplify-and-fix-__perf_install_in_context.
- Refresh patches.fixes/perf-core-Fix-initial-task_ctx-slash-event-installation.
- Refresh patches.fixes/perf-events-Fix-slow-and-broken-cgroup-context-switch-code.
- commit d337d74
* Thu Jan  9 2014 dsterba@suse.cz
- Update Git-commit ids
- Refresh patches.fixes/crc32-0008-bolt-on-crc32c.patch.
- Refresh
  patches.suse/btrfs-0445-do-not-start-delalloc-inodes-during-sync.patch.
- Refresh
  patches.suse/btrfs-0446-fix-repair-code-for-RAID10.patch.
- Refresh
  patches.suse/btrfs-0447-Prevent-root_list-corruption.patch.
- Refresh
  patches.suse/btrfs-0448-fix-block_rsv-and-space_info-lock-ordering.patch.
- Refresh
  patches.suse/btrfs-0449-Fix-space-checking-during-fs-resize.patch.
- Refresh
  patches.suse/btrfs-0450-avoid-deadlocks-from-GFP_KERNEL-allocations-du.patch.
- Refresh
  patches.suse/btrfs-0451-reduce-lock-contention-during-extent-insertion.patch.
- Refresh
  patches.suse/btrfs-0452-Add-properly-locking-around-add_root_to_dirty_.patch.
- Refresh
  patches.suse/btrfs-0453-Fix-mismatching-struct-members-in-ioctl.h.patch.
- Refresh
  patches.suse/btrfs-0983-put-csums-on-the-right-ordered-extent.patch.
- Refresh
  patches.suse/btrfs-enhance-superblock-sanity-checks.patch.
- commit 90cb606
* Thu Jan  9 2014 duwe@suse.de
- Add Git-commit and Patch-mainline headers:
- Refresh patches.arch/s390-35-01-nss-initrd.
- Refresh patches.arch/s390-35-03-zfcp-dif-dix-2.
- Refresh patches.arch/s390-35-05-qdio-busy_bit.
- Refresh patches.arch/s390-35-07-af_iucv-over-hsi.
- Refresh patches.drivers/ipr-add-bluehawk-IDs.
- Refresh patches.drivers/ipr-implement-iopoll.
- Refresh patches.fixes/ipr-eeh-recovery-for-64-bit-adapters.
- Refresh patches.fixes/powerpc-migration-vphn-fix.
  Patch-mainline: no:
- Refresh patches.arch/s390-35-02-page-referenced.
- Refresh patches.arch/s390-35-04-zfcp-disable-auto-lun-scan.
- Refresh patches.arch/s390-35-06-zfcp-kmsg-lun-limit-reached.
- commit 975cdf9
* Thu Jan  9 2014 mhocko@suse.cz
- Delete patches.fixes/oom-warning.
  The additional warning message is not worth carrying. Highorder or
  atomic allocations which are expected to fail should use __GFP_NOWARN
  to not pollute logs with allocation failures which are acceptable.
- commit 35dfee2
* Thu Jan  9 2014 mhocko@suse.cz
- Delete patches.fixes/do_anonymous_page-race
  because it is no longer needed because upstream has fixed the same
  issue with 0ed361dec3694 (mm: fix PageUptodate data race).
- commit bda9188
* Thu Jan  9 2014 mmarek@suse.cz
- Fixed malformed Git-commit: headers
  - patches.drivers/0002-rt2x00-Don-t-disable-G0-PA_PE-bit-in-case-of-BT-coex.patch
  - patches.drivers/0003-rt2x00-Add-support-for-RT3572-RT3592-RT3592-Bluetoot.patch
  - patches.drivers/0004-rt2x00-Interface-sequence-lock-doesn-t-have-to-disab.patch
  - patches.drivers/0014-rt2x00-Implement-tx_frames_pending-mac80211-callback.patch
  - patches.drivers/0016-rt2x00-Fix-compilation-without-CONFIG_RT2X00_LIB_CRY.patch
  - patches.drivers/0018-rt2x00-Add-new-chipset-support.patch
  - patches.fixes/ipv6-unshare-inetpeers.patch
  - patches.fixes/perf-x86-add-intel-ivybridge-event-scheduling-constraints.patch
  - patches.fixes/vfs-dont-chain-pipe-anon-sockets-on-superbloc-s_inodes-list
  - patches.fixes/xprtrdma-transport-should-not-bug-check-when-a-dup-reply-is-received
  - patches.suse/xor-0005-lib-raid6-Add-SSSE3-optimized-recovery-functions.patch
- commit faf9060
* Thu Jan  9 2014 mhocko@suse.cz
- Refresh
  patches.fixes/cpusets-randomize-node-rotor-used-in-cpuset_mem_spre.patch.
- Refresh
  patches.fixes/memcg-change-memcg_oom_mutex-to-spinlock.patch.
- Refresh patches.fixes/mm-do_fault-preallocate-cow-page.patch.
- Refresh
  patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback.patch.
- Refresh
  patches.fixes/mm-vmscan-Check-if-kswapd-should-writepage-once-per-pgdat-scan.patch.
- Refresh
  patches.fixes/mm-vmscan-Do-not-allow-kswapd-to-scan-at-maximum-priority.patch.
- Refresh
  patches.fixes/mm-vmscan-Limit-the-number-of-pages-kswapd-reclaims-at-each-priority.patch.
- commit d65c364
* Thu Jan  9 2014 oneukum@suse.de
- Refresh
  patches.drivers/0004-rt2x00-Interface-sequence-lock-doesn-t-have-to-disab.patch.
- commit 3a638f7
* Thu Jan  9 2014 oneukum@suse.de
- Refresh
  patches.drivers/0002-rt2x00-Don-t-disable-G0-PA_PE-bit-in-case-of-BT-coex.patch.
- commit e506a60
* Thu Jan  9 2014 jbohac@suse.cz
- Fixed patch header: patches.fixes/ipv6-unshare-inetpeers.patch
- commit e82fedb
* Thu Jan  9 2014 oneukum@suse.de
- Refresh patches.drivers/btusb-add-mt76x0e.patch.
- commit 921c767
* Thu Jan  9 2014 tiwai@suse.de
- Refresh patches.drivers/export-ktime_get_monotonic_offset.
- commit f766d77
* Thu Jan  9 2014 oneukum@suse.de
- Refresh
  patches.drivers/0001-xhci-endianness-xhci_calculate_intel_u2_timeout.patch.
- commit 867e9c4
* Thu Jan  9 2014 trenn@suse.de
- Refresh
  Adjust git commit id to Linus tree.
  patches.arch/acpi_remove_warning_for_large_gpe_registers.patch.
- commit c509b93
* Thu Jan  9 2014 mmarek@suse.cz
- patches.fixes/perf-Change-and-simplify-ctx-is_active-semantics: Fix
  email address
- commit d05fc52
* Thu Jan  9 2014 mgorman@suse.de
- Refresh
  patches.fixes/mm-use-up-free-swap-space-before-reaching-OOM-kill.patch.
  patches.fixes/mm-vmscan-add-block-plug-for-page-reclaim.patch.
- commit a7f4a77
* Thu Jan  9 2014 agraf@suse.de
- fixed patch headers
  * patches.arch/s390-kvm-0001-kvm-handle-tprot-intercepts.patch.
  * patches.arch/s390-kvm-0002-KVM-provide-synchronous-registers-in-kvm_run.patch.
  * patches.arch/s390-kvm-0003-KVM-provide-synchronous-registers-in-kvm_run.patch.
  * patches.arch/s390-kvm-0004-KVM-PPC-Add-generic-single-register-ioctls.patch.
  * patches.arch/s390-kvm-0005-move-sie-code-to-entry.S.patch.
  * patches.arch/s390-kvm-0006-kvm-make-sigp-emerg-smp-capable.patch.
  * patches.arch/s390-kvm-0007-KVM-s390-fix-return-value-of-kvm_arch_init_vm.patch.
  * patches.arch/s390-kvm-0008-KVM-s390-fix-register-setting.patch.
  * patches.arch/s390-kvm-0009-KVM-s390-Fix-RUNNING-flag-misinterpretation.patch.
  * patches.arch/s390-kvm-0010-KVM-s390-implement-sigp-external-call.patch.
  * patches.arch/s390-kvm-0011-KVM-s390-handle-SIGP-sense-running-intercepts.patch.
  * patches.arch/s390-kvm-0012-KVM-s390-Fix-tprot-locking.patch.
  * patches.arch/s390-kvm-0013-KVM-s390-announce-SYNC_MMU.patch.
  * patches.arch/s390-kvm-0014-KVM-s390-Fix-return-code-for-unknown-ioctl-numbers.patch.
  * patches.arch/s390-kvm-0015-KVM-s390-rework-code-that-sets-the-prefix.patch.
  * patches.arch/s390-kvm-0016-KVM-s390-provide-the-prefix-register-via-kvm_run.patch.
  * patches.arch/s390-kvm-0017-KVM-s390-provide-general-purpose-guest-registers-v.patch.
  * patches.arch/s390-kvm-0018-KVM-s390-provide-access-guest-registers-via-kvm_ru.patch.
  * patches.arch/s390-kvm-0019-KVM-s390-Sanitize-fpc-registers-for-KVM_SET_FPU.patch.
  * patches.arch/s390-kvm-0020-KVM-s390-make-sigp-restart-return-busy-when-stop-p.patch.
  * patches.arch/s390-kvm-0021-KVM-s390-ignore-sigp-stop-overinitiative.patch.
  * patches.arch/s390-kvm-0022-KVM-s390-add-stop_on_stop-flag-when-doing-stop-and.patch.
  * patches.arch/s390-kvm-0023-KVM-s390-provide-control-registers-via-kvm_run.patch.
  * patches.arch/s390-kvm-0024-KVM-s390-Implement-the-directed-yield-diag-9c-hy.patch.
  * patches.arch/s390-kvm-0025-KVM-s390-Handle-sckpf-instruction.patch.
  * patches.arch/s390-kvm-0026-KVM-s390-implement-KVM_CAP_NR-MAX_VCPUS.patch.
  * patches.arch/s390-kvm-0027-KVM-s390-KVM_GET-SET_ONEREG-for-s390.patch.
  * patches.arch/s390-kvm-0028-KVM-s390-epoch-difference-and-TOD-programmable-fie.patch.
  * patches.arch/s390-kvm-0029-KVM-s390-onereg-for-timer-related-registers.patch.
  * patches.arch/s390-kvm-0030-KVM-s390-Set-CPU-in-stopped-state-on-initial-cpu-r.patch.
  * patches.arch/s390-kvm-0031-KVM-s390-fix-sigp-set-prefix-status-stored-cases.patch.
  * patches.arch/s390-kvm-0032-KVM-s390-Fix-sigp-sense-handling.patch.
  * patches.arch/s390-kvm-0033-KVM-s390-Fix-vcpu_load-handling-in-interrupt-code.patch.
  * patches.arch/s390-kvm-0034-s390-kvm-Interrupt-injection-bugfix.patch.
  * patches.arch/s390-kvm-0035-s390-kvm-dont-announce-RRBM-support.patch.
  * patches.arch/s390-kvm-0036-KVM-s390-Constify-intercept-handler-tables.patch.
  * patches.arch/s390-kvm-0037-KVM-s390-Decoding-helper-functions.patch.
  * patches.arch/s390-kvm-0038-KVM-s390-Support-for-I-O-interrupts.patch.
  * patches.arch/s390-kvm-0039-KVM-s390-Add-support-for-machine-checks.patch.
  * patches.arch/s390-kvm-0040-KVM-s390-In-kernel-handling-of-I-O-instructions.patch.
  * patches.arch/s390-kvm-0041-KVM-s390-Base-infrastructure-for-enabling-capabili.patch.
  * patches.arch/s390-kvm-0042-KVM-s390-Add-support-for-channel-I-O-instructions.patch.
  * patches.arch/s390-virtio-ccw-0001-KVM-s390-Perform-early-event-mask-processing-durin.patch.
  * patches.arch/s390-virtio-ccw-0003-s390-Add-a-mechanism-to-get-the-subchannel-id.patch.
  * patches.arch/s390-virtio-ccw-0004-s390-ccwdev-Include-asm-schid.h.patch.
  * patches.arch/s390-virtio-ccw-0005-KVM-s390-Add-a-channel-I-O-based-virtio-transport.patch.
  * patches.arch/s390-virtio-ccw-0006-KVM-s390-Dynamic-allocation-of-virtio-ccw-I-O-data.patch.
  * patches.arch/s390-virtio-ccw-0007-KVM-s390-Gracefully-handle-busy-conditions-on-ccw_.patch.
- commit 18cf380
* Thu Jan  9 2014 hare@suse.de
- fixed patch headers
  * patches.drivers/be2net-0144-Wait-f-w-POST-until-timeout.patch.
  * patches.drivers/be2net-0145-use-CSR-BAR-SEMAPHORE-reg-for-BE2-BE3.patch.
  * patches.drivers/bnx2fc-host-stats-show-the-link-speed-unkno.patch.
  * patches.drivers/fcoe-0065-libfcoe-Fix-Conflicting-FCFs-issue-in-the-fabric.patch.
  * patches.drivers/fnic-Fix-SGEs-limit.patch.
  * patches.drivers/fnic-fix-for-trusted-cos.patch.
  * patches.drivers/fnic-fixing-issues-in-device-and-firmware-reset-code.patch.
  * patches.drivers/mtip32xx-0060-fix-a-smatch-warning.patch.
  * patches.drivers/mtip32xx-0061-mtip32xx-Disable-TRIM-support.patch.
  * patches.drivers/mtip32xx-0062-Workaround-for-unaligned-writes.patch.
  * patches.drivers/mtip32xx-0063-fix-null-pointer-dereference-during-module-unload.patch.
  * patches.drivers/mtip32xx-0064-correctly-handle-bio-bi_idx-0-conditions.patch.
  * patches.fixes/net-do-not-do-gso-for-CHECKSUM_UNNECESSARY.patch.
  * patches.fixes/scsi-Add-eh_deadline-to-limit-SCSI-EH-runtime.patch.
  * patches.fixes/scsi-dh-alua-retry-mode-parameters-changed.patch.
  * patches.fixes/scsi-libfc-fix-checking-FC_TYPE_BLS.patch.
- commit 9f5cd4d
* Thu Jan  9 2014 acho@suse.com
- Update GIT commit headers.
- Refresh
  patches.drivers/0009-mmc-sdio-Fix-SDIO-3.0-UHS-I-initialization-sequence.patch.
- Refresh
  patches.drivers/0010-mmc-sdio-print-correct-UHS-mode-during-sdio-card-det.patch.
- commit b06919e
* Thu Jan  9 2014 jlee@suse.com
- Update GIT commit headers.
- Refresh patches.arch/0001-Modify-UEFI-anti-bricking-code.patch.
- Refresh patches.suse/x509-remove-certificate-date-checks.patch.
- commit a3eaa5e
* Thu Jan  9 2014 jkosina@suse.cz
- Update GIT commit headers.
- Refresh
  patches.suse/tipc-0001-Convert-fatal-broadcast-sanity-check-to-non-fat.patch.
- Refresh
  patches.suse/tipc-0002-Remove-unused-sanity-test-macro.patch.
- Refresh
  patches.suse/tipc-0003-Standardize-exit-logic-for-message-rejection-ha.patch.
- Refresh
  patches.suse/tipc-0004-Add-sanity-check-to-detect-rejection-of-non-pay.patch.
- Refresh
  patches.suse/tipc-0005-Optimize-routing-of-returned-payload-messages.patch.
- Refresh
  patches.suse/tipc-0006-Optimizations-corrections-to-message-rejection.patch.
- Refresh
  patches.suse/tipc-0007-Eliminate-message-header-routines-for-caching-d.patch.
- Refresh
  patches.suse/tipc-0008-Eliminate-redundant-masking-in-message-header-r.patch.
- Refresh
  patches.suse/tipc-0009-Partition-name-table-instance-array-info-into-t.patch.
- Refresh
  patches.suse/tipc-0010-Convert-name-table-publication-lists-to-standar.patch.
- Refresh
  patches.suse/tipc-0011-Eliminate-checks-for-empty-zone-list-during-nam.patch.
- Refresh
  patches.suse/tipc-0012-Correct-typo-in-link-statistics-output.patch.
- Refresh
  patches.suse/tipc-0013-Eliminate-unused-field-in-bearer-structure.patch.
- Refresh
  patches.suse/tipc-0014-Remove-unnecessary-includes-in-socket-code.patch.
- Refresh
  patches.suse/tipc-0015-Eliminate-useless-check-when-creating-internal-.patch.
- Refresh
  patches.suse/tipc-0016-Cleanup-of-message-header-size-terminology.patch.
- Refresh
  patches.suse/tipc-0017-Optimize-creation-of-FIN-messages.patch.
- Refresh
  patches.suse/tipc-0018-Reject-connection-protocol-message-sent-to-unco.patch.
- Refresh
  patches.suse/tipc-0019-Don-t-create-payload-message-using-connection-p.patch.
- Refresh
  patches.suse/tipc-0020-Optimize-creation-of-connection-protocol-messag.patch.
- Refresh patches.suse/tipc-0021-use-linux-atomic.h.patch.
- Refresh
  patches.suse/tipc-0022-Remove-obsolete-manipulation-of-message-re-rout.patch.
- Refresh
  patches.suse/tipc-0023-Eliminate-obsolete-filter-for-unexpected-unicas.patch.
- Refresh
  patches.suse/tipc-0024-Display-meaningful-peer-interface-name-during-l.patch.
- Refresh
  patches.suse/tipc-0025-Initialize-peer-session-field-of-newly-created-.patch.
- Refresh
  patches.suse/tipc-0026-Enhance-filtering-of-out-dated-link-reset-messa.patch.
- Refresh
  patches.suse/tipc-0027-Update-obsolete-references-to-multicast-link.patch.
- Refresh
  patches.suse/tipc-0028-Cosmetic-changes-to-broadcast-bearer-send-routi.patch.
- Refresh
  patches.suse/tipc-0029-Remove-non-executable-code-to-handle-broadcast-.patch.
- Refresh
  patches.suse/tipc-0030-Enhance-cleanup-of-broadcast-link-when-contact-.patch.
- Refresh
  patches.suse/tipc-0031-Prevent-broadcast-link-stalling-when-another-no.patch.
- Refresh
  patches.suse/tipc-0032-Fix-node-lock-problems-during-broadcast-message.patch.
- Refresh
  patches.suse/tipc-0033-Remove-deferred-queue-head-caching-during-broad.patch.
- Refresh
  patches.suse/tipc-0034-Discard-incoming-broadcast-messages-that-are-un.patch.
- Refresh
  patches.suse/tipc-0035-Remove-obsolete-congestion-handling-when-sendin.patch.
- Refresh
  patches.suse/tipc-0036-Eliminate-redundant-check-when-sending-messages.patch.
- Refresh
  patches.suse/tipc-0037-Prevent-rounding-issues-when-saving-connect-tim.patch.
- Refresh
  patches.suse/tipc-0038-Ensure-congested-links-receive-bearer-status-up.patch.
- Refresh
  patches.suse/tipc-0039-Ensure-both-nodes-recognize-loss-of-contact-bet.patch.
- Refresh
  patches.suse/tipc-0042-Lower-limits-for-number-of-bearers-and-media-ty.patch.
- Refresh
  patches.suse/tipc-0043-Prevent-fragmented-messages-during-initial-name.patch.
- Refresh
  patches.suse/tipc-0044-relocate-coalesce-node-cast-in-tipc_named_node_.patch.
- Refresh
  patches.suse/tipc-0045-Enhance-sending-of-bulk-name-table-messages.patch.
- Refresh
  patches.suse/tipc-0046-Add-support-for-SO_SNDTIMEO-socket-option.patch.
- Refresh
  patches.suse/tipc-0047-Simplify-prohibition-of-listen-and-accept-for-c.patch.
- Refresh
  patches.suse/tipc-0048-Remove-callback-field-from-subscription-structu.patch.
- Refresh
  patches.suse/tipc-0049-Remove-unused-link-event-tracking-code.patch.
- Refresh
  patches.suse/tipc-0050-Fix-files-explicitly-needing-to-include-module.h.patch.
- Refresh patches.suse/tipc-0051-two-vzalloc-cleanups.patch.
- Refresh
  patches.suse/tipc-0052-Enable-use-by-containers-having-their-own-netwo.patch.
- Refresh
  patches.suse/tipc-0053-Register-new-media-using-pre-compiled-structure.patch.
- Refresh
  patches.suse/tipc-0054-Optimize-detection-of-duplicate-media-registrat.patch.
- Refresh
  patches.suse/tipc-0055-Eliminate-duplication-of-media-structures.patch.
- Refresh
  patches.suse/tipc-0056-Streamline-media-registration-error-checking.patch.
- Refresh
  patches.suse/tipc-0057-Improve-handling-of-media-address-printing-erro.patch.
- Refresh
  patches.suse/tipc-0058-Add-new-address-conversion-routines-for-Etherne.patch.
- Refresh
  patches.suse/tipc-0060-Ignore-neighbor-discovery-messages-containing-i.patch.
- Refresh
  patches.suse/tipc-0061-Allow-run-time-alteration-of-default-link-setti.patch.
- Refresh
  patches.suse/tipc-0062-Revise-comment-justifying-release-of-configurat.patch.
- Refresh
  patches.suse/tipc-0063-Minor-optimization-to-deactivation-of-Ethernet-.patch.
- Refresh
  patches.suse/tipc-0065-Eliminate-useless-memset-operations-in-Ethernet.patch.
- Refresh
  patches.suse/tipc-0066-Minor-correction-to-TIPC-module-unloading.patch.
- Refresh
  patches.suse/tipc-0067-Eliminate-useless-check-when-network-address-is.patch.
- Refresh
  patches.suse/tipc-0068-Eliminate-dynamic-allocation-of-broadcast-link-.patch.
- Refresh
  patches.suse/tipc-0069-Ensure-broadcast-link-spinlock-is-held-when-upd.patch.
- Refresh
  patches.suse/tipc-0070-Handle-broadcast-attempt-when-no-neighboring-no.patch.
- Refresh
  patches.suse/tipc-0071-Minor-optimization-of-broadcast-link-transmit-q.patch.
- Refresh
  patches.suse/tipc-0072-Flush-unsent-broadcast-messages-when-contact-wi.patch.
- Refresh
  patches.suse/tipc-0073-Ignore-broadcast-acknowledgements-that-are-out-.patch.
- Refresh
  patches.suse/tipc-0074-Allow-use-of-buf_seqno-helper-routine-by-unicas.patch.
- Refresh
  patches.suse/tipc-0075-rename-struct-media-to-struct-tipc_media.patch.
- Refresh
  patches.suse/tipc-0076-rename-struct-port_list-to-struct-tipc_port_lis.patch.
- Refresh
  patches.suse/tipc-0077-rename-struct-subscription-to-struct-tipc_subsc.patch.
- Refresh
  patches.suse/tipc-0078-rename-struct-subscriber-to-struct-tipc_subscri.patch.
- Refresh
  patches.suse/tipc-0079-rename-struct-bclink-to-struct-tipc_bclink.patch.
- Refresh
  patches.suse/tipc-0080-rename-struct-bcbearer-to-tipc_bcbearer.patch.
- Refresh
  patches.suse/tipc-0081-rename-struct-link-to-struct-tipc_link.patch.
- Refresh
  patches.suse/tipc-0082-rename-struct-bearer_name-to-struct-tipc_bearer.patch.
- Refresh
  patches.suse/tipc-0083-improve-the-link-deferred-queue-insertion-algor.patch.
- Refresh
  patches.suse/tipc-0084-Prevent-transmission-of-outdated-link-protocol-.patch.
- Refresh
  patches.suse/tipc-0085-Prevent-broadcast-link-stalling-in-dual-LAN-env.patch.
- Refresh
  patches.suse/tipc-0086-Ensure-broadcast-link-re-acquires-node-after-li.patch.
- Refresh
  patches.suse/tipc-0087-Fix-problem-with-broadcast-link-synchronization.patch.
- Refresh
  patches.suse/tipc-0088-Add-missing-broadcast-link-lock-when-sending-NA.patch.
- Refresh
  patches.suse/tipc-0089-Fix-node-lock-reclamation-issues-in-broadcast-l.patch.
- Refresh
  patches.suse/tipc-0090-Fix-bug-in-broadcast-link-duplicate-message-sta.patch.
- Refresh
  patches.suse/tipc-0091-Add-missing-locks-in-broadcast-link-statistics-.patch.
- Refresh
  patches.suse/tipc-0092-Major-redesign-of-broadcast-link-ACK-NACK-algor.patch.
- Refresh
  patches.suse/tipc-0093-Remove-obsolete-broadcast-tag-capability.patch.
- Refresh
  patches.suse/tipc-0094-Prevent-loss-of-fragmented-messages-over-unicas.patch.
- Refresh
  patches.suse/tipc-0095-Prevent-loss-of-fragmented-messages-over-broadc.patch.
- Refresh
  patches.suse/tipc-0096-Eliminate-alteration-of-publication-key-during-.patch.
- Refresh
  patches.suse/tipc-0097-Minor-optimization-to-rejection-of-connection-b.patch.
- Refresh
  patches.suse/tipc-0098-Introduce-node-signature-field-in-neighbor-disc.patch.
- Refresh
  patches.suse/tipc-0099-Detect-duplicate-nodes-using-different-network-.patch.
- Refresh
  patches.suse/tipc-0100-Remove-duplicate-check-of-message-destination-n.patch.
- Refresh
  patches.suse/tipc-0101-Simplify-enforcement-of-reserved-name-type-proh.patch.
- Refresh
  patches.suse/tipc-0102-Add-check-to-prevent-insertion-of-duplicate-nam.patch.
- Refresh
  patches.suse/tipc-0103-nuke-the-delimit-static-inline-function.patch.
- Refresh
  patches.suse/tipc-0104-Eliminate-a-test-for-negative-unsigned-quantiti.patch.
- Refresh
  patches.suse/tipc-0105-Hide-internal-details-of-node-table-implementat.patch.
- Refresh
  patches.suse/tipc-0106-Eliminate-trivial-buffer-manipulation-helper-ro.patch.
- Refresh
  patches.suse/tipc-0107-Remove-obsolete-comments-about-routing-table-up.patch.
- Refresh
  patches.suse/tipc-0108-Minor-optimization-to-broadcast-link-synchroniz.patch.
- Refresh
  patches.suse/tipc-0109-Revert-name-table-translation-optimization.patch.
- Refresh
  patches.suse/tipc-0110-Eliminate-obsolete-support-for-not-running-mode.patch.
- Refresh
  patches.suse/tipc-0111-Eliminate-support-for-tipc_mode-global-variable.patch.
- Refresh
  patches.suse/tipc-0112-Un-inline-port-routine-for-processing-incoming-.patch.
- Refresh
  patches.suse/tipc-0113-Eliminate-obsolete-code-for-re-sending-a-messag.patch.
- Refresh
  patches.suse/tipc-0114-Optimize-setting-of-immutable-payload-message-h.patch.
- Refresh
  patches.suse/tipc-0115-cleanup-unsigned-to-unsigned-int.patch.
- Refresh
  patches.suse/tipc-0116-introduce-publication-lists-struct.patch.
- Refresh
  patches.suse/tipc-0117-Factor-out-name-publication-code-to-a-separate-.patch.
- Refresh
  patches.suse/tipc-0118-Separate-cluster-scope-and-zone-scope-names-int.patch.
- Refresh
  patches.suse/tipc-0119-Update-node-scope-publications-when-network-add.patch.
- Refresh
  patches.suse/tipc-0120-Don-t-record-failed-publication-attempt-as-a-su.patch.
- Refresh
  patches.suse/tipc-0121-Add-routines-for-safe-checking-of-node-s-networ.patch.
- Refresh
  patches.suse/tipc-0122-Ensure-network-address-change-doesn-t-impact-na.patch.
- Refresh
  patches.suse/tipc-0123-Optimize-re-initialization-of-port-message-head.patch.
- Refresh
  patches.suse/tipc-0124-Ensure-network-address-change-doesn-t-impact-ne.patch.
- Refresh
  patches.suse/tipc-0125-delete-duplicate-peerport-peernode-helper-funct.patch.
- Refresh
  patches.suse/tipc-0126-Ensure-network-address-change-doesn-t-impact-lo.patch.
- Refresh
  patches.suse/tipc-0127-take-lock-while-updating-node-network-address.patch.
- Refresh
  patches.suse/tipc-0128-properly-handle-off-node-send-requests-with-inv.patch.
- Refresh
  patches.suse/tipc-0129-handle-0.0.0-as-an-alias-for-this-node-on-outgo.patch.
- Refresh
  patches.suse/tipc-0130-Ensure-network-address-change-doesn-t-impact-re.patch.
- Refresh
  patches.suse/tipc-0131-Ensure-network-address-change-doesn-t-impact-co.patch.
- Refresh
  patches.suse/tipc-0132-remove-inline-instances-from-C-source-files.patch.
- Refresh
  patches.suse/tipc-0133-Optimize-re-initialization-of-configuration-ser.patch.
- Refresh
  patches.suse/tipc-0134-Optimize-initialization-of-configuration-servic.patch.
- Refresh
  patches.suse/tipc-0135-Optimize-termination-of-configuration-service.patch.
- Refresh
  patches.suse/tipc-0136-Enhance-re-initialization-of-network-topology-s.patch.
- Refresh
  patches.suse/tipc-0137-Optimize-initialization-of-network-topology-ser.patch.
- Refresh
  patches.suse/tipc-0138-remove-redundant-memset-and-stale-comment-from-.patch.
- Refresh
  patches.suse/tipc-0139-Create-helper-routine-to-delete-unused-name-seq.patch.
- Refresh
  patches.suse/tipc-0140-Enhance-error-checking-of-published-names.patch.
- Refresh
  patches.suse/tipc-0141-Reject-payload-messages-with-invalid-message-ty.patch.
- Refresh patches.suse/tipc-0143-Remove-casts-to-same-type.patch.
- Refresh
  patches.suse/tipc-0144-Fix-nearly-kernel-doc-comments-for-various-funct.patch.
- Refresh
  patches.suse/tipc-0145-Fix-non-kernel-doc-comments-with-kernel-doc-star.patch.
- Refresh
  patches.suse/tipc-0146-factor-stats-struct-out-of-the-larger-link-stru.patch.
- Refresh
  patches.suse/tipc-0147-limit-error-messages-relating-to-memory-leak-to.patch.
- Refresh
  patches.suse/tipc-0148-use-standard-printk-shortcut-macros-pr_err-etc.patch.
- Refresh
  patches.suse/tipc-0149-remove-TIPC-packet-debugging-functions-and-macr.patch.
- Refresh
  patches.suse/tipc-0150-simplify-link_print-by-divorcing-it-from-using-.patch.
- Refresh
  patches.suse/tipc-0151-simplify-print-buffer-handling-in-tipc_printf.patch.
- Refresh
  patches.suse/tipc-0152-phase-out-most-of-the-struct-print_buf-usage.patch.
- Refresh
  patches.suse/tipc-0153-remove-print_buf-and-deprecated-log-buffer-code.patch.
- Refresh
  patches.suse/tipc-0154-optimize-the-initialization-of-network-device-n.patch.
- Refresh
  patches.suse/tipc-0156-remove-pointless-name-sanity-check-and-tipc_alp.patch.
- Refresh
  patches.suse/tipc-0157-manually-inline-single-use-media_name_valid-rou.patch.
- Refresh
  patches.suse/tipc-0158-change-tipc_net_start-routine-return-value-type.patch.
- Refresh
  patches.suse/tipc-0159-convert-tipc_nametbl_size-type-from-variable-to.patch.
- Refresh
  patches.suse/tipc-0160-add-__read_mostly-annotations-to-several-global.patch.
- Refresh
  patches.suse/tipc-0161-eliminate-configuration-for-maximum-number-of-n.patch.
- Refresh
  patches.suse/tipc-0162-eliminate-configuration-for-maximum-number-of-n.patch.
- Refresh
  patches.suse/tipc-0163-tipc-name_table.c-Remove-unecessary-semicolon.patch.
- Refresh
  patches.suse/tipc-0164-prevent-dropped-connections-due-to-rcvbuf-overf.patch.
- Refresh
  patches.suse/tipc-0165-do-not-use-tasklet_disable-before-tasklet_kill.patch.
- Refresh
  patches.suse/tipc-0166-fix-race-inefficiencies-in-poll-wait-behaviour.patch.
- Refresh
  patches.suse/tipc-0167-return-POLLOUT-for-sockets-in-an-unconnected-st.patch.
- Refresh
  patches.suse/tipc-0168-wake-up-all-waiting-threads-at-socket-shutdown.patch.
- Refresh
  patches.suse/tipc-0169-remove-the-bearer-congestion-mechanism.patch.
- Refresh
  patches.suse/tipc-0170-remove-supportable-flag-from-bclink-structure.patch.
- Refresh
  patches.suse/tipc-0171-rename-supported-flag-to-recv_permitted.patch.
- Refresh
  patches.suse/tipc-0172-introduce-message-to-synchronize-broadcast-link.patch.
- Refresh
  patches.suse/tipc-0173-eliminate-an-unnecessary-cast-of-node-variable.patch.
- Refresh
  patches.suse/tipc-0174-delete-TIPC_ADVANCED-Kconfig-variable.patch.
- Refresh
  patches.suse/tipc-0175-remove-obsolete-flush-of-stale-reassembly-buffe.patch.
- Refresh
  patches.suse/tipc-0176-eliminate-aggregate-sk_receive_queue-limit.patch.
- Refresh
  patches.suse/tipc-0177-change-sk_receive_queue-upper-limit.patch.
- Refresh
  patches.suse/tipc-0178-standardize-across-connect-disconnect-function-.patch.
- Refresh
  patches.suse/tipc-0179-consolidate-connection-oriented-message-recepti.patch.
- Refresh
  patches.suse/tipc-0180-introduce-non-blocking-socket-connect.patch.
- Refresh
  patches.suse/tipc-0181-eliminate-connection-setup-for-implied-connect-.patch.
- Refresh
  patches.suse/tipc-0182-add-lock-nesting-notation-to-quiet-lockdep-warn.patch.
- Refresh
  patches.suse/tipc-0183-refactor-accept-code-for-improved-readability.patch.
- commit 6fb3ee9
* Wed Jan  8 2014 jjolly@suse.de
- Refresh Git-commit: headers
  patches.drivers/mlx4_en-fix-allocation-of-CPU-affinity-reverse-map.patch.
- Refresh
  patches.drivers/mlx4_en-fix-allocation-of-device-tx_cq.patch.
- Refresh
  patches.drivers/net-mlx4_en-Disable-RFS-when-running-in-SRIOV-mode.patch.
- commit 9612b48
* Wed Jan  8 2014 jack@suse.cz
- Fixed Git-commit reference in
  patches.fixes/ext4-race-condition-protection-for-ext4_convert_unwr.patch.
- commit 26a8e96
* Wed Jan  8 2014 msrb@suse.com
- Fix Git-commit: headers
- Refresh
  patches.drm/0503-swiotlb-expose-swiotlb_nr_tlb-function-to-modules.
- Refresh
  patches.xen/xen3-0503-swiotlb-expose-swiotlb_nr_tlb-function-to-modules.
- commit 30f9a15
* Wed Jan  8 2014 neilb@suse.de
- Fix Git-commit header for patches.fixes/nfs-increase-callback-threads
- commit 12d10dd
* Wed Jan  8 2014 mmarek@suse.cz
- Fix Git-commit: headers
- Refresh
  patches.drivers/0004-netxen-add-fw-version-compatibility-check.patch.
- Refresh
  patches.fixes/0002-KEYS-Load-.x509-files-into-kernel-keyring.patch.
- commit ccd7979
* Wed Jan  8 2014 rgoldwyn@suse.com
- Delete
  patches.fixes/ocfs2-add-bits_wanted-to-ocfs2_calc_extend_credits.patch.
  This patch was removed from mainline. Alternatively, we can use
  06f9da6e826a0b459652b98a21541bca274bd440, but that is just cosmentic.
- commit fd619ec
* Wed Jan  8 2014 eich@suse.com
- Refresh
  patches.drivers/drm-edid-Don-t-print-messages-regarding-stereo-or-csync-by-default.patch.
- commit 815eecb
* Wed Jan  8 2014 jeffm@suse.com
- Update Git-commit for patches.drivers/bnx2x-multiple-concurrent-l2-traffic-classes.
- commit c3ad986
* Wed Jan  8 2014 jbohac@suse.cz
- Update headers:
- Refresh patches.drivers/igb-fix-phc-stopping-on-max-freq.patch.
- Refresh patches.drivers/net-export-the-receive-time-stamping-hook-for-non-na.patch.
- Refresh patches.drivers/net-export-time-stamp-utility-function-for-ethernet-.patch.
- Refresh patches.drivers/net-introduce-ptp-one-step-time-stamp-mode-for-sync-.patch.
- commit 37b3830
* Wed Jan  8 2014 duwe@suse.de
- Refresh
  patches.drivers/ipr-add-MSI-X-and-distributed-completion.
- Refresh patches.drivers/ipr-add-more-crocodile-IDs.
- Refresh patches.drivers/ipr-handle-ID-malloc-fail.
- Refresh patches.drivers/ipr-reduce-lock-contention.
- Refresh patches.drivers/ipr-resource-path-error-logging-cleanup.
- Those commit IDs changed due to a rebase.
- commit 409528c
* Wed Jan  8 2014 tiwai@suse.de
- Update commit id tags
  patches.drm/3292-drm-i915-split-aux_clock_divider-logic-in-a-separate
  patches.drm/3293-drm-i915-Retry-DP-aux_ch-communications-with-a-diffe
- commit bdcbeff
* Wed Jan  8 2014 bp@suse.de
- Refresh
  patches.arch/x86-mm-send-tlb-flush-ipis-to-online-cpus-only.patch.
- Refresh patches.fixes/rtc-add-an-alarm-disable-quirk.patch.
- commit d9849c9
* Wed Jan  8 2014 jkosina@suse.cz
- Update kabi files (bnc#856307).
- commit c1d6911
* Tue Jan  7 2014 oneukum@suse.de
- patches.suse/bug-853428-scsi_device-fix-kabi.patch:
  (bnc#853428).
- Add READ_CAPACITY_16 quirk (bnc#853428)
- SCSI & usb-storage: add try_rc_10_first flag
  (bnc#853428).
- commit 9def9c9
* Tue Jan  7 2014 mkubecek@suse.cz
- patches.fixes/tcp-bind-fix-autoselection-to-share-ports.patch:
  tcp: bind() fix autoselection to share ports (bnc#823618).
- patches.fixes/tcp-bind-use-stronger-condition-for-bind_conflict.patch:
  tcp: bind() use stronger condition for bind_conflict
  (bnc#823618).
- patches.fixes/tcp-ipv6-bind-use-stronger-condition-for-bind_confli.patch:
  tcp: ipv6: bind() use stronger condition for bind_conflict
  (bnc#823618).
- patches.kabi/kabi-protect-bind_conflict-callback-in-struct-inet_c.patch:
  kabi: protect bind_conflict callback in struct
  inet_connection_sock_af_ops (bnc#823618).
- commit fc487d9
* Tue Jan  7 2014 bp@suse.de
- patches.fixes/kvm-x86-convert-vapic-synchronization-to-cached-functions-cve-2013-6368.patch:
  KVM: x86: Convert vapic synchronization to _cached functions
  (CVE-2013-6368) (bnc#853052 CVE-2013-6368).
- commit 91ed8f0
* Tue Jan  7 2014 mkubecek@suse.cz
- patches.fixes/block-factor-out-vector-mergeable-decision-to-a-help.patch:
  block: factor out vector mergeable decision to a helper function
  (bnc#769644).
- patches.fixes/block-modify-__bio_add_page-check-to-accept-pages-th.patch:
  block: modify __bio_add_page check to accept pages that don't
  start a new segment (bnc#769644).
- commit bbce416
* Tue Jan  7 2014 jbohac@suse.cz
- ipv6: fix race condition regarding dst->expires and dst->from
  (bnc#843185).
- commit 8207b01
* Tue Jan  7 2014 hare@suse.de
- Revert kABI changes of 'libfcoe: Make fcoe_sysfs optional'
  (bnc#837206).
- libfcoe: Make fcoe_sysfs optional / fix fnic NULL exception
  (bnc#837206).
- commit a98e8a2
* Tue Jan  7 2014 mkubecek@suse.cz
- patches.fixes/macvlan-introduce-IFF_MACVLAN-flag-and-helper-functi.patch:
  macvlan: introduce IFF_MACVLAN flag and helper function
  (bnc#846984).
- patches.fixes/macvlan-introduce-macvlan_dev_real_dev-helper-functi.patch:
  macvlan: introduce macvlan_dev_real_dev() helper function
  (bnc#846984).
- patches.fixes/macvlan-disable-LRO-on-lower-device-instead-of-macvl.patch:
  macvlan: disable LRO on lower device instead of macvlan
  (bnc#846984).
- commit c3e7ab8
* Mon Jan  6 2014 jslaby@suse.cz
- patches.fixes/x86-dumpstack-Fix-printk_address-for-direct-addresse.patch:
  x86/dumpstack: Fix printk_address for direct addresses
  (bnc#845621).
- patches.suse/stack-unwind: Refresh.
- patches.xen/xen3-x86-dumpstack-Fix-printk_address-for-direct-addresse.patch:
  x86/dumpstack: Fix printk_address for direct addresses
  (bnc#845621).
- commit 19325c2
* Mon Jan  6 2014 mgorman@suse.de
- patches.fixes/futex-fix-handling-of-read-only-mapped-hugepages.patch:
  futex: fix handling of read-only-mapped hugepages
  (VM Functionality).
- commit 995cee1
* Fri Jan  3 2014 mszeredi@suse.cz
- patches.fixes/autofs4-autofs4_wait-vs-autofs4_catatonic_mode-race.patch:
  autofs4: autofs4_wait() vs. autofs4_catatonic_mode() race
  (bnc#851314).
- patches.fixes/autofs4-catatonic_mode-vs-notify_daemon-race.patch:
  autofs4: catatonic_mode vs. notify_daemon race (bnc#851314).
- patches.fixes/autofs4-close-the-races-around-autofs4_notify_daemon.patch:
  autofs4: close the races around autofs4_notify_daemon()
  (bnc#851314).
- patches.fixes/autofs4-deal-with-autofs4_write-autofs4_write-races.patch:
  autofs4: deal with autofs4_write/autofs4_write races
  (bnc#851314).
- patches.fixes/autofs4-dont-clear-DCACHE_NEED_AUTOMOUNT-on-rootless-mount.patch:
  autofs4 - dont clear DCACHE_NEED_AUTOMOUNT on rootless mount
  (bnc#851314).
- patches.fixes/autofs4-fix-deal-with-autofs4_write-races.patch:
  autofs4 - fix deal with autofs4_write races (bnc#851314).
- patches.fixes/autofs4-use-simple_empty-for-empty-directory-check.patch:
  autofs4 - use simple_empty() for empty directory check
  (bnc#851314).
- commit b552bc0
* Fri Jan  3 2014 mgalbraith@suse.de
- sched: Avoid throttle_cfs_rq() racing with period_timer stopping (bnc#848336).
- commit 6ec09c9
* Fri Jan  3 2014 mgalbraith@suse.de
- sched/balancing: Periodically decay max cost of idle balance
  (bnc#849256).
- sched: Consider max cost of idle balance per sched domain
  (bnc#849256).
- sched: Reduce overestimating rq->avg_idle (bnc#849256).
- commit b3f6220
* Fri Jan  3 2014 jeffm@suse.de
- mutex: Make more scalable by doing fewer atomic operations
  (bnc#849256).
- commit 817d6dd
* Thu Jan  2 2014 bpoirier@suse.de
- patches.fixes/dlm-set-zero-linger-time-on-sctp-socket.patch:
  dlm: set zero linger time on sctp socket (bnc#787843).
- commit a11a11f
* Wed Dec 25 2013 bp@suse.de
- patches.fixes/wireless-radiotap-fix-parsing-buffer-overrun.patch:
  wireless: radiotap: fix parsing buffer overrun (bnc#854634 CVE-2013-7027).
- commit 93ad340
* Sun Dec 22 2013 bp@suse.de
- KVM: x86: fix guest-initiated crash with x2apic (CVE-2013-6376)
  (bnc#853053 CVE-2013-6376).
- commit ee4b173
* Fri Dec 20 2013 hare@suse.de
- lpfc 8.3.42: Fixed issue of task management commands having
  a fixed timeout (bnc#856481).
- advansys: Remove 'last_reset' references (bnc#856481).
- dc395: Move 'last_reset' into internal host structure
  (bnc#856481).
- dpt_i2o: Remove DPTI_STATE_IOCTL (bnc#856481).
- dpt_i2o: return SCSI_MLQUEUE_HOST_BUSY when in reset
  (bnc#856481).
- Add 'eh_deadline' to limit SCSI EH runtime (bnc#856481).
- remove check for 'resetting' (bnc#856481).
- tmscsim: Move 'last_reset' into host structure (bnc#856481).
- Refresh
  patches.drivers/0030-scsi-Added-support-for-adapter-and-firmware-reset.patch.
- commit 3d9269d
* Thu Dec 19 2013 jjolly@suse.de
- s390/pci: obtain function handle in hotplug notifier
  (bnc#856307, LTC#101276).
- commit e2d4b3a
* Thu Dec 19 2013 jjolly@suse.de
- s390/pci/dma: fix accounting of allocated_pages (bnc#856307,
  LTC#101276).
- commit 2be2c16
* Thu Dec 19 2013 jjolly@suse.de
- s390/pci: set error state for unavailable functions (bnc#856307,
  LTC#101276).
- commit bd467f6
* Thu Dec 19 2013 jjolly@suse.de
- s390/pci: fix removal of nonexistent pci bus (bnc#856307,
  LTC#101276).
- commit a7ccd21
* Thu Dec 19 2013 jjolly@suse.de
- s390/pci: prevent inadvertently triggered bus scans (bnc#856307,
  LTC#101276).
- commit 96c2b7b
* Thu Dec 19 2013 bp@suse.de
- patches.fixes/kvm-x86-fix-potential-divide-by-0-in-lapic-cve-2013-6367.patch:
  KVM: x86: Fix potential divide by 0 in lapic (CVE-2013-6367)
  (bnc#853051 CVE-2013-6367).
- commit 728ec36
* Thu Dec 19 2013 jjolly@suse.de
- patches.arch/s390-69-01-crypto-Fix_aes_xts_parameter_corruption.patch:
  crypto: Fix aes-xts parameter corruption (bnc#854546,
  LTC#100718).
- commit 7dae336
* Thu Dec 19 2013 jjolly@suse.de
- crypto: Fix aes-xts parameter corruption (bnc#854548,
  LTC#100718).
- commit 4b9a3a7
* Thu Dec 19 2013 bp@suse.de
- ptp: dynamic allocation of PHC char devices (bnc#851290).
- commit 5b9268c
* Thu Dec 19 2013 dsterba@suse.cz
- Btrfs: don't clear the default compression type
- commit 1321c6e
* Thu Dec 19 2013 bp@suse.de
- patches.fixes/kvm-improve-create-vcpu-parameter-cve-2013-4587.patch:
  KVM: Improve create VCPU parameter (CVE-2013-4587) (bnc#853050 CVE-2013-4587).
- commit ed502ac
* Wed Dec 18 2013 tonyj@suse.de
- perf/x86: Fix offcore_rsp valid mask for SNB/IVB (bnc#825006).
- perf/x86: Add Intel IvyBridge event scheduling constraints
  (bnc#825006).
- commit 4192f4e
* Wed Dec 18 2013 bp@suse.de
- patches.fixes/libertas-potential-oops-in-debugfs.patch:
  libertas: potential oops in debugfs (bnc#852559 CVE-2013-6378).
- commit c4070a9
* Wed Dec 18 2013 bp@suse.de
- patches.fixes/aacraid-prevent-invalid-pointer-dereference.patch:
  aacraid: prevent invalid pointer dereference (bnc#852373 CVE-2013-6380).
- commit 5f53614
* Wed Dec 18 2013 bp@suse.de
- patches.fixes/wlags49_h2-buffer-overflow-setting-station-name.patch:
  staging: wlags49_h2: buffer overflow setting station name (bnc#849029 CVE-2013-4514).
- commit 48bb50c
* Wed Dec 18 2013 bp@suse.de
- patches.fixes/staging-bcm-info-leak-in-ioctl.patch:
  Staging: bcm: info leak in ioctl (bnc#849034 CVE-2013-4515).
- commit 06935dc
* Tue Dec 17 2013 bp@suse.de
- patches.fixes/net-rework-recvmsg-handler-msg_name-and-msg_namelen-logic.patch:
  Refresh.
- commit 248ea58
* Tue Dec 17 2013 jbeulich@suse.com
- pcifront: Deal with toolstack missing 'XenbusStateClosing'
  state.
- xencons: generalize use of add_preferred_console() (bnc#733022,
  bnc#852652).
- Refresh other Xen patches.
- commit be0cbdb
* Tue Dec 17 2013 bp@suse.de
- patches.fixes/net-rework-recvmsg-handler-msg_name-and-msg_namelen-logic.patch:
  net: rework recvmsg handler msg_name and msg_namelen logic
  (bnc#854722).
- commit bcd6863
* Mon Dec 16 2013 bp@suse.de
- patches.fixes/crypto-gf128mul-fix-call-to-memset.patch: crypto:
  gf128mul - fix call to memset() (obvious fix).
- commit dd2e215
* Mon Dec 16 2013 bp@suse.de
- patches.fixes/crypto-ansi_cprng-fix-off-by-one-error-in-non-block-size-request.patch:
  crypto: ansi_cprng - Fix off by one error in non-block size
  request (bnc#840226).
- commit 1f9d5e1
* Sat Dec 14 2013 bp@suse.de
- patches.fixes/aacraid-missing-capable-check-in-compat-ioctl.patch:
  aacraid: missing capable() check in compat ioctl (bnc#852558).
- commit de0d113
* Fri Dec 13 2013 bpoirier@suse.de
- igb: Fix get_fw_version function for all parts (bnc#848317).
- igb: Refactor of init_nvm_params (bnc#848317).
- commit cd50178
* Thu Dec 12 2013 jdelvare@suse.de
- patches.fixes/st-take-additional-queue-ref-in-st_probe.patch:
  Update upstream reference.
- commit 0cd9ac8
* Wed Dec 11 2013 neilb@suse.de
- Update a bugzilla reference.
- commit 1b9a7b8
* Wed Dec 11 2013 tonyj@suse.de
- perf/ftrace: Fix paranoid level for enabling function tracer
  (bnc#849362).
- commit 1422b5d
* Wed Dec 11 2013 tiwai@suse.de
- xhci: Limit the spurious wakeup fix only to HP machines
  (bnc#833097).
- commit de50395
* Wed Dec 11 2013 neilb@suse.de
- patches.fixes/SUNRPC-Fix-a-data-corruption-issue-when-retransmitti.patch:
  SUNRPC: Fix a data corruption issue when retransmitting RPC
  calls (no bugzilla yet - netapp confirms problem and fix).
- commit f31f71b
* Tue Dec 10 2013 jack@suse.cz
- patches.fixes/xfs-Account-log-unmount-transaction-correctly.patch:
  xfs: Account log unmount transaction correctly (bnc#849950).
- commit e9c61b3
* Mon Dec  9 2013 duwe@suse.de
- Update config files.
- commit ff0135e
* Mon Dec  9 2013 duwe@suse.de
- powerpc: Fix memory hotplug with sparse vmemmap (bnc#827527).
- memory-hotplug: implement register_page_bootmem_info_section
  of sparse-vmemmap (bnc#827527).
- powerpc/mm: Mark Memory Resources as busy (bnc#827527).
- powerpc: Add System RAM to /proc/iomem (bnc#827527).
- commit df0d341
* Mon Dec  9 2013 dsterba@suse.cz
- Btrfs: don't BUG_ON() if we get an error walking backrefs
  (FATE#312888).
- Delete
  patches.suse/btrfs-8151-optimize-key-searches-in-btrfs_search_slot.patch.
- commit 2c55b45
* Mon Dec  9 2013 hare@suse.de
- iscsi_target: race condition on shutdown (bnc#850072).
- commit 41d0aa3
* Mon Dec  9 2013 hare@suse.de
- lpfc: correct some issues with txcomplq processing (bnc#818064).
- lpfc: correct an issue with rrq processing (bnc#818064).
- commit 50052f7
* Fri Dec  6 2013 duwe@suse.de
- powerpc: Fix fatal SLB miss when restoring PPR (bnc#853465).
- commit 8196bce
* Fri Dec  6 2013 duwe@suse.de
- powerpc/pseries: Parse and handle EPOW interrupts (bnc#852761).
- powerpc: Make function that parses RTAS error logs global
  (bnc#852761).
- commit 5469c49
* Thu Dec  5 2013 jack@suse.cz
- patches.fixes/blkdev_max_block-make-private-to-fs-buffer.c.patch:
  blkdev_max_block: make private to fs/buffer.c (bnc#820338).
- patches.fixes/vfs-avoid-attempt-to-access-beyond-end-of-device-war.patch:
  vfs: avoid "attempt to access beyond end of device" warnings
  (bnc#820338).
- patches.fixes/vfs-fix-O_DIRECT-read-past-end-of-block-device.patch:
  vfs: fix O_DIRECT read past end of block device (bnc#820338).
- patches.suse/block-nonblock-causes-failfast: Refresh.
- commit 806eab3
* Thu Dec  5 2013 tiwai@suse.de
- drm/i915: add I915_PARAM_HAS_VEBOX to i915_getparam
  (bnc#831103,FATE#316109).
- drm/i915: add I915_EXEC_VEBOX to i915_gem_do_execbuffer()
  (bnc#831103,FATE#316109).
- drm/i915: add VEBOX into debugfs (bnc#831103,FATE#316109).
- drm/i915: Enable vebox interrupts (bnc#831103,FATE#316109).
- drm/i915: vebox interrupt get/put (bnc#831103,FATE#316109).
- drm/i915: consolidate interrupt naming scheme
  (bnc#831103,FATE#316109).
- drm/i915: Convert irq_refounct to struct
  (bnc#831103,FATE#316109).
- drm/i915: make PM interrupt writes non-destructive
  (bnc#831103,FATE#316109).
- drm/i915: Add PM regs to pre/post install
  (bnc#831103,FATE#316109).
- drm/i915: Create an ivybridge_irq_preinstall
  (bnc#831103,FATE#316109).
- drm/i915: Create a more generic pm handler for hsw+
  (bnc#831103,FATE#316109).
- drm/i915: Vebox ringbuffer init (bnc#831103,FATE#316109).
- drm/i915: add HAS_VEBOX (bnc#831103,FATE#316109).
- drm/i915: Rename ring flush functions (bnc#831103,FATE#316109).
- drm/i915: Add VECS semaphore bits (bnc#831103,FATE#316109).
- drm/i915: Introduce VECS: the 4th ring (bnc#831103,FATE#316109).
- drm/i915: Semaphore MBOX update generalization
  (bnc#831103,FATE#316109).
- drm/i915: Comments for semaphore clarification
  (bnc#831103,FATE#316109).
- commit a647e22
* Thu Dec  5 2013 hare@suse.de
- target: Fixup workqueue name (bnc#825056)
- commit 6abfbbd
* Thu Dec  5 2013 hare@suse.de
- patches.fixes/scsi_dh-invoke-callback-if-activate-is-not-present.patch:
  scsi_dh: invoke callback if ->activate is not present
  (bnc#708296).
- patches.fixes/scsi_dh-return-individual-errors-in-scsi_dh_activate.patch:
  scsi_dh: return individual errors in scsi_dh_activate()
  (bnc#708296).
- patches.fixes/scsi_dh_alua-Decode-EMC-Clariion-extended-inquiry.patch:
  scsi_dh_alua: Decode EMC Clariion extended inquiry (bnc#708296).
- patches.fixes/scsi_dh_alua-Decode-HP-EVA-array-identifier.patch:
  scsi_dh_alua: Decode HP EVA array identifier (bnc#708296).
- patches.fixes/scsi_dh_alua-Evaluate-state-for-all-port-groups.patch:
  scsi_dh_alua: Evaluate state for all port groups (bnc#708296).
- patches.fixes/scsi_dh_alua-Fix-missing-close-brace-in-alua_check_s.patch:
  scsi_dh_alua: Fix missing close brace in alua_check_sense
  (bnc#843642).
- patches.fixes/scsi_dh_alua-Make-stpg-synchronous.patch:
  scsi_dh_alua: Make stpg synchronous (bnc#708296).
- patches.fixes/scsi_dh_alua-Pass-buffer-as-function-argument.patch:
  scsi_dh_alua: Pass buffer as function argument (bnc#708296).
- patches.fixes/scsi_dh_alua-Re-evaluate-port-group-states-after-STP.patch:
  scsi_dh_alua: Re-evaluate port group states after STPG
  (bnc#708296).
- patches.fixes/scsi_dh_alua-Recheck-state-on-transitioning.patch:
  scsi_dh_alua: Recheck state on transitioning (bnc#708296).
- patches.fixes/scsi_dh_alua-Rework-rtpg-workqueue.patch:
  scsi_dh_alua: Rework rtpg workqueue (bnc#708296).
- patches.fixes/scsi_dh_alua-Use-separate-alua_port_group-structure.patch:
  scsi_dh_alua: Use separate alua_port_group structure
  (bnc#708296).
- patches.fixes/scsi_dh_alua-allow-get_alua_data-to-return-NULL.patch:
  scsi_dh_alua: Allow get_alua_data() to return NULL (bnc#839407).
- patches.fixes/scsi_dh_alua-asynchronous-RTPG.patch:
  scsi_dh_alua: asynchronous RTPG (bnc#708296).
- patches.fixes/scsi_dh_alua-correctly-terminate-target-port-strings.patch:
  scsi_dh_alua: correctly terminate target port strings
  (bnc#708296).
- patches.fixes/scsi_dh_alua-defer-I-O-while-workqueue-item-is-pendi.patch:
  scsi_dh_alua: defer I/O while workqueue item is pending
  (bnc#708296).
- patches.fixes/scsi_dh_alua-do-not-attach-raid-devices.patch:
  scsi_dh_alua: Do not attach to RAID or enclosure devices
  (bnc#819979).
- patches.fixes/scsi_dh_alua-do-not-attach-to-WLUNs.patch:
  scsi_dh_alua: Do not attach to well-known LUNs (bnc#821980).
- patches.fixes/scsi_dh_alua-fine-grained-locking-in-alua_rtpg_work.patch:
  scsi_dh_alua: fine-grained locking in alua_rtpg_work()
  (bnc#708296).
- patches.fixes/scsi_dh_alua-invalid-state-information-for-optimized.patch:
  scsi_dh_alua: invalid state information for 'optimized' paths
  (bnc#843445).
- patches.fixes/scsi_dh_alua-move-RTPG-to-workqueue.patch:
  scsi_dh_alua: move RTPG to workqueue (bnc#708296).
- patches.fixes/scsi_dh_alua-move-expiry-into-PG-structure.patch:
  scsi_dh_alua: move 'expiry' into PG structure (bnc#708296).
- patches.fixes/scsi_dh_alua-move-some-sense-codes.patch:
  scsi_dh_alua: move some sense code handling into generic code
  (bnc#813245).
- patches.fixes/scsi_dh_alua-multipath-failover-fails.patch:
  scsi_dh_alua: multipath failover fails with error 15
  (bnc#825696).
- patches.fixes/scsi_dh_alua-parse-target-device-id.patch:
  scsi_dh_alua: parse target device id (bnc#708296).
- patches.fixes/scsi_dh_alua-protect-accesses-to-struct-alua_port_gr.patch:
  scsi_dh_alua: protect accesses to struct alua_port_group
  (bnc#708296).
- patches.fixes/scsi_dh_alua-put-sense-buffer-on-stack.patch:
  scsi_dh_alua: put sense buffer on stack (bnc#708296).
- patches.fixes/scsi_dh_alua-reattach-device-handler-failure.patch:
  scsi_dh_alua: reattaching device handler fails with 'Error 15'
  (bnc#843429).
- patches.fixes/scsi_dh_alua-remove-locking-when-checking-state.patch:
  scsi_dh_alua: remove locking when checking state (bnc#708296).
- patches.fixes/scsi_dh_alua-remove-stale-variable.patch:
  scsi_dh_alua: remove stale variable (bnc#708296).
- patches.fixes/scsi_dh_alua-retry-RTPG-on-UNIT-ATTENTION.patch:
  scsi_dh_alua: retry RTPG on UNIT ATTENTION (bnc#708296).
- patches.fixes/scsi_dh_alua-retry-command-on-mode-parameter-changed.patch:
  scsi_dh_alua: retry command on 'mode parameter changed' sense
  code (bnc#843645).
- patches.fixes/scsi_dh_alua-simplify-alua_check_sense.patch:
  scsi_dh_alua: simplify alua_check_sense() (bnc#843642).
- patches.fixes/scsi_dh_alua-simplify-state-update.patch:
  scsi_dh_alua: simplify state update (bnc#708296).
- patches.fixes/scsi_dh_alua-use-delayed_work.patch: scsi_dh_alua:
  use delayed_work (bnc#708296).
- patches.fixes/scsi_dh_alua-use-flag-for-RTPG-extended-header.patch:
  scsi_dh_alua: use flag for RTPG extended header (bnc#708296).
- patches.fixes/scsi_dh_alua-use-local-buffer-for-VPD-inquiry.patch:
  scsi_dh_alua: use local buffer for VPD inquiry (bnc#708296).
- patches.fixes/scsi_dh_alua-use-spin_lock_irqsave-for-port-group.patch:
  scsi_dh_alua: use spin_lock_irqsave for port group (bnc#708296).
- patches.fixes/sd-avoid-deadlocks-when-running-under-multipath.patch:
  sd: avoid deadlocks when running under multipath (bnc#818545).
- commit 032683b
* Wed Dec  4 2013 jbeulich@suse.com
- netback: bump tx queue length (bnc#849404).
- commit 7422e9b
* Wed Dec  4 2013 jbeulich@suse.com
- Refresh Xen patches.
- patches.xen/xen-netback-tx-queue-len: netback: bump tx queue
  length (bnc#849404).
- commit 4648aa1
* Wed Dec  4 2013 oneukum@suse.de
- storage: SMI Corporation usb key added to READ_CAPACITY_10 quirk
  (bnc#850324).
- commit dfc2413
* Wed Dec  4 2013 mgorman@suse.de
- patches.fixes/xfs-improve-ioend-error-handling: Refresh.
- commit f4d97d7
* Tue Dec  3 2013 bpoirier@suse.de
- r8169: check ALDPS bit and disable it if enabled for the 8168g
  (bnc#845352).
  (cherry picked from commit 17053c4cdd75206964e9a5cca9edaeeec8f012cf)
- r8169: check ALDPS bit and disable it if enabled for the 8168g
  (bnc#845352).
- commit 5173ee5
* Mon Dec  2 2013 neilb@suse.de
- patches.fixes/nfs-lock-recovery.fix: Change NFSv4 to not
  recover locks after they are lost (bnc#828236).
- commit b63ceea
* Mon Dec  2 2013 jeffm@suse.com
- patches.fixes/sg-fix-blk_get_queue-usage: sg: fix blk_get_queue
  usage (bnc#834808).
- commit ee7db2e
* Mon Dec  2 2013 sparkaonkar@suse.de
- patches.fixes/sg-fix-blk_get_queue-usage:
  sg: fix blk_get_queue usage (bnc#834808).
- commit 82fe542
* Mon Dec  2 2013 jeffm@suse.de
- sg: fix blk_get_queue usage (bnc#834808).
- commit d085b03
* Fri Nov 29 2013 eich@suse.com
- drm/mgag200: Bug fix: Modified pll algorithm for EH project
  (bnc#841654).
- commit b5c36c6
* Fri Nov 29 2013 eich@suse.com
- drm/i915: fix gen4 digital port hotplug definitions
  (bnc#850103).
- commit 1cf0993
* Fri Nov 29 2013 bpoirier@suse.de
- patches.fixes/netxen-fix-off-by-one-bug-in-netxen_release_tx_buffe.patch:
  netxen: fix off by one bug in netxen_release_tx_buffer()
  (bnc#845729).
- commit dcebd6d
* Fri Nov 29 2013 hare@suse.de
- patches.drivers/lpfc-Do-not-free-original-IOCB-whenever-ABTS-fails.patch:
  lpfc: Do not free original IOCB whenever ABTS fails
  (bnc#806988).
- patches.drivers/lpfc-Fix-kernel-warning-on-spinlock-usage.patch:
  lpfc: Fix kernel warning on spinlock usage (bnc#806988).
- patches.drivers/lpfc-Fixed-system-panic-due-to-midlayer-abort.patch:
  lpfc:  Fixed system panic due to midlayer abort (bnc#806988).
- commit c0b78d3
* Fri Nov 29 2013 hare@suse.de
- dm-mpath: Fixup race condition in activate_path() (bnc#708296).
- dm-mpath: do not detach stale hardware handler (bnc#708296).
- dm-multipath: Improve logging (bnc#708296).
- scsi_dh_alua: defer I/O while workqueue item is pending
  (bnc#708296).
- scsi_dh_alua: Rework rtpg workqueue (bnc#708296).
- scsi_dh_alua: use delayed_work (bnc#708296).
- scsi_dh_alua: move 'expiry' into PG structure (bnc#708296).
- scsi_dh: invoke callback if ->activate is not present
  (bnc#708296).
- scsi_dh_alua: correctly terminate target port strings
  (bnc#708296).
- scsi_dh_alua: retry RTPG on UNIT ATTENTION (bnc#708296).
- scsi_dh_alua: protect accesses to struct alua_port_group
  (bnc#708296).
- scsi_dh_alua: fine-grained locking in alua_rtpg_work()
  (bnc#708296).
- scsi_dh_alua: use spin_lock_irqsave for port group (bnc#708296).
- scsi_dh_alua: remove locking when checking state (bnc#708296).
- scsi_dh_alua: remove stale variable (bnc#708296).
- scsi_dh: return individual errors in scsi_dh_activate()
  (bnc#708296).
- commit d56ac36
* Fri Nov 29 2013 hare@suse.de
- patches.fixes/sd-fix-crash-when-UA-received.patch: Delete.
- commit ad38cef
* Fri Nov 29 2013 hare@suse.de
- patches.drivers/qla2xxx-add-module-paremeter-to-override.patch:
  qla2xxx: Add module parameter to override the default request
  queue size (bnc#826756).
- patches.fixes/sd-fix-crash-when-UA-received.patch: sd: fix
  crash when UA received on DIF enabled device (bnc#841445).
- commit 778a1ab
* Fri Nov 29 2013 hare@suse.de
- qla2xxx: Add module parameter to override the default request
  queue size (bnc#826756).
- commit 85605a9
* Fri Nov 29 2013 jdelvare@suse.de
- mei: ME hardware reset needs to be synchronized (bnc#821619).
- commit 97a989b
* Thu Nov 28 2013 jdelvare@suse.de
- patches.drivers/watchdog-get-rid-of-module_alias_miscdev-statements.patch:
  watchdog: Get rid of MODULE_ALIAS_MISCDEV statements
  (bnc#827767).
- commit 2da7aa7
* Thu Nov 28 2013 jkosina@suse.cz
- patches.fixes/pci-fix-truncation-of-resource-size-to-32-bits.patch:
  PCI: fix truncation of resource size to 32 bits (bnc#843419).
- commit c10ab49
* Wed Nov 27 2013 mmarek@suse.cz
- kabi: Restore struct irq_desc::timer_rand_state.
- commit 6de8362
* Wed Nov 27 2013 mmarek@suse.cz
- Delete obsolete patches.suse/revert-tytsos-random-changes
- commit 4a6bbb2
* Tue Nov 26 2013 jjolly@suse.de
- patches.arch/s390-68-01-qeth-snmp-ioctl.patch: qeth: request
  length checking in snmp ioctl (bnc#849848, LTC#99511).
- commit 6b73c0b
* Tue Nov 26 2013 jkosina@suse.cz
- patches.fixes/random-fix-accounting-race-condition-with-lockless-i.patch:
  random: fix accounting race condition with lockless irq
  entropy_count update (bnc#789359).
- patches.suse/revert-some-random-changes: Delete.
  Remove the temporary revert (workaround) and replace with proper fix.
- commit 20e6c5e
* Tue Nov 26 2013 jjolly@suse.de
- kernel: correct handling of asce-type exceptions (bnc#851879,
  LTC#100293).
- commit a59225c
* Tue Nov 26 2013 jjolly@suse.de
- fs3270: unloading module does not remove device (bnc#851879,
  LTC#100284).
- commit 84392d9
* Tue Nov 26 2013 eich@suse.com
- Updated status of some of the fixes for the mgag200 KMS driver.
  patches.drm/drm-mgag200-Add-an-crtc_disable-callback-to-the-crtc-helper-funcs.patch.
  patches.drm/drm-mgag200-Add-sysfs-support-for-connectors.patch.
  patches.drm/drm-mgag200-Fix-LUT-programming-for-16bpp.patch.
  patches.drm/drm-mgag200-Fix-framebuffer-pitch-calculation.patch.
  patches.drm/drm-mgag200-Fix-logic-in-mgag200_bo_pin-v2.patch.
- commit 3dbed64
* Tue Nov 26 2013 mgalbraith@suse.de
- Pragmatic workaround for realtime class abuse induced latency issues.
- patches.fixes/sched-provide-nortsched-boot-option.patch:
  Provide boot option to disable sched_rt_runtime (bnc#610783).
- patches.fixes/sched-provide-rtkthreads-rtworkqueues-boot-options.patch:
  Provide realtime priority kthread and workqueue boot options (bnc#836718).
- patches.arch/bug-610783_uv_nortsched_boot_option.patch: Delete.
- commit d033a55
* Mon Nov 25 2013 brogers@suse.com
- patches.fixes/kvm-fix-iommu-map-unmap-to-handle-memory-slot-moves.patch:
  KVM: Fix iommu map/unmap to handle memory slot moves
  (CVE-2013-4592 bnc851101).
- patches.fixes/kvm-perform-an-invalid-memslot-step-for-gpa-base-change.patch:
  KVM: perform an invalid memslot step for gpa base change
  (CVE-2013-4592 bnc851101).
- commit 7b82306
* Mon Nov 25 2013 brogers@suse.com
- KVM: Fix iommu map/unmap to handle memory slot moves
  (CVE-2013-4592 bnc851101).
- KVM: perform an invalid memslot step for gpa base change
  (CVE-2013-4592 bnc851101).
- commit 9643d5a
* Mon Nov 25 2013 mmarek@suse.cz
- Refresh patches.drivers/pci-Chelsio-quirk-Enable-Bus-Master-during-Function-Level-Reset.patch
- commit a103dd6
* Mon Nov 25 2013 mgalbraith@suse.de
- bnc#848336 L3: Fix several races in CFS_BANDWIDTH
- patches.fixes/sched-Fix-cfs_bandwidth-misuse-of-hrtimer_expires_remaining.patch:
  sched: Fix cfs_bandwidth misuse of hrtimer_expires_remaining (bnc#848336).
- patches.fixes/sched-Fix-hrtimer_cancel-vs-rq-lock-deadlock.patch:
  sched: Fix hrtimer_cancel()/rq->lock deadlock (bnc#848336).
- patches.fixes/sched-Fix-race-on-toggling-cfs_bandwidth_used.patch:
  sched: Fix race on toggling cfs_bandwidth_used (bnc#848336).
- patches.fixes/sched-Guarantee-new-group-entities-always-have-weight.patch:
  sched: Guarantee new group-entities always have weight (bnc#848336).
- patches.fixes/sched-Use-jump-labels-to-reduce-overhead-when-bandwidth-control-is-inactive.patch:
  sched: Use jump labels to reduce overhead when bandwidth control is inactive (bnc#848336).
- patches.suse/perfmon2.patch: Refresh.
- commit 606167f
* Sat Nov 23 2013 jeffm@suse.com
- btrfs: refresh patchset
- Several patches replaced by upstream versions
- Move SUSE patches to the end of the btrfs series to keep
  context sane for backports.
- Minor code changes, no functional changes except for
  the removal of a double-call of btrfs_truncate_item that would have
  done nothing anyway.
- Moved shims out of transaction.c and into compat.h
- commit 827e1df
* Fri Nov 22 2013 jjolly@suse.de
- s390/pci: implement hotplug notifications (FATE#83037,
  LTC#94737).
- commit 3dfd89f
* Fri Nov 22 2013 jjolly@suse.de
- s390/pci: implement pcibios_remove_bus (FATE#83037, LTC#94737).
- commit 0693f22
* Fri Nov 22 2013 jjolly@suse.de
- s390/pci: improve handling of bus resources (FATE#83037,
  LTC#94737).
- commit e76e0dd
* Fri Nov 22 2013 jkosina@suse.cz
- patches.drivers/pci-Chelsio-quirk-Enable-Bus-Master-during-Function-Level-Reset.patch:
  Modify reset method for Chelsio T4 to avoid hanging when,
  for example, VM using it is terminated (bnc#831168).
- commit 24e374c
* Thu Nov 21 2013 jeffm@suse.com
- btrfs: update Git-commit tags
- commit 9d5900e
* Thu Nov 21 2013 oneukum@suse.de
- Delete
  patches.drivers/0001-quirks-add-touchscreen-that-is-dazzeled-by-remote-wa.patch.
  The patch fixed an issue but caused bnc#846568
- commit 63dbbf1
* Wed Nov 20 2013 jdelvare@suse.de
- patches.arch/iommu-vt-d-remove-stack-trace-from-broken-irq-remapping-warning.patch:
  Update upstream reference.
- commit b8e6c1d
* Wed Nov 20 2013 jack@suse.cz
- patches.fixes/xfs-improve-ioend-error-handling: xfs: improve
  ioend error handling (bnc#846036).
- patches.fixes/xfs-reduce-ioend-latency: xfs: reduce ioend
  latency (bnc#846036).
- patches.fixes/xfs-use-per-filesystem-i-o-completion-workqueues:
  xfs: use per-filesystem I/O completion workqueues (bnc#846036).
- patches.kabi/xfs-use-per-filesystem-i-o-completion-workqueues-kabi:
  xfs: Hide additional entries in struct xfs_mount (bnc#846036
  bnc#848544).
- commit bab15b2
* Wed Nov 20 2013 jack@suse.cz
- xfs: Hide additional entries in struct xfs_mount (bnc#846036
  bnc#848544).
- xfs: use per-filesystem I/O completion workqueues (bnc#846036).
- xfs: improve ioend error handling (bnc#846036).
- xfs: reduce ioend latency (bnc#846036).
- commit 0e85461
* Tue Nov 19 2013 jbohac@suse.cz
- supported.conf: marked net/netfilter/xt_set as supported (bnc#851066)
  xt_set should have been enabled together with the ip_set modules in
  fate#313309
- commit 66f20ac
* Tue Nov 19 2013 ohering@suse.de
- patches.suse/suse-hv-hv_kvp-sles11sp2-negotiate-serveral-versions.patch:
  handle more than just WS2008 in KVP negotiation (bnc#850640).
- commit 8faab33
* Tue Nov 19 2013 mmarek@suse.cz
- Update s390x kabi files (bnc#848335, LTC#99117)
- commit 9d9ac3c
* Tue Nov 19 2013 jjolly@suse.de
  net/mlx4_core: Fix endianness bug in set_param_l
  (bnc#848335,LTC#94737).
- commit ffcbd68
* Tue Nov 19 2013 jjolly@suse.de
  asm-generic: io: Fix ioread16/32be and iowrite16/32be
  (bnc#848335,LTC#94737).
- commit b2ad829
* Tue Nov 19 2013 jjolly@suse.de
-    PCI: Add pcibios_add_device (bnc#848335,LTC#94737).
- Refresh
  patches.drivers/pci-001-PCI-Add-pcibios_release_device.patch.
- Refresh patches.drivers/pci-002-PCI-Add-pcibios_pm_ops.patch.
- commit 0c94da6
* Mon Nov 18 2013 jjolly@suse.de
- qeth: request length checking in snmp ioctl (bnc#847660,
  LTC#99511).
- commit 863e8e8
* Mon Nov 18 2013 jjolly@suse.de
- kernel: correct tlb flush on page table upgrade (bnc#847660,
  LTC#99268).
- commit 8201957
* Mon Nov 18 2013 jjolly@suse.de
- kernel: fix floating-point-control register save and restore
  (bnc#847660, LTC#99000).
- commit 1b4e1b0
* Mon Nov 18 2013 jjolly@suse.de
- crypto: unload of aes_s390 module causes kernel panic
  (bnc#847660, LTC#98706).
- commit fa6fa56
* Mon Nov 18 2013 bpoirier@suse.de
- patches.fixes/mlx4-allocate-just-enough-pages-instead-of-always-4-.patch:
  mlx4: allocate just enough pages instead of always 4 pages
  (bnc#835186 bnc#835074).
- patches.fixes/mlx4-allow-order-0-memory-allocations-in-RX-path.patch:
  mlx4: allow order-0 memory allocations in RX path (bnc#835186
  bnc#835074).
- patches.fixes/net-mlx4-use-one-page-fragment-per-incoming-frame.patch:
  net/mlx4: use one page fragment per incoming frame (bnc#835186
  bnc#835074).
- commit 968eb52
* Mon Nov 18 2013 tiwai@suse.de
- ALSA: hda - load EQ params into IDT codec on HP bNB13 systems
  (bnc#850493).
- commit 67b7d16
* Mon Nov 18 2013 eich@suse.com
- Remove limit from patches.drm/drm-mgag200-Add-missing-limits.patch
  This limit should be taken care of by:
  patches.drm/drm-mgag200-Reject-modes-that-are-too-big-for-VRAM
- Refresh
  patches.drm/drm-mgag200-Reject-modes-when-hdisplay-is-no-multiple-of-8.patch.
- commit 4f969d0
* Mon Nov 18 2013 eich@suse.com
  drm/mgag200: Add missing write to index before accessing data register (bnc #806990).
  This patch replaces
    patches.drm/drm-mgag200-Add-missing-write-to-index-before-accessing-data-register.patch
  by its upstream variant.
  - Refresh:
  * patches.drm/drm-mgag200-Add-doublescan-and-interlace-support.patch.
  * patches.drm/drm-mgag200-Add-missing-limits.patch.
  * patches.drm/drm-mgag200-Added-resolution-and-bandwidth-limits-for-various-G200e-products.patch.
  * patches.drm/drm-mgag200-Reject-modes-when-hdisplay-is-no-multiple-of-8.patch.
  - Delete
  * patches.drm/drm-mgag200-In-all-code-paths-set-index-register-before-writing-data-register.patch.
- commit ed29d54
* Mon Nov 18 2013 neilb@suse.de
- patches.fixes/NFS-Adapt-readdirplus-to-application-usage-patterns.patch:
  NFS: Adapt readdirplus to application usage patterns
  (bnc#834708).
- commit 87021d7
* Fri Nov 15 2013 eich@suse.com
- Replace MGA G200 bandwidth limit code with variant from upstream
  Add limits still missing upstream in separate patches, refresh
  subsequent patches:
- drm/mgag200: Added resolution and bandwidth limits for various
  G200e products.
- drm/mgag200: Add doublescan and interlace support.
- drm/mgag200: Add additional limits for certain G200 variants.
- Refresh
  patches.drm/drm-mgag200-Add-sysfs-support-for-connectors.patch.
- Refresh
  patches.drm/drm-mgag200-Fix-logic-in-mgag200_bo_pin-v2.patch.
- Refresh
  patches.drm/drm-mgag200-In-all-code-paths-set-index-register-before-writing-data-register.patch.
- Refresh
  patches.drm/drm-mgag200-Reject-modes-when-hdisplay-is-no-multiple-of-8.patch.
- Delete
  patches.drm/drm-mgag200-Add-bandwidth-and-resolution-limits.patch.
- commit 4236b29
* Fri Nov 15 2013 trenn@suse.de
- Working around KABI breakage for the newly introduce disable field in
  struct cpuidle_state is wrong. We have a real KABI break. Re-implement
  disabling C-state patches by using an unused bit of the flags field:
- Refresh
  patches.fixes/cpuidle_disable_cstates_also_honor_ladder_governor.patch.
- Refresh patches.fixes/cpuidle_disable_cstates_via_sysfs.patch.
- commit 9ee60ec
* Fri Nov 15 2013 jbeulich@suse.com
- Refresh Xen patches.
- commit 1e135a5
* Fri Nov 15 2013 hare@suse.de
-  isci: Fix a race condition in the SSP task management path
  (bnc#826978).
- commit 9bf07c6
* Thu Nov 14 2013 eich@suse.com
- drm/mgag200: Add sysfs support for connectors.
- commit 4de2ac9
* Thu Nov 14 2013 eich@suse.com
- drm/mgag200: Add an crtc_disable callback to the crtc helper funcs.
- commit c1b6196
* Thu Nov 14 2013 eich@suse.com
- drm/mgag200: Fix logic in mgag200_bo_pin() (v2).
  Replace
    patches.drm/drm-mgag200-Fix-logic-in-mgag200_bo_pin.patch
  by
    patches.drm/drm-mgag200-Fix-logic-in-mgag200_bo_pin-v2.patch.
  which is considerably simpler.
- commit 8b51fb9
* Thu Nov 14 2013 trenn@suse.de
- Introduce KABI exception for cpuidle_state->disable via #ifndef __GENKSYMS__
  Refresh patches.fixes/cpuidle_disable_cstates_via_sysfs.patch.
- commit 908c75f
* Thu Nov 14 2013 eich@suse.com
- patches.drivers/drm-don-t-add-inferred-modes-for-monitors-that-don-t-support-them.patch:
  drm: don't add inferred modes for monitors that don't support them
  (bnc #849809).
  This patch is a backport of 19874f6d774ef39dbfa5e12ecd19df7fd62a1af5
  in the SP3 branch for bnc#798466.
- commit 41c0919
* Thu Nov 14 2013 bp@suse.de
- patches.fixes/0001-PCI-pciehp-Retrieve-link-speed-after-link-is-trained.patch:
  PCI: pciehp: Retrieve link speed after link is trained
  (bnc#820102).
- patches.fixes/0002-PCI-Separate-pci_bus_read_dev_vendor_id-from-pci_sca.patch:
  PCI: Separate pci_bus_read_dev_vendor_id from pci_scan_device
  (bnc#820102).
- patches.fixes/0003-PCI-pciehp-replace-unconditional-sleep-with-config-s.patch:
  PCI: pciehp: replace unconditional sleep with config space
  access  check (bnc#820102).
- patches.fixes/0004-PCI-pciehp-make-check_link_active-more-helpful.patch:
  PCI: pciehp: make check_link_active more helpful (bnc#820102).
- patches.fixes/0005-PCI-pciehp-Add-pcie_wait_link_not_active.patch:
  PCI: pciehp: Add pcie_wait_link_not_active() (bnc#820102).
- patches.fixes/0006-PCI-pciehp-Add-Disable-enable-link-functions.patch:
  PCI: pciehp: Add Disable/enable link functions (bnc#820102).
- patches.fixes/0007-PCI-pciehp-Disable-enable-link-during-slot-power-off.patch:
  PCI: pciehp: Disable/enable link during slot power off/on
  (bnc#820102).
- commit 9cda8d4
* Thu Nov 14 2013 trenn@suse.de
- Honor state disabling in the cpuidle ladder governor
  (bnc#845378).
- cpuidle: add a sysfs entry to disable specific C state for
  debug purpose (bnc#845378).
- commit 0b84803
* Wed Nov 13 2013 bp@suse.de
- x86: Remove some noise from boot log when starting cpus
  (bnc#770541).
- nohz: Remove "Switched to NOHz mode" debugging messages
  (bnc#770541).
- commit 2e35920
* Wed Nov 13 2013 mmarek@suse.cz
- Update drivers/tty/hvc kabi checksums for s390x (bnc#837739)
- commit e00bb91
* Wed Nov 13 2013 trenn@suse.de
- x86/microcode/amd: Tone down printk(), don't treat a missing
  firmware file as an error (bnc#843654).
- commit e5e75f6
* Wed Nov 13 2013 mkubecek@suse.cz
- patches.fixes/xfrm-invalidate-dst-on-policy-insertion-deletion.patch:
  xfrm: invalidate dst on policy insertion/deletion (bnc#842239).
- patches.fixes/xfrm-prevent-ipcomp-scratch-buffer-race-condition.patch:
  xfrm: prevent ipcomp scratch buffer race condition (bnc#842239).
- commit 69d3894
* Tue Nov 12 2013 neilb@suse.de
- patches.fixes/dcache-soft-lockup.fix: Avoid softlockup in
  shrink_dcache_for_umount_subtree (bnc#834473).
- commit fa05a75
* Mon Nov 11 2013 jjolly@suse.de
- Update config files.
- commit cdcbda4
* Mon Nov 11 2013 jjolly@suse.de
- Refresh
  patches.drivers/pci-001-PCI-Add-pcibios_release_device.patch.
- commit 5f2ea02
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: cleanup function information block
  (bnc#848335,FATE#83037,LTC#94737).
- commit 02fd661
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: remove CONFIG_PCI_DEBUG dependancy
  (bnc#848335,FATE#83037,LTC#94737).
- commit c50f61b
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: message cleanup (bnc#848335,FATE#83037,LTC#94737).
- commit 4fc547c
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: implement hibernation hooks
  (bnc#848335,FATE#83037,LTC#94737).
- commit ff7e67a
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: use virtual memory for iommu bitmap
  (bnc#848335,FATE#83037,LTC#94737).
- commit b61049c
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: update function handle after resume from hibernate
  (bnc#848335,FATE#83037,LTC#94737).
- commit b96cb9f
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci/hotplug: convert to be builtin only
  (bnc#848335,FATE#83037,LTC#94737).
- commit fac2a7e
* Mon Nov 11 2013 jjolly@suse.de
- s390/hibernate: add early resume function
  (bnc#848335,FATE#83037,LTC#94737).
- commit ce0eec6
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: try harder to modify a function
  (bnc#848335,FATE#83037,LTC#94737).
- commit 3caf703
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: split lpf (bnc#848335,FATE#83037,LTC#94737).
- commit 8857fdd
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: add recover sysfs knob
  (bnc#848335,FATE#83037,LTC#94737).
- commit a1af0ea
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: use claim_resource (bnc#848335,FATE#83037,LTC#94737).
- commit db92ce5
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: use adapter interrupt vector helpers
  (bnc#848335,FATE#83037,LTC#94737).
- commit a98ab40
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: cleanup function names
  (bnc#848335,FATE#83037,LTC#94737).
- commit 0830fa5
* Mon Nov 11 2013 jjolly@suse.de
- s390/airq: introduce adapter interrupt vector helper
  (bnc#848335,FATE#83037,LTC#94737).
- commit 611520d
* Mon Nov 11 2013 jjolly@suse.de
- s390/airq: simplify adapter interrupt code
  (bnc#848335,FATE#83037,LTC#94737).
- commit ebee033
* Mon Nov 11 2013 jjolly@suse.de
- s390/bitops: fix find_next_bit_left
  (bnc#848335,FATE#83037,LTC#94737).
- commit 8537c73
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: remove per device debug attribute
  (bnc#848335,FATE#83037,LTC#94737).
- commit 175c1bc
* Mon Nov 11 2013 jjolly@suse.de
- s390/dma: fix mapping_error detection
  (bnc#848335,FATE#83037,LTC#94737).
- commit cf0f2ea
* Mon Nov 11 2013 jjolly@suse.de
- s390/dma: do not call debug_dma after free
  (bnc#848335,FATE#83037,LTC#94737).
- commit 7c011e6
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: sysfs remove strlen (bnc#848335,FATE#83037,LTC#94737).
- commit 492c202
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: remove pdev during unplug
  (bnc#848335,FATE#83037,LTC#94737).
- commit 22d6af9
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: cleanup hotplug code
  (bnc#848335,FATE#83037,LTC#94737).
- commit c93a3d5
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: implement pcibios_release_device
  (bnc#848335,FATE#83037,LTC#94737).
- commit 2ca3f43
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: use to_pci_dev (bnc#848335,FATE#83037,LTC#94737).
- commit f7865dc
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: use pci_scan_root_bus
  (bnc#848335,FATE#83037,LTC#94737).
- commit 6d771f7
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: return correct dma address for offset > PAGE_SIZE
  (bnc#848335,FATE#83037,LTC#94737).
- commit 1a974dc
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: remove disable_device implementation
  (bnc#848335,FATE#83037,LTC#94737).
- commit c29fbf2
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: disable per default (bnc#848335,FATE#83037,LTC#94737).
- commit 380f301
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: return error after failed pci ops
  (bnc#848335,FATE#83037,LTC#94737).
- commit c9dc6b8
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: do not read data after failed load
  (bnc#848335,FATE#83037,LTC#94737).
- commit 4afacc5
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: add exception table to load/store instructions
  (bnc#848335,FATE#83037,LTC#94737).
- commit e73ce37
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: rename instruction wrappers
  (bnc#848335,FATE#83037,LTC#94737).
- commit 00b45d9
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: uninline instruction wrappers
  (bnc#848335,FATE#83037,LTC#94737).
- commit c6999bd
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: implement pcibios_add_device
  (bnc#848335,FATE#83037,LTC#94737).
- commit fbccfb0
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: do not modify function handles
  (bnc#848335,FATE#83037,LTC#94737).
- commit 4ec4c21
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: debug device states (bnc#848335,FATE#83037,LTC#94737).
- commit d071469
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: msi cleanup hash usage
  (bnc#848335,FATE#83037,LTC#94737).
- commit e272160
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: use kmem_cache_zalloc instead of
  kmem_cache_alloc/memset (bnc#848335,FATE#83037,LTC#94737).
- commit 4b19e32
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: fix hotplug module init
  (bnc#848335,FATE#83037,LTC#94737).
- commit 498f4e5
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: cleanup clp page allocation
  (bnc#848335,FATE#83037,LTC#94737).
- commit a4f6ca7
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: cleanup clp inline assembly
  (bnc#848335,FATE#83037,LTC#94737).
- commit bc3f7da
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: rename pci_probe to s390_pci_probe
  (bnc#848335,FATE#83037,LTC#94737).
- commit 4d0ab6d
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: remove dead code (bnc#848335,FATE#83037,LTC#94737).
- commit c5c5981
* Mon Nov 11 2013 jjolly@suse.de
- s390/chsc: cleanup SEI helper functions
  (bnc#848335,FATE#83037,LTC#94737).
- commit 27a5343
* Mon Nov 11 2013 jjolly@suse.de
- s390/chsc: fix SEI usage (bnc#848335,FATE#83037,LTC#94737).
- commit b3603c3
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: performance statistics and debug infrastructure
  (bnc#848335,FATE#83037,LTC#94737).
- commit a01e0ff
* Mon Nov 11 2013 jjolly@suse.de
- s390/qdio: rename the misleading PCI flag of qdio devices
  (bnc#848335,FATE#83037,LTC#94737).
- commit b0c7162
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: remove obsolete email addresses
  (bnc#848335,FATE#83037,LTC#94737).
- commit fd1e317
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: speed up __iowrite64_copy by using pci store block
  insn (bnc#848335,FATE#83037,LTC#94737).
- commit cc5952b
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: no msleep in potential IRQ context
  (bnc#848335,FATE#83037,LTC#94737).
- commit f566deb
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: s390 specific PCI sysfs attributes
  (bnc#848335,FATE#83037,LTC#94737).
- commit d5d443f
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: PCI hotplug support via SCLP
  (bnc#848335,FATE#83037,LTC#94737).
- commit cf986b3
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: CHSC PCI support for error and availability events
  (bnc#848335,FATE#83037,LTC#94737).
- commit a98ab8a
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: DMA support (bnc#848335,FATE#83037,LTC#94737).
- commit c8e4cc7
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: PCI adapter interrupts for MSI/MSI-X
  (bnc#848335,FATE#83037,LTC#94737).
- commit fe90e84
* Mon Nov 11 2013 jjolly@suse.de
- s390/bitops: find leftmost bit instruction support
  (bnc#848335,FATE#83037,LTC#94737).
- commit 5aca718
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: CLP interface (bnc#848335,FATE#83037,LTC#94737).
- commit 6389351
* Mon Nov 11 2013 jjolly@suse.de
- s390/pci: base support (bnc#848335,FATE#83037,LTC#94737).
- commit f674416
* Mon Nov 11 2013 jjolly@suse.de
- PCI: Add pcibios_pm_ops for optional arch-specific hibernate
  functionality (bnc#848335,FATE#83037,LTC#94737).
- commit 9d169e7
* Mon Nov 11 2013 jjolly@suse.de
- PCI: Add pcibios_release_device()
  (bnc#848335,FATE#83037,LTC#94737).
- commit 882b46c
* Mon Nov 11 2013 jjolly@suse.de
- patches.arch/s390-cio_robust-1-add_message_for_timeouts_on_internal_IO.patch:
  cio: add message for timeouts on internal I/O
  (bnc#837739,LTC#97047).
- patches.arch/s390-cio_robust-2-dont_abort_verification_after_missing_irq.patch:
  s390/cio: dont abort verification after missing irq
  (bnc#837739,LTC#97047).
- patches.arch/s390-cio_robust-3-skip_broken_paths.patch:
  s390/cio: skip broken paths (bnc#837739,LTC#97047).
- patches.arch/s390-cio_robust-4-export_vpm_via_sysfs.patch:
  s390/cio: export vpm via sysfs (bnc#837739,LTC#97047).
- patches.arch/s390-cio_robust-5-handle_unknown_pgroup_state.patch:
  s390/cio: handle unknown pgroup state (bnc#837739,LTC#97047).
- commit 62e2e92
* Mon Nov 11 2013 mhocko@suse.cz
- patches.fixes/fix-printk-oops-from-nmi.patch: printk: forcibly
  flush nmi ringbuffer if oops is in progress (bnc#849675).
- commit 2aef1d8
* Mon Nov 11 2013 bp@suse.de
- x86: Update UV3 hub revision ID (bnc#846298 fate#314987).
- commit ba3f7c4
* Fri Nov  8 2013 jjolly@suse.de
- tty/hvc_iucv: Disconnect IUCV connection when lowering DTR
  (bnc#839973, LTC#97595).
- commit e9dc7d2
* Fri Nov  8 2013 jjolly@suse.de
- tty/hvc_console: Add DTR/RTS callback to handle HUPCL control
  (bnc#839973, LTC#97595).
- commit 523c126
* Thu Nov  7 2013 tiwai@suse.de
- ALSA: hda - Fix inconsistent mic-mute LED (bnc#848864).
- commit d038121
* Thu Nov  7 2013 mhocko@suse.cz
- patches.fixes/ipc-ipc_rcu_putref-race.patch: fix
  ipc_rcu_{get,put}ref during destruction (bnc#848321,
  CVE-2013-4483).
- commit 931061f
* Wed Nov  6 2013 mhocko@suse.cz
- patches.fixes/Fix-a-few-incorrectly-checked-io_-remap_pfn_range-ca.patch:
  Fix a few incorrectly checked [io_]remap_pfn_range() calls
  (bnc#849021, CVE-2013-4511).
- commit 69b0eb0
* Tue Nov  5 2013 mkubecek@suse.cz
- Delete
  patches.drivers/mlx4-0016-net-remove-use-of-ndo_set_multicast_list-in-drivers.patch.
  (bnc#847261)
- Delete
  patches.drivers/qlge-0008-net-remove-use-of-ndo_set_multicast_list-in-drivers.patch.
  (bnc#847261)
- Delete
  patches.drivers/tg3-0002-net-remove-use-of-ndo_set_multicast_list-in-drivers.patch.
  (bnc#847261)
- Refresh
  patches.drivers/tg3-0050-tg3-Move-tg3_change_mtu-to-a-better-location.patch.
- commit 1c5f591
* Tue Nov  5 2013 mkubecek@suse.cz
- patches.drivers/bna-do-not-register-ndo_set_rx_mode-callback.patch:
  bna: do not register ndo_set_rx_mode callback (bnc#847261).
- patches.drivers/0005-net-remove-use-of-ndo_set_multicast_list-in-drivers.patch:
  Delete (bnc#847261).
- patches.drivers/0022-net-remove-use-of-ndo_set_multicast_list-in-drivers.patch:
  Delete (bnc#847261).
- patches.suse/msft-hv-0064-net-remove-use-of-ndo_set_multicast_list-in-drivers.patch:
  Delete (bnc#847261).
- patches.suse/msft-hv-0287-staging-hv-move-hv_netvsc-out-of-staging-area.patch:
  Refresh.
- patches.suse/msft-hv-0305-net-hyperv-Add-support-for-jumbo-frame-up-to-64KB.patch:
  Refresh.
- patches.suse/msft-hv-0361-hyperv-Add-support-for-setting-MAC-from-within-guest.patch:
  Refresh.
- commit 59d07a4
* Tue Nov  5 2013 oneukum@suse.de
- usb: Fix xHCI host issues on remote wakeup (bnc#846989).
- commit 301e5e0
* Tue Nov  5 2013 oneukum@suse.de
- Intel xhci: refactor EHCI/xHCI port switching (bnc#840116).
- xhci-hub.c: preserved kABI (bnc#840116).
- xhci: Refactor port status into a new function (bnc#840116).
- commit 68d24cc
* Mon Nov  4 2013 hare@suse.de
- patches.drivers/qla2xxx-Module-parameter-ql2xasynclogin.patch:
  qla2xxx: Module parameter 'ql2xasynclogin' (bnc#825896).
- commit 6f4951a
* Mon Nov  4 2013 duwe@suse.de
- powerpc/rtas_flash: Fix validate_flash buffer overflow issue
  (bnc#847842).
- powerpc/rtas_flash: Fix bad memory access (bnc#847842).
- commit 583a4e9
* Fri Nov  1 2013 mmarek@suse.cz
- Revert aer_recover_queue() __GENKSYMS__ hack, add a fake symset with the
  previous value instead (bnc#847721)
- commit 2417eb9
* Fri Nov  1 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix for kabi/*/symvers*.fake
- commit f0a52f0
* Thu Oct 31 2013 neilb@suse.de
- patches.fixes/nfs-xs_tcp_setup_socket.fix: SUNRPC: close a
  rare race in xs_tcp_setup_socket (bnc#794824).
- commit 36fae46
* Wed Oct 30 2013 dsterba@suse.cz
- Disable patches.suse/btrfs-8165-fix-negative-qgroup-tracking-from-owher.patch
  Patch Btrfs-change-how-we-queue-blocks-for-backref-checkin incorrectly
  identified as broken, deleted.
- commit 2590ae4
* Wed Oct 30 2013 dsterba@suse.cz
- patches.kernel.org/revert-Btrfs-change-how-we-queue-blocks-for-backref-checkin.patch:
  Delete again, incorrectly identified as broken.
- commit 831e52b
* Wed Oct 30 2013 dsterba@suse.cz
- Revert Btrfs: change how we queue blocks for backref checking
- commit 89b9f62
* Wed Oct 30 2013 mmarek@suse.cz
- Revert kabi reference checksum for drivers/pci/pcie/aer (bnc#847721)
- commit 18739d7
* Wed Oct 30 2013 jkosina@suse.cz
- i2c: ismt: initialize DMA buffer (bnc#843753).
- commit c1bd8ee
* Tue Oct 29 2013 dsterba@suse.cz
- Delete
  patches.suse/btrfs-1231-don-t-stop-searching-after-encountering-the-wr.patch.
- Delete
  patches.suse/btrfs-8015-make-lzo-the-default-compression-scheme.patch.
- Delete
  patches.suse/btrfs-8016-skip-compression-of-very-small-extents.patch.
- Delete
  patches.suse/btrfs-8024-workaround-for-cleaner-deadlock.patch.
- Delete patches.suse/btrfs-8102-do-delay-iput-in-sync_fs.patch.
- Delete
  patches.suse/btrfs-8116-stop-waiting-on-current-trans-if-we-aborted.patch.
- Delete
  patches.suse/btrfs-8118-free-csums-when-we-re-done-scrubbing-an-extent.patch.
- Delete
  patches.suse/btrfs-8120-stop-using-try_to_writeback_inodes_sb_nr-to-fl.patch.
- Delete
  patches.suse/btrfs-8122-cleanup-orphaned-root-orphan-item.patch.
- Delete
  patches.suse/btrfs-8124-wait-ordered-range-before-doing-direct-io.patch.
- Delete
  patches.suse/btrfs-8188-merge-save_error_info-helpers-into-one.patch.
- Delete
  patches.suse/btrfs-8189-clean-up-transaction-abort-messages.patch.
- Delete patches.suse/btrfs-8190-clean-snapshots-one-by-one.patch.
- commit c5d0014
* Tue Oct 29 2013 mhocko@suse.cz
- patches.fixes/watchdog-update-watchdog_thresh-atomically.patch:
  Add upstream commit info
- commit 5efd135
* Tue Oct 29 2013 mhocko@suse.cz
- patches.fixes/printk-make-nmi-ringbuffer-length-independent.patch:
  Warning fix.
- commit 173e5d9
* Tue Oct 29 2013 jdelvare@suse.de
- iommu/vt-d: add quirk for broken interrupt remapping on 55XX
  chipsets (bnc#844513).
- x86/iommu/vt-d: Expand interrupt remapping quirk to cover x58
  chipset (bnc#844513).
- iommu/vt-d: Only warn about broken interrupt remapping
  (bnc#844513).
- iommu: Remove stack trace from broken irq remapping warning
  (bnc#844513).
- commit a8164e2
* Tue Oct 29 2013 jdelvare@suse.de
- patches.arch/iommu-vt-d-add-quirk-for-broken-interrupt.patch:
  iommu/vt-d: add quirk for broken interrupt remapping on 55XX
  chipsets (bnc#844513).
- patches.arch/iommu-vt-d-expand-interrupt-remapping-quirk.patch:
  x86/iommu/vt-d: Expand interrupt remapping quirk to cover x58
  chipset (bnc#844513).
- patches.arch/iommu-vt-d-only-warn-on-broken-irq-remapping.patch:
  iommu/vt-d: Only warn about broken interrupt remapping
  (bnc#844513).
- patches.arch/iommu-vt-d-remove-stack-trace-from-broken-irq-remapping-warning.patch:
  iommu: Remove stack trace from broken irq remapping warning
  (bnc#844513).
- commit f22f7f5
* Tue Oct 29 2013 mmarek@suse.cz
- kabi: Hide change in aer_recover_queue() from genksyms
  (bnc#847721).
- kabi/severities: Remove whitelist for aer_recover_queue()
- commit 43a0c2a
* Tue Oct 29 2013 jbeulich@suse.com
- Update EC2 config files (STRICT_DEVMEM off, bnc#843732).
- commit 762a3c8
* Mon Oct 28 2013 jbeulich@suse.com
- Refresh Xen patches (bnc#829682, bnc#842063).
- commit 05b1bdc
* Fri Oct 25 2013 dsterba@suse.cz
- Btrfs: fix negative qgroup tracking from owner accounting
  (bug #61951) (bnc#821948).
- commit 7b5ae67
* Fri Oct 25 2013 jkosina@suse.cz
- patches.fixes/lsm-do-not-print-error-when-disabled.patch:
  (bnc#842057).
- commit 23e0004
* Fri Oct 25 2013 jkosina@suse.cz
- Refresh patches.suse/revert-tytsos-random-changes: update context to apply
  after 3.0.101
- commit 1dfa803
* Fri Oct 25 2013 ddiss@suse.de
- patches.fixes/cifs-fill-TRANS2_QUERY_FILE_INFO-ByteCount-fields.patch:
  Fix TRANS2_QUERY_FILE_INFO ByteCount fields (bnc#804950).
- commit 27648c4
* Thu Oct 24 2013 duwe@suse.de
- powerpc/irq: Run softirqs off the top of the irq stack
  (bnc#847319).
- commit 64bce78
* Thu Oct 24 2013 jslaby@suse.cz
- Linux 3.0.101 (bnc#789115).
- patches.fixes/ipv6-tcp-fix-panic-in-SYN-processing.patch:
  Delete.
- commit 4b06a1e
* Wed Oct 23 2013 duwe@suse.de
- patches.drivers/mlx4_en-fix-blueflame-race: net/mlx4_en:
  Fix BlueFlame race (bnc#835684).
- commit f39728d
* Wed Oct 23 2013 duwe@suse.de
- net/mlx4_en: Fix BlueFlame race (bnc#835684).
- commit acd1d37
* Mon Oct 21 2013 lduncan@suse.com
- mvsas: add support for 9480 device id (bnc#843950).
- commit 43218ca
* Mon Oct 21 2013 jbeulich@suse.com
- Refresh Xen patches (bnc#829682, bnc#842063).
- commit efb764c
* Fri Oct 18 2013 jbohac@suse.cz
- patches.kabi/0001-Revert-tcp-RFC-5961-5.2-Blind-Data-Injection-Attack-.patch:
  Refresh.
- patches.kabi/0003-Revert-tcp-refine-SYN-handling-in-tcp_validate_incom.patch:
  Refresh.
- patches.kabi/0004-Revert-tcp-implement-RFC-5961-4.2.patch:
  Refresh.
- patches.kabi/0002-Revert-tcp-tcp_replace_ts_recent-should-not-be-calle.patch:
  Delete.
- patches.kabi/revert-tcp-call-tcp_replace_ts_recent-from-tcp_ack.patch:
  Delete.
  (bnc#845549)
- commit 7735e9d
* Fri Oct 18 2013 tiwai@suse.de
- drm/i915: Disable GGTT PTEs on GEN6+ suspend (bnc#800875).
- drm/i915/hsw: Disable L3 caching of atomic memory operations
  (bnc#800875).
- commit 5f86b83
* Fri Oct 18 2013 mkubecek@suse.cz
- patches.fixes/ipv6-don-t-call-fib6_run_gc-until-routing-is-ready.patch:
  ipv6: don't call fib6_run_gc() until routing is ready
  (bnc#836218).
- commit f7d642a
* Thu Oct 17 2013 tiwai@suse.de
- r8169: fix argument in rtl_hw_init_8168g
  (bnc#845352,bnc#842820).
- r8169: support RTL8168G (bnc#845352,bnc#842820).
- r8169: abstract out loop conditions (bnc#845352,bnc#842820).
- r8169: mdio_ops signature change (bnc#845352,bnc#842820).
- commit a778dc4
* Thu Oct 17 2013 mgorman@suse.de
- patches.fixes/mm-do-not-walk-all-of-system-ram-during-show_mem.patch:
  mm: Do not walk all of system memory during show_mem
  (Reduce tasklist_lock hold times (bnc#821259)).
- commit 70c2de1
* Wed Oct 16 2013 oneukum@suse.de
- quirks: add touchscreen that is dazzeled by remote wakeup
  (bnc#835930).
- commit 8ac3e27
* Wed Oct 16 2013 oneukum@suse.de
- patches.drivers/0001-quirks-add-touchscreen-that-is-dazzeled-by-remote-wa.patch:
  quirks: add touchscreen that is dazzeled by remote wakeup
  (bnc#835930).
- commit 833284e
* Tue Oct 15 2013 jjolly@suse.de
- Reverted previous commits (bnc#839973)
  - Update kabi files.
  - Delete patches.arch/s390-14-01-hvc-console-dtr-rts.patch.
  - Delete patches.arch/s390-14-02-hvc-iucv-lower-dtr.patch.
- commit e08464e
* Tue Oct 15 2013 jack@suse.cz
- patches.fixes/blktrace-Send-BLK_TN_PROCESS-events-to-all-running-t.patch:
  blktrace: Send BLK_TN_PROCESS events to all running traces
  (bnc#838623).
- commit f0933d7
* Tue Oct 15 2013 jjolly@suse.de
- patches.arch/s390-67-01-sclp-buffer.patch: kernel: sclp console
  hangs (bnc#841498, LTC#95711).
- commit f32f7ab
* Tue Oct 15 2013 oneukum@suse.de
- series.conf: disable XHCI ring expansion patches
  because on machines with large memory they cause a
  starvation problem - refresh so scripts don't
  complain (bnc#833635)
- commit 5e645fc
* Tue Oct 15 2013 jjolly@suse.de
- [BZ 97595] tty/hvc_iucv: Disconnect IUCV connection when
  lowering DTR (bnc#839973,LTC#97595).
- commit f744229
* Tue Oct 15 2013 jjolly@suse.de
- [BZ 97595] tty/hvc_console: Add DTR/RTS callback to handle
  HUPCL control (bnc#839973,LTC#97595).
- Update kabi files.
- commit db3fc4b
* Tue Oct 15 2013 neilb@suse.de
- patches.fixes/nfs_flush_incompatible.fix: NFS: make
  nfs_flush_incompatible more generous (bnc#816099).
- commit 86f58df
* Mon Oct 14 2013 jeffm@suse.com
- xfs: growfs: use uncached buffers for new headers (bnc#842604).
- commit a7b438d
* Mon Oct 14 2013 jeffm@suse.com
- patches.fixes/xfs-growfs-use-uncached-buffers-for-new-headers:
  xfs: growfs: use uncached buffers for new headers (bnc#842604).
- commit 68c9af0
* Mon Oct 14 2013 mgorman@suse.de
- patches.fixes/mm-memcg-introduce-own-oom-handler-to-iterate-only-o.patch:
- patches.fixes/mm-memcg-move-all-oom-handling-to-memcontrol.c.patch:
- patches.fixes/mm-oom-avoid-looping-when-chosen-thread-detaches-its.patch:
- patches.fixes/mm-oom-fold-oom_kill_task-into-oom_kill_process.patch:
- patches.fixes/mm-oom-introduce-helper-function-to-process-threads-.patch:
- patches.fixes/mm-oom-reduce-dependency-on-tasklist_lock.patch:
  Update references (Reduce tasklist_lock hold times (bnc#821259)).
- commit 05e456b
* Mon Oct 14 2013 jslaby@suse.cz
- Linux 3.0.100 (CVE-2013-1929 CVE-2013-2015 bnc#813733 bnc#817377
  bnc#841402).
- patches.drivers/cciss-update-to-4.6.28.patch: Refresh.
- patches.drivers/tg3-return-size-from-tg3_vpd_readblock: Refresh.
- patches.fixes/bonding-Convert-hw-addr-handling-to-sync-unsync-supp.patch:
  Refresh.
- patches.suse/msft-hv-0246-Staging-hv-netvsc-Fix-a-dereferencing-issue.patch:
  Refresh.
- patches.suse/msft-hv-0247-Staging-hv-move-hyperv-code-out-of-staging-directo.patch:
  Refresh.
- patches.fixes/ext4-avoid-hang-when-mounting-non-journal-filesystem.patch:
  Delete.
- patches.fixes/intel-iommu-fix-leaks-in-pagetable-freeing.patch:
  Delete.
- patches.fixes/tg3-fix-length-overflow-in-vpd-firmware-parsing:
  Delete.
- patches.suse/msft-hv-0360-Tools-hv-verify-origin-of-netlink-connector-message.patch:
  Delete.
- commit f4b3014
* Mon Oct 14 2013 jslaby@suse.cz
- Linux 3.0.99 (bnc#827246).
- patches.arch/x86-reboot-blacklist-dell-optiplex-990.patch:
  Refresh.
- patches.drivers/0001-xHCI-store-ring-s-type.patch: Refresh.
- patches.suse/tmpfs-clone-shmem_file_splice_read.patch: Refresh.
- patches.fixes/splice-fix-racy-pipe-buffers-uses.patch: Delete.
- commit 8273b1a
* Mon Oct 14 2013 oneukum@suse.de
- series.conf: disable XHCI ring expansion patches
  because on machines with large memory they cause a
  starvation problem (bnc#833635)
- commit 80e9014
* Mon Oct 14 2013 neilb@suse.de
- patches.fixes/nfs-state-fix: NFS: don't try to use lock state
  when we hold a delegation (bnc#831029).
- commit 272c4dd
* Mon Oct 14 2013 neilb@suse.de
- patches.fixes/nfs_lookup_revalidate-fix-a-leak.patch:
  nfs_lookup_revalidate(): fix a leak (bnc#828894).
- commit 93493e0
* Sun Oct 13 2013 neilb@suse.de
- patches.fixes/do_add_mount-umount-l-races.patch:
  do_add_mount()/umount -l races (bnc#836801).
- commit d5a34c1
* Fri Oct 11 2013 jkosina@suse.cz
- patches.fixes/mm-make-snapshotting-pages-for-stable-writes-a-per-bio-operation.patch:
  Refresh:
  add upstream reference
- commit e48f9c0
* Fri Oct 11 2013 jkosina@suse.cz
- Refresh
  patches.fixes/mm-make-snapshotting-pages-for-stable-writes-a-per-bio-operation.patch:
  add upstream reference
- commit 01066fb
* Thu Oct 10 2013 mgorman@suse.de
- thp: reduce khugepaged freezing latency
  (khugepaged blocking suspend-to-ram (bnc#825291)).
- commit 34e6b7f
* Wed Oct  9 2013 acho@suse.com
- Refresh patches.drivers/0008-mmc-bus-print-bus-speed-mode-of-UHS-I-card.patch
  patches.drivers/0008-mmc-bus-print-bus-speed-mode-of-UHS-I-card.patch
  in-place: Fix mismerge(bnc#840489)
- commit 88c012b
* Fri Oct  4 2013 bpoirier@suse.de
- patches.fixes/bnx2x-Change-to-D3hot-only-on-removal.patch:
  bnx2x: Change to D3hot only on removal (bnc#838448).
- commit c20f086
* Fri Oct  4 2013 bpoirier@suse.de
- bnx2x: Change to D3hot only on removal (bnc#838448).
- commit 5b4a19b
* Fri Oct  4 2013 mkubecek@suse.cz
- patches.kernel.org/patch-3.0.97-98: Update references
  (add bnc#842231).
- commit 99fc514
* Thu Oct  3 2013 jslaby@suse.cz
- patches.fixes/ext4-avoid-hang-when-mounting-non-journal-filesystem.patch:
  Update references (bnc#817377 CVE-2013-2015).
- commit 029da8f
* Wed Oct  2 2013 jslaby@suse.cz
- Linux 3.0.98 (bnc#841094).
- patches.fixes/perf-Optimize-event-scheduling-locking: Refresh.
- patches.kabi/kabi-protect-struct-perf_cpu_context.patch: kABI:
  protect struct perf_cpu_context.
- patches.fixes/SCSI-iscsi-don-t-hang-in-endless-loop-if-no-targets-.patch:
  Delete.
- commit ebdcbf1
* Wed Oct  2 2013 bp@suse.de
- patches.fixes/intel-iommu-fix-leaks-in-pagetable-freeing.patch:
  intel-iommu: Fix leaks in pagetable freeing (bnc#841402).
- commit 819ed13
* Wed Oct  2 2013 hare@suse.de
- megaraid_sas: Disable controller reset for ppc (bnc#841050).
- commit 8ed65f9
* Wed Oct  2 2013 hare@suse.de
- scsi_dh_alua: simplify alua_check_sense() (bnc#843642).
- scsi_dh_alua: Fix missing close brace in alua_check_sense
  (bnc#843642).
- scsi_dh_alua: retry command on 'mode parameter changed' sense
  code (bnc#843645).
- commit 6df5f63
* Tue Oct  1 2013 bp@suse.de
- intel-iommu: Fix leaks in pagetable freeing (bnc#841402).
- commit cd4f33f
* Tue Oct  1 2013 hare@suse.de
- scsi_dh_alua: invalid state information for 'optimized' paths
  (bnc#843445).
- scsi_dh_alua: reattaching device handler fails with 'Error 15'
  (bnc#843429).
- commit fde3ea7
* Mon Sep 30 2013 mfasheh@suse.de
- sctp: Implement quick failover draft from tsvwg (bnc#827670).
- commit 5841845
* Mon Sep 30 2013 ohering@suse.de
- patches.suse/msft-hv-0426-Drivers-hv-Support-handling-multiple-VMBUS-versions.patch:
  Drivers: hv: Support handling multiple VMBUS versions
  (fate#314665).
- patches.suse/msft-hv-0429-Drivers-hv-Save-and-export-negotiated-vmbus-version.patch:
  Drivers: hv: Save and export negotiated vmbus version
  (fate#314665).
- patches.suse/msft-hv-0432-Drivers-hv-Move-vmbus-version-definitions-to-hyperv..patch:
  Drivers: hv: Move vmbus version definitions to hyperv.h
  (fate#314665).
- patches.suse/suse-hv-HV_DRV_VERSION.patch: Refresh.
- commit 85cf0c2
* Mon Sep 30 2013 ohering@suse.de
- patches.suse/msft-hv-0530-Drivers-hv-util-Fix-a-bug-in-version-negotiation-cod.patch:
  Drivers: hv: util: Fix a bug in version negotiation code for
  util services (bnc#828714).
- patches.suse/msft-hv-0541-Drivers-hv-util-Correctly-support-ws2008R2-and-earli.patch:
  Drivers: hv: util: Correctly support ws2008R2 and earlier
  (bnc#838346).
- patches.suse/suse-hv-Drivers-hv-util-Fix-a-bug-in-version-negotiation-cod.patch:
  Delete.
- commit 7d878c8
* Mon Sep 30 2013 mmarek@suse.cz
- Always include the git commit in KOTD builds
  This allows us not to set it explicitly in builds submitted to the
  official distribution (bnc#821612, bnc#824171).
- commit b026b9a
* Mon Sep 30 2013 mkubecek@suse.cz
- patches.fixes/ipv6-prevent-fib6_run_gc-contention.patch: ipv6:
  prevent fib6_run_gc() contention (bnc#797526).
- patches.fixes/ipv6-update-ip6_rt_last_gc-every-time-GC-is-run.patch:
  ipv6: update ip6_rt_last_gc every time GC is run (bnc#797526).
- commit a5c7619
* Mon Sep 30 2013 mkubecek@suse.cz
- patches.fixes/softirq-reduce-latencies.patch: softirq: reduce
  latencies (bnc#797526).
- patches.fixes/Fix-lockup-related-to-stop_machine-being-stuck-in-__.patch:
  Fix lockup related to stop_machine being stuck in __do_softirq
  (bnc#797526).
- commit a424064
* Mon Sep 30 2013 mkubecek@suse.cz
- patches.fixes/netfilter-nf_conntrack-use-RCU-safe-kfree-for-conntr.patch:
  netfilter: nf_conntrack: use RCU safe kfree for conntrack
  extensions (bnc#827416 bko#60853 bugzilla.netfilter.org:714).
- commit 65f84c9
* Mon Sep 30 2013 jlee@suse.com
- X.509: Remove certificate date checks (bnc#841656).
- commit 7913792
* Sun Sep 29 2013 ohering@suse.de
- Drivers: hv: vmbus: Do not attempt to negoatiate a new version
  prematurely.
- Drivers: hv: util: Correctly support ws2008R2 and earlier
  (bnc#838346).
- Drivers: hv: vmbus: Terminate vmbus version negotiation
  on timeout.
- Delete obsolete
  patches.suse/suse-hv-Drivers-hv-util-Fix-a-bug-in-util-version-negotiatio.patch.
- commit 16f0bdb
* Fri Sep 27 2013 jeffm@suse.com
- Revert "blktrace: fix race with open trace files and directory removal"
  This reverts commit b3fcb3374bfb33cf94ce94586e9e074507a1e8b7.
  This added the patch a second time to series.conf.
- commit 95f4ad8
* Fri Sep 27 2013 mmarek@suse.cz
- Do not apply the same patch twice
- commit dec865a
* Fri Sep 27 2013 jeffm@suse.com
- patches.fixes/xfs-avoid-double-free-in-xfs_attr_node_addname:
  xfs: avoid double-free in xfs_attr_node_addname.
- patches.fixes/xfs-check-the-return-value-of-xfs_buf_get: xfs:
  Check the return value of xfs_buf_get() (bnc#842604).
- commit c566a7d
* Fri Sep 27 2013 jeffm@suse.com
- patches.fixes/xfs-avoid-double-free-in-xfs_attr_node_addname:
  xfs: avoid double-free in xfs_attr_node_addname.
- patches.fixes/xfs-check-the-return-value-of-xfs_buf_get: xfs:
  Check the return value of xfs_buf_get() (bnc#842604).
- commit 34deef6
* Fri Sep 27 2013 jeffm@suse.com
- xfs: avoid double-free in xfs_attr_node_addname.
- xfs: Check the return value of xfs_buf_get() (bnc#842604).
- commit 956cf9d
* Fri Sep 27 2013 ohering@suse.de
- tools: hv: Improve error logging in VSS daemon.
- tools: hv: Check return value of poll call.
- tools: hv: Check return value of setsockopt call.
- Drivers: hv: util: Fix a bug in version negotiation code for
  util services (bnc#828714).
- Drivers: hv: balloon: Initialize the transaction ID just before
  sending the packet.
- Drivers: hv: remove HV_DRV_VERSION.
- Tools: hv: fix send/recv buffer allocation.
- Tools: hv: check return value of daemon to fix compiler warning.
- Tools: hv: in kvp_set_ip_info free mac_addr right after usage.
- Tools: hv: check return value of system in hv_kvp_daemon.
- Tools: hv: correct payload size in netlink_send.
- Tools: hv: use full nlmsghdr in netlink_send.
- Drivers: hv: vmbus: Fix a bug in the handling of channel offers.
- Refresh patches.suse/suse-hv-HV_DRV_VERSION.patch.
- Refresh
  patches.suse/suse-hv-bind-hv_blkkvsc-to-hv_storvsc.patch.
- Refresh patches.suse/suse-hv-bind-hv_mouse-to-hid-hyperv.patch.
- Delete
  patches.suse/suse-hv-Drivers-hv-util-Fix-a-bug-in-version-negotiation-cod.patch.
- commit 4c97bee
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-flavors, rpm/mkspec: Add version information to obsolete
  flavors (bnc#821465).
- rpm/kernel-binary.spec.in: Move the xenpae obsolete to the
  old-flavors file.
- commit 4140735
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-flavors: Convert the old-packages.conf file to a flat
  list.
- rpm/mkspec: Adjust.
- rpm/old-packages.conf: Delete.
- commit b02d3ef
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-packages.conf: Drop bogus obsoletes for "smp"
  (bnc#821465).
- commit 36def54
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Make sure that all KMP obsoletes are
  versioned (bnc#821465).
- commit 0edb517
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove unversioned provides/obsoletes
  for packages that were only seen in openSUSE releases up to 11.0.
  (bnc#821465).
- commit 183d189
* Fri Sep 27 2013 jslaby@suse.cz
- Linux 3.0.97.
- commit 86d0baf
* Fri Sep 27 2013 jdelvare@suse.de
- config/*/debug: Enable FSCACHE_DEBUG and CACHEFILES_DEBUG
  (bnc#837372).
- commit 1ceef77
* Wed Sep 25 2013 jslaby@suse.cz
- patches.fixes/splice-fix-racy-pipe-buffers-uses.patch: splice:
  fix racy pipe->buffers uses (bnc#827246).
- commit 4f9def6
* Wed Sep 25 2013 jslaby@suse.cz
- patches.fixes/SCSI-iscsi-don-t-hang-in-endless-loop-if-no-targets-.patch:
  iscsi: don't hang in endless loop if no targets present
  (bnc#841094).
- commit 2ffc351
* Wed Sep 25 2013 dsterba@suse.cz
- Disable btrfs-8151-optimize-key-searches-in-btrfs_search_slot.patch
- commit fbfe780
* Wed Sep 25 2013 hare@suse.de
- scsi_dh_alua: Allow get_alua_data() to return NULL (bnc#839407).
- commit 96a852b
* Wed Sep 25 2013 jeffm@suse.com
- blktrace: fix race with open trace files and directory removal
  (bnc#832292).
- commit b3fcb33
* Wed Sep 25 2013 jeffm@suse.com
- patches.fixes/blktrace-fix-race-with-open-trace-files-and-directory-removal:
  blktrace: fix race with open trace files and directory removal
  (bnc#832292).
- commit 9e83ce8
* Tue Sep 24 2013 bpoirier@suse.de
- be2net: Check for POST state in suspend-resume sequence
  (bnc#835189).
- be2net: bug fix on returning an invalid nic descriptor
  (bnc#835189).
- be2net: provision VF resources before enabling SR-IOV
  (bnc#835189).
- be2net: Fix firmware download for Lancer (bnc#835189).
- be2net: Fix to use version 2 of cq_create for SkyHawk-R devices
  (bnc#835189).
- be2net: Use GET_FUNCTION_CONFIG V1 cmd (bnc#835189).
- be2net: Avoid flashing BE3 UFI on BE3-R chip (bnc#835189).
- be2net: Use TXQ_CREATE_V2 cmd (bnc#835189).
- commit eeb820a
* Tue Sep 24 2013 bpoirier@suse.de
- patches.fixes/net-remove-skb_orphan_try.patch: net: remove
  skb_orphan_try() (bnc#834600).
- commit bb4426f
* Mon Sep 23 2013 ddiss@suse.de
- cifs: revalidate directories instiantiated via FIND_* in order to handle DFS referrals (bnc#831143).
- cifs: don't instantiate new dentries in readdir for inodes that need to be revalidated immediately (bnc#831143).
- cifs: rename cifs_readdir_lookup to cifs_prime_dcache and make it void return (bnc#831143).
- cifs: get rid of blind d_drop() in readdir (bnc#831143).
- cifs: cleanup cifs_filldir (bnc#831143).
- commit 5813b3e
* Mon Sep 23 2013 jeffm@suse.com
- reiserfs: fix race with flush_used_journal_lists and
  flush_journal_list (bnc#837803).
- reiserfs: remove useless flush_old_journal_lists.
- commit 1d8555f
* Mon Sep 23 2013 jeffm@suse.com
- patches.fixes/reiserfs-fix-race-with-flush_used_journal_lists-and-flush_journal_list:
  reiserfs: fix race with flush_used_journal_lists and
  flush_journal_list (bnc#837803).
- patches.fixes/reiserfs-remove-useless-flush_old_journal_lists:
  reiserfs: remove useless flush_old_journal_lists.
- commit 5b15f1c
* Mon Sep 23 2013 jack@suse.cz
- Refresh
  patches.fixes/lib-radix-tree.c-make-radix_tree_node_alloc-work-cor.patch.
  Fixup an error during merge. shmem_add_to_page_cache() should use maybe
  variant.
- commit c20358b
* Mon Sep 23 2013 mmarek@suse.cz
- Import kabi files from 3.0.93-0.8.
- commit 1d8a50d
* Mon Sep 23 2013 mmarek@suse.cz
- Import kabi files from 3.0.93-0.5.
- commit fde4525
* Mon Sep 23 2013 mmarek@suse.cz
- Fix date format in kernel-source.changes
- commit 1066184
* Sat Sep 21 2013 jack@suse.cz
- patches.fixes/writeback-do-not-sync-data-dirtied-after-sync-start.patch:
  writeback: Do not sync data dirtied after sync start
  (bnc#833820).
- commit 7d9893d
* Fri Sep 20 2013 oneukum@suse.de
- patches.suse/0001-elousb-some-systems-cannot-stomach-work-around.patch:
  elousb: some systems cannot stomach work around (bnc#840830).
- commit 76a0bc0
* Fri Sep 20 2013 mgorman@suse.de
- bounce: allow use of bounce pool via config option (Bounce
  memory pool initialisation (bnc#836347)).
- block: initialize the bounce pool if high memory may be added later
  (Bounce memory pool initialisation (bnc#836347)).
- commit 626cbf8
* Thu Sep 19 2013 jmcdonough@suse.de
- Fix changes entry for bnc#810323.
- patches.fixes/cifs-fix-mkdir-rmdir-bug-for-the-non-posix-case.patch
  patches.fixes/cifs-use-sensible-file-nlink-values-if-unprovided.patch:
  cifs: Improve performance of browsing directories with several files (bnc#810323).
- patches.fixes/cifs-provide-sane-values-for-nlink-from-non-unix-servers.patch:
  cifs: Ensure cifs directories don't show up as files (bnc#826602).
- commit 4fcbdf9
* Wed Sep 18 2013 hare@suse.de
- bio-integrity: track owner of integrity payload (bnc#831380).
- commit a121375
* Wed Sep 18 2013 hare@suse.de
- patches.fixes/bio-integrity-track-owner.patch: bio-integrity:
  track owner of integrity payload (bnc#831380).
- commit 06d14e6
* Tue Sep 17 2013 mkubecek@suse.cz
- patches.fixes/bonding-check-bond-vlgrp-in-bond_vlan_rx_kill_vid.patch:
  bonding: check bond->vlgrp in bond_vlan_rx_kill_vid()
  (bnc#834905).
- commit 2213502
* Sun Sep 15 2013 jslaby@suse.cz
- Linux 3.0.96.
- commit 6bd9925
* Sun Sep 15 2013 jslaby@suse.cz
- Linux 3.0.95.
- patches.drivers/target-0006-target-Core-cleanups-from-AGrover-round-1.patch:
  Refresh.
- patches.drivers/target-0030-target-Make-all-control-CDBs-scatter-gather.patch:
  Refresh.
- patches.fixes/x86_acer_acpi_ec_call_reg_blacklist.patch:
  Refresh.
- commit 116278a
* Sun Sep 15 2013 jslaby@suse.cz
- Linux 3.0.94.
- commit 202a1fe
* Sun Sep 15 2013 mfasheh@suse.de
- dlm: remove get_comm (bnc#827670).
- commit a0d0b28
* Fri Sep 13 2013 mfasheh@suse.de
- dlm: Avoid LVB truncation (bnc#827670).
- dlm: disable nagle for SCTP (bnc#827670).
- dlm: retry failed SCTP sends (bnc#827670).
- dlm: try other IPs when sctp init assoc fails (bnc#827670).
- dlm: clear correct bit during sctp init failure handling
  (bnc#827670).
- dlm: set sctp assoc id during setup (bnc#827670).
- dlm: clear correct init bit during sctp setup (bnc#827670).
- dlm: fix deadlock between dlm_send and dlm_controld
  (bnc#827670).
- commit f1ef42d
* Fri Sep 13 2013 ddiss@suse.de
-  patches.fixes/cifs-cleanup-cifs_filldir.patch
  patches.fixes/cifs-don-t-instantiate-new-dentries-in-readdir-for-i.patch
  patches.fixes/cifs-get-rid-of-blind-d_drop-in-readdir.patch
  patches.fixes/cifs-rename-cifs_readdir_lookup-to-cifs_prime_dcache.patch
  patches.fixes/cifs-revalidate-directories-instiantiated-via-FIND_-in-or.patch
  cifs: Fix EREMOTE errors encountered on DFS links (bnc#831143).
- commit f319e08
* Fri Sep 13 2013 jbohac@suse.cz
- patches.fixes/sctp-deal-with-multiple-cookie_echo-chunks.patch:
  sctp: deal with multiple COOKIE_ECHO chunks (bnc#826102).
- patches.fixes/sctp-use-correct-sideffect-command-in-duplicate-cook.patch:
  sctp: Use correct sideffect command in duplicate cookie handling
  (bnc#826102, CVE-2013-2206).
- commit ccfb7a5
* Fri Sep 13 2013 dsterba@suse.cz
- Btrfs: add missing error checks to add_data_references
  (FATE#312888).
- Btrfs: change how we queue blocks for backref checking
  (FATE#312888).
- Btrfs: add missing error handling to read_tree_block
  (FATE#312888).
- Btrfs: handle errors when doing slow caching (FATE#312888).
- Btrfs: fix inode leak on kmalloc failure in tree-log.c
  (FATE#312888).
- Btrfs: don't ignore errors from btrfs_run_delayed_items
  (FATE#312888).
- Btrfs: fix oops when writing dirty qgroups to disk
  (FATE#312888).
- Btrfs: do not clear our orphan item runtime flag on eexist
  (FATE#312888).
- Btrfs: remove ourselves from the cluster list under lock
  (FATE#312888).
- Refresh
  patches.suse/btrfs-8144-return-ENOSPC-when-target-space-is-full.patch.
- Refresh
  patches.suse/btrfs-8149-fix-memory-leak-of-orphan-block-rsv.patch.
- commit 0a9e033
* Fri Sep 13 2013 dsterba@suse.cz
- Btrfs: remove unnecessary ->s_umount in cleaner_kthread()
  (FATE#312888).
- Btrfs: make the cleaner complete early when the fs is going
  to be umounted (FATE#312888).
- Btrfs: move the R/O check out of
  btrfs_clean_one_deleted_snapshot() (FATE#312888).
- Btrfs: make the snap/subv deletion end more early when the fs
  is R/O (FATE#312888).
- Refresh
  patches.suse/btrfs-8100-add-ioctl-to-wait-for-qgroup-rescan-completion.patch.
- Refresh
  patches.suse/btrfs-8109-fix-qgroup-rescan-resume-on-mount.patch.
- Refresh
  patches.suse/btrfs-8110-do-not-pin-while-under-spin-lock.patch.
- Refresh
  patches.suse/btrfs-8121-check-if-we-can-nocow-if-we-don-t-have-data-sp.patch.
- Refresh
  patches.suse/btrfs-8125-update-drop-progress-before-stopping-snapshot-.patch.
- Refresh
  patches.suse/btrfs-8143-don-t-bug_on-when-we-fail-when-cleaning-up-tra.patch.
- Refresh
  patches.suse/btrfs-8149-fix-memory-leak-of-orphan-block-rsv.patch.
- Delete
  patches.suse/btrfs-8077-stop-defrag-the-files-automatically-when-doin-.patch.
- commit 7fdf3ae
* Fri Sep 13 2013 mgorman@suse.de
- mm: vmscan: take page buffers dirty and locked state into account KABI fix
  (Limit reclaim in the preserve of IO (bnc#754690)).
- commit b6dad74
* Thu Sep 12 2013 jack@suse.cz
- patches.fixes/lib-radix-tree.c-make-radix_tree_node_alloc-work-cor.patch:
  lib/radix-tree.c: make radix_tree_node_alloc() work correctly
  within interrupt (bnc#763463).
- commit 1a070b3
* Thu Sep 12 2013 mkubecek@suse.cz
- patches.fixes/netfilter-prevent-race-condition-breaking-net-refere.patch:
  netfilter: prevent race condition breaking net reference
  counting (bnc#835094).
- commit 9b4050c
* Wed Sep 11 2013 neilb@suse.de
- patches.fixes/md-raid10-throttle: Throttle number of pending
  write requests in md/raid10 (bnc#833858).
- commit bf94211
* Wed Sep 11 2013 neilb@suse.de
- patches.fixes/dm-ignore-merge_bvec-for-snapshots-when-safe.patch:
  dm: ignore merge_bvec for snapshots when safe (bnc#820848).
- commit e121e4f
* Tue Sep 10 2013 dsterba@suse.cz
- Btrfs: optimize key searches in btrfs_search_slot (FATE#312888).
- Btrfs: fix printing of non NULL terminated string (FATE#312888).
- Btrfs: fix memory leak of orphan block rsv (FATE#312888).
- Btrfs: don't miss inode ref items in BTRFS_IOC_INO_LOOKUP
  (FATE#312888).
- Btrfs: add missing error code to BTRFS_IOC_INO_LOOKUP handler
  (FATE#312888).
- Btrfs: fix the error handling wrt orphan items (FATE#312888).
- Btrfs: don't allow a subvol to be deleted if it is the default
  subovl (FATE#312888).
- Btrfs: return ENOSPC when target space is full (FATE#312888).
- Btrfs: don't bug_on when we fail when cleaning up transactions
  (FATE#312888).
- Btrfs: add missing mounting options in btrfs_show_options()
  (FATE#312888).
- Btrfs: use u64 for subvolid when parsing mount options
  (FATE#312888).
- Btrfs: add sanity checks regarding to parsing mount options
  (FATE#312888).
- Btrfs: cleanup reloc roots properly on error (FATE#312888).
- Btrfs: reset ret in record_one_backref (FATE#312888).
- btrfs: fix get set label blocking against balance (FATE#312888).
- btrfs: fall back to global reservation when removing subvolumes
  (FATE#312888).
- Btrfs: Release uuid_mutex for shrink during device delete
  (FATE#312888).
- commit aaae418
* Tue Sep 10 2013 mhocko@suse.cz
- patches.fixes/rcu-reduce-false-positive-on-racing-rcu.patch:
  rcu: Do not trigger false positive RCU stall detection
  (bnc#834204).
- commit 98873d8
* Tue Sep 10 2013 mszeredi@suse.cz
- cifs: on send failure, readjust server sequence number downward
  (bnc#827966).
- cifs: adjust sequence number downward after signing NT_CANCEL
  request (bnc#827966).
- cifs: on send failure, readjust server sequence number downward
  (bnc#827966).
- cifs: adjust sequence number downward after signing NT_CANCEL
  request (bnc#827966).
- commit 541c00c
* Tue Sep 10 2013 tiwai@suse.de
- xhci: Fix spurious wakeups after S5 on Haswell (bnc#833097).
- commit 8168c7d
* Tue Sep 10 2013 jjolly@suse.de
- [BZ 97332] kernel: allow program interruption filtering in
  user space (bnc#837596, LTC#97332).
- commit d21f1b7
* Mon Sep  9 2013 oneukum@suse.de
- elousb: some systems cannot stomach work around (bnc#830985).
- commit f6dfca5
* Mon Sep  9 2013 dsterba@suse.cz
- btrfs update
  fixups from 3.11
- Btrfs: add ioctl to wait for qgroup rescan completion
  (FATE#312888).
- Btrfs: remove useless copy in quota_ctl (FATE#312888).
- Btrfs: do delay iput in sync_fs (FATE#312888).
- Btrfs: fix estale with btrfs send (FATE#312888).
- Btrfs: return error code in btrfs_check_trunc_cache_free_space()
  (FATE#312888).
- Btrfs: dont do log_removal in insert_new_root (FATE#312888).
- Btrfs: check if leaf's parent exists before pushing items around
  (FATE#312888).
- Btrfs: allow file data clone within a file (FATE#312888).
- Btrfs: simplify unlink reservations (FATE#312888).
- Btrfs: fix qgroup rescan resume on mount (FATE#312888).
- Btrfs: do not pin while under spin lock (FATE#312888).
- Btrfs: add some missing iput()'s in btrfs_orphan_cleanup
  (FATE#312888).
- Btrfs: put our inode if orphan cleanup fails (FATE#312888).
- Btrfs: exclude logged extents before replying when we are mixed
  (FATE#312888).
- Btrfs: fix broken nocow after balance (FATE#312888).
- Btrfs: wake up delayed ref flushing waiters on abort
  (FATE#312888).
- Btrfs: stop waiting on current trans if we aborted
  (FATE#312888).
- Btrfs: fix transaction throttling for delayed refs
  (FATE#312888).
- Btrfs: free csums when we're done scrubbing an extent
  (FATE#312888).
- Btrfs: unlock extent range on enospc in compressed submit
  (FATE#312888).
- Btrfs: stop using try_to_writeback_inodes_sb_nr to flush
  delalloc (FATE#312888).
- Btrfs: check if we can nocow if we don't have data space
  (FATE#312888).
- Btrfs: cleanup orphaned root orphan item (FATE#312888).
- Btrfs: hold the tree mod lock in __tree_mod_log_rewind
  (FATE#312888).
- Btrfs: only do the tree_mod_log_free_eb if this is our last ref
  (FATE#312888).
- Btrfs: wait ordered range before doing direct io (FATE#312888).
- Btrfs: update drop progress before stopping snapshot dropping
  (FATE#312888).
- Btrfs: fix lock leak when resuming snapshot deletion
  (FATE#312888).
- Btrfs: re-add root to dead root list if we stop dropping it
  (FATE#312888).
- btrfs: fix file truncation if FALLOC_FL_KEEP_SIZE is specified
  (FATE#312888).
- Btrfs: fix a bug of snapshot-aware defrag to make it work on
  partial extents (FATE#312888).
- Btrfs: fix extent buffer leak after backref walking
  (FATE#312888).
- Btrfs: do not offset physical if we're compressed (FATE#312888).
- Btrfs: fix backref walking when we hit a compressed extent
  (FATE#312888).
- Btrfs: make sure the backref walker catches all refs to our
  extent (FATE#312888).
- Btrfs: release both paths before logging dir/changed extents
  (FATE#312888).
- btrfs: add btrfs_fs_incompat helper (FATE#312888).
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- Refresh patches.suse/btrfs-update-message-levels.patch.
- Delete
  patches.suse/btrfs-8235-simplify-unlink-reservations.patch.
- commit 12c5701
* Thu Sep  5 2013 jjolly@suse.de
- s390/cio: handle unknown pgroup state (bnc#837741,LTC#97048).
- commit 0b4f4ae
* Thu Sep  5 2013 jjolly@suse.de
- s390/cio: export vpm via sysfs (bnc#837741,LTC#97048).
- commit c019074
* Thu Sep  5 2013 jjolly@suse.de
- s390/cio: skip broken paths (bnc#837741,LTC#97048).
- commit 43598d3
* Thu Sep  5 2013 jjolly@suse.de
- s390/cio: dont abort verification after missing irq
  (bnc#837741,LTC#97048).
- commit c024bc1
* Thu Sep  5 2013 jjolly@suse.de
- cio: add message for timeouts on internal I/O (bnc#837741,LTC#97048).
- commit cb233b1
* Thu Sep  5 2013 lduncan@suse.com
- patches.drivers/libata-set-proper-sk-when-ck_cond-is-set.patch:
  Set proper SK when CK_COND is set (bnc#833588).
- commit de9fdce
* Thu Sep  5 2013 lduncan@suse.com
- Set proper Sense Key for Check Condition (bnc#833588).
- commit 17c9be8
* Thu Sep  5 2013 ohering@suse.de
- patches.suse/suse-hv-Drivers-hv-util-Fix-a-bug-in-util-version-negotiatio.patch:
  Drivers: hv: util: Fix a bug in util version negotiation code
  (bnc#838346).
- commit f6b62c0
* Thu Sep  5 2013 ohering@suse.de
- Drivers: hv: util: Fix a bug in util version negotiation code
  (bnc#838346).
- commit a507da4
* Wed Sep  4 2013 dsterba@suse.cz
- btrfs update
- btrfs: merge save_error_info helpers into one (FATE#312888).
- btrfs: clean up transaction abort messages (FATE#312888).
- Btrfs: cleanup unused arguments of btrfs_csum_data
  (FATE#312888).
- Btrfs: use helper to cleanup tree roots (FATE#312888).
- Btrfs: share stop worker code (FATE#312888).
- btrfs: Cleanup some redundant codes in
  btrfs_lookup_csums_range() (FATE#312888).
- btrfs: clean snapshots one by one (FATE#312888).
- btrfs: deprecate subvolrootid mount option (FATE#312888).
- btrfs: make orphan cleanup less verbose.
- btrfs: cover more error codes in btrfs_decode_error
  (FATE#312888).
- btrfs: make subvol creation/deletion killable in the early
  stages (FATE#312888).
- Btrfs: fix a warning when disabling quota (FATE#312888).
- Btrfs: fix infinite loop when we abort on mount (FATE#312888).
- Btrfs: compare relevant parts of delayed tree refs
  (FATE#312888).
- Btrfs: kill some BUG_ONs() in the find_parent_nodes()
  (FATE#312888).
- Btrfs: fix double free in the iterate_extent_inodes()
  (FATE#312888).
- Btrfs: fix error handling in make/read block group
  (FATE#312888).
- Btrfs: don't wait on ordered extents if we have a trans open
  (FATE#312888).
- Btrfs: log ram bytes properly (FATE#312888).
- Btrfs: fix bad extent logging (FATE#312888).
- Btrfs: improve the performance of the csums lookup
  (FATE#312888).
- btrfs: ignore device open failures in __btrfs_open_devices
  (FATE#312888).
- btrfs: abort unlink trans in missed error case (FATE#312888).
- Btrfs: creating the subvolume qgroup automatically when enabling
  quota (FATE#312888).
- Btrfs: introduce a mutex lock for btrfs quota operations
  (FATE#312888).
- Btrfs: remove some unnecessary spin_lock usages (FATE#312888).
- Btrfs: fix missing check before creating a qgroup relation
  (FATE#312888).
- Btrfs: fix missing check in the btrfs_qgroup_inherit()
  (FATE#312888).
- Btrfs: fix a warning when updating qgroup limit (FATE#312888).
- Btrfs: use tree_root to avoid edquot when disabling quota
  (FATE#312888).
- Btrfs: remove some BUG_ONs() when walking backref tree
  (FATE#312888).
- Btrfs: make __merge_refs() return type be void (FATE#312888).
- Btrfs: add a rb_tree to improve performance of ulist search
  (FATE#312888).
- Btrfs: fix unblocked autodefraggers when remount (FATE#312888).
- Btrfs: fix tree mod log regression on root split operations
  (FATE#312888).
- Btrfs: fix accessing the root pointer in tree mod log functions
  (FATE#312888).
- Btrfs: fix unlock after free on rewinded tree blocks
  (FATE#312888).
- Btrfs: do not continue if out of memory happens (FATE#312888).
- Btrfs: fix confusing edquot happening case (FATE#312888).
- Btrfs: remove unused argument of fixup_low_keys() (FATE#312888).
- Btrfs: fix reada debug code compilation (FATE#312888).
- Btrfs: return error when we specify wrong start to defrag
  (FATE#312888).
- Btrfs: don't force pages under writeback to finish when aborting
  (FATE#312888).
- Btrfs: clear received_uuid field for new writable snapshots
  (FATE#312888).
- Btrfs: fix missing check about ulist_add() in qgroup.c
  (FATE#312888).
- Btrfs: add all ioctl checks before user change for quota
  operations (FATE#312888).
- Btrfs: fix lockdep warning (FATE#312888).
- Btrfs: fix possible infinite loop in slow caching (FATE#312888).
- Btrfs: use REQ_META for all metadata IO (FATE#312888).
- Btrfs: deal with bad mappings in btrfs_map_block (FATE#312888).
- Btrfs: don't call readahead hook until we have read the entire
  eb (FATE#312888).
- Btrfs: don't BUG_ON() in btrfs_num_copies (FATE#312888).
- Btrfs: don't try and free ebs twice in log replay (FATE#312888).
- Btrfs: add tree block level sanity check (FATE#312888).
- Btrfs: only exclude supers in the range of our block group
  (FATE#312888).
- Btrfs: fix all callers of read_tree_block (FATE#312888).
- Btrfs: fix extent logging with O_DIRECT into prealloc
  (FATE#312888).
- Btrfs: cleanup fs roots if we fail to mount (FATE#312888).
- Btrfs: don't panic if we're trying to drop too many refs
  (FATE#312888).
- Btrfs: check return value of commit when recovering log
  (FATE#312888).
- Btrfs: cleanup destroy_marked_extents (FATE#312888).
- Btrfs: various abort cleanups (FATE#312888).
- Btrfs: fix error handling in btrfs_ioctl_send() (FATE#312888).
- Btrfs: set UUID in root_item for created trees (FATE#312888).
- Btrfs: return free space in cow error path (FATE#312888).
- Btrfs: separate sequence numbers for delayed ref tracking and
  tree mod log (FATE#312888).
- Btrfs: allocate new chunks if the space is not enough for
  global rsv (FATE#312888).
- Btrfs: split btrfs_qgroup_account_ref into four functions
  (FATE#312751).
- Btrfs: rescan for qgroups (FATE#312751).
- Btrfs: automatic rescan after "quota enable" command
  (FATE#312751).
- Btrfs: deal with free space cache errors while replaying log
  (FATE#312888).
- Btrfs: remove almost all of the BUG()'s from tree-log.c
  (FATE#312888).
- Btrfs: deal with errors in write_dev_supers (FATE#312888).
- btrfs: make static code static & remove dead code (FATE#312888).
- btrfs: handle errors returned from get_tree_block_key
  (FATE#312888).
- btrfs: remove unused gfp mask parameter from
  release_extent_buffer callchain (FATE#312888).
- btrfs: read entire device info under lock (FATE#312888).
- Btrfs: improve the loop of scrub_stripe (FATE#312888).
- btrfs: use unsigned long type for extent state bits
  (FATE#312888).
- btrfs: enhance superblock checks (FATE#312888).
- Btrfs: allow superblock mismatch from older mkfs (FATE#312888).
- btrfs: annotate quota tree for lockdep (FATE#312888).
- Btrfs: fix off-by-one in fiemap (FATE#312888).
- btrfs: don't stop searching after encountering the wrong item
  (FATE#312888).
- Btrfs: don't null pointer deref on abort (FATE#312888).
- Btrfs: remove warn on in free space cache writeout
  (FATE#312888).
- Btrfs: fix possible memory leak in the find_parent_nodes()
  (FATE#312888).
- Btrfs: fix possible memory leak in replace_path() (FATE#312888).
- Btrfs: don't abort the current transaction if there is no
  enough space for inode cache (FATE#312888).
- Btrfs: don't use global block reservation for inode cache
  truncation (FATE#312888).
- Btrfs: optimize the error handle of use_block_rsv()
  (FATE#312888).
- Btrfs: don't steal the reserved space from the global reserve
  if their space type is different (FATE#312888).
- Btrfs: update the global reserve if it is empty (FATE#312888).
- Btrfs: return errno if possible when we fail to allocate memory
  (FATE#312888).
- Btrfs: fix accessing a freed tree root (FATE#312888).
- Btrfs: fix unprotected root node of the subvolume's inode
  rb-tree (FATE#312888).
- Btrfs: pause the space balance when remounting to R/O
  (FATE#312888).
- Btrfs: remove BUG_ON() in btrfs_read_fs_tree_no_radix()
  (FATE#312888).
- Btrfs: don't invoke btrfs_invalidate_inodes() in the spin lock
  context (FATE#312888).
- btrfs: do away with non-whole_page extent I/O (FATE#312888).
- Btrfs: explicitly use global_block_rsv for quota_tree
  (FATE#312888).
- Btrfs: make sure roots are assigned before freeing their nodes
  (FATE#312888).
- Btrfs: don't delete fs_roots until after we cleanup the
  transaction (FATE#312888).
- btrfs: Drop inode if inode root is NULL (FATE#312888).
- Btrfs: init relocate extent_io_tree with a mapping
  (FATE#312888).
- Btrfs: fix use-after-free bug during umount (FATE#312888).
- Btrfs: stop all workers before cleaning up roots (FATE#312888).
- btrfs: add log message stubs (FATE#312888).
- Refresh
  patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch.
- Refresh
  patches.suse/btrfs-8018-use-irqsave-spinlocks-everywhere.patch.
- Refresh
  patches.suse/btrfs-8077-stop-defrag-the-files-automatically-when-doin-.patch.
- Refresh
  patches.suse/btrfs-8235-simplify-unlink-reservations.patch.
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- Refresh patches.suse/btrfs-update-message-levels.patch.
- Delete
  patches.suse/btrfs-8061-handle-errors-from-read_tree_block.patch.
- Delete
  patches.suse/btrfs-8062-push-up-errors-in-btrfs-num-copies.patch.
- Delete patches.suse/btrfs-8187-enhance-superblock-checks.patch.
- Delete
  patches.suse/btrfs-8191-make-orphan-cleanup-less-verbose.patch.
- Delete
  patches.suse/btrfs-8192-cover-more-error-codes-in-btrfs_decode_error.patch.
- Delete
  patches.suse/btrfs-8193-creating-the-subvolume-qgroup-automatically-wh.patch.
- Delete
  patches.suse/btrfs-8194-make-subvol-creation-deletion-killable-in-the-.patch.
- Delete
  patches.suse/btrfs-8195-fix-infinite-loop-when-we-abort-on-mount.patch.
- Delete
  patches.suse/btrfs-8196-compare-relevant-parts-of-delayed-tree-refs.patch.
- Delete
  patches.suse/btrfs-8197-kill-some-BUG_ONs-in-the-find_parent_nodes.patch.
- Delete
  patches.suse/btrfs-8198-fix-double-free-in-the-iterate_extent_inodes.patch.
- Delete
  patches.suse/btrfs-8199-fix-error-handling-in-make-read-block-group.patch.
- Delete
  patches.suse/btrfs-8200-don-t-wait-on-ordered-extents-if-we-have-a-tra.patch.
- Delete patches.suse/btrfs-8201-log-ram-bytes-properly.patch.
- Delete patches.suse/btrfs-8202-fix-bad-extent-logging.patch.
- Delete
  patches.suse/btrfs-8203-ignore-device-open-failures-in-__btrfs_open_de.patch.
- Delete
  patches.suse/btrfs-8204-abort-unlink-trans-in-missed-error-case.patch.
- Delete
  patches.suse/btrfs-8206-use-tree_root-to-avoid-edquot-when-disabling-q.patch.
- Delete
  patches.suse/btrfs-8207-remove-some-BUG_ONs-when-walking-backref-tree.patch.
- Delete
  patches.suse/btrfs-8208-fix-tree-mod-log-regression-on-root-split-oper.patch.
- Delete
  patches.suse/btrfs-8209-fix-accessing-the-root-pointer-in-tree-mod-log.patch.
- Delete
  patches.suse/btrfs-8210-fix-unlock-after-free-on-rewinded-tree-blocks.patch.
- Delete
  patches.suse/btrfs-8211-do-not-continue-if-out-of-memory-happens.patch.
- Delete
  patches.suse/btrfs-8212-fix-confusing-edquot-happening-case.patch.
- Delete
  patches.suse/btrfs-8213-fix-reada-debug-code-compilation.patch.
- Delete
  patches.suse/btrfs-8214-return-error-when-we-specify-wrong-start-to-de.patch.
- Delete
  patches.suse/btrfs-8215-don-t-force-pages-under-writeback-to-finish-wh.patch.
- Delete
  patches.suse/btrfs-8216-clear-received_uuid-field-for-new-writable-sna.patch.
- Delete
  patches.suse/btrfs-8217-cleanup-fs-roots-if-we-fail-to-mount.patch.
- Delete
  patches.suse/btrfs-8218-check-return-value-of-commit-when-recovering-l.patch.
- Delete patches.suse/btrfs-8219-various-abort-cleanups.patch.
- Delete
  patches.suse/btrfs-8220-deal-with-free-space-cache-errors-while-replay.patch.
- Delete
  patches.suse/btrfs-8221-remove-almost-all-of-the-BUG-s-from-tree-log.c.patch.
- commit 17e06f9
* Wed Sep  4 2013 mkubecek@suse.cz
- mlx4: allow IB_QP_CREATE_USE_GFP_NOFS in mlx4_ib_create_qp()
  (bnc#822433).
- commit 0c06426
* Tue Sep  3 2013 tiwai@suse.de
- Refresh patches.drivers/alsa-sp3-0012-Re-setup-HDMI-pin-and-audio-infoframe-on-st.
  Yet another fix for ELD-resetup patch.  For unstable connectcions, ELD
  might be repolled and the re-setup won't work as is.  Now fixed by
  moving the resetup code into hdmi_present_sense().
- commit 36b0e19
* Mon Sep  2 2013 tiwai@suse.de
- drm/i915: disable sound first on intel_disable_ddi (bnc#833151).
- commit cb10122
* Mon Sep  2 2013 tiwai@suse.de
- Refresh
  patches.drivers/alsa-sp3-0012-Re-setup-HDMI-pin-and-audio-infoframe-on-st.
  Fix S3/S4 resume issue.
- commit 211ac5b
* Mon Sep  2 2013 tiwai@suse.de
- ALSA: hda - Re-setup HDMI pin and audio infoframe on stream
  switches (bnc#833151).
- drm/i915: HDMI/DP - ELD info refresh support for Haswell
  (bnc#833151).
- commit e265b03
* Mon Sep  2 2013 msrb@suse.cz
- drm/cirrus: This is a cirrus version of Egbert Eich's patch for mgag200 (bnc#808079).
- commit 7af28f4
* Fri Aug 30 2013 bpoirier@suse.de
- patches.fixes/vmxnet3-prevent-div-by-zero-panic-when-ring-resizing.patch:
  vmxnet3: prevent div-by-zero panic when ring resizing
  uninitialized dev (bnc#833321).
- commit b817878
* Fri Aug 30 2013 bpoirier@suse.de
- vmxnet3: prevent div-by-zero panic when ring resizing
  uninitialized dev (bnc#833321).
- commit 3df3793
* Fri Aug 30 2013 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit d3fbefc
* Thu Aug 29 2013 mhocko@suse.cz
- patches.fixes/mm-memcg-introduce-own-oom-handler-to-iterate-only-o.patch:
  mm, memcg: introduce own oom handler to iterate only over its own threads.
- patches.fixes/mm-memcg-move-all-oom-handling-to-memcontrol.c.patch:
  mm, memcg: move all oom handling to memcontrol.c.
- patches.fixes/mm-oom-avoid-looping-when-chosen-thread-detaches-its.patch:
  mm, oom: avoid looping when chosen thread detaches its mm.
- patches.fixes/mm-oom-fold-oom_kill_task-into-oom_kill_process.patch:
  mm, oom: fold oom_kill_task() into oom_kill_process().
- patches.fixes/mm-oom-introduce-helper-function-to-process-threads-.patch:
  mm, oom: introduce helper function to process threads during scan.
- patches.fixes/mm-oom-reduce-dependency-on-tasklist_lock.patch:
  mm, oom: reduce dependency on tasklist_lock.
  (Reduce tasklist_lock hold times (bnc#821259)
- commit e7a4f9b
* Fri Aug 23 2013 trenn@suse.de
- ACPI / APEI: Force fatal AER severity when component has been
  reset (bnc#828886 bnc#824568).
- PCI/AER: Move AER severity defines to aer.h (bnc#828886
  bnc#824568).
- PCI/AER: Set dev->__aer_firmware_first only for matching devices
  (bnc#828886 bnc#824568).
- PCI/AER: Factor out HEST device type matching (bnc#828886
  bnc#824568).
- PCI/AER: Don't parse HEST table for non-PCIe devices (bnc#828886
  bnc#824568).
- PCI/AER: Reset link for devices below Root Port or Downstream
  Port (bnc#828886 bnc#824568).
- commit 00d457f
* Thu Aug 22 2013 jjolly@suse.de
- zfcp: fix lock imbalance by reworking request queue locking
  (bnc#835175, LTC#96825).
- commit d3ec1b5
* Thu Aug 22 2013 jjolly@suse.de
- qeth: Fix crash on initial MTU size change (bnc#835175,
  LTC#96809).
- commit b47ea1b
* Thu Aug 22 2013 jjolly@suse.de
- qeth: change default standard blkt settings for OSA Express
  (bnc#835175, LTC#96808).
- commit 5b85409
* Wed Aug 21 2013 jslaby@suse.cz
- Linux 3.0.92 (CVE-2013-2237 bnc#828119).
- Linux 3.0.93.
- patches.suse/0001-elousb-really-long-delays-for-broken-devices.patch:
  Refresh.
- patches.fixes/af_key-initialize-satype-in-key_notify_policy_flush:
  Delete.
- patches.fixes/futex-Take-hugepages-into-account-when-generating-futex_key.patch:
  Delete.
- commit 80500b7
* Wed Aug 21 2013 jslaby@suse.cz
- Linux 3.0.91 (bnc#773006).
- patches.fixes/silence-weird-name-warning: Delete.
- patches.kabi/kabi-protect-struct-trace_iterator.patch: kABI:
  protect struct trace_iterator.
- commit b08882d
* Wed Aug 21 2013 jslaby@suse.cz
- Linux 3.0.90 (CVE-2013-2148 bnc#823517).
- patches.fixes/fanotify-info-leak-in-copy_event_to_user.patch:
  Delete.
- commit 493f02e
* Wed Aug 21 2013 jslaby@suse.cz
- Linux 3.0.89.
- patches.drivers/USB3-0098-xhci-Redundant-check-in-xhci_check_args-for-xhci-devs.patch:
  Refresh.
- commit 55e1fe7
* Wed Aug 21 2013 jslaby@suse.cz
- Linux 3.0.88 (CVE-2013-2232 CVE-2013-2234 CVE-2013-4162 bnc#789010
  bnc#827749 bnc#827750 bnc#831058 LTC#86283).
- patches.fixes/af_key-initialize-satype-in-key_notify_policy_flush:
  Refresh.
- patches.fixes/writeback-split-inode_wb_list_lock-into-bdi_writebac.patch:
  Refresh.
- patches.kabi/revert-net-fix-NULL-dereferences-in-check_peer_redir.patch:
  Refresh.
- patches.arch/s390-61-01-zfcp-revert-xconf-handling.patch:
  Delete.
- patches.fixes/af_key-fix-info-leaks-in-notify-messages: Delete.
- patches.fixes/ipv6-call-udp_push_pending_frames-when-uncorking.patch:
  Delete.
- patches.fixes/ipv6-ip6_sk_dst_check-must-not-assume-ipv6-dst.patch:
  Delete.
- commit 1c0049c
* Tue Aug 20 2013 mhocko@suse.cz
- patches.fixes/x86-Add-workaround-to-NMI-iret-woes.patch: x86:
  Add workaround to NMI iret woes (bnc#831949).
- patches.fixes/x86-Do-not-schedule-while-still-in-NMI-context.patch:
  x86: Do not schedule while still in NMI context (bnc#831949).
- commit 4f6cb7d
* Mon Aug 19 2013 tiwai@suse.de
- drm/i915: no longer call drm_helper_resume_force_mode
  (bnc#831424,bnc#800875).
- commit 3f4c8bb
* Sat Aug 17 2013 bpoirier@suse.de
- bnx2x: protect different statistics flows (bnc#814336).
- commit 672a1e4
* Sat Aug 17 2013 bpoirier@suse.de
- patches.fixes/bnx2x-Avoid-sending-multiple-statistics-queries.patch:
  bnx2x: Avoid sending multiple statistics queries (bnc#814336).
- patches.fixes/bnx2x-protect-different-statistics-flows.patch:
  bnx2x: protect different statistics flows (bnc#814336).
- commit 604e41a
* Thu Aug 15 2013 tiwai@suse.de
- ALSA: hda - Fix unbalanced runtime pm refount (bnc#834742).
- commit 934198f
* Wed Aug 14 2013 mgorman@suse.de
- patches.fixes/reiserfs-delay-reiserfs-lock-until-journal-initialization:
- patches.fixes/reiserfs-don-t-lock-journal_init: Refresh.
  Refresh for series2git.
- commit 898029b
* Wed Aug 14 2013 mgorman@suse.de
- patches.fixes/reiserfs-delay-reiserfs-lock-until-journal-initialization.
- patches.fixes/reiserfs-don-t-lock-journal_init.
  Refresh for series2git
- commit 0e92c5c
* Wed Aug 14 2013 oneukum@suse.de
- Refresh
  patches.suse/0001-xhci-directly-calling-_PS3-on-suspend.patch.
  Make it build on all architectures
- commit a8993ca
* Wed Aug 14 2013 oneukum@suse.de
- Refresh
  patches.suse/0001-xhci-directly-calling-_PS3-on-suspend.patch.
  Make it compile without CONFIG_ACPI
- commit 88eeb95
* Wed Aug 14 2013 oneukum@suse.de
- xhci: directly calling _PS3 on suspend (bnc#833148).
- commit 5438ebd
* Wed Aug 14 2013 mgalbraith@suse.de
- Add futex fix that didn't go into 3.0-stable
- patches.fixes/futex-Take-hugepages-into-account-when-generating-futex_key.patch:
  futex: Take hugepages into account when generating futex_key.
- commit 3f87674
* Tue Aug 13 2013 bpoirier@suse.de
- e1000e: workaround DMA unit hang on I218 (bnc#834647).
- e1000e: unexpected "Reset adapter" message when cable pulled
  (bnc#834647).
- e1000e: 82577: workaround for link drop issue (bnc#834647).
- e1000e: helper functions for accessing EMI registers
  (bnc#834647).
- e1000e: workaround DMA unit hang on I218 (bnc#834647).
- e1000e: unexpected "Reset adapter" message when cable pulled
  (bnc#834647).
- e1000e: 82577: workaround for link drop issue (bnc#834647).
- e1000e: helper functions for accessing EMI registers
  (bnc#834647).
- commit 5f40ffe
* Tue Aug 13 2013 ohering@suse.de
- patches.suse/suse-hv-Drivers-hv-util-Fix-a-bug-in-version-negotiation-cod.patch:
  Drivers: hv: util: Fix a bug in version negotiation code for
  util services (bnc#828714).
- commit 6b5b374
* Tue Aug 13 2013 ohering@suse.de
- kabi/severities: Ignore changes in drivers/hv
- commit 415eb0a
* Tue Aug 13 2013 mhocko@suse.cz
- patches.fixes/printk-add-nmi-ring-buffer.patch: printk: Add
  NMI ringbuffer (bnc#831949).
- patches.fixes/printk-extract-ringbuffer-handling.patch: printk:
  extract ringbuffer handling from vprintk (bnc#831949).
- patches.fixes/printk-safe-nmi-handling.patch: printk: NMI safe
  printk (bnc#831949).
- patches.fixes/printk-fix-softlockups-during-heavy-printing.patch:
  Refresh.
- patches.fixes/printk-make-nmi-ringbuffer-length-independent.patch:
  printk: Make NMI ringbuffer size independent on log_buf_len
  (bnc#831949).
- patches.fixes/printk-do-not-call-unlock_console-from-nmi.patch:
  printk: Do not call console_unlock from nmi context
  (bnc#831949).
- patches.fixes/printk-do-not-use-printk_cpu-from-finish_printk.patch:
  printk: Do not use printk_cpu from finish_printk (bnc#831949).
- commit e53dd41
* Fri Aug  9 2013 jjolly@suse.de
- zfcp: fix schedule-inside-lock in scsi_device list loops
  (bnc#833073, LTC#94937).
- commit d413cc1
* Fri Aug  9 2013 oneukum@suse.de
- uvc: increase number of buffers (bnc#822164, bnc#805804).
- commit f276f3f
* Fri Aug  9 2013 tiwai@suse.de
- drm/i915: Adding more reserved PCI IDs for Haswell (bnc#834116).
- commit 544585e
* Fri Aug  9 2013 jbeulich@suse.com
- patches.xen/xen-netback-generalize: Refresh (bnc#827378).
- Update other Xen patches to 3.0.87.
- commit 7407d8b
* Thu Aug  8 2013 mmarek@suse.cz
- kabi/severities: Allow changes in net/ceph/libceph
- commit d08b6d3
* Thu Aug  8 2013 dalgaaf@suse.de
- remove include of linux/export.h which isn't needed
  (fate#312983).
- fix ceph_key_instantiate() to build correctly without warning
  (fate#312983).
- dd define for SIZE_MAX as in include/linux/kernel.h on recent
  kernels (fate#312983).
- fix rbd_release() to return int instead of void (fate#312983).
- Add define for SIZE_MAX as in include/linux/kernel.h on recent
  kernels (fate#312983).
- replace __atomic_add_unless() with atomic_add_unless()
  (fate#312983).
- libceph: for chooseleaf rules, retry CRUSH map descent from
  root if leaf is failed (fate#312983).
- UAPI: (Scripted) Convert #include "..." to #include <path/...>
  in kernel system headers (fate#312983).
- libceph: support crush tunables (fate#312983).
- libceph: use slab cache for osd client requests (fate#312983).
- libceph: create source file "net/ceph/snapshot.c" (fate#312983).
- libceph: validate timespec conversions (fate#312983).
- libceph: add signed type limits (fate#312983).
- libceph: support pages for class request data (fate#312983).
- libceph: support raw data requests (fate#312983).
- libceph: kill off osd data write_request parameters
  (fate#312983).
- libceph: change how "safe" callback is used (fate#312983).
- libceph: make method call data be a separate data item
  (fate#312983).
- libceph: add, don't set data for a message (fate#312983).
- libceph: implement multiple data items in a message
  (fate#312983).
- libceph: replace message data pointer with list (fate#312983).
- libceph: have cursor point to data (fate#312983).
- libceph: move cursor into message (fate#312983).
- libceph: record bio length (fate#312983).
- libceph: fix possible CONFIG_BLOCK build problem (fate#312983).
- libceph: kill off osd request r_data_in and r_data_out
  (fate#312983).
- libceph: set the data pointers when encoding ops (fate#312983).
- libceph: combine initializing and setting osd data
  (fate#312983).
- libceph: format class info at init time (fate#312983).
- libceph: specify osd op by index in request (fate#312983).
- libceph: add data pointers in osd op structures (fate#312983).
- libceph: rename data out field in osd request op (fate#312983).
- libceph: keep source rather than message osd op array
  (fate#312983).
- libceph: define osd data initialization helpers (fate#312983).
- ceph: build osd request message later for writepages
  (fate#312983).
- libceph: don't build request in ceph_osdc_new_request()
  (fate#312983).
- libceph: record message data length (fate#312983).
- libceph: record length of bio list with bio (fate#312983).
- libceph: drop ceph_osd_request->r_con_filling_msg (fate#312983).
- libceph: define ceph_decode_pgid() only once (fate#312983).
- libceph: define source request op functions (fate#312983).
- ceph: move max constant definitions (fate#312983).
- libceph: make message data be a pointer (fate#312983).
- libceph: kill last of ceph_msg_pos (fate#312983).
- libceph: kill most of ceph_msg_pos (fate#312983).
- libceph: collapse all data items into one (fate#312983).
- libceph: kill ceph message bio_iter, bio_seg (fate#312983).
- libceph: record residual bytes for all message data types
  (fate#312983).
- libceph: wrap auth methods in a mutex (fate#312983).
- libceph: wrap auth ops in wrapper functions (fate#312983).
- libceph: add update_authorizer auth method (fate#312983).
- libceph: implement RECONNECT_SEQ feature (fate#312983).
- libceph: kill message trail (fate#312983).
- libceph: kill osd request r_trail (fate#312983).
- libceph: have osd requests support pagelist data (fate#312983).
- libceph: let osd ops determine request data length
  (fate#312983).
- libceph: implement pages array cursor (fate#312983).
- libceph: implement bio message data item cursor (fate#312983).
- libceph: prepare for other message data item types
  (fate#312983).
- libceph: start defining message data cursor (fate#312983).
- libceph: abstract message data (fate#312983).
- libceph: be explicit about message data representation
  (fate#312983).
- libceph: define ceph_msg_has_*() data macros (fate#312983).
- libceph: record message data byte length (fate#312983).
- libceph: isolate other message data fields (fate#312983).
- libceph: set page info with byte length (fate#312983).
- libceph: isolate message page field manipulation (fate#312983).
- libceph: record byte count not page count (fate#312983).
- libceph: define CEPH_MSG_MAX_MIDDLE_LEN (fate#312983).
- libceph: separate read and write data (fate#312983).
- libceph: distinguish page and bio requests (fate#312983).
- libceph: separate osd request data info (fate#312983).
- libceph: don't assign page info in ceph_osdc_new_request()
  (fate#312983).
- libceph: rename ceph_calc_object_layout() (fate#312983).
- libceph: kill ceph_msg->pagelist_count (fate#312983).
- libceph: use (void *) for untyped data in osd ops (fate#312983).
- libceph: complete lingering requests only once (fate#312983).
- libceph: distinguish page array and pagelist count
  (fate#312983).
- libceph: make ceph_msg->bio_seg be unsigned (fate#312983).
- libceph: add support for HASHPSPOOL pool flag (fate#312983).
- libceph: update osd request/reply encoding (fate#312983).
- libceph: calculate placement based on the internal data types
  (fate#312983).
- ceph: update support for PGID64, PGPOOL3, OSDENC protocol
  features (fate#312983).
- ceph: update "ceph_features.h" (fate#312983).
- libceph: decode into cpu-native ceph_pg type (fate#312983).
- libceph: rename ceph_pg -> ceph_pg_v1 (fate#312983).
- libceph: drop return value from page vector copy routines
  (fate#312983).
- libceph: use void pointers in page vector functions
  (fate#312983).
- libceph: update ceph_fs.h (fate#312983).
- libceph: add ceph_osd_state_name() (fate#312983).
- libceph: update rados.h (fate#312983).
- libceph: kill ceph_osdc_wait_event() (fate#312983).
- libceph: kill ceph_osdc_create_event() "one_shot" parameter
  (fate#312983).
- libceph: kill ceph_calc_raw_layout() (fate#312983).
- ceph: kill ceph_osdc_new_request() "num_reply" parameter
  (fate#312983).
- ceph: kill ceph_osdc_writepages() "flags" parameter
  (fate#312983).
- ceph: kill ceph_osdc_writepages() "dosync" parameter
  (fate#312983).
- ceph: kill ceph_osdc_writepages() "nofail" parameter
  (fate#312983).
- libceph: improve packing in struct ceph_osd_req_op
  (fate#312983).
- libceph: add a compatibility check interface (fate#312983).
- libceph: fix messenger CONFIG_BLOCK dependencies (fate#312983).
- rbd: kill ceph_osd_req_op->flags (fate#312983).
- libceph: pass num_op with ops (fate#312983).
- libceph: don't set pages or bio in ceph_osdc_alloc_request()
  (fate#312983).
- libceph: don't set flags in ceph_osdc_alloc_request()
  (fate#312983).
- libceph: drop osdc from ceph_calc_raw_layout() (fate#312983).
- libceph: drop snapid in ceph_calc_raw_layout() (fate#312983).
- libceph: pass length to ceph_calc_file_object_mapping()
  (fate#312983).
- libceph: pass length to ceph_osdc_build_request() (fate#312983).
- libceph: always allow trail in osd request (fate#312983).
- rbd: drop oid parameters from ceph_osdc_build_request()
  (fate#312983).
- ceph: define ceph_encode_8_safe() (fate#312983).
- libceph: for chooseleaf rules, retry CRUSH map descent from
  root if leaf is failed (fate#312983).
- ceph: Check for created flag in response from mds (fate#312983).
- libceph: remove 'osdtimeout' option (fate#312983).
- libceph: define ceph_pg_pool_name_by_id() (fate#312983).
- rbd: get parent spec for version 2 images (fate#312983).
- UAPI: (Scripted) Convert #include "..." to #include <path/...>
  in kernel system headers (fate#312983).
- libceph: check for invalid mapping (fate#312983).
- libceph: remove unused monc->have_fsid (fate#312983).
- libceph: clean up con flags (fate#312983).
- libceph: replace connection state bits with states
  (fate#312983).
- ceph: define snap counts as u32 everywhere (fate#312983).
- libceph: support crush tunables (fate#312983).
- libceph: move feature bits to separate header (fate#312983).
- libceph: define ceph_extract_encoded_string() (fate#312983).
- libceph: fix off-by-one bug in ceph_encode_filepath()
  (fate#312983).
- libceph: prevent the race of incoming work during teardown
  (fate#312983).
- libceph: fix messenger retry (fate#312983).
- libceph: initialize msgpool message types (fate#312983).
- libceph: set peer name on con_open, not init (fate#312983).
- libceph: drop declaration of ceph_con_get() (fate#312983).
- libceph: define and use an explicit CONNECTED state
  (fate#312983).
- libceph: drop ceph_con_get/put helpers and nref member
  (fate#312983).
- libceph: make ceph_con_revoke_message() a msg op (fate#312983).
- libceph: make ceph_con_revoke() a msg operation (fate#312983).
- libceph: have messages point to their connection (fate#312983).
- libceph: fully initialize connection in con_init()
  (fate#312983).
- libceph: embed ceph connection structure in mon_client
  (fate#312983).
- libceph: start tracking connection socket state (fate#312983).
- libceph: start separating connection flags from state
  (fate#312983).
- libceph: embed ceph messenger structure in ceph_client
  (fate#312983).
- libceph: kill bad_proto ceph connection op (fate#312983).
- libceph: eliminate connection state "DEAD" (fate#312983).
- BUG: headers with BUG/BUG_ON etc. need linux/bug.h
  (fate#312983).
- libceph: init sent and completed when starting (fate#312983).
- libceph: use slab cache for osd client requests (fate#312983).
- libceph: allocate ceph message data with a slab allocator
  (fate#312983).
- libceph: allocate ceph messages with a slab allocator
  (fate#312983).
- libceph: create source file "net/ceph/snapshot.c" (fate#312983).
- libceph: fix byte order mismatch (fate#312983).
- libceph: support pages for class request data (fate#312983).
- libceph: fix two messenger bugs (fate#312983).
- libceph: support raw data requests (fate#312983).
- libceph: clean up osd data field access functions (fate#312983).
- libceph: kill off osd data write_request parameters
  (fate#312983).
- libceph: change how "safe" callback is used (fate#312983).
- libceph: make method call data be a separate data item
  (fate#312983).
- libceph: add, don't set data for a message (fate#312983).
- libceph: implement multiple data items in a message
  (fate#312983).
- libceph: replace message data pointer with list (fate#312983).
- libceph: have cursor point to data (fate#312983).
- libceph: move cursor into message (fate#312983).
- libceph: record bio length (fate#312983).
- libceph: skip message if too big to receive (fate#312983).
- libceph: fix possible CONFIG_BLOCK build problem (fate#312983).
- libceph: kill off osd request r_data_in and r_data_out
  (fate#312983).
- libceph: set the data pointers when encoding ops (fate#312983).
- libceph: combine initializing and setting osd data
  (fate#312983).
- libceph: set message data when building osd request
  (fate#312983).
- libceph: move ceph_osdc_build_request() (fate#312983).
- libceph: format class info at init time (fate#312983).
- libceph: specify osd op by index in request (fate#312983).
- libceph: add data pointers in osd op structures (fate#312983).
- libceph: rename data out field in osd request op (fate#312983).
- libceph: keep source rather than message osd op array
  (fate#312983).
- libceph: define ceph_osd_data_length() (fate#312983).
- libceph: define a few more helpers (fate#312983).
- libceph: define osd data initialization helpers (fate#312983).
- libceph: compute incoming bytes once (fate#312983).
- libceph: provide data length when preparing message
  (fate#312983).
- ceph: build osd request message later for writepages
  (fate#312983).
- libceph: hold off building osd request (fate#312983).
- libceph: don't build request in ceph_osdc_new_request()
  (fate#312983).
- libceph: record message data length (fate#312983).
- libceph: drop ceph_osd_request->r_con_filling_msg (fate#312983).
- libceph: define ceph_decode_pgid() only once (fate#312983).
- libceph: drop mutex on error in handle_reply() (fate#312983).
- libceph: use osd_req_op_extent_init() (fate#312983).
- libceph: clean up ceph_osd_new_request() (fate#312983).
- libceph: don't update op in calc_layout() (fate#312983).
- libceph: pass offset and length out of calc_layout()
  (fate#312983).
- libceph: define source request op functions (fate#312983).
- libceph: define osd_req_opcode_valid() (fate#312983).
- libceph: be explicit in masking bottom 16 bits (fate#312983).
- libceph: account for alignment in pages cursor (fate#312983).
- libceph: page offset must be less than page size (fate#312983).
- libceph: fix broken data length assertions (fate#312983).
- libceph: make message data be a pointer (fate#312983).
- libceph: use only ceph_msg_data_advance() (fate#312983).
- libceph: don't add to crc unless data sent (fate#312983).
- libceph: kill last of ceph_msg_pos (fate#312983).
- libceph: kill most of ceph_msg_pos (fate#312983).
- libceph: use cursor resid for loop condition (fate#312983).
- libceph: collapse all data items into one (fate#312983).
- libceph: get rid of read helpers (fate#312983).
- libceph: no outbound zero data (fate#312983).
- libceph: use cursor for inbound data pages (fate#312983).
- libceph: kill ceph message bio_iter, bio_seg (fate#312983).
- libceph: use cursor for bio reads (fate#312983).
- libceph: record residual bytes for all message data types
  (fate#312983).
- libceph: drop pages parameter (fate#312983).
- libceph: initialize data fields on last msg put (fate#312983).
- libceph: send queued requests when starting new one
  (fate#312983).
- libceph: keep request lists in tid order (fate#312983).
- libceph: requeue only sent requests when kicking (fate#312983).
- libceph: no more kick_requests() race (fate#312983).
- libceph: slightly defer registering osd request (fate#312983).
- libceph: wrap auth methods in a mutex (fate#312983).
- libceph: wrap auth ops in wrapper functions (fate#312983).
- libceph: add update_authorizer auth method (fate#312983).
- libceph: fix authorizer invalidation (fate#312983).
- libceph: clear messenger auth_retry flag when we authenticate
  (fate#312983).
- libceph: implement RECONNECT_SEQ feature (fate#312983).
- libceph: more cleanup of write_partial_msg_pages()
  (fate#312983).
- libceph: kill message trail (fate#312983).
- libceph: kill osd request r_trail (fate#312983).
- libceph: have osd requests support pagelist data (fate#312983).
- libceph: let osd ops determine request data length
  (fate#312983).
- libceph: implement pages array cursor (fate#312983).
- libceph: implement bio message data item cursor (fate#312983).
- libceph: use data cursor for message pagelist (fate#312983).
- libceph: prepare for other message data item types
  (fate#312983).
- libceph: start defining message data cursor (fate#312983).
- libceph: abstract message data (fate#312983).
- libceph: be explicit about message data representation
  (fate#312983).
- libceph: define ceph_msg_has_*() data macros (fate#312983).
- libceph: define and use ceph_crc32c_page() (fate#312983).
- libceph: define and use ceph_tcp_recvpage() (fate#312983).
- libceph: encapsulate reading message data (fate#312983).
- libceph: small write_partial_msg_pages() refactor (fate#312983).
- libceph: consolidate message prep code (fate#312983).
- libceph: use local variables for message positions
  (fate#312983).
- libceph: activate message data assignment checks (fate#312983).
- libceph: set response data fields earlier (fate#312983).
- libceph: record message data byte length (fate#312983).
- ceph: only set message data pointers if non-empty (fate#312983).
- libceph: isolate other message data fields (fate#312983).
- libceph: set page info with byte length (fate#312983).
- libceph: isolate message page field manipulation (fate#312983).
- libceph: record byte count not page count (fate#312983).
- libceph: simplify new message initialization (fate#312983).
- libceph: advance pagelist with list_rotate_left() (fate#312983).
- libceph: define and use in_msg_pos_next() (fate#312983).
- libceph: kill args in read_partial_message_bio() (fate#312983).
- libceph: change type of ceph_tcp_sendpage() "more"
  (fate#312983).
- libceph: minor byte order problems in read_partial_message()
  (fate#312983).
- libceph: define CEPH_MSG_MAX_MIDDLE_LEN (fate#312983).
- libceph: clean up skipped message logic (fate#312983).
- libceph: separate read and write data (fate#312983).
- libceph: distinguish page and bio requests (fate#312983).
- libceph: separate osd request data info (fate#312983).
- libceph: don't assign page info in ceph_osdc_new_request()
  (fate#312983).
- libceph: define mds_alloc_msg() method (fate#312983).
- libceph: drop mutex while allocating a message (fate#312983).
- libceph: rename ceph_calc_object_layout() (fate#312983).
- libceph: kill ceph_msg->pagelist_count (fate#312983).
- libceph: fix wrong opcode use in osd_req_encode_op()
  (fate#312983).
- libceph: complete lingering requests only once (fate#312983).
- libceph: set page alignment in start_request() (fate#312983).
- libceph: distinguish page array and pagelist count
  (fate#312983).
- libceph: don't pass request to calc_layout() (fate#312983).
- libceph: format target object name in caller (fate#312983).
- libceph: pass object number back to calc_layout() caller
  (fate#312983).
- libceph: make ceph_msg->bio_seg be unsigned (fate#312983).
- libceph: fix a osd request memory leak (fate#312983).
- libceph: fix decoding of pgids (fate#312983).
- libceph: add support for HASHPSPOOL pool flag (fate#312983).
- libceph: update osd request/reply encoding (fate#312983).
- libceph: calculate placement based on the internal data types
  (fate#312983).
- ceph: update support for PGID64, PGPOOL3, OSDENC protocol
  features (fate#312983).
- libceph: decode into cpu-native ceph_pg type (fate#312983).
- net: cleanup unsigned to unsigned int (fate#312983).
- libceph: rename ceph_pg -> ceph_pg_v1 (fate#312983).
- libceph: use a do..while loop in con_work() (fate#312983).
- libceph: use a flag to indicate a fault has occurred
  (fate#312983).
- libceph: separate non-locked fault handling (fate#312983).
- libceph: encapsulate connection backoff (fate#312983).
- libceph: eliminate sparse warnings (fate#312983).
- libceph: define connection flag helpers (fate#312983).
- libceph: drop return value from page vector copy routines
  (fate#312983).
- libceph: use void pointers in page vector functions
  (fate#312983).
- libceph: allow STAT osd operations (fate#312983).
- libceph: simplify data length calculation (fate#312983).
- libceph: remove dead code in osd_req_encode_op() (fate#312983).
- libceph: report defined but unsupported osd ops (fate#312983).
- libceph: update ceph_osd_op_name() (fate#312983).
- libceph: add ceph_osd_state_name() (fate#312983).
- libceph: kill ceph_osdc_wait_event() (fate#312983).
- libceph: kill ceph_osdc_create_event() "one_shot" parameter
  (fate#312983).
- libceph: kill ceph_calc_raw_layout() (fate#312983).
- libdeph: don't export ceph_osdc_init() or ceph_osdc_stop()
  (fate#312983).
- libceph: lock outside send_queued() (fate#312983).
- ceph: kill ceph_osdc_new_request() "num_reply" parameter
  (fate#312983).
- ceph: kill ceph_osdc_writepages() "flags" parameter
  (fate#312983).
- ceph: kill ceph_osdc_writepages() "dosync" parameter
  (fate#312983).
- ceph: kill ceph_osdc_writepages() "nofail" parameter
  (fate#312983).
- libceph: don't require r_num_pages for bio requests
  (fate#312983).
- rbd: don't take extra bio reference for osd client
  (fate#312983).
- libceph: add a compatibility check interface (fate#312983).
- libceph: fix messenger CONFIG_BLOCK dependencies (fate#312983).
- ceph: Only allow mounts in the initial network namespace
  (fate#312983).
- libceph: fix undefined behavior when using snprintf()
  (fate#312983).
- libceph: pass num_op with ops (fate#312983).
- libceph: don't set pages or bio in ceph_osdc_alloc_request()
  (fate#312983).
- libceph: don't set flags in ceph_osdc_alloc_request()
  (fate#312983).
- libceph: drop osdc from ceph_calc_raw_layout() (fate#312983).
- libceph: drop snapid in ceph_calc_raw_layout() (fate#312983).
- libceph: pass length to ceph_calc_file_object_mapping()
  (fate#312983).
- libceph: pass length to ceph_osdc_build_request() (fate#312983).
- libceph: kill op_needs_trail() (fate#312983).
- libceph: always allow trail in osd request (fate#312983).
- rbd: drop oid parameters from ceph_osdc_build_request()
  (fate#312983).
- libceph: reformat __reset_osd() (fate#312983).
- crush: avoid recursion if we have already collided
  (fate#312983).
- libceph: for chooseleaf rules, retry CRUSH map descent from
  root if leaf is failed (fate#312983).
- ceph: re-calculate truncate_size for strip object (fate#312983).
- net/ceph: remove depends on CONFIG_EXPERIMENTAL (fate#312983).
- libceph: fix protocol feature mismatch failure path
  (fate#312983).
- libceph: WARN, don't BUG on unexpected connection states
  (fate#312983).
- libceph: always reset osds when kicking (fate#312983).
- libceph: move linger requests sooner in kick_requests()
  (fate#312983).
- libceph: register request before unregister linger
  (fate#312983).
- libceph: don't use rb_init_node() in ceph_osdc_alloc_request()
  (fate#312983).
- libceph: init event->node in ceph_osdc_create_event()
  (fate#312983).
- libceph: init osd->o_node in create_osd() (fate#312983).
- libceph: report connection fault with warning (fate#312983).
- libceph: socket can close in any connection state (fate#312983).
- rbd: remove linger unconditionally (fate#312983).
- libceph: avoid using freed osd in __kick_osd_requests()
  (fate#312983).
- ceph: don't reference req after put (fate#312983).
- libceph: remove 'osdtimeout' option (fate#312983).
- libceph: define ceph_pg_pool_name_by_id() (fate#312983).
- libceph: fix osdmap decode error paths (fate#312983).
- libceph: avoid NULL kref_put when osd reset races with alloc_msg
  (fate#312983).
- rbd: define common queue_con_delay() (fate#312983).
- rbd: let con_work() handle backoff (fate#312983).
- rbd: reset BACKOFF if unable to re-queue (fate#312983).
- rbtree: empty nodes have no color (fate#312983).
- KEYS: Add payload preparsing opportunity prior to key
  instantiate or update (fate#312983).
- ceph: propagate layout error on osd request creation
  (fate#312983).
- libceph: check for invalid mapping (fate#312983).
- ceph: use list_move_tail instead of list_del/list_add_tail
  (fate#312983).
- libceph: Fix sparse warning (fate#312983).
- libceph: remove unused monc->have_fsid (fate#312983).
- libceph: only kunmap kmapped pages (fate#312983).
- libceph: avoid truncation due to racing banners (fate#312983).
- libceph: delay debugfs initialization until we learn global_id
  (fate#312983).
- libceph: fix crypto key null deref, memory leak (fate#312983).
- libceph: recheck con state after allocating incoming message
  (fate#312983).
- libceph: change ceph_con_in_msg_alloc convention to be less
  weird (fate#312983).
- libceph: avoid dropping con mutex before fault (fate#312983).
- libceph: verify state after retaking con lock after dispatch
  (fate#312983).
- libceph: revoke mon_client messages on session restart
  (fate#312983).
- libceph: fix handling of immediate socket connect failure
  (fate#312983).
- libceph: be less chatty about stray replies (fate#312983).
- libceph: clear all flags on con_close (fate#312983).
- libceph: clean up con flags (fate#312983).
- libceph: replace connection state bits with states
  (fate#312983).
- libceph: drop unnecessary CLOSED check in socket state change
  callback (fate#312983).
- libceph: close socket directly from ceph_con_close()
  (fate#312983).
- libceph: drop gratuitous socket close calls in con_work
  (fate#312983).
- libceph: move ceph_con_send() closed check under the con mutex
  (fate#312983).
- libceph: move msgr clear_standby under con mutex protection
  (fate#312983).
- libceph: fix fault locking; close socket on lossy fault
  (fate#312983).
- libceph: trivial fix for the incorrect debug output
  (fate#312983).
- libceph: reset connection retry on successfully negotiation
  (fate#312983).
- libceph: protect ceph_con_open() with mutex (fate#312983).
- libceph: (re)initialize bio_iter on start of message receive
  (fate#312983).
- libceph: resubmit linger ops when pg mapping changes
  (fate#312983).
- libceph: fix mutex coverage for ceph_con_close (fate#312983).
- libceph: report socket read/write error message (fate#312983).
- libceph: support crush tunables (fate#312983).
- libceph: move feature bits to separate header (fate#312983).
- libceph: prevent the race of incoming work during teardown
  (fate#312983).
- libceph: initialize rb, list nodes in ceph_osd_request
  (fate#312983).
- libceph: initialize msgpool message types (fate#312983).
- libceph: fix messenger retry (fate#312983).
- net: Fix non-kernel-doc comments with kernel-doc start marker
  (fate#312983).
- libceph: allow sock transition from CONNECTING to CLOSED
  (fate#312983).
- libceph: initialize mon_client con only once (fate#312983).
- libceph: set peer name on con_open, not init (fate#312983).
- libceph: add some fine ASCII art (fate#312983).
- libceph: small changes to messenger.c (fate#312983).
- libceph: distinguish two phases of connect sequence
  (fate#312983).
- libceph: separate banner and connect writes (fate#312983).
- libceph: define and use an explicit CONNECTED state
  (fate#312983).
- libceph: clear NEGOTIATING when done (fate#312983).
- libceph: clear CONNECTING in ceph_con_close() (fate#312983).
- libceph: don't touch con state in con_close_socket()
  (fate#312983).
- libceph: just set SOCK_CLOSED when state changes (fate#312983).
- libceph: don't change socket state on sock event (fate#312983).
- libceph: SOCK_CLOSED is a flag, not a state (fate#312983).
- libceph: don't use bio_iter as a flag (fate#312983).
- libceph: move init of bio_iter (fate#312983).
- libceph: move init_bio_*() functions up (fate#312983).
- libceph: don't mark footer complete before it is (fate#312983).
- libceph: encapsulate advancing msg page (fate#312983).
- libceph: encapsulate out message data setup (fate#312983).
- libceph: drop ceph_con_get/put helpers and nref member
  (fate#312983).
- libceph: use con get/put methods (fate#312983).
- libceph: fix NULL dereference in reset_connection()
  (fate#312983).
- libceph: flush msgr queue during mon_client shutdown
  (fate#312983).
- libceph: transition socket state prior to actual connect
  (fate#312983).
- libceph: fix overflow in osdmap_apply_incremental()
  (fate#312983).
- libceph: fix overflow in osdmap_decode() (fate#312983).
- libceph: fix overflow in __decode_pool_names() (fate#312983).
- rbd: Clear ceph_msg->bio_iter for retransmitted message
  (fate#312983).
- libceph: make ceph_con_revoke_message() a msg op (fate#312983).
- libceph: make ceph_con_revoke() a msg operation (fate#312983).
- libceph: have messages take a connection reference
  (fate#312983).
- libceph: have messages point to their connection (fate#312983).
- libceph: tweak ceph_alloc_msg() (fate#312983).
- libceph: fully initialize connection in con_init()
  (fate#312983).
- libceph: init monitor connection when opening (fate#312983).
- libceph: drop connection refcounting for mon_client
  (fate#312983).
- libceph: embed ceph connection structure in mon_client
  (fate#312983).
- libceph: use con get/put ops from osd_client (fate#312983).
- libceph: osd_client: don't drop reply reference too early
  (fate#312983).
- libceph: set CLOSED state bit in con_init (fate#312983).
- libceph: provide osd number when creating osd (fate#312983).
- libceph: start tracking connection socket state (fate#312983).
- libceph: start separating connection flags from state
  (fate#312983).
- libceph: embed ceph messenger structure in ceph_client
  (fate#312983).
- libceph: rename kvec_reset and kvec_add functions (fate#312983).
- libceph: rename socket callbacks (fate#312983).
- libceph: kill bad_proto ceph connection op (fate#312983).
- libceph: eliminate connection state "DEAD" (fate#312983).
- crush: include header for global symbols (fate#312983).
- rbd: re-submit flattened write request (part 2) (fate#312983).
- rbd: re-submit write request for flattened clone (fate#312983).
- rbd: re-submit read request for flattened clone (fate#312983).
- rbd: detect when clone image is flattened (fate#312983).
- rbd: reference count parent requests (fate#312983).
- rbd: define parent image request routines (fate#312983).
- rbd: define rbd_dev_unparent() (fate#312983).
- rbd: don't release write request until necessary (fate#312983).
- rbd: get parent info on refresh (fate#312983).
- rbd: ignore zero-overlap parent (fate#312983).
- rbd: support reading parent page data for writes (fate#312983).
- rbd: fix parent request size assumption (fate#312983).
- rbd: kill rbd_img_request_get() (fate#312983).
- rbd: only set up watch for mapped images (fate#312983).
- rbd: set mapping read-only flag in rbd_add() (fate#312983).
- rbd: support reading parent page data (fate#312983).
- rbd: fix an incorrect assertion condition (fate#312983).
- rbd: define rbd_dev_v2_header_info() (fate#312983).
- rbd: get rid of trivial v1 header wrappers (fate#312983).
- rbd: simplify rbd_dev_v1_probe() (fate#312983).
- rbd: update in-core header directly (fate#312983).
- rbd: refactor rbd_header_from_disk() (fate#312983).
- rbd: zero format 1 header structure earlier (fate#312983).
- rbd: set the mapping size and features later (fate#312983).
- rbd: always set read-only flag in rbd_add() (fate#312983).
- rbd: kill rbd_dev_clear_mapping() (fate#312983).
- rbd: don't look up snapshot id in rbd_dev_mapping_set()
  (fate#312983).
- rbd: don't print warning if not mapping a parent (fate#312983).
- rbd: kill rbd_update_mapping_size() (fate#312983).
- rbd: update capacity in rbd_dev_refresh() (fate#312983).
- rbd: revalidate only for mapping size changes (fate#312983).
- rbd: fix leak of format 2 snapshot context (fate#312983).
- block_device_operations->release() should return void
  (fate#312983).
- rbd: fix image request leak on parent read (fate#312983).
- rbd: allocate image object names with a slab allocator
  (fate#312983).
- rbd: allocate object requests with a slab allocator
  (fate#312983).
- rbd: allocate name separate from obj_request (fate#312983).
- rbd: allocate image requests with a slab allocator
  (fate#312983).
- rbd: use binary search for snapshot lookup (fate#312983).
- rbd: clear EXISTS flag if mapped snapshot disappears
  (fate#312983).
- rbd: kill off the snapshot list (fate#312983).
- rbd: define rbd_snap_size() and rbd_snap_features()
  (fate#312983).
- rbd: use snap_id not index to look up snap info (fate#312983).
- rbd: look up snapshot name in names buffer (fate#312983).
- rbd: drop obj_request->version (fate#312983).
- rbd: drop rbd_obj_method_sync() version parameter (fate#312983).
- rbd: more version parameter removal (fate#312983).
- rbd: get rid of some version parameters (fate#312983).
- rbd: stop tracking header object version (fate#312983).
- rbd: snap names are pointer to constant data (fate#312983).
- rbd: don't revalidate so much (fate#312983).
- rbd: fix up the layering warning message (fate#312983).
- ceph: use ceph_create_snap_context() (fate#312983).
- rbd: set up devices only for mapped images (fate#312983).
- rbd: don't have device release destroy rbd_dev (fate#312983).
- rbd: define rbd_dev_unprobe() (fate#312983).
- rbd: don't destroy rbd_dev in device release function
  (fate#312983).
- rbd: drop module later (fate#312983).
- rbd: set up watch in rbd_dev_image_probe() (fate#312983).
- rbd: don't bother checking whether order changes (fate#312983).
- rbd: don't clean up watch in device release function
  (fate#312983).
- rbd: define rbd_header_name() (fate#312983).
- rbd: move more initialization into rbd_dev_image_probe()
  (fate#312983).
- rbd: probe for the parent earlier (fate#312983).
- rbd: remove parent devices on probe error (fate#312983).
- rbd: fix rbd_dev_remove_parent() (fate#312983).
- rbd: kill __rbd_remove() (fate#312983).
- rbd: set mapping info earlier (fate#312983).
- rbd: encapsulate removing parent devices (fate#312983).
- rbd: encapsulate probing for parent devices (fate#312983).
- rbd: defer setting disk capacity (fate#312983).
- rbd: only set device exists flag when ready (fate#312983).
- rbd: fix up some sysfs stuff (fate#312983).
- rbd: fix a bug in resizing a mapping (fate#312983).
- rbd: refactor rbd_dev_probe_update_spec() (fate#312983).
- rbd: rename rbd_dev_probe() (fate#312983).
- rbd: make rbd_dev_destroy() match rbd_dev_create()
  (fate#312983).
- rbd: define rbd snap context routines (fate#312983).
- rbd: use rbd_warn(), not WARN_ON() (fate#312983).
- rbd: move stripe_unit and stripe_count into header
  (fate#312983).
- rbd: make rbd spec names pointer to const (fate#312983).
- rbd: set snapshot id in rbd_dev_probe_update_spec()
  (fate#312983).
- rbd: have snap_by_name() return a snapshot (fate#312983).
- rbd: fix image id leak in initial probe (fate#312983).
- rbd: have rbd_dev_image_id() set format 1 image id
  (fate#312983).
- rbd: avoid dropping extra reference in rbd_free_disk()
  (fate#312983).
- rbd: use rbd_obj_method_sync() return value (fate#312983).
- rbd: fix leak of format 2 snapshot names (fate#312983).
- rbd: rename __rbd_add_snap_dev() (fate#312983).
- rbd: only update values on snap_info success (fate#312983).
- rbd: make snap_size order parameter optional (fate#312983).
- rbd: fix leak of snapshots during initial probe (fate#312983).
- rbd: don't create sysfs entries for non-mapped snapshots
  (fate#312983).
- rbd: activate support for layered images (fate#312983).
- rbd: get and check striping parameters (fate#312983).
- rbd: have rbd_obj_method_sync() return transfer count
  (fate#312983).
- rbd: void data pointers for rbd_obj_method_sync() (fate#312983).
- rbd: give rbd_obj_read_sync() buffer void type (fate#312983).
- rbd: enforce parent overlap (fate#312983).
- rbd: issue a copyup for layered writes (fate#312983).
- rbd: implement full object parent reads (fate#312983).
- rbd: revalidate_disk upon rbd resize (fate#312983).
- rbd: support page array image requests (fate#312983).
- rbd: define zero_pages() (fate#312983).
- rbd: encapsulate submission of image object requests
  (fate#312983).
- rbd: define separate read and write format funcs (fate#312983).
- rbd: issue stat request before layered write (fate#312983).
- rbd: add target object existence flags (fate#312983).
- rbd: always check IMG_DATA flag (fate#312983).
- rbd: adjust image object request ref counting (fate#312983).
- libceph: kill off osd data write_request parameters
  (fate#312983).
- rbd: implement layered reads (fate#312983).
- rbd: probe the parent of an image if present (fate#312983).
- rbd: add an object request flag for image data objects
  (fate#312983).
- rbd: define an rbd object request flags field (fate#312983).
- rbd: encapsulate image object end request handling
  (fate#312983).
- rbd: define image request layered flag (fate#312983).
- rbd: define image request originator flag (fate#312983).
- rbd: define image request flags (fate#312983).
- rbd: record image-relative offset in object requests
  (fate#312983).
- rbd: record aggregate image transfer count (fate#312983).
- rbd: record overall image request result (fate#312983).
- rbd: update feature bits (fate#312983).
- libceph: make method call data be a separate data item
  (fate#312983).
- libceph: combine initializing and setting osd data
  (fate#312983).
- rbd: rearrange some code for consistency (fate#312983).
- rbd: separate initialization of osd data (fate#312983).
- rbd: don't set data in rbd_osd_req_format_op() (fate#312983).
- libceph: specify osd op by index in request (fate#312983).
- libceph: add data pointers in osd op structures (fate#312983).
- libceph: keep source rather than message osd op array
  (fate#312983).
- rbd: define rbd_osd_req_format_op() (fate#312983).
- libceph: define osd data initialization helpers (fate#312983).
- rbd: define inbound data size for method ops (fate#312983).
- libceph: record length of bio list with bio (fate#312983).
- libceph: define source request op functions (fate#312983).
- ceph: move max constant definitions (fate#312983).
- libceph: let osd ops determine request data length
  (fate#312983).
- libceph: record byte count not page count (fate#312983).
- libceph: separate read and write data (fate#312983).
- libceph: distinguish page and bio requests (fate#312983).
- libceph: separate osd request data info (fate#312983).
- rbd: do a safe list traversal in rbd_img_request_submit()
  (fate#312983).
- rbd: don't zero-fill non-image object requests (fate#312983).
- block: Add bio_for_each_segment_all() (fate#312983).
- libceph: update osd request/reply encoding (fate#312983).
- rbd: pass length, not op for osd completions (fate#312983).
- rbd: move rbd_osd_trivial_callback() (fate#312983).
- rbd: eliminate sparse warnings (fate#312983).
- rbd: normalize dout() calls (fate#312983).
- rbd: barriers are hard (fate#312983).
- rbd: ignore zero-length requests (fate#312983).
- libceph: drop return value from page vector copy routines
  (fate#312983).
- rbd: ignore result of ceph_copy_from_page_vector()
  (fate#312983).
- rbd: prevent bytes transferred overflow (fate#312983).
- libceph: allow STAT osd operations (fate#312983).
- rbd: add parentheses to object request iterator macros
  (fate#312983).
- libceph: kill ceph_osdc_create_event() "one_shot" parameter
  (fate#312983).
- rbd: add barriers near done flag operations (fate#312983).
- rbd: turn off interrupts for open/remove locking (fate#312983).
- libceph: don't require r_num_pages for bio requests
  (fate#312983).
- rbd: don't take extra bio reference for osd client
  (fate#312983).
- rbd: prevent open for image being removed (fate#312983).
- rbd: define flags field, use it for exists flag (fate#312983).
- rbd: don't drop watch requests on completion (fate#312983).
- rbd: decrement obj request count when deleting (fate#312983).
- rbd: track object rather than osd request for watch
  (fate#312983).
- rbd: unregister linger in watch sync routine (fate#312983).
- rbd: get rid of rbd_req_sync_exec() (fate#312983).
- rbd: implement sync method with new code (fate#312983).
- rbd: send notify ack asynchronously (fate#312983).
- rbd: get rid of rbd_req_sync_notify_ack() (fate#312983).
- rbd: use new code for notify ack (fate#312983).
- rbd: get rid of rbd_req_sync_watch() (fate#312983).
- rbd: implement watch/unwatch with new code (fate#312983).
- rbd: get rid of rbd_req_sync_read() (fate#312983).
- rbd: implement sync object read with new code (fate#312983).
- rbd: kill rbd_req_coll and rbd_request (fate#312983).
- rbd: kill rbd_rq_fn() and all other related code (fate#312983).
- rbd: new request tracking code (fate#312983).
- rbd: don't retry setting up header watch (fate#312983).
- rbd: check for overflow in rbd_get_num_segments() (fate#312983).
- rbd: small changes (fate#312983).
- rbd: fix type of snap_id in rbd_dev_v2_snap_info()
  (fate#312983).
- rbd: assign watch request more directly (fate#312983).
- rbd: move remaining osd op setup into rbd_osd_req_op_create()
  (fate#312983).
- rbd: move call osd op setup into rbd_osd_req_op_create()
  (fate#312983).
- rbd: don't assign extent info in rbd_req_sync_op()
  (fate#312983).
- rbd: don't assign extent info in rbd_do_request() (fate#312983).
- rbd: don't leak rbd_req for rbd_req_sync_notify_ack()
  (fate#312983).
- rbd: don't leak rbd_req on synchronous requests (fate#312983).
- rbd: combine rbd sync watch/unwatch functions (fate#312983).
- rbd: use a common layout for each device (fate#312983).
- rbd: don't bother calculating file mapping (fate#312983).
- rbd: open code rbd_calc_raw_layout() (fate#312983).
- rbd: pull in ceph_calc_raw_layout() (fate#312983).
- rbd: assume single op in a request (fate#312983).
- rbd: there is really only one op (fate#312983).
- libceph: pass num_op with ops (fate#312983).
- rbd: pass num_op with ops array (fate#312983).
- libceph: don't set pages or bio in ceph_osdc_alloc_request()
  (fate#312983).
- libceph: don't set flags in ceph_osdc_alloc_request()
  (fate#312983).
- libceph: drop osdc from ceph_calc_raw_layout() (fate#312983).
- libceph: drop snapid in ceph_calc_raw_layout() (fate#312983).
- libceph: pass length to ceph_osdc_build_request() (fate#312983).
- rbd: don't bother setting snapid in rbd_do_request()
  (fate#312983).
- rbd: kill rbd_req_sync_op() snapc and snapid parameters
  (fate#312983).
- rbd: drop flags parameter from rbd_req_sync_exec()
  (fate#312983).
- rbd: drop snapid parameter from rbd_req_sync_read()
  (fate#312983).
- rbd: drop oid parameters from ceph_osdc_build_request()
  (fate#312983).
- rbd: separate layout init (fate#312983).
- rbd: only get snap context for write requests (fate#312983).
- rbd: make exists flag atomic (fate#312983).
- rbd: a little more cleanup of rbd_rq_fn() (fate#312983).
- rbd: end request on error in rbd_do_request() caller
  (fate#312983).
- rbd: encapsulate handling for a single request (fate#312983).
- rbd: be picky about osd request status type (fate#312983).
- rbd: standardize ceph_osd_request variable names (fate#312983).
- rbd: standardize rbd_request variable names (fate#312983).
- rbd: add warnings to rbd_dev_probe_update_spec() (fate#312983).
- rbd: add a warning in bio_chain_clone_range() (fate#312983).
- rbd: add warning messages for missing arguments (fate#312983).
- rbd: define and use rbd_warn() (fate#312983).
- rbd: use kmemdup() (fate#312983).
- rbd: kill rbd_spec->image_id_len (fate#312983).
- rbd: kill rbd_spec->image_name_len (fate#312983).
- rbd: document rbd_spec structure (fate#312983).
- rbd: get rid of rbd_{get,put}_dev() (fate#312983).
- rbd: don't use ENOTSUPP (fate#312983).
- rbd: get rid of RBD_MAX_SEG_NAME_LEN (fate#312983).
- rbd: do not allow remove of mounted-on image (fate#312983).
- rbd: get additional info in parent spec (fate#312983).
- rbd: get parent spec for version 2 images (fate#312983).
- rbd: allow null image name (fate#312983).
- rbd: encapsulate last part of probe (fate#312983).
- rbd: define rbd_dev_{create,destroy}() helpers (fate#312983).
- rbd: consolidate rbd_dev init in rbd_add() (fate#312983).
- rbd: don't pass rbd_dev to rbd_get_client() (fate#312983).
- rbd: fill rbd_spec in rbd_add_parse_args() (fate#312983).
- rbd: add reference counting to rbd_spec (fate#312983).
- rbd: define image specification structure (fate#312983).
- rbd: have rbd_add_parse_args() return error (fate#312983).
- rbd: pass and populate rbd_options structure (fate#312983).
- rbd: remove snap_name arg from rbd_add_parse_args()
  (fate#312983).
- rbd: remove options args from rbd_add_parse_args()
  (fate#312983).
- rbd: get rid of snap_name_len (fate#312983).
- rbd: do all argument parsing in one place (fate#312983).
- rbd: move ceph_parse_options() call up (fate#312983).
- rbd: rename snap_exists field (fate#312983).
- rbd: move snap info out of rbd_mapping struct (fate#312983).
- rbd: make pool_id a 64 bit value (fate#312983).
- rbd: remove snapshots on error in rbd_add() (fate#312983).
- rbd: simplify rbd_rq_fn() (fate#312983).
- rbd: kill rbd_device->rbd_opts (fate#312983).
- rbd: simplify rbd_merge_bvec() (fate#312983).
- rbd: increase maximum snapshot name length (fate#312983).
- rbd: verify rbd image order value (fate#312983).
- rbd: consolidate rbd_do_op() calls (fate#312983).
- rbd: drop rbd_do_op() opcode and flags (fate#312983).
- rbd: kill rbd_req_{read,write}() (fate#312983).
- rbd: fix read-only option name (fate#312983).
- rbd: zero return code in rbd_dev_image_id() (fate#312983).
- rbd: fix bug in rbd_dev_id_put() (fate#312983).
- rbd: activate v2 image support (fate#312983).
- rbd: implement feature checks (fate#312983).
- rbd: define rbd_dev_v2_refresh() (fate#312983).
- rbd: define rbd_update_mapping_size() (fate#312983).
- rbd: BUG on invalid layout (fate#312983).
- rbd: update remaining header fields for v2 (fate#312983).
- rbd: get snapshot name for a v2 image (fate#312983).
- rbd: get the snapshot context for a v2 image (fate#312983).
- rbd: get image features for a v2 image (fate#312983).
- rbd: get the object prefix for a v2 rbd image (fate#312983).
- rbd: add code to get the size of a v2 rbd image (fate#312983).
- rbd: lay out header probe infrastructure (fate#312983).
- rbd: encapsulate code that gets snapshot info (fate#312983).
- rbd: add an rbd features field (fate#312983).
- rbd: don't use index in __rbd_add_snap_dev() (fate#312983).
- rbd: kill create_snap sysfs entry (fate#312983).
- rbd: define rbd_dev_image_id() (fate#312983).
- rbd: define some new format constants (fate#312983).
- rbd: support data returned from OSD methods (fate#312983).
- rbd: pass flags to rbd_req_sync_exec() (fate#312983).
- rbd: set up watch before announcing disk (fate#312983).
- rbd: set initial capacity in rbd_init_disk() (fate#312983).
- rbd: drop dev registration check for new snap (fate#312983).
- rbd: call rbd_init_disk() sooner (fate#312983).
- rbd: defer setting device id (fate#312983).
- rbd: read the header before registering device (fate#312983).
- rbd: call set_snap() before snap_devs_update() (fate#312983).
- rbd: defer registering snapshot devices (fate#312983).
- rbd: assign header name later (fate#312983).
- rbd: use snaps list in rbd_snap_by_name() (fate#312983).
- rbd: don't register snapshots in bus_add_dev() (fate#312983).
- rbd: move locking out of rbd_header_set_snap() (fate#312983).
- rbd: simplify rbd_init_disk() a bit (fate#312983).
- rbd: do some header initialization earlier (fate#312983).
- rbd: simplify snap_by_name() interface (fate#312983).
- rbd: set mapping name with the rest (fate#312983).
- rbd: return snap name from rbd_add_parse_args() (fate#312983).
- rbd: record mapped size (fate#312983).
- rbd: separate mapping info in rbd_dev (fate#312983).
- rbd: kill rbd_image_header->total_snaps (fate#312983).
- rbd: kill rbd_dev->q (fate#312983).
- rbd: rename __rbd_init_snaps_header() (fate#312983).
- rbd: rename rbd_id_get() (fate#312983).
- rbd: define rbd_assert() (fate#312983).
- rbd: split up rbd_get_segment() (fate#312983).
- rbd: check for overflow in rbd_get_num_segments() (fate#312983).
- rbd: drop needless test in rbd_rq_fn() (fate#312983).
- rbd: bio_chain_clone() cleanups (fate#312983).
- rbd: kill notify_timeout option (fate#312983).
- rbd: add read_only rbd map option (fate#312983).
- rbd: move rbd_opts to struct rbd_device (fate#312983).
- rbd: more cleanup in rbd_header_from_disk() (fate#312983).
- rbd: kill incore snap_names_len (fate#312983).
- rbd: don't over-allocate space for object prefix (fate#312983).
- rbd: handle locking inside __rbd_client_find() (fate#312983).
- rbd: add new snapshots at the tail (fate#312983).
- rbd: rename block_name -> object_prefix (fate#312983).
- rbd: separate reading header from decoding it (fate#312983).
- rbd: expand rbd_dev_ondisk_valid() checks (fate#312983).
- rbd: return earlier in rbd_header_from_disk() (fate#312983).
- rbd: rearrange rbd_header_from_disk() (fate#312983).
- rbd: use sizeof (object) instead of sizeof (type) (fate#312983).
- rbd: ensure invalid pointers are made null (fate#312983).
- rbd: make snap_names_len a u64 (fate#312983).
- rbd: simplify __rbd_init_snaps_header() (fate#312983).
- rbd: drop dev reference on error in rbd_open() (fate#312983).
- rbd: create rbd_refresh_helper() (fate#312983).
- rbd: return obj version in __rbd_refresh_header() (fate#312983).
- rbd: fixes in rbd_header_from_disk() (fate#312983).
- rbd: always pass ops array to rbd_req_sync_op() (fate#312983).
- rbd: pass null version pointer in add_snap() (fate#312983).
- rbd: make rbd_create_rw_ops() return a pointer (fate#312983).
- rbd: have __rbd_add_snap_dev() return a pointer (fate#312983).
- rbd: drop "object_name" from rbd_req_sync_unwatch()
  (fate#312983).
- rbd: drop "object_name" from rbd_req_sync_notify_ack()
  (fate#312983).
- rbd: drop "object_name" from rbd_req_sync_notify()
  (fate#312983).
- rbd: drop "object_name" from rbd_req_sync_watch() (fate#312983).
- rbd: drop rbd_dev parameter in snap functions (fate#312983).
- rbd: drop rbd_header_from_disk() gfp_flags parameter
  (fate#312983).
- rbd: snapc is unused in rbd_req_sync_read() (fate#312983).
- rbd: rename rbd_device->id (fate#312983).
- rbd: encapsulate header validity test (fate#312983).
- rbd: clean up a few dout() calls (fate#312983).
- rbd: simplify __rbd_remove_all_snaps() (fate#312983).
- rbd: drop extra header_rwsem init (fate#312983).
- rbd: kill rbd_image_header->snap_seq (fate#312983).
- rbd: set snapc->seq only when refreshing header (fate#312983).
- rbd: preserve snapc->seq in rbd_header_set_snap() (fate#312983).
- rbd: don't use snapc->seq that way (fate#312983).
- rbd: send header version when notifying (fate#312983).
- rbd: use reference counting for the snap context (fate#312983).
- rbd: set image size when header is updated (fate#312983).
- rbd: expose the correct size of the device in sysfs
  (fate#312983).
- rbd: only reset capacity when pointing to head (fate#312983).
- rbd: return errors for mapped but deleted snapshot
  (fate#312983).
- rbd: kill num_reply parameters (fate#312983).
- rbd: option symbol renames (fate#312983).
- rbd: more symbol renames (fate#312983).
- rbd: rename some fields in struct rbd_dev (fate#312983).
- rbd: use rbd_dev consistently (fate#312983).
- rbd: dynamically allocate snapshot name (fate#312983).
- rbd: dynamically allocate image name (fate#312983).
- rbd: dynamically allocate image header name (fate#312983).
- rbd: dynamically allocate object prefix (fate#312983).
- rbd: dynamically allocate pool name (fate#312983).
- rbd: create pool_id device attribute (fate#312983).
- rbd: rename rbd_dev->block_name (fate#312983).
- rbd: define dup_token() (fate#312983).
- rbd: drop a useless local variable (fate#312983).
- rbd: endian bug in rbd_req_cb() (fate#312983).
- rbd: Fix ceph_snap_context size calculation (fate#312983).
- commit 45f5fb7
* Thu Aug  8 2013 jbeulich@suse.com
- Refresh patches.xen/xen-netback-generalize (bnc#827378).
- Update Xen patches to 3.0.87.
- commit 1f4d08f
* Wed Aug  7 2013 bpoirier@suse.de
- patches.fixes/mlx4_en-Adding-40gb-speed-report-for-ethtool.patch:
  mlx4_en: Adding 40gb speed report for ethtool (bnc#831410).
- commit 0f738b7
* Tue Aug  6 2013 tiwai@suse.de
- drm/i915: Retry DP aux_ch communications with a different
  clock after failure (bnc#831422).
- drm/i915: split aux_clock_divider logic in a separated function
  for reuse (bnc#831422).
- drm/i915: dp: increase probe retries (bnc#831422).
- drm/i915: Only clear write-domains after a successful wait-seqno
  (bnc#831422).
- drm/i915: Fix write-read race with multiple rings (bnc#831422).
- drm/i915: Retry DP aux_ch communications with a different
  clock after failure (bnc#831422).
- drm/i915: split aux_clock_divider logic in a separated function
  for reuse (bnc#831422).
- drm/i915: dp: increase probe retries (bnc#831422).
- drm/i915: Only clear write-domains after a successful wait-seqno
  (bnc#831422).
- drm/i915: Fix write-read race with multiple rings (bnc#831422).
- commit 4e2b19b
* Tue Aug  6 2013 tiwai@suse.de
- xhci: Add xhci_disable_ports boot option (bnc#822164).
- commit 3e9bc54
* Tue Aug  6 2013 oneukum@suse.de
- xhci: set device to D3Cold on shutdown (bnc#833097).
- commit 8a05a13
* Mon Aug  5 2013 jeffm@suse.com
- Refresh
  patches.fixes/reiserfs-locking-handle-nested-locks-properly:
  Fixed double unlock in reiserfs_setattr failure path.
- commit 6d8c69a
* Mon Aug  5 2013 jeffm@suse.com
- patches.fixes/reiserfs-locking-handle-nested-locks-properly:
  Fixed double unlock in reiserfs_setattr failure path.
- commit 8ffc3bd
* Mon Aug  5 2013 jeffm@suse.com
- Fixed out-of-order application of reiserfs fixes.
- commit 82c691b
* Mon Aug  5 2013 jeffm@suse.com
- reiserfs: locking, release lock around quota operations
  (bnc#815320).
- reiserfs: locking, push write lock out of xattr code
  (bnc#815320).
- reiserfs: locking, handle nested locks properly (bnc#815320).
- reiserfs: don't lock journal_init() (bnc#815320).
- reiserfs: delay reiserfs lock until journal initialization
  (bnc#815320).
- commit 52c058f
* Mon Aug  5 2013 jeffm@suse.com
- patches.fixes/reiserfs-delay-reiserfs-lock-until-journal-initialization:
  reiserfs: delay reiserfs lock until journal initialization
  (bnc#815320).
- patches.fixes/reiserfs-don-t-lock-journal_init: reiserfs:
  don't lock journal_init() (bnc#815320).
- patches.fixes/reiserfs-locking-handle-nested-locks-properly:
  reiserfs: locking, handle nested locks properly (bnc#815320).
- patches.fixes/reiserfs-locking-push-write-lock-out-of-xattr-code:
  reiserfs: locking, push write lock out of xattr code
  (bnc#815320).
- patches.fixes/reiserfs-locking-release-lock-around-quota-operations:
  reiserfs: locking, release lock around quota operations
  (bnc#815320).
- commit 1326dba
* Mon Aug  5 2013 neilb@suse.de
- patches.suse/nfs-no-share-transport: NFS: support
  "nosharetransport" option (bnc#807502, bnc#828192, FATE#315593).
- commit f3124ca
* Sun Aug  4 2013 ohering@suse.de
- HID: hyperv: convert alloc+memcpy to memdup.
- Drivers: hv: vmbus: Implement multi-channel support
  (fate#316098).
- Drivers: hv: Add the GUID fot synthetic fibre channel device
  (fate#316098).
- tools: hv: Check return value of setsockopt call.
- tools: hv: Check return value of poll call.
- tools: hv: Check retrun value of strchr call.
- tools: hv: Fix file descriptor leaks.
- tools: hv: Improve error logging in KVP daemon.
- drivers: hv: switch to use mb() instead of smp_mb().
- drivers: hv: check interrupt mask before read_index.
- drivers: hv: allocate synic structures before hv_synic_init().
- storvsc: Increase the value of scsi timeout for storvsc devices
  (fate#316098).
- storvsc: Update the storage protocol to win8 level
  (fate#316098).
- storvsc: Implement multi-channel support (fate#316098).
- storvsc: Support FC devices (fate#316098).
- storvsc: Increase the value of STORVSC_MAX_IO_REQUESTS
  (fate#316098).
- hyperv: Fix the NETIF_F_SG flag setting in netvsc.
- Drivers: hv: vmbus: incorrect device name is printed when
  child device is unregistered.
- Tools: hv: KVP: Fix a bug in IPV6 subnet enumeration
  (bnc#828714).
- commit 7ad6a7b
* Fri Aug  2 2013 jbohac@suse.cz
- patches.fixes/ipv6-ip6_append_data_mtu-did-not-care-about-pmtudisc.patch:
  ipv6: ip6_append_data_mtu did not care about pmtudisc and
  frag_size (bnc#831055, CVE-2013-4163).
- commit 88ac12c
* Fri Aug  2 2013 jbohac@suse.cz
- ipv6: ip6_append_data_mtu did not care about pmtudisc and
  frag_size (bnc#831055, CVE-2013-4163).
- commit cb4b06f
* Fri Aug  2 2013 mhocko@suse.cz
- patches.fixes/include-linux-smp.h-define-__smp_call_function_singl.patch:
  Refresh to fix ia64 compile failure
- commit 334fa1e
* Fri Aug  2 2013 hare@suse.de
- patches.fixes/dm-mpath-add-retain_attached_hw_handler-feature.patch:
  Fixup typo.
- commit f64fa61
* Fri Aug  2 2013 mhocko@suse.cz
- patches.fixes/include-linux-smp.h-define-__smp_call_function_singl.patch:
  Refresh.
- commit d468ff2
* Fri Aug  2 2013 hare@suse.de
- patches.fixes/dm-mpath-add-retain_attached_hw_handler-feature.patch:
  dm mpath: add retain_attached_hw_handler feature (bnc#760407).
- patches.fixes/scsi_dh-add-scsi_dh_attached_handler_name.patch:
  scsi_dh: add scsi_dh_attached_handler_name (bnc#760407).
- commit 0ebc91a
* Thu Aug  1 2013 jeffm@suse.com
- patches.fixes/af_key-fix-info-leaks-in-notify-messages: af_key:
  fix info leaks in notify messages (bnc#827749 CVE-2013-2234).
- patches.fixes/af_key-initialize-satype-in-key_notify_policy_flush:
  af_key: initialize satype in key_notify_policy_flush()
  (bnc#828119 CVE-2013-2237).
- commit 71b609c
* Thu Aug  1 2013 jeffm@suse.com
- af_key: fix info leaks in notify messages (bnc#827749
  CVE-2013-2234).
- af_key: initialize satype in key_notify_policy_flush()
  (bnc#828119 CVE-2013-2237).
- commit c723f6a
* Thu Aug  1 2013 jbohac@suse.cz
- patches.fixes/ipv6-call-udp_push_pending_frames-when-uncorking.patch:
  ipv6: call udp_push_pending_frames when uncorking a socket with
  (bnc#831058, CVE-2013-4162).
- commit 324ac0b
* Thu Aug  1 2013 jbohac@suse.cz
- ipv6: call udp_push_pending_frames when uncorking a socket with
  (bnc#831058, CVE-2013-4162).
- commit c9869be
* Thu Aug  1 2013 jeffm@suse.de
- tg3: fix length overflow in VPD firmware parsing (bnc#813733
  CVE-2013-1929).
- commit 6fa0504
* Thu Aug  1 2013 jeffm@suse.com
- patches.fixes/tg3-fix-length-overflow-in-vpd-firmware-parsing:
  tg3: fix length overflow in VPD firmware parsing (bnc#813733
  CVE-2013-1929).
- commit 317a7b3
* Thu Aug  1 2013 jbohac@suse.cz
- patches.fixes/ipv6-ip6_sk_dst_check-must-not-assume-ipv6-dst.patch:
  ipv6: ip6_sk_dst_check() must not assume ipv6 dst (bnc#827750,
  CVE-2013-2232).
- commit cab9b16
* Thu Aug  1 2013 jeffm@suse.com
- patches.fixes/xfs-fix-xfs_buf_find-oops-on-blocks-beyond-the-filesystem-end:
  xfs: fix _xfs_buf_find oops on blocks beyond the filesystem end
  (CVE-2013-1819 bnc#807471).
- commit 4beaca3
* Thu Aug  1 2013 jeffm@suse.com
- xfs: fix _xfs_buf_find oops on blocks beyond the filesystem end
  (CVE-2013-1819 bnc#807471).
- commit 1cee98f
* Thu Aug  1 2013 jbohac@suse.cz
- ipv6: ip6_sk_dst_check() must not assume ipv6 dst (bnc#827750,
  CVE-2013-2232).
- commit d6d0221
* Thu Aug  1 2013 mkubecek@suse.cz
- kernel-source.changes: add missing entries
- commit 37c0487
* Wed Jul 31 2013 jjolly@suse.de
- dasd: fix hanging devices after path events (bnc#831623,
  LTC#96336).
- commit 0300f6f
* Wed Jul 31 2013 jjolly@suse.de
- kernel: z90crypt module load crash (bnc#831623, LTC#96214).
- commit 36e38be
* Wed Jul 31 2013 jjolly@suse.de
-  - kabi/severities: Added drivers/s390/crypto/* for upcoming change
  from IBM that changes the kabi on s390 only (bnc#831623)
- commit b7be45c
* Wed Jul 31 2013 jkosina@suse.cz
- ata: Fix DVD not dectected at some platform with Wellsburg PCH
  (bnc#822225).
- commit a2182ef
* Wed Jul 31 2013 tiwai@suse.de
- Update patch-mainline tags in patches.drivers/alsa-*
- commit 0622164
* Wed Jul 31 2013 tiwai@suse.de
- Update git-commit and patch-mainline tags in some patches.drm/*
- commit b0add64
* Wed Jul 31 2013 tiwai@suse.de
- drm/i915: edp: add standard modes (bnc#832318).
- commit 1e348a5
* Wed Jul 31 2013 tiwai@suse.de
- Don't switch camera on yet more HP machines (bnc#822164).
- commit 5966fd2
* Tue Jul 30 2013 tiwai@suse.de
- Refresh patches.fixes/0001-Don-t-switch-camera-on-HP-EB-820-G1.patch.
  Fix a typo, it's EliteBook, not ProBook.
- commit 3435761
* Tue Jul 30 2013 oneukum@suse.de
- Don't switch camera on HP EB 820 G1 (bnc#822164).
- commit f4ebfbf
* Tue Jul 30 2013 oneukum@suse.de
- xhci: Avoid NULL pointer deref when host dies (bnc#827271).
- commit aaa6a5f
* Tue Jul 30 2013 mkubecek@suse.cz
- bonding: disallow change of MAC if fail_over_mac enabled
  (bnc#827376).
- bonding: propagate unicast lists down to slaves (bnc#773255 bnc#827372).
- net/bonding: emit address change event also in bond_release
  (bnc#773255 bnc#827372).
- bonding: emit event when bonding changes MAC (bnc#773255
  bnc#827372).
- commit ba50c02
* Mon Jul 29 2013 oneukum@suse.de
- usb: host: xhci: Enable XHCI_SPURIOUS_SUCCESS for all
  controllers with xhci 1.0 (bnc#797909).
- commit 3267090
* Mon Jul 29 2013 oneukum@suse.de
- xhci: fix null pointer dereference on
  ring_doorbell_for_active_rings (bnc#827271).
- commit 058dca3
* Mon Jul 29 2013 meissner@suse.de
- updated reference for security issue fixed inside (CVE-2013-3301 bnc#815256)
- commit 7bafa46
* Mon Jul 29 2013 hare@suse.de
- qla2xxx: Clear the MBX_INTR_WAIT flag when the mailbox time-out
  happens (bnc#830478).
- commit 0741c2a
* Fri Jul 26 2013 tiwai@suse.de
- drm/i915: initialize gt_lock early with other spin locks
  (bnc#801341).
- drm/i915: fix up gt init sequence fallout (bnc#801341).
- drm/i915: initialize gt_lock early with other spin locks
  (bnc#801341).
- drm/i915: fix up gt init sequence fallout (bnc#801341).
- commit 5ca56f4
* Fri Jul 26 2013 mgalbraith@suse.de
- timer_list: Correct the iterator for timer_list (bnc#818047).
- commit a169258
* Fri Jul 26 2013 tiwai@suse.de
- firmware: don't spew errors in normal boot (bnc#831438,
  fate#314574).
- commit 04e6623
* Fri Jul 26 2013 tiwai@suse.de
- ALSA: virtuoso: Xonar DSX support (FATE#316016).
- commit c3948c3
* Thu Jul 25 2013 neilb@suse.de
- patches.fixes/SUNRPC-Ensure-we-release-the-socket-write-lock-if-th.patch:
  SUNRPC: Ensure we release the socket write lock if the rpc_task
  exits early (bnc#830901).
- commit 5e1819c
* Wed Jul 24 2013 jeffm@suse.com
- patches.suse/ext4-rw-unsupported.patch: Re-add config option
  Building ext4 as the ext4-writeable KMP uses CONFIG_EXT4_FS_RW=y
  to denote that read-write module should be enabled. This update
  just defaults allow_rw to true if it's set.
- commit b78ad6b
* Wed Jul 24 2013 bpoirier@suse.de
- Correct series order for
  patches.drivers/e1000-fix-vlan-processing-regression.patch
- commit 20b7781
* Wed Jul 24 2013 bpoirier@suse.de
- e1000: fix vlan processing regression (bnc#830766).
- commit af515a1
* Wed Jul 24 2013 jeffm@suse.com
- patches.suse/ext4-rw-unsupported.patch: ext4: force read-only
  unless rw=1 module option is used (fate#314864).
- commit a44f0fd
* Tue Jul 23 2013 bp@suse.de
- Refresh patches.fixes/rtc-add-an-alarm-disable-quirk.patch.
- commit e991b87
* Tue Jul 23 2013 jack@suse.cz
- rpm/kernel-binary.spec.in: Remove obsolete ext4-writeable. Needs to be
  handled differently. (bnc#830822)
- commit 2f2a441
* Tue Jul 23 2013 jeffm@suse.com
- Revert "rpm/kernel-binary.spec.in: Add obsolete rpm directive for ext4_writeable KMP"
  This reverts commit 41f780d42fc10e5f40b51d88cd64a98bb8c56dac.
  The complete ext4 code is present in the kernel, but needs to
  be enabled with the allow_unsupported=1 module option. Otherwise,
  sites using the ext4-writable module will find their file systems
  will only be read-only after update.
- commit 75ca21f
* Tue Jul 23 2013 jack@suse.cz
- rpm/kernel-binary.spec.in: Add obsolete rpm directive for ext4_writeable KMP
  as now in-kernel ext4 module is used in all cases (bnc#830822)
- commit 41f780d
* Tue Jul 23 2013 hare@suse.de
- dm mpath: fix ioctl deadlock when no paths (bnc#808940).
- commit 1b2627c
* Mon Jul 22 2013 jkosina@suse.cz
- patches.fixes/hid-fix-data-access-in-implement-fix.patch:
  Refresh: fix context.
- commit 050977d
* Mon Jul 22 2013 jkosina@suse.cz
- patches.fixes/hid-fix-data-access-in-implement-fix.patch: HID:
  fix unused rsize usage (bnc#783475).
- commit 6bb7b34
* Mon Jul 22 2013 meissner@suse.de
- add reference for b43 format string flaw (bnc#822579 CVE-2013-2852)
- commit 357f6fe
* Mon Jul 22 2013 jkosina@suse.cz
- patches.fixes/hid-fix-data-access-in-implement.patch: HID:
  fix data access in implement() (bnc#783475).
- commit 232b799
* Mon Jul 22 2013 jack@suse.cz
- patches.fixes/xfs-fix-deadlock-in-xfs_rtfree_extent-with-kernel-v3.x.patch:
  xfs: fix deadlock in xfs_rtfree_extent with kernel v3.x
  (bnc#829622).
- commit e9bde88
* Mon Jul 22 2013 jslaby@suse.cz
- Linux 3.0.87.
- patches.fixes/x86_acer_acpi_ec_call_reg_blacklist.patch:
  Refresh.
- commit 8ebf022
* Fri Jul 19 2013 jjolly@suse.de
- kernel: sclp console hangs (bnc#830346, LTC#95711).
- commit 20d95e2
* Fri Jul 19 2013 bp@suse.de
- Refresh patches.fixes/rtc-add-an-alarm-disable-quirk.patch.
- commit 95c4d80
* Fri Jul 19 2013 msrb@suse.com
- Delete patches.drm/1209-nvc0-fb-shut-up-pmfb-interrupt-after-the-first-occurrence.
  It was removed from series.conf in
  063ed686e5a3cda01a7ddbc49db1499da917fef5 but the file wasn't deleted.
- commit 1d3b91b
* Fri Jul 19 2013 ohering@suse.de
- Drivers: hv: balloon: Do not post pressure status if interrupted
  (bnc#829539).
- Drivers: hv: balloon: Fix a bug in the hot-add code
  (bnc#829539).
- commit 6199b33
* Fri Jul 19 2013 tiwai@suse.de
- drm/i915: Fix incoherence with fence updates on Sandybridge+
  (bnc#809463).
- drm/i915: merge {i965, sandybridge}_write_fence_reg()
  (bnc#809463).
- drm/i915: Fix incoherence with fence updates on Sandybridge+
  (bnc#809463).
- drm/i915: merge {i965, sandybridge}_write_fence_reg()
  (bnc#809463).
- commit fea80a4
* Fri Jul 19 2013 bp@suse.de
- Refresh patches.fixes/rtc-add-an-alarm-disable-quirk.patch.
- commit ab6e923
* Fri Jul 19 2013 mkubecek@suse.cz
- r8169: allow multicast packets on sub-8168f chipset
  (bnc#805371).
- r8169: support new chips of RTL8111F (bnc#805371).
- r8169: define the early size for 8111evl (bnc#805371).
- r8169: fix the reset setting for 8111evl (bnc#805371).
- r8169: add MODULE_FIRMWARE for the firmware of 8111evl
  (bnc#805371).
- r8169: fix sticky accepts packet bits in RxConfig (bnc#805371).
- r8169: adjust the RxConfig settings (bnc#805371).
- r8169: support RTL8111E-VL (bnc#805371).
- r8169: add ERI functions (bnc#805371).
- r8169: modify the flow of the hw reset (bnc#805371).
- r8169: adjust some registers (bnc#805371).
- r8169: check firmware content sooner (bnc#805371).
- r8169: support new firmware format (bnc#805371).
- r8169: explicit firmware format check (bnc#805371).
- r8169: move the firmware down into the device private data
  (bnc#805371).
- r8169: allow multicast packets on sub-8168f chipset
  (bnc#805371).
- r8169: support new chips of RTL8111F (bnc#805371).
- r8169: define the early size for 8111evl (bnc#805371).
- r8169: fix the reset setting for 8111evl (bnc#805371).
- r8169: add MODULE_FIRMWARE for the firmware of 8111evl
  (bnc#805371).
- r8169: fix sticky accepts packet bits in RxConfig (bnc#805371).
- r8169: adjust the RxConfig settings (bnc#805371).
- r8169: support RTL8111E-VL (bnc#805371).
- r8169: add ERI functions (bnc#805371).
- r8169: modify the flow of the hw reset (bnc#805371).
- r8169: adjust some registers (bnc#805371).
- r8169: check firmware content sooner (bnc#805371).
- r8169: support new firmware format (bnc#805371).
- r8169: explicit firmware format check (bnc#805371).
- r8169: move the firmware down into the device private data
  (bnc#805371).
- commit c5156d2
* Fri Jul 19 2013 mhocko@suse.cz
- patches.fixes/mm-link_mem_sections-touch-nmi-watchdog.patch:
  mm: link_mem_sections make sure nmi watchdog doesn't trigger
  while linking memory sections (bnc#820434).
- commit 280d10c
* Fri Jul 19 2013 tiwai@suse.de
- drm/i915: fix long-standing SNB regression in power consumption
  after resume v2 (bnc#801341).
- commit 90833ed
* Thu Jul 18 2013 bp@suse.de
- RTC: Add an alarm disable quirk (bnc#805740).
- commit ff37eda
* Thu Jul 18 2013 tiwai@suse.de
- drm/i915: Fix bogus hotplug warnings at resume (bnc#828087).
- drm/i915: Serialize all register access
  (bnc#809463,bnc#812274,bnc#822878,bnc#828914).
- drm/i915: Resurrect ring kicking for semaphores, selectively
  (bnc#828087).
- drm/i915: Fix bogus hotplug warnings at resume (bnc#828087).
- drm/i915: Serialize all register access
  (bnc#809463,bnc#812274,bnc#822878,bnc#828914).
- drm/i915: Resurrect ring kicking for semaphores, selectively
  (bnc#828087).
- commit 42bac52
* Thu Jul 18 2013 tiwai@suse.de
- drm/i915: use lower aux clock divider on non-ULT HSW
  (bnc#800875).
- drm/i915: preserve the PBC bits of TRANS_CHICKEN2 (bnc#828087).
- drm/i915: set CPT FDI RX polarity bits based on VBT
  (bnc#828087).
- drm/i915: hsw: fix link training for eDP on port-A (bnc#800875).
- drm/i915: use lower aux clock divider on non-ULT HSW
  (bnc#800875).
- drm/i915: preserve the PBC bits of TRANS_CHICKEN2 (bnc#828087).
- drm/i915: set CPT FDI RX polarity bits based on VBT
  (bnc#828087).
- drm/i915: hsw: fix link training for eDP on port-A (bnc#800875).
- commit 3aeb564
* Thu Jul 18 2013 jjolly@suse.de
- patches.arch/s390-66-02-smp-ipi.patch: kernel: lost IPIs on
  CPU hotplug (bnc#825048, LTC#94784).
- commit e7b2aca
* Thu Jul 18 2013 mkubecek@suse.cz
- patches.fixes/iwlwifi-use-correct-supported-firmware-for-6035-and-.patch:
  iwlwifi: use correct supported firmware for 6035 and 6000g2
  (bnc#825887).
- commit a79c159
* Thu Jul 18 2013 mhocko@suse.cz
- patches.fixes/watchdog-update-watchdog_thresh-atomically.patch:
  watchdog: Update watchdog_thresh atomically (bnc#829357).
- patches.fixes/watchdog-update-watchdog_tresh-properly.patch:
  watchdog: update watchdog_tresh properly (bnc#829357).
- patches.fixes/watchdog-make-disable-enable-hotplug-and-preempt-save.patch:
  watchdog-make-disable-enable-hotplug-and-preempt-save.patch
  (bnc#829357).
- commit ca86321
* Wed Jul 17 2013 mmarek@suse.cz
- kabi/severities: Ignore changes in drivers/hv
- commit 534375b
* Wed Jul 17 2013 hare@suse.de
- patches.drivers/lpfc-return-correct-error-code-on-bsg_timeout.patch:
  lpfc: Return correct error code on bsg_timeout (bnc#816043).
- commit c8658e3
* Wed Jul 17 2013 hare@suse.de
- patches.fixes/dm-drop-table-reference-on-ioctl-retry.patch:
  dm-multipath: Drop table when retrying ioctl (bnc#808940).
- commit 63eb32f
* Wed Jul 17 2013 hare@suse.de
- scsi: Do not retry invalid function error (bnc#809122).
- commit c0a03a1
* Wed Jul 17 2013 hare@suse.de
- patches.suse/scsi-do-not-retry-invalid-function-error.patch:
  scsi: Do not retry invalid function error (bnc#809122).
- commit bddb433
* Wed Jul 17 2013 hare@suse.de
- scsi: Always retry internal target error (bnc#745640,
  bnc#825227).
- commit c49940c
* Wed Jul 17 2013 hare@suse.de
- patches.suse/scsi-always-retry-internal-target-error.patch:
  scsi: Always retry internal target error (bnc#745640,
  bnc#825227).
- commit 852c8ec
* Wed Jul 17 2013 eich@suse.com
- patches.drivers/drm-edid-Don-t-print-messages-regarding-stereo-or-csync-by-default.patch:
  Refresh: add upstream commit ID.
- commit 45e0072
* Tue Jul 16 2013 brogers@suse.com
- patches.suse/acpiphp-match-to-Bochs-dmi-data.patch: Refresh.
  (bnc#824915).
- commit 8a22717
* Tue Jul 16 2013 brogers@suse.com
- Refresh patches.suse/acpiphp-match-to-Bochs-dmi-data.patch (bnc#824915).
- commit 427a565
* Tue Jul 16 2013 mmarek@suse.cz
- Update kabi files.
- commit 2b6f039
* Tue Jul 16 2013 jslaby@suse.cz
- Linux 3.0.86 (CVE-2013-1059 CVE-2013-2164 CVE-2013-2851 bnc#822575
  bnc#824295 bnc#826350).
- patches.ceph/0125-libceph-auth-client-NULL-pointer-dereference.patch:
  Delete.
- patches.fixes/block-do-not-pass-disk-names-as-format-strings.patch:
  Delete.
- patches.fixes/cdrom-use-kzalloc-for-failing-hardware: Delete.
- commit 2ff3da5
* Mon Jul 15 2013 jack@suse.cz
- Updated Patch-mainline header.
- commit 8e30f4f
* Mon Jul 15 2013 oneukum@suse.de
- ACPI:remove panic in case hardware has changed after S4
  (bnc#829001).
- commit 9986086
* Mon Jul 15 2013 jslaby@suse.cz
- Linux 3.0.85.
- commit 2c56a69
* Mon Jul 15 2013 hare@suse.de
- patches.drivers/ibmvfc-Driver-version-1.0.11.patch: ibmvfc:
  Driver version 1.0.1 (bnc#825142).
- patches.drivers/ibmvfc-Fix-for-offlining-devices-during-error-recove.patch:
  ibmvfc: Fix for offlining devices during error recovery
  (bnc#825142).
- patches.drivers/ibmvfc-Properly-set-cancel-flags-when-cancelling-abo.patch:
  ibmvfc: Properly set cancel flags when cancelling abort
  (bnc#825142).
- patches.drivers/ibmvfc-Send-cancel-when-link-is-down.patch:
  ibmvfc: Send cancel when link is down (bnc#825142).
- patches.drivers/ibmvfc-Support-FAST_IO_FAIL-in-EH-handlers.patch:
  ibmvfc: Support FAST_IO_FAIL in EH handlers (bnc#825142).
- patches.drivers/ibmvfc-Suppress-ABTS-if-target-gone.patch:
  ibmvfc: Suppress ABTS if target gone (bnc#825142).
- commit 2f1f48f
* Fri Jul 12 2013 mhocko@suse.cz
- patches.fixes/fs-dcache.c-add-cond_resched-to-shrink_dcache_parent.patch:
  fs/dcache.c: add cond_resched() to shrink_dcache_parent()
  (bnc#829082).
- commit e30b534
* Fri Jul 12 2013 jankit@suse.de
- patches.fixes/cdrom-use-kzalloc-for-failing-hardware:
  drivers/cdrom/cdrom.c: use kzalloc() for failing hardware
  (bnc#824295, CVE-2013-2164).
- commit a597aae
* Fri Jul 12 2013 jlee@suse.com
- patches.suse/0001-kmsg_dump-don-t-run-on-non-error-paths-by-default.patch:
  Refresh.
- commit 29182d4
* Thu Jul 11 2013 jlee@suse.com
- patches.suse/0001-kmsg_dump-don-t-run-on-non-error-paths-by-default.patch:
  kmsg_dump: don't run on non-error paths by default (bnc#820172).
- commit ae3b8d8
* Wed Jul 10 2013 jeffm@suse.com
- btrfs: update Git-commit and Patch-mainline tags
- commit 5d2983e
* Wed Jul 10 2013 hare@suse.de
- supported.conf: mark tcm_qla2xxx as supported
- commit f09978a
* Wed Jul 10 2013 mhocko@suse.cz
- patches.fixes/mm-honor-min_free_kbytes-set-by-user.patch: mm:
  honor min_free_kbytes set by user (bnc#826960).
- commit 9a9a255
* Tue Jul  9 2013 ohering@suse.de
- Drivers: hv: util: Fix a bug in version negotiation code for
  util services (bnc#828714).
- commit 096306d
* Tue Jul  9 2013 bpoirier@suse.de
- patches.suse/msft-hv-0406-hyperv-Fix-a-kernel-warning-from-netvsc_linkstatus_c.patch:
  hyperv: Fix a kernel warning from netvsc_linkstatus_callback()
  (bnc#828574).
- commit 971b702
* Tue Jul  9 2013 mgalbraith@suse.de
- Fix up hardening patch to not gripe when avg > available,
  which lockless access makes possible and happens in -rt
  kernels running a cpubound ltp realtime testcase.  Just
  keep the output sane in that case.
- patches.fixes/sched-harden-rq-rt-usage-accounting.patch:
  Refresh.
- commit 4dff3b4
* Mon Jul  8 2013 mmarek@suse.cz
- kabi/severities: Add exception for aer_recover_queue()
  There should not be any user besides ghes.ko.
- commit 5a17892
* Mon Jul  8 2013 mmarek@suse.cz
- Fix rpm changelog
- commit d18910a
* Sun Jul  7 2013 tiwai@suse.de
- PCI / PM: restore the original behavior of pci_set_power_state()
  (bnc#827930).
- commit e7b248e
* Fri Jul  5 2013 mszeredi@suse.cz
- fanotify: info leak in copy_event_to_user() (CVE-2013-2148
  bnc#823517).
- commit 953bfa0
* Fri Jul  5 2013 oneukum@suse.de
- usb: xhci: check usb2 port capabilities before adding hw link
  PM support (bnc#828265).
- commit 3fc7227
* Thu Jul  4 2013 trenn@suse.de
- aerdrv: Move cper_print_aer() call out of interrupt context
  (bnc#822052, bnc#824568).
- PCI/AER: pci_get_domain_bus_and_slot() call missing required
  pci_dev_put() (bnc#822052, bnc#824568).
- commit 4768974
* Wed Jul  3 2013 jack@suse.cz
- patches.fixes/block-do-not-pass-disk-names-as-format-strings.patch:
  block: do not pass disk names as format strings (bnc#822575
  CVE-2013-2851).
- commit bb7454f
* Wed Jul  3 2013 duwe@suse.de
- powerpc: POWER8 cputable entries (bnc#824256).
- commit d20e3c4
* Tue Jul  2 2013 rw@suse.de
- patches.ceph/0125-libceph-auth-client-NULL-pointer-dereference.patch:
  libceph: Fix NULL pointer dereference in auth client code.
  (CVE-2013-1059, bnc#826350)
- commit b742357
* Tue Jul  2 2013 neilb@suse.de
- patches.fixes/md-raid10-reshape-bugs: Fix two bug affecting
  RAID10 reshape.
- commit b479fed
* Tue Jul  2 2013 neilb@suse.de
- patches.fixes/nfs-execute-only-files: Allow NFSv4 to run
  execute-only files (bnc#765523).
- commit f93c281
* Mon Jul  1 2013 rgoldwyn@suse.de
- patches.fixes/ocfs2-remove-unnecssary-error-while-rm-non-empty-dirs.patch:
  fs/ocfs2/namei.c: remove unecessary ERROR when removing
  non-empty directory (bnc#819363).
- commit 3fccdd6
* Mon Jul  1 2013 jack@suse.cz
- patches.fixes/block-queue-depth-3.diff: block: Reserve only one
  queue tag for sync IO if only 3 tags are available (bnc#806396).
- commit 7514518
* Mon Jul  1 2013 dsterba@suse.cz
- patches.suse/btrfs-0510-merge-contigous-regions-when-loading-free-spac.patch:
  Btrfs: merge contigous regions when loading free space cache
  (FATE#312888).
- patches.suse/btrfs-0512-fix-how-we-deal-with-the-orphan-block-rsv.patch:
  Btrfs: fix how we deal with the orphan block rsv (FATE#312888).
- patches.suse/btrfs-0589-fix-wrong-check-during-log-recovery.patch:
  Btrfs: fix wrong check during log recovery (FATE#312888).
- patches.suse/btrfs-0615-change-how-we-indicate-we-re-adding-csums.patch:
  Btrfs: change how we indicate we're adding csums (FATE#312888).
- patches.suse/btrfs-0768-delay-block-group-item-insertion.patch:
  Refresh.
- patches.suse/btrfs-0769-remove-bytes-argument-from-do_chunk_alloc.patch:
  Refresh.
- patches.suse/btrfs-0796-run-delayed-refs-first-when-out-of-space.patch:
  Refresh.
- patches.suse/btrfs-0804-don-t-commit-instead-of-overcommitting.patch:
  Refresh.
- patches.suse/btrfs-0954-don-t-take-inode-delalloc-mutex-if-we-re-a-fre.patch:
  Refresh.
- patches.suse/btrfs-1092-use-reserved-space-for-creating-a-snapshot.patch:
  Refresh.
- patches.suse/btrfs-1107-cleanup-to-make-the-function-btrfs_delalloc_re.patch:
  Refresh.
- patches.suse/btrfs-1136-fix-space-leak-when-we-fail-to-reserve-metadat.patch:
  Refresh.
- patches.suse/btrfs-1137-fix-space-accounting-for-unlink-and-rename.patch:
  Refresh.
- patches.suse/btrfs-8235-simplify-unlink-reservations.patch:
  Refresh.
- commit 13aa84d
* Mon Jul  1 2013 jbeulich@suse.com
- Refresh a few Xen patches, namely patches.xen/xen-x86-EFI.
- commit 5e9061a
* Fri Jun 28 2013 mgorman@suse.de
- mm: vmscan: Do not continue scanning if reclaim was aborted for compaction
  (Limit reclaim in the preserve of IO (bnc#754690)).
- commit d824927
* Fri Jun 28 2013 jslaby@suse.cz
- Linux 3.0.84.
- commit ea40b02
* Fri Jun 28 2013 jslaby@suse.cz
- Linux 3.0.83.
- commit 9f68939
* Thu Jun 27 2013 jlee@suse.com
- x86, efi: retry ExitBootServices() on failure (bnc#823386).
- x86/efi: Fix dummy variable buffer allocation (bnc#822080).
- commit 3935df2
* Thu Jun 27 2013 jjolly@suse.de
- [BZ 94825] af_iucv: Missing man page (bnc#825037, LTC#94825).
- commit 6c94f86
* Thu Jun 27 2013 jjolly@suse.de
- kernel: lost IPIs on CPU hotplug (bnc#825037, LTC#94784).
- commit ed54629
* Thu Jun 27 2013 jjolly@suse.de
- dasd: Add missing descriptions for dasd timeout messages
  (bnc#825037, LTC#94762).
- commit 2468532
* Thu Jun 27 2013 jjolly@suse.de
- dasd: Fix hanging device after resume with internal error 13
  (bnc#825037, LTC#94554).
- commit 97311b2
* Thu Jun 27 2013 jjolly@suse.de
- cio: Suppress 2nd path verification during resume (bnc#825037,
  LTC#94554).
- commit 0584c34
* Thu Jun 27 2013 jjolly@suse.de
- vmcp: Missing man page (bnc#825037, LTC#94453).
- commit db0b3bf
* Thu Jun 27 2013 jjolly@suse.de
- kernel: 3215 console crash (bnc#825037, LTC#94302).
- commit 535156a
* Thu Jun 27 2013 jjolly@suse.de
- iucv: fix kernel panic at reboot (bnc#825037, LTC#93803).
- commit ff12d43
* Wed Jun 26 2013 jdelvare@suse.de
- patches.drivers/drm-i915-add-wait_for-in-init_ring_common:
  drm/i915: Add wait_for in init_ring_common (bnc#813604).
- patches.drivers/drm-i915-mark-the-ringbuffers-as-being-in-the-gtt-domain:
  drm/i915: Mark the ringbuffers as being in the GTT domain
  (bnc#813604).
- commit 92c21de
* Wed Jun 26 2013 jack@suse.cz
- patches.fixes/ext4-avoid-hang-when-mounting-non-journal-filesystem.patch:
  ext4: avoid hang when mounting non-journal filesystems with
  orphan list (bnc#817377).
- commit 7cdf308
* Wed Jun 26 2013 mmarek@suse.cz
- Move kabi fixes to patches.kabi:
  patches.kabi/mm-compaction-scan-pfn-caching-KABI-fix.patch
  patches.kabi/mm-compaction-scan-pfn-caching-KABI.patch
  patches.kabi/mm-mmu_notifier-have-mmu_notifiers-use-a-global-SRCU-so-they-may-safely-schedule-kabi.patch
  patches.kabi/netfilter-kABI-fix-after-making-event-callback-regis.patch
- commit e0dd6cf
* Tue Jun 25 2013 mgorman@suse.de
- patches.fixes/mm-compaction-scan-pfn-caching-KABI-fix.patch:
  mm: compaction: Scan PFN caching KABI workaround
  (Fix KABI breakage (bnc#825657)).
- commit 25740f8
* Mon Jun 24 2013 mszeredi@suse.cz
- patches.fixes/autofs4-fix-get_next_positive_subdir.patch:
  autofs4 - fix get_next_positive_subdir() (bnc#819523).
- commit 229f92b
* Mon Jun 24 2013 rgoldwyn@suse.de
- patches.fixes/ocfs2-add-bits_wanted-to-ocfs2_calc_extend_credits.patch:
  Add bits_wanted while calculating credits in
  ocfs2_calc_extend_credits (bnc#822077).
- commit d695f08
* Mon Jun 24 2013 jack@suse.cz
- writeback: Avoid needless scanning of b_dirty list (bnc#819018).
- writeback: Do not sort b_io list only because of block device
  inode (bnc#819018).
- commit 264e607
* Fri Jun 21 2013 jdelvare@suse.de
- patches.suse/trace-open.patch: re-enable io tracing (bnc#785901).
- commit bef4f6c
* Fri Jun 21 2013 tiwai@suse.de
- Fix VT1708 jack detection on SLEPOS machines (bnc#813922).
- ALSA: hda - Avoid choose same converter for unused pins
  (bnc#826186).
- ALSA: hda - Cache the MUX selection for generic HDMI
  (bnc#826186).
- ALSA: hda - Haswell converter power state D0 verify
  (bnc#826186).
- commit 812d5dd
* Fri Jun 21 2013 mkubecek@suse.cz
- patches.xen/1230-netback-dont-disconnect-on-oversized-packet.patch:
  Update references (bnc#823342).
- commit 3815ef4
* Thu Jun 20 2013 tiwai@suse.de
- patches.suse/0001-pciehp-Ignore-missing-surprise-bit-on-some-hosts.patch:
  Refresh.  Corrected the old mismatching DMI strings.
- commit 4842f38
* Thu Jun 20 2013 neilb@suse.de
- patches.fixes/SUNRPC-Prevent-an-rpc_task-wakeup-race.patch:
  SUNRPC: Prevent an rpc_task wakeup race (bnc#825591).
- commit ba99fcb
* Wed Jun 19 2013 bpoirier@suse.de
- patches.drivers/tg3-Prevent-system-hang-during-repeated-EEH-errors.patch:
  tg3: Prevent system hang during repeated EEH errors
  (bnc#822066).
- commit 67d28d9
* Wed Jun 19 2013 bpoirier@suse.de
- tg3: Prevent system hang during repeated EEH errors
  (bnc#822066).
- commit e193f48
* Wed Jun 19 2013 hare@suse.de
- scsi_dh_alua: multipath failover fails with error 15
  (bnc#825696).
- commit 2f5cd12
* Tue Jun 18 2013 dsterba@suse.cz
- Refresh patches.suse/btrfs-8235-simplify-unlink-reservations.patch.
- commit 6f82e69
* Tue Jun 18 2013 oneukum@suse.de
- Don't switch camera on HP EB 8780 (bnc#797090).
- commit b97a9d4
* Tue Jun 18 2013 dsterba@suse.cz
- Disable patches.suse/btrfs-8235-simplify-unlink-reservations.patch
- commit 8322220
* Mon Jun 17 2013 dsterba@suse.cz
- Btrfs: simplify unlink reservations (bnc#801427).
- commit 5de0720
* Mon Jun 17 2013 oneukum@suse.de
- Do not switch webcam for HP EB 8580w (bnc#797090).
- commit 47bd885
* Mon Jun 17 2013 dsterba@suse.cz
- patches.suse/btrfs-0409-add-__get_block_group_index-helper.patch:
  Update references (bnc#801427).
- patches.suse/btrfs-0609-flush-delayed-inodes-if-we-re-short-on-space.patch:
  Btrfs: flush delayed inodes if we're short on space
  (bnc#801427).
- patches.suse/btrfs-0621-rework-shrink_delalloc.patch: Btrfs:
  rework shrink_delalloc (bnc#801427).
- patches.suse/btrfs-0759-fix-our-overcommit-math.patch: Btrfs:
  fix our overcommit math (bnc#801427).
- patches.suse/btrfs-0768-delay-block-group-item-insertion.patch:
  Btrfs: delay block group item insertion (bnc#801427).
- patches.suse/btrfs-0769-remove-bytes-argument-from-do_chunk_alloc.patch:
  Btrfs: remove bytes argument from do_chunk_alloc (bnc#801427).
- patches.suse/btrfs-0796-run-delayed-refs-first-when-out-of-space.patch:
  Btrfs: run delayed refs first when out of space (bnc#801427).
- patches.suse/btrfs-0804-don-t-commit-instead-of-overcommitting.patch:
  Btrfs: don't commit instead of overcommitting (bnc#801427).
- patches.suse/btrfs-0954-don-t-take-inode-delalloc-mutex-if-we-re-a-fre.patch:
  Btrfs: don't take inode delalloc mutex if we're a free space
  inode (bnc#801427).
- patches.suse/btrfs-1033-fix-chunk-allocation-error-handling.patch:
  Btrfs: fix chunk allocation error handling (bnc#801427).
- patches.suse/btrfs-1034-remove-extent-mapping-if-we-fail-to-add-chunk.patch:
  Btrfs: remove extent mapping if we fail to add chunk
  (bnc#801427).
- patches.suse/btrfs-1035-do-not-overcommit-if-we-don-t-have-enough-spac.patch:
  Btrfs: do not overcommit if we don't have enough space for
  global rsv (bnc#801427).
- patches.suse/btrfs-1050-rework-the-overcommit-logic-to-be-based-on-the.patch:
  Btrfs: rework the overcommit logic to be based on the total size
  (bnc#801427).
- patches.suse/btrfs-1058-steal-from-global-reserve-if-we-are-cleaning-u.patch:
  Btrfs: steal from global reserve if we are cleaning up orphans
  (bnc#801427).
- patches.suse/btrfs-1091-clear-chunk_alloc-flag-on-retryable-failure.patch:
  clear chunk_alloc flag on retryable failure (bnc#801427).
- patches.suse/btrfs-1092-use-reserved-space-for-creating-a-snapshot.patch:
  Btrfs: use reserved space for creating a snapshot (bnc#801427).
- patches.suse/btrfs-1107-cleanup-to-make-the-function-btrfs_delalloc_re.patch:
  Btrfs: cleanup to make the function
  btrfs_delalloc_reserve_metadata more logic (bnc#801427).
- patches.suse/btrfs-1136-fix-space-leak-when-we-fail-to-reserve-metadat.patch:
  Btrfs: fix space leak when we fail to reserve metadata space
  (bnc#801427).
- patches.suse/btrfs-1137-fix-space-accounting-for-unlink-and-rename.patch:
  Btrfs: fix space accounting for unlink and rename (bnc#801427).
- patches.suse/btrfs-8190-limit-fallocate-extent-reservation-to-256MB.patch:
  Update references (bnc#801427).
- patches.suse/btrfs-8233-allocate-new-chunks-if-the-space-is-not-enough.patch:
  Btrfs: allocate new chunks if the space is not enough for
  global rsv (bnc#801427).
- patches.suse/btrfs-8234-various-abort-cleanups.patch: Btrfs:
  various abort cleanups (bnc#812526 bnc#801427).
- patches.suse/btrfs-8235-simplify-unlink-reservations.patch:
  Btrfs: simplify unlink reservations (bnc#801427).
- patches.suse/btrfs-handle-EIO: Refresh.
- patches.suse/btrfs-8165-remove-bytes-argument-from-do_chunk_alloc.patch:
  Delete.
- commit 66c7db1
* Mon Jun 17 2013 jbeulich@suse.com
- patches.xen/1232-backends-reject-ring-overruns.patch: backends:
  Check for insane amounts of requests on the ring.
- Update Xen patches to 3.0.82.
- commit 6f0f288
* Fri Jun 14 2013 ohering@suse.de
- Drivers: hv: Fix a bug in get_vp_index().
- hyperv: Fix a compiler warning in netvsc_send().
- Tools: hv: Fix a checkpatch warning.
- tools: hv: skip iso9660 mounts in hv_vss_daemon.
- tools: hv: use FIFREEZE/FITHAW in hv_vss_daemon.
- tools: hv: use getmntent in hv_vss_daemon.
- Tools: hv: Fix a checkpatch warning.
- tools: hv: fix checks for origin of netlink message in
  hv_vss_daemon.
- Tools: hv: fix warnings in hv_vss_daemon.
- x86, hyperv: Handle Xen emulation of Hyper-V more gracefully.
- hyperv: Fix a kernel warning from netvsc_linkstatus_callback().
- Drivers: hv: balloon: make local functions static.
- tools: hv: daemon should check type of received Netlink msg.
- tools: hv: daemon setsockopt should use options macros.
- tools: hv: daemon should subscribe only to CN_KVP_IDX group.
- driver: hv: remove cast for kmalloc return value.
- commit 45072bf
* Fri Jun 14 2013 bpoirier@suse.de
- patches.arch/netiucv-Hold-rtnl-between-name-allocation-and-device.patch:
  netiucv: Hold rtnl between name allocation and device
  registration (bnc#824159).
- commit 3a5581b
* Fri Jun 14 2013 bpoirier@suse.de
- Refresh
  patches.arch/netiucv-Hold-rtnl-between-name-allocation-and-device.patch.
- commit d85058d
* Thu Jun 13 2013 jslaby@suse.cz
- Linux 3.0.82.
- commit f208c80
* Thu Jun 13 2013 jslaby@suse.cz
- Linux 3.0.81 (CVE-2013-1774 bnc#806976 bnc#817035 bnc#821052).
- patches.fixes/mm-mmu_notifier-have-mmu_notifiers-use-a-global-SRCU-so-they-may-safely-schedule-kabi.patch:
  Refresh.
- patches.drivers/0001-USB-UHCI-fix-for-suspend-of-virtual-HP-controller.patch:
  Delete.
- patches.drivers/0001-USB-io_ti-Fix-NULL-dereference-in-chase_port.patch:
  Delete.
- patches.fixes/mm-mmu_notifier-re-fix-freed-page-still-mapped-in-se.patch:
  Delete.
- commit f8045aa
* Thu Jun 13 2013 eich@suse.com
- patches.drivers/drm-edid-Don-t-print-messages-regarding-stereo-or-csync-by-default.patch:
  drm/edid: Don't print messages regarding stereo or csync by
  default (bnc #821235).
- commit 03aa511
* Thu Jun 13 2013 msrb@suse.com
- mm: fixup compilation error due to an asm write through a const pointer.
  (bnc#823795)
- commit e9edc05
* Thu Jun 13 2013 bpoirier@suse.de
- netiucv: Hold rtnl between name allocation and device
  registration (bnc#824159).
- commit c051cd3
* Thu Jun 13 2013 jkosina@suse.cz
- Disable ERST pstore by default (bnc#816892).
- commit dcdb2d3
* Thu Jun 13 2013 jkosina@suse.cz
- powerpc: Add isync to copy_and_flush (bnc#823191).
- commit 808b7e1
* Thu Jun 13 2013 oneukum@suse.de
- don't switch cam port on HP EliteBook 840 (bnc#822164).
- commit 40c1f1f
* Thu Jun 13 2013 jbeulich@suse.com
- x86, avx: don't use avx instructions with "noxsave" boot param
  (bnc#821802).
- commit ccab990
* Thu Jun 13 2013 neilb@suse.de
- patches.fixes/net-sunrpc-xpt_auth_cache-should-be-ignored-when-exp.patch:
  net/sunrpc: xpt_auth_cache should be ignored when expired
  (bnc#803320).
- patches.fixes/sunrpc-cache-ensure-items-removed-from-cache-do-not-.patch:
  sunrpc/cache: ensure items removed from cache do not have
  pending upcalls (bnc#803320).
- patches.fixes/sunrpc-cache-remove-races-with-queuing-an-upcall.patch:
  sunrpc/cache: remove races with queuing an upcall (bnc#803320).
- patches.fixes/sunrpc-cache-use-cache_fresh_unlocked-consistently-a.patch:
  sunrpc/cache: use cache_fresh_unlocked consistently and
  correctly (bnc#803320).
- commit d2dc132
* Wed Jun 12 2013 brogers@suse.com
- KVM: x86: emulate movdqa (bnc#821070).
- KVM: x86 emulator: add support for vector alignment
  (bnc#821070).
- KVM: x86 emulator: expand decode flags to 64 bits (bnc#821070).
- commit 4b18acd
* Wed Jun 12 2013 jbeulich@suse.com
- netfront: fix kABI after "reduce gso_max_size to account for
  max TCP header".
- netback: don't disconnect frontend when seeing oversize packet.
- netfront: reduce gso_max_size to account for max TCP header.
- backends: Check for insane amounts of requests on the ring.
- Update Xen patches to 3.0.80.
- commit 4fd6481
* Wed Jun 12 2013 oneukum@suse.de
- xhci - correct comp_mode_recovery_timer on return from hibernate
  (bnc#808136).
- commit b5d9f01
* Tue Jun 11 2013 neilb@suse.de
- patches.fixes/md-raid10-enough-fixes: md/raid10 'enough' fixes
  (bnc#773837).
- commit 9a37056
* Tue Jun 11 2013 neilb@suse.de
- x86, avx: don't use avx instructions with "noxsave" boot param
  (bnc#821802).
- commit b1c5dfb
* Tue Jun 11 2013 neilb@suse.de
- Add another bnc number to a patch
- commit 11275b2
* Mon Jun 10 2013 mgorman@suse.de
- mm: vmscan: take page buffers dirty and locked state into account KABI
  (Limit reclaim in the preserve of IO (bnc#754690)).
- commit 47d2473
* Mon Jun 10 2013 mgorman@suse.de
- mm: vmscan: take page buffers dirty and locked state into account
  (Limit reclaim in the preserve of IO (bnc#754690)).
- commit 4535b7a
* Mon Jun 10 2013 mgorman@suse.de
- mm: vmscan: treat pages marked for immediate reclaim as zone congestion
  (Limit reclaim in the preserve of IO (bnc#754690)).
- commit 0762bda
* Mon Jun 10 2013 mgorman@suse.de
- mm: vmscan: move direct reclaim wait_iff_congested into shrink_list
  (Limit reclaim in the preserve of IO (bnc#754690)).
- commit 9c20c04
* Mon Jun 10 2013 mgorman@suse.de
- mm: vmscan: set zone flags before blocking
  (Limit reclaim in the preserve of IO (bnc#754690)).
- commit f9b010e
* Mon Jun 10 2013 mgorman@suse.de
- mm: vmscan: stall page reclaim after a list of pages have been processed
  (Limit reclaim in the preserve of IO (bnc#754690)).
- commit 7265c8e
* Mon Jun 10 2013 mgorman@suse.de
- mm: vmscan: stall page reclaim and writeback pages based on dirty/writepage pages encountered
  (Limit reclaim in the preserve of IO (bnc#754690)).
- commit df97e07
* Mon Jun 10 2013 mgorman@suse.de
- Refresh
  patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback-fix.patch.
  patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback.patch.
  patches.fixes/mm-vmscan-Check-if-kswapd-should-writepage-once-per-pgdat-scan.patch.
  patches.fixes/mm-vmscan-Decide-whether-to-compact-the-pgdat-based-on-reclaim-progress.patch.
  patches.fixes/mm-vmscan-Do-not-allow-kswapd-to-scan-at-maximum-priority.patch.
  patches.fixes/mm-vmscan-Flatten-kswapd-priority-loop.patch.
  patches.fixes/mm-vmscan-Have-kswapd-writeback-pages-based-on-dirty-pages-encountered-not-priority.patch.
  patches.fixes/mm-vmscan-Limit-the-number-of-pages-kswapd-reclaims-at-each-priority.patch.
  patches.fixes/mm-vmscan-Move-logic-from-balance_pgdat-to-kswapd_shrink_zone.patch.
  patches.fixes/mm-vmscan-Obey-proportional-scanning-requirements-for-kswapd.patch.
- Delete
  patches.fixes/mm-vmscan-Have-kswapd-writeback-pages-based-on-dirty-pages-encountered-not-priority-fix.patch.
- commit b3effa9
* Mon Jun 10 2013 mmarek@suse.cz
- Refresh vanilla config files.
- commit 381cc3e
* Mon Jun 10 2013 jlee@suse.com
- lib/Makefile: Fix oid_registry build dependency (bnc#823223).
- commit 38c6feb
* Sat Jun  8 2013 jlee@suse.com
- Modify UEFI anti-bricking code (bnc#822080).
- commit eb27c4e
* Fri Jun  7 2013 jkosina@suse.cz
- Update config files: disable IP_PNP (bnc#822825)
- commit f93c115
* Thu Jun  6 2013 tiwai@suse.de
- Fix kABI breakage for addition of snd_hda_bus.no_response_fallback (bnc#823597).
- commit a0f3973
* Thu Jun  6 2013 trenn@suse.de
- patches.drivers/pstore_disable_efi_backend_by_default.patch:
  Disable efi pstore by default (bnc#804482 bnc#820172).
- commit bb15ef6
* Thu Jun  6 2013 tiwai@suse.de
- ALSA: hda - Don't take unresponsive D3 transition too serious
  (bnc#823597).
- ALSA: hda - Introduce bit flags to snd_hda_codec_read/write()
  (bnc#823597).
- ALSA: hda - Check CORB overflow (bnc#823597).
- ALSA: hda - Check validity of CORB/RIRB WP reads (bnc#823597).
- commit 1ec7128
* Thu Jun  6 2013 neilb@suse.de
- patches.fixes/md-get-bitmap-file.fix: md: Fix problem with
  GET_BITMAP_FILE returning wrong status (bnc#812974).
- commit 5757bd0
* Wed Jun  5 2013 mhocko@suse.cz
- patches.fixes/mm-pagewalk.c-walk_page_range-should-avoid-VM_PFNMAP.patch:
  mm/pagewalk.c: walk_page_range should avoid VM_PFNMAP areas
  (bnc#822942).
- commit 1dfc2a7
* Wed Jun  5 2013 bpoirier@suse.de
- bnx2x: Fix bridged GSO for 57710/57711 chips (bnc#819610).
- commit 3ea6be0
* Tue Jun  4 2013 eich@suse.com
- drm/i915: force full modeset if the connector is in DPMS OFF
  mode (bnc #809975).
- commit 087284e
* Tue Jun  4 2013 eich@suse.com
- drm/i915/sdvo: Use &intel_sdvo->ddc instead of intel_sdvo->i2c
  for DDC (bnc #808855).
- commit e266efa
* Tue Jun  4 2013 oneukum@suse.de
- patches.drivers/0001-USB-xHCI-override-bogus-bulk-wMaxPacketSize-values.patch:
  USB: xHCI: override bogus bulk wMaxPacketSize values
  (bnc#823082).
- commit f170de1
* Tue Jun  4 2013 acho@suse.com
- patches.drivers/btusb-add-mt76x0e.patch:
  BTUSB: Add MediaTek bluetooth MT76x0E support
  (bnc#797727 bnc#822340).
- commit 81076f2
* Tue Jun  4 2013 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-034-Fix-system-panic-when-DMA-40-bits-for-Nvidi:
  ALSA: hda - Fix system panic when DMA > 40 bits for Nvidia
  audio controllers (bnc#818465).
- commit 4268e57
* Mon Jun  3 2013 bpoirier@suse.de
- qlge: Update version to 1.00.00.32 (bnc#819195).
- qlge: Fix ethtool autoneg advertising (bnc#819195).
- qlge: Fix receive path to drop error frames (bnc#819195).
- qlge: remove NETIF_F_TSO6 flag (bnc#819195).
- remove init of dev->perm_addr in drivers (bnc#819195).
- drivers/net: fix up function prototypes after __dev* removals
  (bnc#819195).
- qlge: remove __dev* attributes (bnc#819195).
- drivers: ethernet: qlogic: qlge_dbg.c: Fixed a coding style
  issue (bnc#819195).
- commit ef4467c
* Mon Jun  3 2013 bpoirier@suse.de
- cxgb4: Force uninitialized state if FW_ON_ADAPTER is <
  FW_VERSION and we're the MASTER_PF (bnc#809130).
- commit 90423d1
* Mon Jun  3 2013 tiwai@suse.de
- ALSA: hda - Add hint for suppressing lower cap for IDT codecs
  (bnc#812332).
- commit e13c62e
* Mon Jun  3 2013 oneukum@suse.de
- patches.drivers/0001-USB-UHCI-fix-for-suspend-of-virtual-HP-controller.patch:
  USB: UHCI: fix for suspend of virtual HP controller
  (bnc#817035).
- commit a0936ce
* Mon Jun  3 2013 mgalbraith@suse.de
- timer_list: Convert timer list to be a proper seq_file
  (bnc#818047).
- timer_list: Split timer_list_show_tickdevices (bnc#818047).
- sched: Fix /proc/sched_debug failure on very very large systems
  (bnc#818047).
- sched: Fix /proc/sched_stat failure on very very large systems
  (bnc#818047).
- commit ef0441f
* Fri May 31 2013 jeffm@suse.com
- patches.fixes/reiserfs-fix-spurious-multiple-fill-in-reiserfs_readdir_dentry:
  reiserfs: fix spurious multiple-fill in reiserfs_readdir_dentry
  (bnc#822722).
- commit f5a0e1f
* Fri May 31 2013 jeffm@suse.com
- reiserfs: fix spurious multiple-fill in reiserfs_readdir_dentry
  (bnc#822722).
- commit d566eae
* Fri May 31 2013 msrb@suse.com
- Revert "drm/mm: fix dump table BUG. (bnc#808837)"
  This reverts commit d9d33304620fd7fbd16bc6b40f22b9eb8d56a0f0.
  Preceding merge brought patches.kernel.org/patch-3.0.78-79 that already
  contains this fix.
- commit 5fc74e1
* Fri May 31 2013 msrb@suse.com
- drm/mm: fix dump table BUG. (bnc#808837)
- commit d9d3330
* Fri May 31 2013 jack@suse.cz
- xfs: Move allocation stack switch up to xfs_bmapi (bnc#815356).
- xfs: introduce XFS_BMAPI_STACK_SWITCH (bnc#815356).
- xfs: zero allocation_args on the kernel stack (bnc#815356).
- xfs: fix debug_object WARN at xfs_alloc_vextent() (bnc#815356).
- xfs: don't defer metadata allocation to the workqueue
  (bnc#815356).
- xfs: introduce an allocation workqueue (bnc#815356).
- commit 5b5dbdf
* Fri May 31 2013 mkubecek@suse.cz
- patches.fixes/SCSI-libfc-don-t-exch_done-on-invalid-sequence-ptr.patch:
  libfc: don't exch_done() on invalid sequence ptr (bnc#810722).
- commit 497d098
* Fri May 31 2013 mmarek@suse.cz
- Update s390x kabi for drivers/s390/char/raw3270 (bnc#792991)
- commit 82ad5ef
* Fri May 31 2013 mmarek@suse.cz
- Use guards to disable ring expansion series
- commit c8b3c0e
* Fri May 31 2013 mkubecek@suse.cz
- patches.fixes/netfilter-ip6t_LOG-fix-logging-of-packet-mark.patch:
  netfilter: ip6t_LOG: fix logging of packet mark (bnc#821930).
- commit bc46991
* Thu May 30 2013 ohering@suse.de
- patches.suse/suse-hv-HV_DRV_VERSION.patch: hyperv: use 3.4 as
  LIC version string (bnc#822431).
- commit 8f3ef0e
* Thu May 30 2013 bpoirier@suse.de
- patches.fixes/virtio_net-introduce-VIRTIO_NET_HDR_F_DATA_VALID.patch:
  virtio_net: introduce VIRTIO_NET_HDR_F_DATA_VALID (bnc#819655).
- commit 73a4a36
* Thu May 30 2013 bpoirier@suse.de
- virtio_net: introduce VIRTIO_NET_HDR_F_DATA_VALID (bnc#819655).
- commit 22d31c6
* Thu May 30 2013 jlee@suse.com
- Revert the backported cc5a080c5 patch and child patches for bnc#822080:
- Refresh
  patches.drivers/0009-x86-efi-Implement-efi_no_storage_paranoia-parameter.patch.
- Refresh
  patches.suse/0008_efi_Enable_secure_boot_lockdown_automatically_when_enabled_in_firmware_v2.patch.
- Delete patches.drivers/0001-x86-efi-Fix-a-build-warning.patch.
- Delete
  patches.drivers/0001-x86-efi-initial-the-local-variable-of-DataSize-to.patch.
- Delete
  patches.drivers/0002-efi-Check-EFI-revision-in-setup_efi_vars.patch.
- Delete
  patches.drivers/0005-efi-Pass-boot-services-variable-info-to-runtime-cod.patch.
- Delete
  patches.drivers/0006-efi-Distinguish-between-remaining-space-and-actua.patch.
- commit 909d02e
* Thu May 30 2013 mhocko@suse.cz
- mm: mmu_notifier: re-fix freed page still mapped in secondary
  MMU (bnc#821052).
- commit ab828dc
* Thu May 30 2013 hare@suse.de
- Refresh patches.fixes/scsi_dh_alua-do-not-attach-to-WLUNs.patch.
- commit e1578a4
* Thu May 30 2013 hare@suse.de
- Update lpfc version for 8.3.7.10.6p driver release (bnc#816065).
- commit 9d06232
* Thu May 30 2013 tonyj@suse.de
- s390/ftrace: fix mcount adjustment (bnc#809895).
- commit 4bbc296
* Wed May 29 2013 oneukum@suse.de
- Revert ring expansion patches
  Some devices don't work reliably with it
  (bnc#816925, bnc#820183)
- commit a17d7cc
* Wed May 29 2013 hare@suse.de
- Update
  patches.drivers/lpfc-revert-Fixed-async-FCF-modified-event.patch.
- commit 59726c9
* Wed May 29 2013 hare@suse.de
- scsi_dh_alua: Do not attach to well-known LUNs (bnc#821980).
- commit 16702d2
* Wed May 29 2013 jslaby@suse.cz
- Linux 3.0.80.
- commit 4ef0cff
* Wed May 29 2013 hare@suse.de
- mtip32xx: Correctly handle bio->bi_idx != 0 conditions
  (FATE#311167,bnc#820569).
- mtip32xx: Fix NULL pointer dereference during module unload
  (FATE#311167,bug#820569).
- commit 45fc94c
* Wed May 29 2013 tiwai@suse.de
- ALSA: hda - Enable mic-mute LED on more HP laptops (bnc#821859).
- commit 267a904
* Wed May 29 2013 tiwai@suse.de
- drm/i915: clear the stolen fb before resuming (bnc#808015).
- drm/i915: Clear the stolen fb before enabling (bnc#808015).
- commit 2d7badb
* Wed May 29 2013 mgorman@suse.de
- HWPOISON: fix misjudgement of page_action() for errors on
  mlocked pages (Memory failure RAS (bnc#821799)).
- HWPOISON: check dirty flag to match against clean page (Memory
  failure RAS (bnc#821799)).
- HWPOISON: change order of error_states[]'s elements (Memory
  failure RAS (bnc#821799)).
- mm: hwpoison: fix action_result() to print out dirty/clean
  (Memory failure RAS (bnc#821799)).
- commit d416706
* Wed May 29 2013 mhocko@suse.cz
- patches.fixes/mm-mmu_notifier-have-mmu_notifiers-use-a-global-SRCU-so-they-may-safely-schedule-kabi.patch:
  Refresh.
- patches.fixes/mm-mmu_notifier-re-fix-freed-page-still-mapped-in-se.patch:
  mm: mmu_notifier: re-fix freed page still mapped in secondary
  MMU (bnc#821052).
- commit decceb9
* Wed May 29 2013 hare@suse.de
- Fix kABI breakage due to
  patches.arch/s390-3270-asynchronous-size-sensing.patch.
- commit 7d27bc7
* Wed May 29 2013 hare@suse.de
- Update patches.arch/s390-3270-asynchronous-size-sensing.patch
  (bnc#792991, LTC#87621).
- commit cbcbdf7
* Wed May 29 2013 hare@suse.de
- lpfc: Revert 'Fixed async FCF modified event to in-use FCF
  ...' (bnc#816065).
- commit 6ac8762
* Tue May 28 2013 jbeulich@suse.com
- patches.xen/1230-netback-dont-disconnect-on-oversized-packet.patch:
  netback: don't disconnect frontend when seeing oversize packet.
- patches.xen/1231-netfront-limit-skblen.patch: netfront: reduce
  gso_max_size to account for max TCP header.
- patches.kabi/1231-netfront-limit-skblen.patch: netfront: fix
  kABI after "reduce gso_max_size to account for max TCP header".
- patches.xen/1167-x86_64-memset.patch: Delete.
- Refresh other Xen patches.
- commit ba2c8a6
* Tue May 28 2013 jack@suse.cz
- xfs: Fix kABI due to change in xfs_buf (bnc#815356).
- commit f85f75e
* Tue May 28 2013 jack@suse.cz
- patches.kabi/xfs-buffer-kabi.patch: xfs: Fix kABI due to change
  in xfs_buf (bnc#815356).
- commit 134ce08
* Tue May 28 2013 jack@suse.cz
- patches.fixes/xfs-fix-race-while-discarding-buffers-V4.patch:
  xfs: fix race while discarding buffers [V4] (bnc#815356
  (comment 36)).
- commit 984b7a3
* Tue May 28 2013 jack@suse.cz
- xfs: fix race while discarding buffers [V4] (bnc#815356
  (comment 36)).
- commit 0e1e374
* Tue May 28 2013 jack@suse.cz
- xfs: Serialize file-extending direct IO (bnc#818371).
- commit 1ddf8a0
* Mon May 27 2013 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit 9ed30ab
* Mon May 27 2013 duwe@suse.de
- kernel: Fix absolute memory access for /dev/mem (bnc#820982,
  LTC#93650).
- commit ae28918
* Mon May 27 2013 bp@suse.de
- tick: Cleanup NOHZ per cpu data on cpu down.
- commit 8a06278
* Mon May 27 2013 bp@suse.de
- Revert "x86, amd: Disable way access filter on Piledriver CPUs"
  it is  duplicated.
- commit 63b7038
* Mon May 27 2013 jack@suse.cz
- patches.fixes/xfs-DIO-i_size-corruption-fix.patch: xfs:
  Serialize file-extending direct IO (bnc#818371).
- commit cf95113
* Mon May 27 2013 mhocko@suse.cz
- timer: Don't reinitialize the cpu base lock during
  CPU_UP_PREPARE (stable update).
- commit 2de079b
* Mon May 27 2013 mhocko@suse.cz
- cgroup: fix an off-by-one bug which may trigger BUG_ON()
  (stable update).
- commit 6f4c7e4
* Mon May 27 2013 mhocko@suse.cz
- s390/memory hotplug: prevent offline of active memory increments
  (stable update).
- commit 4f6a7b7
* Fri May 24 2013 bpoirier@suse.de
- r8169: fix vlan tag read ordering.
- xfrm6: release dev before returning error.
- ipv6: do not clear pinet6 field.
- macvlan: fix passthru mode race between dev removal and rx path.
- 3c59x: fix PCI resource management.
- 3c59x: fix freeing nonexistent resource on driver unload.
- bridge: fix race with topology change timer.
- tcp: force a dst refcount when prequeue packet.
- ath9k: fix key allocation error handling for powersave keys.
- ipvs: ip_vs_sip_fill_param() BUG: bad check of return value.
- wireless: regulatory: fix channel disabling race condition.
- i2c: xiic: must always write 16-bit words to TX_FIFO.
- commit 352c856
* Fri May 24 2013 hare@suse.de
- s390/3270: asynchronous size sensing (bnc#792991).
- s390/3270: introduce device notifier (bnc#792991).
- commit 8a300d8
* Fri May 24 2013 hare@suse.de
- Update lpfc version for 8.3.7.10.5p driver release (bnc#818064).
- lpfc: fix unsafe walking and delete linked list (bnc#818064).
- commit 24b2a0c
* Fri May 24 2013 jdelvare@suse.de
- Delete patches.arch/013-apei_fixes.patch (bnc#816403)
  This patch was causing random I/O memory corruption.
- commit 0bfa066
* Fri May 24 2013 hare@suse.de
- patches.fixes/iscsi-target-fix-heap-buffer-overflow-on-error.patch:
  iscsi-target: fix heap buffer overflow on error (CVE-2013-2850,
  bnc#821560).
  Conflicts:
  series.conf
- patches.fixes/iscsi-target-fix-heap-buffer-overflow-on-error.patch:
  iscsi-target: fix heap buffer overflow on error (CVE-2013-2850,
  bnc#821560).
- commit 88ebc3b
* Thu May 23 2013 dsterba@suse.cz
- Btrfs: deal with free space cache errors while replaying log
  (FATE#312888 bnc#812526).
- Btrfs: cleanup fs roots if we fail to mount (FATE#312888
  bnc#812526).
- Btrfs: check return value of commit when recovering log
  (FATE#312888 bnc#812526).
- Btrfs: various abort cleanups (FATE#312888 bnc#812526).
- Btrfs: remove almost all of the BUG()'s from tree-log.c
  (FATE#312888 bnc#812526).
- commit 13f8ea3
* Thu May 23 2013 mgorman@suse.de
- Refresh
  patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback-fix-2.patch.
- commit ee1efa5
* Thu May 23 2013 mgorman@suse.de
- mm: vmscan: Block kswapd if it is encountering pages under writeback -fix
- Refresh patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback-fix.patch.
  (Limit reclaim in the preserve of IO (bnc#754690)).
- commit e245c69
* Thu May 23 2013 oneukum@suse.de
- patches.fixes/0001-Do-not-switch-webcams-in-some-HP-ProBooks-to-XHCI.patch:
  Do not switch webcams in some HP ProBooks to XHCI (bnc#805804).
- commit a55df5e
* Thu May 23 2013 brogers@suse.com
- KVM: VMX: fix halt emulation while emulating invalid guest sate.
- commit f897700
* Thu May 23 2013 oneukum@suse.de
- patches.fixes/avoid_ehci_xhci_switch_for_BT_PB430.patch:
  Do not switch BT on HP ProBook 4340 (bnc#812281).
- patches.fixes/0001-References-bnc-812281.patch: Delete.
- commit 4aee29e
* Thu May 23 2013 oneukum@suse.de
- patches.fixes/0001-References-bnc-812281.patch: Do not switch
  BT on HP ProBook 4340 (bnc#812281).
- commit a998ea8
* Wed May 22 2013 bpoirier@suse.de
- bnx2x: Fix GSO for 57710/57711 chips (FATE#313915 bnc#819610).
- commit a96b9dc
* Wed May 22 2013 hare@suse.de
- Fixup compilation issues:
  * patches.drivers/lpfc-fix-unsafe-walking-and-delete-linked-list.patch.
  * patches.fixes/scsi_dh_alua-simplify-state-update.patch.
- commit 6ebdef3
* Wed May 22 2013 hare@suse.de
- lpfc: fix unsafe walking and delete linked list (bnc#818064).
- commit 958b1b8
* Wed May 22 2013 mgorman@suse.de
- mm: vmscan: Have kswapd writeback pages based on dirty pages encountered, not priority -fix
  (Limit reclaim in the preserve of IO (bnc#754690)).
- commit 9f87b7b
* Wed May 22 2013 hare@suse.de
- scsi_dh_alua: simplify state update (bnc#708296).
- commit 9be31dc
* Wed May 22 2013 trenn@suse.de
- Revert Haswell family 0x45 extra idle mwait support.
  Better wait with this one for Intel approval and submit it after GM if
  suitable.
- commit a93b929
* Wed May 22 2013 hare@suse.de
- qla2xxx: Fix for locking issue between driver ISR and mailbox
  routines (bnc#820738).
- commit eb2032f
* Tue May 21 2013 tonyj@suse.de
- patches.arch/s390-ftrace-fix-mcount-adjustment.patch:
  s390/ftrace: fix mcount adjustment (bnc#809895).
- commit 989a8fc
* Tue May 21 2013 trenn@suse.de
- intel_idle: initial C8, C9, C10 support (bnc#820948).
- commit be9d48b
* Tue May 21 2013 jslaby@suse.cz
- patches.kernel.org/Revert-x86-amd-Disable-way-access-filter-on-Piledriv.patch:
  Revert "x86, amd: Disable way access filter on Piledriver CPUs"
  it is duplicated.
- commit fee9a7f
* Tue May 21 2013 mhocko@suse.cz
- patches.fixes/memory_dev_init-do-not-soft-lockup.patch: mm:
  memory_dev_init make sure nmi watchdog doesn't trigger while
  registering memory sections (bnc#804609, bnc#820434).
- commit 03169a1
* Tue May 21 2013 mgorman@suse.de
- patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback.patch.
- patches.fixes/mm-vmscan-Check-if-kswapd-should-writepage-once-per-pgdat-scan.patch.
- patches.fixes/mm-vmscan-Decide-whether-to-compact-the-pgdat-based-on-reclaim-progress.patch.
- patches.fixes/mm-vmscan-Do-not-allow-kswapd-to-scan-at-maximum-priority.patch.
- patches.fixes/mm-vmscan-Flatten-kswapd-priority-loop.patch.
- patches.fixes/mm-vmscan-Have-kswapd-writeback-pages-based-on-dirty-pages-encountered-not-priority.patch.
- patches.fixes/mm-vmscan-Limit-the-number-of-pages-kswapd-reclaims-at-each-priority.patch.
- patches.fixes/mm-vmscan-Move-logic-from-balance_pgdat-to-kswapd_shrink_zone.patch.
- patches.fixes/mm-vmscan-Obey-proportional-scanning-requirements-for-kswapd.patch.
- mm: vmscan: Block kswapd if it is encountering pages under writeback -fix
  (Limit reclaim in the preserve of IO (bnc#754690)).
- commit 24a102f
* Mon May 20 2013 jslaby@suse.cz
- Linux 3.0.79.
- patches.xen/xen3-patch-2.6.36: Refresh.
- commit 19d164d
* Mon May 20 2013 jslaby@suse.cz
- Linux 3.0.78.
- patches.fixes/x86-kexec-temporary-hack-v2: Refresh.
- commit 5002560
* Mon May 20 2013 jslaby@suse.cz
- Linux 3.0.77.
- patches.arch/ia64-page-migration: Refresh.
- patches.drivers/0001-usb-storage-CY7C68300A-chips-do-not-support-Cypress-.patch:
  Delete.
- patches.rpmify/revert-can-sja1000-fix-handling-on-dt-properties-on-.patch:
  Delete.
- patches.rpmify/s390-move-dummy-io_remap_pfn_range-to-asm-pgtable.h.patch:
  Delete.
- commit a64eaef
* Mon May 20 2013 jack@suse.cz
- patches.fixes/xfs-backward-alloc-fix.diff: xfs: Avoid
  pathological backwards allocation (bnc#805945).
- commit 0928dcc
* Fri May 17 2013 jdelvare@suse.de
- Disable patches.arch/013-apei_fixes.patch for now
- commit ac01046
* Fri May 17 2013 hare@suse.de
- ibmvfc: Fix for offlining devices during error recovery
  (bnc#810098).
- commit 8d631b6
* Fri May 17 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Avoid duplicates in the certifiate list.
- commit 6066daa
* Fri May 17 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do an exit 0 at the end of each scriptlet
  (bnc#809617).
- commit 347e31b
* Fri May 17 2013 mgorman@suse.de
- patches.fixes/mm-compaction-Restart-compaction-from-near-where-it-left-off.patch:
  mm: compaction: Restart compaction from near where it left off
- patches.fixes/mm-compaction-cache-if-a-pageblock-was-scanned-and-no-pages-were-isolated.patch:
  mm: compaction: cache if a pageblock was scanned and no pages were isolated
- patches.fixes/mm-compaction-clear-PG_migrate_skip-based-on-compaction-and-reclaim-activity.patch:
  mm: compaction: clear PG_migrate_skip based on compaction and reclaim activity
- patches.fixes/mm-compaction-scan-pfn-caching-KABI.patch:
  mm: compaction: Scan PFN caching KABI workaround
- patches.fixes/mm-page-allocat-remove-thp-guard.patch:
  mm: page_allocator: Remove first_pass guard
- patches.fixes/mm-vmscan-do-not-stall-on-writeback-during-memory-compaction.patch:
  mm: vmscan: do not stall on writeback during memory compaction
  Cache compaction restart points for faster compaction cycles (bnc#816451)
- commit cac8d98
* Thu May 16 2013 bpoirier@suse.de
- qlge: fix dma map leak when the last chunk is not allocated
  (bnc#819519).
- commit 135f7ad
* Thu May 16 2013 bpoirier@suse.de
- patches.drivers/qlge-fix-dma-map-leak-when-the-last-chunk-is-not-all.patch:
  qlge: fix dma map leak when the last chunk is not allocated
  (bnc#819519).
- commit df8b377
* Thu May 16 2013 hare@suse.de
- scsi_dh_alua: Do not attach to RAID or enclosure devices
  (bnc#819979).
- commit e59baef
* Thu May 16 2013 neilb@suse.de
- Move patches from patches.kernel.org to patches.fixes
  I guess I misunderstood the implication of kernel.org
- commit a20949c
* Thu May 16 2013 neilb@suse.de
- patches.kernel.org/0002-SUNRPC-Get-rid-of-the-redundant-xprt-shutdown-bit-fi.patch:
  SUNRPC: Get rid of the redundant xprt->shutdown bit field
  (bnc#800907).
- patches.kernel.org/0007-SUNRPC-Ensure-that-we-grab-the-XPRT_LOCK-before-call.patch:
  SUNRPC: Ensure that we grab the XPRT_LOCK before calling
  xprt_alloc_slot (bnc#800907).
- patches.kernel.org/0008-SUNRPC-Fix-a-UDP-transport-regression.patch:
  SUNRPC: Fix a UDP transport regression (bnc#800907).
- patches.kernel.org/0009-SUNRPC-Allow-caller-of-rpc_sleep_on-to-select-priori.patch:
  SUNRPC: Allow caller of rpc_sleep_on() to select priority levels
  (bnc#800907).
- patches.kernel.org/0010-SUNRPC-Replace-xprt-resend-and-xprt-sending-with-a-p.patch:
  SUNRPC: Replace xprt->resend and xprt->sending with a priority
  queue (bnc#800907).
- patches.kernel.org/0011-SUNRPC-Fix-potential-races-in-xprt_lock_write_next.patch:
  SUNRPC: Fix potential races in xprt_lock_write_next()
  (bnc#800907).
- commit fd7fbf6
* Wed May 15 2013 mgorman@suse.de
- x86/mm: account for PGDIR_SIZE alignment
  Fix boot problem on HP platform (bnc#816971).
- commit ed5529e
* Wed May 15 2013 tiwai@suse.de
- drm/i915: don't intel_crt_init on any ULT machines (bnc#810210).
- commit 8bf71c3
* Wed May 15 2013 jkosina@suse.cz
- patches.fixes/perf-treat-attr.config-as-u64-in-perf_swevent_init.patch:
  Delete, obsoleted by 3.0.75 stable update.
- commit 96c987e
* Wed May 15 2013 jkosina@suse.cz
- patches.fixes/perf-treat-attr.config-as-u64-in-perf_swevent_init.patch:
  perf: Treat attr.config as u64 in perf_swevent_init()
  (bnc#819789, CVE-2013-2094).
- commit 5e244d7
* Tue May 14 2013 lduncan@suse.de
- qla4xxx: v5.03.00.06.11.3-k0 (FATE#313902 bnc#818154).
- iscsi class, qla4xxx: fix sess/conn refcounting when find fns
  are used (FATE#313902 bnc#818154).
- qla4xxx: Fix iocb_cnt calculation in qla4xxx_send_mbox_iocb()
  (FATE#313902 bnc#818154).
- commit 779e0ad
* Tue May 14 2013 trenn@suse.de
- megaraid_sas: Fix kdump for MFI based controllers (bnc#809220).
- commit 0d352fc
* Tue May 14 2013 eich@suse.de
- drm/i915: unreference default context on module unload.
- commit e0c6758
* Tue May 14 2013 neilb@suse.de
- patches.fixes/md-cannot-re-add-disks-after-recovery.patch:
  md: cannot re-add disks after recovery (bnc#808647).
- commit a10374f
* Mon May 13 2013 bpoirier@suse.de
- cxgb4: fix error recovery when t4_fw_hello returns a positive
  value (bnc#818497).
- commit 404c8de
* Mon May 13 2013 jack@suse.cz
- patches.fixes/xattr-getxattr-improve-handling-of-allocation-f.patch:
  fs/xattr.c:getxattr(): improve handling of allocation failures
  (bnc#818053).
- patches.fixes/xattr-listxattr-fall-back-to-vmalloc-if-kmalloc.patch:
  fs/xattr.c:listxattr(): fall back to vmalloc() if kmalloc()
  failed (bnc#818053).
- patches.fixes/xattr-setxattr-improve-handling-of-allocation-f.patch:
  fs/xattr.c:setxattr(): improve handling of allocation failures
  (bnc#818053).
- patches.fixes/xattr-suppress-page-allocation-failure-warnings.patch:
  fs/xattr.c: suppress page allocation failure warnings from
  sys_listxattr() (bnc#818053).
- commit 15d250d
* Sat May 11 2013 jankit@suse.de
- patches.fixes/virtio-blk-call-revalidate_disk-upon-online-disk-resize:
  virtio-blk: Call revalidate_disk() upon online disk resize
  (bnc#817339).
- commit fafc38d
* Fri May 10 2013 jankit@suse.de
- virtio-blk: Call revalidate_disk() upon online disk resize
  (bnc#817339).
- commit 7abfcf3
* Fri May 10 2013 mmarek@suse.cz
- rpm/kernel-source.spec.in: Fix the certificate name in the preamble
- commit 11479d8
* Fri May 10 2013 mmarek@suse.cz
- rpm/SLES-UEFI-SIGN-Certificate-2048.crt: New SLES signing certificate
  (uses 2048bit key)
- commit ceca61e
* Fri May 10 2013 oneukum@suse.de
- patches.drivers/0001-usb-storage-CY7C68300A-chips-do-not-support-Cypress-.patch:
  usb-storage: CY7C68300A chips do not support Cypress ATACB
  (bnc#819295).
- commit 58f28d1
* Fri May 10 2013 oneukum@suse.de
- xhci - clarify compliance mode debug messages (bnc#819302).
- commit 78222cf
* Fri May 10 2013 oneukum@suse.de
- usb-storage: CY7C68300A chips do not support Cypress ATACB
  (bnc#819295).
- commit 00ec318
* Fri May 10 2013 jankit@suse.de
- libata: forbid port runtime pm by default, fixing regression
  (bnc#813357).
- commit 4f8e168
* Fri May 10 2013 hare@suse.de
- sd: avoid deadlocks when running under multipath (bnc#818545).
- commit e13ab22
* Thu May  9 2013 brogers@suse.com
- KVM: x86: Increase the "hard" max VCPU limit (bnc#819243).
- commit 79472f5
* Thu May  9 2013 dsterba@suse.cz
- powerpc: Fix atomic_xxx_return barrier semantics (bnc#806935).
- commit 6014580
* Thu May  9 2013 mhocko@suse.cz
- Compile fix for CONFIG_DEBUG_VM
  patches.suse/mm-memcg-print-statistics-from-live-counters.patch.
- commit 30d564c
* Thu May  9 2013 mhocko@suse.cz
- memcg, oom: provide more precise dump info while memcg oom
  happening (memcg enhancements).
- memcg: rename MEM_CGROUP_STAT_SWAPOUT as MEM_CGROUP_STAT_SWAP
  (memcg cleanups).
- mm: memcg: print statistics from live counters (memcg cleanups).
- kabi: hide mem_cgroup_zone_nr_lru_pages from kabi checker
  (memcg cleanups).
- memcg: consolidate memory cgroup lru stat functions (memcg
  cleanups).
- mm: memcg: group swapped-out statistics counter logically
  (memcg cleanups).
- mm: memcg: print statistics directly to seq_file (memcg
  cleanups).
- commit b709b42
* Thu May  9 2013 ohering@suse.de
- hyperv: Fix RNDIS send_completion code path.
- commit 652c95e
* Thu May  9 2013 mkubecek@suse.cz
- patches.kernel.org/patch-3.0.60-61: Update references
  (add bnc#810580).
- commit 56c1215
* Wed May  8 2013 ohering@suse.de
- add upstream git-commit tag to various hyper-v patches
- commit e0acef3
* Wed May  8 2013 ohering@suse.de
- add upstream git-commit tag:
  patches.suse/suse-hv-fate314663-0001-mm-Export-split_page.patch.
  patches.suse/suse-hv-fate314663-0001-mm-extend-memory-hotplug-API-to-allow-memory-hotplug.patch.
- commit 3b971c0
* Wed May  8 2013 jack@suse.cz
- Updated upstream references in patches.
- commit 177db68
* Wed May  8 2013 jjolly@suse.de
- scm_block: Cannot specify optimal parameter for exclusive
  usecase (bnc#817401, LTC#92891).
- commit 6fe8ab6
* Wed May  8 2013 jjolly@suse.de
- zfcp: status read buffers on first adapter open with link down
  (bnc#817401, LTC#92429).
- commit 9d2f4aa
* Wed May  8 2013 jjolly@suse.de
- qeth: Fix missing pointer update (bnc#817401, LTC#92087).
- commit bf59898
* Wed May  8 2013 jjolly@suse.de
- mm: crash after transaction abort due protection exception
  (bnc#817401, LTC#92089).
- commit 039c6cd
* Wed May  8 2013 jlee@suse.com
- iTCO_wdt: Watchdog/GPIO patch for Intel Avoton SoC (bnc#807394).
- commit beacc2e
* Wed May  8 2013 oneukum@suse.de
- patches.drivers/0001-usb-Using-correct-way-to-clear-usb3.0-device-s-remot.patch:
  Refresh.
- commit ce050f1
* Wed May  8 2013 oneukum@suse.de
- patches.drivers/0001-usb-Using-correct-way-to-clear-usb3.0-device-s-remot.patch:
  usb: Using correct way to clear usb3.0 device's remote wakeup
  feature (bnc#818516).
- commit c3fc9e5
* Wed May  8 2013 oneukum@suse.de
- patches.drivers/0001-xhci-Fix-TD-size-for-isochronous-URBs.patch:
  xhci: Fix TD size for isochronous URBs (bnc#818514).
- commit 464b93f
* Wed May  8 2013 hare@suse.de
- Refresh patches.fixes/scsi_dh_alua-move-some-sense-codes.patch.
- commit 4ecf1d0
* Wed May  8 2013 tiwai@suse.de
- Refresh patches.drivers/alsa-sp3-pre-702-Apply-pin-enablement-workaround-to-all-Hasw.
  Fix the build with SP3-base code.
- commit 9916035
* Wed May  8 2013 hare@suse.de
- scsi_dh_alua: move some sense code handling into generic code
  (bnc#813245).
- commit 674fa47
* Wed May  8 2013 tiwai@suse.de
- patches.drivers/alsa-sp3-pre-701-fixup-D3-pin-and-right-channel-mute-on-Hasw:
  ALSA: hda - fixup D3 pin and right channel mute on Haswell
  HDMI audio (bnc#818798).
- patches.drivers/alsa-sp3-pre-702-Apply-pin-enablement-workaround-to-all-Hasw:
  ALSA: hda - Apply pin-enablement workaround to all Haswell
  HDMI codecs (bnc#818798).
- commit d904205
* Tue May  7 2013 eich@suse.com
- drm/mgag200: Add bandwidth and resolution limits (bnc #806990).
- drm/mgag200: Copy fb name string before using it in
  mgag200_fb_create() (bnc #806990).
- drm/mgag200: Fix LUT programming for 16bpp (bnc #806990).
- drm/mgag200: Fix framebuffer pitch calculation (bnc #806990).
- drm/mgag200: Fix logic in mgag200_bo_pin() (bnc #806990).
- drm/mgag200: Fix memleak in error path in mgag200_bo_create()
  (bnc #806990).
- drm/mgag200: Fix memleaks in error path in mgag200_fb_create()
  (bnc #806990).
- drm/mgag200: Free container instead of member in
  mga_user_framebuffer_destroy() (bnc #806990).
- drm/mgag200: In all code paths set index register before
  writing data register (bnc #806990).
- drm/mgag200: Initialized data needed to map fbdev memory
  (bnc #806990).
- drm/mgag200: Make local function mgag200_gem_init_object()
  static (bnc #806990).
- drm/mgag200: Reject modes when hdisplay is no multiple of 8
  (bnc #806990).
- drm/mgag200: Simplify function mgag200_bo_unpin() (bnc #806990).
- drm/mgag200: Simplify function mgag200_ttm_placement()
  (bnc #806990).
- Delete
  patches.drm/DRM-mgag200-Add-bandwidth-and-resolution-limits.patch.
- commit d1cdd9f
* Tue May  7 2013 hare@suse.de
- mtip32xx: Workaround for unaligned writes (bnc#818635).
- mtip32xx: mtip32xx: Disable TRIM support (bnc#818635).
- mtip32xx: fix a smatch warning (bnc#818635).
- mtip32xx: fix two smatch warnings (bnc#818635).
- mtip32xx: Add debugfs entry device_status (bnc#818635).
- mtip32xx: return 0 from pci probe in case of rebuild
  (bnc#818635).
- mtip32xx: recovery from command timeout (bnc#818635).
- mtip32xx: fix error return code in mtip_pci_probe()
  (bnc#818635).
- mtip32xx: add missing GENERIC_HARDIRQS dependency (bnc#818635).
- mtip32xx.c:1726:5: sparse: symbol 'mtip_send_trim' was not
  declared (bnc#818635).
- mtip32xx.c:4029:1: sparse: symbol 'mtip_workq_sdbf0' was not
  declared (bnc#818635).
- mtip32xx: add trim support (bnc#818635).
- mtip32xx: Add workqueue and NUMA support (bnc#818635).
- mtip32xx: fix for crash when the device surprise removed during
  rebuild (bnc#818635).
- mtip32xx: fix for driver hang after a command timeout
  (bnc#818635).
- commit 98c96af
* Tue May  7 2013 hare@suse.de
- scsi_dh_alua: Recheck state on transitioning (bnc#708296).
- scsi_dh_alua: Evaluate state for all port groups (bnc#708296).
- scsi_dh_alua: asynchronous RTPG (bnc#708296).
- scsi_dh_alua: move RTPG to workqueue (bnc#708296).
- scsi_dh_alua: Decode HP EVA array identifier (bnc#708296).
- scsi_dh_alua: Decode EMC Clariion extended inquiry (bnc#708296).
- scsi_dh_alua: parse target device id (bnc#708296).
- scsi_dh_alua: Use separate alua_port_group structure
  (bnc#708296).
- scsi_dh_alua: use local buffer for VPD inquiry (bnc#708296).
- scsi_dh_alua: put sense buffer on stack (bnc#708296).
- scsi_dh_alua: Re-evaluate port group states after STPG
  (bnc#708296).
- scsi_dh_alua: Make stpg synchronous (bnc#708296).
- scsi_dh_alua: Pass buffer as function argument (bnc#708296).
- scsi_dh_alua: use flag for RTPG extended header (bnc#708296).
- commit e8f4da0
* Tue May  7 2013 oneukum@suse.de
- Update config files.
  Set CONFIG_USB_XHCI_HCD_DEBUGGING because there are still many controller bugs coming in
- commit 4bc84ff
* Mon May  6 2013 jack@suse.cz
- patches.fixes/xfs-fallback-to-vmalloc-for-large-buffers-in-xfs_att.patch:
  xfs: fallback to vmalloc for large buffers in
  xfs_attrmulti_attr_get (bnc#818053).
- patches.fixes/xfs-fallback-to-vmalloc-for-large-buffers-in-xfs_attrlist_by_handle:
  xfs: fallback to vmalloc for large buffers in
  xfs_attrlist_by_handle (bnc#818053).
- patches.fixes/xfs-fallback-to-vmalloc-for-large-buffers-in-xfs_compat_attrlist_by_handle:
  xfs: xfs: fallback to vmalloc for large buffers in
  xfs_compat_attrlist_by_handle (bnc#818053).
- commit fc91992
* Mon May  6 2013 oneukum@suse.de
- xHCI: update sg tablesize.
- xHCI: Allocate 2 segments for transfer ring.
- xHCI: check enqueue pointer advance into dequeue seg.
- xhci: Fix hang on back-to-back Set TR Deq Ptr commands.
- xhci: Don't warn on empty ring for suspended devices.
- xHCI: dynamic ring expansion.
- xHCI: set cycle state when allocate rings.
- xHCI: factor out segments allocation and free function.
- xHCI: count free TRBs on transfer ring.
- xHCI: store ring's last segment and segment numbers.
- xHCI: store ring's type.
- commit dd92f67
* Mon May  6 2013 oneukum@suse.de
- patches.drivers/0001-xHCI-store-ring-s-type.patch: xHCI:
  store ring's type.
- patches.drivers/0001-xhci-Fix-hang-on-back-to-back-Set-TR-Deq-Ptr-command.patch:
  xhci: Fix hang on back-to-back Set TR Deq Ptr commands.
- patches.drivers/0002-xHCI-check-enqueue-pointer-advance-into-dequeue-seg.patch:
  xHCI: check enqueue pointer advance into dequeue seg.
- patches.drivers/0002-xHCI-store-ring-s-last-segment-and-segment-numbers.patch:
  xHCI: store ring's last segment and segment numbers.
- patches.drivers/0003-xHCI-Allocate-2-segments-for-transfer-ring.patch:
  xHCI: Allocate 2 segments for transfer ring.
- patches.drivers/0003-xHCI-count-free-TRBs-on-transfer-ring.patch:
  xHCI: count free TRBs on transfer ring.
- patches.drivers/0004-xHCI-factor-out-segments-allocation-and-free-functio.patch:
  xHCI: factor out segments allocation and free function.
- patches.drivers/0004-xHCI-update-sg-tablesize.patch: xHCI:
  update sg tablesize.
- patches.drivers/0005-xHCI-set-cycle-state-when-allocate-rings.patch:
  xHCI: set cycle state when allocate rings.
- patches.drivers/0005-xhci-Reserve-one-command-for-USB3-LPM-disable.patch:
  xhci: Reserve one command for USB3 LPM disable.
- patches.drivers/0006-xHCI-dynamic-ring-expansion.patch: xHCI:
  dynamic ring expansion.
- patches.drivers/0007-xhci-Don-t-warn-on-empty-ring-for-suspended-devices.patch:
  xhci: Don't warn on empty ring for suspended devices.
- commit 829297d
* Mon May  6 2013 jlee@suse.com
- x86, efi: Fix display detection in EFI boot stub (bnc#812176).
- commit 38714f0
* Mon May  6 2013 neilb@suse.de
- patches.fixes/md-raid1-dont-release-reference.patch: md/raid1:
  Don't release reference to device while handling read error
  (bnc#809122, bnc#814719).
- commit 6662ba1
* Fri May  3 2013 jlee@suse.com
- x86, efi: initial the local variable of DataSize to zero
  (fate#314499, fate#314509).
- commit df4013e
* Fri May  3 2013 mmarek@suse.cz
- rpm/mkspec: Stop generating the get_release_number.sh file
  It was only needed for the old KOTD.
- commit 3e0897c
* Fri May  3 2013 mmarek@suse.cz
- rpm/kernel-*.spec.in, rpm/mkspec: Do not force the "<RELEASE>"
  string in specfiles.
- commit ca4b4b1
* Fri May  3 2013 mhocko@suse.cz
- patches.fixes/mm-mmap-check-for-RLIMIT_AS-before-unmapping.patch:
  mm/mmap: check for RLIMIT_AS before unmapping (bnc#818327).
- commit 46629c6
* Fri May  3 2013 jack@suse.cz
- patches.suse/mm-Fix-add_page_wait_queue-to-work-for-locked.patch:
  Fix add_page_wait_queue() to work for PG_Locked bit waiters
  (bnc#792584).
- commit 6eb41ea
* Fri May  3 2013 mkubecek@suse.cz
- patches.fixes/bonding-only-use-primary-address-for-ARP.patch:
  bonding: only use primary address for ARP (bnc#815444).
- patches.fixes/bonding-remove-entries-for-master_ip-and-vlan_ip-and.patch:
  bonding: remove entries for master_ip and vlan_ip and query
  devices instead (bnc#815444).
- commit 19d3605
* Thu May  2 2013 jslaby@suse.cz
- Linux 3.0.76 (CVE-2013-0160 bnc#797175 bnc#815745).
- patches.kabi/kabi-undo-cred_to_ucred-change.patch: kABI:
  undo cred_to_ucred change.
- patches.arch/s390-35-07-af_iucv-over-hsi: Refresh.
- patches.arch/s390-45-01-af_iucv-remove-iucv-path.patch: Refresh.
- patches.arch/s390-50-01-af_iucv-netdev-event.patch: Refresh.
- patches.fixes/af_unix-do-not-pack-creds-for-dying-process:
  Refresh.
- patches.kabi/revert-rtnetlink-Fix-problem-with-buffer-allocation.patch:
  Refresh.
- patches.kabi/revert-rtnetlink-fix-rtnl_calcit-and-rtnl_dump_ifinf.patch:
  Refresh.
- patches.kabi/revert-tcp-call-tcp_replace_ts_recent-from-tcp_ack.patch:
  Revert "tcp: call tcp_replace_ts_recent() from tcp_ack()".
- patches.fixes/TTY-do-not-update-atime-mtime-on-read-write.patch:
  Delete.
- patches.fixes/TTY-fix-atime-mtime-regression.patch: Delete.
- commit b159555
* Thu May  2 2013 mmarek@suse.cz
- rpm/kernel-spec-macros: Properly handle KOTD release numbers with
  .g<commit> suffix
- commit 9d677c1
* Thu May  2 2013 mmarek@suse.cz
- rpm/kernel-spec-macros: Drop the %%release_num macro
  We no longer put the -rcX tag into the release string.
- commit 7e1cd98
* Thu May  2 2013 jslaby@suse.cz
- Linux 3.0.75 (bnc#806980 bnc#816443 CVE-2013-1796 CVE-2013-1797
  CVE-2013-1798).
- patches.rpmify/revert-can-sja1000-fix-handling-on-dt-properties-on-.patch:
  Revert "can: sja1000: fix handling on dt properties on little
  endian systems".
- patches.rpmify/s390-move-dummy-io_remap_pfn_range-to-asm-pgtable.h.patch:
  s390: move dummy io_remap_pfn_range() to asm/pgtable.h.
- patches.arch/kvm-introduce-kvm_read_guest_cached.patch: Refresh.
- patches.suse/btrfs-8120-return-error-of-btrfs_update_inode-to-caller.patch:
  Refresh.
- patches.arch/kvm-convert-msr_kvm_system_time-to-use-gfn_to_hva_cache_init.patch:
  Delete.
- patches.arch/kvm-fix-bounds-checking-in-ioapic-indirect-register-read.patch:
  Delete.
- patches.arch/kvm-fix-for-buffer-overflow-in-handling-of-msr_kvm_system_time.patch:
  Delete.
- patches.kernel.org/0011-Revert-sysfs-fix-race-between-readdir-and-lseek.patch:
  Delete.
- patches.suse/Revert-8021q-fix-a-potential-use-after-free.patch:
  Delete.
- commit 0efd08b
* Thu May  2 2013 mchang@suse.com
- fix disordered pstore patch series
  the pstore_info is defined in
  patches.drivers/apei_pstore_mainline_010.patch which is needed by
  patches.arch/001-efi_pstore_fixes.patch, but the order they applied in
  series.conf are causing build error when people doing git-bisect.
  fix by moving apei_pstore_mainline backport patches before
  001-efi_pstore_fixes.patch.
- commit 7753942
* Thu May  2 2013 mhocko@suse.cz
- patches.suse/mm-speedup-in-__early_pfn_to_nid.patch: add git commit
- commit 28b7c89
* Tue Apr 30 2013 jdelvare@suse.de
- Move most PCI patches earlier in series.conf, to help bisectability
- Refresh
  patches.arch/pci_aer_show_successful_recovered_devices.patch.
- Refresh
  patches.arch/x86_PCI-Preserve-existing-pci_bfsort-whitelist-for-Dell-systems.patch.
- Refresh
  patches.drivers/pci-introduce-option-to-disable-ARI.patch.
- Refresh patches.fixes/irq_per_pci_device_msi_irq_listing.patch.
- Refresh
  patches.fixes/kvm-KVM-IOMMU-Disable-device-assignment-without-interrup.patch.
- Refresh
  patches.fixes/pci-Add-flag-indicating-device-has-been-assigned-by-.patch.
- Refresh
  patches.fixes/pci-disable_MPS_configuration_by_default.patch.
- Refresh
  patches.fixes/pci-don-t-crash-when-reading-mpss-from-root-complex.patch.
- Refresh
  patches.fixes/pci-export-pcie_bus_configure_settings-symbol.patch.
- Refresh
  patches.fixes/pci-fix_pointer_dereference_before_call_to_pcie_bus_configure_settings.patch.
- Refresh
  patches.fixes/pci-remove-mrrs-modification-from-mps-setting-code.patch.
- Refresh
  patches.fixes/pci-set-device-power-state-to-PCI_D0.patch.
- Refresh
  patches.fixes/pci-set-pci-e-max-payload-size-on-fabric.patch.
- Refresh patches.fixes/pci_blacklist_usecrs.patch.
- commit 445a952
* Tue Apr 30 2013 tiwai@suse.de
- drm/i915: Needs_dmar, not (bnc#808010,bnc#811054).
- commit be0038f
* Tue Apr 30 2013 bp@suse.de
- x86/iommu/dmar: Remove warning for HPET scope type (bnc#816969).
- commit 9db03cc
* Tue Apr 30 2013 jlee@suse.com
- efi: Check EFI revision in setup_efi_vars (fate#314499,
  fate#314509).
- x86, efi: Fix a build warning (fate#314499, fate#314509).
- commit e2be6d6
* Mon Apr 29 2013 hare@suse.de
- Reshuffle patches to allow bisecting
- commit 2756d15
* Mon Apr 29 2013 jslaby@suse.cz
- patches.fixes/TTY-fix-atime-mtime-regression.patch: TTY:
  fix atime/mtime regression (bnc#815745).
- commit cf9260a
* Sat Apr 27 2013 lduncan@suse.de
- patches.drivers/sd_dif-problem-with-verify-of-type-1-protection-information:
  sd_dif: problem with verify of type 1 protection information
  (PI) (bnc#817010).
- commit 8b2261d
* Fri Apr 26 2013 mmarek@suse.cz
- Import RC1 kabi files.
- commit 73af6c9
* Fri Apr 26 2013 lduncan@suse.com
- sd_dif: problem with verify of type 1 protection information
  (PI) (bnc#817010).
- commit 38d95dd
* Fri Apr 26 2013 mgorman@suse.de
- mm: vmscan: Move logic from balance_pgdat() to
  kswapd_shrink_zone() (Limit reclaim in the preserve of IO
  (bnc#754690)).
- mm: vmscan: Check if kswapd should writepage once per pgdat scan
  (Limit reclaim in the preserve of IO (bnc#754690)).
- mm: vmscan: Block kswapd if it is encountering pages under
  writeback (Limit reclaim in the preserve of IO (bnc#754690)).
- mm: vmscan: Have kswapd writeback pages based on dirty pages
  encountered, not priority (Limit reclaim in the preserve of IO
  (bnc#754690)).
- mm: vmscan: Do not allow kswapd to scan at maximum priority
  (Limit reclaim in the preserve of IO (bnc#754690)).
- mm: vmscan: Decide whether to compact the pgdat based on reclaim
  progress (Limit reclaim in the preserve of IO (bnc#754690)).
- mm: vmscan: Flatten kswapd priority loop (Limit reclaim in
  the preserve of IO (bnc#754690)).
- mm: vmscan: Obey proportional scanning requirements for kswapd
  (Limit reclaim in the preserve of IO (bnc#754690)).
- mm: vmscan: Limit the number of pages kswapd reclaims at each
  priority (Limit reclaim in the preserve of IO (bnc#754690)).
- vmscan: add block plug for page reclaim (Limit reclaim in the
  preserve of IO (bnc#754690)).
- mm: use up free swap space before reaching OOM kill (Limit
  reclaim in the preserve of IO (bnc#754690)).
- mm/vmscan: store "priority" in struct scan_control (Limit
  reclaim in the preserve of IO (bnc#754690)).
- commit 16b5746
* Fri Apr 26 2013 mgalbraith@suse.de
- patches.fixes/sched-harden-rq-rt-usage-accounting.patch:
  Sched: harden rq rt usage accounting (bnc#769685, bnc#788590).
- commit 8921c9d
* Thu Apr 25 2013 bpoirier@suse.de
- Refresh configs
- commit 76e7128
* Thu Apr 25 2013 bpoirier@suse.de
- sfc: Select PTP_1588_CLOCK (fate#314848).
- drivers/net/ethernet/sfc/ptp.c: adjust duplicate test
  (bnc#786035 FATE#314299).
- sfc: Fix naming of MTD partitions for FPGA bitfiles (bnc#786035
  FATE#314299).
- Refresh
  patches.drivers/ptp-enable-clock-drivers-along-with-associated-net-p.patch.
- Refresh
  patches.drivers/sfc-0140-sfc-Add-support-for-IEEE-1588-PTP.patch.
- commit fe2fe45
* Thu Apr 25 2013 bpoirier@suse.de
- sfc: Work-around flush timeout when flushes have completed
  (bnc#786035 FATE#314299).
- sfc: Really disable flow control while flushing (bnc#786035
  FATE#314299).
- commit 9d3c517
* Thu Apr 25 2013 bp@suse.de
- x86, uv, uv3: Trim MMR register definitions after code changes
  for  SGI UV3 (bnc#810627).
- x86, uv, uv3: Check current gru hub support for SGI UV3
  (bnc#810627).
- x86, uv, uv3: Update Time Support for SGI UV3 (bnc#810627).
- x86, uv, uv3: Update x2apic Support for SGI UV3 (bnc#810627).
- x86, uv, uv3: Update Hub Info for SGI UV3 (bnc#810627).
- x86, uv, uv3: Update ACPI Check to include SGI UV3 (bnc#810627).
- x86, uv, uv3: Update MMR register definitions for SGI
  Ultraviolet  System 3 (UV3) (bnc#810627).
- commit 2af8e5c
* Thu Apr 25 2013 mgorman@suse.de
- mm: swap: Mark swap pages writeback before queueing for direct
  IO (Swap over NFS (fate#304949)).
- swap: redirty page if page write fails on swap file (Swap over
  NFS (fate#304949)).
- commit 04d656d
* Thu Apr 25 2013 jslaby@suse.cz
- disable patches.fixes/TTY-do-not-update-atime-mtime-on-read-write.patch
  as it breaks 'w' utility (bnc#797175). Waiting for upstream
  opinion.
- commit 5503e13
* Thu Apr 25 2013 mgorman@suse.de
- Refresh patches.suse/revert-tytsos-random-changes.
- commit dedee95
* Thu Apr 25 2013 hare@suse.de
- block: fix discard merging limits (bnc#813643).
- commit 50b0ac9
* Thu Apr 25 2013 hare@suse.de
- scsi: Handle MLQUEUE busy response in scsi_send_eh_cmnd
  (bnc#816121).
- commit d68049f
* Thu Apr 25 2013 hare@suse.de
- ibmvfc: Driver version 1.0.11 (bug#812224).
- ibmvfc: Suppress ABTS if target gone (bug#812224).
- ibmvfc: Send cancel when link is down (bug#812224).
- ibmvfc: Support FAST_IO_FAIL in EH handlers (bug#812224).
- ibmvfc: Properly set cancel flags when cancelling abort
  (bug#812224).
- commit f96d1c0
* Wed Apr 24 2013 bp@suse.de
- printk: Fix scheduling-while-atomic problem in console_cpu_notify()
  (bnc#809540).
- commit f487074
* Wed Apr 24 2013 jdelvare@suse.de
- patches.kernel.org/revert-dmi_scan-changes-1.patch:
  Revert "dmi_scan: fix missing check for _DMI_ signature in
  smbios_present()".
- patches.kernel.org/revert-dmi_scan-changes-2.patch: Revert
  "drivers/firmware/dmi_scan.c: fetch dmi version from SMBIOS
  if it exists".
- patches.kernel.org/revert-dmi_scan-changes-3.patch: Revert
  "drivers/firmware/dmi_scan.c: check dmi version when get
  system uuid".
- commit 395d734
* Wed Apr 24 2013 mmarek@suse.cz
- rpm/macros.kernel-source: Fix the -c option if -n is not given
- commit 5c14dd0
* Wed Apr 24 2013 jbeulich@suse.com
- Update Xen patches to 3.0.74.
- Update patches.xen/xen-x86-EFI in order to ...
- ... delete patches.xen/xen-x86-EFI-add-stub.patch.
- commit 2003d5a
* Wed Apr 24 2013 hare@suse.de
- be2net: Use GET_PROFILE_CONFIG V1 cmd for BE3-R (bnc#815405).
- be2net: fix re-loaded PF driver to re-gain control of its VFs
  (bnc#815405).
- commit 7bc189f
* Wed Apr 24 2013 hare@suse.de
- lpfc: Update lpfc version for 8.3.7.10.3p driver release.
- lpfc: Fixed not returning FAILED status in SCSI host reset
  (bnc#816788).
- commit d3c6160
* Wed Apr 24 2013 hare@suse.de
- lpfc: Fixed bad book keeping in posting els sgls to port
  (bnc#816788).
- lpfc: Fixed deadlock between hbalock and nlp_lock use
  (bnc#816788).
- lpfc: Fixed crash when processing bsg's sg list with high
  memory pages (bnc#816788).
- lpfc: Fix driver issues with SCSI Host reset (bnc#816788).
- lpfc: Fixed async FCF modified event to in-use FCF failure to
  trigger recovery.
- commit 7053c5b
* Wed Apr 24 2013 mgalbraith@suse.de
- patches.fixes/rcu-Avoid-spurious-RCU-CPU-stall-warnings.patch:
  rcu: Avoid spurious RCU CPU stall warnings (bnc#816586).
- patches.fixes/rcu-Dump-local-stack-if-cannot-dump-all-CPUs-stacks.patch:
  rcu: Dump local stack if cannot dump all CPUs' stacks (bnc#816586).
- patches.fixes/rcu-Fix-detection-of-abruptly-ending-stall.patch:
  rcu: Fix detection of abruptly-ending stall (bnc#816586).
- patches.fixes/rcu-Suppress-NMI-backtraces-when-stall-ends-before-dump.patch:
  rcu: Suppress NMI backtraces when stall ends before dump (bnc#816586).
- commit e552a49
* Tue Apr 23 2013 jlee@suse.com
- x86,efi: Add stub to efi-xen.c (fate#314499, fate#314509).
- commit db85639
* Tue Apr 23 2013 hare@suse.de
- dm-multipath: Drop table when retrying ioctl (bnc#808940).
- commit 5bd01bc
* Mon Apr 22 2013 mhocko@suse.cz
- Refresh patches.suse/mm-speedup-in-__early_pfn_to_nid.patch.
- commit 8e59060
* Mon Apr 22 2013 mhocko@suse.cz
- patches.suse/mm-speedup-in-__early_pfn_to_nid.patch: mm:
  speedup in __early_pfn_to_nid (bnc#810624).
- mm: speedup in __early_pfn_to_nid (bnc#810624).
- commit 0ff930b
* Mon Apr 22 2013 meissner@suse.de
- fix kernel-source.changes mistakes
- commit a7ce00c
* Mon Apr 22 2013 jlee@suse.com
- Update config files.
- Refresh
  add 'CONFIG_UCS2_STRING=y' to following config files:
  config/i386/debug
  config/i386/default
  config/i386/pae
  config/i386/trace
  config/ia64/debug
  config/ia64/default
  config/ia64/trace
  config/x86_64/debug
  config/x86_64/default
  config/x86_64/trace
  config/x86_64/xen
  patches.fixes/0003-crypto-GnuPG-based-MPI-lib-make-files-part-3.patch.
- Refresh
  patches.fixes/0011-X.509-Implement-simple-static-OID-registry.patch.
- Refresh
  patches.suse/0008_efi_Enable_secure_boot_lockdown_automatically_when_enabled_in_firmware_v2.patch.
- Refresh patches.xen/xen-x86-EFI.
- Refresh patches.xen/xen3-auto-xen-kconfig.diff.
- commit 06044e0
* Mon Apr 22 2013 jlee@suse.com
- x86,efi: Implement efi_no_storage_paranoia parameter
  (fate#314499, fate#314509).
- efi: Export efi_query_variable_store() for efivars.ko
  (fate#314499, fate#314509).
- x86/Kconfig: Make EFI select UCS2_STRING (fate#314499,
  fate#314509).
- efi: Distinguish between "remaining space" and actually used
  space (fate#314499, fate#314509).
- efi: Pass boot services variable info to runtime code
  (fate#314499, fate#314509).
- Move utf16 functions to kernel core and rename (fate#314499,
  fate#314509,).
- x86,efi: Check max_size only if it is non-zero (fate#314499,
  fate#314509).
- x86, efivars: firmware bug workarounds should be in platform
  code (fate#314499, fate#314509).
- x86, efi: Set runtime_version to the EFI spec revision
  (fate#314499, fate#314509).
- commit 279a668
* Mon Apr 22 2013 jkosina@suse.cz
- patches.kernel.org/0011-Revert-sysfs-fix-race-between-readdir-and-lseek.patch:
  [PATCH 3.0-stable] Revert "sysfs: fix race between readdir
  and lseek" (bnc#816443).
- commit 342df61
* Mon Apr 22 2013 jkosina@suse.cz
- [PATCH 3.0-stable] Revert "sysfs: fix race between readdir
  and lseek" (bnc#816443).
- commit d484b01
* Mon Apr 22 2013 mkubecek@suse.cz
- Revert "8021q: fix a potential use-after-free".
- commit 10b1a25
* Mon Apr 22 2013 mkubecek@suse.cz
- patches.suse/Revert-8021q-fix-a-potential-use-after-free.patch:
  Revert "8021q: fix a potential use-after-free".
- commit da20808
* Mon Apr 22 2013 jeffm@suse.com
- supported.conf: Added missing deps for pNFS.
- commit e509b50
* Sun Apr 21 2013 jeffm@suse.de
- supported.conf: added pNFS modules (bnc#811085).
- commit 0a87c77
* Fri Apr 19 2013 msrb@suse.com
- Fix DRM mismerges.
- Refresh patches.drm/1822-drm-i915-kick-any-firmware-framebuffers-before-claiming-the-gtt.
- Refresh patches.drm/1874-drm-i915-agp-intel-gtt-prep-work-for-direct-setup.
- Refresh patches.drm/2271-merge-tag-v3-6-rc2-into-drm-intel-next.
- Refresh patches.drm/2328-drm-i915-add-workarounds-directly-to-gen6_render_ring_flush.
- Refresh patches.drm/3029-drm-i915-stop-using-agp-layer-for-gen6.
- commit aa02d6b
* Fri Apr 19 2013 lduncan@suse.de
- qla4xxx: v5.03.00.05.11.3-k0 (FATE#313902 bnc#815913).
- qla4xxx: Assign values using correct datatype (FATE#313902
  bnc#815913).
- qla4xxx: Fix smatch warnings (FATE#313902 bnc#815913).
- qla4xxx: Fix sparse warning for qla4xxx_sysfs_ddb_tgt_create
  (FATE#313902 bnc#815913).
- qla4xxx: Silence gcc warning (FATE#313902 bnc#815913).
- commit 659ba5e
* Fri Apr 19 2013 duwe@suse.de
- ipr: Need to reset adapter after the 6th EEH error (bnc#816120).
- ipr: SATA DVD probing failed with 64bit adapter (bnc#816118).
- commit 4ea7c1a
* Fri Apr 19 2013 jbeulich@suse.com
- Update Xen patches to 3.0.74.
- commit 95326c5
* Fri Apr 19 2013 jjolly@suse.de
- zcrypt: ap bus rescan problem when toggle crypto adapters on/off
  (bnc#815926, LTC#91798).
- commit 561472e
* Thu Apr 18 2013 bpoirier@suse.de
- qlcnic: Bump up the version to 5.1.38 (bnc#804494).
- qlcnic: Clear link status when interface is down (bnc#804494).
- qlcnic: change mdelay to msleep (bnc#804494).
- qlcnic: Log warning message for 83xx adapter in MSI mode
  (bnc#804494).
- qlcnic: Fix configure mailbox interrupt command for 83xx adapter
  (bnc#804494).
- drivers:net: dma_alloc_coherent: use __GFP_ZERO instead of
  memset(, 0) (bnc#804494).
- driver/qlogic: replace ip_fast_csum with csum_replace2
  (bnc#804494).
- drivers:net: Remove dma_alloc_coherent OOM messages
  (bnc#804494).
- commit 52d44da
* Thu Apr 18 2013 jbohac@suse.cz
- keep tick_do_timer_cpu on CPU0 with nohz off (bnc#727639).
- commit 0f67f1d
* Thu Apr 18 2013 eich@suse.com
- DRM/mgag200: Add bandwidth and resolution limits (bnc #806990).
- commit 920b476
* Thu Apr 18 2013 jbohac@suse.cz
- igb: fix PHC stopping on max freq (bnc#814604).
- commit 474daac
* Thu Apr 18 2013 bpoirier@suse.de
- bnx2x: Prevent null pointer dereference in AFEX mode
  (bnc#815661).
- bnx2x: Fix KR2 rapid link flap (bnc#815178).
- commit abcd729
* Thu Apr 18 2013 dsterba@suse.cz
- patches.suse/btrfs-1013-don-t-re-enter-when-allocating-a-chunk.patch:
  Btrfs: don't re-enter when allocating a chunk (FATE#312888).
- patches.suse/btrfs-1019-save-us-a-read_lock.patch: Btrfs:
  save us a read_lock (FATE#312888).
- patches.suse/btrfs-1026-Check-CAP_DAC_READ_SEARCH-for-btrfs_IOC_INO_PA.patch:
  Btrfs: Check CAP_DAC_READ_SEARCH for BTRFS_IOC_INO_PATHS
  (FATE#312888).
- patches.suse/btrfs-1038-remove-unused-fs_info-from-btrfs_decode_error.patch:
  btrfs: remove unused fs_info from btrfs_decode_error()
  (FATE#312888).
- patches.suse/btrfs-1039-handle-null-fs_info-in-btrfs_panic.patch:
  btrfs: handle null fs_info in btrfs_panic() (FATE#312888).
- patches.suse/btrfs-1042-fix-varargs-in-__btrfs_std_error.patch:
  btrfs: fix varargs in __btrfs_std_error (FATE#312888).
- patches.suse/btrfs-1056-fix-the-race-between-bio-and-btrfs_stop_worker.patch:
  Btrfs: fix the race between bio and btrfs_stop_workers
  (FATE#312888).
- patches.suse/btrfs-1097-fix-NULL-pointer-after-aborting-a-transaction.patch:
  Btrfs: fix NULL pointer after aborting a transaction
  (FATE#312888).
- patches.suse/btrfs-8195-fix-infinite-loop-when-we-abort-on-mount.patch:
  Btrfs: fix infinite loop when we abort on mount.
- commit 4f6bbab
* Thu Apr 18 2013 bpoirier@suse.de
- Fix Reference
- commit fc6f9da
* Thu Apr 18 2013 dsterba@suse.cz
- patches.suse/btrfs-8024-workaround-for-cleaner-deadlock.patch: Delete.
- patches.suse/btrfs-8077-stop-defrag-the-files-automatically-when-doin-.patch:
  Refresh.
- patches.suse/btrfs-8094-flush-all-the-dirty-pages-if-try_to_writeback_.patch:
  Refresh.
- patches.suse/btrfs-8095-use-writeback_inodes_sb-_nr-_if_idle.patch:
  Refresh.
- commit ec6129f
* Thu Apr 18 2013 duwe@suse.de
- ppc: Fix audit crash due to save/restore PPR changes
  (bnc#815867).
- commit bef8c20
* Thu Apr 18 2013 duwe@suse.de
- ppc: fix 2 new defects found with further testing of the Power7+
  NX device driver (bnc#814748).
- commit 67d4049
* Thu Apr 18 2013 dsterba@suse.cz
- patches.suse/btrfs-0992-don-t-try-to-notify-udev-about-missing-devices.patch:
  btrfs: don't try to notify udev about missing devices
  (FATE#312888).
- patches.suse/btrfs-1064-add-cancellation-points-to-defrag.patch:
  btrfs: add cancellation points to defrag (FATE#312888).
- patches.suse/btrfs-1072-define-btrfs_MAGIC-as-a-u64-value.patch:
  btrfs: define BTRFS_MAGIC as a u64 value (FATE#312888).
- patches.suse/btrfs-1089-make-sure-NODATACOW-also-gets-NODATASUM-set.patch:
  Btrfs: make sure NODATACOW also gets NODATASUM set
  (FATE#312888).
- patches.suse/btrfs-1110-enforce-min_bytes-parameter-during-extent-allo.patch:
  Btrfs: enforce min_bytes parameter during extent allocation
  (FATE#312888).
- patches.suse/btrfs-1116-build-up-error-handling-for-merge_reloc_roots.patch:
  Btrfs: build up error handling for merge_reloc_roots
  (FATE#312888).
- patches.suse/btrfs-1117-free-all-recorded-tree-blocks-on-error.patch:
  Btrfs: free all recorded tree blocks on error (FATE#312888).
- patches.suse/btrfs-1118-do-not-BUG_ON-in-prepare_to_reloc.patch:
  Btrfs: do not BUG_ON in prepare_to_reloc (FATE#312888).
- patches.suse/btrfs-1119-do-not-BUG_ON-on-aborted-situation.patch:
  Btrfs: do not BUG_ON on aborted situation (FATE#312888).
- patches.suse/btrfs-1130-handle-a-bogus-chunk-tree-nicely.patch:
  Btrfs: handle a bogus chunk tree nicely (FATE#312888).
- patches.suse/btrfs-1143-don-t-drop-path-when-printing-out-tree-errors-.patch:
  Btrfs: don't drop path when printing out tree errors in scrub
  (FATE#312888).
- patches.suse/btrfs-8194-make-subvol-creation-deletion-killable-in-the-.patch:
  btrfs: make subvol creation/deletion killable in the early
  stages.
- patches.suse/btrfs-8204-abort-unlink-trans-in-missed-error-case.patch:
  btrfs: abort unlink trans in missed error case.
- patches.suse/btrfs-8213-fix-reada-debug-code-compilation.patch:
  Btrfs: fix reada debug code compilation.
- patches.suse/btrfs-8214-return-error-when-we-specify-wrong-start-to-de.patch:
  Btrfs: return error when we specify wrong start to defrag.
- patches.suse/btrfs-8215-don-t-force-pages-under-writeback-to-finish-wh.patch:
  Btrfs: don't force pages under writeback to finish when
  aborting.
- commit d4f29b9
* Thu Apr 18 2013 mmarek@suse.cz
- Remove set -x and set +e statements in KMP scripts
- commit f5bb838
* Thu Apr 18 2013 bp@suse.de
- x86, efi: Refactor efi_init() a bit (bnc#812397).
  Only a partial backport removing only the bogus message because it is
  too late for the remaining changes now.
- commit 1f4eb38
* Thu Apr 18 2013 jlee@suse.com
- Refresh
  patches.drivers/0006-efi_pstore-Introducing-workqueue-updating-sysfs.patch.
  Fix build error:
  CC [M]  net/9p/error.o
  drivers/firmware/efivars.c:1697: error: redefinition of
  ‘variable_is_present’
  make[2]: *** [drivers/firmware/efivars.o] Error 1
  make[1]: *** [drivers/firmware] Error 2
  make: *** [drivers] Error 2
  CC [M]  lib/cpu-notifier-error-inject.o
  Because variable_is_present function already merged in
  patches.kernel.org/patch-3.0.71-72.
- commit 5914f48
* Thu Apr 18 2013 jlee@suse.com
- x86, EFI: Calculate the EFI framebuffer size instead of trusting
  the firmware (bnc#812176).
- efifb: Skip DMI checks if the bootloader knows what it's doing
  (bnc#812176).
- X86: Improve GOP detection in the EFI boot stub (bnc#812176).
- commit 98e932b
* Thu Apr 18 2013 brogers@suse.com
- KVM: VMX: Use posted interrupt to deliver virtual interrupt
  (fate#313618).
- KVM: VMX: Add the deliver posted interrupt algorithm
  (fate#313618).
- KVM: Set TMR when programming ioapic entry (fate#313618).
- KVM: Call common update function when ioapic entry changed
  (fate#313618).
- KVM: VMX: Check the posted interrupt capability (fate#313618).
- KVM: VMX: Register a new IPI for posted interrupt (fate#313618).
- KVM: VMX: Enable acknowledge interupt on vmexit (fate#313618).
- KVM: Use eoi to track RTC interrupt delivery status
  (fate#313618).
- KVM: Let ioapic know the irq line status (fate#313618).
- KVM: Force vmexit with virtual interrupt delivery (fate#313618).
- KVM: Add reset/restore rtc_status support (fate#313618).
- KVM: Return destination vcpu on interrupt injection
  (fate#313618).
- KVM: Introduce struct rtc_status (fate#313618).
- KVM: Add vcpu info to ioapic_update_eoi() (fate#313618).
- KVM: Call kvm_apic_match_dest() to check destination vcpu
  (fate#313618).
- KVM: VMX: disable apicv by default (fate#313618).
- commit 7a5ac04
* Thu Apr 18 2013 dsterba@suse.cz
- Btrfs: make sure nbytes are right after log replay.
- Btrfs: don't wait on ordered extents if we have a trans open.
- Btrfs: log ram bytes properly.
- Btrfs: fix bad extent logging.
- btrfs: ignore device open failures in __btrfs_open_devices.
- btrfs: abort unlink trans in missed error case.
- Btrfs: use tree_root to avoid edquot when disabling quota.
- Btrfs: remove some BUG_ONs() when walking backref tree.
- Btrfs: fix tree mod log regression on root split operations.
- Btrfs: fix accessing the root pointer in tree mod log functions.
- Btrfs: fix unlock after free on rewinded tree blocks.
- Btrfs: do not continue if out of memory happens.
- Btrfs: fix confusing edquot happening case.
- Btrfs: fix reada debug code compilation.
- Btrfs: return error when we specify wrong start to defrag.
- Btrfs: don't force pages under writeback to finish when
  aborting.
- Btrfs: clear received_uuid field for new writable snapshots.
- commit adc870f
* Wed Apr 17 2013 duwe@suse.de
- missed one hash -> hash.w change
- commit 6477906
* Wed Apr 17 2013 duwe@suse.de
- patches.suse/revert-some-random-changes: /dev/urandom returning
  EOF: trim down revert to not change kabi. (bnc#789359).
- commit 2510012
* Wed Apr 17 2013 tiwai@suse.de
- patches.drivers/alsa-sp3-pre-695-Yet-another-fix-for-broken-HSW-HDMI-pin:
  Refresh.  Fix the invalid PCI SSID check (bnc#806404)
- commit 1096e07
* Wed Apr 17 2013 mkubecek@suse.cz
- patches.fixes/tun-reserves-space-for-network-in-skb.patch:
  tun: reserves space for network in skb (bnc#803394).
- commit e0913c7
* Wed Apr 17 2013 jslaby@suse.cz
- Linux 3.0.74.
- patches.kabi/revert-x86-mm-Patch-out-arch_flush_lazy_mmu_mode-whe.patch:
  Revert "x86, mm: Patch out arch_flush_lazy_mmu_mode() when
  running on bare metal".
- commit 49c673d
* Wed Apr 17 2013 jslaby@suse.cz
- Linux 3.0.73.
- patches.suse/kdump-x86-remap-allocator: Delete.
- commit 02bd848
* Wed Apr 17 2013 jslaby@suse.cz
- Linux 3.0.72 (CVE-2010-3873 CVE-2011-4131 CVE-2011-4604 CVE-2011-4622
  CVE-2012-1601 CVE-2012-2119 CVE-2012-2137 CVE-2012-4461 CVE-2012-5517
  bnc#651219 bnc#730117 bnc#736149 bnc#738210 bnc#754898 bnc#758243
  bnc#767612 bnc#787821 bnc#789235).
- patches.kabi/kabi-protect-struct-tracer.patch: kABI: protect
  struct tracer.
- patches.arch/005-efi_pstore_fixes.patch: Refresh.
- patches.drivers/0001-add-firmware-update-for-Atheros-0cf3-311f.patch:
  Refresh.
- patches.drivers/0001-enable-Atheros-0cf3-311e-for-firmware-upload.patch:
  Refresh.
- patches.suse/btrfs-0448-fix-block_rsv-and-space_info-lock-ordering.patch:
  Refresh.
- patches.drivers/drm-i915-don-t-set-unpin_work-if-vblank_get-fails:
  Delete.
- patches.fixes/batman-adv-Only-write-requested-number-of-byte-to-us.patch:
  Delete.
- patches.fixes/batman-adv-bat_socket_read-missing-checks.patch:
  Delete.
- patches.fixes/kvm-KVM-Clean-up-error-handling-during-VCPU-creation.patch:
  Delete.
- patches.fixes/kvm-KVM-Ensure-all-vcpus-are-consistent-with-in-kernel-i.patch:
  Delete.
- patches.fixes/kvm-KVM-x86-Prevent-starting-PIT-timers-in-the-absence-o.patch:
  Delete.
- patches.fixes/kvm-invalid-opcode-oops-on-SET_SREGS-with-OSXSAVE-bi.patch:
  Delete.
- patches.fixes/kvm-set-irq.patch: Delete.
- patches.fixes/macvtap-zerocopy-validate-vectors-before-building-sk.patch:
  Delete.
- patches.fixes/mm-hotplug-correctly-add-zone-to-other-nodes-list.patch:
  Delete.
- patches.fixes/nfs-bitmap-fix-fix: Delete.
- patches.fixes/nfs-bitmap-size.fix: Delete.
- patches.fixes/x25-Handle-undersized-fragmented-skbs.patch:
  Delete.
- patches.fixes/x25-Validate-incoming-call-user-data-lengths.patch:
  Delete.
- patches.rpmify/ia64-sa_restorer-fix.patch: Delete.
- commit 0a5a5d8
* Wed Apr 17 2013 jslaby@suse.cz
- Linux 3.0.72 (CVE-2010-3873 CVE-2011-4131 CVE-2011-4604 CVE-2011-4622
  CVE-2012-1601 CVE-2012-2119 CVE-2012-2137 CVE-2012-4461 CVE-2012-5517
  bnc#651219 bnc#730117 bnc#736149 bnc#738210 bnc#754898 bnc#758243
  bnc#767612 bnc#787821 bnc#789235).
- patches.arch/005-efi_pstore_fixes.patch: Refresh.
- patches.drivers/0001-add-firmware-update-for-Atheros-0cf3-311f.patch:
  Refresh.
- patches.drivers/0001-enable-Atheros-0cf3-311e-for-firmware-upload.patch:
  Refresh.
- patches.suse/btrfs-0448-fix-block_rsv-and-space_info-lock-ordering.patch:
  Refresh.
- patches.drivers/drm-i915-don-t-set-unpin_work-if-vblank_get-fails:
  Delete.
- patches.fixes/batman-adv-Only-write-requested-number-of-byte-to-us.patch:
  Delete.
- patches.fixes/batman-adv-bat_socket_read-missing-checks.patch:
  Delete.
- patches.fixes/kvm-KVM-Clean-up-error-handling-during-VCPU-creation.patch:
  Delete.
- patches.fixes/kvm-KVM-Ensure-all-vcpus-are-consistent-with-in-kernel-i.patch:
  Delete.
- patches.fixes/kvm-KVM-x86-Prevent-starting-PIT-timers-in-the-absence-o.patch:
  Delete.
- patches.fixes/kvm-invalid-opcode-oops-on-SET_SREGS-with-OSXSAVE-bi.patch:
  Delete.
- patches.fixes/kvm-set-irq.patch: Delete.
- patches.fixes/macvtap-zerocopy-validate-vectors-before-building-sk.patch:
  Delete.
- patches.fixes/mm-hotplug-correctly-add-zone-to-other-nodes-list.patch:
  Delete.
- patches.fixes/nfs-bitmap-fix-fix: Delete.
- patches.fixes/nfs-bitmap-size.fix: Delete.
- patches.fixes/x25-Handle-undersized-fragmented-skbs.patch:
  Delete.
- patches.fixes/x25-Validate-incoming-call-user-data-lengths.patch:
  Delete.
- patches.rpmify/ia64-sa_restorer-fix.patch: Delete.
- commit c54bdef
* Wed Apr 17 2013 duwe@suse.de
- remove one hunk already included in kABI fixup
- commit a5dfe55
* Wed Apr 17 2013 duwe@suse.de
- patches.suse/revert-tytsos-random-changes: /dev/urandom
  returning EOF (bnc#89359).
- commit 209e1d9
* Wed Apr 17 2013 duwe@suse.de
- fix /dev/urandom sometimes returning EOF on s390x (bnc#89359).
- commit 83c638e
* Tue Apr 16 2013 duwe@suse.de
- Update patches.suse/zcrypt-feed-hwrandom:
  do not crash on rmmod after offlining the hardware
  (bnc#814948).
- commit ae44e46
* Tue Apr 16 2013 bpoirier@suse.de
- PCI: msi: fix imbalanced refcount of msi irq sysfs objects
  (bnc#806674).
- commit 4f9fdfc
* Tue Apr 16 2013 hare@suse.de
- patches.fixes/st-take-additional-queue-ref-in-st_probe.patch:
  Fixup blk_get_queue() (bnc#816533)
- commit 85ee6e7
* Tue Apr 16 2013 jbeulich@suse.com
- agp: iommu_gfx_mapped only available if CONFIG_INTEL_IOMMU
  is set.
- drm/i915: disable ppgtt on snb when dmar is enabled.
- drm/i915: enable semaphores on gen6 if dmar is not active.
- drm/i915: Stop using AGP layer for GEN6+.
- drm/i915: Disable WC PTE updates to w/a buggy IOMMU on ILK
  (bnc#806406).
- Do not allow access to /dev/cpu/microcode in secure boot mode
  (bnc#813166).
- Refresh other Xen patches.
- commit 6cf0c46
* Tue Apr 16 2013 jjolly@suse.de
- zfcp: block queue limits with data router (bnc#813708,
  LTC#91760).
- commit bc41a36
* Tue Apr 16 2013 jjolly@suse.de
- hibernate: Save and restore absolute zero pages (bnc#813708,
  LTC#91615).
- commit 1d987d0
* Tue Apr 16 2013 jjolly@suse.de
- kdump: Add PM notifier for kdump (bnc#813708, LTC#91616).
- commit 1a7bb82
* Tue Apr 16 2013 jjolly@suse.de
- kernel: kernel module cannot be loaded (bnc#813708, LTC#91552).
- commit 4995747
* Mon Apr 15 2013 jjolly@suse.de
- cxgb4: fix SQ allocation when On-Chip SQ is disabled
  (bnc#812812,LTC#90789).
- commit d577113
* Mon Apr 15 2013 tiwai@suse.de
- Update config files.
  Enable CONFIG_SND_HDA_CODEC_CA0132_DSP (bnc#814440,FATE#314291)
- commit 7360740
* Mon Apr 15 2013 tiwai@suse.de
- ALSA: hda/ca0132 - Update latency based on DSP state
  (bnc#814440,FATE#314291).
- ALSA: hda - Introduce get_delay codec PCM ops
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Delay HP amp turnon (bnc#814440,FATE#314291).
- ALSA: hda - Fix abuse of snd_hda_lock_devices() for DSP loader
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Remove extra setting of dsp_state
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Check download state of DSP
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Check if dspload_image succeeded
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Avoid division by zero in dspxfr_one_seg()
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Add missing \n to debug prints
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Fix type of INVALID_CHIP_ADDRESS
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Slight optimization for build with DSP
  (bnc#814440,FATE#314291).
- ALSA: hda - Fix memory leak and error handling in CA0132 DSP
  loader (bnc#814440,FATE#314291).
- ALSA: CA0132: Improve the DSP transfer timeout calculations
  (bnc#814440,FATE#314291).
- ALSA: hda - Set non-snoop for Creative HD-audio controllers
  (bnc#814440,FATE#314291).
- ALSA: hda - Fix misc compile warnings in patch_ca0132.c
  (bnc#814440,FATE#314291).
- ALSA: hda - Add new Kconfig CONFIG_SND_HDA_CODEC_CA0132_DSP
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Make some symbols static
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Fix a wrong comma in snd_printdd() call
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Declare firmware only when really built
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Fix possible invalid DMA channel deallocation
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Fix possible NULL dereference
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Fix another smatch warning
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Fix superfluous unsigned check
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132 - Use snd_hda_set_pin_ctl() helper again
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132: Fix potential init errors and update module
  description (bnc#814440,FATE#314291).
- ALSA: hda/ca0132: Shuffle to group together related code
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132: Code shuffle to group similar functions
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132: Add tuning controls (bnc#814440,FATE#314291).
- ALSA: hda/ca0132: Add unsol handler for DSP and jack detection
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132: Add PCM enhancements (bnc#814440,FATE#314291).
- ALSA: hda/ca0132: Add DSP mixer controls and helpers
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132: Init chip, DSP effects and mixer settings
  (bnc#814440,FATE#314291).
- ALSA: hda/ca0132: Add new definitions and structs for DSP
  (bnc#814440,FATE#314291).
- ALSA: hda - Remove superfluous zero-clear memset in
  patch_ca0132.c (bnc#814440,FATE#314291).
- ALSA: hda - Fix NULL dereference in error path of patch_ca0132.c
  (bnc#814440,FATE#314291).
- ALSA: hda - Remove unnecessary struct hda_stream_format from
  CA0132 (bnc#814440,FATE#314291).
- ALSA: hda - Update chipio functions and DSP write wait timeout
  (bnc#814440,FATE#314291).
- ALSA: hda - Add comments and descriptions to CA0132 functions
  (bnc#814440,FATE#314291).
- ALSA: hda - Update CA0132 codec to load DSP firmware binary
  (bnc#814440,FATE#314291).
- ALSA: hda - Add DSP firmware enums and defs to CA0132 codec
  (bnc#814440,FATE#314291).
- ALSA: hda - Add CA0132 register definitions file
  (bnc#814440,FATE#314291).
- commit 3bbcb95
* Mon Apr 15 2013 trenn@suse.de
- intel_idle: additional Haswell CPU-id (bnc#811928).
- commit b125709
* Mon Apr 15 2013 tiwai@suse.de
- ALSA: hda - Fix handling of VT1708 jack detection (bnc#813922).
- commit 22adc8d
* Mon Apr 15 2013 tiwai@suse.de
- Refresh patches.drivers/alsa-sp3-pre-694-Add-fixup-for-Haswell-to-enable-all-pin.
  Fix the invalid PCI SSID check (bnc#806404)
- commit bacd44b
* Sat Apr 13 2013 lduncan@suse.de
- qla4xxx: v5.03.00.04.11.3-k0 (FATE#313902 bnc#814640).
- qla4xxx: Added print statements to display AENs (FATE#313902
  bnc#814640).
- qla4xxx: Use correct value for max flash node entries
  (FATE#313902 bnc#814640).
- qla4xxx: Restrict logout from boot target session using session
  id (FATE#313902 bnc#814640).
- qla4xxx: Use correct flash ddb offset for ISP40XX (FATE#313902
  bnc#814640).
- commit 9e5f345
* Sat Apr 13 2013 hare@suse.de
- bfa: fix for Brocade FC Direct Attach LUN discovery failure
  (bnc#816037).
- bfa: fix faulty handling of states in lps state machine
  (bnc#816022).
- commit 6484a0f
* Sat Apr 13 2013 hare@suse.de
- cciss: kdump fails on SmartArray P410i (bnc#812740).
- commit c19b980
* Fri Apr 12 2013 mgorman@suse.de
- patches.fixes/mm-make-snapshotting-pages-for-stable-writes-a-per-bio-operation.patch:
  mm: Make snapshotting pages for stable writes a per-bio operation
- patches.suse/fs-knows-MAY_APPEND.diff
  Refresh
  Only enable stable page writes when necessary (bnc#807517).
- commit e6e0d84
* Thu Apr 11 2013 hare@suse.de
- Fix race between starved list processing and device removal
  (bnc#812224).
- commit b513bfe
* Thu Apr 11 2013 hare@suse.de
- libsas: use right function to alloc smp response (bnc#813745).
- commit ee902dc
* Thu Apr 11 2013 hare@suse.de
- libsas: fix handling vacant phy in sas_set_ex_phy()
  (bnc#813472).
- commit 54c11b2
* Wed Apr 10 2013 tiwai@suse.de
- drm/i915: make the panel fitter work on pipes B and C on Haswell
  (bnc#814517).
- commit 080025b
* Wed Apr 10 2013 tiwai@suse.de
- Delete patches.drm/3108-drm-i915-make-the-panel-fitter-work-on-pipes-b-and-c-on-ivb.
  It's already included in stable kernel, so we applied doubly (bnc#814517)
- commit 4a294d8
* Tue Apr  9 2013 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit 0aa67c6
* Tue Apr  9 2013 tiwai@suse.de
- ALSA: hda - Fix no independent HP handling for VIA codecs
  (bnc#813922).
- commit 66f721b
* Tue Apr  9 2013 tiwai@suse.de
- ALSA: hda - Fix VIA volumes in output path (bnc#813922).
- commit 141d301
* Tue Apr  9 2013 tiwai@suse.de
- ALSA: hda - Fix Master volume info for VIA (bnc#813922).
- commit 50e6080
* Mon Apr  8 2013 bpoirier@suse.de
- patches.drivers/ixgbe-Address-fact-that-RSC-was-not-setting-GSO-size.patch:
  Fix bnc#802712
- commit 0b0b28f
* Mon Apr  8 2013 ohering@suse.de
- hv: set guest os id (bnc#814005).
- commit f46f335
* Mon Apr  8 2013 tiwai@suse.de
- patches.suse/SUSE-bootsplash: Refresh.
  Fix build error without CONFIG_BOOTSPLASH
- commit 0ed83bc
* Mon Apr  8 2013 tiwai@suse.de
- patches.suse/SUSE-bootsplash: Refresh.
  Fix bootsplash breakage due to 3.0.67 stable fix (bnc#813963)
- commit 920d61f
* Fri Apr  5 2013 jeffm@suse.com
- Refresh patches.suse/supported-flag-module-taint.
- commit 6a0a4ab
* Fri Apr  5 2013 jeffm@suse.com
- patches.suse/ext4-rw-unsupported.patch: use taint_unsupported() and switch to param_[sg]et_bool instead of open-coding it.
- commit f44a9cd
* Fri Apr  5 2013 jeffm@suse.com
- supported-flag: add taint_unsupported() call.
- commit bfc9ac4
* Fri Apr  5 2013 trenn@suse.de
- FADT: Remove extraneous warning for very large GPE registers
  (bnc#811088).
- commit 3111ef7
* Fri Apr  5 2013 mhocko@suse.cz
- patches.fixes/drivers-base-memory.c-fix-memory_dev_init-long-delay.patch:
  drivers/base/memory.c: fix memory_dev_init() long delay
  (bnc#804609).
- patches.fixes/init-mm-reschedule-when-initialising-large-numbers-of-sections.patch:
  Superseded by by the above patch.
- commit 20bd0c4
* Fri Apr  5 2013 jslaby@suse.cz
- patches.rpmify/mtd-drop-physmap_configure.patch: mtd: drop
  physmap_configure (bnc#809375).
- commit 1ec61f6
* Fri Apr  5 2013 hare@suse.de
- block: makes bio_split support bio without data (bnc#813643).
- commit 3c1aa50
* Thu Apr  4 2013 bpoirier@suse.de
- Correct merge resolution
  The merge of sfc in "f6c30f3 Merge branch 'SLE11-SP2' into SLE11-SP3" favored
  a version of the driver that looks like the one from -stable but, following
  bnc#786035, the driver version in SP3 looks more like the one from v3.8-rc1.
  The little fixups in this commit revert to the latter alternative.
- sfc: Really disable flow control while flushing (bnc#786035
  FATE#314299).
- Refresh
  patches.drivers/sfc-0084-sfc-Add-SR-IOV-back-end-support-for-SFC9000-family.patch.
- commit 7ac0d3d
* Thu Apr  4 2013 dsterba@suse.cz
- btrfs: clean up transaction abort messages.
- btrfs: merge save_error_info helpers into one.
- btrfs: clean snapshots one by one.
- btrfs: make orphan cleanup less verbose.
- btrfs: cover more error codes in btrfs_decode_error.
- Btrfs: creating the subvolume qgroup automatically when
  enabling quota.
- btrfs: make subvol creation/deletion killable in the early
  stages.
- Btrfs: fix infinite loop when we abort on mount.
- Btrfs: compare relevant parts of delayed tree refs.
- Btrfs: kill some BUG_ONs() in the find_parent_nodes().
- Btrfs: fix double free in the iterate_extent_inodes().
- Btrfs: fix error handling in make/read block group.
- Refresh patches.suse/btrfs-8187-enhance-superblock-checks.patch.
- Refresh patches.suse/btrfs-update-message-levels.patch.
- Delete
  patches.suse/btrfs-8059-handle-errors-when-excluding-super-extents.patch.
- Delete
  patches.suse/btrfs-8076-fix-deadlock-when-the-process-of-delayed-refs-.patch.
- Delete
  patches.suse/btrfs-8186-continue-after-abort-during-snapshot-drop.patch.
- Delete patches.suse/btrfs-8189-clean-snapshots-one-by-one.patch.
- Delete
  patches.suse/btrfs-8190-deprecate-subvolrootid-mount-option.patch.
- Delete
  patches.suse/btrfs-8191-cover-more-error-codes-in-btrfs_decode_error.patch.
- Delete
  patches.suse/btrfs-8192-fix-EIO-from-btrfs-send-in-is_extent_unchanged.patch.
- commit 7c259e7
* Thu Apr  4 2013 dsterba@suse.cz
- Btrfs: fix EIO from btrfs send in is_extent_unchanged for
  punched holes (FATE#312888).
- Btrfs: fix space leak when we fail to reserve metadata space
  (FATE#312888).
- Btrfs: fix space accounting for unlink and rename (FATE#312888).
- Btrfs: hold the ordered operations mutex when waiting on
  ordered extents (FATE#312888).
- Btrfs: limit the global reserve to 512mb (FATE#312888).
- Btrfs: fix double free in the btrfs_qgroup_account_ref()
  (FATE#312888).
- Btrfs: fix wrong reservation of csums (FATE#312888).
- Btrfs: fix wrong return value of btrfs_lookup_csum()
  (FATE#312888).
- Btrfs: don't drop path when printing out tree errors in scrub
  (FATE#312888).
- Refresh
  patches.suse/btrfs-8077-stop-defrag-the-files-automatically-when-doin-.patch.
- Delete
  patches.suse/btrfs-8193-fix-space-leak-when-we-fail-to-reserve-metadat.patch.
- Delete
  patches.suse/btrfs-8194-fix-space-accounting-for-unlink-and-rename.patch.
- Delete
  patches.suse/btrfs-8195-hold-the-ordered-operations-mutex-when-waiting.patch.
- Delete
  patches.suse/btrfs-8196-limit-the-global-reserve-to-512mb.patch.
- commit a076a54
* Thu Apr  4 2013 duwe@suse.de
- drivers/crypto/nx: fix init race, alignmasks and GCM bug
  (bnc#812137).
- commit f445dbe
* Thu Apr  4 2013 neilb@suse.de
- Allow NFSv4 to run execute-only files (bnc#765523).
- commit cfb7b13
* Wed Apr  3 2013 trenn@suse.de
- Do not allow access to /dev/cpu/microcode in secure boot mode
  (bnc#813166).
- commit cc46984
* Wed Apr  3 2013 trenn@suse.de
- mark patches.arch/x86_microcode_disable_firmwareload_interface.patch
  with +trenn for now to get firmware loading interface ability for Intel
  microcode again (#813166). If it is clear that we will go this way, I
  will totally remove the patch from the repo.
- commit e13c690
* Wed Apr  3 2013 mmarek@suse.cz
- patches.kernel.org/patch-3.0.70-71: More upstream commit id.
- commit a51da60
* Wed Apr  3 2013 mmarek@suse.cz
- patches.kernel.org/patch-3.0.70-71: Add more upstream commit ids.
- commit 21ebb86
* Wed Apr  3 2013 tiwai@suse.de
- Replace CONFIG_INTEL_IOMMU with CONFIG_DMAR (bnc#808010).
- intel/iommu: force writebuffer-flush quirk on Gen 4 Chipsets
  (bnc#808010).
- iommu/intel: disable DMAR for g4x integrated gfx (bnc#808010).
- intel-iommu: Export a flag indicating that the IOMMU is used
  for iGFX (bnc#808010).
- commit b1faec7
* Tue Apr  2 2013 oneukum@suse.de
- patches.drivers/0001-Bluetooth-btusb-hide-more-usb_submit_urb-errors.patch:
  Bluetooth: btusb: hide more usb_submit_urb errors (bnc#812281).
- commit 47c54f8
* Tue Apr  2 2013 jkosina@suse.cz
- blk: avoid divide-by-zero with zero discard granularity
  (bnc#812935).
- commit 25ae5d2
* Mon Apr  1 2013 hare@suse.de
- be2net: Use new F/W mailbox cmd to manipulate interrupts
  (bnc#805179).
- be2net: enable interrupts in be_probe() (RoCE and other ULPs
  need them) (bnc#805179).
- commit ad6ff17
* Mon Apr  1 2013 hare@suse.de
- Update
  patches.fixes/scsi-fix-device-removal-NULL-pointer-dereference.patch
  (bnc#738284,bnc#812224).
- commit 91db0a3
* Mon Apr  1 2013 hare@suse.de
- Add upstream commit IDs:
- Refresh
  patches.fixes/0004-isci-Adding-documentation-to-API-change-and-fixup-s.patch.
- Refresh
  patches.fixes/0006-isci-dynamic-interrupt-coalescing.patch.
- Refresh patches.fixes/0008-isci-add-version-number.patch.
- Refresh patches.fixes/aacraid-check-scsi_dma_map_return-value.
- Refresh
  patches.fixes/iscsi-Add-Serial-Number-Arithmetic-LT-and-GT-into-i.patch.
- Refresh
  patches.fixes/iscsi-Resolve-iscsi_proto.h-naming-conflicts-with-d.patch.
- Refresh
  patches.fixes/iscsi-Use-struct-scsi_lun-in-iscsi-structs-instead.patch.
- Refresh
  patches.fixes/iscsi-class-fix-link-local-mispelling.patch.
- Refresh patches.fixes/iscsi-class-fix-vlan-configuration.patch.
- Refresh
  patches.fixes/iscsi_ibft-be2iscsi-iscsi_boot-fix-boot-kobj-data.patch.
- Refresh
  patches.fixes/kernel.h-Add-DIV_ROUND_UP_ULL-and-DIV_ROUND_UP_SECT.patch.
- Refresh
  patches.fixes/qla4xxx-fix-data-alignment-and-use-nl-helpers.patch.
- Refresh patches.fixes/scsi-dh-alua-errorneous-tpg_id-check.
- Refresh patches.fixes/scsi_dh_alua-Optimize-stpg-command.patch.
- Refresh
  patches.fixes/scsi_dh_alua-Store-pref-bit-from-RTPG.patch.
- Refresh
  patches.fixes/scsi_dh_alua-backoff-alua-rtpg-retry-linearly-v.patch.
- Refresh
  patches.fixes/scsi_dh_alua-fix-time-interval-for-alua-rtpg-commands.
- Refresh
  patches.fixes/scsi_dh_alua-implement-implied-transition-timeout.patch.
- Refresh patches.fixes/scsi_dh_alua-retry-rtpg-ext-hdr.patch.
- scsi_dh_alua: Inroduce the set_params interface scsi_dh_alua
  handler (bnc#755758).
- commit 2879105
* Sat Mar 30 2013 ohering@suse.de
- Drivers: hv: vmbus: Fix a bug in hv_need_to_signal()
  (bnc#811417).
- commit bb1e3f8
* Sat Mar 30 2013 lduncan@suse.de
- qla4xxx: v5.03.00.03.11.3-k0 (bnc#810194, FATE#313902).
- qla4xxx: Replace dev type macros with generic portal type macros
  (bnc#810194, FATE#313902).
- scsi_transport_iscsi: Declare portal type string macros for
  generic use (bnc#810194, FATE#313902).
- qla4xxx: Add flash node mgmt support (bnc#810194, FATE#313902).
- libiscsi: export function iscsi_switch_str_param (bnc#810194,
  FATE#313902).
- scsi_transport_iscsi: Add flash node mgmt support (bnc#810194,
  FATE#313902).
- qla4xxx: Skip retry of initialize_adapter only for ISP8XXX
  (bnc#810194, FATE#313902).
- qla4xxx: Assign correct CHAP table address to FLT (bnc#810194,
  FATE#313902).
- qla4xxx: Added missing check for ISP83XX in CHAP related
  functions (bnc#810194, FATE#313902).
- qla4xxx: don't free NULL dma pool (bnc#810194, FATE#313902).
- commit 252e9e8
* Sat Mar 30 2013 ohering@suse.de
- Drivers: hv: balloon: Permit Linux to specify hot-add alignment
  requirements (fate#314663).
- commit f6e9f7a
* Fri Mar 29 2013 ohering@suse.de
- Drivers: hv: Add a new driver to support host initiated backup
  (fate#314921).
- commit d530598
* Fri Mar 29 2013 ohering@suse.de
- Update patches.suse/suse-hv-fate314862-synthetic-video.patch.
- move pci ids from hyperv.h to source file to match upstream v3
- commit 6ea42a4
* Fri Mar 29 2013 rgoldwyn@suse.de
- patches.fixes/o2dlm-fix-NULL-pointer-dereference-in-o2dlm_blocking_ast_wrapper:
  o2dlm: fix NULL pointer dereference in o2dlm_blocking_ast_wrapper (bnc#806492)
- commit cc1cfe7
* Fri Mar 29 2013 jjolly@suse.de
- patches.arch/s390-65-01-qeth-fix_wait_for_threads_deadlock.patch:
  qeth: fix qeth_wait_for_threads() deadlock for OSN devices
  (bnc#812315, LTC#90910).
- commit d3540df
* Fri Mar 29 2013 hare@suse.de
- Add missing Git-commit IDs:
- Refresh
  patches.fixes/block-Consolidate-command-flag-and-queue-limit-check.patch.
- Refresh patches.fixes/block-add-blk_queue_dead.patch.
- Refresh patches.fixes/block-add-bsg-helper-library.patch.
- Refresh
  patches.fixes/block-add-missing-blk_queue_dead-checks.patch.
- Refresh
  patches.fixes/block-do-no-artificially-constrain-max_sectors.patch.
- Refresh patches.fixes/block-drop-blk_get_put_queue.patch.
- Refresh
  patches.fixes/block-fix-race-on-request.end_io-invocations.patch.
- Refresh patches.fixes/dcb-Use-ifindex-instead-of-ifname.patch.
- Refresh
  patches.fixes/dcb-add-DCBX-mode-to-event-notifier-attributes.patch.
- Refresh
  patches.fixes/dcb-add-stub-routines-for-not-CONFIG_DCB.patch.
- Refresh patches.fixes/dm-table-set-flush-capability.
- Refresh
  patches.fixes/scsi-dh-rdac-Adding-NetApp-as-a-brand-name-for-rdac.patch.
- Refresh
  patches.fixes/scsi-dh-rdac-associate-hba-and-storage.patch.
- Refresh
  patches.fixes/scsi-edd-Treat-XPRS-host-bus-type-the-same-as.patch.
- Refresh patches.fixes/scsi-fix-the-new-host-byte-settings.patch.
- Refresh
  patches.fixes/scsi-libfc-avoid-exchanges-collision-during-lport.patch.
- Refresh
  patches.fixes/scsi-libfc-improve-flogi-retries-to-avoid-lport-s.patch.
- Refresh
  patches.fixes/scsi-scan-dont-fail-scans-when-host-is-in-recovery.patch.
- Refresh patches.fixes/scsi-stop-accepting-scsi-requests.patch.
- Refresh
  patches.fixes/scsi_dh_rdac-Add-a-new-netapp-vendor-product-string.patch.
- Refresh
  patches.fixes/scsi_dh_rdac-Consolidate-rdac-strings-together.patch.
- scsi_dh_rdac: Adding couple more vendor product ids
  (bnc#688912).
- Refresh
  patches.fixes/scsi_dh_rdac-minor-return-fix-for-rdac.patch.
- Refresh
  patches.fixes/scsi_lib-pause-between-error-retries.patch.
- Refresh
  patches.fixes/sd-ensure-we-correctly-disable-devices.patch.
- Delete patches.fixes/scsi_dh_rdac-add-new-netapp-id.patch.
- Delete
  patches.fixes/sd-Ensure-we-correctly-disable-devices-with-unk.patch.
- commit ee1bc38
* Fri Mar 29 2013 hare@suse.de
- Replace patches.fixes/scsi-fix-device-removal-NULL-pointer-dereference.patch
  with upstream version.
- commit 6b16ff8
* Fri Mar 29 2013 mhocko@suse.cz
- patches.fixes/mm-page_alloc-avoid-marking-zones-full-prematurely.patch:
  fix ALLOC_WMARK_MASK check (bnc#808166)
- commit d53ebd2
* Thu Mar 28 2013 jslaby@suse.cz
- Linux 3.0.71.
- patches.fixes/netfilter-fix-sending-ICMPv6-on-netfilter-reassembly.patch:
  Refresh.
- patches.kabi/kabi-ipv4-remove-inclusion.patch: kABI: ipv4,
  remove inclusion.
- patches.drivers/drm-i915-bounds-check-execbuffer-relocation-count:
  Delete.
- commit fd13ffc
* Thu Mar 28 2013 dsterba@suse.cz
- reenable two patches
- commit 2841e0f
* Thu Mar 28 2013 mhocko@suse.cz
- mm: account skipped entries to avoid looping in find_get_pages
  (bnc#811244).
- commit b368d3a
* Thu Mar 28 2013 trenn@suse.de
- Do not modify perf bias performance setting by default at boot
  (bnc#812259).
- commit 298043e
* Thu Mar 28 2013 dsterba@suse.cz
- btrfs: deprecate subvolrootid mount option.
- btrfs: clean snapshots one by one.
- btrfs: cover more error codes in btrfs_decode_error.
- Btrfs: fix EIO from btrfs send in is_extent_unchanged for
  punched holes.
- Btrfs: fix space leak when we fail to reserve metadata space.
- Btrfs: fix space accounting for unlink and rename.
- Btrfs: hold the ordered operations mutex when waiting on
  ordered extents.
- Btrfs: limit the global reserve to 512mb.
- commit d30f6aa
* Thu Mar 28 2013 ohering@suse.de
- drivers/hv: Fix ring buffer signaling (bnc#811417).
- commit b2816c6
* Thu Mar 28 2013 mmarek@suse.cz
- MODSIGN: Add option to disable signature verification.
- Update config files (disable CONFIG_MODULE_SIG_CHECK).
- Refresh
  patches.suse/0001-modsign-Always-enforce-module-signing-in-a-Secure-Boot.patch.
- Refresh
  patches.suse/0005-MODSIGN-Add-module-certificate-blacklist-keyring.patch.
- commit c0bc7fe
* Thu Mar 28 2013 jlee@suse.com
- Refresh
  patches.fixes/0002-X.509-Support-parse-long-form-of-length-octets-in-Au.patch.
  (bnc#811869)
  Modified the length of AuthorityKeyIdentifier check shold not just keyid
  but maybe also include DirName and serial.
- commit c87796c
* Thu Mar 28 2013 mmarek@suse.cz
- Refresh
  patches.fixes/block-reject-invalid-queue-attribute-values.patch.
- commit bdac5f8
* Thu Mar 28 2013 trenn@suse.de
- Refresh
  patches.drivers/pstore_disable_efi_backend_by_default.patch.
  Remove harsh warning message -> Samsung bricking issue should have been fixed.
- commit a4eeafc
* Thu Mar 28 2013 trenn@suse.de
- Update config files.
  Disable CONFIG_PCI_IOV for all ppc64 flavors (bnc#810656).
- commit b69b696
* Thu Mar 28 2013 lduncan@suse.de
- Refresh patches.drivers/bnx2x-added-fw-gro-bridging-support,
  fixing ppc64 build error.
- commit 05d2716
* Thu Mar 28 2013 jlee@suse.com
- x86: Require CAP_COMPROMISE_KERNEL for MSR writing
  (fate#314486).
- commit a203f33
* Thu Mar 28 2013 jlee@suse.com
- qlcnic: Bump up the version to 5.1.37 (bnc#804494).
- qlcnic: Implement flash sysfs callback for 83xx adapter
  (bnc#804494).
- qlcnic: remove duplicated include from qlcnic_sysfs.c
  (bnc#804494).
- qlcnic: Fix ethtool statistics collection (bnc#804494).
- qlcnic: Fix ethtool statistics for 82xx adapter (bnc#804494).
- qlcnic: Enable LED test support for 83xx adapter (bnc#804494).
- qlcnic: Fix endian issues in 83xx driver (bnc#804494).
- treewide: Fix typo in various drivers (bnc#804494).
- qlcnic: Fix configure interrupts for 83xx adapter types
  (bnc#804494).
- qlcnic: Fix internal loopback test for 82xx adapter
  (bnc#804494).
- qlcnic: fix ping resumption to a VM after a live migration
  (bnc#804494).
- qlcnic: fix estimation of receive MSS in case of LRO for 83xx
  adapter (bnc#804494).
- qlcnic: refactor Legacy interrupt handling for 83xx
  (bnc#804494).
- qlcnic: fix mailbox interrupt (bnc#804494).
- qlcnic: fix unsupported CDRP command error message (bnc#804494).
- qlcnic: fix mailbox response handling (bnc#804494).
- qlcnic: enhance MSIX allocation failure log message
  (bnc#804494).
- qlcnic: fix async event handling during diagnostic loopback test
  (bnc#804494).
- qlcnic: refactor 83xx diagnostic IRQ test (bnc#804494).
- qlcnic: refactor 83xx diagnostic loopback test (bnc#804494).
- qlcnic: helper routine to handle async events (bnc#804494).
- qlcnic: fix firmware based IDC participation (bnc#804494).
- qlcnic: fix initialize NIC mailbox command (bnc#804494).
- qlcnic: set gso_type (bnc#804494).
- qlcnic: Updating copyright information (bnc#804494).
- ethernet: Remove unnecessary alloc/OOM messages, alloc cleanups
  (bnc#804494).
- qlcnic: silence false positive overflow warning (bnc#804494).
- qlcnic: add support for FDB netdevice ops (bnc#804494).
- commit ca698bc
* Thu Mar 28 2013 lduncan@suse.de
- bnx2x: Fix intermittent long KR2 link up time (FATE#313915
  bnc#790597).
- bnx2x: Fix KR2 link (FATE#313915 bnc#790597).
- bnx2x: Restore FCoE 4-port devices support (FATE#313915
  bnc#790597).
- bnx2x: use FW 7.8.17 (FATE#313915 bnc#790597).
- bnx2x: Avoid using zero MAC (FATE#313915 bnc#790597).
- bnx2x: Control SFP+ tap values via nvm config (FATE#313915
  bnc#790597).
- bnx2x: Add EEE support for BCM84834 (FATE#313915 bnc#790597).
- bnx2x: Add RJ45 SFP module detection (FATE#313915 bnc#790597).
- bnx2x: Get gso_segs from FW (FATE#313915 bnc#790597).
- bnx2x: Prevent "Unknown MF" print in SF mode (FATE#313915
  bnc#790597).
- bnx2x: Take chip version from MFW (FATE#313915 bnc#790597).
- bnx2x: fix vlan-mac memory leak (FATE#313915 bnc#790597).
- bnx2x: Fix port identification for the 84834 (FATE#313915
  bnc#790597).
- bnx2x: Fix KR2 work-around condition (FATE#313915 bnc#790597).
- cnic, bnx2x: Add CNIC_DRV_STATE_HANDLES_IRQ to ethdev->drv_state
  (FATE#313915 bnc#790597).
- bnx2x: Modify unload conditions (FATE#313915 bnc#790597).
- bnx2x: Correct memory preparation and release (FATE#313915
  bnc#790597).
- bnx2x: fix GRO parameters (FATE#313915 bnc#790597).
- bnx2x: Added FW GRO bridging support (FATE#313915 bnc#790597).
- commit 2f17574
* Thu Mar 28 2013 lduncan@suse.de
- bnx2x: Clean previous IGU status before ack (FATE#313915
  bnc#790597).
- bnx2x: Added nvram personalities support (FATE#313915
  bnc#790597).
- bnx2x: Fix rare self-test failures (FATE#313915 bnc#790597).
- bnx2x: use SAN Mac for FCoE (FATE#313915 bnc#790597).
- bnx2x: Add an additional fatal hw assertion - BRB_HW_INTERRUPT
  (FATE#313915 bnc#790597).
- bnx2x: Clear dirty status when booting after UNDI (FATE#313915
  bnc#790597).
- bnx2x: Allow management traffic after boot from SAN (FATE#313915
  bnc#790597).
- bnx2x: Fix fastpath structures when memory allocation fails
  (FATE#313915 bnc#790597).
- commit 7745f68
* Wed Mar 27 2013 mmarek@suse.cz
- rpm/kernel-cert-subpackage: Fix description and summary.
- commit 5934263
* Wed Mar 27 2013 jack@suse.cz
- fs: Reserve space in struct superblock (bnc#804734).
- mm: Make default vm_ops provide ->page_mkwrite handler
  (bnc#804734).
- mm: Update file times from fault path only if .page_mkwrite
  is not set (bnc#804734).
- sysfs: Push file_update_time() into bin_page_mkwrite()
  (bnc#804734).
- gfs2: Push file_update_time() into gfs2_page_mkwrite()
  (bnc#804734).
- 9p: Push file_update_time() into v9fs_vm_page_mkwrite()
  (bnc#804734).
- ceph: Push file_update_time() into ceph_page_mkwrite()
  (bnc#804734).
- fs: Push file_update_time() into __block_page_mkwrite()
  (bnc#804734).
- fb_defio: Push file_update_time() into fb_deferred_io_mkwrite()
  (bnc#804734).
- commit 40997e6
* Wed Mar 27 2013 dsterba@suse.cz
- Btrfs: update to use fs_state bit (FATE#312888).
- Btrfs: handle a bogus chunk tree nicely (FATE#312888).
- Btrfs: fix missing qgroup reservation before fallocating
  (FATE#312888).
- Btrfs: fix locking on ROOT_REPLACE operations in tree mod log
  (FATE#312888).
- Btrfs: fix memory leak in btrfs_create_tree() (FATE#312888).
- Btrfs: fix race between mmap writes and compression
  (FATE#312888).
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- disable patches touching unsupported features
- commit f3da486
* Wed Mar 27 2013 mmarek@suse.cz
- patches.suse/0001-pciehp-Ignore-missing-surprise-bit-on-some-hosts.patch:
  Fix dmi match table definition and missing space in printk (bnc#796412).
- commit cee55b0
* Wed Mar 27 2013 jbeulich@suse.com
- Update Xen patches to 3.0.70 and c/s 1228.
- supported.conf: Correct entry for blktap2-new.
- commit 3b25b67
* Wed Mar 27 2013 jlee@suse.com
- Refresh
  patches.suse/0007_Secure_boot_Add_a_dummy_kernel_parameter_that_will_switch_on_Secure_Boot_mode_v2.patch.
  Add descrption of secureboot_enable to
  Documentation/kernel-parameters.txt
- commit c500693
* Wed Mar 27 2013 jlee@suse.com
- Change the patch priority in serial.conf, Move
  patches.suse/0004-EFI-Add-in-kernel-variable-to-determine-if-Secure-Boot-is-enabled.patch
  to lock down function patches group and refresh the following patch:
- Refresh patches.suse/0002-Add-EFI-signature-data-types.patch.
- Refresh
  patches.suse/0003-Add-an-EFI-signature-blob-parser-and-key-loader.patch.
- Refresh
  patches.suse/0004-EFI-Add-in-kernel-variable-to-determine-if-Secure-Boot-is-enabled.patch.
- Refresh
  patches.suse/0006-MODSIGN-Import-certificates-from-UEFI-Secure-Boot-v3.patch.
- commit b8f57e7
* Tue Mar 26 2013 rw@suse.de
- ia64, mm: add WB/UC check for early_ioremap.  (bnc#807677)
- commit d4654ff
* Tue Mar 26 2013 ptesarik@suse.cz
- patches.drivers/fnic-fix-SGEs-limit.patch: fnic: Fix SGEs limit
  (bnc#807431).
- commit 4da8989
* Mon Mar 25 2013 brogers@suse.com
- KVM: Fix mmu_reload() clash with nested vmx event injection
  (fate#314655).
- KVM: nVMX: Clean up and fix pin-based execution controls
  (fate#314655).
- Update patches.arch/kvm-nvmx-fix-nested-vmx-tsc-emulation.patch
  (fate#314655).
- Refresh
  patches.arch/x86-apicv-add-virtual-interrupt-delivery-support.patch.
- commit 6b1d173
* Mon Mar 25 2013 oneukum@suse.de
- patches.drivers/0001-USB-io_ti-Fix-NULL-dereference-in-chase_port.patch:
  USB: io_ti: Fix NULL dereference in chase_port() (bnc#806976,
  CVE-2013-1774).
- commit 179bd35
* Mon Mar 25 2013 oneukum@suse.de
- patches.suse/0001-pciehp-Ignore-missing-surprise-bit-on-some-hosts.patch:
  pciehp: Ignore missing surprise bit on some hosts (bnc#796412).
- commit 78665ef
* Mon Mar 25 2013 hare@suse.de
- lpfc: Update lpfc version for 8.3.7.10.1p driver release
  (bnc#810882).
- lpfc: Fixed potential mis-interpretation of READ_TOPOLOGY
  reserved fields (bnc#810882).
- lpfc: Fix default value for lpfc_enable_rrq (bnc#810882).
- lpfc: Fixed circular locking dependency and inconsistent lock
  state issues (bnc#810882).
- lpfc: Fixed PT2PT bring up problem for FC SLI4 (bnc#810882).
- lpfc: Fixed OXID reuse issue (bnc#810882).
- lpfc: Fixed async FCF modified event to in-use FCF failure to
  trigger recovery (bnc#810882).
- lpfc: Fixed deadlock condition in FCF round robin handling
  (bnc#810882).
- lpfc: Fixed bsg timeout handling issues that would result in
  crashes (bnc#810882).
- lpfc: Fixed NMI watch dog panic's when resetting the hba
  (bnc#810882).
- lpfc: Fixed degraded performance after cable pulls (bnc#810882).
- lpfc: fix potential NULL pointer dereference in
  lpfc_sli4_rq_put() (bnc#810882).
- commit b0c99d6
* Mon Mar 25 2013 mhocko@suse.cz
- patches.fixes/mm-block-optionally-snapshot-page-contents-to-provide-stable-pages-during-write.patch:
  Refresh - compile fix
- commit f473696
* Mon Mar 25 2013 jdelvare@suse.de
- patches.drivers/0004-i2c-Add-iSMT-support-for-Intel-Avoton-SOC.patch: Update upstream references.
- commit 157f2c8
* Sun Mar 24 2013 tonyj@suse.de
- perf: Add ABI reference sizes (bnc#789200, fate#313753,
  fate#312066).
- commit 874d6c2
* Sun Mar 24 2013 jslaby@suse.cz
- Linux 3.0.70 (CVE-2013-1848 bnc#793139 bnc#797042 bnc#806431 bnc#809155
  bnc#809748).
- patches.rpmify/ia64-sa_restorer-fix.patch: ia64 sa_restorer fix.
- patches.drivers/dcbnl-add-cee-notification: Refresh.
- patches.drivers/dcbnl-aggregated-cee-get-operation: Refresh.
- patches.suse/SoN-0010-netvm-Set-PF_MEMALLOC-as-appropriate-during-SKB-proc.patch:
  Refresh.
- patches.drivers/0001-cdc-wdm-fix-buffer-overflow.patch: Delete.
- patches.drivers/drm-i915-EBUSY-status-handling-added-to-i915_gem_fau:
  Delete.
- patches.fixes/TTY-do-not-reset-master-s-packet-mode.patch:
  Delete.
- patches.fixes/block-use-i_size_write-in-bd_set_size: Delete.
- patches.fixes/ext3-Fix-format-string-issues.patch: Delete.
- patches.fixes/loopdev-fix-a-deadlock: Delete.
- commit d873b4e
* Sat Mar 23 2013 jjolly@suse.de
- supported.conf:
- commit ff7729c
* Sat Mar 23 2013 jjolly@suse.de
- Update config files. Enabled EBTABLES for s390 and s390x
  (bnc#810141)
- commit 1a53815
* Fri Mar 22 2013 mkubecek@suse.cz
- patches.fixes/ipv6-Queue-fragments-per-interface-for-multicast-lin.patch:
  ipv6: Queue fragments per interface for multicast/link-local
  addresses (bnc#804220).
- commit 04e7409
* Fri Mar 22 2013 mkubecek@suse.cz
- patches.fixes/netfilter-send-ICMPv6-message-on-fragment-reassembly.patch:
  netfilter: send ICMPv6 message on fragment reassembly timeout
  (bnc#773577).
- patches.fixes/netfilter-fix-sending-ICMPv6-on-netfilter-reassembly.patch:
  netfilter: fix sending ICMPv6 on netfilter reassembly timeout
  (bnc#773577).
- commit 3902fdd
* Fri Mar 22 2013 jjolly@suse.de
- net/mlx4_en: Disable RFS when running in SRIOV mode (bnc#810655,
  LTC#90417).
- commit aa3aa08
* Fri Mar 22 2013 jjolly@suse.de
- mlx4_en: fix allocation of device tx_cq (bnc#810655, LTC#90417).
- commit 37f7f3d
* Fri Mar 22 2013 jjolly@suse.de
- mlx4_en: fix allocation of CPU affinity reverse-map (bnc#810655,
  LTC#90417).
- commit fc01708
* Fri Mar 22 2013 duwe@suse.de
- ipr: dlpar failed when adding an adapter back (bnc#809550).
- ipr: Avoid target_destroy accessing memory after it was freed
  (bnc#809550).
- commit bea36fe
* Fri Mar 22 2013 hare@suse.de
- libfcoe: Fix Conflicting FCFs issue in the fabric (bnc#809526).
- commit 2a8d797
* Fri Mar 22 2013 hare@suse.de
- bna: fix for RX data processing (bnc#809101,FATE#313822).
- commit cba25b9
* Fri Mar 22 2013 hare@suse.de
- bfa: xen port init fix (bnc#755944,FATE#313822).
- commit 31f12f1
* Thu Mar 21 2013 jack@suse.cz
- patches.fixes/jbd-clear-revoked-flag-on-buffers-before-a-new-trans.patch:
  jbd: clear revoked flag on buffers before a new transaction
  started (bnc#806395).
- commit ca431f9
* Thu Mar 21 2013 jack@suse.cz
- jbd: clear revoked flag on buffers before a new transaction
  started (bnc#806395).
- commit ff4bbe5
* Thu Mar 21 2013 mkubecek@suse.cz
- patches.fixes/xfrm6-count-extension-headers-into-payload-length.patch:
  xfrm6: count extension headers into payload length (bnc#794513).
- commit 7329a23
* Thu Mar 21 2013 mgorman@suse.de
- patches.fixes/mm-page_alloc-avoid-marking-zones-full-prematurely.patch:
  mm: page_alloc: Avoid marking zones full prematurely after zone_reclaim()
  (Evict inactive pages when zone_reclaim is enabled (bnc#808166)).
- commit b05e027
* Thu Mar 21 2013 hare@suse.de
- enable
  patches.fixes/block-reject-invalid-queue-attribute-values.patch
  after review.
- commit 4317b73
* Thu Mar 21 2013 hare@suse.de
- Enable some minor block layer fixes
- Delete
  patches.fixes/block-CFQ-avoid-moving-request-to-different-queue.patch.
- Delete
  patches.fixes/block-Remove-the-control-of-complete-cpu-from-bio.patch.
- Delete
  patches.fixes/block-fix-request_queue-flags-initialization.patch.
- Delete patches.fixes/block-prevent-race-cleanup.patch.
- Delete patches.fixes/block-recursive-merge-requests.patch.
- Delete
  patches.fixes/block-remove-deadlock-in-disk_clear_events.patch.
- Delete
  patches.fixes/block-reorganize-throtl_get_tg-and-blk_throtl_bio.patch.
- commit 488e70b
* Thu Mar 21 2013 hare@suse.de
- Delete
  patches.fixes/blk-throttle-Free-up-policy-node-associated-with-del.patch.
- Delete
  patches.fixes/blk-throttle-Take-blkcg-lock-while-traversing-blkcg-.patch.
- Delete
  patches.fixes/blk-throttle-use-queue_is_locked-instead-of-lockdep_.patch.
- commit 5704f2f
* Thu Mar 21 2013 hare@suse.de
- Remove obsolete patches
  * Delete patches.fixes/LDM-Fix-reassembly-of-extended-VBLKs.patch.
  * Delete
  patches.fixes/block-flush-MEDIA_CHANGE-from-drivers-on-close-2.patch.
  * Delete
  patches.fixes/compat_ioctl-fix-warning-caused-by-qemu.patch.
  * Delete
  patches.fixes/iosched-prevent-aliased-requests-from-starving-other.patch.
- commit ad27fbb
* Thu Mar 21 2013 hare@suse.de
- lpfc: driver panic in __lpfc_sli_issue_iocb_s4 during EEH
  (bnc#806611).
- commit d2c3b63
* Thu Mar 21 2013 hare@suse.de
- hpsa: reorganize error handling in hpsa_passthru_ioctl
  (bnc#812177).
- hpsa: check for dma_mapping_error in hpsa_map_sg_chain_block
  (bnc#812177).
- hpsa: Check for dma_mapping_error for all code paths using
  fill_cmd (bnc#812177).
- hpsa: Check for dma_mapping_error in hpsa_map_one (bnc#812177).
- hpsa: Fixup marketing names (bnc#812177).
- commit 1da9c93
* Thu Mar 21 2013 jbeulich@suse.com
- patches.xen/1228-pciback-MSI-X-prepare.patch: pciback: notify
  hypervisor about devices intended to be assigned to guests.
- patches.xen/xen-clockevents: Update (bnc#803712).
- patches.xen/xen-ipi-per-cpu-irq: Update (bnc#803712).
- patches.xen/xen3-patch-2.6.19: Update (bnc#809166).
- Update Xen patches to 3.0.68.
- commit cafba00
* Wed Mar 20 2013 jdelvare@suse.de
- patches.fixes/st-take-additional-queue-ref-in-st_probe.patch:
  st: Take additional queue ref in st_probe (bnc#801038,
  bnc#788826).
- commit 3734d53
* Wed Mar 20 2013 brogers@suse.com
- Refresh
  patches.arch/kvm-convert-msr_kvm_system_time-to-use-gfn_to_hva_cache_init.patch.
- Refresh
  patches.arch/kvm-fix-for-buffer-overflow-in-handling-of-msr_kvm_system_time.patch.
- commit 017876f
* Wed Mar 20 2013 brogers@suse.com
- Update patches to what was accepted upstream.
- patches.arch/kvm-convert-msr_kvm_system_time-to-use-gfn_to_hva_cache_init.patch:
  Refresh.
- patches.arch/kvm-fix-for-buffer-overflow-in-handling-of-msr_kvm_system_time.patch:
  Refresh.
- commit 333cfd2
* Wed Mar 20 2013 hare@suse.de
- block: Consolidate command flag and queue limit checks for
  merges (bnc#809314).
- sd: Permit merged discard requests (bnc#809314).
- be2iscsi: Fix the NOP-In handling code path (bnc#809503).
- Refresh
  patches.fixes/block-Avoid-that-request_fn-is-invoked-on-a-dead-que.patch.
- Update
  patches.fixes/block-Clean-up-special-command-handling-logic.patch
  (bnc#809314).
- Refresh patches.fixes/block-Rename-queue-dead-flag.patch.
- Refresh patches.fixes/block-add-blk_queue_dead.patch.
- Update
  patches.fixes/block-add-plug-for-blkdev_issue_discard.patch
  (bnc#809314).
- Update
  patches.fixes/block-discard-granularity-might-not-be-power-of-2.patch
  (bnc#809314).
- Refresh patches.fixes/block-drop-blk_get_put_queue.patch.
- block: fix request_queue lifetime handling by making
  blk_queue_cleanup() properly shutdown (bnc#778477).
- block: re-use existing 'reading' variable instead of checking
  direction again (bnc#778477).
- Update
  patches.fixes/block-reorganize-rounding-of-max_discard_sectors.patch
  (bnc#809314).
- Update
  patches.fixes/block-split-discard-into-aligned-requests.patch
  (bnc#809314).
- Refresh patches.suse/blk-timeout-no-round.
- Delete
  patches.fixes/Fix-device-removal-NULL-pointer-dereference.patch.
- Delete
  patches.fixes/block-check-for-QUEUE_FLAG_DEAD-in-elv_completed_re.patch.
- Delete
  patches.fixes/block-check-for-QUEUE_FLAG_DEAD-in-elv_put_request.patch.
- Delete
  patches.fixes/scsi-remove-duplicate-call-to-blk_cleanup_queue.patch.
- commit 0cbfa68
* Wed Mar 20 2013 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit 412a848
* Wed Mar 20 2013 duwe@suse.de
- ipr: fix addition of abort command to HRRQ free queue
  (bnc#808946).
- commit cd12c1d
* Wed Mar 20 2013 tiwai@suse.de
- Refresh patches.drm/drm-radeon-disable-new-devices.
  Revive ES1000 again.  You only live twice.
- commit 7bf4d59
* Wed Mar 20 2013 mmarek@suse.cz
- Delete patches.kabi/* workarounds
- commit f5246b0
* Tue Mar 19 2013 jeffm@suse.com
- patches.suse/ext4-rw-unsupported.patch: Fix module description text
  (bnc#810307).
- commit e8f2f33
* Tue Mar 19 2013 oneukum@suse.de
- patches.drivers/0001-drivers-xhci-fix-incorrect-bit-test.patch:
  drivers: xhci: fix incorrect bit test (bnc#714604).
- commit c9cf298
* Tue Mar 19 2013 tiwai@suse.de
- Disable new devices in SP3 radeon driver (bnc#807366).
- commit 6430050
* Tue Mar 19 2013 mkubecek@suse.cz
- patches.fixes/xfrm-remove-unused-xfrm4_policy_fini.patch:
  xfrm: remove unused xfrm4_policy_fini() (bnc#801717).
- patches.fixes/xfrm-make-gc_thresh-configurable-in-all-namespaces.patch:
  xfrm: make gc_thresh configurable in all namespaces
  (bnc#801717).
- patches.kabi/kabi-use-net_generic-to-avoid-changes-in-struct-net.patch:
  kabi: use net_generic to avoid changes in struct net
  (bnc#801717).
- commit 1acffe1
* Tue Mar 19 2013 jslaby@suse.cz
- Linux 3.0.69.
- patches.fixes/md-raid0-fix-error-return-from-create_stripe_zones.patch:
  Delete.
- commit 0484edf
* Tue Mar 19 2013 hare@suse.de
- mpt2sas fails EEH recovery from injected pci bus error
  (bnc#806612).
- commit 89b37d8
* Mon Mar 18 2013 lduncan@suse.com
- be2iscsi: Fix the NOP-In handling code path (bnc#809503)
- commit 3b9bbdd
* Mon Mar 18 2013 brogers@suse.com
- KVM: Fix bounds checking in ioapic indirect register read
  (bnc#806980 CVE-2013-1798).
- KVM: Convert MSR_KVM_SYSTEM_TIME to use gfn_to_hva_cache_init
  (bnc#806980 CVE-2013-1797).
- KVM: Fix for buffer overflow in handling of MSR_KVM_SYSTEM_TIME
  (bnc#806980 CVE-2013-1796).
- KVM: introduce kvm_read_guest_cached (bnc#806980).
- commit 1de7613
* Mon Mar 18 2013 jack@suse.cz
- patches.fixes/xfs-Fix-WARN_ON-delalloc-in-xfs_vm_releasepage.patch:
  xfs: Fix WARN_ON(delalloc) in xfs_vm_releasepage() (bnc#806631).
- commit cf98fc6
* Mon Mar 18 2013 ohering@suse.de
- Drivers: hv: Notify the host of permanent hot-add failures
  (fate#314663).
- Drivers: hv: balloon: Support 2M page allocations for ballooning
  (fate#314663).
- mm: Export split_page() (fate#314663).
- commit 493c90b
* Mon Mar 18 2013 ohering@suse.de
- update MEMORY_HOTPLUG handling in hv balloon (fate#314663)
- Update config files and reenable hv_balloon on i386
- commit c58f767
* Mon Mar 18 2013 tiwai@suse.de
- Refresh patch-mainline and git-commit tags in patches.drivers/alsa-sp3-*
  patches.drivers/alsa-sp3-dsp-002-Add-new-DSP-loader-callback-routines.
  patches.drivers/alsa-sp3-dsp-003-Change-return-value-for-load_dsp_prepare.
  patches.drivers/alsa-sp3-pre-675-Add-workaround-for-conflicting-IEC958-contr.
  patches.drivers/alsa-sp3-pre-681-Keep-power-link-on-for-PantherPoint-HDMI.
  patches.drivers/alsa-sp3-pre-686-Fix-recursive-suspend-resume-call.
  patches.drivers/alsa-sp3-pre-687-Limit-runtime-PM-support-only-to-known-Inte.
  patches.drivers/alsa-sp3-pre-690-New-PCI-ID-for-Haswell-ULT.
  patches.drivers/alsa-sp3-pre-691-Release-assigned-pin-cvt-at-error-path.
  patches.drivers/alsa-sp3-pre-692-Support-rereading-widgets-under-the-functio.
  patches.drivers/alsa-sp3-pre-693-Apply-mic-mute-LED-fixup-for-new-HP-laptops.
  patches.drivers/alsa-sp3-pre-694-Add-fixup-for-Haswell-to-enable-all-pin.
  patches.drivers/alsa-sp3-pre-695-Yet-another-fix-for-broken-HSW-HDMI-pin.
  patches.drivers/alsa-sp3-pre-696-Support-mute-LED-on-HP-AiO-buttons.
- commit 6d6bb74
* Mon Mar 18 2013 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-033-Support-mute-LED-on-HP-AiO-buttons:
  Refresh tags.
- commit df9ce9c
* Mon Mar 18 2013 jjolly@suse.de
- [BZ 89928] kdump: Do not add standby memory for kdump
  (bnc#809678, LTC#89928).
- commit 8fad70f
* Mon Mar 18 2013 jjolly@suse.de
- [BZ 84815] zfcp: Adapt to new FC_PORTSPEED semantics
  (bnc#809678, LTC#84815).
- commit 804bf4f
* Mon Mar 18 2013 dsterba@suse.cz
- Btrfs: fix warning of free_extent_map (FATE#312888 bnc#808926).
- btrfs: use rcu_barrier() to wait for bdev puts at unmount
  (FATE#312888).
- Btrfs: get better concurrency for snapshot-aware defrag work
  (FATE#312888).
- Btrfs: return EIO if we have extent tree corruption
  (FATE#312888).
- Btrfs: return as soon as possible when edquot happens
  (FATE#312888).
- Btrfs: fix warning when creating snapshots (FATE#312888).
- Delete
  patches.suse/btrfs-8188-return-as-soon-as-possible-when-edquot-happens.patch.
- Delete
  patches.suse/btrfs-8189-fix-warning-when-creating-snapshots.patch.
- commit f142b8d
* Mon Mar 18 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix sed command with multiple certificates
- commit 76ad6d7
* Sun Mar 17 2013 jeffm@suse.com
- patches.fixes/block-use-i_size_write-in-bd_set_size: block:
  use i_size_write() in bd_set_size() (bnc#809748).
- patches.fixes/loopdev-fix-a-deadlock: loopdev: fix a deadlock
  (bnc#809748).
- commit ca0ac66
* Fri Mar 15 2013 tiwai@suse.de
- ALSA: hda - Support mute LED on HP AiO buttons (bnc#808991).
- commit 4241daa
* Fri Mar 15 2013 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-033-Support-mute-LED-on-HP-AiO-buttons:
  ALSA: hda - Support mute LED on HP AiO buttons (bnc#808991).
- commit fb6e987
* Fri Mar 15 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Install the used certificates below
  /etc/uefi/certs (fate#314507).
- commit 408523c
* Fri Mar 15 2013 mmarek@suse.cz
- rpm/kernel-cert-subpackage: Make the template work with multiple
  certificates.
- commit f378ad1
* Fri Mar 15 2013 jeffm@suse.com
- patches.suse/supported-flag: fix mis-reported supported status (bnc#809493).
- patches.suse/supported-flag-enterprise: Refresh.
- commit bb4f65d
* Fri Mar 15 2013 jeffm@suse.com
- ext4: force read-only unless rw=1 module option is used
  (fate#314864).
- commit 5c76e08
* Fri Mar 15 2013 jeffm@suse.com
- patches.suse/supported-flag: fix mis-reported supported status (bnc#809493).
- Refresh patches.suse/supported-flag-enterprise.
- commit 499f6dc
* Fri Mar 15 2013 tiwai@suse.de
- Update patch-mainline tags in patches.drm/*
- commit 01846c6
* Fri Mar 15 2013 jslaby@suse.cz
- patches.fixes/TTY-do-not-update-atime-mtime-on-read-write.patch:
  Refresh.
- patches.fixes/kvm-invalid-opcode-oops-on-SET_SREGS-with-OSXSAVE-bi.patch:
  Refresh.
- patches.fixes/nfs-bitmap-size.fix: Refresh.
  Update upstream tags.
- commit b4b8ffe
* Fri Mar 15 2013 jlee@suse.com
- Refresh
  patches.drivers/0004-efivarfs-guid-part-of-filenames-are-case-insensitive.patch.
  (bnc#809369)
- commit 2f0a73b
* Thu Mar 14 2013 dsterba@suse.cz
- Refresh patches.suse/btrfs-8189-fix-warning-when-creating-snapshots.patch.
- commit 315c3f0
* Thu Mar 14 2013 brogers@suse.com
- patches.arch/kvm-convert-msr_kvm_system_time-to-use-gfn_to_hva_cache_init.patch:
  KVM: Convert MSR_KVM_SYSTEM_TIME to use gfn_to_hva_cache_init
  (bnc#806980 CVE-2013-1797).
- patches.arch/kvm-fix-bounds-checking-in-ioapic-indirect-register-read.patch:
  KVM: Fix bounds checking in ioapic indirect register read
  (bnc#806980 CVE-2013-1798).
- patches.arch/kvm-fix-for-buffer-overflow-in-handling-of-msr_kvm_system_time.patch:
  KVM: Fix for buffer overflow in handling of MSR_KVM_SYSTEM_TIME
  (bnc#806980 CVE-2013-1796).
- patches.arch/kvm-introduce-kvm_read_guest_cached.patch: KVM:
  introduce kvm_read_guest_cached (bnc#806980).
- commit b1445b7
* Thu Mar 14 2013 mmarek@suse.cz
- rpm/kernel-source.spec.in: Make scripts/sign-file executable (bnc#807845)
- commit 57807e3
* Thu Mar 14 2013 mgorman@suse.de
- patches.fixes/x86-numa-Add-constraints-check-for-nid-parameters.patch:
  x86/numa: Add constraints check for nid parameters
  (Cope with negative SRAT distances (bnc#807853)).
- commit 32623b6
* Thu Mar 14 2013 oneukum@suse.de
- patches.drivers/0001-cdc-wdm-fix-buffer-overflow.patch: Refresh.
  Correct Git-Commit
- commit fd835e1
* Thu Mar 14 2013 hare@suse.de
- bnx2fc: Bumped version to 1.0.14 (FATE#313818, bnc#809080).
- bnx2fc: Update copyright information (FATE#313818, bnc#809080).
- bnx2fc: Fix race condition between IO completion and abort
  (FATE#313818, bnc#809080).
- bnx2fc: Include chip number in the symbolic name (FATE#313818,
  bnc#809080).
- bnx2fc: Enable cached tasks to improve performance (FATE#313818,
  bnc#809080).
- commit 2df9b16
* Thu Mar 14 2013 jack@suse.cz
- Added CVE reference to patches.fixes/ext3-Fix-format-string-issues.patch
- commit 5eed66d
* Thu Mar 14 2013 tiwai@suse.de
- patches.drivers/drm-i915-Periodically-sanity-check-power-management:
  drm/i915: Periodically sanity check power management
  (bnc#808307).
- patches.drivers/drm-i915-bounds-check-execbuffer-relocation-count:
  drm/i915: bounds check execbuffer relocation count
  (bnc#808829,CVE-2013-0913).
- commit 8aa36b1
* Thu Mar 14 2013 jjolly@suse.de
- series.conf: disabled patches.arch/s390-64-03-kernel-inc-phys-mem.patch
  due to excessive kabi break. (bnc#801720)
- commit 3bf6ee5
* Thu Mar 14 2013 jlee@suse.com
- efivars: Sanitise string length returned by
  GetNextVariableName() (fate#314499, fate#314509, bnc#806499).
- efivarfs: return accurate error code in efivarfs_fill_super()
  (fate#314499, fate#314509).
- efivars: efivarfs_valid_name() should handle pstore syntax
  (fate#314499, fate#314509).
- efi: be more paranoid about available space when creating
  variables (fate#314499, fate#314509).
- efivarfs: Validate filenames much more aggressively
  (fate#314499, fate#314509).
- efi_pstore: Introducing workqueue updating sysfs (fate#314499,
  fate#314509).
- efivars: Disable external interrupt while holding efivars->lock
  (fate#314499, fate#314509).
- efivarfs: guid part of filenames are case-insensitive
  (fate#314499, fate#314509).
- efi_pstore: Avoid deadlock in non-blocking paths (fate#314499,
  fate#314509).
- pstore: Avoid deadlock in panic and emergency-restart path
  (fate#314499, fate#314509).
- efi_pstore: Check remaining space with QueryVariableInfo()
  before writing data (fate#314499, fate#314509).
- commit 036a27b
* Thu Mar 14 2013 jlee@suse.com
- Refresh
  patches.suse/0009_acpi_Ignore_acpi_rsdp_kernel_parameter_in_a_secure_boot_environment_v2.patch.
  (bnc#808418)
- Refresh
  patches.suse/0011-hibernate-Disable-in-a-Secure-Boot-environment.patch.
  (bnc#808418)
- commit e0fc233
* Wed Mar 13 2013 duwe@suse.de
- Set the PRRN bits in the architecture vector (bnc#808724).
- pseries/iommu: close DDW race between functions of adapter
  (bnc#808220).
- commit ee58836
* Wed Mar 13 2013 tiwai@suse.de
- Delete patches.drm/3245-drm-i915-set-TRANSCODER_EDP-even-earlier.diff (bnc#809191)
  This patch caused a blank screen on HSW eDP of HP AiO model.
  Safer to revert for now
- commit ccc6062
* Wed Mar 13 2013 jack@suse.cz
- patches.fixes/ext3-Fix-format-string-issues.patch: ext3:
  Fix format string issues (bnc#809155).
- commit e568e5c
* Wed Mar 13 2013 mgorman@suse.de
- patches.fixes/x86-64-Fix-memset-to-support-sizes-of-4Gb-and-above.patch:
  x86-64: Fix memset() to support sizes of 4Gb and above
  (Properly initialise memmap on large machines (bnc#802353)).
- commit b36c083
* Wed Mar 13 2013 eich@suse.com
- Delete
  patches.drm/DRM-i915-On-G45-enable-cursor-plane-briefly-after-enabling-the-display-plane.patch.
- commit acaff63
* Wed Mar 13 2013 ohering@suse.de
- hv balloon driver now depends on MEMORY_HOTPLUG,
  which is disabled on i386 (fate#314663)
- Update config files and disable hv_balloon on i386
- commit 2f0d283
* Wed Mar 13 2013 ohering@suse.de
- Drivers: hv: balloon: Implement hot-add functionality
  (fate#314663).
- mm: extend memory hotplug API to allow memory hotplug in
  virtual machines (fate#314663).
- commit 37d4b06
* Tue Mar 12 2013 tiwai@suse.de
- Refresh patches.drivers/alsa-sp3-pre-695-Yet-another-fix-for-broken-HSW-HDMI-pin
  Fix a superfluous incremental leading to the double array size (bnc#808966)
- commit 228f922
* Tue Mar 12 2013 tiwai@suse.de
- patches.drivers/alsa-sp3-pre-695-Yet-another-fix-for-broken-HSW-HDMI-pin:
  Refresh.  Fix a superfluous incremental leading to the double
  array size (bnc#808966)
- commit 5b5ce38
* Tue Mar 12 2013 tiwai@suse.de
- drm/i915: Use the fixed pixel clock for eDP in
  intel_dp_set_m_n() (bnc#807362).
- Revert "drm/i915: try to train DP even harder" (bnc#807362).
- commit f10c453
* Tue Mar 12 2013 ohering@suse.de
- Drivers: hv: vmbus: Handle channel rescind message correctly
  (fate#314663).
- Drivers: hv: balloon: Make the balloon driver not unloadable
  (fate#314663).
- Drivers: hv: balloon: Execute hot-add code in a separate context
  (fate#314663).
- commit 387ae5b
* Tue Mar 12 2013 ohering@suse.de
- Drivers: hv: balloon: Execute balloon inflation in a separate
  context (fate#314663).
- Drivers: hv: balloon: Do not request completion notification
  (fate#314663).
- commit 51336f8
* Tue Mar 12 2013 ohering@suse.de
- storvsc: Handle dynamic resizing of the device.
- storvsc: Restructure error handling code on command completion.
- storvsc: avoid usage of WRITE_SAME.
- commit 25cca99
* Tue Mar 12 2013 ohering@suse.de
- add mainline tags for two hyperv driver patches
- commit 5cef715
* Tue Mar 12 2013 jbeulich@suse.com
- Update Xen patches to 3.0.68 and c/s 1226.
- add symbols to hypercall stubs.
- Update EC2 config files (PPS and PTP_1588_CLOCK* off).
- Refresh patches.xen/xen-clockevents (bnc#803712).
- commit bbb7310
* Tue Mar 12 2013 jjolly@suse.de
- supported.conf: Added ib_qib.ko (bnc#807910,FATE#314303)
- commit a737e34
* Mon Mar 11 2013 mmarek@suse.cz
- MODSIGN: Support for signing_key.{x509,priv} in the M= directory.
- commit e8707f1
* Mon Mar 11 2013 mmarek@suse.cz
- Delete patches.suse/kbuild-no-extmod-sign.
- commit bbecbb8
* Mon Mar 11 2013 jkosina@suse.cz
- This is a revert/disabling of patches of 2b072c8dcd1801 ("Block layer fixes
  (bnc#778477)") as the patches are incomplete (build failures) and the scope
  needs to be determined.
- Refresh
  patches.fixes/Fix-device-removal-NULL-pointer-dereference.patch.
- Refresh
  patches.fixes/scsi-fix-device-removal-NULL-pointer-dereference.patch.
- Refresh patches.suse/blk-timeout-no-round.
- commit 63d86b8
* Mon Mar 11 2013 tiwai@suse.de
- drm/i915: also disable south interrupts when handling them.
- drm/i915: enable irqs earlier when resuming (bnc#806406).
- drm/i915: Fixup hpd irq register setup ordering (bnc#806406).
- commit ee4af79
* Mon Mar 11 2013 mgorman@suse.de
- patches.fixes/mm-bdi-allow-block-devices-to-say-that-they-require-stable-page-writes.patch:
  bdi: allow block devices to say that they require stable page writes
- patches.fixes/mm-only-enforce-stable-page-writes-if-the-backing-device-requires-it.patch:
  mm: only enforce stable page writes if the backing device requires it
- patches.fixes/mm-block-optionally-snapshot-page-contents-to-provide-stable-pages-during-write.patch:
  block: optionally snapshot page contents to provide stable pages during write
- patches.fixes/mm-9pfs-fix-filesystem-to-wait-for-stable-page-writeback.patch:
  9pfs: fix filesystem to wait for stable page writeback
- patches.fixes/mm-ocfs2-wait-for-page-writeback-to-provide-stable-pages.patch:
  ocfs2: wait for page writeback to provide stable pages
- patches.fixes/mm-ubifs-wait-for-page-writeback-to-provide-stable-pages.patch:
  ubifs: wait for page writeback to provide stable pages
- patches.suse/fs-knows-MAY_APPEND.diff
  Refresh
  Only enable stable page writes when required by underlying BDI (bnc#807517).
- commit 7a4ccb0
* Mon Mar 11 2013 tiwai@suse.de
- drm/mgag200: Bug fix: Renesas board now selects native
  resolution (bnc#806990).
- drm/mgag200: Reject modes that are too big for VRAM
  (bnc#806990).
- drm/i915: Turn off hsync and vsync on ADPA when disabling crt
  (bnc#806406).
- drm/i915: Fix incorrect definition of ADPA HSYNC and VSYNC bits
  (bnc#806406).
- drm/i915: Increase the RC6p threshold (bnc#806406).
- commit a109836
* Mon Mar 11 2013 tiwai@suse.de
- DRM/i915: On G45 enable cursor plane briefly after enabling
  the display plane (bnc#806406).
- drm/i915: Fix Haswell/CRW PCI IDs (bnc#806406).
- drm/i915: Don't clobber crtc->fb when queue_flip fails
  (bnc#806406).
- drm/i915: wait_event_timeout's timeout is in jiffies
  (bnc#806406).
- commit df4cb88
* Mon Mar 11 2013 rw@suse.de
- supported.conf: add drivers/s390/block/scm_block
  (fate#314095, bnc#807237)
- commit a225eab
* Mon Mar 11 2013 tiwai@suse.de
- rpm/kernel-binary.spec.in: Update intel-e1000e obsoleted version
- commit 450bd62
* Sun Mar 10 2013 mmarek@suse.cz
- KMP: Add -c <cert> option to the %%kernel_module_package macro
  This produces an -ueficert subpackage that imports the certificate into
  the MokList when installed (fate#314511)
- commit 94983de
* Sun Mar 10 2013 dsterba@suse.cz
- Btrfs: improve the delayed inode throttling (FATE#312888).
- commit f64024c
* Fri Mar  8 2013 hare@suse.de
- Block layer fixes (bnc#778477):
  - LDM: Fix reassembly of extended VBLKs (bnc#778477).
  - allow blk_flush_policy to return REQ_FSEQ_DATA independent of
  * FLUSH (bnc#778477).
  - blk: add an upper sanity check on partition adding (bnc#778477).
  - blk-flush: fix invalid BUG_ON in blk_insert_flush (bnc#778477).
  - blk-flush: move the queue kick into (bnc#778477).
  - blk-throttle: Free up policy node associated with deleted rule
  - blk-throttle: Take blkcg->lock while traversing
    blkcg->policy_list (bnc#778477).
  - blk-throttle: correctly determine sync bio (bnc#778477).
  - blk-throttle: use queue_is_locked() instead of lockdep_is_held()
  - block: Add blk_rq_pos(rq) to sort rq when plushing (bnc#778477).
  - block: Avoid missed wakeup in request waitqueue (bnc#778477).
  - block: Avoid scheduling delayed work on a dead queue
  - block: Avoid that request_fn is invoked on a dead queue
  - block CFQ: avoid moving request to different queue (bnc#778477).
  - block: Clean up special command handling logic (bnc#778477).
  - block: Don't access request after it might be freed
  - block: Don't check QUEUE_FLAG_SAME_COMP in
    __blk_complete_request (bnc#778477).
  - block: Fix queue_flag update when rq_affinity goes from 2 to 1
  - block: Let blk_drain_queue() caller obtain the queue lock
  - block: Make blk_cleanup_queue() wait until request_fn finished
  - block: Make rq_affinity = 1 work as expected (bnc#778477).
  - block: Mitigate lock unbalance caused by lock switching
  - block: Remove the control of complete cpu from bio (bnc#778477).
  - block: Rename queue dead flag (bnc#778477).
  - block: add GENHD_FL_NO_PART_SCAN (bnc#778477).
  - block: add missed trace_block_plug (bnc#778477).
  - block: add plug for blkdev_issue_discard (bnc#778477).
  - block: avoid building too big plug list (bnc#778477).
  - block: avoid unnecessary plug list flush (bnc#778477).
  - block: blk-throttle should be drained regardless of q->elevator
  - block, cfq: fix empty queue crash caused by request merge
  - block: change force plug flush call order (bnc#778477).
  - block: discard granularity might not be power of 2 (bnc#778477).
  - block: don't call blk_drain_queue() if elevator is not up
  - block: don't call elevator callbacks for plug merges
  - block: don't kick empty queue in blk_drain_queue() (bnc#778477).
  - block: drop @tsk from attempt_plug_merge() and explain sync
    rules (bnc#778477).
  - block: fix blk_queue_end_tag() (bnc#778477).
  - block: fix drain_all condition in blk_drain_queue()
  - block: fix flush machinery for stacking drivers with differring
  - block: fix genhd refcounting in blkio_policy_parse_and_set()
  - block: fix request_queue->flags initialization (bnc#778477).
  - block: fix request_queue lifetime handling by making
  - block: fix warning with calling smp_processor_id() in
    preemptible (bnc#778477).
  - block: flush MEDIA_CHANGE from drivers on close(2) (bnc#778477).
  - block: improve rq_affinity placement (bnc#778477).
  - block: make auto block plug flush threshold per-disk based
  - block: make get_request[_wait]() fail if queue is dead
  - block: move blk_throtl prototypes to block/blk.h (bnc#778477).
  - block: pass around REQ_* flags instead of broken down booleans
  - block: prevent race/cleanup (bnc#778477).
  - block: re-use existing 'reading' variable instead of checking
  - block: recursive merge requests (bnc#778477).
  - block: reject invalid queue attribute values (bnc#778477).
  - block: remove deadlock in disk_clear_events (bnc#778477).
  - block: remove elevator_queue->ops (bnc#778477).
  - block: reorder elevator switch sequence (bnc#778477).
  - block: reorganize queue draining (bnc#778477).
  - block: reorganize rounding of max_discard_sectors (bnc#778477).
  - block: reorganize throtl_get_tg() and blk_throtl_bio()
  - block: separate out blk_rq_merge_ok() and blk_try_merge() from
  - block: simplify force plug flush code a little bit (bnc#778477).
  - block: split discard into aligned requests (bnc#778477).
  - block: strict rq_affinity (bnc#778477).
  - block: use NUMA_NO_NODE instead of -1 (bnc#778477).
  - block: warn if tag is greater than real_max_depth (bnc#778477).
  - compat_ioctl: fix warning caused by qemu (bnc#778477).
  - elevator: use ELV_NAME_MAX instead of magic number 16 for
  - iosched: prevent aliased requests from starving other I/O
- Refresh
  patches.fixes/Fix-device-removal-NULL-pointer-dereference.patch.
- Refresh
  patches.fixes/scsi-fix-device-removal-NULL-pointer-dereference.patch.
- Refresh patches.suse/blk-timeout-no-round.
- commit 2b072c8
* Fri Mar  8 2013 msrb@novell.com
- drm: don't add inferred modes for monitors that don't support them.
  (bnc#798466)
- commit 0a5bfec
* Fri Mar  8 2013 mmarek@suse.cz
- KMP: Add the -kmp suffix inside the subpackage definition
- commit 3d90790
* Fri Mar  8 2013 mmarek@suse.cz
- KMP: The %%sign_files macro is not needed anymore
- commit 52b90db
* Fri Mar  8 2013 jlee@suse.com
- efivarfs: Delete dentry from dcache in efivarfs_file_write()
  (fate#314499, fate#314509).
- efivarfs: Never return ENOENT from firmware (fate#314499,
  fate#314509).
- efivarfs: Drop link count of the right inode (fate#314499,
  fate#314509).
- commit 8c8cfd5
* Fri Mar  8 2013 dsterba@suse.cz
- Btrfs: fix warning when creating snapshots.
- Btrfs: return as soon as possible when edquot happens.
- commit f3d3f07
* Thu Mar  7 2013 brogers@suse.com
- patches.arch/kvm-emulator-drop-rpl-check-from-linearize-function.patch:
  KVM: emulator: drop RPL check from linearize() function
  (bnc#754583).
- commit 852688e
* Thu Mar  7 2013 lduncan@suse.com
- qla4xxx: Boot from SAN fix for ISP83XX (bnc#808031,
  FATE#313902).
- qla4xxx: Fix debug level to avoid floods of same message
- qla4xxx: Fix double reset in case of firmware hung for ISP83XX
- qla4xxx: Fixed request queue count manipulation on response path
- qla4xxx: Pass correct LUN address to firmware in case of
  lun_reset
- qla4xxx: Set graceful reset bit for ISP83XX
- qla4xxx: Take E-port out of reset before disabling pause frames
- qla4xxx: v5.03.00.02.11.3-k0
- commit 7a89194
* Thu Mar  7 2013 dsterba@suse.cz
- btrfs: enhance superblock checks.
- commit c89dc2a
* Thu Mar  7 2013 jlee@suse.com
- i2c: iSMT SMBus patch for Intel Avoton DeviceIDs  (fate#313701,
  bnc#807394).
- i2c: i801: SMBus patch for Intel Avoton DeviceIDs (fate#313701,
  bnc#807394).
- ahci: Add Device IDs for Intel Wellsburg PCH (fate#313702,
  bnc#807133).
- ata_piix: IDE-mode SATA patch for Intel Avoton DeviceIDs
  (fate#313701, bnc#807394).
- ahci: AHCI-mode SATA patch for Intel Avoton DeviceIDs
  (fate#313701, bnc#807394).
- commit 20b1d00
* Thu Mar  7 2013 oneukum@suse.de
- patches.drivers/0001-USB-Don-t-use-EHCI-port-sempahore-for-USB-3.0-hubs.patch:
  USB: Don't use EHCI port sempahore for USB 3.0 hubs
  (bnc#807560).
- patches.drivers/0002-USB-Prepare-for-refactoring-by-adding-extra-udev-che.patch:
  USB: Prepare for refactoring by adding extra udev checks
  (bnc#807560).
- patches.drivers/0003-USB-Rip-out-recursive-call-on-warm-port-reset.patch:
  USB: Rip out recursive call on warm port reset (bnc#807560).
- patches.drivers/0004-USB-Fix-connected-device-switch-to-Inactive-state.patch:
  USB: Fix connected device switch to Inactive state (bnc#807560).
- patches.drivers/0005-modify-hub-to-detect-unplugs-in-all-states.patch:
  modify hub to detect unplugs in all states (bnc#807560).
- commit bb5744c
* Thu Mar  7 2013 tiwai@suse.de
- drm/i915: Handle untiled planes when computing their offsets
  (bnc#806406).
- drm/i915: Fix RC6VIDS encode/decode (bnc#806406).
- drm/i915: Disable WC PTE updates to w/a buggy IOMMU on ILK
  (bnc#806406).
- drm/i915: Use HAS_L3_GPU_CACHE in i915_gem_l3_remap
  (bnc#806406).
- drm/i915: Fix PIPE_CONTROL DW/QW write through global GTT on
  IVB+ (bnc#806406).
- drm/i915: Set i9xx sdvo clock limits according to specifications
  (bnc#806406).
- drm/i915: Set i9xx lvds clock limits according to specifications
  (bnc#806406).
- drm/i915: remove bogus mutex_unlock from error-path
  (bnc#806406).
- drm/i915: don't save/restore DSPARB on gen5+ (bnc#806406).
- drm/i915: only disable enabled planes on intel_fb_restore_mode
  (bnc#806406).
- drm/i915: set TRANSCODER_EDP even earlier (bnc#806406).
- drm/i915: don't send DP "idle" pattern before "normal" on HSW
  PORT_A (bnc#806406).
- commit f52c6b8
* Thu Mar  7 2013 brogers@suse.com
- KVM: emulator: drop RPL check from linearize() function
  (bnc#754583).
- commit 6867047
* Thu Mar  7 2013 duwe@suse.de
- ipr: ipr_test_msi() fails when running with msi-x enabled
  adapter (bnc#806608).
- ipr: Fix oops while resetting an ipr adapter (bnc#806781).
- powerpc: Use the newly added get_required_mask dma_map_ops hook
  (bnc#807082).
- dma-mapping: Add get_required_mask if arch overrides default
  (bnc#807082).
- powerpc: Override dma_get_required_mask by platform hook and
  ops (bnc#807082).
- commit e0dffb3
* Thu Mar  7 2013 hare@suse.de
- Delete patches.fixes/dm-mpath-do-not-call-request_module.
- Delete patches.fixes/dm-mpath-reset-map_pointer-on-requeue.
- commit 1616dde
* Thu Mar  7 2013 hare@suse.de
- dm: clear bi_end_io on remapping failure (FATE#314163).
- dm: fix limits initialization when there are no data devices
  (FATE#314163).
- dm ioctl: do not leak argv if target message only contains
  whitespace (FATE#314163).
- dm ioctl: forbid multiple device specifiers (FATE#314163).
- dm ioctl: introduce __get_dev_cell (FATE#314163).
- dm ioctl: prevent empty message (FATE#314163).
- dm mpath: add retain_attached_hw_handler feature (FATE#314163).
- dm mpath: check if scsi_dh module already loaded before trying
  to load (FATE#314163).
- dm mpath: delay retry of bypassed pg (FATE#314163).
- dm mpath: detect invalid map_context (FATE#314163).
- dm mpath: fix check for null mpio in end_io fn (FATE#314163).
- dm mpath: reduce size of struct multipath (FATE#314163).
- dm: remove superfluous smp_mb (FATE#314163).
- dm: retain table limits when swapping to new table with no
  devices (FATE#314163).
- dm table: clean dm_get_device and move exports (FATE#314163).
- dm table: clear add_random unless all devices have it set
  (FATE#314163).
- dm table: fix discard support (FATE#314163).
- dm table: propagate non rotational flag (FATE#314163).
- Refresh
  patches.suse/dm-thin-0003-dm-table-share-target-argument-parsing-functions.patch.
- commit 80b30c5
* Thu Mar  7 2013 mmarek@suse.cz
- Refresh patches.fixes/mlx4-correct-call-to_ib_ah_attr.patch.
- commit ad7d3b7
* Thu Mar  7 2013 tonyj@suse.de
- x86/perf: Add IvyBridge EP support (bnc#805456).
- commit cb46961
* Thu Mar  7 2013 hare@suse.de
- qla2xxx: Fix crash during firmware dump procedure (bnc#805696).
- commit c06c7f3
* Thu Mar  7 2013 hare@suse.de
- be2net: use CSR-BAR SEMAPHORE reg for BE2/BE3 (bnc#801926).
- benet: Wait f/w POST until timeout (bnc#801926).
- commit 8c0f6f3
* Thu Mar  7 2013 ohering@suse.de
- supported.conf: fix typo in last commit
- commit 703205f
* Thu Mar  7 2013 ohering@suse.de
- supported.conf: mark hyperv_fb as supported (fate#314862)
- commit f187f3b
* Thu Mar  7 2013 dsterba@suse.cz
- Btrfs: enforce min_bytes parameter during extent allocation
  (FATE#312888).
- commit a5b01b5
* Wed Mar  6 2013 brogers@suse.com
- KVM: VMX: disable SMEP feature when guest is in non-paging mode
  (FATE#313612).
- KVM: MMU: Adjust shadow paging to work when SMEP=1 and CR0.WP=0
  (FATE#313612).
- commit c054f74
* Wed Mar  6 2013 ohering@suse.de
- video: Add Hyper-V Synthetic Video Frame Buffer Driver
  (fate#314862).
- Update config files.
- commit ebac6de
* Wed Mar  6 2013 rgoldwyn@suse.de
- patches.fixes/mlx4-correct-call-to_ib_ah_attr.patch: Correct
  calls to to_ib_ah_attr() (bnc#806847).
- commit 9164d70
* Wed Mar  6 2013 hare@suse.de
- megaraid_sas: Add 4k FastPath DIF support
  (bnc#784804,FATE#313894).
- megaraid_sas: Dont load DevHandle unless FastPath enabled
  (bnc#784804,FATE#313894).
- megaraid_sas: Version and Changelog update
  (bnc#784804,FATE#313894).
- commit aba2eb1
* Wed Mar  6 2013 brogers@suse.com
- KVM: Add RDWRGSFS support when setting CR4 (bnc#805793).
- KVM: Enable DRNG feature support for KVM (bnc#805793).
- KVM: Enable ERMS feature support for KVM (bnc#805793).
- KVM: Expose RDWRGSFS bit to KVM guests (bnc#805793).
- KVM: Remove RDWRGSFS bit from CR4_RESERVED_BITS (bnc#805793).
- Refresh
  patches.arch/kvm-expose-latest-intel-cpu-new-features-bmi1-bmi2-fma-avx2-to-guest.patch.
- Refresh
  patches.arch/kvm-vmx-use-ept-access-bit-in-response-to-memory-notifiers.patch.
- Refresh
  patches.arch/kvm-x86-expose-intel-cpu-new-features-hle-rtm-to-guest.patch.
- Refresh patches.arch/x86-kvm-invpcid.patch.
- Refresh patches.arch/x86-kvm-osvw.patch.
- commit 339f54f
* Tue Mar  5 2013 neilb@suse.de
- Add bug id to a patch
- commit 21dce8e
* Tue Mar  5 2013 dsterba@suse.cz
- Btrfs: make sure NODATACOW also gets NODATASUM set
  (FATE#312888).
- Btrfs: fix backref walking race with tree deletions
  (FATE#312888).
- clear chunk_alloc flag on retryable failure (FATE#312888).
- Btrfs: use reserved space for creating a snapshot (FATE#312888).
- Btrfs: do not change inode flags in rename (FATE#312888).
- btrfs: cleanup for open-coded alignment (FATE#312888).
- Btrfs: copy everything if we've created an inline extent
  (FATE#312888).
- Btrfs: fix memory leak of log roots (FATE#312888).
- Btrfs: fix NULL pointer after aborting a transaction
  (FATE#312888).
- btrfs: remove a printk from scan_one_device (FATE#312888).
- Btrfs: remove unnecessary dget_parent/dput when creating the
  pending snapshot (FATE#312888).
- Btrfs: fix wrong reserved space in qgroup during snap/subv
  creation (FATE#312888).
- Btrfs: fix wrong reserved space when deleting a
  snapshot/subvolume (FATE#312888).
- btrfs: use only inline_pages from extent buffer (FATE#312888).
- Btrfs: fix missing deleted items in btrfs_clean_quota_tree
  (FATE#312888).
- Btrfs: return ENOMEM rather than use BUG_ON when
  btrfs_alloc_path fails (FATE#312888).
- Btrfs: remove reduplicate check about root in the function
  btrfs_clean_quota_tree (FATE#312888).
- Btrfs: don't call btrfs_qgroup_free if just btrfs_qgroup_reserve
  fails (FATE#312888).
- Btrfs: cleanup to make the function
  btrfs_delalloc_reserve_metadata more logic (FATE#312888).
- Btrfs: delete inline extents when we find them during logging
  (FATE#312888).
- Btrfs: fix wrong handle at error path of create_snapshot()
  when the commit fails (FATE#312888).
- Btrfs: fix unclosed transaction handler when the async
  transaction commitment fails (FATE#312888).
- Btrfs: check for NULL pointer in updating reloc roots
  (FATE#312888).
- Btrfs: build up error handling for merge_reloc_roots
  (FATE#312888).
- Btrfs: free all recorded tree blocks on error (FATE#312888).
- Btrfs: do not BUG_ON in prepare_to_reloc (FATE#312888).
- Btrfs: do not BUG_ON on aborted situation (FATE#312888).
- Btrfs: avoid deadlock on transaction waiting list (FATE#312888).
- Btrfs: allow running defrag in parallel to administrative tasks
  (FATE#312888).
- Refresh
  patches.suse/btrfs-8022-forced-readonly-when-free_log_tree-fails.patch.
- commit 153206f
* Tue Mar  5 2013 hare@suse.de
- fnic: Fix memory leak issue in Vlan Discovery (bnc#805099).
- commit 5e5f33a
* Tue Mar  5 2013 agraf@suse.de
- Update config files: Disable vhost for s390x (bnc#807493)
- commit cf6c8ae
* Tue Mar  5 2013 trenn@suse.de
- supported.conf:
  Adding drivers/edac/edac_mce_amd
  bnc#807336
- commit 68b181c
* Tue Mar  5 2013 trenn@suse.de
- xhci: correctly enable interrupts.
- commit bd09194
* Tue Mar  5 2013 jslaby@suse.cz
- Linux 3.0.68 (bnc#768052 bnc#802153 bnc#804154 CVE-2013-0871).
- patches.arch/x86_x2apic_use_phys_apic_mode_on_bios_request.patch:
  Delete.
- patches.fixes/ptrace-ensure-arch_ptrace-ptrace_request-can-never-r.patch:
  Delete.
- patches.fixes/ptrace-introduce-signal_wake_up_state-and-ptrace_sig.patch:
  Delete.
- patches.fixes/quota-autoload-the-quota_v2-module-for-qfmt_vfs_v1-quota-format:
  Delete.
- patches.fixes/wake_up_process-should-be-never-used-to-wakeup-a-TAS.patch:
  Delete.
- patches.rpmify/dca-check-against-empty-dca_domains-list-before-fix.patch:
  Delete.
- patches.rpmify/s390-kvm-Fix-store-status-for-ACRS-FPRS-fix.patch:
  Delete.
- commit 37ad977
* Tue Mar  5 2013 duwe@suse.de
- supported.conf: add drivers/crypto/nx/nx-crypto (bnc#807034)
- commit de25e4a
* Tue Mar  5 2013 eich@suse.com
- patches.drivers/DRM-i915-On-G45-enable-cursor-plane-briefly-after-enabling-the-display-plane.patch:
  DRM/i915: On G45 enable cursor plane briefly after enabling
  the display plane (bnc #753371) [backported from drm-intel-fixes].
- commit c621eab
* Mon Mar  4 2013 eich@suse.com
- DRM/i915: On G45 enable cursor plane briefly after enabling
  the display plane (bnc #753371).
- commit 8e09121
* Mon Mar  4 2013 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch
- commit 0ddfaf1
* Mon Mar  4 2013 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash-mgadrmfb-workaround.
  Add the same w/a for ast and cirrus KMS, too (bnc#806990).
- commit 14bd535
* Mon Mar  4 2013 jslaby@suse.cz
- Refresh
  patches.arch/s390-kvm-0018-KVM-s390-provide-access-guest-registers-via-kvm_ru.patch.
- commit e7c2409
* Mon Mar  4 2013 jlee@suse.com
- iTCO_wdt: Add Device IDs for Intel Wellsburg PCH (fate#313702).
- ALSA: hda_intel: Add Device IDs for Intel Wellsburg PCH
  (fate#313702).
- i2c: i801: Add Device IDs for Intel Wellsburg PCH (fate#313702).
- ata_piix: Add Device IDs for Intel Wellsburg PCH (fate#313702).
- ahci: Add Device IDs for Intel Wellsburg PCH (fate#313702).
- commit f71c797
* Fri Mar  1 2013 jjolly@suse.de
- [FEAT NET1222] ib_uverbs: Allow explicit mmio trigger
  (FATE#83366, ltc#83367).
- commit 9a449d8
* Fri Mar  1 2013 tiwai@suse.de
- Fix broken VT1 output with mgadrmfb (bnc#806990).
- commit 52e6b95
* Fri Mar  1 2013 duwe@suse.de
- Update patches.suse/zcrypt-feed-hwrandom (bnc#806825).
  Allow zcrypt module unload even when the thread is
  blocked writing to a full random pool.
- commit b1d6aa8
* Fri Mar  1 2013 duwe@suse.de
- Update patches.suse/zcrypt-feed-hwrandom (bnc#806825).
  Allow zcrypt module unload even when the thread is
  blocked writing to a full random pool.
- commit 5c3c822
* Fri Mar  1 2013 jack@suse.cz
- Updated warning message in patches.suse/xfs-warn-rt-volume.patch.
- commit 4498b6e
* Fri Mar  1 2013 oneukum@suse.de
- patches.drivers/0001-USB-move-usb_translate_errors-to-linux-usb.h.patch:
  USB: move usb_translate_errors to linux/usb (bnc#806908).
- patches.drivers/0002-USB-add-EOPNOTSUPP-to-usb_translate_errors.patch:
  USB: add EOPNOTSUPP to usb_translate_errors (bnc#806908).
- patches.suse/0001-cdc-wdm-add-helper-to-preserve-kABI.patch:
  Delete.
- commit d1a5364
* Fri Mar  1 2013 oneukum@suse.de
- patches.drivers/0002-USB-cdc-wdm-sanitize-error-returns.patch:
  USB: cdc-wdm: sanitize error returns (bnc#806908).
- patches.drivers/0003-USB-cdc-wdm-cleanup-error-codes.patch:
  USB: cdc-wdm: cleanup error codes (bnc#806908).
- patches.suse/0001-cdc-wdm-add-helper-to-preserve-kABI.patch:
  cdc-wdm: add helper to preserve kABI (bnc#806908).
- commit aea8c8a
* Thu Feb 28 2013 jslaby@suse.cz
- Linux 3.0.67 (bnc#578046, bnc#786814, bnc#806138, CVE-2013-1767,
  FATE#306952).
- patches.rpmify/dca-check-against-empty-dca_domains-list-before-fix.patch:
  dca: check against empty dca_domains list before unregister
  provider fix.
- patches.rpmify/s390-kvm-Fix-store-status-for-ACRS-FPRS-fix.patch:
  s390/kvm: Fix store status for ACRS/FPRS fix.
- patches.kabi/kabi-restore-utf8s_to_utf16s.patch: kABI: restore
  utf8s_to_utf16s.
- patches.suse/msft-hv-0247-Staging-hv-move-hyperv-code-out-of-staging-directo.patch:
  Refresh.
- patches.suse/msft-hv-0344-Drivers-hv-Support-the-newly-introduced-KVP-messag.patch:
  Refresh.
- patches.suse/msft-hv-0361-hyperv-Add-support-for-setting-MAC-from-within-guest.patch:
  Refresh.
- patches.suse/msft-hv-0374-Drivers-hv-kvp-Support-the-new-IP-injection-messages.patch:
  Refresh.
- patches.fixes/ext4-add-missing-kfree-on-error-return-path-in-add_new_gdb:
  Delete.
- patches.fixes/ext4-free-resources-in-some-error-path-in-ext4_fill_super:
  Delete.
- patches.fixes/mm-mmu_notifier-have-mmu_notifiers-use-a-global-SRCU-so-they-may-safely-schedule.patch:
  Delete.
- patches.fixes/mm-mmu_notifier-make-the-mmu_notifier-srcu-static.patch:
  Delete.
- patches.fixes/mm-mmu_notifier_unregister-NULL-Pointer-deref-and-multiple---release-callouts.patch:
  Delete.
- patches.fixes/tmpfs-fix-use-after-free-of-mempolicy-object.patch:
  Delete.
- patches.suse/msft-hv-0261-NLS-improve-UTF8-UTF16-string-conversion-routine.patch:
  Delete.
- commit 18e9ba0
* Thu Feb 28 2013 jdelvare@suse.de
- supported.conf: Mark drivers/hwmon/jc42 as supported
- commit 859ba7e
* Thu Feb 28 2013 duwe@suse.de
- patches.drivers/cxgb4i-remove-the-scsi-host-device-when-removing-device:
  cxgb4i: Remove the scsi host device when removing device
  (bnc#722398)
- commit f453908
* Thu Feb 28 2013 jdelvare@suse.de
- i2c: fix i2c-ismt.c printk format warning (FATE#313511).
- commit 0534893
* Thu Feb 28 2013 jdelvare@suse.de
- patches.drivers/i2c-support-for-intel-ismt-smbus-host-controller.patch: Update upstream reference
- commit aa18d74
* Thu Feb 28 2013 jack@suse.cz
- Warn if XFS realtime volumes are used (fate#314871).
- commit b904402
* Thu Feb 28 2013 tiwai@suse.de
- supported.conf: Add missing entries for ast, cirrus, gmag200 and drm/i2c modules (bnc#806694)
- commit 613387a
* Wed Feb 27 2013 rgoldwyn@suse.de
- patches.fixes/xprtrdma-transport-should-not-bug-check-when-a-dup-reply-is-received: The transport should not bug-check when a dup reply is received
  (bnc#763494).
- commit 98e27a6
* Wed Feb 27 2013 jjolly@suse.de
- powerpc/pseries: Round up MSI-X requests (bnc#804284,LTC#88786).
- commit 6e4b889
* Wed Feb 27 2013 jjolly@suse.de
- Update s390x config files to remove CONFIG_USB_SUPPORT and related
  settings (bnc#802343)
- commit 210ad44
* Wed Feb 27 2013 mhocko@suse.cz
- patches.fixes/tmpfs-fix-use-after-free-of-mempolicy-object.patch:
  tmpfs: fix use-after-free of mempolicy object (bnc#806138,
  CVE-2013-1767).
- commit a67ceed
* Wed Feb 27 2013 oneukum@suse.de
- patches.drivers/0001-cdc-wdm-fix-buffer-overflow.patch: Refresh.
- patches.drivers/0004-USB-cdc-wdm-cannot-use-dev_printk-when-device-is-gon.patch:
  Refresh.
- commit c5bf5e2
* Wed Feb 27 2013 mmarek@suse.cz
- Disable module signing for x86_64/ec2 as well (fate#314508#c17)
- commit 6f84db1
* Wed Feb 27 2013 oneukum@suse.de
- patches.drivers/0001-cdc-wdm-fix-buffer-overflow.patch: cdc-wdm:
  fix buffer overflow (bnc#806431).
- commit dcce887
* Wed Feb 27 2013 oneukum@suse.de
- patches.drivers/0004-USB-cdc-wdm-cannot-use-dev_printk-when-device-is-gon.patch:
  USB: cdc-wdm: cannot use dev_printk when device is gone
  (bnc#806469).
- commit 5ed57b5
* Wed Feb 27 2013 oneukum@suse.de
- patches.drivers/0002-USB-cdc-wdm-fix-memory-leak.patch: USB:
  cdc-wdm: fix memory leak (bnc#806466).
- commit 929a354
* Wed Feb 27 2013 mmarek@suse.cz
- Only enable module signing on platforms that support secure boot
  (fate#314508#c17)
- commit 6efc08e
* Wed Feb 27 2013 hare@suse.de
- patches.fixes/block-add-blk_queue_dead.patch: fixup patch
  (bnc#805298)
- commit 8e586de
* Tue Feb 26 2013 jjolly@suse.de
- patches.arch/s390-64-01-zfcpdump-diag308-loop.patch: ipl:
  Implement diag308 loop for zfcpdump (bnc#801720, LTC#88197).
- patches.arch/s390-64-02-zfcpdump-hsa-attribute.patch: zcore:
  Add hsa file (bnc#801720, LTC#88198).
- patches.arch/s390-64-03-kernel-inc-phys-mem.patch: kernel:
  support physical memory > 4TB (bnc#801720, LTC#88787).
- patches.arch/s390-64-04-mm-mapfixed-crst-upgrade.patch: mm:
  Fix crst upgrade of mmap with MAP_FIXED (bnc#801720, LTC#88797).
- commit a346476
* Tue Feb 26 2013 jeffm@suse.com
- aoe: allow comma separator in aoe_iflist value (FATE#314860 bnc#806858).
- aoe: allow user to disable target failure timeout (FATE#314860 bnc#806858).
- aoe: associate frames with the AoE storage target (FATE#314860 bnc#806858).
- aoe: avoid races between device destruction and discovery
  (FATE#314860 bnc#806858).
- aoe: avoid running request handler on plugged queue
  (FATE#314860 bnc#806858).
- aoe: become I/O request queue handler for increased user control
  (FATE#314860 bnc#806858).
- aoe: cleanup: correct comment for aoetgt nout (FATE#314860 bnc#806858).
- aoe: cleanup: remove unused ata_scnt function (FATE#314860 bnc#806858).
- aoe: commands in retransmit queue use new destination on failure
  (FATE#314860 bnc#806858).
- aoe: copy fallback timing information on destination failover
  (FATE#314860 bnc#806858).
- aoe: describe the behavior of the "err" character device
  (FATE#314860 bnc#806858).
- aoe: disallow unsupported AoE minor addresses (FATE#314860 bnc#806858).
- aoe: do revalidation steps in order (FATE#314860 bnc#806858).
- aoe: err device: include MAC addresses for unexpected responses
  (FATE#314860 bnc#806858).
- aoe: failover remote interface based on aoe_deadsecs parameter
  (FATE#314860 bnc#806858).
- aoe: fix use after free in aoedev_by_aoeaddr() (FATE#314860 bnc#806858).
- aoe: for performance support larger packet payloads
  (FATE#314860 bnc#806858).
- aoe: identify source of runt AoE packets (FATE#314860 bnc#806858).
- aoe: improve handling of misbehaving network paths
  (FATE#314860 bnc#806858).
- aoe: improve network congestion handling (FATE#314860 bnc#806858).
- aoe: increase default cap on outstanding AoE commands in the
  network (FATE#314860 bnc#806858).
- aoe: increase net_device reference count while using it
  (FATE#314860 bnc#806858).
- aoe: initialize sysminor to avoid compiler warning
  (FATE#314860 bnc#806858).
- aoe: kernel thread handles I/O completions for simple locking
  (FATE#314860 bnc#806858).
- aoe: make dynamic block minor numbers the default (FATE#314860 bnc#806858).
- aoe: make error messages more specific in static minor
  allocation (FATE#314860 bnc#806858).
- aoe: manipulate aoedev network stats under lock (FATE#314860 bnc#806858).
- aoe: "payload" sysfs file exports per-AoE-command data transfer
  size (FATE#314860 bnc#806858).
- aoe: print warning regarding a common reason for dropped
  transmits (FATE#314860 bnc#806858).
- aoe: provide ATA identify device content to user on request
  (FATE#314860 bnc#806858).
- aoe: remove call to request handler from I/O completion
  (FATE#314860 bnc#806858).
- aoe: remove unused code (FATE#314860 bnc#806858).
- aoe: remove unused code and add cosmetic improvements
  (FATE#314860 bnc#806858).
- aoe: remove vestigial request queue allocation (FATE#314860 bnc#806858).
- aoe: retain static block device numbers for backwards
  compatibility (FATE#314860 bnc#806858).
- aoe: return real minor number for static minors (FATE#314860 bnc#806858).
- aoe: support larger I/O requests via aoe_maxsectors module param
  (FATE#314860 bnc#806858).
- aoe: support more AoE addresses with dynamic block device
  minor numbers (FATE#314860 bnc#806858).
- aoe: support the forgetting (flushing) of a user-specified
  AoE target (FATE#314860 bnc#806858).
- aoe: update and specify AoE address guards and error messages
  (FATE#314860 bnc#806858).
- aoe: update aoe-internal version number to 50 (FATE#314860 bnc#806858).
- aoe: update cap on outstanding commands based on config query
  response (FATE#314860 bnc#806858).
- aoe: update copyright year in touched files (FATE#314860 bnc#806858).
- aoe: update documentation to better reflect aoe-plus-udev usage
  (FATE#314860 bnc#806858).
- aoe: update documentation with new URL and VM settings reference
  (FATE#314860 bnc#806858).
- aoe: update driver-internal version number to 60 (FATE#314860 bnc#806858).
- aoe: update driver-internal version to 64+ (FATE#314860 bnc#806858).
- aoe: update internal version number to 49 (FATE#314860 bnc#806858).
- aoe: update internal version number to 81 (FATE#314860 bnc#806858).
- aoe: use a kernel thread for transmissions (FATE#314860 bnc#806858).
- aoe: use dynamic number of remote ports for AoE storage target
  (FATE#314860 bnc#806858).
- aoe: use high-resolution RTTs with fallback to low-res
  (FATE#314860 bnc#806858).
- aoe: use packets that work with the smallest-MTU local interface
  (FATE#314860 bnc#806858).
- aoe: whitespace cleanup (FATE#314860 bnc#806858).
- commit 4420e3f
* Tue Feb 26 2013 jjolly@suse.de
- mm: Fix crst upgrade of mmap with MAP_FIXED (bnc#805052,
  LTC#88797).
- commit a87a20a
* Tue Feb 26 2013 jjolly@suse.de
- dasd: Fix unresponsive device after all channel paths were lost
  (bnc#805052, LTC#88850).
- commit d334ed2
* Tue Feb 26 2013 jjolly@suse.de
- kernel: support physical memory > 4TB (bnc#805052, LTC#88787).
- commit 01b8c8c
* Tue Feb 26 2013 trenn@suse.de
- Refresh, fix broken mainline commit by merging it with a fix:
  broken git commit ea0dcf903e7d76aa5d483d876215fedcfdfe140f merged with
  git commit cb214ede7657db458fd0b2a25ea0b28dbf900ebc
  patches.arch/x86_x2apic_use_phys_apic_mode_on_bios_request.patch.
- commit 8e82401
* Tue Feb 26 2013 jankit@suse.de
- patches.drivers/lpfc-Check-fc_block_scsi_eh-return-value-correctly-for-lpfc_abort_handler.patch:
  Check fc_block_scsi_eh return value correctly for
  lpfc_abort_handler (bnc#803674).
- commit 6230cb3
* Tue Feb 26 2013 jjolly@suse.de
- IB/iser: Add more RX CQs to scale out processing of SCSI
  responses (bnc#786036, FATE#314304).
- commit f0bd1a2
* Tue Feb 26 2013 jjolly@suse.de
- IB/iser: Fix error flow in iser ep connection establishment
  (bnc#786036, FATE#314304).
- commit b9b921a
* Tue Feb 26 2013 jjolly@suse.de
- IB/iser: Free IB connection resources in the proper place
  (bnc#786036, FATE#314304).
- commit 321875b
* Tue Feb 26 2013 jjolly@suse.de
- IB/iser: DMA unmap TX bufs used for iSCSI/iSER headers
  (bnc#786036, FATE#314304).
- commit 3bdf9b4
* Tue Feb 26 2013 jjolly@suse.de
- IB/iser: Use separate buffers for the login request/response
  (bnc#786036, FATE#314304).
- commit 168236d
* Tue Feb 26 2013 jjolly@suse.de
- IB/iser: Support iSCSI PDU padding (bnc#786036, FATE#314304).
- commit cf98c3a
* Tue Feb 26 2013 jjolly@suse.de
- IB/iser: Fix wrong mask when sizeof (dma_addr_t) > sizeof
  (unsigned long) (bnc#786036, FATE#314304).
- commit 2f8d14f
* Tue Feb 26 2013 neilb@suse.de
- patches.fixes/md-fix-bug-in-handling-of-new_data_offset.patch:
  md: fix bug in handling of new_data_offset (bnc#805823).
- commit f652f41
* Tue Feb 26 2013 neilb@suse.de
- patches.fixes/md-Avoid-OOPS-when-reshaping-raid1-to-raid0.patch:
  md: Avoid OOPS when reshaping raid1 to raid0 (Useful OOPS fix).
- patches.fixes/md-fix-two-bugs-when-attempting-to-resize-RAID0-arra.patch:
  md: fix two bugs when attempting to resize RAID0 array (Useful
  BUG() fix).
- patches.fixes/md-raid0-fix-error-return-from-create_stripe_zones.patch:
  md: raid0: fix error return from create_stripe_zones (useful
  bug fix).
- commit c9eae57
* Mon Feb 25 2013 jeffm@suse.com
- patches.fixes/ext4-add-missing-kfree-on-error-return-path-in-add_new_gdb:
  ext4: add missing kfree() on error return path in add_new_gdb().
- patches.fixes/ext4-free-resources-in-some-error-path-in-ext4_fill_super:
  ext4: Free resources in some error path in ext4_fill_super.
- commit 08d0f2b
* Mon Feb 25 2013 tiwai@suse.de
- rpm/kernel-binary.spec.in: Correct the version number to obsolete drm-kmp properly
- commit 777c4b4
* Mon Feb 25 2013 jslaby@suse.cz
- Linux 3.0.66.
- commit 20c19c1
* Mon Feb 25 2013 jslaby@suse.cz
- patches.fixes/TTY-do-not-update-atime-mtime-on-read-write.patch:
  TTY: do not update atime/mtime on read/write (bnc#797175
  CVE-2013-0160).
- commit 3c3acea
* Mon Feb 25 2013 tiwai@suse.de
- patches.arch/intel_idle_add_haswell_support.patch: intel_idle:
  support Haswell (fate#313720).
- commit 24755e4
* Mon Feb 25 2013 tiwai@suse.de
- patches.drivers/hp_accel-Add-a-new-PnP-ID-HPQ6007-for-new-HP-laptops:
  hp_accel: Add a new PnP ID HPQ6007 for new HP laptops
  (bnc#802445).
- commit f724854
* Mon Feb 25 2013 neilb@suse.de
- patches.fixes/nfs-umount-fix: Ensure NFS doesn't block on dead
  server during unmount (bnc#794529).
- commit 766b245
* Sat Feb 23 2013 jslaby@suse.cz
- patches.fixes/TTY-do-not-reset-master-s-packet-mode.patch:
  Refresh.
- patches.rpmify/spi-mpc8xxx_spi-len.patch: Delete.
  Update upstream tags. The second one fixed differently.
- commit 666f23c
* Fri Feb 22 2013 bpoirier@suse.de
- tg3: Add 57766 device support (bnc#790588 FATE#313912).
- commit 1218224
* Fri Feb 22 2013 bp@suse.de
- x86, mm: Send tlb flush IPIs to online cpus only (bnc#798406).
- commit adc5976
* Fri Feb 22 2013 ohering@suse.de
- merge hv changes from v3.9-rc1:
- hv: hv_balloon: remove duplicated include from hv_balloon.c.
- tools/hv: Fix /var subdirectory.
- tools/hv: Fix permissions of created directory and files.
- Drivers: hv: remove unused variable in vmbus_recvpacket_raw().
- tools: hv: fix a typo in hv_set_ifconfig.sh.
- tools: hv: Fix how ifcfg-* file is created.
- Drivers: hv: vmbus_flow_handler() can be static.
- tools: hv: Use CLOEXEC when opening kvp_pool files.
- Drivers: hv: vmbus: Consolidate all offer GUID definitions
  in hyperv.h.
- Drivers: hv: Use consolidated GUID definitions.
- Drivers: net: hyperv: Use the consolidated GUID definition.
- Drivers: scsi: storvsc: Use the consolidated GUID definition.
- Drivers: hid: hid-hyperv: Use consolidated GUID definitions.
- Drivers: hv: Execute shutdown in a thread context.
- X86: Add a check to catch Xen emulation of Hyper-V.
- x86, hyperv: HYPERV depends on X86_LOCAL_APIC.
- Refresh patches.xen/xen3-patch-2.6.32.
- commit 959a83b
* Fri Feb 22 2013 bpoirier@suse.de
- Refresh patches.arch/s390-sles11sp3-16-06-pci-stub.patch.
  Fix a build failure in mlx4 due to the pci stubs:
  drivers/infiniband/hw/mlx4/mad.c:833: error: implicit declaration of function
  'kmalloc'
- commit da8dc78
* Fri Feb 22 2013 ohering@suse.de
- update patch headers fate314663 and fate314665.
  no code changes.
- commit 6ebc7b9
* Fri Feb 22 2013 ohering@suse.de
- rename patches for fate314663 and fate314665 to simplify
  mainline tracking. no code changes.
- commit b84e0b4
* Fri Feb 22 2013 jkosina@suse.cz
- Update config files: run oldconfig on s390
- commit 2a80842
* Fri Feb 22 2013 jkosina@suse.cz
- Update config files: disable PTP on s390. This is a partial revert of 5283bd87ad
  as ioremap()/iounmap() and friends don't exist on s390 in our config due to
  !CONFIG_PCI
- commit 2d4e5cc
* Fri Feb 22 2013 tiwai@suse.de
- drm/cirrus: Use 16bpp as default (bnc#799216).
- drm/cirrus: Correct register values for 16bpp (bnc#799216).
- commit d45bd0e
* Fri Feb 22 2013 mgorman@suse.de
- mm: mmu_notifier: have mmu_notifiers use a global SRCU so they may safely schedule
- mm: mmu_notifier: make the mmu_notifier srcu static
- mmu_notifier_unregister NULL Pointer deref and multiple ->release() callouts
- Delete
  patches.fixes/Have-mmu_notifiers-use-SRCU-so-they-may-safely-schedule-build-fix.patch.
- Delete
  patches.fixes/Have-mmu_notifiers-use-SRCU-so-they-may-safely-schedule.patch.
  (bnc#578046, bnc#786814, FATE#306952).
- commit 1314b16
* Fri Feb 22 2013 jankit@suse.de
- patches.fixes/block-disable-discard-request-merge-temporarily.patch:
  block: disable discard request merge temporarily (bnc#803067).
- commit 34d581a
* Fri Feb 22 2013 dsterba@suse.cz
- btrfs: fixup writeback_inodes_sb wrappers use.
- commit d97fb17
* Fri Feb 22 2013 tiwai@suse.de
- Update HD-audio drivers for Nvidia/AMD HDMI and Haswell audio
- patches.drivers/alsa-sp3-pre-002-Allow-multple-SPDIF-controls-per-codec:
  ALSA: hda: Allow multple SPDIF controls per codec (bnc#780977).
- patches.drivers/alsa-sp3-pre-003-Virtualize-SPDIF-out-controls:
  ALSA: hda: Virtualize SPDIF out controls (bnc#780977).
- patches.drivers/alsa-sp3-pre-004-Separate-generic-and-non-generic-implementa:
  ALSA: hda: Separate generic and non-generic implementations.
- patches.drivers/alsa-sp3-pre-005-hdmi_eld_update_pcm_info-update-a-stream-in:
  ALSA: hda: hdmi_eld_update_pcm_info: update a stream in place.
- patches.drivers/alsa-sp3-pre-006-HDMI-Support-codecs-with-fewer-cvts-than-pi:
  ALSA: hda: HDMI: Support codecs with fewer cvts than pins.
- patches.drivers/alsa-sp3-pre-019-Add-snd_hda_get_conn_list-helper-function:
  ALSA: hda - Add snd_hda_get_conn_list() helper function.
- patches.drivers/alsa-sp3-pre-122-Add-snd_hda_override_conn_list-helper-funct:
  ALSA: hda - Add snd_hda_override_conn_list() helper function.
- patches.drivers/alsa-sp3-pre-305-Increase-the-max-number-of-coverters-pins-i:
  ALSA: hda - Increase the max number of coverters/pins in
  patch_hdmi.c (bnc#780977).
- patches.drivers/alsa-sp3-pre-316-Check-non-snoop-in-a-single-place:
  ALSA: hda - Check non-snoop in a single place (bnc#801713).
- patches.drivers/alsa-sp3-pre-319-Use-LPIB-Position-fix-for-Intel-SCH-Poulsbo:
  ALSA: HDA: Use LPIB Position fix for Intel SCH Poulsbo
  (bnc#801713).
- patches.drivers/alsa-sp3-pre-336-hda_intel-Add-Oaktrail-identifiers:
  ALSA: hda_intel: Add Oaktrail identifiers (bnc#801713).
- patches.drivers/alsa-sp3-pre-337-Use-LPIB-position-fix-for-Oaktrail:
  ALSA: HDA: Use LPIB position fix for Oaktrail (bnc#801713).
- patches.drivers/alsa-sp3-pre-436-add-id-for-Atom-Cedar-Trail-HDMI-codec:
  ALSA: hda - add id for Atom Cedar Trail HDMI codec (bnc#801713).
- patches.drivers/alsa-sp3-pre-514-Fix-detection-of-Creative-SoundCore3D-contr:
  ALSA: hda - Fix detection of Creative SoundCore3D controllers
  (bnc#762424).
- patches.drivers/alsa-sp3-pre-527-add-power-states-information-in-proc:
  ALSA: hda - add power states information in proc (bnc#801713).
- patches.drivers/alsa-sp3-pre-528-Show-D3cold-state-in-proc-files:
  ALSA: hda - Show D3cold state in proc files (bnc#801713).
- patches.drivers/alsa-sp3-pre-529-check-supported-power-states:
  ALSA: hda - check supported power states (bnc#801713).
- patches.drivers/alsa-sp3-pre-530-reduce-msleep-time-if-EPSS-power-states-sup:
  ALSA: hda - reduce msleep time if EPSS power states supported
  (bnc#801713).
- patches.drivers/alsa-sp3-pre-531-check-proper-return-value:
  ALSA: hda - check proper return value (bnc#801713).
- patches.drivers/alsa-sp3-pre-532-power-setting-error-check:
  ALSA: hda - power setting error check (bnc#801713).
- patches.drivers/alsa-sp3-pre-560-Add-DeviceID-for-Haswell-HDA:
  ALSA: hda - Add DeviceID for Haswell HDA (bnc#801713).
- patches.drivers/alsa-sp3-pre-561-add-Haswell-HDMI-codec-id:
  ALSA: hda - add Haswell HDMI codec id (bnc#801713).
- patches.drivers/alsa-sp3-pre-562-Fix-driver-type-of-Haswell-controller-to-AZ:
  ALSA: hda - Fix driver type of Haswell controller to
  AZX_DRIVER_SCH.
- patches.drivers/alsa-sp3-pre-563-Add-new-GPU-codec-ID-to-snd-hda:
  ALSA: hda - Add new GPU codec ID to snd-hda (bnc#780977).
- patches.drivers/alsa-sp3-pre-596-hda_intel-Add-Device-IDs-for-Intel-Lynx-Point-L:
  Refresh.
- patches.drivers/alsa-sp3-pre-621-HDMI-Fix-channel_allocation-array-wrong-order:
  ALSA: HDMI - Fix channel_allocation array wrong order
  (bnc#801713).
- patches.drivers/alsa-sp3-pre-627-Avoid-BDL-position-workaround-when-no_perio:
  ALSA: hda - Avoid BDL position workaround when no_period_wakeup
  is set (bnc#801713).
- patches.drivers/alsa-sp3-pre-635-Allow-to-pass-position_fix-0-explicitly:
  ALSA: hda - Allow to pass position_fix=0 explicitly
  (bnc#801713).
- patches.drivers/alsa-sp3-pre-641-Add-another-pci-id-for-Haswell-board:
  ALSA: hda - Add another pci id for Haswell board.
- patches.drivers/alsa-sp3-pre-647-force-use-of-SSYNC-bits:
  ALSA: hda - force use of SSYNC bits (bnc#801713).
- patches.drivers/alsa-sp3-pre-648-use-LPIB-for-delay-estimation:
  ALSA: hda - use LPIB for delay estimation (bnc#801713).
- patches.drivers/alsa-sp3-pre-649-add-PCI-identifier-for-Intel-5-Series-3400:
  ALSA: hda - add PCI identifier for Intel 5 Series/3400
  (bnc#801713).
- patches.drivers/alsa-sp3-pre-675-Add-workaround-for-conflicting-IEC958-contr:
  ALSA: hda - Add workaround for conflicting IEC958 controls
  (FATE#314311).
- patches.drivers/alsa-sp3-pre-676-Stop-LPIB-delay-counting-on-broken-hardware:
  ALSA: hda - Stop LPIB delay counting on broken hardware
  (FATE#313695).
- patches.drivers/alsa-sp3-pre-688-Always-turn-on-pins-for-HDMI-DP:
  ALSA: hda - Always turn on pins for HDMI/DP (FATE#313695).
- patches.drivers/alsa-sp3-pre-689-bug-fix-for-invalid-connection-list-of-Hasw:
  ALSA: hda - bug fix for invalid connection list of Haswell
  HDMI codec pins (FATE#313695).
- patches.drivers/alsa-sp3-pre-690-New-PCI-ID-for-Haswell-ULT:
  ALSA - HDA: New PCI ID for Haswell ULT (bnc#801713).
- patches.drivers/alsa-sp3-pre-691-Release-assigned-pin-cvt-at-error-path:
  ALSA: hda - Release assigned pin/cvt at error path of
  hdmi_pcm_open() (bnc#801713).
- patches.drivers/alsa-sp3-pre-692-Support-rereading-widgets-under-the-functio:
  ALSA: hda - Support rereading widgets under the function group
  (bnc#801713).
- patches.drivers/alsa-sp3-pre-694-Add-fixup-for-Haswell-to-enable-all-pin:
  ALSA: hda - Add fixup for Haswell to enable all pin and
  convertor widgets (bnc#801713).
- patches.drivers/alsa-sp3-pre-695-Yet-another-fix-for-broken-HSW-HDMI-pin:
  ALSA: hda - Yet another fix for broken HSW HDMI pin connections
  (bnc#801713).
- patches.kabi/alsa-spdif-update-kabi-fixes: Fix kABI breakage
  due to HD-audio HDMI updates (bnc#780977).
- commit c9134f3
* Fri Feb 22 2013 tiwai@suse.de
- Remove yet another ugly backport hack in previous DRM updates
- kref: Implement kref_get_unless_zero v3.
- Delete patches.drm/3240-revert-rcu-lock-for-object-lookup.diff.
- commit 6b9508d
* Fri Feb 22 2013 jlee@suse.com
- MODSIGN: Fix including certificate twice when the
  signing_key.x509 already exists (bnc#805114).
- commit be1db34
* Fri Feb 22 2013 bpoirier@suse.de
- mlx4_core: Fix advertisement of wrong PF context behaviour
  (bnc#786036 FATE#314304).
- net/mlx4_core: Set number of msix vectors under SRIOV mode to
  firmware defaults (bnc#786036 FATE#314304).
- net/mlx4_en: Fix bridged vSwitch configuration for non SRIOV
  mode (bnc#786036 FATE#314304).
- mlx4_core: Allow choosing flow steering mode (bnc#786036
  FATE#314304).
- mlx4_core: Adjustments to Flow Steering activation logic for
  SR-IOV (bnc#786036 FATE#314304).
- mlx4_core: Fix error flow in the flow steering wrapper
  (bnc#786036 FATE#314304).
- mlx4_core: Add QPN enforcement for flow steering rules set by
  VFs (bnc#786036 FATE#314304).
- net/mlx4_en: Use generic etherdevice.h functions (bnc#786036
  FATE#314304).
- drivers/net: fix up function prototypes after __dev* removals
  (bnc#786036 FATE#314304).
- mlx4_core: remove __dev* attributes (bnc#786036 FATE#314304).
- net/mlx4_en: Set number of rx/tx channels using ethtool
  (bnc#786036 FATE#314304).
- net/mlx4_en: Fix TX moderation info loss after set_ringparam
  is called (bnc#786036 FATE#314304).
- mlx4_core: Fix potential deadlock in mlx4_eq_int() (bnc#786036
  FATE#314304).
- IB/mlx4: Fix spinlock order to avoid lockdep warnings
  (bnc#786036 FATE#314304).
- mlx4: 64-byte CQE/EQE support (bnc#786036 FATE#314304).
- mlx4_en: Remove remnants of LRO support (bnc#786036
  FATE#314304).
- commit f4beba5
* Fri Feb 22 2013 bpoirier@suse.de
- various: Fix spelling of "asynchronous" in comments (bnc#786036
  FATE#314304).
- mlx4: change TX coalescing defaults (bnc#786036 FATE#314304).
- net/mlx4_core: Unmap UAR also in the case of error flow
  (bnc#786036 FATE#314304).
- net/mlx4_en: Don't use vlan tag value as an indication for
  vlan presence (bnc#786036 FATE#314304).
- net/mlx4_en: Fix double-release-range in tx-rings (bnc#786036
  FATE#314304).
- mlx4_core: Perform correct resource cleanup if
  mlx4_QUERY_ADAPTER() fails (bnc#786036 FATE#314304).
- mlx4_core: Remove annoying debug messages from SR-IOV flow
  (bnc#786036 FATE#314304).
- IB/mlx4: Synchronize cleanup of MCGs in MCG paravirtualization
  (bnc#786036 FATE#314304).
- IB/mlx4: Fix QP1 P_Key processing in the Primary Physical
  Function (PPF) (bnc#786036 FATE#314304).
- IB/mlx4: Fix build error on platforms where UL is not 64 bits
  (bnc#786036 FATE#314304).
- mlx4_core: Adjust flow steering attach wrapper so that IB
  works on SR-IOV VFs (bnc#786036 FATE#314304).
- mlx4: dont orphan skbs in mlx4_en_xmit() (bnc#786036
  FATE#314304).
- mlx4_core: Disable SENSE_PORT for multifunction devices
  (bnc#786036 FATE#314304).
- mlx4_core: Clean up enabling of SENSE_PORT for older
  (ConnectX-1/-2) HCAs (bnc#786036 FATE#314304).
- mlx4_core: Stash PCI ID driver_data in mlx4_priv structure
  (bnc#786036 FATE#314304).
- mlx4_core: Fix crash on uninitialized priv->cmd.slave_sem
  (bnc#786036 FATE#314304).
- mlx4_core: Trivial cleanups to driver log messages (bnc#786036
  FATE#314304).
- mlx4_core: Trivial readability fix: "0X30" -> "0x30" (bnc#786036
  FATE#314304).
- IB/mlx4: Create paravirt contexts for VFs when master IB driver
  initializes (bnc#786036 FATE#314304).
- mlx4: Modify proxy/tunnel QP mechanism so that guests do no
  calculations (bnc#786036 FATE#314304).
- mlx4: Paravirtualize Node Guids for slaves (bnc#786036
  FATE#314304).
- mlx4: Activate SR-IOV mode for IB (bnc#786036 FATE#314304).
- IB/mlx4: Miscellaneous adjustments for SR-IOV IB support
  (bnc#786036 FATE#314304).
- mlx4_core: INIT/CLOSE port logic for IB ports in SR-IOV mode
  (bnc#786036 FATE#314304).
- net/mlx4_core: Adjustments to SET_PORT for IB SR-IOV (bnc#786036
  FATE#314304).
- IB/mlx4: Add iov directory in sysfs under the ib device
  (bnc#786036 FATE#314304).
- IB/mlx4: Propagate P_Key and guid change port management events
  to slaves (bnc#786036 FATE#314304).
- mlx4: Add alias_guid mechanism (bnc#786036 FATE#314304).
- IB/sa: Add GuidInfoRecord query support (bnc#786036
  FATE#314304).
- mlx4_core: Add IB port-state machine and port mgmt event
  propagation (bnc#786036 FATE#314304).
- IB/mlx4: Add CM paravirtualization (bnc#786036 FATE#314304).
- IB/core: Move CM_xxx_ATTR_ID macros from cm_msgs.h to ib_cm.h
  (bnc#786036 FATE#314304).
- IB/mlx4: Add multicast group (MCG) paravirtualization for SR-IOV
  (bnc#786036 FATE#314304).
- mlx4: MAD_IFC paravirtualization (bnc#786036 FATE#314304).
- IB/mlx4: SR-IOV multiplex and demultiplex MADs (bnc#786036
  FATE#314304).
- IB/core: Add ib_find_exact_cached_pkey() (bnc#786036
  FATE#314304).
- mlx4: Implement QP paravirtualization and maintain
  phys_pkey_cache for smp_snoop (bnc#786036 FATE#314304).
- IB/mlx4: Initialize SR-IOV IB support for slaves in master
  context (bnc#786036 FATE#314304).
- mlx4_core: Add proxy and tunnel QPs to the reserved QP area
  (bnc#786036 FATE#314304).
- IB/mlx4: SR-IOV IB context objects and proxy/tunnel SQP support
  (bnc#786036 FATE#314304).
- net/mlx4_core: Initialize IB port capabilities for all slaves
  (bnc#786036 FATE#314304).
- mlx4_core: Remove annoying debug message in the resource tracker
  (bnc#786036 FATE#314304).
- IB/mlx4: Fill in sq_sig_type in query QP (bnc#786036
  FATE#314304).
- mlx4_core: Fix integer overflows so 8TBs of memory registration
  works (bnc#786036 FATE#314304).
- netdev: make pci_error_handlers const (bnc#786036 FATE#314304).
- net/mlx4_core: Return the error value in case of command
  initialization failure (bnc#786036 FATE#314304).
- net/mlx4_core: Fixing error flow in case of QUERY_FW failure
  (bnc#786036 FATE#314304).
- net/mlx4_core: Looking for promiscuous entries on the correct
  port (bnc#786036 FATE#314304).
- net/mlx4_core: Add security check / enforcement for flow
  steering rules set for VMs (bnc#786036 FATE#314304).
- net/mlx4_core: Put Firmware flow steering structures in common
  header files (bnc#786036 FATE#314304).
- mlx4: Use PCI Express Capability accessors (bnc#786036
  FATE#314304).
- IB/mlx4: Check iboe netdev pointer before dereferencing it
  (bnc#786036 FATE#314304).
- mlx4_core: Clean up buddy bitmap allocation (bnc#786036
  FATE#314304).
- mlx4_core: Fix integer overflow issues around MTT table
  (bnc#786036 FATE#314304).
- mlx4_core: Allow large mlx4_buddy bitmaps (bnc#786036
  FATE#314304).
- drivers/net/ethernet/mellanox/mlx4/mcg.c: fix error return code
  (bnc#786036 FATE#314304).
- IB/mlx4: Fix possible deadlock on sm_lock spinlock (bnc#786036
  FATE#314304).
- net/mlx4_core: Remove port type restrictions (bnc#786036
  FATE#314304).
- net/mlx4_en: Fixing TX queue stop/wake flow (bnc#786036
  FATE#314304).
- net/mlx4_en: loopbacked packets are dropped when SMAC=DMAC
  (bnc#786036 FATE#314304).
- net/mlx4_en: Limit the RFS filter IDs to be < RPS_NO_FILTER
  (bnc#786036 FATE#314304).
- mlx4: Add support for EEH error recovery (bnc#786036
  FATE#314304).
- mlx4_en: map entire pages to increase throughput (bnc#786036
  FATE#314304).
- net/mlx4_en: Add accelerated RFS support (bnc#786036
  FATE#314304).
- {NET,IB}/mlx4: Add rmap support to mlx4_assign_eq (bnc#786036
  FATE#314304).
- net/mlx4: Move MAC_MASK to a common place (bnc#786036
  FATE#314304).
- net/mlx4_en: dereferencing freed memory (bnc#786036
  FATE#314304).
- net/mlx4: off by one in parse_trans_rule() (bnc#786036
  FATE#314304).
- mlx4: Put physical GID and P_Key table sizes in mlx4_phys_caps
  struct and paravirtualize them (bnc#786036 FATE#314304).
- mlx4_core: Allow guests to have IB ports (bnc#786036
  FATE#314304).
- mlx4_core: Implement mechanism for reserved Q_Keys (bnc#786036
  FATE#314304).
- net/mlx4_core: Free ICM table in case of error (bnc#786036
  FATE#314304).
- mlx4_core: Remove double function declarations (bnc#786036
  FATE#314304).
- IB/mlx4: Fill the masked_atomic_cap attribute in query device
  (bnc#786036 FATE#314304).
- mlx4: Use port management change event instead of smp_snoop
  (bnc#786036 FATE#314304).
- IB/mlx4: Generate GID change events in IBoE code (bnc#786036
  FATE#314304).
- IB/core: Add GID change event (bnc#786036 FATE#314304).
- IB/mlx4: Add debug prints (bnc#786036 FATE#314304).
- mlx4_core: Pass an invalid PCI id number to VFs (bnc#786036
  FATE#314304).
- net/mlx4_en: Add support for drop action through ethtool
  (bnc#786036 FATE#314304).
- net/mlx4_en: Manage flow steering rules with ethtool (bnc#786036
  FATE#314304).
- net/mlx4: Implement promiscuous mode with device managed
  flow-steering (bnc#786036 FATE#314304).
- net/mlx4_core: Add resource tracking for device managed flow
  steering rules (bnc#786036 FATE#314304).
- {NET, IB}/mlx4: Add device managed flow steering firmware API
  (bnc#786036 FATE#314304).
- net/mlx4_core: Add firmware commands to support device managed
  flow steering (bnc#786036 FATE#314304).
- net/mlx4: Set steering mode according to device capabilities
  (bnc#786036 FATE#314304).
- net/mlx4_en: Re-design multicast attachments flow (bnc#786036
  FATE#314304).
- net/mlx4_core: Change resource tracking ID to be 64 bit
  (bnc#786036 FATE#314304).
- net/mlx4_core: Change resource tracking mechanism to use
  red-black tree (bnc#786036 FATE#314304).
- mlx4: set maximal number of default RSS queues (bnc#786036
  FATE#314304).
- net/mlx4_en: Release QP range in free_resources (bnc#786036
  FATE#314304).
- net/mlx4: Use single completion vector after NOP failure
  (bnc#786036 FATE#314304).
- net/mlx4_en: Set correct port parameters during device
  initialization (bnc#786036 FATE#314304).
- IB/mlx4: Fix max_wqe capacity reported from query device
  (bnc#786036 FATE#314304).
- mlx4_core: Fix setting VL_cap in mlx4_SET_PORT wrapper flow
  (bnc#786036 FATE#314304).
- ethernet: Remove casts to same type (bnc#786036 FATE#314304).
- IB/mlx4: Fix EQ deallocation in legacy mode (bnc#786036
  FATE#314304).
- net/mlx4_core: Fix obscure mlx4_cmd_box parameter in
  QUERY_DEV_CAP (bnc#786036 FATE#314304).
- net/mlx4_core: Check port out-of-range before using in
  mlx4_slave_cap (bnc#786036 FATE#314304).
- net/mlx4_core: Fixes for VF / Guest startup flow (bnc#786036
  FATE#314304).
- net/mlx4_en: Fix improper use of "port" parameter in
  mlx4_en_event (bnc#786036 FATE#314304).
- net/mlx4_core: Fix number of EQs used in ICM initialisation
  (bnc#786036 FATE#314304).
- net/mlx4_core: Fix the slave_id out-of-range test in mlx4_eq_int
  (bnc#786036 FATE#314304).
- IB/mlx4: Fix mlx4_ib_add() error flow (bnc#786036 FATE#314304).
- IB/mlx4: Increase the number of vectors (EQs) available for ULPs
  (bnc#786036 FATE#314304).
- net/mlx4_en: num cores tx rings for every UP (bnc#786036
  FATE#314304).
- net/mlx4_core: Fixed error flow in rem_slave_eqs (bnc#786036
  FATE#314304).
- net/mlx4_core: Add XRC domains and counters to resource tracker
  (bnc#786036 FATE#314304).
- net/mlx4_core: Fix potential kernel Oops in res tracker during
  Dom0 driver unload (bnc#786036 FATE#314304).
- net/mlx4_core: Do not reset module-parameter num_vfs when fail
  to enable sriov (bnc#786036 FATE#314304).
- net/mlx4_core: Remove unused *_str functions from the resource
  tracker (bnc#786036 FATE#314304).
- net/mlx4_core: Change SYNC_TPT to be native (not wrapped)
  (bnc#786036 FATE#314304).
- net/mlx4_core: Fix init_port mask state for slaves (bnc#786036
  FATE#314304).
- net/mlx4: Address build warnings on set but not used variables
  (bnc#786036 FATE#314304).
- mlx4_core: Change bitmap allocator to work in round-robin
  fashion (bnc#786036 FATE#314304).
- IB/mlx4: Replace printk(KERN_yyy...) with
  pr_yyy(...) (bnc#786036 FATE#314304).
- mlx4_core: Add second capabilities flags field (bnc#786036
  FATE#314304).
- IB/mlx4: Put priority bits in WQE of IBoE MLX QP (bnc#786036
  FATE#314304).
- IB/mlx4: Add raw packet QP support (bnc#786036 FATE#314304).
- IB/core: Add raw packet QP type (bnc#786036 FATE#314304).
- RDMA/core: Add XRC QPs (bnc#786036 FATE#314304).
- mlx4_en: Byte Queue Limit support (bnc#786036 FATE#314304).
- mlx4_en: Moving to Interrupts for TX completions (bnc#786036
  FATE#314304).
- mlx4_en: Added Ethtool support for TX Interrupt coalescing
  (bnc#786036 FATE#314304).
- net: Fix spelling typo in net (bnc#786036 FATE#314304).
- net/mlx4_en: sk_prio <=> UP for untagged traffic (bnc#786036
  FATE#314304).
- commit 01ac819
* Fri Feb 22 2013 bpoirier@suse.de
- net/mlx4_en: DCB QoS support (bnc#786036 FATE#314304).
- Update config files.
- commit a5fd292
* Fri Feb 22 2013 bpoirier@suse.de
- net/mlx4_core: set port QoS attributes (bnc#786036 FATE#314304).
- net/mlx4_en: Force user priority by QP attribute (bnc#786036
  FATE#314304).
- mlx4: allocate just enough pages instead of always 4 pages
  (bnc#786036 FATE#314304).
- IB/mlx4: Don't return an invalid speed when a port is down
  (bnc#786036 FATE#314304).
- mlx4_core: fix race on comm channel (bnc#786036 FATE#314304).
- device.h: audit and cleanup users in main include dir
  (bnc#786036 FATE#314304).
- mlx4_core: Report thermal error events (bnc#786036 FATE#314304).
- mlx4_core: Fix one more static exported function (bnc#786036
  FATE#314304).
- mlx4_core: fix bug in modify_cq wrapper for resize flow
  (bnc#786036 FATE#314304).
- mlx4_core: Get rid of redundant ext_port_cap flags (bnc#786036
  FATE#314304).
- net/mlx4: defining functions as static (bnc#786036 FATE#314304).
- net/mlx4: remove unused functions (bnc#786036 FATE#314304).
- net/mlx4: fixing sparse warnings for not declared, functions
  (bnc#786036 FATE#314304).
- net/mlx4: fixing sparse warnings when copying mac, address to
  gid entry (bnc#786036 FATE#314304).
- net/mlx4: fix sparse warnings on wrong type for RSS keys
  (bnc#786036 FATE#314304).
- net/mlx4: fix sparse warnings on TX blue flame buffer
  (bnc#786036 FATE#314304).
- net/mlx4: fix sparse warnings on TX control flags, endianess
  (bnc#786036 FATE#314304).
- net/mlx4_en: Saving mem access on data path (bnc#786036
  FATE#314304).
- mlx4_core: remove buggy sched_queue masking (bnc#786036
  FATE#314304).
- mlx4_en: remove sparse errors (bnc#786036 FATE#314304).
- mlx4_en: dont change mac_header on xmit (bnc#786036
  FATE#314304).
- mlx4_core: Scale size of MTT table with system RAM (bnc#786036
  FATE#314304).
- mlx4_core: Allow dynamic MTU configuration for IB ports
  (bnc#786036 FATE#314304).
- IB/mlx4: Fix info returned when querying IBoE ports (bnc#786036
  FATE#314304).
- IB/mlx4: Fix possible missed completion event (bnc#786036
  FATE#314304).
- mlx4: Enforce device max FMR maps in FMR alloc (bnc#786036
  FATE#314304).
- IB/mlx4: Set bad_wr for invalid send opcode (bnc#786036
  FATE#314304).
- mlx4_core: Fixing array indexes when setting port types
  (bnc#786036 FATE#314304).
- mlx4_core: Exported functions can't be static (bnc#786036
  FATE#314304).
- mlx4: Setting new port types after all interfaces unregistered
  (bnc#786036 FATE#314304).
- mlx4: Replacing pool_lock with mutex (bnc#786036 FATE#314304).
- mlx4_core: Do not map BF area if capability is 0 (bnc#786036
  FATE#314304).
- mlx4: add unicast steering entries to resource_tracker
  (bnc#786036 FATE#314304).
- mlx4: attach multicast with correct flag (bnc#786036
  FATE#314304).
- mlx4: remove redundant adding of steering type to gid
  (bnc#786036 FATE#314304).
- mlx4: remove unnecessary variables and arguments (bnc#786036
  FATE#314304).
- mlx4: remove unused field high_prios (bnc#786036 FATE#314304).
- mlx4: fix QP tree trashing (bnc#786036 FATE#314304).
- mlx4_core: fix buffer overrun (bnc#786036 FATE#314304).
- mlx4: Fix kcalloc parameters swapped (bnc#786036 FATE#314304).
- mlx4: fix DMA mapping leak when allocation fails (bnc#786036
  FATE#314304).
- mlx4: allow device removal by fixing dma unmap size (bnc#786036
  FATE#314304).
- mlx4_core: use correct port for steering (bnc#786036
  FATE#314304).
- mlx4_core: use correct flag for unicast_promisc (bnc#786036
  FATE#314304).
- mlx4_core: fix memory leak at multi_func_cleanup (bnc#786036
  FATE#314304).
- netdev: ethernet dev_alloc_skb to netdev_alloc_skb (bnc#786036
  FATE#314304).
- mlx4: Fix typo in cmd.c (bnc#786036 FATE#314304).
- drivers/net: Remove alloc_etherdev error messages (bnc#786036
  FATE#314304).
- drivers/net: Remove unnecessary k.alloc/v.alloc OOM messages
  (bnc#786036 FATE#314304).
- mlx4_core: map async events to arbitrary slave eqs (bnc#786036
  FATE#314304).
- mlx4_core: Fix mtt profile issue (bnc#786036 FATE#314304).
- mlx4_core: removed function index from vf (bnc#786036
  FATE#314304).
- mlx4_en: eth statistics modification (bnc#786036 FATE#314304).
- mlx4: VF is not allowed to perform dump stats (bnc#786036
  FATE#314304).
- mlx4_en: clear all eth statistics when port goes up (bnc#786036
  FATE#314304).
- mlx4_en: set number of rx rings used by RSS using ethtool
  (bnc#786036 FATE#314304).
- IB/mlx4: Fix SL to 802.1Q priority-bits mapping for IBoE
  (bnc#786036 FATE#314304).
- mlx4_core: Elaborating limitation on VF port options (bnc#786036
  FATE#314304).
- mlx4_core: fix mtt range deallocation (bnc#786036 FATE#314304).
- mlx4_core: limiting VF port options (bnc#786036 FATE#314304).
- mlx4_core: using array index for sense_allowed (bnc#786036
  FATE#314304).
- mlx4: Add missing include of linux/slab.h (bnc#786036
  FATE#314304).
- mlx4_en: FIX: Setting default_qpn before using it (bnc#786036
  FATE#314304).
- module_param: make bool parameters really bool (net &
  drivers/net) (bnc#786036 FATE#314304).
- mlx4: Fixing wrong error codes in communication channel
  (bnc#786036 FATE#314304).
- mlx4: not using spin_lock_irq when getting vf by resource
  (bnc#786036 FATE#314304).
- mlx4_en: nullify cached multicast address list after cleanup
  (bnc#786036 FATE#314304).
- mlx4_core: Changing link sensing logic (bnc#786036 FATE#314304).
- mlx4: capability for link sensing (bnc#786036 FATE#314304).
- mlx4: Fix compile error when driver is comiled-in (bnc#786036
  FATE#314304).
- mlx4_en: updated driver version to 2.0 (bnc#786036 FATE#314304).
- mlx4_core: updated driver version to 1.1 (bnc#786036
  FATE#314304).
- mlx4_core: Modify driver initialization flow to accommodate
  SRIOV for Ethernet (bnc#786036 FATE#314304).
- mlx4_core: adjust catas operation for SRIOV mode (bnc#786036
  FATE#314304).
- mlx4_core: mtts resources units changed to offset (bnc#786036
  FATE#314304).
- mlx4_en: Allow communication between functions on same host
  (bnc#786036 FATE#314304).
- mlx4: Ethernet port management modifications (bnc#786036
  FATE#314304).
- mlx4: Traffic steering management support for SRIOV (bnc#786036
  FATE#314304).
- mlx4_ib: disable SRIOV mode for IB ports (not yet supported)
  (bnc#786036 FATE#314304).
- mlx4_core: resource tracking for HCA resources used by guests
  (bnc#786036 FATE#314304).
- mlx4_core: Add wrapper functions and comm channel and slave
  event support to EQs (bnc#786036 FATE#314304).
- mlx4_core: mtt modifications for SRIOV (bnc#786036 FATE#314304).
- mlx4_core: cq modifications for SRIOV (bnc#786036 FATE#314304).
- mlx4_core: qp modifications for SRIOV (bnc#786036 FATE#314304).
- mlx4_core: srq modifications for SRIOV (bnc#786036 FATE#314304).
- mlx4_core: Added FW commands and their wrappers for supporting
  SRIOV (bnc#786036 FATE#314304).
- net/mlx4_core: Implement the master-slave communication channel
  (bnc#786036 FATE#314304).
- mlx4_core: Reduce number of PD bits to 17 (bnc#786036
  FATE#314304).
- mlx4_core: Add "native" argument to mlx4_cmd and its callers
  (where needed) (bnc#786036 FATE#314304).
- mlx4: Extanding port_mask functionality (bnc#786036
  FATE#314304).
- mlx4_core: initial header-file changes for SRIOV support
  (bnc#786036 FATE#314304).
- net/mlx4_en: bug fix for the case of vlan id 0 and UP 0
  (bnc#786036 FATE#314304).
- net/mlx4_en: adding loopback support (bnc#786036 FATE#314304).
- net/mlx4_en: fix WOL handlers were always looking at port2
  capability bit (bnc#786036 FATE#314304).
- net/mlx4_en: using non collapsed CQ on TX (bnc#786036
  FATE#314304).
- net/mlx4_en: fix sparse warning on a cast which truncates bits
  from constant value (bnc#786036 FATE#314304).
- net/mlx4: fix UDP RSS related settings (bnc#786036 FATE#314304).
- net/mlx4: move RSS related definitions to be global (bnc#786036
  FATE#314304).
- Sweep the last of the active .get_drvinfo floors under ethernet/
  (bnc#786036 FATE#314304).
- mlx4_en: nullify cq->vector field when closing completion queue
  (bnc#786036 FATE#314304).
- IB/mlx4: Fix shutdown crash accessing a non-existent bitmap
  (bnc#786036 FATE#314304).
- mlx4_en: Remove FCS bytes from packet length (bnc#786036
  FATE#314304).
- treewide: use __printf not
  __attribute__((format(printf,...))) (bnc#786036 FATE#314304).
- drivers/net: Add moduleparam.h to drivers as required
  (bnc#786036 FATE#314304).
- drivers/net: Add module.h to drivers who were implicitly using
  it (bnc#786036 FATE#314304).
- mlx4_core: Deprecate log_num_vlan module param (bnc#786036
  FATE#314304).
- IB/mlx4: Don't set VLAN in IBoE WQEs' control segment
  (bnc#786036 FATE#314304).
- IB/mlx4: Enable 4K mtu for IBoE (bnc#786036 FATE#314304).
- IB/mlx4: Configure extended active speeds (bnc#786036
  FATE#314304).
- mlx4_core: Add extended port capabilities support (bnc#786036
  FATE#314304).
- mlx4: convert to SKB paged frag API (bnc#786036 FATE#314304).
- mlx4_en: fix skb truesize underestimation (bnc#786036
  FATE#314304).
- mlx4_en: Updating driver version (bnc#786036 FATE#314304).
- mlx4_en: Adding rxhash support (bnc#786036 FATE#314304).
- mlx4_en: Recording rx queue for gro packets (bnc#786036
  FATE#314304).
- mlx4_en: Checksum counters per ring (bnc#786036 FATE#314304).
- mlx4_en: Controlling FCS header removal (bnc#786036
  FATE#314304).
- mlx4: Fix vlan table overflow (bnc#786036 FATE#314304).
- net: add skb frag size accessors (bnc#786036 FATE#314304).
- mlx4_en: fix endianness with blue frame support (bnc#786036
  FATE#314304).
- mlx4_en: Adding 40gb speed report for ethtool (bnc#786036
  FATE#314304).
- mlx4_en: Fix crash upon device initialization error (bnc#786036
  FATE#314304).
- mlx4_en: Fix QP number calculation according to module param
  (bnc#786036 FATE#314304).
- mlx4_en: Added missing iounmap upon releasing a device
  (bnc#786036 FATE#314304).
- mlx4_en: Adjusting moderation per each ring (bnc#786036
  FATE#314304).
- mlx4_en: Removing reserve vectors (bnc#786036 FATE#314304).
- mlx4_en: Assigning TX irq per ring (bnc#786036 FATE#314304).
- mlx4_core: Fix buddy->num_free allocation size (bnc#786036
  FATE#314304).
- mlx4_core: Use the right function to free eq->page_list entries
  (bnc#786036 FATE#314304).
- mlx4_core: Clean up error flow in mlx4_register_mac()
  (bnc#786036 FATE#314304).
- net: remove use of ndo_set_multicast_list in drivers (bnc#786036
  FATE#314304).
- commit 5a758ed
* Fri Feb 22 2013 bpoirier@suse.de
- mlx4: Fix infiniband Kconfig dependencies (bnc#786036
  FATE#314304).
- commit efdbfa5
* Fri Feb 22 2013 bpoirier@suse.de
- mlx4: Move the Mellanox driver (bnc#786036 FATE#314304).
- Update config files.
- supported.conf:
- commit 5b07cd9
* Fri Feb 22 2013 bpoirier@suse.de
- Update config files.
- commit d92a5c0
* Fri Feb 22 2013 bpoirier@suse.de
- mlx4: decreasing ref count when removing mac (bnc#786036
  FATE#314304).
- mlx4: Fixing Ethernet unicast packet steering (bnc#786036
  FATE#314304).
- atomic: use <linux/atomic.h> (bnc#786036 FATE#314304).
- mlx4_core: Bump the driver version to 1.0 (bnc#786036
  FATE#314304).
- mlx4: do vlan cleanup (bnc#786036 FATE#314304).
- IB/mlx4: Use flow counters on IBoE ports (bnc#786036
  FATE#314304).
- mlx4_core: Add network flow counters (bnc#786036 FATE#314304).
- mlx4_core: Fix location of counter index in QP context struct
  (bnc#786036 FATE#314304).
- mlx4_core: Read extended capabilities into the flags field
  (bnc#786036 FATE#314304).
- mlx4_core: Extend capability flags to 64 bits (bnc#786036
  FATE#314304).
- mlx4: remove unnecessary read of PCI_CAP_ID_EXP (bnc#786036
  FATE#314304).
- mlx4: use pci_dev->revision (bnc#786036 FATE#314304).
- IB/mlx4: remove __devinit from mlx4_init_xrcd_table()
  (bnc#786036 FATE#314304).
- commit 4941b91
* Fri Feb 22 2013 dsterba@suse.cz
- Btrfs: fix crash in log replay with qgroups enabled
  (FATE#312888).
- btrfs: access superblock via pagecache in scan_one_device
  (FATE#312888).
- Btrfs: use slabs for delayed reference allocation (FATE#312888).
- Btrfs: cleanup unnecessary clear when freeing a transaction
  or a trans handle (FATE#312888).
- Btrfs: use common work instead of delayed work (FATE#312888).
- Btrfs: cleanup similar code in delayed inode (FATE#312888).
- Btrfs: fix lots of orphan inodes when the space is not enough
  (FATE#312888).
- Btrfs: make delayed ref lock logic more readable (FATE#312888).
- Btrfs: flush all dirty inodes if writeback can not start
  (FATE#312888).
- Btrfs: use wrapper page_offset (FATE#312888).
- Btrfs: fix trivial error in btrfs_ioctl_resize() (FATE#312888).
- Btrfs: wait on ordered extents at the last possible moment
  (FATE#312888).
- Btrfs: don't re-enter when allocating a chunk (FATE#312888).
- Btrfs: remove deprecated comments (FATE#312888).
- Btrfs: kill unused arguments of cache_block_group (FATE#312888).
- Btrfs: kill unused argument of update_block_group (FATE#312888).
- Btrfs: kill unused argument of btrfs_pin_extent_for_log_replay
  (FATE#312888).
- Btrfs: use token to avoid times mapping extent buffer
  (FATE#312888).
- Btrfs: save us a read_lock (FATE#312888).
- Btrfs: record first logical byte in memory (FATE#312888).
- Btrfs: make raid attr array more readable (FATE#312888).
- Btrfs: check the return value of btrfs_start_delalloc_inodes()
  (FATE#312888).
- Btrfs: check the return value of btrfs_run_ordered_operations()
  (FATE#312888).
- Btrfs: traverse and flush the delalloc inodes once
  (FATE#312888).
- Btrfs: don't traverse the ordered operation list repeatedly
  (FATE#312888).
- Btrfs: Check CAP_DAC_READ_SEARCH for BTRFS_IOC_INO_PATHS
  (FATE#312888).
- Btrfs: protect fs_info->alloc_start (FATE#312888).
- Btrfs: use percpu counter for dirty metadata count
  (FATE#312888).
- Btrfs: use percpu counter for fs_info->delalloc_bytes
  (FATE#312888).
- Btrfs: use the inode own lock to protect its delalloc_bytes
  (FATE#312888).
- Btrfs: use seqlock to protect fs_info->avail_{data, metadata,
  system}_alloc_bits (FATE#312888).
- Btrfs: use bit operation for ->fs_state (FATE#312888).
- Btrfs: fix chunk allocation error handling (FATE#312888).
- Btrfs: remove extent mapping if we fail to add chunk
  (FATE#312888).
- Btrfs: do not overcommit if we don't have enough space for
  global rsv (FATE#312888).
- btrfs: remove unused fd in btrfs_ioctl_send() (FATE#312888).
- btrfs: list_entry can't return NULL (FATE#312888).
- btrfs: remove unused fs_info from btrfs_decode_error()
  (FATE#312888).
- btrfs: handle null fs_info in btrfs_panic() (FATE#312888).
- btrfs: annotate intentional switch case fallthroughs
  (FATE#312888).
- btrfs: add missing break in btrfs_print_leaf() (FATE#312888).
- btrfs: fix varargs in __btrfs_std_error (FATE#312888).
- btrfs: remove unused "item" in btrfs_insert_delayed_item()
  (FATE#312888).
- btrfs: remove unnecessary DEFINE_WAIT() declarations
  (FATE#312888).
- btrfs: ensure we don't overrun devices_info[] in
  __btrfs_alloc_chunk (FATE#312888).
- Btrfs: fix freeing delayed ref head while still holding its
  mutex (FATE#312888).
- Btrfs: fix how we discard outstanding ordered extents on abort
  (FATE#312888).
- Btrfs: unreserve space if our ordered extent fails to work
  (FATE#312888).
- Btrfs: account for orphan inodes properly during cleanup
  (FATE#312888).
- Btrfs: rework the overcommit logic to be based on the total size
  (FATE#312888).
- Btrfs: handle errors in compression submission path
  (FATE#312888).
- Btrfs: if we aren't committing just end the transaction if we
  error out (FATE#312888).
- btrfs: remove cache only arguments from defrag path
  (FATE#312888).
- Btrfs: extend the checksum item as much as possible
  (FATE#312888).
- btrfs: add "no file data" flag to btrfs send ioctl (FATE#312888
  FATE#311399).
- Btrfs: fix the race between bio and btrfs_stop_workers
  (FATE#312888).
- Btrfs: fix memory leak of pending_snapshot->inherit
  (FATE#312888).
- Btrfs: steal from global reserve if we are cleaning up orphans
  (FATE#312888).
- Btrfs: cleanup orphan reservation if truncate fails
  (FATE#312888).
- Btrfs: fix deadlock due to unsubmitted (FATE#312888).
- Btrfs: serialize unlocked dio reads with truncate (FATE#312888).
- Btrfs: implement unlocked dio write (FATE#312888).
- btrfs: put some enospc messages under enospc_debug
  (FATE#312888).
- btrfs: add cancellation points to defrag (FATE#312888).
- Btrfs: remove unused extent io tree ops V2 (FATE#312888).
- Btrfs: eliminate a use-after-free in btrfs_balance()
  (FATE#312888).
- Btrfs: allow for selecting only completely empty chunks
  (FATE#312888).
- Btrfs: relax the block group size limit for bitmaps
  (FATE#312888).
- Btrfs: place ordered operations on a per transaction list
  (FATE#312888).
- Btrfs: Add a new ioctl to get the label of a mounted file system
  (FATE#312888).
- Btrfs: set/change the label of a mounted file system
  (FATE#312888).
- btrfs: define BTRFS_MAGIC as a u64 value (FATE#312888).
- Btrfs: fix the qgroup reserved space is released prematurely
  (FATE#312888).
- Btrfs: fix the deadlock between the transaction start/attach
  and commit (FATE#312888).
- Btrfs: fix uncompleted transaction (FATE#312888).
- Btrfs: fix cleaner thread not working with inode cache option
  (FATE#312888).
- Btrfs: fix missing check before disabling quota (FATE#312888).
- Btrfs: fix missing release of qgroup reservation in
  commit_transaction() (FATE#312888).
- Btrfs: add rw argument to merge_bio_hook() (FATE#312888).
- Btrfs: reduce lock contention on extent buffer locks
  (FATE#312888).
- Btrfs: reduce CPU contention while waiting for delayed extent
  operations (FATE#312888).
- btrfs: Init io_lock after cloning btrfs device struct
  (FATE#312888).
- btrfs: limit fallocate extent reservation to 256MB
  (FATE#312888).
- Btrfs: snapshot-aware defrag (FATE#312888).
- Btrfs: fix wrong outstanding_extents when doing DIO write
  (FATE#312888).
- Btrfs: fix remount vs autodefrag (FATE#312888).
- Refresh
  patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch.
- Refresh
  patches.suse/btrfs-8021-Prefix-mount-messages-with-btrfs-for-clarity.patch.
- Refresh
  patches.suse/btrfs-8024-workaround-for-cleaner-deadlock.patch.
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- Refresh patches.suse/btrfs-update-message-levels.patch.
- Delete
  patches.suse/btrfs-8094-flush-all-the-dirty-pages-if-try_to_writeback_.patch.
- Delete
  patches.suse/btrfs-8189-use-common-work-instead-of-delayed-work.patch.
- Delete
  patches.suse/btrfs-8190-limit-fallocate-extent-reservation-to-256MB.patch.
- Delete
  patches.suse/btrfs-add-no-file-data-flag-to-btrfs-send-ioctl.patch.
- Delete patches.suse/btrfs-enospc-debugging-messages.patch.
- commit 5c46fd0
* Fri Feb 22 2013 bpoirier@suse.de
- Rename patches.drivers/mlx3-use-GFP_NOFS-during-ipoib-tx-path.patch
  Discrepancy between Subject and file name. It's for mlx4, not "mlx3".
- commit dc98386
* Fri Feb 22 2013 dsterba@suse.cz
- Btrfs: Fix typo in fs/btrfs.
- Btrfs: don't start a new transaction when starting sync
  (FATE#312888).
- Refresh
  patches.suse/btrfs-0852-recheck-bio-against-block-device-when-we-map-t.patch.
- Refresh
  patches.suse/btrfs-8189-use-common-work-instead-of-delayed-work.patch.
- Delete patches.suse/btrfs-8202-Fix-typo-in-fs-btrfs.patch.
- commit 16a9d7d
* Fri Feb 22 2013 jbohac@suse.cz
- net: export the receive time stamping hook for non-NAPI drivers
  (fate#314848).
- net: export time stamp utility function for Ethernet MAC drivers
  (fate#314848).
- net: introduce ptp one step time stamp mode for sync packets
  (fate#314848).
- pch_gbe: correct receive time stamp filtering (fate#314848).
- pch_gbe: do not set the channel control register (fate#314848).
- pch_gbe: export a method to set the receive match address
  (fate#314848).
- pch_gbe, ptp_pch: Fix the dependency direction between these
  drivers (fate#314848).
- pps: class_create() returns an ERR_PTR, not NULL (fate#314848).
- pps: default echo function (fate#314848).
- pps, ptp: Remove dependencies on EXPERIMENTAL (fate#314848).
- pps: return PTR_ERR on error in device_create (fate#314848).
- ptp: add an ioctl to compare PHC time with system time
  (fate#314848).
- ptp: Enable clock drivers along with associated net/PHY drivers
  (fate#314848).
- ptp: link the phc device to its parent device (fate#314848).
- ptp: Make PTP_1588_CLOCK select rather than depend on PPS
  (fate#314848).
- ptp: provide the clock's adjusted frequency (fate#314848).
- ptp: remember the adjusted frequency (fate#314848).
- ptp_pch: Add missing #include <linux/slab.h> (fate#314848).
- ptp_pch: rename pch_pcidev to pci_driver to fix section mismatch
  (fate#314848).
- net/pch_gbe: supports eg20t ptp clock (fate#314848).
- supports eg20t ptp clock (fate#314848).
- Update config files.
- Refresh
  patches.drivers/tg3-0099-tg3-PTP-Implement-the-ptp-api-and-ethtool-functions.patch.
- supported.conf: add ptp and pps-core
- commit 5283bd8
* Thu Feb 21 2013 bpoirier@suse.de
- Remove mlx4 patches according to the vendor's patch series
- Delete
  patches.drivers/IB-0003-mlx4_core-Add-extended-port-capabilities-support.patch.
- Delete
  patches.drivers/IB-0004-mlx4-Configure-extended-active-speeds.patch.
- Delete patches.drivers/ib_mlx4_check_iboe_pointer.patch.
- Delete patches.drivers/mlx4_eeh_recovery.patch.
- Delete
  patches.drivers/mlx4_en-0001-fix-endianness-with-blue-frame-support.patch.
- Delete
  patches.drivers/mlx4_en-map-entire-pages-to-increase-throughput.
- commit 6695d05
* Thu Feb 21 2013 bpoirier@suse.de
- Remove recent mlx4 patches
- Delete
  patches.drivers/0001-mlx4_en-Adding-40gb-speed-report-for-ethtool.patch.
- Delete
  patches.drivers/0002-mlx4_core-Extend-capability-flags-to-64-bits.patch.
- Delete
  patches.drivers/0003-mlx4-capability-for-link-sensing.patch.
- Delete
  patches.drivers/0004-mlx4_core-Stash-PCI-ID-driver_data-in-mlx4_priv-str.patch.
- Delete
  patches.drivers/0005-mlx4_core-Clean-up-enabling-of-SENSE_PORT-for-older.patch.
- Delete
  patches.drivers/0006-mlx4_en-fix-skb-truesize-underestimation.patch.
- Delete
  patches.drivers/0007-mlx4_en-nullify-cached-multicast-address-list-after.patch.
- Delete
  patches.drivers/0008-mlx4-allocate-just-enough-pages-instead-of-always-4.patch.
- Delete
  patches.drivers/0009-net-mlx4_core-Remove-port-type-restrictions.patch.
- commit ef4ad8d
* Thu Feb 21 2013 bpoirier@suse.de
- Remove mlx4 patches that can be inserted in the vendor's series
- Delete
  patches.drivers/0001-mlx4_en-Added-missing-iounmap-upon-releasing-a-devic.patch.
- Delete
  patches.drivers/0002-mlx4-allow-device-removal-by-fixing-dma-unmap-size.patch.
- Delete patches.drivers/mlx4_en-Assigning-TX-irq-per-ring.patch.
- commit 85c6aec
* Thu Feb 21 2013 msrb@novell.com
- Delete updates of exynos driver.
- Refresh patches.drm/0315-vmwgfx-take-the-driver-out-of-staging.
- Refresh patches.drm/0535-drm-replace-pitch-with-pitches-in-drm_framebuffer.
- Refresh patches.drm/0698-drm-add-support-for-private-planes.
- Refresh patches.drm/0961-drm-drop-setting-vm_file-to-filp.
- Refresh patches.drm/1037-drm-udl-initial-udl-driver-v4.
- Refresh patches.drm/1596-drm-initial-kms-driver-for-ast-aspeed-technologies-2000-series-v2.
- Refresh patches.drm/1669-drm-constify-gem_vm_ops-pointer.
- Refresh patches.drm/1670-drm-constify-drm_mode_config_funcs-pointer.
- Refresh patches.drm/2011-drm-make-the-mode_fixup-operations-mode-argument-a-const-pointer.
- Refresh patches.drm/2180-drm-use-drm_compat_ioctl-for-32-bit-apps.
- Refresh patches.drm/2290-workqueue-deprecate-flush_work_sync.
- Refresh patches.drm/2308-drm-remove-the-raw_edid-field-from-struct-drm_display_info.
- Refresh patches.drm/2540-drm-refcnt-drm_framebuffer-v4-1.
- Refresh patches.drm/2551-uapi-scripted-remove-redundant-drm-uapi-header-inclusions-from-drivers-gpu.
- Refresh patches.drm/2552-uapi-scripted-convert-include-to-include-path-in-drivers-gpu.
- Refresh patches.drm/2553-uapi-scripted-convert-include-to-include-path-in-kernel-system-headers.
- Delete patches.drm/0306-drm-add-drm-driver-for-samsung-soc-exynos4210.
- Delete patches.drm/0327-drm-exynos-fixed-overlay-data-updating.
- Delete patches.drm/0328-drm-exynos-fixed-overlay-updating-time-at-page-flip.
- Delete patches.drm/0329-drm-exynos-added-device-object-as-argument-of-subdrv_probe.
- Delete patches.drm/0330-drm-exynos-fixed-bug-to-exynos_drm_fb_dev_reinit.
- Delete patches.drm/0331-drm-exynos-added-comments-and-code-clean.
- Delete patches.drm/0332-drm-exynos-fixed-page-flip-bug.
- Delete patches.drm/0333-drm-exynos-fixed-build-warnings-and-comments.
- Delete patches.drm/0430-drm-exynos-added-padding-to-be-64-bit-align.
- Delete patches.drm/0437-drm-exynos-added-kms-poll-for-handling-hpd-event.
- Delete patches.drm/0438-drm-exynos-fixed-connector-flag-with-hpd-and-interlace-scan-for-hdmi.
- Delete patches.drm/0439-drm-exynos-fixed-converting-between-display-mode-and-timing.
- Delete patches.drm/0440-drm-exynos-added-manager-object-to-connector.
- Delete patches.drm/0441-drm-exynos-changed-exynos_drm_display-to-exynos_drm_display_ops.
- Delete patches.drm/0442-drm-exynos-restored-kernel_fb_list-when-reiniting-fb_helper.
- Delete patches.drm/0443-drm-exynos-removed-meaningless-parameter-from-fbdev-update.
- Delete patches.drm/0444-drm-exynos-added-crtc-dpms-for-disable-crtc.
- Delete patches.drm/0445-drm-exynos-checked-for-null-pointer.
- Delete patches.drm/0446-drm-exynos-use-gem-create-function-generically.
- Delete patches.drm/0447-drm-exynos-removed-unnecessary-variable.
- Delete patches.drm/0448-drm-exynos-changed-buffer-structure.
- Delete patches.drm/0449-drm-exynos-fix-vblank-bug.
- Delete patches.drm/0450-drm-exynos-include-linux-module-h.
- Delete patches.drm/0452-drm-exynos-add-disable-of-manager.
- Delete patches.drm/0453-drm-exynos-fixed-wrong-err-ptr-usage-and-destroy-call-in-exeception.
- Delete patches.drm/0559-drm-exynos-fix-compile-errors.
- Delete patches.drm/0560-drm-exynos-use-struct-drm_mode_fb_cmd2.
- Delete patches.drm/0561-drm-exynos-updated-crtc-and-encoder-dpms-framework.
- Delete patches.drm/0562-drm-exynos-add-runtime-pm-feature-for-fimd.
- Delete patches.drm/0563-drm-exynos-add-plane-support-with-fimd.
- Delete patches.drm/0679-drm-exynos-gem-code-cleanup.
- Delete patches.drm/0680-drm-exynos-fix-a-fake-mmap-offset-creation.
- Delete patches.drm/0681-drm-exynos-split-creation-of-gem-object-and-gem-handle.
- Delete patches.drm/0682-drm-exynos-remove-buffer-creation-of-fbdev-from-drm-framebuffer-creation.
- Delete patches.drm/0683-drm-exynos-added-pm-support.
- Delete patches.drm/0685-drm-exynos-support-multi-buffers.
- Delete patches.drm/0686-drm-exynos-change-driver-name.
- Delete patches.drm/0687-drm-exynos-extend-vblank-off-delay-time.
- Delete patches.drm/0688-drm-exynos-added-mutex-lock-and-code-clean.
- Delete patches.drm/0689-drm-exynos-added-hdmi-display-support.
- Delete patches.drm/0752-drm-exynos-use-release_mem_region-instead-of-release_resource.
- Delete patches.drm/0753-drm-exynos-fix-build-dependency-for-drm_exynos_hdmi.
- Delete patches.drm/0754-drm-exynos-fixed-build-dependency-for-drm_exynos_fimd.
- Delete patches.drm/0755-drm-exynos-fixed-pm-feature-for-fimd-module.
- Delete patches.drm/0774-drm-exynos-fix-typo-in-exynos_mixer-c.
- Delete patches.drm/0775-drm-exynos-changed-priority-of-mixer-layers.
- Delete patches.drm/0776-drm-exynos-removed-pageflip_event_list-init-code-when-closed.
- Delete patches.drm/0777-drm-exynos-added-possible_clones-setup-function.
- Delete patches.drm/0778-drm-exynos-fixed-page-flip-issue.
- Delete patches.drm/0779-drm-exynos-removed-exynos_drm_fbdev_recreate-function.
- Delete patches.drm/0780-drm-exynos-added-postclose-to-release-resource.
- Delete patches.drm/0781-drm-exynos-added-panel-physical-size.
- Delete patches.drm/0782-drm-exynos-exynos_drm-h-header-file-fixes.
- Delete patches.drm/0797-drm-exynos-use-correct-exynos-drm-name-for-platform-device.
- Delete patches.drm/0798-drm-exynos-fix-runtime_pm-fimd-device-state-on-probe.
- Delete patches.drm/0799-drm-exynos-fix-fb_videomode-drm_mode_modeinfo-conversion.
- Delete patches.drm/0800-drm-exynos-use-drm_fb_helper_set_par-directly.
- Delete patches.drm/1056-drm-exynos-remove-exynos_mixer-h.
- Delete patches.drm/1057-drm-exynos-add-hdmi-version-1-4-support.
- Delete patches.drm/1058-drm-exynos-added-mode_fixup-feature-and-code-clean.
- Delete patches.drm/1059-drm-exynos-update-gem-and-buffer-framework.
- Delete patches.drm/1060-drm-exynos-added-new-funtion-to-get-put-dma-address.
- Delete patches.drm/1061-drm-exynos-release-pending-pageflip-events-when-closed.
- Delete patches.drm/1062-drm-exynos-remove-module-of-exynos-drm-subdrv.
- Delete patches.drm/1063-drm-exynos-add-subdrv-open-close-functions.
- Delete patches.drm/1064-drm-exynos-add-is_local-member-in-exynos_drm_subdrv-struct.
- Delete patches.drm/1065-drm-exynos-cleanup-exynos_hdmi-h.
- Delete patches.drm/1066-drm-exynos-add-default-pixel-format-for-plane.
- Delete patches.drm/1067-drm-exynos-enable-hdmi-audio-feature.
- Delete patches.drm/1118-drm-exynos-added-virtual-display-driver.
- Delete patches.drm/1169-drm-exynos-fixed-page-align-and-code-clean.
- Delete patches.drm/1170-drm-exynos-fixed-duplicated-page-allocation-bug.
- Delete patches.drm/1172-drm-exynos-add-format-list-of-plane.
- Delete patches.drm/1181-drm-exynos-remove-unnecessary-type-conversion-of-hdmi-and-mixer.
- Delete patches.drm/1182-drm-exynos-remove-unused-codes-in-hdmi-and-mixer.
- Delete patches.drm/1183-drm-exynos-rename-s-hdmi_overlay_number-mixer_win_nr.
- Delete patches.drm/1184-drm-exynos-use-define-instead-of-default_win-member-in-struct-mixer_context.
- Delete patches.drm/1185-drm-exynos-fix-struct-for-operation-callback-functions-to-driver-name.
- Delete patches.drm/1186-drm-exynos-fix-to-pointer-manager-member-of-struct-exynos_drm_subdrv.
- Delete patches.drm/1188-drm-exynos-fixed-exynos-broken-ioctl.
- Delete patches.drm/1200-drm-exynos-fixed-duplicatd-memory-allocation-bug.
- Delete patches.drm/1201-drm-exynos-fixed-exynos_drm_gem_map_pages-bug.
- Delete patches.drm/1202-drm-exynos-added-missed-vm-area-region-mapping-type.
- Delete patches.drm/1541-drm-exynos-added-cache-attribute-support-for-gem.
- Delete patches.drm/1542-drm-exynos-added-drm-prime-feature.
- Delete patches.drm/1543-drm-exynos-added-a-feature-to-get-gem-buffer-information.
- Delete patches.drm/1544-drm-exynos-cleanup-for-hdmi-platform-data.
- Delete patches.drm/1545-drm-exynos-use-platform_get_irq_byname-for-hdmi.
- Delete patches.drm/1546-drm-exynos-use-threaded-irq-for-hdmi-hotplug.
- Delete patches.drm/1547-drm-exynos-add-dpms-for-hdmi.
- Delete patches.drm/1548-drm-exynos-add-pm-functions-for-hdmi-and-mixer.
- Delete patches.drm/1612-drm-exynos-fixed-wrong-pageflip-finish-event-for-interlace-mode.
- Delete patches.drm/1613-drm-exynos-enable-dvi-mode-for-dvi-monitor.
- Delete patches.drm/1614-drm-exynos-add-additional-display-mode-for-hdmi.
- Delete patches.drm/1615-drm-exynos-added-source-size-to-overlay-structure.
- Delete patches.drm/1616-drm-exynos-added-vp-scaling-feature-for-hdmi.
- Delete patches.drm/1617-drm-exynos-add-g2d-driver.
- Delete patches.drm/1781-drm-exynos-use-drm_format_-nv12-yuv420-instead-of-drm_format_-nv12m-yuv420m.
- Delete patches.drm/1782-drm-exynos-fixed-size-type.
- Delete patches.drm/1783-drm-exynos-driver_bus_platform-is-not-a-driver-feature.
- Delete patches.drm/1784-drm-exynos-don-t-cast-gem-object-to-exynos-gem-object-when-not-needed.
- Delete patches.drm/1785-drm-exynos-keep-a-reference-to-frame-buffer-gem-objects.
- Delete patches.drm/1786-drm-exynos-remove-dummy-encoder-get_crtc-operation-implementation.
- Delete patches.drm/1787-drm-exynos-fixed-blending-for-hdmi-graphic-layer.
- Delete patches.drm/2069-drm-exynos-fix-point-to-call-overlay_ops-mode_set.
- Delete patches.drm/2070-drm-exynos-fix-to-set-pipe-of-crtc.
- Delete patches.drm/2071-drm-exynos-define-to_exynos_plane-macro.
- Delete patches.drm/2072-drm-exynos-use-private-plane-for-crtc.
- Delete patches.drm/2073-drm-exynos-update-overlay-via-plane-from-crtc.
- Delete patches.drm/2074-drm-exynos-add-property-for-plane-zpos.
- Delete patches.drm/2075-drm-exynos-fix-dpms-operation-for-mode-set.
- Delete patches.drm/2076-drm-exynos-remove-unnecessary-connector-dpms-control.
- Delete patches.drm/2077-drm-exynos-add-plane-enable-disable.
- Delete patches.drm/2078-drm-exynos-add-crtc-disable-function.
- Delete patches.drm/2079-drm-exynos-add-property-for-crtc-mode.
- Delete patches.drm/2080-drm-exynos-add-missing-static-storage-class-specifier.
- Delete patches.drm/2081-drm-exynos-use-devm_-functions-in-exynos_drm_fimd-c.
- Delete patches.drm/2082-drm-exynos-use-devm_-functions-in-exynos_hdmi-c.
- Delete patches.drm/2083-drm-exynos-use-devm_-functions-in-exynos_mixer-c.
- Delete patches.drm/2084-drm-exynos-return-null-if-exynos_pages_to_sg-fails.
- Delete patches.drm/2085-drm-exynos-check-for-null-in-return-value-of-dma_buf_map_attachment.
- Delete patches.drm/2086-drm-exynos-fix-buffer-pitch-calculation.
- Delete patches.drm/2087-drm-exynos-removed-unnecessary-declaration.
- Delete patches.drm/2088-drm-exynos-set-edid-fake-data-only-for-test.
- Delete patches.drm/2089-drm-exynos-check-if-raw-edid-data-is-fake-or-not-for-test.
- Delete patches.drm/2090-drm-exynos-fixed-edid-data-setting-at-vidi-connection-request.
- Delete patches.drm/2091-drm-exynos-fixed-build-warning.
- Delete patches.drm/2092-drm-exynos-use-alloc_page-to-allocate-pages.
- Delete patches.drm/2093-drm-exynos-set-buffer-type-from-exporter.
- Delete patches.drm/2094-drm-exynos-do-not-release-memory-region-from-exporter.
- Delete patches.drm/2095-drm-exynos-removed-unnecessary-variable-e3fd38cf.
- Delete patches.drm/2096-drm-exynos-fixed-a-comment-to-gem-size.
- Delete patches.drm/2097-drm-exynos-use-_free_page-to-deallocate-memory.
- Delete patches.drm/2098-drm-exynos-fixed-exception-to-page-allocation-failure.
- Delete patches.drm/2186-drm-exynos-remove-redundant-check-in-exynos_hdmi-c-file.
- Delete patches.drm/2187-drm-exynos-remove-redundant-check-in-exynos_drm_fimd-c-file.
- Delete patches.drm/2188-drm-exynos-use-devm_kzalloc-in-exynos_drm_vidi-c-file.
- Delete patches.drm/2189-drm-exynos-use-devm_kzalloc-in-exynos_drm_hdmi-c-file.
- Delete patches.drm/2190-drm-exynos-use-devm_-functions-in-exynos_drm_g2d-c-file.
- Delete patches.drm/2191-drm-exynos-use-err_cast-inlined-function-instead-of-err_ptrptr_err.
- Delete patches.drm/2192-drm-exynos-fixed-page-align-bug.
- Delete patches.drm/2193-drm-exynos-add-dependency-for-g2d-in-kconfig.
- Delete patches.drm/2194-drm-exynos-make-g2d_pm_ops-static.
- Delete patches.drm/2195-drm-exynos-add-missing-braces-around-sizeof-in-exynos_hdmi-c.
- Delete patches.drm/2196-drm-exynos-add-missing-braces-around-sizeof-in-exynos_mixer-c.
- Delete patches.drm/2197-drm-exynos-add-dummy-support-for-dmabuf-mmap.
- Delete patches.drm/2198-drm-exynos-fix-double-call-of-drm_prime_init-destroy_file_private.
- Delete patches.drm/2199-drm-exynos-remove-drm_format_nv12m-from-plane-module.
- Delete patches.drm/2658-drm-exynos-added-device-object-to-subdrv-s-remove-callback-as-argument.
- Delete patches.drm/2659-drm-exynos-separated-subdrv_probe-function-into-two-parts.
- Delete patches.drm/2660-drm-exynos-separeated-fimd_power_on-into-some-parts.
- Delete patches.drm/2661-drm-exynos-fixed-duplicated-mode-setting.
- Delete patches.drm/2662-drm-exynos-add-wait_for_vblank-callback-interface.
- Delete patches.drm/2663-drm-exynos-make-sure-that-hardware-overlay-for-fimd-is-disabled.
- Delete patches.drm/2664-drm-exynos-make-sure-that-hardware-overlay-for-hdmi-is-disabled.
- Delete patches.drm/2665-drm-exynos-check-nv12m-format-specific-to-exynos-properly.
- Delete patches.drm/2666-drm-exynos-update-crtc-to-plane-safely.
- Delete patches.drm/2667-drm-exynos-disable-plane-when-released.
- Delete patches.drm/2668-drm-exynos-add-pid-to-g2d_runqueue_node.
- Delete patches.drm/2669-drm-exynos-fix-duplicated-mutex-lock-issue.
- Delete patches.drm/2670-drm-exynos-check-crtc-s-dpms-mode-at-page-flip.
- Delete patches.drm/2671-drm-exynos-check-crtc-s-dpms-mode-at-setcrtc.
- Delete patches.drm/2672-drm-exynos-support-drm_wait_vblank-feature-for-vidi.
- Delete patches.drm/2673-drm-exynos-fix-potential-null-pointer-dereference.
- Delete patches.drm/2674-drm-exynos-add-platform_device_id-table-and-driver-data-for-drm-fimd.
- Delete patches.drm/2675-drm-exynos-fix-display-power-call-issue.
- Delete patches.drm/2676-drm-exynos-fix-to-calculate-crtc-shown-via-screen.
- Delete patches.drm/2677-drm-exynos-fix-kcalloc-size-of-g2d-cmdlist-node.
- Delete patches.drm/2685-drm-exynos-hdmi-support-for-platform-variants.
- Delete patches.drm/2686-drm-exynos-hdmi-fix-interrupt-handling.
- Delete patches.drm/2687-drm-exynos-hdmi-use-s5p-hdmi-platform-data.
- Delete patches.drm/2688-drm-exynos-hdmi-turn-off-hpd-interrupt-in-hdmi-chip.
- Delete patches.drm/2689-drm-exynos-remove-drm-hdmi-platform-data-struct.
- Delete patches.drm/2690-drm-exynos-hdmi-add-support-for-exynos5-ddc.
- Delete patches.drm/2691-drm-exynos-hdmi-add-support-for-exynos5-hdmiphy.
- Delete patches.drm/2692-drm-exynos-hdmi-add-support-for-platform-variants-for-mixer.
- Delete patches.drm/2693-drm-exynos-hdmi-add-support-to-disable-video-processor-in-mixer.
- Delete patches.drm/2694-drm-exynos-hdmi-add-support-for-exynos5-mixer.
- Delete patches.drm/2695-drm-exynos-hdmi-replace-is_v13-with-version-check-in-hdmi.
- Delete patches.drm/2696-drm-exynos-hdmi-add-support-for-exynos5-hdmi.
- Delete patches.drm/2697-drm-exynos-hdmi-remove-drm-common-hdmi-platform-data-struct.
- Delete patches.drm/2772-drm-exynos-fix-display-on-issue.
- Delete patches.drm/2773-drm-exynos-add-support-for-arch_multiplatform.
- Delete patches.drm/2774-drm-exynos-removed-warning-due-to-missing-typecast-for-mixer-driver-data.
- Delete patches.drm/2802-drm-exynos-fix-linux-framebuffer-address-setting.
- commit f4f7e23
* Thu Feb 21 2013 msrb@novell.com
- Delete updates of nouveau driver.
- Refresh patches.drm/0071-drm-remove-drm_pci_device_is_pcie.
- Refresh patches.drm/0143-drm-ttm-add-a-way-to-bo_wait-for-either-the-last-read-or-last-write.
- Refresh patches.drm/0358-revert-drm-ttm-add-a-way-to-bo_wait-for-either-the-last-read-or-last-write.
- Refresh patches.drm/0487-drm-make-the-per-driver-file_operations-struct-const.
- Refresh patches.drm/0489-drm-add-an-fb-creation-ioctl-that-takes-a-pixel-format-v5.
- Refresh patches.drm/0510-drm-ttm-merge-ttm_backend-and-ttm_tt-v5.
- Refresh patches.drm/0511-drm-ttm-introduce-callback-for-ttm_tt-populate-unpopulate-v4.
- Refresh patches.drm/0515-drm-ttm-isolate-dma-data-from-ttm_tt-v4.
- Refresh patches.drm/0516-drm-ttm-simplify-memory-accounting-for-ttm-user-v2.
- Refresh patches.drm/0517-drm-ttm-callback-move_notify-any-time-bo-placement-change-v4.
- Refresh patches.drm/0535-drm-replace-pitch-with-pitches-in-drm_framebuffer.
- Refresh patches.drm/0711-ttm-fix-agp-since-ttm-tt-rework.
- Refresh patches.drm/0751-drm-ttm-fix-two-regressions-since-move_notify-changes.
- Refresh patches.drm/0872-drm-add-convenience-function-to-create-an-enum-property.
- Refresh patches.drm/0873-drm-add-convenience-function-to-create-an-range-property.
- Refresh patches.drm/1589-vga_switcheroo-introduce-struct-vga_switcheroo_client_ops.
- Refresh patches.drm/1670-drm-constify-drm_mode_config_funcs-pointer.
- Refresh patches.drm/1677-ttm-add-prime-sharing-support-to-ttm-v2.
- Refresh patches.drm/1683-drm-nouveau-radeon-add-static-const-to-the-dma-buf-ops.
- Refresh patches.drm/2011-drm-make-the-mode_fixup-operations-mode-argument-a-const-pointer.
- Refresh patches.drm/2023-drm-kill-reclaim_buffers-callback.
- Refresh patches.drm/2045-drm-track-dev_mapping-in-more-robust-and-flexible-way.
- Refresh patches.drm/2290-workqueue-deprecate-flush_work_sync.
- Refresh patches.drm/2407-drm-use-ph-to-dump-small-buffers.
- Refresh patches.drm/2551-uapi-scripted-remove-redundant-drm-uapi-header-inclusions-from-drivers-gpu.
- Refresh patches.drm/2552-uapi-scripted-convert-include-to-include-path-in-drivers-gpu.
- Refresh patches.drm/2678-merge-branch-drm-next-of-git-people-freedesktop-org-airlied-linux.
- Refresh patches.drm/3066-drm-ttm-remove-ttm_buffer_object-buffer_start.
- Refresh patches.drm/3080-drm-ttm-remove-sync_arg-from-driver-functions.
- Delete patches.drm/0006-drm-nvc0-read-temperature-on-fermi-like-we-do-on-nv84.
- Delete patches.drm/0007-drm-nvc0-fb-allocate-page-for-some-unknown-pffb-object.
- Delete patches.drm/0008-drm-nvc0-fifo-fix-typos-in-unload_context.
- Delete patches.drm/0009-drm-nvc0-gr-macro-to-determine-fermi-class-will-use-it-in-a-few-places.
- Delete patches.drm/0010-drm-nvc0-gr-0x9197-0x9297-state-init.
- Delete patches.drm/0011-drm-nvc0-gr-some-initial-state-modifications.
- Delete patches.drm/0012-drm-nvc0-gr-enable-0xc8-0xce-support-no-idea-if-it-works-or-not.
- Delete patches.drm/0013-drm-nvc1-gr-switch-on-acceleration-support.
- Delete patches.drm/0014-drm-nouveau-default-to-noaccel-on-0xc1-0xc8-0xce-for-now.
- Delete patches.drm/0015-drm-nvc0-fix-suspend-resume-of-pgraph-pcopyn.
- Delete patches.drm/0016-drm-nvc0-gr-import-and-use-our-own-fuc-by-default.
- Delete patches.drm/0017-drm-nvc0-gr-add-some-missing-magics-for-0xc1-0xc8-0xce.
- Delete patches.drm/0018-drm-nvc0-gr-calculate-magicgpc918-ourselves.
- Delete patches.drm/0019-drm-nvc0-gr-fix-typo-in-class9197-init.
- Delete patches.drm/0020-drm-nvc0-gr-fill-in-some-more-data-for-0xc1-0xc8-0xce.
- Delete patches.drm/0021-drm-nouveau-log-if-accel-is-disabled-by-default-on-a-chipset.
- Delete patches.drm/0022-drm-nv50-dcb-table-quirks-for-another-busted-xfx-board.
- Delete patches.drm/0023-drm-nouveau-silence-error-for-missing-dac-loadval-table.
- Delete patches.drm/0024-drm-nouveau-allocate-structure-to-store-per-client-data.
- Delete patches.drm/0025-drm-nouveau-use-null-file_priv-for-drm-created-channels.
- Delete patches.drm/0026-drm-nouveau-store-a-per-client-channel-list.
- Delete patches.drm/0027-drm-nouveau-no-need-to-update-bo-offset-from-vma-after-validate.
- Delete patches.drm/0028-drm-nv50-nvc0-vm-don-t-touch-chan_vm.
- Delete patches.drm/0029-drm-nv50-nvc0-vm-take-client-reference-on-shared-channel-vm.
- Delete patches.drm/0030-drm-nv50-nvc0-chan-inherit-vm-from-fpriv-rather-than-chan_vm-directly.
- Delete patches.drm/0031-drm-nouveau-remove-chan-argument-from-nouveau_gem_new.
- Delete patches.drm/0032-drm-nouveau-gem-implement-stub-hooks-for-gem-object-open-close.
- Delete patches.drm/0033-drm-nouveau-modify-gpuobj-ntfy-takedown-ordering.
- Delete patches.drm/0034-drm-nouveau-initialise-any-vm-for-a-channel-before-pushbuf-ntfy.
- Delete patches.drm/0035-drm-nouveau-will-need-to-specify-channel-for-vm-ful-gpuobj-allocations.
- Delete patches.drm/0036-drm-nouveau-skip-move_notify-if-bo-does-not-have-a-vma-attached.
- Delete patches.drm/0037-drm-nouveau-store-bo-s-page-size-in-nouveau_bo.
- Delete patches.drm/0038-drm-nouveau-create-temp-vmas-for-both-src-and-dst-of-bo-moves.
- Delete patches.drm/0039-drm-nouveau-convert-some-bo-offset-use-to-vma-offset.
- Delete patches.drm/0040-drm-nouveau-convert-bo-mem-start-usage-to-bo-offset.
- Delete patches.drm/0041-drm-nv50-nvc0-completely-disable-relocs.
- Delete patches.drm/0042-drm-nouveau-initial-changes-to-support-multiple-vmas-per-buffer-object.
- Delete patches.drm/0043-drm-nv50-nvc0-explicitly-map-fbcon-fb-into-channel-vm.
- Delete patches.drm/0044-drm-nv50-nvc0-explicitly-map-notifier-bo-into-channel-vm.
- Delete patches.drm/0045-drm-nv50-nvc0-explicitly-map-pushbuf-bo-into-channel-vm.
- Delete patches.drm/0046-drm-nv84-nvc0-explicitly-map-semaphore-buffer-into-channel-vm.
- Delete patches.drm/0047-drm-nv50-nvc0-lookup-pushbuf-virtual-address-on-dma_push.
- Delete patches.drm/0048-drm-nvc0-explicitly-map-pdisp-semaphore-buffer-into-each-channel-s-vm.
- Delete patches.drm/0049-drm-nouveau-fixup-gem_info-ioctl-to-return-client-specific-bo-virtual.
- Delete patches.drm/0050-drm-nouveau-remove-chan-argument-from-nouveau_bo_new.
- Delete patches.drm/0051-drm-nouveau-remove-implicit-mapping-of-every-bo-into-chan_vm.
- Delete patches.drm/0052-drm-nv50-enable-use-of-per-client-gpu-address-space.
- Delete patches.drm/0053-drm-nouveau-add-some-debug-output-if-nouveau_mm-busy-at-destroy-time.
- Delete patches.drm/0054-drm-nvc0-enable-per-client-address-spaces.
- Delete patches.drm/0055-drm-nouveau-fix-display-takedown-order-to-match-reverse-init-order.
- Delete patches.drm/0056-drm-nouveau-shut-lockdep-up-if-last-vm-ref-needs-to-destroy-pgd.
- Delete patches.drm/0057-drm-nouveau-rework-vram-init-fini-ordering-a-little.
- Delete patches.drm/0058-drm-nouveau-fix-null-pointer-deref-on-pre-nv50-chipsets.
- Delete patches.drm/0059-drm-nouveau-un-blacklist-nvce-accel.
- Delete patches.drm/0060-drm-nvc0-push-prunk140-irq-messages-to-debug-loglevel.
- Delete patches.drm/0061-drm-nouveau-temp-fix-signed-unsigned-int-logic.
- Delete patches.drm/0062-drm-nouveau-temp-add-default-calibration-values-for-nv67.
- Delete patches.drm/0063-drm-nouveau-fix-off-by-one.
- Delete patches.drm/0064-drm-nouveau-fix-fetching-vbios-from-above-4gib-vram-addresses.
- Delete patches.drm/0065-drm-nouveau-fix-nouveau_mem-object-leak.
- Delete patches.drm/0066-drm-nouveau-fix-nouveau_vma-object-leak.
- Delete patches.drm/0067-drm-nouveau-calculate-reserved-vram-for-pramin-value-before-use.
- Delete patches.drm/0068-drm-nouveau-error-paths-leak-in-nvc0_graph_construct_context.
- Delete patches.drm/0080-drm-nv50-dp-fix-hack-to-work-for-macbooks-booted-via-efi.
- Delete patches.drm/0081-drm-nouveau-do-not-leak-in-nv20_graph_create.
- Delete patches.drm/0082-drm-nouveau-add-a-quirk-for-gigabyte-nx86t.
- Delete patches.drm/0083-drm-nouveau-ignore-connector-type-when-deciding-digital-analog-on-dvi-i.
- Delete patches.drm/0084-drm-nouveau-detect-disabled-device-in-irq-handler-and-return-irq_none.
- Delete patches.drm/0085-drm-nv40-gr-rewrite-split-context-takedown-functions.
- Delete patches.drm/0086-drm-nouveau-replace-nv04_graph_fifo_access-use-with-direct-reg-bashing.
- Delete patches.drm/0087-drm-nouveau-pass-flag-to-engine-fini-method-on-suspend.
- Delete patches.drm/0088-drm-nouveau-gr-disable-fifo-access-and-idle-before-suspend-ctx-unload.
- Delete patches.drm/0125-drm-nv50-crtc-bail-out-if-fb-is-not-bound-to-crtc.
- Delete patches.drm/0126-drm-nouveau-fix-oops-on-pre-semaphore-hardware.
- Delete patches.drm/0127-drm-nouveau-fix-nv04_sgdma_bind-on-non-4kb-pages-archs.
- Delete patches.drm/0128-drm-nv04-crtc-bail-out-if-fb-is-not-bound-to-crtc.
- Delete patches.drm/0167-drm-nouveau-pm-store-voltage-in-microvolts.
- Delete patches.drm/0168-drm-nouveau-pm-initial-attempt-at-parsing-volt-0x40.
- Delete patches.drm/0169-drm-nouveau-pm-add-yet-another-vid-gpio-tag.
- Delete patches.drm/0170-drm-nouveau-pm-add-support-for-parsing-perflvl-voltage-on-fermi-chips.
- Delete patches.drm/0171-drm-nouveau-pm-show-any-info-we-can-manage-to-glean-on-current-perflvl.
- Delete patches.drm/0172-drm-nvc0-pm-enable-voltage_get.
- Delete patches.drm/0173-drm-nouveau-pm-allow-voltage-only-perflvl-set-enable-nvc0.
- Delete patches.drm/0174-drm-nouveau-pm-some-fermi-chipsets-still-use-volt-0x30.
- Delete patches.drm/0175-drm-nva3-pm-rewrite-clock-readback-functions-far-more-correct-now.
- Delete patches.drm/0176-drm-nouveau-pm-add-hooks-to-get-set-all-clocks-at-once.
- Delete patches.drm/0177-drm-nva3-pm-rewrite-clock_set-and-switch-to-new-interfaces.
- Delete patches.drm/0178-drm-nva3-pm-parse-reclock-vdec-41a0-clocks.
- Delete patches.drm/0179-drm-nva3-pm-tidy-and-add-some-comments-here-and-there.
- Delete patches.drm/0180-drm-nv50-gr-insert-set-clr-of-a-ctxprog-flag-at-start-end-of-ctxprog.
- Delete patches.drm/0181-drm-nouveau-add-function-to-wait-until-a-callback-returns-true.
- Delete patches.drm/0182-drm-nva3-pm-idle-graphics-engine-before-changing-clocks.
- Delete patches.drm/0183-drm-nvc0-pm-initial-implementation-of-clocks_get.
- Delete patches.drm/0184-drm-nvc0-pm-more-complete-parsing-of-clock-domains.
- Delete patches.drm/0185-drm-nouveau-rename-nv40_mpeg-to-nv31_mpeg.
- Delete patches.drm/0186-drm-nv31-mpeg-support-for-a-single-class3174-user.
- Delete patches.drm/0187-drm-nouveau-embed-nouveau_mm.
- Delete patches.drm/0188-drm-nouveau-allow-a-nouveau_mm-to-be-created-with-holes.
- Delete patches.drm/0189-drm-nvc0-gr-add-support-for-nvcf-chipset.
- Delete patches.drm/0190-drm-nvc0-vram-support-non-uniform-memory-size-per-controller.
- Delete patches.drm/0191-drm-nvc0-gr-copy-gpc-mpart-config-from-pffb.
- Delete patches.drm/0192-drm-nouveau-don-t-complain-for-disabled-timingset-entries.
- Delete patches.drm/0193-drm-nvc0-gr-unblacklist-nvcf-acceleration.
- Delete patches.drm/0194-drm-nouveau-tmr-calibrate-for-ns-timestamps-on-init.
- Delete patches.drm/0195-drm-nv04-pm-recalibrate-timer-on-nvclk-changes.
- Delete patches.drm/0196-drm-nvd0-add-a-card_type-for-0xdx-chipsets.
- Delete patches.drm/0197-drm-nouveau-make-general-drm-modesetting-init-common.
- Delete patches.drm/0198-drm-nouveau-fixup-init-fini-sequence-to-deal-with-no-crtcs.
- Delete patches.drm/0199-drm-nouveau-allow-modeset-module-option-to-select-headless-mode.
- Delete patches.drm/0200-drm-nouveau-initial-chipset-description-for-nvdx-chipsets.
- Delete patches.drm/0201-drm-nvd0-i2c-initial-implementation.
- Delete patches.drm/0202-drm-nvd0-gpio-initial-implementation.
- Delete patches.drm/0203-drm-nouveau-bios-fix-init_gpio-for-new-chipsets.
- Delete patches.drm/0204-drm-nvd0-pm-enable-clock-voltage-hooks.
- Delete patches.drm/0205-drm-nouveau-bios-allow-passing-in-crtc-to-the-init-table-parser.
- Delete patches.drm/0206-drm-nvd0-disp-very-initial-evo-setup.
- Delete patches.drm/0207-drm-nvd0-disp-whip-up-some-basic-dma-handling-for-the-evo-channels.
- Delete patches.drm/0208-drm-nvd0-disp-start-on-interrupt-handling.
- Delete patches.drm/0209-drm-nvd0-disp-setup-a-couple-of-dma-objects-we-ll-need.
- Delete patches.drm/0210-drm-nvd0-disp-start-on-sor-encoder-functions.
- Delete patches.drm/0211-drm-nvd0-disp-skeletal-handling-of-modeset-interrupts.
- Delete patches.drm/0212-drm-nvd0-disp-initial-crtc-object-implementation.
- Delete patches.drm/0213-drm-nvd0-disp-they-moved-the-linear-flag.
- Delete patches.drm/0214-drm-nvd0-disp-some-magic-to-make-evo-happeir.
- Delete patches.drm/0215-drm-nvd0-disp-remove-lp-reordering-from-vram-dmaobj-create-fb-dmaobjs.
- Delete patches.drm/0216-drm-nvd0-disp-extend-the-init-voodoo-to-cover-crtcs.
- Delete patches.drm/0217-drm-nvd0-disp-dac-encoder-module.
- Delete patches.drm/0218-drm-nvd0-disp-stub-dac-load-detect-prevents-oops.
- Delete patches.drm/0219-drm-nvd0-disp-initial-attempt-at-modeset-irq-handling.
- Delete patches.drm/0220-drm-nvd0-disp-fixup-clut-so-it-actually-works.
- Delete patches.drm/0221-drm-nvd0-disp-push-the-update-button-in-mode_set_base.
- Delete patches.drm/0222-drm-nvd0-disp-scaling.
- Delete patches.drm/0223-drm-nvd0-disp-handle-sync-polarity-kill-off-some-unknown.
- Delete patches.drm/0224-drm-nvd0-disp-dac-load-detect.
- Delete patches.drm/0225-drm-nvd0-disp-determine-u-table-config-in-or_mode_set.
- Delete patches.drm/0226-drm-nvd0-disp-track-down-fb-positioning-method.
- Delete patches.drm/0227-drm-nvd0-disp-untested-lvds-support.
- Delete patches.drm/0228-drm-nvd0-disp-do-modeset-irq-handling-from-tasklet.
- Delete patches.drm/0229-drm-nvd0-disp-rewrite-irq-handler-should-be-somewhat-sturdier-now.
- Delete patches.drm/0230-drm-nvd0-disp-tidy-up-what-we-have-so-far.
- Delete patches.drm/0231-drm-nouveau-enable-hwmon-support-when-both-nouveau-hwmon-are-built-as-modules.
- Delete patches.drm/0232-drm-nvd0-lets-not-attempt-to-dereference-a-nv50_display-pointer.
- Delete patches.drm/0233-drm-nvc0-gr-remove-max-tpc-count-info.
- Delete patches.drm/0234-drm-nvd0-no-page-flipping-at-the-moment.
- Delete patches.drm/0235-drm-nouveau-remove-special-casing-of-hotplug-detection-type.
- Delete patches.drm/0236-drm-nouveau-pm-add-initial-nv3x-nvcx-memtiming-support-improve-other-cards.
- Delete patches.drm/0237-drm-nouveau-pm-document-and-expose-cl-and-wr-for-0x1002cx.
- Delete patches.drm/0238-drm-nouveau-magic-to-make-auxch-on-new-macbooks-booted-in-efi-mode-work.
- Delete patches.drm/0239-drm-nva3-pm-pll-disabled-if-bit-0-of-ctrl-not-set.
- Delete patches.drm/0240-drm-nouveau-determine-timing-crystal-freq-from-straps.
- Delete patches.drm/0241-drm-nva3-pm-use-crystal-freq-where-appropriate.
- Delete patches.drm/0242-drm-nva3-pm-fixup-for-nvaf-special.
- Delete patches.drm/0243-drm-nouveau-tmr-fix-miscalculation-of-ratio-on-pre-nv4x-chipsets.
- Delete patches.drm/0244-drm-nouveau-workaround-semaphore-hw-bug-causing-unnecessary-interrupts.
- Delete patches.drm/0245-drm-nouveau-dp-rewrite-auxch-transaction-routines.
- Delete patches.drm/0246-drm-nouveau-dp-remove-reliance-on-vbios-for-native-displayport.
- Delete patches.drm/0247-drm-nouveau-tidy-connector-hotplug-handler-punt-messages-to-debug.
- Delete patches.drm/0248-drm-nouveau-backlight-make-more-consistent-with-rest-of-driver-style.
- Delete patches.drm/0249-drm-nv50-backlight-take-the-sor-into-account-when-bashing-regs.
- Delete patches.drm/0250-drm-nv50-backlight-express-brightness-level-in-percent.
- Delete patches.drm/0251-drm-nva3-backlight-add-suppport-for-newer-style-backlight-regs.
- Delete patches.drm/0252-drm-nouveau-bios-check-for-null-script-pointers-in-parser.
- Delete patches.drm/0253-drm-nouveau-dp-pass-in-required-datarate-to-link-training.
- Delete patches.drm/0254-drm-nouveau-dp-restructure-link-training-code.
- Delete patches.drm/0255-drm-nouveau-dp-store-unencoded-link_bw-everywhere.
- Delete patches.drm/0256-drm-nouveau-dp-execute-some-more-vbios-tables-relating-to-link-rate.
- Delete patches.drm/0257-drm-nouveau-dp-enable-down-spread-if-vbios-and-sink-support-it.
- Delete patches.drm/0258-drm-nv40-pm-parse-geometric-delta-clock-from-vbios.
- Delete patches.drm/0259-drm-nv40-pm-write-nv40-specific-reclocking-routines.
- Delete patches.drm/0260-drm-nouveau-dp-link-rate-scripts-are-selected-with-a-comparison-table.
- Delete patches.drm/0261-drm-nouveau-dp-use-alternate-lane-mask-for-nvaf.
- Delete patches.drm/0262-drm-nvc0-gr-remove-module_firmware-lines.
- Delete patches.drm/0263-drm-nouveau-dp-preserve-non-pattern-bits-in-dp_training_pattern_set.
- Delete patches.drm/0264-drm-nouveau-bios-simplify-u-d-table-hash-matching-func-to-just-match.
- Delete patches.drm/0265-drm-nouveau-dp-return-master-dp-table-pointer-too-when-looking-up-encoder.
- Delete patches.drm/0266-drm-nouveau-dp-add-support-for-displayport-table-0x30.
- Delete patches.drm/0267-drm-nv50-gr-enable-ctxprog-xfer-only-when-we-need-it-to-save-power.
- Delete patches.drm/0268-drm-nouveau-if-requested-try-harder-at-disabling-sysmem-pushbufs.
- Delete patches.drm/0269-drm-nv50-gr-refactor-initialisation.
- Delete patches.drm/0270-drm-nv40-pm-execute-memory-reset-script-from-vbios.
- Delete patches.drm/0271-drm-nvc0-pm-minor-clock-readback-fixes.
- Delete patches.drm/0272-drm-nouveau-fix-printk-typo-in-ioremap-failure-path.
- Delete patches.drm/0273-drm-nvd9-disp-stub-some-more-api-hooks-so-we-don-t-oops-on-resume.
- Delete patches.drm/0274-drm-nvd9-disp-bail-out-of-mode_set_base-if-no-fb-bound-to-crtc.
- Delete patches.drm/0275-drm-nvc0-fifo-avoid-touching-missing-subfifos.
- Delete patches.drm/0276-drm-nvc0-fb-slightly-improve-pmfb-intr-handling-move-out-of-nvc0_graph-c.
- Delete patches.drm/0277-drm-nouveau-remove-allocations-from-gart-populate-hook.
- Delete patches.drm/0401-drm-nouveau-fix-oops-if-i2c-bus-not-found-in-nouveau_i2c_identify.
- Delete patches.drm/0402-drm-nv50-bios-fixup-mpll-programming-from-the-init-table-parser.
- Delete patches.drm/0403-drm-nv50-gr-typo-fix-how-about-we-not-reset-fifo-during-graph-init.
- Delete patches.drm/0404-drm-nv50-vram-fix-incorrect-detection-of-bank-count-on-newer-chipsets.
- Delete patches.drm/0405-drm-nv50-fix-stability-issue-on-nv86.
- Delete patches.drm/0406-drm-nvc0-vram-storage-type-0xc3-is-not-compressed.
- Delete patches.drm/0407-drm-nouveau-testing-the-wrong-variable.
- Delete patches.drm/0408-drm-nv40-pm-fix-issues-on-igp-chipsets-which-don-t-have-memory.
- Delete patches.drm/0409-drm-nvc0-vram-skip-disabled-pbfb-subunits.
- Delete patches.drm/0410-drm-nvc0-enable-acceleration-on-0xc8-by-default.
- Delete patches.drm/0411-drm-nvc0-gr-fix-some-bugs-in-grctx-generation.
- Delete patches.drm/0412-drm-nvc1-hacky-workaround-to-fix-accel-issues.
- Delete patches.drm/0413-drm-nvc0-gr-fixup-the-mmio-list-register-writes-for-0xc1.
- Delete patches.drm/0414-drm-nvc0-enable-acceleration-for-nvc1-by-default.
- Delete patches.drm/0415-drm-nv10-change-the-bo-size-threshold-determining-the-memory-placement-range.
- Delete patches.drm/0416-drm-nouveau-by-default-use-low-bpp-framebuffer-on-low-memory-cards.
- Delete patches.drm/0417-drm-nouveau-fix-bandwidth-calculation-for-displayport.
- Delete patches.drm/0459-drm-nouveau-add-dumb-ioctl-support.
- Delete patches.drm/0460-drm-nvc0-gr-fix-tp-init-for-transform-feedback-offset-queries.
- Delete patches.drm/0461-drm-nvd0-disp-fix-sor-dpms-typo-preventing-dpms-on-in-some-situations.
- Delete patches.drm/0462-drm-nouveau-keep-ramin-heap-within-the-channel.
- Delete patches.drm/0463-drm-nouveau-fix-oopses-caused-by-clear-being-called-on-unpopulated-ttms.
- Delete patches.drm/0464-drm-nv50-disp-silence-compiler-warning.
- Delete patches.drm/0514-drm-nouveau-enable-the-ttm-dma-pool-when-swiotlb-is-active-v3.
- Delete patches.drm/0564-drm-nv40-pm-parse-fan-pwm-divisor-from-vbios-tables.
- Delete patches.drm/0565-drm-nv40-pm-implement-first-type-of-pwm-fanspeed-funcs.
- Delete patches.drm/0566-drm-nv41-pm-implement-a-second-type-of-fanspeed-pwm.
- Delete patches.drm/0567-drm-nouveau-pm-hook-up-fanspeed-get-set-if-they-re-present.
- Delete patches.drm/0568-drm-nouveau-vdec-implement-stub-modules-for-the-known-engines.
- Delete patches.drm/0569-drm-nv50-pm-add-support-for-pwm-fan-control.
- Delete patches.drm/0570-drm-nouveau-pm-manual-pwm-fanspeed-management-for-nv40-boards.
- Delete patches.drm/0571-drm-nv50-pm-mostly-nailed-down-fan-pwm-frequency-selection.
- Delete patches.drm/0572-drm-nouveau-gpio-remove-invert-flag-use-state-everywhere.
- Delete patches.drm/0573-drm-nouveau-pm-introduce-generic-handler-for-on-chip-fan-controller.
- Delete patches.drm/0574-drm-nv50-pm-convert-to-new-fanspeed-pwm-controller-hooks.
- Delete patches.drm/0575-drm-nv40-pm-convert-to-new-pwm-hooks-also-fixing-pwm-type-detection.
- Delete patches.drm/0576-drm-nouveau-pm-remove-defunct-fanspeed_set-get-from-pm-table.
- Delete patches.drm/0577-drm-nv50-pm-s-unk05-vdec.
- Delete patches.drm/0578-drm-nouveau-hdmi-build-eld-from-edid-notify-audio-driver-of-its-presence.
- Delete patches.drm/0579-drm-nouveau-hdmi-add-hdmi-register-accessors-to-handle-hdmi-block-move.
- Delete patches.drm/0580-drm-nouveau-hdmi-enable-sending-of-avi-audio-infoframes.
- Delete patches.drm/0581-drm-nv50-crtc-disable-flip-overlay-around-scaling-mode-changes.
- Delete patches.drm/0582-drm-nouveau-move-master-modesetting-init-to-nouveau_display.
- Delete patches.drm/0583-drm-nouveau-add-overscan-compensation-connector-properties.
- Delete patches.drm/0584-drm-nv50-also-report-errors-in-mp1-mp2-when-they-happen.
- Delete patches.drm/0585-drm-nouveau-disable-output-polling-through-suspend.
- Delete patches.drm/0586-drm-nouveau-restore-performance-mode-a-bit-later.
- Delete patches.drm/0587-drm-nouveau-restore-cursors-after-restoring-mode.
- Delete patches.drm/0588-drm-nv50-disp-move-sync-routine-to-where-it-can-be-used-by-other-modules.
- Delete patches.drm/0589-drm-nv50-disp-synchronise-display-right-after-init.
- Delete patches.drm/0590-drm-nv50-disp-completely-reset-disp-if-master-evo-channel-active-at-init.
- Delete patches.drm/0591-drm-nv50-disp-disconnect-encoders-before-reprogramming-them.
- Delete patches.drm/0592-drm-nv50-disp-wait-for-encoder-disconnect-to-complete-before-link-training.
- Delete patches.drm/0593-drm-nouveau-determine-a-value-for-display_info-bpc-if-edid-doesn-t.
- Delete patches.drm/0594-drm-nouveau-no-need-to-pass-parameters-into-set_scale-dither.
- Delete patches.drm/0595-drm-nouveau-improve-dithering-properties-and-implement-proper-auto-mode.
- Delete patches.drm/0596-drm-nouveau-don-t-pretend-to-support-the-dvi-i-select-subconnector-prop.
- Delete patches.drm/0597-drm-nv50-disp-allow-interlaced-and-doublescan-modes-on-digital-outputs.
- Delete patches.drm/0598-drm-nouveau-disp-kill-off-nouveau_crtc-mode.
- Delete patches.drm/0599-drm-nv50-disp-rewrite-crtc-timing-calculation-with-proper-names-and-fixes.
- Delete patches.drm/0600-drm-nv50-disp-fix-scaling-of-doublescan-modes.
- Delete patches.drm/0601-drm-nvd0-read-temperature-as-we-did-on-nv84-boards.
- Delete patches.drm/0602-drm-nouveau-pm-make-clocks_set-return-an-error-code-clocks_set-can-fail.
- Delete patches.drm/0603-drm-nv50-pm-s-pll_unk05-pll_vdec.
- Delete patches.drm/0604-drm-nv50-pm-rewrite-clock-management-and-switch-to-the-new-pm-hooks.
- Delete patches.drm/0605-drm-nv04-nv30-pm-port-to-newer-interfaces.
- Delete patches.drm/0606-drm-nouveau-pm-remove-the-older-interfaces-completely.
- Delete patches.drm/0607-drm-nouveau-pm-change-volt-fan-before-upclock-but-after-downclock.
- Delete patches.drm/0608-drm-nv50-pm-free-state-struct-after-setting-clocks.
- Delete patches.drm/0609-drm-nv50-disp-stricter-check-for-evo-being-active-on-init.
- Delete patches.drm/0610-drm-nvc0-gr-update-fuc-source-to-assemble-with-latest-envyas.
- Delete patches.drm/0611-drm-nvc0-gr-add-initial-support-for-nvd9-not-quite-there-yet.
- Delete patches.drm/0612-drm-nv50-pm-0x84-0x86-can-t-use-1-for-nvclk-src-need-0x50-method.
- Delete patches.drm/0613-drm-nv50-pm-fix-thinko-which-lead-to-clocks-being-slightly-off-sometimes.
- Delete patches.drm/0614-drm-nv50-pm-avoid-touching-dom6-vdec-clocks-if-perflvl-doesn-t-define-it.
- Delete patches.drm/0615-drm-nv50-pm-stabilise-transition-to-100mhz-mclk-a-bit.
- Delete patches.drm/0616-drm-nv50-pm-only-touch-0x611200-on-nv92.
- Delete patches.drm/0617-drm-nva3-copy-update-fuc-source-for-latest-envytools.
- Delete patches.drm/0618-drm-nva3-copy-fix-typo-in-fuc-which-caused-host-to-not-recieve-exceptions.
- Delete patches.drm/0619-drm-nouveau-print-correct-engine-number-which-failed-to-unload-idle.
- Delete patches.drm/0620-drm-nv50-fix-page-faulting-for-128mb-page-table-sizes.
- Delete patches.drm/0621-drm-nouveau-hdmi-enable-audio-for-nva3-nvd0-chipsets.
- Delete patches.drm/0622-drm-nvd0-disp-send-eld-to-the-audio-codec.
- Delete patches.drm/0623-drm-nvd0-disp-enable-hdmi-on-sor-if-hdmi-monitor-present.
- Delete patches.drm/0624-drm-nvd0-disp-hook-evo-up-to-debugging.
- Delete patches.drm/0625-drm-nvd0-disp-enable-hdmi-audio.
- Delete patches.drm/0626-drm-nv50-pm-fix-a-typo-in-clock-calculation.
- Delete patches.drm/0627-drm-nouveau-pm-fix-missing-volt-changes-when-boot-voltage-is-undefined.
- Delete patches.drm/0628-drm-nouveau-disp-introduce-proper-init-fini-separate-from-create-destroy.
- Delete patches.drm/0629-drm-nouveau-re-jig-fbcon-suspend-resume-process-a-little.
- Delete patches.drm/0630-drm-nv50-disp-fix-evo-for-create-init-destroy-fini-split.
- Delete patches.drm/0631-drm-nouveau-shutdown-display-on-suspend-hibernate.
- Delete patches.drm/0632-drm-nvd0-disp-update-crtc-timing-calculations-for-interlace-doublescan.
- Delete patches.drm/0633-drm-nvd0-disp-scaler-updates-overscan-compensation-etc.
- Delete patches.drm/0634-drm-nvd0-disp-init-display-sync-channels.
- Delete patches.drm/0635-drm-nvd0-disp-have-evo-names-now-use-them.
- Delete patches.drm/0636-drm-nvd0-disp-make-it-clearer-that-the-cursor-regs-are-pio-evo-channels.
- Delete patches.drm/0637-drm-nvd0-disp-add-support-for-page-flipping.
- Delete patches.drm/0638-drm-nvd0-disp-initialise-overlay-channels.
- Delete patches.drm/0639-drm-nvd0-disp-handle-yet-another-interrupt.
- Delete patches.drm/0640-drm-nvd0-disp-rename-sync-channel-to-flip-channel.
- Delete patches.drm/0641-drm-nvd0-disp-use-single-shared-sync-bo-for-all-evo-channels.
- Delete patches.drm/0642-drm-nouveau-bios-pass-drm_device-to-romptr-rather-than-nvbios.
- Delete patches.drm/0643-drm-nouveau-bios-fold-fixup_legacy_i2c.
- Delete patches.drm/0644-drm-nouveau-bios-start-refactoring-dcb-routines.
- Delete patches.drm/0645-drm-nouveau-i2c-do-parsing-of-i2c-related-vbios-info-in-nouveau_i2c-c.
- Delete patches.drm/0646-drm-nouveau-i2c-tidy-up-bit-bang-helpers-also-fixing-nv50-setsda-bug.
- Delete patches.drm/0647-drm-nouveau-i2c-fix-debug-message.
- Delete patches.drm/0648-drm-nouveau-i2c-handle-bit-banging-ourselves.
- Delete patches.drm/0649-drm-nouveau-disp-parse-connector-info-directly-in-nouveau_connector-c.
- Delete patches.drm/0650-drm-nouveau-mxm-initial-implementation-of-dcb-sanitisation.
- Delete patches.drm/0651-drm-nouveau-mxm-implement-wmi-shadow-method.
- Delete patches.drm/0652-drm-nouveau-mxm-implement-dsm-shadow-method.
- Delete patches.drm/0653-drm-nouveau-mxm-implement-rom-shadow-method.
- Delete patches.drm/0654-drm-nouveau-dp-remove-broken-display-depth-function-use-the-improved-one.
- Delete patches.drm/0655-drm-nv04-disp-handle-dual-link-spwg-panels-without-needing-quirks.
- Delete patches.drm/0656-drm-nv50-pm-introduce-hwsq-based-memory-reclocking.
- Delete patches.drm/0657-drm-nouveau-hwsq-remove-some-magic-give-proper-opcode-names.
- Delete patches.drm/0658-drm-nouveau-just-pass-gpio-line-to-pwm_-not-entire-gpio-struct.
- Delete patches.drm/0659-drm-nouveau-gpio-reimplement-as-nouveau_gpio-c-fixing-a-number-of-issues.
- Delete patches.drm/0660-drm-nv40-disp-implement-support-for-hotplug-irq.
- Delete patches.drm/0661-drm-nouveau-move-hpd-enable-disable-to-common-code.
- Delete patches.drm/0662-drm-nvc0-pm-initial-engine-reclocking.
- Delete patches.drm/0663-drm-nouveau-fix-pushbufs-over-the-4gb-mark.
- Delete patches.drm/0664-drm-nouveau-fix-notifier-blocks-over-the-4gb-mark.
- Delete patches.drm/0675-drm-nouveau-ttm-fix-crash-as-a-result-of-a-recent-ttm-change.
- Delete patches.drm/0723-drm-nouveau-pm-fix-build-with-hwmon-off.
- Delete patches.drm/0732-nouveau-properly-check-for-dsm-function-support.
- Delete patches.drm/0734-nouveau-support-optimus-models-for-vga_switcheroo.
- Delete patches.drm/0761-drm-nouveau-disp-check-that-panel-power-gpio-is-enabled-at-init-time.
- Delete patches.drm/0762-drm-nouveau-mxm-pretend-to-succeed-even-if-we-can-t-shadow-the-mxm-sis.
- Delete patches.drm/0763-drm-nouveau-fix-typo-on-mxmdcb-option.
- Delete patches.drm/0764-drm-nv50-pm-signedness-bug-in-nv50_pm_clocks_pre.
- Delete patches.drm/0956-drm-nouveau-do-a-better-job-at-hiding-the-nih-i2c-bit-banging-algo.
- Delete patches.drm/0963-drm-nouveau-move-vram-detection-funcs-to-chipset-specific-fb-code.
- Delete patches.drm/0964-drm-nouveau-memory-type-detection-for-the-really-old-chipsets.
- Delete patches.drm/0965-drm-nv20-split-pfb-code-out-of-nv10_fb-c.
- Delete patches.drm/0966-drm-nv20-nv40-add-memory-type-detection.
- Delete patches.drm/0967-drm-nv50-add-memory-type-detection.
- Delete patches.drm/0968-drm-nv50-hopefully-handle-the-ddr2-ddr3-memtype-detection-somewhat-better.
- Delete patches.drm/0969-drm-nvc0-add-initial-memory-type-detection.
- Delete patches.drm/0970-drm-nouveau-rework-the-init-takedown-ordering.
- Delete patches.drm/0971-drm-nouveau-pm-style-fixes.
- Delete patches.drm/0972-drm-nouveau-pm-restore-fan-speed-after-suspend.
- Delete patches.drm/0973-drm-nouveau-move-pwm_divisor-to-the-nouveau_pm_fan-struct.
- Delete patches.drm/0974-drm-nouveau-pm-improve-the-reclocking-logs-readability.
- Delete patches.drm/0975-drm-nouveau-pm-improve-memory-timing-generation.
- Delete patches.drm/0976-drm-nouveau-fix-module-parameter-description-formats.
- Delete patches.drm/0977-drm-nouveau-pm-avoid-potential-divide-by-zero.
- Delete patches.drm/0978-drm-nouveau-pm-restructure-bios-table-parsing.
- Delete patches.drm/0979-drm-nouveau-pm-implement-ddr2-ddr3-gddr3-gddr5-mr-generation-and-validation.
- Delete patches.drm/0980-drm-nouveau-pm-readback-boot-perflvl-before-parsing-vbios.
- Delete patches.drm/0981-drm-nouveau-pm-calculate-memory-timings-at-perflvl-creation-time.
- Delete patches.drm/0982-drm-nouveau-pm-embed-timings-into-perflvl-structs.
- Delete patches.drm/0983-drm-nouveau-pm-introduce-ram-reclocking-helper.
- Delete patches.drm/0984-drm-nv50-pm-initial-work-towards-proper-memory-reclocking-with-timings.
- Delete patches.drm/0985-drm-nv50-disp-more-accurate-function-to-determine-active-crtcs.
- Delete patches.drm/0986-drm-nv50-pm-use-hwsq-for-engine-reclocking-too.
- Delete patches.drm/0987-drm-nv50-pm-wait-for-all-fifo-connected-engines-to-idle-before-reclocking.
- Delete patches.drm/0988-drm-nouveau-pm-track-mr2-for-gddr3.
- Delete patches.drm/0989-drm-nv50-fix-detection-of-second-vram-rank.
- Delete patches.drm/0990-drm-nouveau-pm-detect-when-we-need-dll-disabled-for-gddr3.
- Delete patches.drm/0991-drm-nouveau-pm-fix-dll-off-dll-on-transitions.
- Delete patches.drm/0992-drm-nouveau-pm-rework-to-allow-selecting-separate-profiles-for-ac-battery.
- Delete patches.drm/0993-drm-nouveau-pm-extend-profile-interface-for-destroy-init-fini.
- Delete patches.drm/0994-drm-nouveau-mem-handle-dll_off-for-ddr2-ddr3.
- Delete patches.drm/0995-drm-nouveau-recognise-dcb-connector-type-for-dp-dvi-vga-dms-59.
- Delete patches.drm/0996-drm-nv50-nvc0-vm-support-unsnooped-system-memory.
- Delete patches.drm/0997-drm-nv50-display-expose-color-vibrance-control.
- Delete patches.drm/0998-drm-nvc0-fb-detect-presense-of-second-rank.
- Delete patches.drm/0999-drm-nouveau-pm-init-only-after-display-subsystem-has-been-created.
- Delete patches.drm/1000-drm-nouveau-mxm-call-mxmi-to-determine-revision-before-calling-mxms.
- Delete patches.drm/1001-drm-nouveau-dp-fix-bad-comparison-in-dp_link_train_commit.
- Delete patches.drm/1002-drm-nvc0-pm-restrict-pll-mode-to-clocks-that-can-actually-use-it.
- Delete patches.drm/1003-drm-nouveau-pm-several-fixes-for-nvc0-memory-timings.
- Delete patches.drm/1004-drm-nv40-pm-fix-fanspeed-regression.
- Delete patches.drm/1005-drm-nvc0-vram-get-part-count-from-punits.
- Delete patches.drm/1006-drm-nvd0-disp-attempt-to-handle-more-than-2-crtcs-if-possible.
- Delete patches.drm/1007-drm-nouveau-bios-attempt-acpi-rom-fetch-before-pcirom.
- Delete patches.drm/1008-drm-nouveau-bios-rework-vbios-shadowing.
- Delete patches.drm/1009-drm-nouveau-pm-fix-oops-if-chipset-has-no-pm-support-at-all.
- Delete patches.drm/1010-drm-nouveau-dp-make-functions-for-executing-various-bios-tables.
- Delete patches.drm/1011-drm-nouveau-dp-move-all-nv50-sor-specific-code-out-of-nouveau_dp-c.
- Delete patches.drm/1012-drm-nv50-hwsq-some-nv92-fixes.
- Delete patches.drm/1013-drm-nouveau-dp-make-dp-dpms-function-common-call-from-sor-code-instead.
- Delete patches.drm/1014-drm-nvd0-disp-initial-implementation-of-displayport.
- Delete patches.drm/1015-drm-nvd0-disp-fix-dcb-sor-link-matching-in-supervisor-handler.
- Delete patches.drm/1016-drm-nouveau-dp-account-for-channel-coding-overhead-in-link-training.
- Delete patches.drm/1017-drm-nvd0-disp-move-syncs-magic-setup-to-or-mode_set.
- Delete patches.drm/1018-drm-nvd0-disp-disconnect-encoders-before-reprogramming-them.
- Delete patches.drm/1019-drm-nouveau-map-first-page-of-mmio-early-and-determine-chipset-earlier.
- Delete patches.drm/1020-drm-nouveau-add-userspace-fallback-hints.
- Delete patches.drm/1122-drm-nouveau-ttm-always-do-buffer-moves-on-kernel-channel.
- Delete patches.drm/1123-drm-nouveau-remove-subchannel-names-from-places-where-it-doesn-t-matter.
- Delete patches.drm/1124-drm-nouveau-move-fence-sequence-check-to-start-of-loop.
- Delete patches.drm/1125-drm-nvc0-disp-reimplement-flip-completion-method-as-fifo-method.
- Delete patches.drm/1126-drm-nouveau-remove-m2mf-creation-on-userspace-channels.
- Delete patches.drm/1127-drm-nouveau-inform-userspace-of-new-kernel-subchannel-requirements.
- Delete patches.drm/1128-drm-nouveau-oops-increase-channel-dispc_vma-to-4.
- Delete patches.drm/1129-drm-nvd0-disp-ignore-clock-set-if-no-pclk.
- Delete patches.drm/1130-drm-nouveau-bump-version-to-1-0-0.
- Delete patches.drm/1131-drm-nouveau-move-out-of-staging-drivers.
- Delete patches.drm/1132-drm-nouveau-add-bios-connector-type-for-dms59.
- Delete patches.drm/1133-drm-nve0-initial-modesetting-support-for-kepler-chipsets.
- Delete patches.drm/1134-drm-nve0-disp-nvidia-randomly-decided-to-move-the-dithering-method.
- Delete patches.drm/1135-drm-nouveau-dp-support-version-4-0-of-dp-table.
- Delete patches.drm/1145-drm-nouveau-fix-thinko-causing-init-to-fail-on-cards-without-accel.
- Delete patches.drm/1146-drm-nouveau-default-to-8bpc-for-non-lvds-panels-if-edid-isn-t-useful.
- Delete patches.drm/1147-drm-nouveau-i2c-fix-thinko-regression-on-really-old-chipsets.
- Delete patches.drm/1151-drm-nouveau-oops-create-m2mf-for-nvd9-too.
- Delete patches.drm/1152-revert-drm-nouveau-inform-userspace-of-new-kernel-subchannel-requirements.
- Delete patches.drm/1153-drm-nouveau-inform-userspace-of-relaxed-kernel-subchannel-requirements.
- Delete patches.drm/1161-drm-nouveau-select-power_supply.
- Delete patches.drm/1162-nouveau-fix-crash-when-pci_ram_rom-returns-a-size-of-0.
- Delete patches.drm/1163-nouveau-bios-fix-tracking-of-bios-image-data.
- Delete patches.drm/1171-revert-nouveau-bios-fix-tracking-of-bios-image-data.
- Delete patches.drm/1196-drm-nouveau-pm-don-t-read-write-beyond-end-of-stack-buffer.
- Delete patches.drm/1198-nouveau-set-special-lane-map-for-the-right-chipset.
- Delete patches.drm/1207-drm-nouveau-bios-fix-regression-on-some-nv4x-board.
- Delete patches.drm/1208-drm-nouveau-hdmi-use-correct-hdmi-regs-for-nvaa-nvac.
- Delete patches.drm/1210-drm-nv10-gpio-fix-thinko-in-mask-for-gpio-lines-2-9.
- Delete patches.drm/1214-nouveau-initialise-has_optimus-variable.
- Delete patches.drm/1219-drm-nouveau-i2c-resume-use-of-i2c-algo-bit-rather-than-custom-stack.
- Delete patches.drm/1664-drm-nouveau-dp-probe-branch-sink-ouis-v2.
- Delete patches.drm/1678-nouveau-add-prime-support.
- Delete patches.drm/1684-drm-nva3-pm-introduce-more-paranoia.
- Delete patches.drm/1685-drm-nva3-pm-hook-up-to-ram-reclocking-helper.
- Delete patches.drm/1686-drm-nva3-pm-initial-attempt-at-more-magic-pfb-regs.
- Delete patches.drm/1687-drm-nva3-pm-more-random-unknown-pfb-regs.
- Delete patches.drm/1688-drm-nva3-pm-begin-to-restructure-memory-clock-changes-another-magic.
- Delete patches.drm/1689-drm-nva3-pm-attempt-to-bash-a-few-0x100200-bits-correctly.
- Delete patches.drm/1690-drm-nva3-pm-make-pll-pll-mode-work.
- Delete patches.drm/1691-drm-nva3-pm-initial-attempt-at-handling-111100-111104.
- Delete patches.drm/1692-drm-nva3-pm-another-few-magic-regs-and-slightly-better-0x004018-handling.
- Delete patches.drm/1693-drm-nvc0-pm-start-filling-in-memory-reclocking-stubs.
- Delete patches.drm/1694-drm-nvc0-pm-enable-mpll-src-pll-and-calc-mpll-coefficients.
- Delete patches.drm/1695-drm-nvd9-pm-oops-fix-timing-calc.
- Delete patches.drm/1696-drm-nvc0-pm-very-initial-mclk-freq-change.
- Delete patches.drm/1697-drm-nouveau-pm-some-more-delays-for-ddr3-reclocking.
- Delete patches.drm/1698-drm-nouveau-give-a-slightly-larger-pciegart-aperture-on-all-chipsets.
- Delete patches.drm/1699-drm-nve0-fifo-initial-implementation.
- Delete patches.drm/1700-drm-nve0-gr-initial-implementation.
- Delete patches.drm/1701-drm-nv50-fbcon-move-2d-class-to-subchannel-3.
- Delete patches.drm/1702-drm-nve0-ttm-implement-buffer-moves-with-weirdo-pcopy-on-pgraph-methods.
- Delete patches.drm/1703-drm-nouveau-bios-allow-loading-alternate-vbios-image-as-firmware.
- Delete patches.drm/1704-drm-nouveau-use-the-same-packet-header-macros-as-userspace.
- Delete patches.drm/1705-drm-nve0-graph-bump-hub2gpc-buffer-size.
- Delete patches.drm/1706-drm-nv50-fix-ramin-heap-size-for-kernel-channel-too.
- Delete patches.drm/1707-drm-nouveau-cleanup-after-display-init-failure.
- Delete patches.drm/1708-drm-nv50-disp-fixup-error-paths-in-crtc-object-creation.
- Delete patches.drm/1709-drm-nv40-50-gr-restructure-grctx-prog-generation.
- Delete patches.drm/1710-drm-nouveau-base-fence-timeout-on-time-of-emission.
- Delete patches.drm/1711-drm-nv04-disp-disable-vblank-interrupts-when-disabling-display.
- Delete patches.drm/1712-drm-nvd0-disp-remove-unnecessary-sync-from-flip_next.
- Delete patches.drm/1713-drm-nouveau-create-real-execution-engine-for-software-object-class.
- Delete patches.drm/1714-drm-nouveau-move-flip-related-channel-setup-to-software-engine.
- Delete patches.drm/1715-drm-nouveau-fence-make-ttm-interfaces-wrap-ours-not-the-other-way-around.
- Delete patches.drm/1716-drm-nouveau-fence-minor-api-changes-for-an-upcoming-rework.
- Delete patches.drm/1717-drm-nouveau-fence-convert-to-exec-engine-and-improve-channel-sync.
- Delete patches.drm/1718-drm-nouveau-fix-engine-context-destructor-ordering.
- Delete patches.drm/1719-drm-nouveau-bios-fix-some-shadowing-issues-particularly-acpi.
- Delete patches.drm/1720-drm-nouveau-fence-fix-a-race-where-fence-channel-can-disappear.
- Delete patches.drm/1721-drm-nouveau-fifo-remove-all-the-special-engine-hooks.
- Delete patches.drm/1722-drm-nv50-fifo-construct-playlist-from-hw-context-table-state.
- Delete patches.drm/1723-drm-nv50-gr-make-sure-next_to_current-is-executed-even-if-nothing-done.
- Delete patches.drm/1724-drm-nv50-fifo-use-hardware-channel-kickoff-functionality.
- Delete patches.drm/1725-drm-nv50-remove-execution-engine-context-saves-on-suspend.
- Delete patches.drm/1726-drm-nv50-remove-manual-context-unload-on-context-destruction.
- Delete patches.drm/1727-drm-nv50-graph-remove-ability-to-do-interrupt-driven-context-switching.
- Delete patches.drm/1728-drm-nouveau-fifo-turn-all-fifo-modules-into-engine-modules.
- Delete patches.drm/1729-drm-nv98-crypt-non-stub-implementation-of-the-engine-hooks.
- Delete patches.drm/1730-drm-nouveau-fbcon-use-fence-for-sync-rather-than-notifier.
- Delete patches.drm/1731-drm-nouveau-ttm-untangle-code-to-support-accelerated-buffer-moves.
- Delete patches.drm/1732-drm-nv84-ttm-use-crypto-engine-for-async-buffer-copies.
- Delete patches.drm/1733-drm-nv98-ttm-add-in-a-disabled-crypto-engine-buffer-copy-method.
- Delete patches.drm/1734-drm-nva3-ttm-use-copy-engine-for-async-buffer-moves.
- Delete patches.drm/1735-drm-nvc0-ttm-use-copy-engines-for-async-buffer-moves.
- Delete patches.drm/1736-drm-nvd9-copy-initialise-copy-engine-seems-to-work-like-nvc0.
- Delete patches.drm/1737-drm-nouveau-disp-fix-dithering-not-being-enabled-on-some-edp-macbooks.
- Delete patches.drm/1738-drm-nv50-decode-pgraph-data_error-0x24.
- Delete patches.drm/1739-drm-nouveau-turn-a-bug-into-a-warn.
- Delete patches.drm/1740-drm-nouveau-fix-a-minor-annoyance-in-an-output-string.
- Delete patches.drm/1741-drm-nouveau-check-dsm-on-switcheroo-unregister.
- Delete patches.drm/1742-drm-nouveau-unregister-switcheroo-client-on-exit.
- Delete patches.drm/1743-drm-nouveau-nvd9-fix-gpio-initialisation-sequence.
- Delete patches.drm/1764-nouveau-add-stub-dma-buf-mmap-functionality.
- Delete patches.drm/1770-nouveau-add-vmap-support-to-nouveau-prime-support.
- Delete patches.drm/1818-drm-nouveau-add-license-header-to-prime.
- Delete patches.drm/2057-nouveau-fix-alignment-requirements-on-src-and-dst-addresses.
- Delete patches.drm/2058-drm-nouveau-dcb-table-quirk-for-fdo-50830.
- Delete patches.drm/2059-drm-nv84-decode-pcrypt-errors.
- Delete patches.drm/2060-drm-nv50-rename-invalid_query_or_texture-error-to-invalid_operation.
- Delete patches.drm/2061-drm-nouveau-gem-fix-object-reference-leak-in-a-failure-path.
- Delete patches.drm/2062-drm-nouveau-move-current-gpuobj-code-out-of-nouveau_object-c.
- Delete patches.drm/2063-drm-nouveau-mark-most-of-our-ioctls-as-deprecated-move-to-compat-layer.
- Delete patches.drm/2064-drm-nv50-extend-vblank-semaphore-to-generic-dmaobj-offset-pair.
- Delete patches.drm/2065-drm-nouveau-init-vblank-requests-list.
- Delete patches.drm/2100-drm-nve0-fifo-add-support-for-the-flip-completion-swmthd.
- Delete patches.drm/2130-drm-nvd0-disp-mask-off-high-16-bit-of-negative-cursor-x-coordinate.
- Delete patches.drm/2131-drm-nouveau-aux-mask-off-higher-bits-of-auxch-index-in-i2c-table-entry.
- Delete patches.drm/2132-nouveau-fixup-scanout-enable-in-nvc0_pm.
- Delete patches.drm/2133-drm-nouveau-disable-copy-engine-on-nvaf.
- Delete patches.drm/2134-drm-nv86-fifo-suspend-fix.
- Delete patches.drm/2162-drm-nvc0-copy-check-punits-to-determine-which-copy-engines-are-disabled.
- Delete patches.drm/2174-drm-nvd0-disp-hopefully-fix-selection-of-6-8bpc-mode-on-dp-outputs.
- Delete patches.drm/2175-drm-nv50-gpio-initialise-to-vbios-defaults-during-init.
- Delete patches.drm/2203-drm-nouveau-fix-booting-with-plymouth-dumb-support.
- Delete patches.drm/2207-revert-drm-nv50-gpio-initialise-to-vbios-defaults-during-init.
- Delete patches.drm/2209-drm-nouveau-add-dmi-quirk-for-gpio-reset.
- Delete patches.drm/2210-drm-nouveau-silence-a-debug-message-triggered-by-newer-userspace.
- Delete patches.drm/2211-drm-nvc0-ltcg-mask-off-intr-0x10.
- Delete patches.drm/2214-drm-nvc0-fifo-ignore-bits-in-pfifo_intr-that-aren-t-set-in-pfifo_intr_en.
- Delete patches.drm/2560-drm-nvc0-fence-restore-pre-suspend-fence-buffer-context-on-resume.
- Delete patches.drm/2561-drm-nouveau-gem-use-bo-offset-rather-than-mm_node-start.
- Delete patches.drm/2562-drm-nouveau-restructure-source-tree-split-core-from-drm-implementation.
- Delete patches.drm/2563-drm-nouveau-agp-move-all-agp-stuff-into-its-own-source-file.
- Delete patches.drm/2564-drm-nouveau-core-pull-in-most-of-the-new-core-infrastructure.
- Delete patches.drm/2565-drm-nouveau-implement-module-init-functions-in-nouveau_drm-c.
- Delete patches.drm/2566-drm-nouveau-have-non-core-mmio-accesses-go-through-device-object.
- Delete patches.drm/2567-drm-nouveau-bios-pull-in-basic-vbios-subdev-more-to-come-later.
- Delete patches.drm/2568-drm-nouveau-oldbios-remove-shadowing-support-use-bios-subdev-s-image.
- Delete patches.drm/2569-drm-nouveau-gpio-port-gpio-to-subdev-interfaces.
- Delete patches.drm/2570-drm-nouveau-i2c-port-to-subdev-interfaces.
- Delete patches.drm/2571-drm-nouveau-clk-implement-stub-clock-subdev.
- Delete patches.drm/2572-drm-nouveau-clock-pull-in-the-implementation-from-all-over-the-place.
- Delete patches.drm/2573-drm-nouveau-implement-devinit-subdev-and-new-init-table-parser.
- Delete patches.drm/2574-drm-nouveau-mc-port-to-subdev-interfaces.
- Delete patches.drm/2575-drm-nouveau-timer-port-to-subdev-interfaces.
- Delete patches.drm/2576-drm-nouveau-core-add-support-for-reverse-mm-allocations.
- Delete patches.drm/2577-drm-nv50-instmem-allocate-vram-for-kernel-objects-from-end-of-vram.
- Delete patches.drm/2578-drm-nouveau-fb-merge-fb-vram-and-port-to-subdev-interfaces.
- Delete patches.drm/2579-drm-nv04-nv40-instmem-duplicate-nv04-code-as-nv40-remove-alternate-paths.
- Delete patches.drm/2580-drm-nv04-nv40-instmem-remove-use-of-nouveau_gpuobj_new_fake.
- Delete patches.drm/2581-drm-nv04-nv40-fifo-remove-use-of-nouveau_gpuobj_new_fake.
- Delete patches.drm/2582-drm-nvc0-fifo-handle-bar1-control-regs-much-like-fifo-nve0.
- Delete patches.drm/2583-drm-nouveau-gpuobj-create-wrapper-functions-for-mapping-gpuobj-into-vm-bar.
- Delete patches.drm/2584-drm-nouveau-gpuobj-remove-flags-for-vm-mappings.
- Delete patches.drm/2585-drm-nv50-instmem-remove-use-of-nouveau_gpuobj_new_fake.
- Delete patches.drm/2586-drm-nouveau-remove-last-use-of-nouveau_gpuobj_new_fake.
- Delete patches.drm/2587-drm-nouveau-instmem-completely-new-implementation-as-a-subdev-module.
- Delete patches.drm/2588-drm-nv04-disp-kick-all-private-state-out-to-own-header.
- Delete patches.drm/2589-drm-nouveau-pull-nouveau_bo-definitions-into-their-own-header.
- Delete patches.drm/2590-drm-nouveau-pull-nouveau_gem-definitions-into-their-own-header.
- Delete patches.drm/2591-drm-nouveau-fence-un-port-from-nouveau_exec_engine-interfaces.
- Delete patches.drm/2592-drm-nvc0-nve0-graph-rename-dev-to-priv-no-code-changes.
- Delete patches.drm/2593-drm-nouveau-move-some-more-code-around-to-more-appropriate-places.
- Delete patches.drm/2594-drm-nouveau-pageflip-kick-flip-handling-out-of-engsw-and-into-fence.
- Delete patches.drm/2595-drm-nvc0-gr-share-headers-between-fermi-and-kepler-graphics-code.
- Delete patches.drm/2596-drm-nvc0-gr-generate-grctx-template-at-init-time-not-first-context-ctor.
- Delete patches.drm/2597-drm-nouveau-port-all-engines-to-new-engine-module-format.
- Delete patches.drm/2598-drm-nouveau-start-culling-unused-code.
- Delete patches.drm/2599-drm-nouveau-mxm-split-up-into-bios-code-and-a-subdev-module.
- Delete patches.drm/2600-drm-nouveau-acpi-move-definitions-out-of-nouveau_drv-h.
- Delete patches.drm/2601-drm-nouveau-move-compat-ioctl-out-of-nouveau_drv-h.
- Delete patches.drm/2602-drm-nouveau-flatten-nv-read-write-mc-video-fb-extdev.
- Delete patches.drm/2603-drm-nouveau-backlight-remove-dependence-on-nouveau_drv-h.
- Delete patches.drm/2604-drm-nouveau-device-include-the-official-chipset-names.
- Delete patches.drm/2605-drm-nouveau-port-remainder-of-drm-code-and-rip-out-compat-layer.
- Delete patches.drm/2606-drm-nouveau-add-kconfig-options-for-debug-control.
- Delete patches.drm/2607-drm-nvc0-gr-remove-reset-after-grctx-construction-hack.
- Delete patches.drm/2608-drm-nouveau-core-remove-some-left-over-pieces-from-the-porting-process.
- Delete patches.drm/2609-drm-nouveau-device-return-proper-error-codes-if-ioremap-fails.
- Delete patches.drm/2610-drm-nve0-fifo-support-engine-selection-when-creating-fifo-channels.
- Delete patches.drm/2611-drm-nve0-copy-add-initial-support-for-the-async-copy-engines.
- Delete patches.drm/2612-drm-nve0-use-async-copy-engine-for-ttm-buffer-moves-if-available.
- Delete patches.drm/2613-drm-nv84-fifo-mask-only-the-engine-we-re-waiting-on-for-channel-unload.
- Delete patches.drm/2614-drm-nouveau-core-protect-engine-context-list-with-hardirq-safe-spinlock.
- Delete patches.drm/2615-drm-nouveau-fifo-add-method-to-lookup-fifo-chid-related-to-a-given-object.
- Delete patches.drm/2616-drm-nouveau-core-have-fifo-store-a-unique-context-identifier-at-attach-time.
- Delete patches.drm/2617-drm-nouveau-restore-fifo-chid-information-in-engine-error-messages.
- Delete patches.drm/2618-drm-nouveau-fifo-separate-object-classes-for-dma-channels.
- Delete patches.drm/2619-drm-nouveau-fifo-version-the-dma-channel-class-struct.
- Delete patches.drm/2620-drm-nv84-fifo-add-support-for-dma-channel-class.
- Delete patches.drm/2621-drm-nv50-fifo-add-support-for-dma-channel-class.
- Delete patches.drm/2622-drm-nouveau-add-defines-for-internal-class-names.
- Delete patches.drm/2623-drm-nouveau-dmaobj-reject-unsupported-parent-types-instead-of-half-succeeding.
- Delete patches.drm/2624-drm-nouveau-fifo-use-defines-instead-of-hardcoded-class-ids.
- Delete patches.drm/2625-drm-nouveau-constify-instances-of-nouveau_bitfield-and-nouveau_enum-structs.
- Delete patches.drm/2626-drm-nouveau-quiet-some-static-related-sparse-noise.
- Delete patches.drm/2627-drm-nouveau-sw-trap-and-clear-pmc_intr_0_software.
- Delete patches.drm/2628-drm-nve0-ibus-handle-pibus-interrupts-to-prevent-storm.
- Delete patches.drm/2629-drm-nve0-gr-initial-fuc-implementation-based-on-fermi-s-code.
- Delete patches.drm/2630-drm-nve0-gr-remove-0x404160-bashing-from-hub-fuc.
- Delete patches.drm/2631-drm-nve0-gr-enable-use-of-our-fuc-by-default.
- Delete patches.drm/2632-drm-nvc0-ltcg-read-lts-count-at-startup.
- Delete patches.drm/2633-drm-nvc0-gr-rebuild-fuc-with-latest-envyas.
- Delete patches.drm/2634-drm-nvc0-gr-implement-initial-trap-handler.
- Delete patches.drm/2635-drm-nvc0-fifo-re-bash-pbus-regs-after-vm-fault-to-bars-peephole.
- Delete patches.drm/2636-drm-nouveau-core-have-client-id-be-a-string-rather-than-an-integer.
- Delete patches.drm/2637-drm-nouveau-have-drm-debugging-macros-build-on-top-of-core-macros.
- Delete patches.drm/2638-drm-nouveau-log-channel-debug-error-messages-from-client-object-rather-than-drm-client.
- Delete patches.drm/2639-drm-nouveau-bios-check-that-fixed-tvdac-gpio-data-is-valid-before-using-it.
- Delete patches.drm/2640-drm-nouveau-fix-pm-initialization-order.
- Delete patches.drm/2641-drm-nouveau-gpio-expose-the-pwm-toggle-parameter-found-in-the-gpio-vbios-table.
- Delete patches.drm/2642-drm-nouveau-therm-rework-thermal-table-parsing.
- Delete patches.drm/2643-drm-nouveau-therm-use-the-extdev-table-to-detect-i2c-monitoring-devices.
- Delete patches.drm/2644-drm-nouveau-bios-parse-the-pwm-divisor-from-the-perf-table.
- Delete patches.drm/2645-drm-nouveau-therm-move-thermal-related-functions-to-the-therm-subdev.
- Delete patches.drm/2646-drm-nouveau-fan-rewrite-the-fan-tachometer-driver-to-get-more-precision-faster.
- Delete patches.drm/2647-drm-nouveau-therm-calculate-the-pwm-divisor-on-nv50.
- Delete patches.drm/2648-drm-nouveau-hwmon-rename-pwm0-to-pmw1-to-follow-hwmon-s-rules.
- Delete patches.drm/2649-drm-nouveau-therm-add-support-for-fan-control-modes.
- Delete patches.drm/2650-drm-nvc0-ibus-initial-implementation-of-subdev.
- Delete patches.drm/2651-drm-nouveau-store-supported-dma-mask-in-vmmgr.
- Delete patches.drm/2652-drm-nv04-dmaobj-fixup-vm-target-handling-in-preparation-for-nv4x-pcie.
- Delete patches.drm/2653-drm-nv44-vm-fix-and-enable-use-of-real-pciegart.
- Delete patches.drm/2654-drm-nv41-vm-fix-and-enable-use-of-real-pciegart.
- Delete patches.drm/2655-drm-nouveau-devinit-fixup-various-issues-with-subdev-ctor-init-ordering.
- Delete patches.drm/2656-drm-nv98-crypt-fix-fuc-build-with-latest-envyas.
- Delete patches.drm/2700-drm-nouveau-bios-fix-shadowing-of-acpi-roms-larger-than-64kib.
- Delete patches.drm/2701-drm-nouveau-remove-unused-nouveau_parent_ctor.
- Delete patches.drm/2702-drm-nv50-clk-wire-up-pll_calc-hook.
- Delete patches.drm/2703-drm-nouveau-fan-fix-a-typo-in-pwm-s-input-clock-calculation.
- Delete patches.drm/2704-drm-nouveau-timer-bump-ptimer-s-alarm-delay-from-u32-to-u64.
- Delete patches.drm/2726-drm-nouveau-pm-do-not-stop-reclocking-if-failing-to-set-the-fan-speed.
- Delete patches.drm/2727-drm-nv50-fb-fix-double-free-of-vram-mm.
- Delete patches.drm/2728-drm-nouveau-only-call-ttm_agp_tt_create-when-_os_has_agp.
- Delete patches.drm/2729-drm-nouveau-bios-fix-typo-in-error-message.
- Delete patches.drm/2730-nouveau-fix-warning-on-32-bit-build.
- Delete patches.drm/2734-drm-nouveau-handle-same-fb-page-flips.
- Delete patches.drm/2735-drm-nouveau-bios-improve-error-handling-when-reading-the-vbios-from-acpi.
- Delete patches.drm/2736-drm-nouveau-fix-nouveau_mm-nouveau_mm_node-leak.
- Delete patches.drm/2737-drm-nouveau-warn-when-trying-to-free-mm-which-is-still-in-use.
- Delete patches.drm/2738-drm-nouveau-validate-vbios-size.
- Delete patches.drm/2739-drm-nouveau-bios-fetch-full-4kib-block-to-determine-acpi-rom-image-size.
- Delete patches.drm/2740-drm-nv41-vm-don-t-init-hw-pciegart-on-boards-with-agp-bridge.
- Delete patches.drm/2741-drm-nouveau-fb-fix-reporting-of-memory-type-on-gf8-igps.
- Delete patches.drm/2742-drm-nouveau-clock-fix-missing-pll-type-addr-when-matching-default-entry.
- Delete patches.drm/2767-drm-nouveau-i2c-fix-typo-when-checking-nvio-i2c-port-validity.
- Delete patches.drm/2768-drm-nouveau-allow-creation-of-zero-sized-mm.
- Delete patches.drm/2769-drm-nv50-fb-prevent-oops-on-chipsets-without-compression-tags.
- Delete patches.drm/2770-drm-nouveau-resurrect-headless-mode-since-rework.
- Delete patches.drm/2771-drm-nouveau-headless-mode-by-default-if-pci-class-vga-display.
- Delete patches.drm/2784-drm-nv41-vm-fix-typo-in-type-name.
- Delete patches.drm/2785-drm-nv40-graph-fix-typo-in-type-names.
- Delete patches.drm/2786-drm-nv40-mpeg-fix-context-handling.
- Delete patches.drm/2787-drm-nvc0-disp-fix-regression-in-vblank-semaphore-release.
- Delete patches.drm/2794-drm-nvc0-disp-fix-thinko-in-vblank-regression-fix.
- Delete patches.drm/2795-drm-nv40-allocate-ctxprog-with-kmalloc.
- Delete patches.drm/2796-drm-nouveau-add-missing-pll_calc-calls.
- Delete patches.drm/2797-drm-nouveau-bios-fix-dcb-v1-5-parsing.
- Delete patches.drm/2801-drm-nouveau-use-the-correct-fence-implementation-for-nv50.
- Delete patches.drm/3074-drm-nouveau-free-memory-allocated-with-alloc_apertures.
- commit 063ed68
* Thu Feb 21 2013 jbeulich@suse.com
- Update Xen patches to 3.0.63.
- patches.xen/1223-netback-count-requests-result.patch: netback:
  fix netbk_count_requests().
- patches.xen/xen3-mm-x86-mm-Check-if-PUD-is-large-when-validating-a-kernel-address.patch:
  x86/mm: Check if PUD is large when validating a kerneladdress
  (bnc#794805).
- commit 3df8c74
* Thu Feb 21 2013 bpoirier@suse.de
- Rename
  patches.drivers/iw_cxgb3-0005-IB-Use-central-enum-for-speed-instead-of-hard-coded-.patch
  It's not specific to cxgb3
- commit 0d2f0e4
* Thu Feb 21 2013 tiwai@suse.de
- rpm/kernel-binary.spec.in: obsolete drm-kmp <= 3.7
- commit 1fc3d39
* Thu Feb 21 2013 tiwai@suse.de
- Revert UAPI header movement in drm stack
- Delete patches.drm/2554-uapi-scripted-set-up-uapi-kbuild-files.
- Delete patches.drm/2684-uapi-scripted-disintegrate-include-drm.
- Delete patches.drm/2806-makefile-include-fixes.diff.
- Refresh
  patches.drm/2689-drm-exynos-remove-drm-hdmi-platform-data-struct.
- Refresh
  patches.drm/2851-drm-i915-allow-drm_root_only_drm_master-to-submit-privileged-batchbuffers.
- Refresh
  patches.drm/3063-drm-add-support-for-monotonic-vblank-timestamps.
- Refresh
  patches.drm/3193-drm-i915-reduce-memory-pressure-during-shrinker-by-preallocating-swizzle-pages.
- Refresh
  patches.drm/3206-drm-i915-implement-workaround-for-broken-cs-tlb-on-i830-845.
- commit ed7b914
* Thu Feb 21 2013 eich@suse.com
- Delete patches.suse/drm-radeon-remove-ES1000-support.
  All issues which led to bnc#746526 have meanwhile been fixed upstream.
  Since upstream is now merged into our tree we can reenable ES1000, now.
- commit 2ae2df6
* Thu Feb 21 2013 tiwai@suse.de
- Export ktime_get_monotonic_offset().
- commit c46d391
* Thu Feb 21 2013 hare@suse.de
- libfcoe: Handle CVL while waiting to select an FCF (bnc#802533).
- commit 5d93237
* Thu Feb 21 2013 hare@suse.de
- libfcoe: Check for unusable FCFs before looking for conflicting
  FCFs (bnc#801523).
- commit 9e81e1b
* Thu Feb 21 2013 tiwai@suse.de
- Remove a few ugly w/a patches in patches.drm
  Backport the (small) upstream patches properly instead.
- i2c: export bit-banging algo functions.
- sched/wait: Add __wake_up_all_locked() API.
- Refresh
  patches.drm/1270-drm-i915-intel_i2c-gmbus-disabled-and-reserved-ports-are-invalid.
- Refresh
  patches.drm/2552-uapi-scripted-convert-include-to-include-path-in-drivers-gpu.
- Delete patches.drm/1220-i2c-algo-bit.diff.
- Delete patches.drm/2216-radeon-remove-wake_up_all_locked.diff.
- Delete patches.drm/3239-intel-gmch-kabi-fix.diff.
- Delete patches.drm/3242-revert-monotonic-vblank.diff.
- commit 1935bc9
* Thu Feb 21 2013 mgorman@suse.de
- patches.fixes/mm-mmu_notifier-have-mmu_notifiers-use-a-global-SRCU-so-they-may-safely-schedule.patch:
  mm: mmu_notifier: have mmu_notifiers use a global SRCU so they may safely schedule
- patches.fixes/mm-mmu_notifier-make-the-mmu_notifier-srcu-static.patch:
  mm: mmu_notifier: make the mmu_notifier srcu static
- patches.fixes/mm-mmu_notifier_unregister-NULL-Pointer-deref-and-multiple---release-callouts.patch:
  mmu_notifier_unregister NULL Pointer deref and multiple ->release() callouts
- patches.fixes/mm-mmu_notifier-have-mmu_notifiers-use-a-global-SRCU-so-they-may-safely-schedule-kabi.patch:
  Have mmu_notifiers use SRCU so they may safely schedule kabi compatability
- patches.fixes/Have-mmu_notifiers-use-SRCU-so-they-may-safely-schedule.patch:
- patches.fixes/Have-mmu_notifiers-use-SRCU-so-they-may-safely-schedule-build-fix.patch:
  Delete, replace with upstream equivalent and add KABI workaround
  (bnc#578046, bnc#786814, FATE#306952).
- commit df06b4b
* Thu Feb 21 2013 mhocko@suse.cz
- Delete patches.suse/revert-network-error-fixes
- commit 1ee3093
* Thu Feb 21 2013 jbeulich@suse.com
- update Xen patches to 3.0.65 and c/s 1224
- swiotlb: Expose swiotlb_nr_tlb function to modules
- drm/ttm: Use pr_fmt and pr_<level>
- hpwdt: handle NMI_SERR and NMI_IO_CHECK (bnc#777746)
- Update EC2 config files.
- commit 0d36762
* Thu Feb 21 2013 trenn@suse.de
- intel_idle: support Haswell (fate#313720).
- commit 8ee5a45
* Wed Feb 20 2013 jlee@suse.com
- Refresh
  patches.fixes/0002-X.509-Support-parse-long-form-of-length-octets-in-Au.patch.
- commit 45cd092
* Wed Feb 20 2013 trenn@suse.de
- Disable efi pstore by default (bnc#804482).
- commit f0bc124
* Wed Feb 20 2013 hare@suse.de
- net: do not do gso for CHECKSUM_UNNECESSARY in netif_needs_gso
  (bnc#804574).
- commit 0843993
* Tue Feb 19 2013 jeffm@suse.com
- supported-flag: "no support" and "external support" aren't fatal.
- commit 4170a74
* Tue Feb 19 2013 mhocko@suse.cz
- patches.fixes/ptrace-ensure-arch_ptrace-ptrace_request-can-never-r.patch:
  Refresh.
- commit 1576ecd
* Tue Feb 19 2013 mhocko@suse.cz
- patches.fixes/ptrace-ensure-arch_ptrace-ptrace_request-can-never-r.patch:
  ptrace: ensure arch_ptrace/ptrace_request can never race with
  SIGKILL (bnc#804154, CVE-2013-0871).
- patches.fixes/ptrace-introduce-signal_wake_up_state-and-ptrace_sig.patch:
  ptrace: introduce signal_wake_up_state() and
  ptrace_signal_wake_up() (bnc#804154, CVE-2013-0871).
- patches.fixes/wake_up_process-should-be-never-used-to-wakeup-a-TAS.patch:
  wake_up_process() should be never used to wakeup a
  TASK_STOPPED/TRACED task (bnc#804154, CVE-2013-0871).
- commit 3371933
* Mon Feb 18 2013 jslaby@suse.cz
- Linux 3.0.65 (bnc#794805).
- patches.fixes/mm-x86-mm-Check-if-PUD-is-large-when-validating-a-kernel-address.patch:
  Delete.
- commit 36b6a9d
* Mon Feb 18 2013 jbohac@suse.cz
- Revert "Remove PTP from tg3"
  This reverts commit f683b6d0407ee5d01e8ff7b3e688a439a5676e02.
  Support for PTP in tg3 as requested by fate#314848.
- commit d0a8792
* Mon Feb 18 2013 mmarek@suse.cz
- Update kabi files.
- commit 7383549
* Mon Feb 18 2013 jbohac@suse.cz
- patches.fixes/ipv6-dont-send-packet-to-big-messages-to-self.patch:
  ipv6: Don't send packet to big messages to self (bnc#786150).
- commit 34a13ad
* Mon Feb 18 2013 mgorman@suse.de
- jbd: Refine commit writeout logic (Reduce parallel read
  latency ext3).
- jbd: Add fixed tracepoints (Reduce parallel read latency ext3).
- commit 9214b2c
* Mon Feb 18 2013 neilb@suse.de
- Allow NFSD to server NFSv3 over IPv6
  This was disabled in -SP1 as nfs-utils didn't support it.
  nfs-utils in -SP3 does.
- commit 4ea6fe0
* Sun Feb 17 2013 jjolly@suse.de
- s390: PCI stub functions (bnc#802343, FATE#83037, ltc#83040).
- Update config files.
- commit 3d4bbde
* Sun Feb 17 2013 jjolly@suse.de
- chelsio: remove get_clock and use ktime_get (bnc#802343,
  FATE#83037, ltc#83040).
- commit 3f10226
* Sun Feb 17 2013 jjolly@suse.de
- 3com: make 3c59x depend on HAS_IOPORT (bnc#802343, FATE#83037,
  ltc#83040).
- commit 622bbd9
* Sun Feb 17 2013 jjolly@suse.de
- vga: compile fix, disable vga for s390 (bnc#802343, FATE#83037,
  ltc#83040).
- commit 766592e
* Sun Feb 17 2013 jjolly@suse.de
- s390/pci: PCI adapter interrupts for MSI/MSI-X (bnc#802343,
  FATE#83037, ltc#83040).
- Update patches.arch/s390-sles11sp3-16-01-pci-base-support.patch
  (bnc#802343, FATE#83037, ltc#83040).
- commit a3033d1
* Sun Feb 17 2013 jjolly@suse.de
- s390/pci: base support (bnc#802343, FATE#83037, ltc#83040).
- commit 8d65dee
* Sun Feb 17 2013 jjolly@suse.de
- Update config files to v3.0.63.
- commit 2ce3ca5
* Sat Feb 16 2013 jjolly@suse.de
- asm-generic: add MMU variants of io.h functions
  (bnc#802343,FATE#314128,LTC#83040).
- commit 6d590dc
* Fri Feb 15 2013 ptesarik@suse.cz
- hpwdt: handle NMI_SERR and NMI_IO_CHECK (bnc#777746).
- commit 22603c3
* Fri Feb 15 2013 ptesarik@suse.cz
- patches.drivers/hpwdt_allow_kdump_by_default.patch: hpwdt:
  Unregister NMI events on exit (bnc#777746).
- patches.drivers/hpwdt_only_byte_reads_writes.patch: Refresh.
- commit 47b60c3
* Fri Feb 15 2013 jslaby@suse.cz
- Linux 3.0.64 (bnc#799209 bnc#801782).
- patches.drivers/0188-tg3-Migrate-phy-preprocessor-defs-to-system-defs.patch:
  Refresh.
- patches.drivers/tg3-fix-link-down-notify-failure-when-eee-disabled:
  Refresh.
- patches.kabi/revert-net-fix-NULL-dereferences-in-check_peer_redir.patch:
  Refresh.
- patches.fixes/bridge-Pull-ip-header-into-skb-data-before-looking-i.patch:
  Delete.
- patches.fixes/kernel-resource.c-fix-stack-overflow-in-__reserve_re.patch:
  Delete.
- commit ec8ac25
* Fri Feb 15 2013 mgorman@suse.de
- Refresh patches.drm/2271-merge-tag-v3-6-rc2-into-drm-intel-next.
  (series2git required refresh)
- commit bd7af85
* Fri Feb 15 2013 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
  fix logic (bnc#803982)
- commit a6e924c
* Fri Feb 15 2013 mgorman@suse.de
- patches.fixes/mm-x86-mm-Check-if-PUD-is-large-when-validating-a-kernel-address.patch:
  x86/mm: Check if PUD is large when validating a kernel address
  (bnc#794805).
- commit cc188c9
* Fri Feb 15 2013 jlee@suse.com
- patches.drivers/ata-Fix-DVD-not-dectected-at-some-Haswell-platforms.patch:
  ata: Fix DVD not dectected at some Haswell platforms
  (bnc#792674).
- commit 9dd92f6
* Thu Feb 14 2013 jack@suse.cz
- patches.fixes/printk-fix-softlockups-during-heavy-printing.patch:
  Avoid softlockups in printk (bnc#744692, bnc#789311).
- commit aae27f9
* Thu Feb 14 2013 msrb@novell.com
- Refresh patches.drm/0793-drm-radeon-deal-with-errors-from-framebuffer-init-path.
- Refresh patches.drm/2458-drm-radeon-properly-handle-mc_stop-mc_resume-on-evergreen-v2.
  Because of patches.kernel.org/patch-3.0.62-63.
- commit f7b059d
* Thu Feb 14 2013 rgoldwyn@suse.de
- patches.fixes/af_unix-do-not-pack-creds-for-dying-process:
  Do not pack credentials for dying processes (bnc#779577,
  bnc#803056).
- Disable the following patches because of change in default
  behavior (bnc#803056)
- patches.fixes/af_netlink-force-credentials-passing and
- patches.fixes/af_unix-dnt-send-SCM_CREDENTIALS-by-default
- commit f67a598
* Thu Feb 14 2013 rgoldwyn@suse.de
- patches.fixes/af_unix-do-not-pack-creds-for-dying-process:
  Do not pack credentials for dying processes (bnc#779577,
  bnc#803056).
- patches.fixes/af_netlink-force-credentials-passing: Delete.
- patches.fixes/af_unix-dnt-send-SCM_CREDENTIALS-by-default:
  Delete.
- commit 6b15562
* Thu Feb 14 2013 jack@suse.cz
- patches.fixes/xfs-punch-new-delalloc-blocks-out-of-failed-writes-i.patch:
  xfs: punch new delalloc blocks out of failed writes inside EOF
  (bnc#761849).
- patches.fixes/xfs-xfs_sync_data-is-redundant.patch: xfs:
  xfs_sync_data is redundant (bnc#761849).
- commit 492fe07
* Thu Feb 14 2013 jjolly@suse.de
- net/mlx4_core: Remove port type restrictions
  (bnc#802982,FATE#314021,LTC#83206).
- commit 7f7d8b5
* Thu Feb 14 2013 jjolly@suse.de
- mlx4: allocate just enough pages instead of always 4 pages
  (bnc#802982,FATE#314021,LTC#83206).
- commit ec44611
* Thu Feb 14 2013 jjolly@suse.de
- mlx4_en: nullify cached multicast address list after cleanup
  (bnc#802982,FATE#314021,LTC#83206).
- commit 2ce58cf
* Thu Feb 14 2013 jjolly@suse.de
- mlx4_en: fix skb truesize underestimation
  (bnc#802982,FATE#314021,LTC#83206).
- commit 65daad9
* Thu Feb 14 2013 jjolly@suse.de
- mlx4_core: Clean up enabling of SENSE_PORT for older
  (ConnectX-1/-2) HCAs (bnc#802982,FATE#314021,LTC#83206).
- commit 0161fe2
* Thu Feb 14 2013 jjolly@suse.de
- mlx4_core: Stash PCI ID driver_data in mlx4_priv structure
  (bnc#802982,FATE#314021,LTC#83206).
- commit 69abe81
* Thu Feb 14 2013 jjolly@suse.de
- mlx4: capability for link sensing
  (bnc#802982,FATE#314021,LTC#83206).
- commit 057114c
* Thu Feb 14 2013 jjolly@suse.de
- mlx4_core: Extend capability flags to 64 bits
  (bnc#802982,FATE#314021,LTC#83206).
- commit 50ba09b
* Thu Feb 14 2013 jjolly@suse.de
- mlx4_en: Adding 40gb speed report for ethtool
  (bnc#802982,FATE#314021,LTC#83206).
- commit c10cab7
* Wed Feb 13 2013 msrb@novell.com
- Update config for newer drm.
  CONFIG_DRM_AST=m
  CONFIG_DRM_CIRRUS_QEMU=m
  CONFIG_DRM_MGAG200=m
- commit 48d1829
* Wed Feb 13 2013 msrb@novell.com
- use pm_qos_params.h.
- Revert monotonic vblank.
- Revert commit 6311803b1294432ee680fec5e628efae0d485fa2 drm:
  use memchr_inv().
- Revert commit cdad05216c2b2edfe92a9f87d6ae51aab277f3b2 drm/ttm,
  drm/vmwgfx: Use RCU locking for object lookups v3.
- intel: gmch kabi fix.
- Revert "drm/radeon/kms: enable the ttm dma pool if swiotlb is
  on V4".
- drm/i915: GFX_MODE Flush TLB Invalidate Mode must be '1'
  for scanline waits.
- drm/i915: Disable AsyncFlip performance optimisations.
- drm/i915: fix FORCEWAKE posting reads.
- drm/i915/eDP: do not write power sequence registers for
  ghost eDP.
- drm/i915: Close race between processing unpin task and queueing
  the flip.
- drm/i915: fixup l3 parity sysfs access check.
- drm/i915: Clear the existing watermarks for g4x when modifying
  the cursor sr.
- drm/i915: do not access BLC_PWM_CTL2 on pre-gen4 hardware.
- drm/i915: Don't allow ring tail to reach the same cacheline
  as head.
- drm/i915: Decouple the object from the unbound list before
  freeing pages.
- ast: Kms only for secure boot.
- cirrus: Kms only for secure boot.
- mgag200: Kms only for secure boot.
- i915: lvds add standard modes.
- drm/i915: Use pixel size for computing linear offsets into
  a sprite.
- drm/i915: Revert shrinker changes from "Track unbound pages".
- drm: Only evict the blocks required to create the requested
  hole.
- drm/i915: Treat crtc->mode.clock == 0 as disabled.
- drm/i915; Only increment the user-pin-count after successfully
  pinning the bo.
- drm/i915: disable shrinker lock stealing for create_mmap_offset.
- drm/i915: optionally disable shrinker lock stealing.
- drm/i915: fix flags in dma buf exporting.
- i915: ensure that VGA plane is disabled.
- drm/i915: Preallocate the drm_mm_node prior to manipulating
  the GTT drm_mm manager.
- drm: Export routines for inserting preallocated nodes into
  the mm manager.
- drm/i915: don't disable disconnected outputs.
- drm/i915: Implement workaround for broken CS tlb on i830/845.
- drm/i915: Implement WaSetupGtModeTdRowDispatch.
- drm/i915: Implement WaDisableHiZPlanesWhenMSAAEnabled.
- drm/i915: Fixup cursor latency used for IVB lp3 watermarks.
- drm/i915: Prefer CRTC 'active' rather than 'enabled' during
  WM computations.
- drm/i915: Fix shifted screen on top of LVDS on IVY laptop.
- drm/i915: disable cpt phase pointer fdi rx workaround.
- drm/i915: set the LPT FDI RX polarity reversal bit when needed.
- drm/i915: add lpt_init_pch_refclk.
- drm/i915: add support for mPHY destination on intel_sbi_{read,
  write}.
- drm/i915: reject modes the LPT FDI receiver can't handle.
- drm/i915: fix hsw_fdi_link_train "retry" code.
- commit 936d571
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: don't prevent CPU idle states.
- drm/i915: Reduce memory pressure during shrinker by
  preallocating swizzle pages.
- drm/i915: extract common link_m_n helpers.
- drm/i915: drop unnecessary clearing of pch dp transcoder
  timings.
- drm/i915: WARN on !crtc in intel_dp_link_down.
- drm/i915: use wait_for_vblank instead of msleep(17).
- drm/i915: rip out pre-production ilk cpu edp w/a.
- drm/i915: move set_pll_edp to intel_dp.c.
- drm/i915: rip out pre-DDI stuff from haswell_crtc_mode_set.
- drm/i915: be less verbose when handling gmbus/aux irqs.
- drm/i915: Remove duplicate and unused register #defines in
  i915_reg.h.
- drm/i915: use _NOTRACE for gmbus/dp aux wait loops.
- drm/i915: irq-drive the dp aux communication.
- drm/i915: wire up do aux channel done interrupt.
- drm/i915: use gmbus irq to wait for gmbus idle.
- drm/i915: use the gmbus irq for waits.
- drm/i915: wire up gmbus irq handler.
- drm/i915: extract gmbus_wait_hw_status.
- drm/i915: reorder setup sequence to have irqs for output setup.
- drm/i915: setup the hangcheck timer early.
- drm/i915: don't handle PIPE_LEGACY_BLC_EVENT_STATUS on vlv.
- drm/i915: haswell has the same irq handlers as ivb.
- drm/i915: Add intel_ring_handle_seqno wrap.
- drm/i915: Split intel_ring_begin.
- drm/i915: Fix debugfs seqno info print to use uint.
- drm/i915: Add debugfs entry to read/write next_seqno.
- drm/i915: fixup sparse warnings.
- drm/i915: Remove check for conflicting relocation write-domains.
- drm/i915: Tighten the checks for invalid relocation domains.
- drm/i915: Fix dieing -> dying typo.
- drm/i915: Use a slab for object allocation.
- drm/i915: Allocate overlay registers from stolen memory.
- drm/i915: Allocate ringbuffers from stolen memory.
- drm/i915: Allocate fbcon from stolen memory.
- drm/i915: Introduce i915_gem_object_create_stolen().
- drm/i915: Support readback of stolen objects upon error.
- drm/i915: Allow objects to be created with no backing pages,
  but stolen space.
- drm/i915: Delay allocation of stolen space for FBC.
- drm/i915: Avoid clearing preallocated regions from the GTT.
- drm/i915: Fix detection of base of stolen memory.
- drm: Introduce an iterator over holes in the drm_mm range
  manager.
- drm: Introduce drm_mm_create_block().
- drm/i915: optimize ilk/snb irq handler.
- i915: convert struct spinlock to spinlock_t.
- drm/i915: kill intel_dp_link_clock().
- drm/i915: invert the log inside intel_prepare_ddi.
- drm/i915: add HAS_DDI check.
- drm/i915: remove Haswell code from ironlake_fdi_pll_enable.
- drm/i915: intel_prepare_ddi_buffers should be static.
- drm/i915: optimize the shmem_pwrite slowpath handling.
- drm/i915: simplify shmem pwrite/pread slowpath handling.
- drm/i915: enable intel_lvds->pre_pll_enable for ilk+, too.
- drm/i915: move intel_update_lvds to intel_lvds->pre_pll_enable.
- drm/i915: add intel_lvds->reg.
- drm/i915: track is_dual_link in intel_lvds.
- drm/i915: move is_dual_link_lvds to intel_lvds.c.
- drm/i915: replace ad-hoc dual-link lvds checks.
- drm/i915: add encoder->pre_pll_enable callback.
- drm/i915/debugfs: Prune a couple of superfluous leading zeros
  from bo domains.
- drm/i915: Kill i915_gem_execbuffer_wait_for_flips().
- drm/i915: remove duplicate register #defines.
- commit 0077864
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: Set sync_seqno properly after seqno wrap.
- drm/i915: Include the last semaphore sync point in the
  error-state.
- drm/i915: Rearrange code to only have a single method for
  waiting upon the ring.
- drm/i915: Simplify flushing activity on the ring.
- drm/i915: Preallocate next seqno before touching the ring.
- drm/i915: force restore on lid open.
- drm/i915: Wait upon the last request seqno, rather than a
  future seqno.
- drm/i915: fix possible NULL dereference of dev_priv.
- drm/i915: Increase the response time for slow SDVO devices.
- drm/i915: set the VIC of the mode on the AVI InfoFrame.
- drm: add drm_mode_cea_vic.
- drm/i915: Fix pte updates in ggtt clear range.
- drm/i915: promote Haswell to full support.
- drm/i915: Report the origin of the LVDS fixed panel mode.
- drm/i915: LVDS fallback to fixed-mode if EDID not present.
- drm/i915/sdvo: kfree the intel_sdvo_connector, not
  drm_connector, on destroy.
- drm/i915: drm_connector_property -> drm_object_property.
- drm/i915: use drm_send_vblank_event() helper.
- drm/i915: Use pci_resource functions for BARs.
- drm/i915: Borrow our struct_mutex for the direct reclaim.
- drm/i915: Defer assignment of obj->gtt_space until after all
  possible mallocs.
- drm/i915: Apply the IBX transcoder A w/a for HDMI to SDVO
  as well.
- drm/i915: implement WaMbcDriverBootEnable on Haswell.
- drm/i915: fix intel_ddi_get_cdclk_freq for ULT machines.
- drm/i915: make the panel fitter work on pipes B and C on IVB.
- drm/i915: don't intel_crt_init if DDI A has 4 lanes.
- drm/i915: make DP work on LPT-LP machines.
- drm/i915: fix false positive "Unclaimed write" messages.
- drm/i915: use cpu/pch transcoder on intel_enable_pipe.
- drm/i915: don't limit Haswell CRT encoder to pipe A.
- drm/i915: Flush outstanding unpin tasks before pageflipping.
- drm/i915: resurrect panel lid handling.
- drm/i915: Enable DP audio for Haswell.
- drm/i915: Pin the object whilst faulting it in.
- drm/i915: Guard pages being reaped by OOM whilst binding-to-GTT.
- drm/i915: Remove bogus test for a present execbuffer.
- drm/i915: Remove save/restore of physical HWS_PGA register.
- drm/i915: Fix warning in i915_gem_chipset_flush.
- drm/i915: Only check for valid PP_{ON, OFF}_DELAYS on pre
  ILK hardware.
- drm/i915: drop buggy write to FDI_RX_CHICKEN register.
- drm/i915: Use LRI to update the semaphore registers.
- drm/i915: add LynxPoint-LP PCH ID.
- drm/i915: Optimize DIV_ROUND_CLOSEST call.
- drm/vmwgfx: Make vmw_dmabuf_unreference handle NULL objects.
- drm/vmwgfx: Refactor module load to not require fifo unless
  fbdev is loaded.
- drm/vmwgfx: Make screen object code not require fifo at
  init time.
- drm/vmwgfx: Make overlay code not require fifo at init time.
- drm/vmwgfx: Enable traces *after* we've hidden SVGA.
- drm/ttm: alter cpu_writers to return -EBUSY in ttm_execbuf_util
  reservations.
- drm/ttm: Optimize reservation slightly.
- drm/ttm, drm/vmwgfx: Use RCU locking for object lookups v3.
- drm: Make hashtab rcu-safe.
- drm/ttm: remove sync_arg from driver functions.
- drm/ttm: remove sync_obj_arg from ttm_bo_move_accel_cleanup.
- drm/ttm: remove sync_obj_arg member.
- drm/vmwgfx: remove use of fence_obj_args.
- DRM/KMS: Add Bail-Out Conditions for Loop.
- drm: don't unnecessarily enable the polling work.
- drm/nouveau: free memory allocated with alloc_apertures().
- drm/radeon: check alloc_apertures() success in
  radeon_kick_out_firmware_fb().
- drm/mgag200: remove unneeded aper->count assignment after
  alloc_apertures().
- drm/mgag200: free memory allocated with alloc_apertures().
- drm/mgag200: check alloc_apertures() success in mga_vram_init().
- drm/cirrus: check alloc_apertures() success in
  cirrus_kick_out_firmware_fb().
- drm/ttm: remove ttm_mem_global->queue.
- drm/ttm: remove ttm_bo_device->nice_mode.
- drm/ttm: remove ttm_buffer_object->buffer_start.
- drm/radeon: Use hweight32.
- drm: use memchr_inv().
- drm: add support for monotonic vblank timestamps.
- drm: use monotonic time in
  drm_calc_vbltimestamp_from_scanoutpos.
- drm: don't poll forced connectors.
- drm: don't start the poll engine in probe_single_connector.
- drm: properly init/reset connector status.
- drm: run the hpd irq event code directly.
- drm: handle HPD and polled connectors separately.
- drm: extract drm_kms_helper_hotplug_event.
- drm: add drm_send_vblank_event() helper (v5).
- drm/udl: Add missing static storage class specifiers in
  udl_connector.c.
- drm/drm_stub: Remove unnecessary null check before kfree.
- drm/fb_helper: Fix potential NULL pointer dereference.
- drm/crtc: Fix potential NULL pointer dereference.
- drm/crtc: Remove redundant NULL check before kfree.
- drm: Reject addfb2 with undefined flag bits set.
- drm: fix documentation for drm_crtc_set_mode().
- drm: get cea video id code for a given display mode.
- drm/drm_fb_helper: Remove unnecessary braces.
- drm/fb_helper: Convert printk to pr_* and dev_*.
- drm/fb_helper: Fix checkpatch errors.
- drm: fix returning -EINVAL on setmaster if another master
  is active.
- drm/i915: Restore physical HWS_PGA after resume.
- drm/i915: Report amount of usable graphics memory in MiB.
- drm/i915/i2c: Track users of GMBUS force-bit.
- drm/i915: Allocate the proper size for contexts.
- drm/i915: Update load-detect failure paths for modeset-rework.
- drm/i915: Clear unused fields of mode for framebuffer creation.
- drm/i915: Always calculate 8xx WM values based on a 32-bpp
  framebuffer.
- drm/i915: Fix sparse warnings in from AGP kill code.
- drm/i915: Missed lock change with rps lock.
- drm/i915: Move the remaining gtt code.
- drm/i915: flush system agent TLBs on SNB.
- drm/i915: Kill off now unused gen6+ AGP code.
- drm/i915: Calculate correct stolen size for GEN7+.
- drm/i915: Stop using AGP layer for GEN6+.
- drm/i915: drop the double-OP_STOREDW usage in blt_ring_flush.
- drm/i915: don't rewrite the GTT on resume v4.
- drm/i915: protect RPS/RC6 related accesses (including PCU)
  with a new mutex.
- drm/i915: put ring frequency and turbo setup into a work
  queue v5.
- drm/i915: don't block resume on fb console resume v2.
- drm/i915: extract l3_parity substruct from dev_priv.
- drm/i915: move dri1 dungeon out of dev_priv.
- drm/i915: move pwrctx/renderctx to the other ilk power state.
- drm/i915: move dev_priv->(rps|ips) out of line.
- drm/i915: move the suspend/resume register file out of dev_priv.
- drm/i915: add clock gating regs to VLV offset check function.
- drm/i915: PIPE_CONTROL TLB invalidate requires CS stall.
- drm/i915: TLB invalidation with MI_FLUSH_DW requires a post-sync
  op v3.
- drm/i915: implement WaDisablePSDDualDispatchEnable on IVB & VLV.
- drm/i915: implement WaDisableVLVClockGating_VBIIssue on VLV.
- drm/i915: implement WaForceL3Serialization on VLV and IVB
  (https://bugs.freedesktop.org/show_bug.cgi?id=50250).
- drm/i915: implement WaDisableDopClockGatingisable on VLV
  and IVB.
- drm/i915: implement WaDisableL3CacheAging on VLV.
- drm/i915: fix Haswell FDI link disable path.
- drm/i915: fix Haswell FDI link training code.
- drm/i915: remove HAS_eDP as unnecessary and inconsistent
  indirection.
- drm/i915: set the correct number of FDI lanes on Haswell.
- drm/i915: kill pch_init_clock_gating indirection.
- drm/i915: implement WADP0ClockGatingDisable.
- drm/i915: CPT+ pch transcoder workaround.
- drm/i915: drop unnecessary check from fdi_link_train code.
- drm/i915: check whether the pch is the soulmate of the cpu.
- drm/i915: move panel connectors to the front.
- drm: add helper to sort panels to the head of the connector
  list.
- drm/i915: don't assert disabled FDI before disabling the FDI.
- drm/i915: don't call intel_disable_pch_pll on Haswell/LPT.
- drm/i915: implement timing override workarounds on LPT.
- drm/i915: use CPU and PCH transcoders on
  lpt_disable_pch_transcoder.
- drm/i915: Add SURFLIVE register definitions.
- drm/i915: use PIPECONF_INTERLACE_MASK_HSW on
  lpt_enable_pch_transcoder.
- drm/i915: don't assert_pch_ports_disabled on LPT.
- drm/i915: don't rely on previous values when setting LPT
  TRANSCONF.
- drm/i915: use CPU and PCH transcoders on
  lpt_enable_pch_transcoder.
- drm/i915: don't assert_pch_pll_enabled on
  lpt_enable_pch_transcoder.
- drm/i915: remove IBX code from lpt_enable_pch_transcoder.
- drm/i915: remove Haswell code from
  ironlake_enable_pch_transcoder.
- drm/i915: fork lpt version of ironlake_{en,
  dis}able_pch_transcoder.
- drm/i915: rename intel_{en, dis}able_transcoder.
- drm/i915: use the CPU and PCH transcoders on lpt_pch_enable.
- drm/i915: don't assert_panel_unlocked on LPT.
- drm/i915: don't call ironlake_enable_pch_pll on lpt_pch_enable.
- drm/i915: rename intel_enable_pch_pll to
  ironlake_enable_pch_pll.
- drm/i915: remove ironlake bits from lpt_pch_enable.
- drm/i915: remove Haswell/LPT bits from ironlake_pch_enable.
- drm/i915: add lpt_pch_enable.
- drm/i915: use intel_ddi_get_hw_state on CRT encoder too.
- drm/i915: don't set ADPA pipe select on LPT.
- drm/i915: move encoder->mode_set calls to crtc_mode_set.
- drm/i915: Introduce intel_crtc_update_sarea_pos().
- drm/i915: Bad pixel formats can't reach the sprite code.
- drm/i915: pixel_size == cpp.
- drm/i915: Check the framebuffer offset.
- drm/i915: Check framebuffer stride more thoroughly.
- drm/i915: Fix display pixel format handling.
- drm/i915: move more pte encoding to pte encode.
- drm/i915: Extract PPGTT pte encoding.
- drm/i915: introduce gtt_pte_t.
- drm/i915: Add dev to ppgtt.
- drm/i915: No LLC_MLC for HSW.
- drm/i915/ringbuffer: exclude last 2 cachelines on 845g on
  all callpaths.
- drm/i915: create the DDI encoder.
- drm/i915: add intel_ddi_connector_get_hw_state.
- drm/i915: add port field to intel_digital_port.
- drm/i915: reset intel_encoder->type when DP or HDMI is detected.
- drm/i915: split intel_dp_init into encoder and connector pieces.
- drm/i915: split intel_hdmi_init into encoder and connector
  pieces.
- drm/i915: create intel_digital_port and use it.
- drm/i915: add intel_dp_to_dev and intel_hdmi_to_dev.
- drm/i915: simplify assignments inside intel_dp.c.
- drm/i915: Fix HSW power well control state read.
- drm/i915: Flush using only the correct base address register.
- drm/i915: implement WaDisableRenderCachePipelinedFlush.
- drm/i915: implement WaIssueDummyWriteToWakeupFromRC6.
- drm/i915: adjust sprite base address.
- drm/i915: Fix sprite offset on HSW.
- drm/i915: Fix primary plane offset on HSW.
- drm/i915: Error out when trying to set a y-tiled as a sprite.
- drm/i915/tv: Use intel_flush_display_plane() to flush the
  primary plane.
- drm/i915: check fdi B/C lane sharing constraint.
- drm/i915: add ->display.modeset_global_resources callback.
- drm/i915: BUG on impossible pch dp port.
- drm/i915: add comment about pch pll enabling rules.
- drm/i915: set FDI_RX_MISC to recommended values on CPT/PPT.
- drm/i915: clarify why we need to enable fdi plls so early.
- drm/i915: Write the FDI RX TU size reg at the right time.
- drm/i915: shut up spurious message in intel_dp_get_hw_state.
- drm/vmwgfx: use ttm_bo_is_reserved.
- drm/radeon: Use ttm_bo_is_reserved.
- drm/ttm: add ttm_bo_is_reserved.
- drm: Ignore blob propertys in drm_property_change_is_valid().
- drm: Constify some function arguments.
- drm: Be more paranoid with integer overflows.
- drm/i915: pass adjusted_mode to intel_choose_pipe_bpp_dither(),
  again.
- drm/i915/dp: change eDP default scaling mode to respect
  aspect ratio.
- drm/i915/dp: allow configuring eDP panel fitting scaling mode.
- drm/i915/lvds: move fitting mode from intel_lvds_connector
  to intel_panel.
- drm/i915: debug print all of the DPCD we have.
- drm/i915: VLV does not have a sprite scaler.
- drm/i915/sdvo: restore i2c adapter config on intel_sdvo_init()
  failures.
- drm/i915/sdvo: force GPIO bit-banging also on default pin.
- drm/i915: enable DDI eDP.
- drm/i915: turn the eDP DDI panel on/off.
- drm/i915: set/unset the DDI eDP backlight.
- drm/i915: set the correct eDP aux channel clock divider on DDI.
- drm/i915: select the correct pipe when using TRANSCODER_EDP.
- drm/i915: implement workaround for VTOTAL when using
  TRANSCODER_EDP.
- drm/i915: convert pipe timing definitions to transcoder.
- drm/i915: convert CPU M/N timings to transcoder.
- drm/i915: convert PIPE_MSA_MISC to transcoder.
- drm/i915: convert PIPECONF to use transcoder instead of pipe.
- drm/i915: check TRANSCODER_EDP on intel_modeset_setup_hw_state.
- drm/i915: convert DDI_FUNC_CTL to transcoder.
- drm/i915: convert PIPE_CLK_SEL to transcoder.
- drm/i915: add TRANSCODER_EDP.
- drm/i915: don't call Haswell PCH code when we can't or don't
  need.
- drm/i915: simplify intel_crtc_driving_pch.
- drm/i915: fix checks inside haswell_crtc_{enable, disable}.
- drm/i915: fix checks inside ironlake_crtc_{enable, disable}.
- drm/i915: fork a Haswell version of ironlake_crtc_{enable,
  disable}.
- drm/i915: remove an extra #define for DP_RECEIVER_CAP_SIZE.
- drm/i915: extract intel_dp_init_panel_power_sequencer.
- drm/i915/dp: compute the pch dp aux divider from the rawclk.
- drm/i915/eDP: compute the panel power clock divisor from the
  pch rawclock.
- drm/i915: enable/disable backlight for eDP.
- drm/i915: make edp panel power sequence setup more robust.
- drm/i915: Don't try to use SPR_SCALE when we don't have a
  sprite scaler.
- drm/i915/dp: actually nack test request.
- drm: extract drm_dp_max_lane_count helper.
- drm: extract dp link bw helpers.
- drm/i915: use the new dp train delay helpers.
- drm: extract dp link train delay functions from radeon.
- drm: extract helpers to compute new training values from
  sink request.
- drm: dp helper: extract drm_dp_clock_recovery_ok.
- drm: dp helper: extract drm_dp_channel_eq_ok.
- drm: rename drm_dp_i2c_helper.c to drm_dp_helper.c.
- drm/i915: remove unused mem_block struct definition.
- drm/i915: Move cached EDID to intel_connector.
- drm/i915: Do not free the passed EDID in
  intel_connector_update_modes().
- drm/i915: Move the fixed mode to intel_panel.
- drm/i915: Create generic intel_panel for LVDS and eDP.
- drm/i915/dp: Initialize eDP fixed mode in intel_dp_init.
- drm/i915/lvds: Move some connector specific info across from
  the encoder.
- drm/i915: Backlight setup requires connector so pass it as
  parameter.
- drm/i915/lvds: Move the acpi_lid_notifier from drm_i915_private
  to the connector.
- drm/i915/lvds: Introduce intel_lvds_connector.
- drm/i915/lvds: Rename intel_lvds to intel_lvds_encoder.
- drm/i915: Don't program DSPCLK_GATE_D twice on IVB and VLV.
- drm/i915: Program DSPCLK_GATE_D only once on Ironlake.
- drm/i915: Consolidate ILK_DSPCLK_GATE and PCH_DSPCLK_GATE.
- drm/i915: unconditionally use mt forcewake on hsw/ivb.
- drm/i915: set the correct function pointers for Haswell DP.
- drm/i915: implement Haswell DP link train sequence.
- drm/i915: fix Haswell DP M/N registers.
- drm/i915: add DP support to intel_ddi_disable_port.
- drm/i915: add DP support to intel_ddi_mode_set.
- drm/i915: add DP support to intel_enable_ddi.
- drm/i915: add DP support to intel_ddi_get_hw_state.
- drm/i915: add DP support to intel_ddi_get_encoder_port.
- drm/i915: fix DP AUX register definitions on Haswell.
- drm/i915: Clear FORCEWAKE when taking over from BIOS.
- drm/i915: don't save/restor ADPA for kms.
- drm/i915/crt: explicitly set up HOTPLUG_BITS on resume.
- drm/i915/crt: don't set HOTPLUG bits on !PCH.
- drm/i915: don't save/restore HWS_PGA reg for kms.
- drm/i915: don't save/restore irq regs for kms.
- drm/i915: don't save/restore DP regs for kms.
- drm/i915: use TU_SIZE macro at intel_dp_set_m_n.
- drm/i915: add basic Haswell DP link train bits.
- drm/i915: add DP support to intel_ddi_pll_mode_set.
- drm/i915: add intel_ddi_set_pipe_settings.
- drm/i915: add DP support to intel_ddi_enable_pipe_func.
- drm/i915: Document the multi-threaded FORCEWAKE bits.
- drm/i915: Allow DRM_ROOT_ONLY|DRM_MASTER to submit privileged
  batchbuffers.
- drm/i915: move hpd handling to (ibx|cpt)_irq_handler.
- Revert "drm/i915: Try harder to complete DP training pattern 1".
- DRM/i915: Restore sdvo_flags after dtd->mode->dtd Roundrtrip.
- DRM/i915: Don't clone SDVO LVDS with analog.
- DRM/i915: Add QUIRK_INVERT_BRIGHTNESS for NCR machines.
- DRM/i915: Don't delete DPLL Multiplier during DAC init.
- drm/i915: Add rc6vids to debugfs.
- drm/i915: Workaround to bump rc6 voltage to 450.
- drm/i915: Extract PCU communication.
- drm/i915: Fix the SCC/SSC typo in the SPLL bits definition.
- drm/i915: pipe and planes should be disabled on
  haswell_crtc_mode_set.
- drm/i915: disable DDI_BUF_CTL at the correct time.
- drm/i915: don't implement WaDisableEarlyCull for Haswell.
- drm/i915: don't rely on previous values set on DDI_BUF_CTL.
- drm/i915: completely rewrite the Haswell PLL handling code.
- drm/i915: add haswell_set_pipeconf.
- drm/i915: add proper CPU/PCH checks to crtc_mode_set functions.
- drm/i915: add haswell_crtc_mode_set.
- drm/i915: enable and disable PIPE_CLK_SEL at the right time.
- drm/i915: enable and disable DDI_FUNC_CTL at the right time.
- drm/i915: rewrite the LCPLL code.
- drm/i915: Align the retire_requests worker to the nearest
  second.
- drm/i915: Align the hangcheck wakeup to the nearest second.
- drm/i915: Remove the WaDisableBackToBackFlipFix w/a for Haswell.
- drm/i915: Document that we are implementing
  WaDisableBackToBackFlipFix.
- drm/i915: remove duplicated include from intel_modes.c.
- drm/i915: Remove the disabling of VHR unit clock gating for HSW.
- drm/i915: implement WaDisableEarlyCull for VLV and IVB.
- drm/i915: s/DRM_IRQ_ARGS/int irq, void *arg.
- drm/i915: extract intel_set_pipe_timings from crtc_mode_set.
- drm/i915: add debug logging to ASLE backlight set requests.
- drm/i915: Fixup HDMI output on Valleyview.
- drm/i915: Add eDP support for Valleyview.
- drm/i915: Enable DisplayPort in Valleyview.
- drm/i915: Program correct m n tu register for Valleyview.
- drm/i915: Add Valleyview lane control definitions.
- drm/i915: Fix SDVO IER and status bits for Valleyview.
- drm/i915: Set aux clk to 100MHz for Valleyview.
- drm/i915: limit VLV IRQ enables to those we use.
- drm/i915: remove unused variables from ironlake_crtc_mode_set.
- drm/i915: extract compute_dpll from ironlake_crtc_mode_set.
- drm/i915: extract set_m_n from ironlake_crtc_mode_set.
- drm/i915: don't recheck for invalid pipe bpp.
- commit b111bb2
* Wed Feb 13 2013 msrb@novell.com
- kbuild: fix drm include.
- Refresh patches.xen/xen3-patch-2.6.27.
- Refresh patches.xen/xen3-patch-2.6.31.
- commit b9c28f3
* Wed Feb 13 2013 msrb@novell.com
- makefile: include fixes.
- define kuid_t.
- Revert "drm/i915: enable rc6 on ilk again".
- drm/i915: do not default to 18 bpp for eDP if missing from VBT.
- drm/exynos: fix linux framebuffer address setting.
- drm/nouveau: use the correct fence implementation for nv50.
- drm/radeon: add new SI pci id.
- commit 7822bbc
* Wed Feb 13 2013 msrb@novell.com
- drm/radeon: properly track the crtc not_enabled case
  evergreen_mc_stop().
- drm/i915: disable cloning on sdvo.
- drm/nouveau/bios: fix DCB v1.5 parsing.
- drm/nouveau: add missing pll_calc calls.
- drm/nv40: allocate ctxprog with kmalloc.
- drm/nvc0/disp: fix thinko in vblank regression fix..
- drm/ttm: remove unneeded preempt_disable/enable.
- ttm: Clear the ttm page allocated from high memory zone
  correctly.
- drm/radeon: fix logic error in atombios_encoders.c.
- drm/i915: do not ignore eDP bpc settings from vbt.
- drm/i915/sdvo: clean up connectors on intel_sdvo_init()
  failures.
- drm/vmwgfx: Fix a case where the code would BUG when trying
  to pin GMR memory.
- drm/nvc0/disp: fix regression in vblank semaphore release.
- drm/nv40/mpeg: fix context handling.
- drm/nv40/graph: fix typo in type names.
- drm/nv41/vm: fix typo in type name.
- drm/radeon/si: add some missing regs to the VM reg checker.
- drm/radeon/cayman: add some missing regs to the VM reg checker.
- drm/radeon: fix typo in evergreen_mc_resume().
- drm: set dev_mapping before calling drm_open_helper.
- drm/i915/crt: fix DPMS standby and suspend mode handling.
- drm/udl: fix stride issues scanning out stride != width*bpp.
- drm/radeon: add load detection support for ext DAC on R200 (v2).
- drm/radeon: fix ATPX function documentation.
- drivers/gpu/drm/radeon/evergreen_cs.c: Remove unnecessary
  semicolon.
- drm: exynos: removed warning due to missing typecast for mixer
  driver data.
- drm/exynos: add support for ARCH_MULTIPLATFORM.
- drm/exynos: fix display on issue.
- drm/nouveau: headless mode by default if pci class != vga
  display.
- drm/nouveau: resurrect headless mode since rework.
- drm/nv50/fb: prevent oops on chipsets without compression tags.
- drm/nouveau: allow creation of zero-sized mm.
- drm/nouveau/i2c: fix typo when checking nvio i2c port validity.
- drm/i915: Only kick out vesafb if we takeover the fbcon
  with KMS.
- drm/i915: be less verbose about inability to provide vendor
  backlight.
- drm/radeon: fix ATPX regression in acpi rework.
- drm/radeon: fix ATPX function documentation.
- drm/radeon: move the retry to gem_object_create.
- drm/radeon: move size limits to gem_object_create.
- drm/radeon: use vzalloc for gart pages.
- drm/radeon: fix and simplify pot argument checks v3.
- drm/radeon: fix header size estimation in VM code.
- drm/radeon: remove set_page check from VM code.
- drm/radeon: fix si_set_page v2.
- drm/radeon: fix cayman_vm_set_page v2.
- drm/radeon: fix PFP sync in vm_flush.
- drm/radeon: add error output if VM CS fails on cayman.
- drm/radeon: give each backlight a unique id.
- drm/radeon: fix sparse warning.
- drm/radeon: add some new SI PCI ids.
- drm/i915: VGA needs to be on pipe A on i830M.
- drm/ttm: Fix a theoretical race in ttm_bo_cleanup_refs().
- drm/ttm: Fix a theoretical race.
- drm: platform: Don't initialize driver-private data.
- drm/debugfs: remove redundant info from gem_names.
- drm: fb: cma: Fail gracefully on allocation failure.
- drm: fb: cma: Fix typo in debug message.
- drm/nouveau/clock: fix missing pll type/addr when matching
  default entry.
- drm/nouveau/fb: fix reporting of memory type on GF8+ IGPs.
- drm/nv41/vm: don't init hw pciegart on boards with agp bridge.
- drm/nouveau/bios: fetch full 4KiB block to determine ACPI ROM
  image size.
- drm/nouveau: validate vbios size.
- drm/nouveau: warn when trying to free mm which is still in use.
- drm/nouveau: fix nouveau_mm/nouveau_mm_node leak.
- drm/nouveau/bios: improve error handling when reading the
  vbios from ACPI.
- drm/nouveau: handle same-fb page flips.
- drm/i915: Initialize obj->pages before use by
  i915_gem_object_do_bit17_swizzle().
- drm/i915: Insert i915_preliminary_hw_support variable.
- drm/i915: shut up spurious WARN in the gtt fault handler.
- nouveau: fix warning on 32-bit build.
- drm/nouveau/bios: fix typo in error message.
- drm/nouveau: only call ttm_agp_tt_create when __OS_HAS_AGP.
- drm/nv50/fb: fix double free of vram mm.
- drm/nouveau/pm: do not stop reclocking if failing to set the
  fan speed.
- drm: fix warning on 32-bit.
- drm: radeon: fix printk format warning.
- drm/radeon: fix spelling typos in debugging output.
- drm/radeon: check if pcie gen 2 is already enabled (v2).
- drm/radeon/cayman: set VM max pfn at MC init.
- drm/radeon: separate pt alloc from lru add.
- drm/radeon: don't add the IB pool to all VMs v2.
- drm/radeon: allocate page tables on demand v4.
- drm/radeon: update comments to clarify VM setup (v2).
- drm/radeon: allocate PPLLs from low to high.
- drm/radeon: fix compilation with backlight disabled.
- drm/radeon: use %%zu for formatting size_t.
- drm/i915: fix non-DP-D eDP backlight cleanup and module reload.
- drm/i915: HSW CRW stability magic.
- drm/i915/dvo-ch7xxx: fix get_hw_state.
- drm/i915: fixup the plane->pipe fixup code.
- drm/i915: rip out the pipe A quirk for i855gm.
- drm/i915: disable wc gtt pte mappings on gen2.
- commit 7143832
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: fixup i915_gem_object_get_page inline helper.
- commit 32e6783
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: Disallow preallocation of requests.
- Refresh patches.xen/xen3-patch-2.6.29.
- commit 7fc6f3b
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: Set guardband clipping workaround bit in the right
  register.
- drm/nouveau/timer: bump ptimer's alarm delay from u32 to u64.
- drm/nouveau/fan: fix a typo in PWM's input clock calculation.
- drm/nv50/clk: wire up pll_calc hook.
- drm/nouveau: remove unused _nouveau_parent_ctor.
- drm/nouveau/bios: fix shadowing of ACPI ROMs larger than 64KiB.
- drm/i915: paper over a pipe-enable vs pageflip race.
- drm/i915: remove useless BUG_ON which caused a regression
  in 3.5.
- drm: exynos: hdmi: remove drm common hdmi platform data struct.
- drm: exynos: hdmi: add support for exynos5 hdmi.
- drm: exynos: hdmi: replace is_v13 with version check in hdmi.
- drm: exynos: hdmi: add support for exynos5 mixer.
- drm: exynos: hdmi: add support to disable video processor
  in mixer.
- drm: exynos: hdmi: add support for platform variants for mixer.
- drm: exynos: hdmi: add support for exynos5 hdmiphy.
- drm: exynos: hdmi: add support for exynos5 ddc.
- drm: exynos: remove drm hdmi platform data struct.
- drm: exynos: hdmi: turn off HPD interrupt in HDMI chip.
- drm: exynos: hdmi: use s5p-hdmi platform data.
- drm: exynos: hdmi: fix interrupt handling.
- drm: exynos: hdmi: support for platform variants.
- UAPI: (Scripted) Disintegrate include/drm.
- drm/i915: Fix GT_MODE default value.
- drm/i915: don't frob the vblank ts in finish_page_flip.
- drm/i915: call drm_handle_vblank before finish_page_flip.
- drm/i915: print warning if vmi915_gem_fault error is not
  handled.
- drm/i915: Try harder to complete DP training pattern 1.
- Merge branch 'drm-next' of
  git://people.freedesktop.org/~airlied/linux.
- drm/exynos: fix kcalloc size of g2d cmdlist node.
- drm/exynos: fix to calculate CRTC shown via screen.
- drm/exynos: fix display power call issue.
- drm/exynos: add platform_device_id table and driver data for
  drm fimd.
- drm/exynos: Fix potential NULL pointer dereference.
- drm/exynos: support drm_wait_vblank feature for VIDI.
- drm/exynos: check crtc's dpms mode at SetCrtc.
- drm/exynos: check crtc's dpms mode at page flip.
- drm/exynos: fix duplicated mutex lock issue.
- drm/exynos: add pid to g2d_runqueue_node.
- drm/exynos: Disable plane when released.
- drm/exynos: update crtc to plane safely.
- drm/exynos: check NV12M format specific to Exynos properly.
- drm/exynos: make sure that hardware overlay for hdmi is
  disabled.
- drm/exynos: make sure that hardware overlay for fimd is
  disabled.
- drm/exynos: add wait_for_vblank callback interface.
- drm/exynos: fixed duplicated mode setting.
- drm/exynos: separeated fimd_power_on into some parts.
- drm/exynos: separated subdrv_probe function into two parts.
- drm/exynos: added device object to subdrv's remove callback
  as argument.
- drm/i915: set swizzling to none on VLV.
- drm/nv98/crypt: fix fuc build with latest envyas.
- drm/nouveau/devinit: fixup various issues with subdev ctor/init
  ordering.
- drm/nv41/vm: fix and enable use of "real" pciegart.
- drm/nv44/vm: fix and enable use of "real" pciegart.
- drm/nv04/dmaobj: fixup vm target handling in preparation for
  nv4x pcie.
- drm/nouveau: store supported dma mask in vmmgr.
- drm/nvc0/ibus: initial implementation of subdev.
- drm/nouveau/therm: add support for fan-control modes.
- drm/nouveau/hwmon: rename pwm0* to pmw1* to follow hwmon's
  rules.
- drm/nouveau/therm: calculate the pwm divisor on nv50+.
- drm/nouveau/fan: rewrite the fan tachometer driver to get more
  precision, faster.
- drm/nouveau/therm: move thermal-related functions to the
  therm subdev.
- drm/nouveau/bios: parse the pwm divisor from the perf table.
- drm/nouveau/therm: use the EXTDEV table to detect i2c monitoring
  devices.
- drm/nouveau/therm: rework thermal table parsing.
- drm/nouveau/gpio: expose the PWM/TOGGLE parameter found in
  the gpio vbios table.
- drm/nouveau: fix pm initialization order.
- drm/nouveau/bios: check that fixed tvdac gpio data is valid
  before using it.
- drm/nouveau: log channel debug/error messages from client
  object rather than drm client.
- drm/nouveau: have drm debugging macros build on top of core
  macros.
- drm/nouveau/core: have client-id be a string, rather than
  an integer.
- drm/nvc0/fifo: re-bash PBUS regs after vm-fault to
  BARs/PEEPHOLE.
- drm/nvc0/gr: implement initial trap handler.
- drm/nvc0/gr: rebuild fuc with latest envyas.
- drm/nvc0/ltcg: read LTS count at startup.
- drm/nve0/gr: enable use of our fuc by default.
- drm/nve0/gr: remove 0x404160 bashing from hub fuc.
- drm/nve0/gr: initial fuc implementation, based on fermi's code.
- drm/nve0/ibus: handle PIBUS interrupts to prevent storm.
- drm/nouveau/sw: trap and clear PMC_INTR_0_SOFTWARE.
- drm/nouveau: quiet some static-related sparse noise.
- drm/nouveau: constify instances of nouveau_bitfield and
  nouveau_enum structs.
- drm/nouveau/fifo: use defines instead of hardcoded class ids.
- drm/nouveau/dmaobj: reject unsupported parent types instead
  of half-succeeding.
- drm/nouveau: add defines for internal class names.
- drm/nv50/fifo: add support for dma channel class.
- drm/nv84/fifo: add support for dma channel class.
- drm/nouveau/fifo: version the dma channel class struct.
- drm/nouveau/fifo: separate object classes for dma channels.
- drm/nouveau: restore fifo chid information in engine error
  messages.
- drm/nouveau/core: have fifo store a unique context identifier
  at attach time.
- drm/nouveau/fifo: add method to lookup fifo chid related to
  a given object.
- drm/nouveau/core: protect engine context list with hardirq-safe
  spinlock.
- drm/nv84/fifo: mask only the engine we're waiting on for
  channel unload.
- drm/nve0: use async copy engine for ttm buffer moves if
  available.
- drm/nve0/copy: add initial support for the async copy engines.
- drm/nve0/fifo: support engine selection when creating fifo
  channels.
- drm/nouveau/device: return proper error codes if ioremap fails.
- drm/nouveau/core: remove some left-over pieces from the
  porting process.
- drm/nvc0-/gr: remove reset-after-grctx-construction hack.
- drm/nouveau: add Kconfig options for debug control.
- drm/nouveau: port remainder of drm code, and rip out compat
  layer.
- drm/nouveau/device: include the official chipset names.
- drm/nouveau/backlight: remove dependence on nouveau_drv.h.
- drm/nouveau: flatten nv{Read,Write}{MC,VIDEO,FB,EXTDEV}.
- drm/nouveau: move compat ioctl out of nouveau_drv.h.
- drm/nouveau/acpi: move definitions out of nouveau_drv.h.
- commit a95f32d
* Wed Feb 13 2013 msrb@novell.com
- drm/nouveau/mxm: split up into bios code and a subdev module.
- drm/nouveau: start culling unused code.
- drm/nouveau: port all engines to new engine module format.
- drm/nvc0-/gr: generate grctx template at init time, not first
  context ctor.
- drm/nvc0-/gr: share headers between fermi and kepler graphics
  code.
- drm/nouveau/pageflip: kick flip handling out of engsw and
  into fence.
- drm/nouveau: move some more code around to more appropriate
  places.
- drm/nvc0-nve0/graph: rename dev to priv, no code changes.
- drm/nouveau/fence: un-port from nouveau_exec_engine interfaces.
- drm/nouveau: pull nouveau_gem definitions into their own header.
- drm/nouveau: pull nouveau_bo definitions into their own header.
- drm/nv04/disp: kick all private state out to own header.
- drm/nouveau/instmem: completely new implementation, as a
  subdev module.
- drm/nouveau: remove last use of nouveau_gpuobj_new_fake().
- drm/nv50/instmem: remove use of nouveau_gpuobj_new_fake().
- drm/nouveau/gpuobj: remove flags for vm-mappings.
- drm/nouveau/gpuobj: create wrapper functions for mapping gpuobj
  into vm/bar.
- drm/nvc0/fifo: handle bar1 control regs much like fifo/nve0.
- drm/nv04-nv40/fifo: remove use of nouveau_gpuobj_new_fake().
- drm/nv04-nv40/instmem: remove use of nouveau_gpuobj_new_fake().
- drm/nv04-nv40/instmem: duplicate nv04 code as nv40, remove
  alternate paths.
- drm/nouveau/fb: merge fb/vram and port to subdev interfaces.
- drm/nv50-/instmem: allocate vram for kernel objects from end
  of vram.
- drm/nouveau/core: add support for reverse mm allocations.
- drm/nouveau/timer: port to subdev interfaces.
- drm/nouveau/mc: port to subdev interfaces.
- drm/nouveau: implement devinit subdev, and new init table
  parser.
- drm/nouveau/clock: pull in the implementation from all over
  the place.
- drm/nouveau/clk: implement stub clock subdev.
- drm/nouveau/i2c: port to subdev interfaces.
- drm/nouveau/gpio: port gpio to subdev interfaces.
- drm/nouveau/oldbios: remove shadowing support, use bios
  subdev's image.
- drm/nouveau/bios: pull in basic vbios subdev, more to come
  later.
- drm/nouveau: have non-core mmio accesses go through device
  object.
- drm/nouveau: implement module init functions in nouveau_drm.c.
- drm/nouveau/core: pull in most of the new core infrastructure.
- drm/nouveau/agp: move all agp stuff into its own source file.
- drm/nouveau: restructure source tree, split core from drm
  implementation.
- drm/nouveau/gem: use bo.offset rather than mm_node.start.
- drm/nvc0/fence: restore pre-suspend fence buffer context
  on resume.
- drm/savage: re-add busmaster enable, regression fix.
- drm/ast: drop duplicate initialization.
- drm/radeon: add vm set_page() callback for SI.
- drm/radeon: rework the vm_flush interface.
- drm/radeon: use WRITE_DATA packets for vm flush on SI.
- UAPI: (Scripted) Set up UAPI Kbuild files.
- UAPI: (Scripted) Convert #include "..." to #include <path/...>
  in kernel system headers.
- UAPI: (Scripted) Convert #include "..." to #include <path/...>
  in drivers/gpu/.
- UAPI: (Scripted) Remove redundant DRM UAPI header #inclusions
  from drivers/gpu/.
- UAPI: Refer to the DRM UAPI headers with <...> and from certain
  headers only.
- drm/dp: Make sink count DP 1.2 aware.
- drm/dp: Document DP spec versions for various DPCD registers.
- drm/i915/dp: Be smarter about connection sense for branch
  devices.
- drm/i915/dp: Fetch downstream port info if needed during
  DPCD fetch.
- drm/dp: Update DPCD defines.
- drm: Export drm_probe_ddc().
- drm/radeon/pm: fix multi-head profile handling on BTC+ (v2).
- drm: change ioctl permissions.
- drm: support for rotated scanout.
- drm: refcnt drm_framebuffer (v4.1).
- drm/i915: Flush the pending flips on the CRTC before
  modification.
- drm/i915: Actually invalidate the TLB for the SandyBridge HW
  contexts w/a.
- drivers/gpu/drm/ttm/ttm_page_alloc_dma.c: Remove useless kfree.
- drm: Destroy the planes prior to destroying the associated CRTC.
- gpu/drm/ttm: use copy_highpage.
- drm/udl: Add missing static storage class specifiers in
  udl_fb.c.
- drm/udl: Make udl_crtc_init() static.
- drm/udl: Make udl_enc_destroy() static.
- drm/udl: Use NULL instead of 0 for pointers.
- drm/radeon: fix radeon power state debug output.
- drm/radeon: allow MIP_ADDRESS=0 for MSAA textures on Evergreen.
- drm/radeon/kms: allow STRMOUT_BASE_UPDATE on RS780 and RS880.
- drm/radeon: add 2-level VM pagetables support v9.
- drm/radeon: refactor set_page chipset interface v5.
- drm/radeon: Fix scratch register leak in IB test.
- drm/radeon: restore backlight level on resume.
- drm/radeon: add get_backlight_level callback.
- drm/radeon: validate PPLL in crtc fixup.
- drm/radeon: work around KMS modeset limitations in PLL
  allocation (v2).
- drm/i915: Fix set_caching locking.
- drm/i915: use adjusted_mode instead of mode for checking the
  6bpc force flag.
- drm/i915: Wrap external callers to IPS state with appropriate
  locks.
- drm/i915: s/cacheing/caching/.
- drm/i915: make sure we write all the DIP data bytes.
- drm/i915: BUG() on unexpected HDMI register.
- drm/radeon: make non-DP PPLL sharing more robust.
- drm/radeon: store the encoder in the radeon_crtc.
- drm/radeon: rework crtc pll setup to better support PPLL
  sharing.
- drm/radeon: allow PPLL sharing on non-DP displays.
- drm/radeon/dce3: use a single PPLL for all DP displays.
- drm/radeon: rework pll selection (v4).
- drm/radeon: fix typo in atombios_get_encoder_mode.
- drm/radeon/atom: fix typo in SetPixelClock handling.
- drm/radeon: white space cleanup in transmitter setup.
- drm/radeon: clean up encoder dp checks.
- drm/radeon: rework the VM code a bit more (v2).
- drm/radeon: fix gem_close_object handling.
- drm/radeon: let bo_reserve take no_intr instead of no_wait
  param.
- drm/radeon: move and rename radeon_bo_va function.
- drm/radeon: move IB pool to 1MB offset.
- drm/radeon: fix VA overlap check.
- drm/radeon: fix VA range check.
- drm/radeon: fix VM syncing with multiple rings.
- drm/radeon: Remove unused functions.
- drm/radeon: Mark all possible functions / structs as static.
- drm/radeon: remove dead function def.
- drm/radeon: implement bounds checking on thermal controller
  lookup.
- drm/radeon: document async VM changes in ni.c.
- drm/radeon: make page table updates async v2.
- drm/radeon: make sure ib bo is properly bound and up to date
  in vm space.
- drm/radeon: Move looping over the PTEs into chip code.
- drm/radeon: rework VM page table handling.
- drm/radeon: rework VMID handling.
- drm/radeon: make VM flushs a ring operation.
- drm/radeon: add sync helper function.
- drm/radeon: remove vm_unbind.
- drm/radeon: move VM funcs into asic structure.
- drm/radeon: cleanup VM id handling a bit.
- drm/radeon/atom: add consolidate bpc code.
- drm/radeon: rework the backlight control to be an asic callback.
- drm/radeon: add initial support for ATCS ACPI methods.
- drm/radeon: document radeon_atpx_handler.c (v2).
- drm/radeon: reorganize ATPX support (v2).
- drm/radeon: update ATPX verify interface handling (v2).
- drm/radeon: document radeon_acpi.c.
- drm/radeon: block the keypress on ATIF events.
- drm/radeon: re-organize the acpi notifier callback.
- drm/radeon: implement handler for ACPI event.
- drm/radeon: implement wrapper for GET_SYSTEM_PARAMS.
- drm/radeon: implement radeon_atif_verify_interface.
- drm/radeon: refactor radeon_atif_call.
- drm/radeon: add backlight control for atom devices (v2).
- drm/radeon: rework legacy backlight control.
- drm/radeon: track whether the GPU controls the backlight (v2).
- drm/radeon: add a license header to radeon_apci.c.
- drm/radeon: add new AMD ACPI header and update relevant code
  (v2).
- Annotate int2float() as being a pure function.
- Replace int2float() with an optimized version.
- Rename i2f() to int2float(), and make it global so one copy
  can be removed.
- drm/radeon: remove gui_idle interrupt infrastructure.
- drm/radeon/dynpm: wait for fences on all rings when reclocking.
- drm/radeon: properly handle mc_stop/mc_resume on evergreen+
  (v2).
- drm/radeon/r5xx-r7xx: don't use radeon_crtc for vblank callback
  (v2).
- drm/radeon/r1xx-r4xx: don't use radeon_crtc for vblank callback.
- drm/radeon: clean up evergreen_get_vblank_counter.
- drm/radeon/dce4+: don't use radeon_crtc for vblank callback.
- drm/i915: Fix !CONFIG_PM sysfs for real this time.
- drm/i915: Assert that the exec object lookup table is a
  power-of-two.
- drm/i915: HDMI - Clear Audio Enable bit for Hot Plug
  unconditionally.
- drm/i915: Convert the dmabuf object to use the new
  i915_gem_object_ops.
- drm/i915: update dpms property in set_mode.
- drm/i915: don't call dpms funcs after set_mode.
- drm/i915: don't disable fdi links harder in ilk_crtc_enable.
- drm/i915: rip out intel_disable_pch_ports.
- agp/intel: Use a write-combining map for updating PTEs.
- drm/i915: Limit the ioremap of the PCI bar to the registers.
- drm/i915: Show render P state thresholds in sysfs.
- drm/i915: Add setters for min/max frequency.
- drm/i915: rip out edp special case from dp_link_down.
- drm/i915: Drop the misleading cast to the wrong user pointer
  type.
- i915: initialize CADL in opregion.
- drm/i915: disable the cpu edp port after the cpu pipe.
- drm/i915: rip out dp port enabling cludges^Wchecks.
- drm/i915: robustify edp_pll_on/off.
- drm/i915: clean up the cpu edp pll special case.
- drm/i915: add encoder->pre_enable/post_disable.
- drm/i915: rip out early dp port write for gm45/ilk.
- drm/i915: Error checks in gen6_set_rps.
- drm/i915: POSTING_READ the new rps value.
- drm/i915: Add current/max/min GPU freq to sysfs.
- drm/i915: #define gpu freq multipler.
- drm/i915: variable renames.
- drm/i915: extract compute_clocks from ironlake_crtc_mode_set.
- drm/i915: simplify setting DSPCNTR inside
  ironlake_crtc_mode_set.
- drm/i915: extract ironlake_set_pipeconf form
  ironlake_crtc_mode_set.
- drm/i915: Replace the array of pages with a scatterlist.
- drm/i915: Pin backing pages for pread.
- drm/i915: Pin backing pages for pwrite.
- drm/i915: Pin backing pages whilst exporting through a dmabuf
  vmap.
- drm/i915: Introduce drm_i915_gem_object_ops.
- drm/i915: placeholder getparam.
- drm: micro optimise cache flushing.
- drm: Add NV24 and NV42 pixel formats.
- DRM: Add DRM KMS/FB CMA helper.
- DRM: Add DRM GEM CMA helper.
- drm/i915: fix OOPS in lid_notify.
- drm/i915: correctly update crtc->x/y in set_base.
- drm/edid: limit printk when facing bad edid.
- userns: Convert drm to use kuid and kgid and struct pid where
  appropriate.
- vmwgfx: remove useless set memory to zero use memset().
- drm: edid: add support for E-DDC.
- drm: Remove unnecessary test for ARM.
- drm: use %%*ph to dump small buffers.
- drm: edid: Refactor HDMI VSDB detection.
- drm: edid: Add bounds checking to HDMI VSDB parsing.
- drm: edid: Add some bounds checking.
- drm: consistently name interlaced modes.
- drm: make buffer management work without DRM_MASTER.
- drm/fb helper: don't call drm_helper_connector_dpms directly.
- drm/i915: improve modeset state checking after dpms calls.
- commit 70e32f3
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: add tons of modeset state checks.
- drm/i915: disable all crtcs at suspend time.
- drm/i915: push commit_output_state past the crtc/encoder
  preparing.
- drm/i915: switch the load detect code to the staged modeset
  config.
- drm/i915: WARN if the pipe won't turn off.
- drm/i915: s/intel_encoder_disable/intel_encoder_noop.
- drm/i915: push commit_output_state past crtc disabling.
- drm/i915: implement new set_mode code flow.
- drm/i915: compute masks of crtcs affected in set_mode.
- drm/i915: use staged outuput config in lvds->mode_fixup.
- drm/i915: use staged outuput config in tv->mode_fixup.
- drm/i915: extract adjusted mode computation.
- drm/i915: move output commit and crtc disabling into set_mode.
- drm/i915: remove crtc disabling special case.
- drm/i915: push crtc->fb update into pipe_set_base.
- drm/i915: stage modeset output changes.
- drm/i915: don't save all the encoder/crtc state in set_config.
- drm/i915: convert pointless error checks in set_config to BUGs.
- drm/i915: don't update the fb base if there is no fb.
- drm/i915: implement crtc helper semantics relied upon by the
  fb helper.
- drm/i915: extract intel_set_config_update_output_state.
- drm/i915: extract intel_set_config_compute_mode_changes.
- drm/i915: extract modeset config save/restore code.
- drm/i915: introduce struct intel_set_config.
- drm/i915: ensure the force pipe A quirk is actually followed.
- drm/i915: rip out intel_dp->dpms_mode.
- drm/i915: rip out intel_crtc->dpms_mode.
- drm/i915: check connector hw/sw state.
- drm/i915: read out the modeset hw state at load and resume time.
- drm/i915/dvo: implement get_hw_state.
- drm/i915/sdvo: implement get_hw_state.
- drm/i915/crt: implement get_hw_state.
- drm/i915/lvds: implement get_hw_state.
- drm/i915/tv: implement get_hw_state.
- drm/i915/hdmi: implement get_hw_state.
- drm/i915/dp: implement get_hw_state.
- drm/i915: Add interfaces to read out encoder/connector hw state.
- drm/i915: WARN when trying to enabled an unused crtc.
- drm/i915: call crtc functions directly.
- drm/i915: rip out encoder->prepare/commit.
- drm/i915: simplify intel_crtc_prepare_encoders.
- drm/i915: copy&paste drm_crtc_helper_set_mode.
- drm/i915: inline intel_best_encoder.
- drm/i915: call set_base directly.
- drm/i915: copy&paste drm_crtc_helper_set_config.
- drm/i915: clean up encoder_prepare/commit.
- drm/i915: rip out encoder->disable/enable checks.
- drm/i915: convert dpms functions of dvo/sdvo/crt.
- drm/i915/dvo: convert to encoder disable/enable.
- drm/i915/sdvo: convert to encoder disable/enable.
- drm/i915/crt: convert to encoder disable/enable.
- drm/i915/dp: convert to encoder disable/enable.
- drm/i915/lvds: convert to encoder disable/enable.
- drm/i915/tv: convert to encoder enable/disable.
- drm/i915/hdmi: convert to encoder->disable/enable.
- drm/i915: add direct encoder disable/enable infrastructure.
- drm/i915: rip out crtc prepare/commit indirection.
- drm/i915: add crtc->enable/disable vfuncs insted of dpms.
- drm/i915: Enable some sysfs stuff without CONFIG_PM.
- drm: udl: usb: Fix recursive Kconfig dependency.
- drm/i915: Never read FORCEWAKE.
- drm/i915: Change forcewake timeout to 2ms.
- drm/i915: use cpu_relax() in wait_for_atomic.
- drm/i915: Extract forcewake ack timeout.
- drm/i915: fix sdvo hotplug support check and activation.
- drm/i915: Convert remaining debugfs iterators over rings to
  for_each_ring().
- drm/i915: differ error message between forcwake timeouts.
- drm/i915: align vlv forcewake with common lore.
- drm/i915: add a tracepoint for gpu frequency changes.
- drm/ips: move drps/ips/ilk related variables into dev_priv->ips.
- drm/i915: add workarounds to gen7_render_ring_flush.
- drm/i915: add workarounds directly to gen6_render_ring_flush.
- drm/i915: add gen7_render_ring_flush.
- drm/i915: move i915_get_extra_insdone out of CONFIG_DEBUG_FS
  block.
- drm/i915: disable rc6 on ilk when vt-d is enabled.
- drm/i915: Avoid unbinding due to an interrupted pin_and_fence
  during execbuffer.
- drm/i915: Use new INSTDONE registers (Gen7+).
- drm/i915: Add new INSTDONE registers.
- drm/i915: Extract reading INSTDONE.
- drm/i915: Use a non-blocking wait for set-to-domain ioctl.
- drm/i915: Juggle code order to ease flow of the next patch.
- drm/i915: Use cpu relocations if the object is in the GTT but
  not mappable.
- drm/i915: Extract general object init routine.
- drm/i915: Protect private gem objects from truncate (such as
  imported dmabuf).
- drm/i915: Only pwrite through the GTT if there is space in
  the aperture.
- drm: Add misssing static storage class specifier in
  drm_fb_helper.c file.
- drm: Add missing static storage class specifier in drm_irq.c
  file.
- drm/i2c/ch7006: Convert to dev_pm_ops.
- drm/usb: select USB_SUPPORT in Kconfig.
- drm: Define SAREA_MAX for Loongson (PageSize = 16KB).
- drm: Handle io prot correctly for MIPS.
- drm: remove the raw_edid field from struct drm_display_info.
- drm/ast: fix EDID memory leak.
- drm/mgag200: remove unused validate_sequence.
- drm/cirrus: Remove unused validate_sequence.
- drm/ast: remove unused validate_sequence.
- i915: use alloc_ordered_workqueue() instead of explicit UNBOUND
  w/ max_active = 1.
- drm/radeon: Use PCI Express Capability accessors.
- sgi-agp: Use list_for_each_entry() for bus->devices traversal.
- drm/i915: Find unclaimed MMIO writes.
- drm/i915: Add ERR_INT to gen7 error state.
- drm/i915: Cantiga+ cannot handle a hsync front porch of 0.
- drm/i915: fix reassignment of variable "intel_dp->DP".
- drm/i915: Try harder to allocate an mmap_offset.
- drm/i915: Show pin count in debugfs.
- drm/i915: Show (count, size) of purgeable objects in
  i915_gem_objects.
- drm/i915: Add some sanity checks to unbound tracking.
- drm/i915: Track unbound pages.
- workqueue: deprecate system_nrt[_freezable]_wq.
- workqueue: deprecate flush[_delayed]_work_sync().
- drm/i915: move functions around.
- drm/i915: Haswell HDMI audio initialization.
- drm/udl: call begin/end cpu access at more appropriate time.
- drm/i915: implement dma buf begin_cpu_access (v2).
- drm/i915: Allow VGA on CRTC 2.
- drm/i915: Don't hardcode the number of pipes in the error
  state dump.
- drm/fb-helper: don't clobber output routing in setup_crtcs.
- drm/i915: ironlake_write_eld code cleanup.
- drm/i915: write eld info for HDMI audio.
- drm/i915: HSW audio registers definition.
- drm/i915: extract ironlake_fdi_pll_disable.
- drm/i915: kill a few unused things in dev_priv.
- drm/i915: simplify dvo dpms interface.
- drm/i915: drop intel_encoder argument to load_detect_pipe
  functions.
- drm/i915: prepare load-detect pipe code for dpms changes.
- drm/i915: rip out the overlay pipe A workaround.
- drm/i915/ns2501: kill pll A enabling hack.
- drm/i915: add missing gen2 pipe A quirk entries.
- Merge tag 'v3.6-rc2' into drm-intel-next.
- drm/i915: don't grab dev->struct_mutex for userspace forcewak.
- drm/i915: try harder to find WR PLL clock settings.
- drm/i915: use the correct encoder type when comparing.
- drm/i915: Lazily apply the SNB+ seqno w/a.
- drm/i915: enable rc6 on ilk again.
- drm/i915: fix up ilk drps/ips locking.
- drm/i915: DE_PCU_EVENT irq is ilk-only.
- drm/i915: kill dev_priv->mchdev_lock.
- drm/i915: move all rps state into dev_priv->rps.
- drm/i915: use mutex_lock_interruptible for debugfs files.
- drm/i915: fixup up debugfs rps state handling.
- drm/i915: properly guard ilk ips state.
- drm/i915: add parentheses around PIXCLK_GATE definitions.
- drm/i915: reindent Haswell register definitions.
- drm/i915: completely reset the value of DDI_FUNC_CTL.
- drm/i915: correctly set the DDI_FUNC_CTL bpc field.
- drm/i915: set the DDI sync polarity bits.
- drm/i915: fix pipe DDI mode select.
- drm/i915: dump the device info.
- drm/i915: fixup desired rps frequency computation.
- drm/i915: Add I915_GEM_PARAM_HAS_SEMAPHORES.
- drm/i915: Only apply the SNB pipe control w/a to gen6.
- drm/i915: prevent possible pin leak on error path.
- drm/i915: rip out sanitize_pm again.
- drm/i915: Only set the down rps limit when at the loweset
  frequency.
- drm/i915: Export ability of changing cache levels to userspace.
- drm/i915: Segregate memory domains in the GTT using coloring.
- drm/i915: Expand DPF support to Haswell.
- drm/i915: Macro to determine DPF support.
- drm/i915: Add contexts for HSW.
- drm/i915: Avoid concurrent access when marking the device
  as idle/busy.
- drm/i915: Split i915_gem_flush_ring() into seperate
  invalidate/flush funcs.
- drm/i915: Clear the pending_gpu_fenced_access flag at the
  start of execbuffer.
- drm/i915: Replace the complex flushing logic with simple
  invalidate/flush all.
- drm/i915: Remove the explicit flush of the GPU write domain.
- drm/i915: Remove explicit flush from
  i915_gem_object_flush_fence().
- drm/i915: Remove the per-ring write list.
- drm/i915: Remove the defunct flushing list.
- drm/i915: Replace the pending_gpu_write flag with an explicit
  seqno.
- drm/i915: Remove assertion over write domain after
  i915_gem_object_sync().
- commit a4d6df1
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: Allow late allocation of request for i915_add_request().
- Refresh patches.xen/xen3-patch-2.6.29.
- commit 483d205
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: add inte_crt->adpa_reg.
- drm/i915: create VLV_DSIPLAY_BASE #define.
- commit 4d72fe6
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: Return a mask of the active rings in the high word
  of busy_ioctl.
- drm/i915: add register read IOCTL.
- commit 4f53c0a
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: Reserve ioctl numbers for set/get_caching.
- drm/i915: Support for ns2501-DVO.
- drm/i915: add port field to struct intel_dp and use it.
- drm/i915: move common code to intel_dp_set_link_train.
- drm/i915: add port parameter to intel_hdmi_init.
- drm/i915: simplify possible_clones computation.
- drm/i915: group ADPA #defines together.
- drm/i915: Cleanup context switching through do_switch().
- commit 2596ec4
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: Move DP structs to shared location.
- commit f0c9ae3
* Wed Feb 13 2013 msrb@novell.com
- radeon: remove wake_up_all_locked.
- radeon: fix kmaloc_array.
- commit dac60a1
* Wed Feb 13 2013 msrb@novell.com
- drm/nvc0/fifo: ignore bits in PFIFO_INTR that aren't set in
  PFIFO_INTR_EN.
- drm/udl: limit modes to the sku pixel limits.
- vmwgfx: corruption in vmw_event_fence_action_create().
- drm/nvc0/ltcg: mask off intr 0x10.
- drm/nouveau: silence a debug message triggered by newer
  userspace.
- drm/nouveau: add dmi quirk for gpio reset.
- drm/radeon: Prevent leak of scratch register on resume from
  suspend.
- Revert "drm/nv50-/gpio: initialise to vbios defaults during
  init".
- Revert "drm/radeon: rework pll selection (v3)".
- drm/i915: Reduce a pin-leak BUG into a WARN.
- drm/i915: enable lvds pin pairs before dpll on gen2.
- drm/nouveau: fix booting with plymouth + dumb support.
- drm/radeon: make 64bit fences more robust v3.
- drm/radeon: rework pll selection (v3).
- drm: Drop the NV12M and YUV420M formats.
- drm/exynos: remove DRM_FORMAT_NV12M from plane module.
- drm/exynos: fix double call of
  drm_prime_(init/destroy)_file_private.
- drm/exynos: add dummy support for dmabuf-mmap.
- drm/exynos: Add missing braces around sizeof in exynos_mixer.c.
- drm/exynos: Add missing braces around sizeof in exynos_hdmi.c.
- drm/exynos: Make g2d_pm_ops static.
- drm/exynos: Add dependency for G2D in Kconfig.
- drm/exynos: fixed page align bug.
- drm/exynos: Use ERR_CAST inlined function instead of
  ERR_PTR(PTR_ERR(..
- drm/exynos: Use devm_* functions in exynos_drm_g2d.c file.
- drm/exynos: Use devm_kzalloc in exynos_drm_hdmi.c file.
- drm/exynos: Use devm_kzalloc in exynos_drm_vidi.c file.
- drm/exynos: Remove redundant check in exynos_drm_fimd.c file.
- drm/exynos: Remove redundant check in exynos_hdmi.c file.
- vmwgfx: add dumb ioctl support.
- drm/i915: fix up the IBX transcoder B check.
- drm/i915: set the right gen3 flip_done mode also at resume.
- drm/i915: initialize dpio_lock spin lock.
- drm/vmwgfx: allow a kconfig option to choose if fbcon is
  enabled.
- drm: use drm_compat_ioctl for 32-bit apps.
- drm/i915: do not expose a dysfunctional backlight interface
  to userspace.
- drm/i915: only enable sdvo hotplug irq if needed.
- drm/i915/edp: get the panel delay before powering up.
- drm/ast: drop debug level on error printk.
- drm/nv50-/gpio: initialise to vbios defaults during init.
- drm/nvd0/disp: hopefully fix selection of 6/8bpc mode on
  DP outputs.
- drm: Add EDID_QUIRK_FORCE_REDUCED_BLANKING for ASUS VW222S.
- drm/radeon: fix dig encoder selection on DCE61.
- drm/radeon: fix double free in radeon_gpu_reset.
- drm/radeon: force dma32 to fix regression rs4xx,rs6xx,rs740.
- drm/radeon: rework panel mode setup.
- drm/radeon/atom: powergating fixes for DCE6.
- drm/radeon/atom: rework DIG modesetting on DCE3+.
- drm/radeon: don't disable plls that are in use by other crtcs.
- drm/radeon: add proper checking of RESOLVE_BOX command for
  r600-r700.
- drm/radeon: initialize tracked CS state.
- drm/radeon: fix reading CB_COLORn_MASK from the CS.
- drm/nvc0/copy: check PUNITS to determine which copy engines
  are disabled.
- drm/i915: Use the correct size of the GTT for placing the
  per-process entries.
- drm: Check for invalid cursor flags.
- drm: Initialize object type when using DRM_MODE() macro.
- drm/i915: fix color order for BGR formats on IVB.
- drm/i915: fix wrong order of parameters in port checking
  functions.
- drm: Add missing static storage class specifiers in drm_proc.c
  file.
- drm/udl: dpms off the crtc when disabled.
- drm: Remove two unused fields from struct drm_display_mode.
- drm: stop vmgfx driver explosion.
- drm/radeon/ss: use num_crtc rather than hardcoded 6.
- Revert "drm/radeon: fix bo creation retry path".
- drm/i915: use hsw rps tuning values everywhere on gen6+.
- drm/radeon: split ATRM support out from the ATPX handler (v3).
- drm/radeon: convert radeon vfct code to use
  acpi_get_table_with_size.
- drm/radeon: implement ACPI VFCT vbios fetch (v3).
- drm/radeon: fix checking of MSAA renderbuffers on r600-r700.
- drm/radeon: allow CMASK and FMASK in the CS checker on
  r600-r700.
- drm/radeon: init lockup timeout on ring init.
- drm/radeon: avoid turning off spread spectrum for used pll.
- vga_switcheroo: Don't require handler init callback.
- drm/i915: fall back to bit-banging if GMBUS fails in CRT
  EDID reads.
- drm/i915: extract connector update from intel_ddc_get_modes()
  for reuse.
- drm/i915: fix hsw uncached pte.
- drm/i915/contexts: fix list corruption.
- drm/i915: fix EDID memory leak in SDVO.
- drm/i915: Apply post-sync write for pipe control invalidates.
- drm/i915: reorder edp disabling to fix ivb MacBook Air.
- drm/nv86/fifo: suspend fix.
- drm/nouveau: disable copy engine on NVAF.
- nouveau: fixup scanout enable in nvc0_pm.
- drm/nouveau/aux: mask off higher bits of auxch index in i2c
  table entry.
- drm/nvd0/disp: mask off high 16 bit of negative cursor
  x-coordinate.
- drm/i915: ensure i2c adapter is all set before adding it.
- drm/radeon: fix typo in function header comment.
- drm/radeon/kms: implement timestamp userspace query (v2).
- drm/radeon/kms: add MSAA texture support for r600-evergreen.
- drm/radeon/kms: reorder code in r600_check_texture_resource.
- drm/radeon: fence virtual address and free it once idle v4.
- drm/radeon: fix some missing parens in asic macros.
- drm/radeon: add some new SI pci ids.
- drm/radeon: fix ordering in pll picking on dce4+.
- drm/radeon: fix bank tiling parameters on cayman.
- drm/radeon: fix bank tiling parameters on evergreen.
- drm/radeon: fix bank tiling parameters on SI.
- drm/radeon: properly handle crtc powergating.
- drm/radeon: properly handle SS overrides on TN (v2).
- drm/radeon/dce4+: set a more reasonable cursor watermark.
- drm/radeon: fix handling for ddc type 5 on combios.
- drm/i915: ignore eDP bpc settings from vbt.
- drm/i915: Fix blank panel at reopening lid.
- drm/mgag200: fix G200ER pll picking algorithm.
- drm/edid: Fix potential memory leak in edid_load().
- drm/udl: Use ERR_CAST inlined function instead of
  ERR_PTR(PTR_ERR(..
- drm/radeon/kms: allow "invalid" DB formats as a means to
  disable DB.
- drm/i915: add more Haswell PCI IDs.
- drm/i915: make rc6 in sysfs functions conditional.
- drm/i915: Workaround hang with BSD and forcewake on SandyBridge.
- drm/i915: Make intel_panel_get_backlight static.
- i915: don't map imported dma-bufs for dmar.
- drm/i915: remove unused variable.
- drm/i915: Don't forget to apply SNB PIPE_CONTROL GTT workaround.
- drm/nve0/fifo: add support for the flip completion swmthd.
- drm/i915: fix forcewake related hangs on snb.
- drm/exynos: fixed exception to page allocation failure.
- drm/exynos: use __free_page() to deallocate memory.
- drm/exynos: fixed a comment to gem size.
- drm/exynos: removed unnecessary variable.
- drm/exynos: do not release memory region from exporter.
- drm/exynos: set buffer type from exporter.
- drm/exynos: use alloc_page() to allocate pages.
- drm/exynos: fixed build warning.
- drm/exynos: fixed edid data setting at vidi connection request.
- drm/exynos: check if raw edid data is fake or not for test.
- drm/exynos: set edid fake data only for test.
- drm/exynos: removed unnecessary declaration.
- drm/exynos: fix buffer pitch calculation.
- drm/exynos: check for null in return value of
  dma_buf_map_attachment().
- drm/exynos: return NULL if exynos_pages_to_sg fails.
- drm/exynos: Use devm_* functions in exynos_mixer.c.
- drm/exynos: Use devm_* functions in exynos_hdmi.c.
- drm/exynos: Use devm_* functions in exynos_drm_fimd.c.
- drm/exynos: Add missing static storage class specifier.
- drm/exynos: add property for crtc mode.
- drm/exynos: add crtc disable function.
- drm/exynos: add plane enable/disable.
- drm/exynos: remove unnecessary connector dpms control.
- drm/exynos: fix dpms operation for mode set.
- drm/exynos: add property for plane zpos.
- drm/exynos: update overlay via plane from crtc.
- drm/exynos: use private plane for crtc.
- drm/exynos: define to_exynos_plane macro.
- drm/exynos: fix to set pipe of crtc.
- drm/exynos: fix point to call overlay_ops->mode_set.
- i915: Remove silly test.
- i915: fix error path leak in intel_sdvo_write_cmd.
- vlv: it might be wise if we initialised the flag value...
- drm/nouveau: init vblank requests list.
- drm/nv50: extend vblank semaphore to generic dmaobj + offset
  pair.
- drm/nouveau: mark most of our ioctls as deprecated, move to
  compat layer.
- drm/nouveau: move current gpuobj code out of nouveau_object.c.
- drm/nouveau/gem: fix object reference leak in a failure path.
- drm/nv50: rename INVALID_QUERY_OR_TEXTURE error to
  INVALID_OPERATION.
- drm/nv84: decode PCRYPT errors.
- drm/nouveau: dcb table quirk for fdo#50830.
- nouveau: Fix alignment requirements on src and dst addresses.
- drm/i915: unbreak lastclose for failed driver init.
- drm/i915: Set the context before setting up regs for the
  context.
- drm/i915: constify mode in crtc_mode_fixup.
- drm/i915/lvds: ditch ->prepare special case.
- drm/i915: dereferencing an error pointer.
- drm/i915: fix invalid reference handling of the default ctx obj.
- drm/i915: Add -EIO to the list of known errors for __wait_seqno.
- drm/i915: Flush the context object from the CPU caches upon
  switching.
- drm/radeon: fix dpms on/off on trinity/aruba v2.
- drm/radeon: check for allocation failure in
  radeon_ring_backup().
- drm/radeon: fix bo creation retry path.
- drm: track dev_mapping in more robust and flexible way.
- drm/ttm: remove stale declaration and field.
- drm/i915: Make the lock for pageflips interruptible.
- drm/i915: don't forget the PCH backlight registers.
- drm/i915: Insert a flush between batches if the breadcrumb
  was dropped.
- drm/i915: missing error case in init status page.
- drm/i915: mask tiled bit when updating ILK sprites.
- drm/i915: try to train DP even harder.
- drm/i915: kill intel_ddc_probe.
- drm/i915: check whether we actually received an edid in
  detect_ddc.
- drm/i915: fix up PCH backlight #define mixup.
- commit 70901bf
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: Add comments to explain the BSD tail write workaround.
- drm/i915: Disable the BLT on pre-production SNB hardware.
- drm/i915: initialize power wells in modeset_init_hw.
- drm/i915: Only request PM interrupts for the events we handled.
- drm/i915/context: Add missing IVB context sizes.
- drm/i915/context/: s/CTX/CXT.
- drm/sis: fixup sis_mm ioctl structs.
- drm: kill i915/i830 ids from drm_pciids.h.
- drm: unconditionally clean up dma buffers of closing clients.
- drm: kill dma queue support.
- drm: ditch strange DRIVER_DMA_QUEUE only error bail-out.
- drm: kill reclaim_buffers callback.
- drm/savage: clean up reclaim_buffers.
- drm: kill reclaim_buffers_locked.
- Revert "Revert "drm/i810: cleanup reclaim_buffers"".
- drm: kill reclaim_buffers_idlelocked functions.
- drm/sis: clean up reclaim_buffers.
- drm/via: clean up reclaim_buffers.
- drm/udl: port over blanking code from udlfb.
- drm/radeon/kms: auto detect pcie link speed from root port.
- drm/pci: add support for getting the supported link bw.
- drm/radeon: improve GPU lockup debugging info on
  r6xx/r7xx/r8xx/r9xx.
- drm/mgag200: fix null pointer dereference.
- drm: Make the .mode_fixup() operations mode argument a const
  pointer.
- drm: remove the list_head from drm_mode_set.
- drm/radeon: fix SS setup for DCPLL.
- drm/radeon: fix up pll selection on DCE5/6.
- drm/radeon: start to document evergreen.c.
- drm/radeon: start to document the functions r100.c.
- drm/radeon: document VM functions in radeon_gart.c (v3).
- drm/radeon: document non-VM functions in radeon_gart.c (v2).
- drm/radeon: document radeon_ring.c (v4).
- drm/radeon: document radeon_fence.c (v2).
- drm/radeon: document radeon_asic.c.
- drm/radeon: document radeon_irq_kms.c.
- commit 9d74cdc
* Wed Feb 13 2013 msrb@novell.com
- drm/radeon: document radeon_kms.c.
- drm/radeon: document radeon_device.c (v2).
- drm/radeon: add rptr save support for r1xx-r5xx.
- drm/radeon: update rptr saving logic for memory buffers.
- drm/radeon: remove radeon_ring_index().
- drm/radeon: update ib_execute for SI (v2).
- drm/radeon: fix const IB handling v2.
- drm/radeon: let sa manager block for fences to wait for v2.
- drm/radeon: return an error if there is nothing to wait for.
- drm: Disallow DRM_IOCTL_MODESET_CTL for KMS drivers.
- drm/radeon: implement ring saving on reset v4.
- drm/radeon: record what is next valid wptr for each ring v4.
- drm/radeon: move radeon_ib_ring_tests out of chipset code.
- drm/radeon: remove vm_manager start/suspend.
- drm/radeon: remove r600_blit_suspend.
- drm/radeon: remove ip_pool start/suspend.
- drm/radeon: make cp init on cayman more robust.
- drm/radeon: remove FIXME comment from chipset suspend.
- drm/radeon: fix fence init after resume.
- drm/radeon: fix fence value access.
- drm/radeon: fix ring commit padding.
- drm/radeon: add an exclusive lock for GPU reset v2.
- drm/radeon: fix fence related segfault in CS.
- drm/radeon: add error handling to radeon_vm_unbind_locked.
- drm/radeon: add error handling to fence_wait_empty_locked.
- drm: Add colouring to the range allocator.
- drm: fail gracefully when proc isn't setup.
- drm/i915: program FDI_RX TP and FDI delays.
- drm/i915: introduce for_each_encoder_on_crtc.
- drm/i915: adjust framebuffer base address on gen4+.
- drm/i915: introduce crtc->dspaddr_offset.
- drm/i915: Reject page flips with changed format/offset/pitch.
- drm/i915: Zero initialize mode_cmd.
- drm/i915: don't return a spurious -EIO from intel_ring_begin.
- drm/i915: properly SIGBUS on I/O errors.
- drm/i915: non-interruptible sleeps can't handle -EAGAIN.
- drm/i915: fix PIPE_DDI_PORT_MASK.
- drm/i915: prevent bogus intel_update_fbc notifications.
- drm/i915: re-initialize DDI buffer translations after resume.
- drm/i915: don't ironlake_init_pch_refclk() on LPT.
- drm/i915: get rid of dev_priv->info->has_pch_split.
- drm/i915: add PCH_NONE to enum intel_pch.
- drm/i915: prefer wide & slow to fast & narrow in DP configs.
- drm/i915: fix up ilk rc6 disabling confusion.
- drm/i915: move force wake support into intel_pm.
- drm/i915: enable RC6 workaround on Haswell.
- drm/i915: introduce haswell_init_clock_gating.
- drm/i915: disable RC6 when disabling rps.
- drm/i915: enable RC6 by default on Haswell.
- drm/i915: slightly improve gt enable/disable routines.
- drm/i915: add RPS configuration for Haswell.
- drm/i915: support Haswell force waking.
- drm/i915: Implement w/a for sporadic read failures on waking
  from rc6.
- drm/i915: Group the GT routines together in both code and
  vtable.
- drm/i915: linuxify create_hw_context().
- drm/radeon: move r100_enable_bm to a more logic place.
- drm/radeon: clean up CS functions in r100.c.
- drm/i915: fix PIPE_WM_LINETIME definition.
- drm/i915: "Flush Me Harder" required on gen6+.
- drm/i915/sprite: Fix mem leak in intel_plane_init().
- drm/i915: correct IVB default sprite format.
- drm/i915: mask tiled bit when updating IVB sprites.
- drm/i915/bios: cleanup return type of intel_parse_bios().
- agp/intel-agp: remove snb+ host bridge pciids.
- drm/i915: disable drm agp support for !gen3 with kms enabled.
- drm/i915: don't use dev->agp.
- drm/i915: make enable/disable_gt_powersave locking consistent.
- commit dc95950
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: wrap up gt powersave enabling functions.
- drm: use format %%d to print error code.
- drm: Add missing static storage class specifier.
- drm/radeon: replace cs_mutex with vm_mutex v3.
- drm/radeon: replace pflip and sw_int counters with atomics.
- drm/radeon: apply Murphy's law to the kms irq code v3.
- drm/radeon: fix & improve ih ring handling v3.
- drm/radeon: remove some unneeded structure members.
- drm/radeon: replace vmram_mutex with mclk_lock v2.
- drm/radeon: rework ring syncing code.
- drm/radeon: add infrastructure for advanced ring synchronization
  v2.
- drm/radeon: remove radeon_fence_create.
- drm/i915: bind driver to ValleyView chipsets.
- drm/i915: enable display messages to GT on ValleyView.
- drm/i915: support page flipping on ValleyView.
- drm/i915: don't enable PPGTT on VLV yet.
- agp/intel: use correct GTT offset on VLV.
- agp/intel: allow cacheable and GDFT PTEs on ValleyView.
- drm/i915: VLV VGA port only handles on & off, like PCH VGA.
- drm/i915: access VLV regs through read/write switch.
- drm/i915: add HDMI and DP port enumeration on ValleyView.
- drm/i915: add ValleyView specific CRT detect function.
- drm/i915: Enable DP panel power sequencing for ValleyView.
- drm/i915: ValleyView mode setting limits and PLL functions.
- drm/i915: disable flushing_list/gpu_write_list.
- drm/i915: return -ENODEV if hw context are not supported.
- drm/i915: simplify context_idr_cleanup.
- drm/i915/context: shut up compiler.
- drm/i915: return -ENOENT if the context doesn't exist.
- drm/i915: initialize the context idr unconditionally.
- drm/i915: fix module unload after context merge.
- drm/i915: add L3 bank clock gating disable on VLV.
- drm/i915: add TDL unit clock gating disable for VLV.
- drm/i915: load boot context at driver init time.
- drm/i915: disable RCBP and VDS unit clock gating on SNB and VLV.
- drm/i915: fixup hangman rebase goof-up.
- drm/i915: set IDICOS to medium uncore resources.
- drm/i915: disable contexts on old HW.
- drm/i915: properly wait for SBI status.
- drm/i915/crt: Do not rely upon the HPD presence pin.
- drm/i915: reset the GPU on context fini.
- commit 02f2115
* Wed Feb 13 2013 msrb@novell.com
- drm/i915/context: switch contexts with execbuf2.
- drm/i915/context: create & destroy ioctls.
- drm/i915: switch to default context on idle.
- drm/i915: add ccid to error state.
- drm/i915: use the default context.
- drm/i915: possibly invalidate TLB before context switch.
- drm/i915: PIPE_CONTROL_TLB_INVALIDATE.
- drm/i915: Ivybridge MI_ARB_ON_OFF context w/a.
- drm/i915: ensure context objects are bound to the global gtt.
- drm/i915: context switch implementation.
- drm/i915: context basic create & destroy.
- drm/i915: preliminary context support.
- drm/i915: CXT_SIZE register offsets added.
- drm/i915: ignore pipe select bit when checking for LVDS
  register initialization.
- drm/i915: Switch off FBC when disabling the primary plane
  when obscured.
- drm/i915: call intel_enable_gtt.
- agp/intel-gtt: move gart base addres setup.
- drm/i915 + agp/intel-gtt: prep work for direct setup.
- agp/intel-gtt: don't require the agp bridge on setup.
- drm/i915: stop using dev->agp->base.
- agp/intel-gtt: remove dead code.
- drm/i915: allow pipe A for lvds on gen4.
- drm/i915: properly enable the blc controller on the right pipe.
- drm/i915: clear up backlight #define confusion on gen4+.
- drm/i915: pnv has a backlight polarity control bit, too.
- drm/i915: ensure HDMI port is disabled inside set_infoframes.
- drm/i915: Add wait render timeout get param.
- drm/i915: Inifite timeout for wait ioctl.
- drm/i915: assert that the IBX port transcoder select w/a
  is implemented.
- drm/i915: implement IBX hdmi transcoder select workaround.
- drm/i915: add min freq control to debugfs.
- drm/i915: don't chnage the original mode in dp_mode_fixup.
- drm/i915: adjusted_mode->clock in the dp mode_fixup.
- drm/i915: compute the target_clock for edp directly.
- drm/i915: extract object active state flushing code.
- drm/i915: clarify IBX dp workaround.
- drm/i915: simplify sysfs setup code.
- drm/i915: initialize the parity work only once.
- drm/i915: ivybridge_handle_parity_error should be static.
- drm/i915: l3 parity sysfs interface.
- drm/i915: remap l3 on hw init.
- drm/i915: enable parity error interrupts.
- drm/i915: Dynamic Parity Detection handling.
- drm/i915: s/mdelay/msleep/ in the sdvo detect function.
- drm/i915: reuse the sdvo tv clock adjustment in ilk mode_set.
- drm/i915: there's no cxsr on ilk.
- drm/i915: add some barriers when changing DIPs.
- drm/i915: remove comment about HSW HDMI DIPs.
- drm/i915: don't set SDVO_BORDER_ENABLE when we're HDMI.
- drm/i915: don't write 0 to DIP control at HDMI init.
- drm/i915: disable DIP while changing the port.
- drm/i915: explicitly disable the DIPs we're not using.
- drm/i915: don't wait for vblank while writing InfoFrames.
- drm/i915: enable DIP before enabling each InfoFrame.
- drm/i915: only set the HDMI port on the DIP once.
- drm/i915: properly alternate between DVI and HDMI.
- drm/i915: add set_infoframes to struct intel_hdmi.
- drm/i915/hdmi: Fix reg values for g4x_hdmi_connected.
- commit e56382e
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: s/i915_wait_request/i915_wait_seqno/g.
- Refresh patches.xen/xen3-patch-2.6.29.
- commit 67b013d
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: wait render timeout ioctl.
- commit 10fe468
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: improve i915_wait_request_begin trace.
- drm/i915: timeout parameter for seqno wait.
- drm/i915: don't silently ignore sdvo mode_set failures.
- drm/i915: clarify preferred sdvo input mode code.
- drm/i915/dp: For consistency use the DP hotplug synonyms.
- drm/i915/hdmi: Query the live connector status bit for G4x.
- drm/i915: SDVO hotplug have different interrupt status bits
  for i915/i965/g4x.
- drm/i915: Inspect the right status bits for DP/HDMI hotplug
  on gen4.
- drm/i915: All members of gen4 have hotplug, so unconditionally
  enable its irq.
- commit ef8141b
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: kick any firmware framebuffers before claiming
  the gtt.
- drm/radeon: fix rare segfault.
- drm/radeon: fix VM page table setup on SI.
- Revert "drm/i915: allow PCH PWM override on IVB".
- drm/nouveau: add license header to prime.
- drm/udl: Make sure to get correct endian keys from vendor
  descriptor.
- drm/i915: rip out the PM_IIR WARN.
- drm: drop comment about this header being autogenerated.
- drm/radeon: SI tiling fixes for display.
- drm/i915: cache the EDID for eDP panels.
- Revert "drm/i915/dp: Use auxch precharge value of 5 everywhere".
- drm/i915: eDP aux needs vdd.
- drm/i915: don't enumerate HDMID if an eDP panel is already
  active on the port.
- drm/radeon: add support for STRMOUT_BASE_UPDATE on 7xx.
- drm/radeon: add some additional 6xx/7xx/EG register init.
- drm/radeon: enable HDMI on DCE5 (AKA NI excluding Aruba).
- drm sis: initialize object_idr.
- drm via: initialize object_idr.
- drm/radeon/prime: reserve/unreserve around pin.
- drm/radeon: fix regression in dynpm due to multi-ring rework.
- drm/udl: only bind to the video devices on the hub.
- drm/ttm: Fix buffer object metadata accounting regression v2.
- commit 0db03ba
* Wed Feb 13 2013 msrb@novell.com
- drm: increase DRM_OBJECT_MAX_PROPERTY to 24.
- drm/radeon: fix tiling and command stream checking on
  evergreen v3.
- Revert "drm/i915/crt: Do not rely upon the HPD presence pin".
- drm/i915: pch_irq_handler -> {ibx, cpt}_irq_handler.
- drm/i915: fix up ivb plane 3 pageflips.
- drm/radeon/kms: add new SI PCI ids.
- drm/radeon/kms: add new Palm, Sumo PCI ids.
- drm/radeon/kms: add new Trinity PCI ids.
- drm/radeon: fix vm deadlocks on cayman.
- drm/radeon: fix gpu_init on si.
- drm/radeon/hdmi: don't set SEND_MAX_PACKETS bit.
- drm/radeon/audio: don't hardcode CRTC id.
- drm/radeon: make audio_init consistent across asics.
- drm/exynos: fixed blending for hdmi graphic layer.
- drm/exynos: Remove dummy encoder get_crtc operation
  implementation.
- drm/exynos: Keep a reference to frame buffer GEM objects.
- drm/exynos: Don't cast GEM object to Exynos GEM object when
  not needed.
- drm/exynos: DRIVER_BUS_PLATFORM is not a driver feature.
- drm/exynos: fixed size type.
- drm/exynos: Use DRM_FORMAT_{NV12, YUV420} instead of
  DRM_FORMAT_{NV12M, YUV420M}.
- drm/i915: hold forcewake around ring hw init.
- drm/i915: Mark the ringbuffers as being in the GTT domain.
- drm/edid: Make the header fixup threshold tunable.
- drm/radeon: fix regression in UMS CS ioctl.
- drm/vmwgfx: Fix nasty write past alloced memory area.
- drm/radeon: fixup tiling group size and backendmap on r6xx-r9xx
  (v4).
- drm/radeon: fix bank information in tiling config.
- drm/mgag200: kick off conflicting framebuffers earlier.
- drm/cirrus: kick out conflicting framebuffers earlier.
- radeon: add radeon prime vmap support.
- nouveau: add vmap support to nouveau prime support.
- udl: support vmapping imported dma-bufs.
- i915: add dma-buf vmap support for exporting vmapped buffer.
- cirrus: avoid crash if driver fails to load.
- drm/i915/crt: Do not rely upon the HPD presence pin.
- radeon: add stub dma-buf mmap functionality.
- nouveau: add stub dma-buf mmap functionality.
- i915: add stub dma-buf mmap callback.
- drm/i915: Reset last_retired_head when resetting ring.
- drm/edid/quirks: ViewSonic VA2026w.
- drm/udl: remove unused variables.
- drm: Use stdint types for consistency.
- drm: Constify params to format_check() and framebuffer_checks().
- drm/radeon: fix typo in trinity tiling setup.
- drm/udl: unlock before returning in udl_gem_mmap().
- radeon: make radeon_cs_update_pages static.
- drm/i915: tune down the noise of the RP irq limit fail.
- drm/i915: Remove the error message for unbinding pinned buffers.
- drm/i915: Limit page allocations to lowmem (dma32) for i965.
- dma-buf: minor documentation fixes.
- dma-buf: add vmap interface.
- dma-buf: mmap support.
- drm/i915: reject doubleclocked cea modes on dp.
- drm/i915: Adding TV Out Missing modes.
- drm/i915: no lvds quirk for HP t5740e Thin Client.
- drm/i915: Fix PCH PLL assertions to not assume CRTC:PLL
  relationship.
- drm/i915: Always update RPS interrupts thresholds along with
  frequency.
- drm/nouveau/nvd9: Fix GPIO initialisation sequence.
- drm/nouveau: Unregister switcheroo client on exit.
- drm/nouveau: Check dsm on switcheroo unregister.
- drm/nouveau: fix a minor annoyance in an output string.
- drm/nouveau: turn a BUG into a WARN.
- drm/nv50: decode PGRAPH DATA_ERROR = 0x24.
- drm/nouveau/disp: fix dithering not being enabled on some
  eDP macbooks.
- drm/nvd9/copy: initialise copy engine, seems to work like nvc0.
- drm/nvc0/ttm: use copy engines for async buffer moves.
- drm/nva3/ttm: use copy engine for async buffer moves.
- drm/nv98/ttm: add in a (disabled) crypto engine buffer copy
  method.
- drm/nv84/ttm: use crypto engine for async buffer copies.
- drm/nouveau/ttm: untangle code to support accelerated buffer
  moves.
- drm/nouveau/fbcon: use fence for sync, rather than notifier.
- drm/nv98/crypt: non-stub implementation of the engine hooks.
- drm/nouveau/fifo: turn all fifo modules into engine modules.
- drm/nv50/graph: remove ability to do interrupt-driven context
  switching.
- drm/nv50: remove manual context unload on context destruction.
- drm/nv50: remove execution engine context saves on suspend.
- drm/nv50/fifo: use hardware channel kickoff functionality.
- drm/nv50/gr: make sure NEXT_TO_CURRENT is executed even if
  nothing done.
- drm/nv50/fifo: construct playlist from hw context table state.
- drm/nouveau/fifo: remove all the "special" engine hooks.
- drm/nouveau/fence: fix a race where fence->channel can
  disappear.
- drm/nouveau/bios: fix some shadowing issues, particularly acpi.
- drm/nouveau: fix engine context destructor ordering.
- drm/nouveau/fence: convert to exec engine, and improve
  channel sync.
- drm/nouveau/fence: minor api changes for an upcoming rework.
- drm/nouveau/fence: make ttm interfaces wrap ours, not the
  other way around.
- drm/nouveau: move flip-related channel setup to software engine.
- drm/nouveau: create real execution engine for software object
  class.
- drm/nvd0/disp: remove unnecessary sync from flip_next.
- drm/nv04/disp: disable vblank interrupts when disabling display.
- drm/nouveau: base fence timeout on time of emission.
- drm/nv40-50/gr: restructure grctx/prog generation.
- drm/nv50/disp: fixup error paths in crtc object creation.
- drm/nouveau: cleanup after display init failure.
- drm/nv50: fix ramin heap size for kernel channel too.
- drm/nve0/graph: bump hub2gpc buffer size.
- drm/nouveau: use the same packet header macros as userspace.
- drm/nouveau/bios: allow loading alternate vbios image as
  firmware.
- drm/nve0/ttm: implement buffer moves with weirdo pcopy-on-pgraph
  methods.
- drm/nv50-/fbcon: move 2d class to subchannel 3.
- drm/nve0/gr: initial implementation.
- drm/nve0/fifo: initial implementation.
- drm/nouveau: give a slightly larger pci(e)gart aperture on
  all chipsets.
- drm/nouveau/pm: some more delays for ddr3 reclocking.
- drm/nvc0/pm: very initial mclk freq change.
- drm/nvd9/pm: oops, fix timing calc.
- drm/nvc0/pm: enable mpll src pll, and calc mpll coefficients.
- drm/nvc0/pm: start filling in memory reclocking stubs.
- drm/nva3/pm: another few magic regs, and slightly better
  0x004018 handling.
- drm/nva3/pm: initial attempt at handling 111100/111104.
- drm/nva3/pm: make pll->pll mode work.
- drm/nva3/pm: attempt to bash a few 0x100200 bits correctly.
- drm/nva3/pm: begin to restructure memory clock changes +
  another magic.
- drm/nva3/pm: more random unknown PFB regs.
- drm/nva3/pm: initial attempt at more magic PFB regs.
- drm/nva3/pm: hook up to ram reclocking helper.
- drm/nva3/pm: introduce more paranoia.
- drm/nouveau/radeon: add static const to the dma-buf ops.
- drm/i915: make some dmabuf things static.
- drm: update ast/cirrus/mgag200 for change in TTM api.
- drm/radeon: add PRIME support (v2).
- i915: add dmabuf/prime buffer sharing support.
- nouveau: add PRIME support.
- ttm: add prime sharing support to TTM (v2).
- udl: add prime fd->handle support.
- drm/prime: add exported buffers to current fprivs imported
  buffer list (v2).
- drm/prime: introduce sg->pages/addr arrays helper.
- drm: add plane properties.
- drm: add bitmask property type.
- drm: Make the CRTC gamma_set operation optional.
- drm: Constify drm_mode_config_funcs pointer.
- drm: Constify gem_vm_ops pointer.
- drm: Miscellaneous typo fixes and documentation updates.
- drm: Don't initialize local ret variable when not needed.
- drm: Delete the vblank timer synchronously at cleanup time.
- drm/backlight: initialize struct backlight_properties properly.
- drm/nouveau/dp: Probe branch/sink OUIs (v2).
- drm/radeon/dp: Probe branch/sink OUIs.
- drm/i915/dp: Probe branch/sink OUIs.
- drm/dp: Add DPCD OUI register defines.
- drm/radeon/hdmi: compile audio status in 1 function.
- drm/i915: fix module unload since error_state rework.
- drm/i915: be more careful when returning -ENXIO in gmbus
  transfer.
- drm/i915: IBX has a fixed pch pll to pch pipe mapping.
- drm/i915: implement hsw_write_infoframe.
- drm/i915: small hdmi coding style cleanups.
- drm/kms: fix Kconfig for new drivers.
- drm/i915: Enable the PCH PLL for all generations after link
  training.
- drm/i915: Convert BUG_ON(!pll->active) and friends to a WARN.
- drm/i915: disable gmbus on i830.
- drm/i915: Replace the feature tests for BLT/BSD with ring
  init checks.
- drm/i915: Check whether the ring is initialised prior to
  dispatch.
- drm/i915: Introduce for_each_ring() macro.
- drm/i915: Assert that the transcoder is indeed off before
  modifying it.
- drm/i915: hook Haswell devices in place.
- drm/i915: prepare HDMI link for Haswell.
- drm/i915: move HDMI structs to shared location.
- drm/i915: add WR PLL programming table.
- drm/i915: add support for DDI-controlled digital outputs.
- drm/i915: detect digital outputs on Haswell.
- drm/i915: program iCLKIP on Lynx Point.
- drm/i915: program WM_LINETIME on Haswell.
- drm/i915: define Haswell watermarks and clock gating.
- drm/i915: use ironlake eld write routine for Haswell.
- drm/i915: support DDI training in FDI mode.
- drm/i915: initialize DDI buffer translations.
- drm/i915: account for only one PCH receiver on Haswell.
- drm/i915: handle DDI-related assertions.
- drm/i915: add LPT PCH checks.
- drm/i915: enable power wells on Haswell init.
- drm/i915: detect PCH encoders on Haswell.
- drm/i915: do not use fdi_normal_train on Haswell.
- drm/i915: show unknown sdvox registers on hdmi init.
- drm/i915: properly check for pipe count.
- drm/i915: calculate watermarks for devices that have 3 pipes.
- drm/i915: add support for SBI ops.
- drm/i915: reuse Ivy Bridge interrupts code for Haswell.
- drm/i915: add new Haswell DIP controls registers.
- drm/i915: gen6_enable_rps() wants to be called after ring
  initialisation.
- drm/cirrus/ast/mgag200: fix build without CONFIG_VGA_CONSOLE.
- drm/prime: expose capability flags for userspace.
- drm/radeon/hdmi: use new AFMT structs.
- drm/radeon/hdmi: store info about all AFMT blocks.
- drm/exynos: add G2D driver.
- drm/exynos: added vp scaling feature for hdmi.
- drm/exynos: added source size to overlay structure.
- drm/exynos: add additional display mode for hdmi.
- drm/exynos: enable dvi mode for dvi monitor.
- drm/exynos: fixed wrong pageflip finish event for interlace
  mode.
- drm/radeon: make use of radeon_gem_init() consistent.
- drm/radeon: eliminate redundant connector_names table.
- drm/radeon: Also reset BCI on SI GPU reset.
- drm/radeon: don't mess with hot plug detect for eDP or LVDS
  connector v2.
- drm: checking the wrong variable in savage_do_init_bci().
- drm/radeon: check kmalloc() for failures.
- drm: add CRTC properties.
- drm: add 'count' to struct drm_object_properties.
- drm: make the connector properties code use the object
  properties code.
- drm: add generic ioctls to get/set properties on any object.
- drm: create struct drm_object_properties and use it.
- drm: WARN() when drm_connector_attach_property fails.
- drm: add drm_property_change_is_valid.
- drm/kms: driver for virtual cirrus under qemu.
- mgag200: initial g200se driver (v2).
- drm: Initial KMS driver for AST (ASpeed Technologies) 2000
  series (v2).
- drm/radeon/hdmi: fix some coding style.
- drm/radeon/hdmi: update modesetting.
- drm/radeon/hdmi: separate evergreen code.
- drm/radeon/kms/hdmi: helper getting ready ACR entry.
- drm/radeon/kms/hdmi: clean&improve handling HDMI mode.
- drm/radeon/kms/hdmi: enable audio packets at one place.
- vga_switcheroo: Introduce struct vga_switcheroo_client_ops.
- drm: pass dev to drm_vm_{open,close}_locked().
- drm/i915: Simplify interrupt processing for IvyBridge.
- drm/i915: enable semaphores on gen6 if dmar is not active.
- drm/radeon/kms: fix warning on 32-bit in atomic fence printing.
- drm/radeon: make the ib an inline object.
- drm/radeon: remove r600 blit mutex v2.
- drm/radeon: move the semaphore from the fence into the ib.
- drm/radeon: immediately free ttm-move semaphore.
- drm/radeon: rip out the ib pool.
- drm/radeon: simplify semaphore handling v2.
- drm/radeon: multiple ring allocator v3.
- drm/radeon: use one wait queue for all rings add fence_wait_any
  v2.
- drm/radeon: define new SA interface v3.
- drm/radeon: make sa bo a stand alone object.
- drm/radeon: keep start and end offset in the SA.
- drm/radeon: add sub allocator debugfs file.
- drm/radeon: add proper locking to the SA v3.
- drm/radeon: use inline functions to calc sa_bo addr.
- drm/radeon: rework locking ring emission mutex in fence deadlock
  detection v2.
- drm/radeon: rework fence handling, drop fence list v7.
- drm/radeon: convert fence to uint64_t v4.
- drm/radeon: replace the per ring mutex with a global one.
- drm/radeon: fix possible lack of synchronization btw ttm and
  other ring.
- drm/i915: s/intel_infoframe/gm45_infoframe.
- drm/i915: s/i9xx_/gm45_ for the gm45 write_infoframe function.
- drm/i915: replace intel_infoframe_freq with
  VIDEO_DIP_FREQ_VSYNC.
- drm/i915: Limit calling mark-busy only for potential scanouts.
- drm/i915: implement ironlake_wait_for_vblank.
- drm/i915: set the DIP port on ibx_write_infoframe.
- drm/i915: ibx_write_infoframe can disable AVI.
- drm/i915: split ironlake_write_infoframe into ibx_ and cpt_.
- drm/i915: simplify intel_encoder_commit.
- drm/i915: mask the video DIP frequency when changing it.
- drm/i915: disable the infoframe before changing it.
- drm/i915: break intel_infoframe_flags into _enable and
  _frequency.
- drm/i915: mask the video DIP port select.
- drm/i915: start writing infoframes at address 0 on gen 4.
- drm/i915: change coding style of the write_infoframe functions.
- drm/i915: DSL_LINEMASK is 12 bits only on gen2.
- Merge remote-tracking branch 'airlied/drm-core-next' into
  drm-intel-next-queued.
- drm/exynos: add PM functions for hdmi and mixer.
- drm/exynos: add dpms for hdmi.
- drm/exynos: use threaded irq for hdmi hotplug.
- drm/exynos: use platform_get_irq_byname for hdmi.
- drm/exynos: cleanup for hdmi platform data.
- drm/exynos: added a feature to get gem buffer information.
- drm/exynos: added drm prime feature.
- drm/exynos: added cache attribute support for gem.
- drm/i915: Support pageflipping interrupts for all 3-pipes
  on IVB.
- drm/i915: fix gen4 gpu reset.
- drm/i915: remove modeset reset from i915_reset.
- drm/i915: also reset the media engine on gen4/5.
- drm/i915: kill flags parameter for reset functions.
- drm/i915: make gpu hangman more resilient.
- drm/i915: extract intel_gpu_reset.
- drm/i915: simplify i915_reset a bit.
- drm/i915: allow the existing error_state to be destroyed.
- drm/i915: rework dev->first_error locking.
- drm/i915: add interface to simulate gpu hangs.
- drm/i915: use mode values consistently when converting to
  sdvo dtd.
- drm/i915: rip out unnecessary calls to drm_mode_set_crtcinfo.
- drm/i915: Periodically sanity check power management.
- drm/i915: make DBLCLK modes work.
- drm/i915: rename AVI InfoFrame field 'PR' to 'YQ_CN_PR'.
- drm/i915: Wait for the clocks to stabilise before updating PLLs.
- drm/i915: rip out intel_dpio_write again.
- drm/i915: extract some common olr+wedge code.
- drm/i915: move pnv|ilk_gem_mem_freq to intel_pm.c.
- drm/i915: fixup __iomem mixups in ringbuffer.c.
- drm/i915: rework legacy GFX HWS handling.
- drm/i915: kill pointless clearing of dev_priv->hws_map.
- drm/i915: move rps/emon function declarations.
- drm/i915: move the ips code to intel_pm.c.
- drm/i915: disallow clip rects on gen5+.
- drm/i915: move LP_RING&friends to i915_dma.c.
- drm/i915: extract dri1 breadcrumb update from irq handler.
- drm/i915: move dri1 irq ioctl code to i915_dma.c.
- drm/i915: rip out dri1 breadcrumb updates from gen5+ irq
  handlers.
- commit 8e906da
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: kill intel_clear_scanline_wait.
- drm/i915: remove LP_RING&friends from modeset code.
- drm/i915: rip out dev_priv->tex_lru_log_granularity.
- drm/i915 disallow physical batchbuffers for KMS.
- drm/i915: create dev_priv->dri1 dragon dungeon^W^W sub-struct.
- drm/i915: move dri1 vblank stubs to i915_dma.c.
- drm/i915: Remove unused dev_priv->vblank_pipe.
- drm/i915: Remove unused ring->irq_seqno.
- drm/i915: use __wait_seqno for ring throttle.
- drm/i915: remove polled wait from throttle.
- drm/i915: extract __wait_seqno from i915_wait_request.
- drm/i915: drop polled waits from i915_wait_request.
- drm/i915: kill waiting_seqno.
- drm/i915: move vbetool invoked ier stuff.
- commit f62d18e
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: remove do_retire from i915_wait_request.
- Refresh patches.xen/xen3-patch-2.6.29.
- commit f923eb6
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: use the new masked bit macro some more.
- drm/i915: Remove unused and unloved vblank macros.
- drm/i915: Inline I915_INTERRUPT_ENABLE_FIX.
- drm/i915: Handle PendingFlip on gen3 robustly.
- drm/i915: Cleanup gen3 irq uninstall.
- commit d32665d
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: HWSTAM is only 16-bit on gen3.
- drm/i915: Remove gen4 irq code from gen3 irq routine.
- drm/i915: Remove gen3 irq code from gen4 irq routine.
- drm/i915: Clear FlipDone semantics change for pageflipping
  on gen3.
- drm/i915: Duplicate and split the gen3/4 irq handler.
- drm/i915: pending_flip_is_done is gen3, name it so.
- drm/i915: Remove redundant initialisation of per-ring IRQ
  waitqueues.
- drm/i915: Unconditionally initialise the interrupt workers.
- drm/i915: check for kms in dri1 ioctls.
- commit ee05cac
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: rip out dev_priv->has_gem.
- drm/i915: rip out GEM drm feature checks.
- drm/i915: disallow gem ums init ioctl for kms.
- drm/i915: properly check for MODESET for kms driver ioctls.
- drm/i915: CR clock gating is recommend to be set on PineView.
- drm/i915: Move GEM initialisation from i915_dma.c to i915_gem.c.
- drm/i915: Split the stolen handling for GEM out of i915_dma.c.
- drm/i915: Remove the deferred-free list.
- drm/i915: Remove the list of pinned inactive objects.
- drm/i915: Remove i915_gem_evict_inactive().
- drm/i915: Bump the inactive LRU on set-to-GTT-domain.
- drm/i915: Remove too early plane enable on pre-PCH hardware.
- commit a922ff2
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: Use a global lock for modifying global irq flags.
- drm/i915: implement Disable4x2SubspanOptimization w/a for
  ivb, too.
- drm/i915: create macros to handle masked bits.
- drm/i915: manage PCH PLLs separately from pipes.
- drm/i915: i8xx interrupt handler.
- drm/i915: Only the zap the VMA after updating the tiling
  parameters.
- drm/i915: Clarify the semantics of tiling_changed.
- drm/i915: fixup tv load-detect on enabled but not active crtc.
- drm/i915: re-add static qualifier to get_cxsr_latency.
- drm/i915: __iomem fixes for gem.
- drm/i915: __iomem fixes for debugfs.
- drm/i915: __iomem fixes for overlay.
- drm/i915: __iomem fixes for opregion.
- drm/i915: Remove i915_gem_ringbuffer_(data|info) from debugfs.
- drm/i915/sprite: Avoid incurring extra vblank stall when
  updating plane on IVB.
- drm/i915: print computed bpp in dp link configuration.
- commit 62c0804
* Wed Feb 13 2013 msrb@novell.com
- drm/radeon: add connector table for SAM440ep embedded board.
- drm/radeon: avoid leaking const ib (not used yet on si and
  newer GPU).
- drm/radeon: Original Radeons had PCI GART, not PCIe GART.
- drm/radeon: remove cayman_gpu_is_lockup.
- drm/radeon: remove r300_gpu_is_lockup.
- drm/radeon: make forcing ring activity a common function.
- drm/radeon: unlock the ring mutex while waiting for the
  next fence.
- drm/radeon: make lockup timeout a module param.
- drm/radeon: move lockup detection code into radeon_ring.c.
- drm/radeon: rework recursive gpu reset handling.
- drm/radeon: fix a bug with the ring syncing code.
- drm/radeon: don't keep list of created fences.
- drm/radeon: rename fence_wait_last to fence_wait_empty.
- drm/radeon: return -ENOENT in fence_wait_next v2.
- drm/radeon: fix a bug in the SA code.
- drm/radeon: rework gpu lockup detection and processing.
- drm/radeon: use central function for IB testing.
- drm/radeon: register ring debugfs handlers on init.
- drm/radeon: replace gpu_lockup with ring->ready flag.
- drm/radeon: make radeon_gpu_is_lockup a per ring function.
- drm/kms: reduce some messages to debug level (v2).
- drm/radeon/kms/hdmi: use relative offsets, official regs.
- drm/radeon/kms: keep HDMI state in separated variable.
- drm/radeon/kms: get rid of r600_hdmi_find_free_block.
- drm/radeon/kms: get rid of hdmi_config_offset.
- drm/radeon/kms: move audio params to separated struct.
- radeon_cp: Remove unneeded tests for NULL before calling
  release_firmware().
- drm/edid: fix collision between two patches breaking build.
- drm: fixed: Add dfixed_frac.
- drm: Store vendor IDs directly in the EDID quirk structure.
- drm/edid: Try harder to fix up base EDID blocks.
- drm: Unify and fix idr error handling.
- drm/radeon/kms: fix up audio interrupt handling.
- drm/radeon/kms: add register definitions for audio.
- drm/radeon/kms: improve bpc handling (v2).
- drm/i915: rc6 residency (fix the fix).
- drm/i915/tv: fix open-coded ARRAY_SIZE.
- drm: replace open-coded ARRAY_SIZE with macro.
- drm: add DRM_MODE_FLAG_DBLCLK to CEA modes requiring it.
- drm: add the VIC number to the CEA EDID modes.
- drm: Parse color format information in CEA blocks.
- drm: Fix EDID color format parsing.
- drm: Add sanity checks to framebuffer creation.
- drm: Add drm_format_{horz, vert}_chroma_subsampling() utility
  functions.
- drm: Add drm_format_plane_cpp() utility function.
- drm: Move drm_format_num_planes() to drm_crtc.c.
- drm/i915: invalidate render cache on gen2.
- drm/i915: Silence the change of LVDS sync polarity.
- drm/i915: add generic power management initialization.
- drm/i915: move clock gating functionality into intel_pm module.
- drm/i915: move emon functionality into intel_pm module.
- commit fa7fa20
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: move drps, rps and rc6-related functions to intel_pm.
- Refresh patches.xen/xen3-drm-i915-load-a-ring-frequency-scaling-table-v3.
- commit 546bb1c
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: fix line breaks in intel_pm.
- commit 7822def
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: move watermarks settings into intel_pm module.
- drm/i915: move fbc-related functionality into intel_pm module.
- drm/i915: Refactor get_fence() to use the common fence writing
  routine.
- drm/i915: Refactor fence clearing to use the common fence
  writing routine.
- drm/i915: Refactor put_fence() to use the common fence writing
  routine.
- drm/i915: Prepare to consolidate fence writing.
- drm/i915: Remove the unsightly "optimisation" from
  flush_fence().
- drm/i915: Simplify fence finding.
- drm/i915: Discard the unused obj->last_fenced_ring.
- drm/i915: Remove unused ring->setup_seqno.
- drm/i915: Remove fence pipelining.
- drm/i915: Remove the pipelined parameter from get_fence().
- drm/i915: Wait for all pending operations to the fb before
  disabling the pipe.
- drm/i915: Don't set a MBZ bit in gen2/3 MI_FLUSH.
- commit d7bdb0d
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: intel_update_fbc() requires struct_mutex, so no
  longer atomic.
- drm/i915: Unpin the flip target if we fail to queue the flip.
- drm/i915: Replace open coded MI_BATCH_GTT.
- drm/i915: Always flush tiling changes before accessing through
  the GTT.
- drm/i915: don't use variable size arrays.
- drm/i915: trivial sparse fixes.
- commit 00b8ee3
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: IBX+ doesn't have separate vsync/hsync controls on
  the VGA DAC.
- drm/i915: Mask reserved bits in display/sprite address
  registers.
- drm/i915: disable rc6 on haswell for now.
- drm/i915: share IVB cursor routine with Haswell.
- drm/i915: haswell has 3 pipes as well.
- drm/i915: share forcewaking code between IVB and HSW.
- drm/i915: add WRPLL divider programming bits.
- drm/i915: add definition of LPT FDI port width registers.
- drm/i915: set stc evict disable lra evict w/a.
- drm/i915: implement w/a for incorrect guarband clipping.
- drm/i915: properly set ppgtt cacheability on snb.
- drm/i915: set w/a bit for snb pagefaults.
- drm/i915: implement a media hang w/a.
- drm/i915/sprite: Always enable the scaler on IronLake.
- drm/i915: Export the generic, not arch specific,
  intel_update_watermarks().
- radeon: Fix typo in radeon_gem.c.
- drm/i915: Refactor the deferred PM_IIR handling into a single
  function.
- drm/i915: don't pwrite tiled objects through the gtt.
- drm/i915: Trigger hangcheck if we detect more a repeating
  missed IRQ.
- drm/i915/intel_i2c: reduce verbosity of some messages.
- drm/i915/intel_i2c: handle zero-length reads.
- drm/i915: inline enable/disable_irq into ring->get/put_irq.
- drm/i915: don't set up gem ring functions on gen5 for !kms.
- drm/i915: consolidate ring->add_request a bit.
- drm/i915: split up ring->dispatch_execbuffer functions.
- drm/i915: don't enable the gen6 bsd ring tail write enable
  on gen7.
- drm/i915: split out the gen5 ring irq get/put functions.
- drm/i915: abstract away ring-specific irq_get/put.
- drm/i915: consolidate ring->sync-to functions.
- drm/i915: don't set up rings on gen6+ for non-kms.
- commit 81b59bb
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: dynamically set up blt ring functions and parameters.
- drm/i915: dynamically set up bsd ring functions and params.
- drm/i915: dynamically set up the render ring functions and
  params.
- drm/i915: set ring->size in common ring setup code.
- drm/i915: rip out ring->irq_mask.
- drm/i915: hide (seqno-1) in ringbuffer code.
- drm/i915: fix for when semaphore updates fail.
- drm/i915: i915_gem_object_sync must handle NULL.
- drm/i915: allow PCH PWM override on IVB.
- drm/i915: disable turbo on ValleyView for now.
- drm/i915: check PPS regs for sanity when using eDP.
- drm/i915: Allow concurrent read access between CPU and GPU
  domain.
- drm/i915: simplify ppgtt setup.
- drm/i915: make DP configuration vars less confusing in
  ironlake_crtc_mode_se.
- drm/i915: rc6 in sysfs.
- commit 4bc5d9d
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: Ironlake shares the same video sprite controls
  as Sandybridge.
- drm/i915/intel_i2c: remove POSTING_READ() from gmbus transfers.
- drm/i915/intel_i2c: reuse GMBUS2 value read in polling loop.
- drm/i915/intel_i2c: use INDEX cycles for i2c read transactions.
- drm/i915/intel_i2c: use WAIT cycle, not STOP.
- drm/i915/intel_i2c: always wait for IDLE before clearing NAK.
- drm/i915/intel_i2c: use double-buffered writes.
- drm/i915/intel_i2c: handle zero-length writes.
- commit 5d3efaa
* Wed Feb 13 2013 msrb@novell.com
- drm/i915: use register name when disabling VGA.
- drm/i915: use semaphores for the display plane.
- drm/i915: Reorganise rules for get_fence/put_fence.
- drm/i915: add rc6 residency times to debugfs.
- commit ea2a301
* Wed Feb 13 2013 msrb@novell.com
- agp: Use u32 __iomem annotation to silence sparse warning.
- Refresh patches.xen/xen3-patch-2.6.32.
- commit 168c532
* Wed Feb 13 2013 msrb@novell.com
- agp: Remove 'break' after 'return' statement.
- commit 9dcd4ca
* Wed Feb 13 2013 msrb@novell.com
- drm/radeon/kms: attempt to avoid copying data twice on coherent
  cards. (v3).
- drm/radeon: enable pci bus mastering after card is initialised
  (v2).
- drm/i915: VCS is not the last ring.
- drm/i915: Add a dual link lvds quirk for MacBook Pro 8,2.
- drm/i915: make quirks more verbose.
- drm/i915: dump the DMA fetch addr register on pre-gen6.
- drm/i915/sdvo: Include YRPB as an additional TV output type.
- drm/i915: disallow gem init ioctl on ilk.
- drm/i915: refuse to load on gen6+ without kms.
- drm/i915: extract gt interrupt handler.
- drm/i915: use render gen to switch ring irq functions.
- drm/i915: rip out old HWSTAM missed irq WA for vlv.
- drm/i915: open code gen6+ ring irqs.
- drm/i915: ring irq cleanups.
- drm/i915: add SFUSE_STRAP registers for digital port detection.
- drm/i915: add WM_LINETIME registers.
- drm/i915: add WRPLL clocks.
- drm/i915: add LCPLL control registers.
- drm/i915: add SSC offsets for SBI access.
- drm/i915: add port clock selection support for HSW.
- drm/i915: add S PLL control.
- drm/i915: add PIXCLK_GATE register.
- drm/i915: add SBI registers.
- drm/i915: add definition of DDI buffer translations regs.
- drm/i915: add definitions for DDI_BUF_CTL registers.
- drm/i915: add DP_TP_STATUS registers.
- drm/i915: add DP_TP_CTL registers.
- drm/i915: add DDI registers.
- drm/i915: add enumeration for DDI ports.
- drm/i915: add support for power wells.
- drm/i915: add support for LynxPoint PCH.
- drm/i915: add Haswell devices and their PCI IDs.
- drm/i915: transform HAS_PCH_SPLIT in a feature check.
- radeon: remove redundant ';' from radeon_vm_bo_update_pte().
- drm/i915: check for disabled interrupts on ValleyView.
- drm/i915: ValleyView IRQ support.
- drm/i915: interrupt bit definitions for VLV.
- drm/i915: add ValleyView specific force wake get/put functions.
- agp/intel: add ValleyView AGP driver.
- agp/intel: map more registers for use by the GTT code.
- drm/i915: Enable HDMI on ValleyView.
- drm/i915: program drain latency regs on ValleyView.
- drm/i915: add ValleyView clock gating init.
- drm/i915: add DPIO support.
- drm/i915: PLL defines for VLV.
- drm/i915: ValleyView watermark support.
- drm/i915: add ValleyView driver structs and IS_VALLEYVIEW macro.
- drm/i915: split PLL update code out of i9xx_crtc_mode_set.
- drm/i915: split LVDS update code out of i9xx_crtc_mode_set.
- drm/i915: Initialise GTT MTRR to -1.
- drm/i915/intel_i2c: allocate gmbus array as part of
  drm_i915_private.
- drm/i915/intel_i2c: gmbus disabled and reserved ports are
  invalid.
- drm/i915/intel_i2c: refactor using intel_gmbus_get_adapter.
- drm/i915/intel_i2c: use i2c pre/post_xfer functions to setup
  gpio xfers.
- drm/i915/intel_i2c: assign HDMI port D to pin pair 6.
- drm/i915/intel_i2c: cleanup error messages and comments.
- drm/i915/intel_i2c: refactor gmbus_xfer.
- drm/i915: mark pwrite/pread slowpaths with unlikely.
- drm/i915: fixup in-line clflushing on bit17 swizzled bos.
- mm: extend prefault helpers to fault in more than PAGE_SIZE.
- drm/i915: extract copy helpers from shmem_pread|pwrite.
- drm/i915: use uncached writes in pwrite.
- drm/i915: fall back to shmem pwrite when the buffer is not
  accessible.
- drm/i915: implement inline clflush for pwrite.
- drm/i915: don't clobber userspace memory before commiting to
  the pread.
- drm/i915: drop gtt slowpath.
- drm/i915: don't call shmem_read_mapping unnecessarily.
- drm/i915: don't use gtt_pwrite on LLC cached objects.
- drm/i915: kill ranged cpu read domain support.
- drm/i915: move clflushing into shmem_pread.
- drm: add helper to clflush a virtual address range.
- drm/i915: merge shmem_pread slow&fast-path.
- drm/i915: merge shmem_pwrite slow&fast-path.
- drm/i915: Avoid using mappable space for relocation processing
  through the CPU.
- drm/i915: clear the entire gtt when using gem.
- drm/i915: the intel gtt is _not_ an agp bridge!.
- drm/i915: s/i915_gem_do_init/i915_gem_init_global_gtt.
- drm/i915: Batch copy_from_user for relocation processing.
- drm/i915: enable gmbus on gen2.
- drm/i915: add an explict mmio base for gpio/gmbus io.
- drm/i915/sdov: switch IS_SDVOB to a flag.
- drm/i915: re-order GT IIR bit definitions.
- drm/i915: move NEEDS_FORCE_WAKE to i915_drv.c.
- drm/i915: Release the mmap offset when purging a buffer.
- drm/i915: shut up six instances of -Warray-bounds.
- drm/i915: shut up two instances -Wunitialized.
- drm/i915: add HAS_ALIASING_PPGTT parameter for userspace.
- drm/i915: enable lazy global-gtt binding.
- drm/i915: implement SNB workaround for lazy global gtt.
- drm/i915: bind objects to the global gtt only when needed.
- drm/i915: split out dma mapping from global gtt bind/unbind
  functions.
- i915: Add and use pr_fmt and pr_<level>.
- drm/i915: panel: invert brightness acer aspire 5734z.
- drm/i915: panel: invert brightness via quirk.
- drm/i915: panel: invert brightness via parameter.
- drm/i915: Add wait_for in init_ring_common.
- drm/i915: Don't do MTRR setup if PAT is enabled.
- drm/i915: Pull MTRR setup to its own function.
- drm/i915: Retry reading the PCH FDI receiver ISR.
- drm/i915: remove ACPI related DRM_ERRORs.
- i915: Add option to bypass vbt table.
- i2c algo bit.
- commit 109ce4e
* Wed Feb 13 2013 msrb@novell.com
- drm/nouveau/i2c: resume use of i2c-algo-bit, rather than
  custom stack.
- drm/i915: Do no set Stencil Cache eviction LRA w/a on gen7+.
- drm/i915: disable sdvo hotplug on i945g/gm.
- drm/radeon: clarify and extend wb setup on APUs and NI+ asics.
- drm/i915: enable dip before writing data on gen4.
- nouveau: initialise has_optimus variable.
- fixing dmi match for hp t5745 and hp st5747 thin client.
- drm/i915: Only enable IPS polling for gen5.
- drm/i915: Do not read non-existent DPLL registers on PCH
  hardware.
- drm/nv10/gpio: fix thinko in mask for gpio lines 2-9.
- nvc0/fb: shut up PMFB interrupt after the first occurrence.
- drm/nouveau/hdmi: use correct hdmi regs for nvaa/nvac.
- drm/nouveau/bios: fix regression on some nv4x board.
- drm/i915: Set the Stencil Cache eviction policy to non-LRA mode.
- drm/radeon/kms: need to set up ss on DP bridges as well.
- drm/radeon/kms: use frac fb div on APUs.
- drm/radeon: add a missing entry to encoder_names.
- drm/exynos: added missed vm area region mapping type.
- drm/exynos: fixed exynos_drm_gem_map_pages bug.
- drm/exynos: fixed duplicatd memory allocation bug.
- drm/i915: fixup load-detect on enabled, but not active pipe.
- nouveau: Set special lane map for the right chipset.
- drm: Releasing FBs before releasing GEM objects during
  drm_release.
- drm/nouveau/pm: don't read/write beyond end of stack buffer.
- radeon: fix r600/agp when vram is after AGP (v3).
- drm: fix page_flip error handling.
- drm/usb: fix module license on drm/usb layer.
- drm/i915: Do not set "Enable Panel Fitter" on SNB pageflips.
- drm/i915: Hold mode_config lock whilst changing mode for
  lastclose().
- drm/radeon/si: add missing radeon_bo_unreserve in si_rlc_init()
  v2.
- drm/i915: don't clobber the special upscaling lvds timings.
- drm/exynos: fixed exynos broken ioctl.
- drm/i915: clear fencing tracking state when retiring requests.
- drm/exynos: fix to pointer manager member of struct
  exynos_drm_subdrv.
- drm/exynos: fix struct for operation callback functions to
  driver name.
- drm/exynos: use define instead of default_win member in struct
  mixer_context.
- drm/exynos: rename s/HDMI_OVERLAY_NUMBER/MIXER_WIN_NR.
- drm/exynos: remove unused codes in hdmi and mixer.
- drm/exynos: remove unnecessary type conversion of hdmi and
  mixer.
- drm/i915: make rc6 module parameter read-only.
- drm/i915: implement ColorBlt w/a.
- Revert "drm/i915: reenable gmbus on gen3+ again".
- drm/i915: properly compute dp dithering for user-created modes.
- drm/radeon/kms: fix DVO setup on some r4xx chips.
- drm/radeon: replace udelay with mdelay for long timeouts.
- drm/i915: Finish any pending operations on the framebuffer
  before disabling.
- drm/i915: Removed IVB forced enable of sprite dest key.
- drm/exynos: add format list of plane.
- Revert "nouveau/bios: Fix tracking of BIOS image data".
- drm/exynos: fixed duplicated page allocation bug.
- drm/exynos: fixed page align and code clean.
- drm/i915: treat src w & h as fixed point in sprite handling
  code.
- drm/i915: don't leak struct_mutex lock on ppgtt init failures.
- drm/i915: disable ppgtt on snb when dmar is enabled.
- drm/radeon: Don't dereference possibly-NULL pointer.
- mm, drm/udl: fixup vma flags on mmap.
- nouveau/bios: Fix tracking of BIOS image data.
- nouveau: Fix crash when pci_ram_rom() returns a size of 0.
- drm/nouveau: select POWER_SUPPLY.
- drm/i915: properly clear SSC1 bit in the pch refclock init code.
- drm/i915: apply CS reg readback trick against missed IRQ on snb.
- drm/i915: enable plain RC6 on Sandy Bridge by default.
- drm/i915: allow to select rc6 modes via kernel parameter.
- drm/i915: Mark untiled BLT commands as fenced on gen2/3.
- drm/i915: properly restore the ppgtt page directory on resume.
- drm: base prime/dma-buf support (v5).
- drm/nouveau: inform userspace of relaxed kernel subchannel
  requirements.
- Revert "drm/nouveau: inform userspace of new kernel subchannel
  requirements".
- drm/nouveau: oops, create m2mf for nvd9 too.
- drm/radeon: Only warn if the intra-domain offset actually
  exceeds the limit.
- drm/radeon/kms: add htile support to the cs checker v3.
- drm/radeon/kms/atom: force bpc to 8 for now.
- drm/nouveau/i2c: fix thinko/regression on really old chipsets.
- drm/nouveau: default to 8bpc for non-LVDS panels if EDID
  isn't useful.
- drm/nouveau: fix thinko causing init to fail on cards without
  accel.
- dma-buf: correct dummy function declarations.
- dma-buf: document fd flags and O_CLOEXEC requirement.
- dma_buf: Add documentation for the new cpu access support.
- dma-buf: add support for kernel cpu access.
- dma-buf: don't hold the mutex around map/unmap calls.
- dma-buf: add get_dma_buf().
- dma-buf: pass flags into dma_buf_fd.
- dma-buf: add dma_data_direction to unmap dma_buf_op.
- headers: include linux/types.h where appropriate.
- drm/nouveau/dp: support version 4.0 of DP table.
- drm/nve0/disp: nvidia randomly decided to move the dithering
  method.
- drm/nve0: initial modesetting support for kepler chipsets.
- drm/nouveau: add bios connector type for dms59.
- drm/nouveau: move out of staging drivers.
- drm/nouveau: bump version to 1.0.0.
- drm/nvd0/disp: ignore clock set if no pclk.
- drm/nouveau: oops, increase channel dispc_vma to 4.
- drm/nouveau: inform userspace of new kernel subchannel
  requirements.
- drm/nouveau: remove m2mf creation on userspace channels.
- drm/nvc0-/disp: reimplement flip completion method as fifo
  method.
- drm/nouveau: move fence sequence check to start of loop.
- drm/nouveau: remove subchannel names from places where it
  doesn't matter.
- drm/nouveau/ttm: always do buffer moves on kernel channel.
- drm/i915: use DDC_ADDR instead of hard-coding it.
- drm/radeon: use DDC_ADDR instead of hard-coding it.
- drm: remove unneeded redefinition of DDC_ADDR.
- drm/exynos: added virtual display driver.
- drm/radeon/kms: update duallink checks for DCE6.
- drm/radeon/kms: add trinity pci ids.
- drm/radeon/kms: add radeon_asic struct for trinity.
- drm/radeon/kms: add support for ucode loading on trinity (v2).
- drm/radeon/kms/vm: set vram base offset properly for TN.
- drm/radeon/kms: Update evergreen functions for trinity.
- drm/radeon/kms: cayman gpu init updates for trinity.
- drm/radeon/kms: Add checks for TN in the DP bridge code.
- drm/radeon/kms/DCE6.1: ss is not supported on the internal
  pplls.
- drm/radeon/kms: disable PPLL0 on DCE6.1 when not in use.
- drm/radeon/kms: Adjust pll picker for DCE6.1.
- drm/radeon/kms: DCE6.1 disp eng pll updates.
- drm/radeon/kms: DCE6.1 watermark updates for TN.
- drm/radeon/kms: no support for internal thermal sensor on
  TN yet.
- drm/radeon/kms: add trinity (TN) chip family.
- drm/radeon/kms: Add SI pci ids.
- drm/radeon: Update radeon_info_ioctl for SI. (v2).
- drm/radeon/kms: add radeon_asic struct for SI.
- drm/radeon/kms: add support for compute rings in CS ioctl on SI.
- drm/radeon/kms: fill in startup/shutdown callbacks for SI.
- drm/radeon/kms: add support for interrupts on SI.
- drm/radeon/kms: Add support for RLC init on SI.
- drm/radeon/kms: add IB and fence dispatch functions for SI.
- drm/radeon/kms: add support for CP setup on SI.
- drm/radeon/kms: add support for MC ucode loading on SI.
- drm/radeon/kms: add ucode loading for SI.
- drm/radeon/kms: Only VM CS ioctl is supported on SI (v2).
- drm/radeon/kms: add VM CS checker for SI.
- drm/radeon/kms: add support for the CONST IB to the CS ioctl.
- drm/radeon/kms: add support for MC/VM setup on SI.
- drm/radeon/kms: Add support for SI GPU reset.
- drm/radeon/kms: add gpu init support for SI.
- drm/radeon/kms: add support for internal thermal sensor on SI.
- drm/radeon/kms: update power table parsing for SI.
- drm/radeon/kms/atom: add support for SI SetVoltage table.
- drm/radeon/kms: update comments about dig encoders/transmitters.
- drm/radeon/kms: DP aux updates for DCE6.
- drm/radeon/kms/atom: add support for DCE6.x dig transmitters.
- drm/radeon/kms: DCE6 disp eng pll updates.
- drm/radeon/kms/atom: add support for crtc power gating.
- drm/radeon/kms/atom: DCE6 no longer has crtcmemreq bits.
- drm/radeon/kms: fix up atom HPD gpio parsing for DCE6.
- drm/radeon/kms: add initial DCE6 display watermark support.
- drm/radeon/kms: add SI chip families.
- drm/radeon/kms: upstream power table updates.
- drm/radeon/kms: upstream atombios.h updates.
- drm/radeon/kms: Upstream ObjectID.h updates.
- drm/radeon/kms: add info query for max pipes.
- drm: remove the second argument of kmap_atomic().
- drm: allow loading an EDID as firmware to override broken
  monitor.
- drm/exynos: enable hdmi audio feature.
- drm/exynos: add default pixel format for plane.
- drm/exynos: cleanup exynos_hdmi.h.
- drm/exynos: add is_local member in exynos_drm_subdrv struct.
- drm/exynos: add subdrv open/close functions.
- drm/exynos: remove module of exynos drm subdrv.
- drm/exynos: release pending pageflip events when closed.
- drm/exynos: added new funtion to get/put dma address.
- drm/exynos: update gem and buffer framework.
- drm/exynos: added mode_fixup feature and code clean.
- drm/exynos: add HDMI version 1.4 support.
- drm/exynos: remove exynos_mixer.h.
- drm/radeon: Drop radeon_gem_object_(un)pin.
- drm/radeon: Restrict offset for legacy display engine.
- drm/radeon/kms: reduce probe latency on digital connectors.
- commit c7a3646
* Wed Feb 13 2013 msrb@novell.com
- drm/ttm: Use pr_fmt and pr_<level>.
- Refresh patches.xen/xen3-patch-2.6.35.
- commit d7f80d0
* Wed Feb 13 2013 msrb@novell.com
- drivers/gpu/drm/savage/savage_state.c: add missing kfree.
- drivers/gpu/drm/radeon/radeon_cs.c: eliminate possible double
  free.
- drm/radeon: dp only enable enhanced framing if sink supports.
- drm/radeon/kms: skip db/cb/streamout checking when possible
  on r600.
- drm/radeon/kms: compute GPU addresses correctly on r600.
- drm/radeon/kms: remove some unused variables in
  evergreen_cs_track.
- drm/radeon/kms: skip db/cb/streamout checking when possible
  on evergreen.
- drm/radeon/kms: optimize streamout checking for evergreen.
- drm/radeon/kms: compute GPU addresses correctly on evergreen.
- drm/radeon/kms: make some DRM errors more informative.
- drm/radeon/kms: skip cb/db checking if SX_MISC is 1 on r600+.
- drm/usb: move usb support into a separate module.
- dma-buf: Constify ops argument to dma_buf_export().
- drm: fix build with UDL if USB is a module.
- drm/udl: initial UDL driver (v4).
- drm: add core support for unplugging a device (v2).
- drm/modeset: add helper to unplug all connectors from sysfs.
- drm/sysfs: protect sysfs removal code against being run twice.
- drm: Add drm_mode_copy().
- drm: Use a flexible array member for blob property data.
- drm: Handle drm_object_get() failures.
- drm: Make drm_crtc_convert_{umode, to_umode} static and constify
  their params.
- drm: Fix drm_mode_attachmode_crtc().
- drm: Check CRTC viewport against framebuffer size.
- drm: Check user mode against overflows.
- drm: Fix memory leak in drm_mode_setcrtc().
- drm: Make drm_mode_attachmode() void.
- drm: Check crtc x and y coordinates.
- drm: Warn if mode to umode conversion overflows the destination
  types.
- drm: Change drm_display_mode::type to unsigned.
- drm: Reject mode set with current fb if no current fb is bound.
- drm/nouveau: add userspace fallback hints.
- drm/nouveau: map first page of mmio early and determine
  chipset earlier.
- drm/nvd0/disp: disconnect encoders before reprogramming them.
- drm/nvd0/disp: move syncs/magic setup to or mode_set.
- drm/nouveau/dp: account for channel coding overhead in link
  training.
- drm/nvd0/disp: fix dcb sor link matching in supervisor handler.
- drm/nvd0/disp: initial implementation of displayport.
- drm/nouveau/dp: make dp dpms function common, call from sor
  code instead.
- drm/nv50/hwsq: some nv92 fixes.
- drm/nouveau/dp: move all nv50/sor-specific code out of
  nouveau_dp.c.
- drm/nouveau/dp: make functions for executing various bios
  tables.
- drm/nouveau/pm: fix oops if chipset has no pm support at all.
- drm/nouveau/bios: rework vbios shadowing.
- drm/nouveau/bios: attempt acpi rom fetch before pcirom.
- drm/nvd0/disp: attempt to handle more than 2 crtcs if possible.
- drm/nvc0/vram: get part count from PUNITS.
- drm/nv40/pm: fix fanspeed regression.
- drm/nouveau/pm: several fixes for nvc0 memory timings.
- drm/nvc0/pm: restrict pll mode to clocks that can actually
  use it.
- drm/nouveau/dp: fix bad comparison in dp_link_train_commit().
- commit 567c5e5
* Wed Feb 13 2013 jdelvare@suse.de
- patches.drivers/Intel-Centerton-03-sch_gpio.patch: Add GPIO
  support for Intel Centerton SOC  (bnc#792793).
- commit 7d5cb66
* Wed Feb 13 2013 jdelvare@suse.de
- patches.drivers/Intel-Centerton-02-mfd-lpc_sch.patch:
  Add Multifunction Device support for Intel Centerton SOC
  (bnc#792793).
- commit 403f371
* Wed Feb 13 2013 jdelvare@suse.de
- patches.drivers/Intel-Centerton-01-pci_ids.patch: Add Intel
  Legacy Block support for Intel Centerton SOC  (bnc#792793).
- commit 7a35755
* Tue Feb 12 2013 msrb@novell.com
- drm/nouveau/mxm: call mxmi to determine revision before
  calling mxms.
- drm/nouveau/pm: init only after display subsystem has been
  created.
- drm/nvc0/fb: detect presense of second rank.
- drm/nv50/display: expose color vibrance control.
- drm/nv50-nvc0/vm: support unsnooped system memory.
- drm/nouveau: recognise DCB connector type for DP+DVI+VGA DMS-59.
- drm/nouveau/mem: handle dll_off for ddr2/ddr3.
- drm/nouveau/pm: extend profile interface for destroy/init/fini.
- drm/nouveau/pm: rework to allow selecting separate profiles
  for ac/battery.
- drm/nouveau/pm: fix dll off -> dll on transitions.
- drm/nouveau/pm: detect when we need dll disabled for gddr3.
- drm/nv50: fix detection of second vram rank.
- drm/nouveau/pm: track mr2 for gddr3.
- drm/nv50/pm: wait for all fifo-connected engines to idle
  before reclocking.
- drm/nv50/pm: use hwsq for engine reclocking too.
- drm/nv50/disp: more accurate function to determine active crtcs.
- drm/nv50/pm: initial work towards proper memory reclocking,
  with timings.
- drm/nouveau/pm: introduce ram reclocking helper.
- drm/nouveau/pm: embed timings into perflvl structs.
- drm/nouveau/pm: calculate memory timings at perflvl creation
  time.
- drm/nouveau/pm: readback boot perflvl *before* parsing vbios.
- drm/nouveau/pm: implement DDR2/DDR3/GDDR3/GDDR5 MR generation
  and validation.
- drm/nouveau/pm: restructure bios table parsing.
- drm/nouveau/pm: avoid potential divide-by-zero.
- drm/nouveau: Fix module parameter description formats.
- drm/nouveau/pm: improve memory timing generation.
- drm/nouveau/pm: improve the reclocking logs' readability.
- drm/nouveau: move pwm_divisor to the nouveau_pm_fan struct.
- drm/nouveau/pm: restore fan speed after suspend.
- drm/nouveau/pm: style fixes.
- drm/nouveau: rework the init/takedown ordering.
- drm/nvc0: add initial memory type detection.
- drm/nv50: hopefully handle the DDR2/DDR3 memtype detection
  somewhat better.
- drm/nv50: add memory type detection.
- drm/nv20-nv40: add memory type detection.
- drm/nv20: split PFB code out of nv10_fb.c.
- drm/nouveau: memory type detection for the really old chipsets.
- drm/nouveau: move vram detection funcs to chipset-specific
  fb code.
- drm: cope with platformdev->id == -1.
- drm: drop setting vm_file to filp.
- drm/i915: reenable gmbus on gen3+ again.
- drm/i915: i2c: unconditionally set up gpio fallback.
- drm/i915: merge gmbus and gpio i2c adpater into one.
- drm/i915: merge struct intel_gpio into struct intel_gmbus.
- drm/nouveau: do a better job at hiding the NIH i2c bit-banging
  algo.
- drm/i915: add dev_priv to intel_gmbus.
- drm/i915: Fix single msg gmbus_xfers writes.
- drm/radeon: fix deferred page-flip detection logic on
  Avivo-based ASICs.
- drm: remove unused code.
- drm/radeon/kms: clean up radeon_asic struct (v2).
- drm/radeon/kms: reorganize surface callbacks.
- drm/radeon/kms: move clock/pcie setting callbacks into pm
  struct.
- drm/radeon/kms: reorganize display callbacks.
- drm/radeon/kms: reorganize gart callbacks.
- drm/radeon/kms: make ring_start, ring_test, and ib_test
  per ring.
- drm/radeon/kms: remove unused cp callbacks from radeon_asic.
- drm/radeon/kms: reorganize irq callbacks.
- drm/radeon/kms: reorganize copy callbacks.
- drm/radeon: fix IB debugfs files for multiple cards.
- drm/radeon: also make the cs_parse function per ring.
- drm/radeon/kms: no need to align IB like this.
- drm/radeon: move ring syncing after bo validation.
- drm/i915: error_buffer->ring should be signed.
- drm/i915: Silence the error message from i915_wait_request().
- drm/i915: use the new hdmi_force_audio enum more.
- drm/i915: No need to search again after retiring requests.
- drm/i915: Only bump refcnt on objects scheduled for eviction.
- drm/radeon/kms: reorganize pm callbacks.
- drm/radeon/kms: reorganize page flip callbacks.
- drm/radeon/kms: reorganize hpd callbacks.
- drm/radeon/kms: add a radeon asic callback for mc idle.
- drm/radeon/kms: add wait_for_vblank asic callback.
- drm/i915/bios: Downgrade the "signature missing" DRM_ERROR
  to debug.
- drm/i915: Ignore LVDS on hp t5745 and hp st5747 thin client.
- drm/i915: Fixes distorted external screen image on HP 2730p.
- Merge remote-tracking branch 'airlied/drm-next' into
  for-airlied.
- drm: add some caps for userspace to discover more info for
  dumb KMS driver (v2).
- Revert "drivers/gpu/drm/i915/intel_overlay.c needs seq_file.h".
- drm/radeon/evergreen: make texdw array larger.
- drm/i915/lvds: Always use the presence pin for LVDS on PCH.
- drm/i915: Record the position of the request upon error.
- drm/i915: Record the in-flight requests at the time of a hang.
- drm/i915: Record the tail at each request and use it to estimate
  the head.
- drm/i915: add missing SDVO bits for interlaced modes on ILK.
- drm/i915: Fix race condition in accessing GMBUS.
- drm/i915: add a "force-dvi" HDMI audio mode.
- drm/i915: Don't lock panel registers when downclocking.
- drm/radeon: add support for evergreen/ni tiling informations
  v11.
- drm/radeon/kms: add support for streamout v7.
- drm: Fix kcalloc parameters swapped.
- drm/vmwgfx: Bump driver minor.
- vmwgfx: Move function declaration to correct header.
- drm/vmwgfx: Treat out-of-range initial width and height as
  host errors.
- vmwgfx: Pick up the initial size from the width and height regs.
- vmwgfx: Add page flip support.
- vmwgfx: Pipe fence out of screen object dirty functions.
- vmwgfx: Make it possible to get fence from execbuf.
- vmwgfx: Clean up pending event references to struct drm_file
  objects on close.
- vmwgfx: Rework fence event action.
- drm/modes: do not enforce an odd vtotal for interlaced modes.
- drm/i915: fix up locking inconsistency around gem_do_init.
- drm/i915: enable forcewake voodoo also for gen6.
- drm/i915: fixup seqno allocation logic for lazy_request.
- drm/i915: outstanding_lazy_request is a u32.
- drm/i915: check gtfifodbg after possibly failed writes.
- drm/i915: catch gtfifo errors on forcewake_put.
- drm/i915: use gtfifodbg.
- drm/i915: set interlaced bits for TRANSCONF.
- drm/i915: fixup overlay checks for interlaced modes.
- drm/i915: allow interlaced mode output on the HDMI connector.
- drm/i915: allow interlaced mode output on the SDVO connector.
- drm/i915: correctly program the VSYNCSHIFT register.
- drm/i915: don't allow interlaced pipeconf on gen2.
- drm/i915: fixup interlaced support on ilk+.
- drm/i915: fixup interlaced vertical timings confusion, part 2.
- drm/i915: fixup interlaced vertical timings confusion, part 1.
- drm/i915: clean up interlaced pipeconf bit definitions.
- drm/i915: enable ppgtt.
- drm/i915: ppgtt debugfs info.
- drm/i915: ppgtt register definitions.
- drm/i915: ppgtt binding/unbinding support.
- drm/i915: initialization/teardown for the aliasing ppgtt.
- agp/intel-gtt: export the gtt pagetable iomapping.
- agp/intel-gtt: export the scratch page dma address.
- drm/i915: dump even more into the error_state.
- drm: do not set fb_info->pixmap fields.
- drm: add convenience function to create an range property.
- drm: add convenience function to create an enum property.
- drm/i915: s/DRM_ERROR/DRM_DEBUG in i915_gem_execbuffer.c.
- drm/i915: add gen6+ registers to i915_swizzle_info.
- drm/i915: consolidate swizzling control bit frobbing.
- drm/i915: swizzling support for snb/ivb.
- drm: Fix typo in rv515.c.
- drm: Fix typo in vmwgfx_drv.c.
- drm crtc_helper: use list_for_each_entry.
- drm crtc: Fix locking comments.
- drm fb helper: remove unused variable crtc_id.
- drm fb helper: remove unused variable conn_limit.
- drm fb helper: use drm_helper_connector_dpms to do dpms.
- drm: add proper return value for drm_mode_crtc_set_gamma_size.
- drm drm_fb_helper: destroy modes.
- drm crtc: use drm_mode_destroy instead of kfree in
  drm_mode_remove.
- drm/edid: drm modes have to be free with drm_mode_destroy.
- drm crtc: add forgotten idr cleanup functions.
- drm/radeon/kms: add r1xx/r2xx CS support for tiled textures.
- drm/radeon/kms: add r1xx/r2xx support for CS_KEEP_TILING_FLAGS.
- drm: give up on edid retries when i2c bus is not responding.
- drm/radeon/kms/dce3+: add support for hw i2c using atom.
- drm/radeon/kms: Use the standard VESA timeout for DDC channels.
- drm/kms: Make i2c buses faster.
- drm/radeon/kms: remove benchmarks shorter than one page.
- drm/radeon/kms: common definitions for blit copy code.
- drm: remove master fd restriction on mode setting getters.
- drm/i915: Handle unmappable buffers during error state capture.
- drm/i915: rewrite shmem_pread_slow to use copy_to_user.
- drm/i915: rewrite shmem_pwrite_slow to use copy_from_user.
- drm/i915: fall through pwrite_gtt_slow to the shmem slow path.
- drm/i915: add debugfs file for swizzling information.
- drm/i915: fix swizzle detection for gen3.
- drm/i915: Remove the upper limit on the bo size for mapping
  into the CPU domain.
- drm/i915: add per-ring fault reg to error_state.
- drm/i915: reject GTT domain in relocations.
- drm/i915: remove the i915_batchbuffer_info debugfs file.
- drm/i915: capture error_state also for stuck rings.
- drm/i915: refactor debugfs create functions.
- drm/i915: refactor debugfs open function.
- drm/i915: don't trash the gtt when running out of fences.
- drm/i915: Separate fence pin counting from normal bind pin
  counting.
- drm/i915/ringbuffer: kill snb blt workaround.
- drm/i915: collect more per ring error state.
- drm/i915: refactor ring error state capture to use arrays.
- drm/i915: switch ring->id to be a real id.
- drm/i915: correct lock type in destroy.
- drm/i915: drm/i915: Fix recursive calls to unmap.
- commit 23ad04d
* Tue Feb 12 2013 msrb@novell.com
- drm/i915: argument to control retiring behavior.
- Refresh patches.xen/xen3-patch-2.6.29.
- commit 02ef6cb
* Tue Feb 12 2013 msrb@novell.com
- drm/i915: Correct the bit number for the MI_FLUSH_ENABLE.
- commit 631801c
* Tue Feb 12 2013 msrb@novell.com
- drm/i915: Remove the MI_FLUSH_ENABLE setting.
- commit 314c96c
* Tue Feb 12 2013 msrb@novell.com
- drm/i915: fixup assert_pipe to take the pipe A quirk into
  account.
- drm/i915: print out which pixel format we do not support.
- drm/i915: properly mask and or watermark values for sprites.
- drm/i915: clarify gen2 pageflip cmd.
- drm/i915: add a LLC feature flag in device description.
- commit c78012b
* Tue Feb 12 2013 msrb@novell.com
- drm/i915: kill i915_mem.c.
- drm/i915: Use kcalloc instead of kzalloc to allocate array.
- drm/i915/dp: Check for AUXCH error before checking for success.
- drm/i915/dp: Use auxch precharge value of 5 everywhere.
- drm/i915/dp: Tweak auxch clock divider for PCH.
- commit 5db2317
* Tue Feb 12 2013 msrb@novell.com
- drm/i915: Remove a comment about PCH from the non-PCH path.
- drm/i915: Fix assert_pch_hdmi_disabled to mention HDMI (not DP).
- drm/i915: Implement plane-disabled assertion for PCH too.
- drivers: i915: Fix BLC PWM register setup.
- drm/i915: Check that plane/pipe is disabled before removing
  the fb.
- drm/i915: fix typo in function name.
- drm/i915: split out pll divider code.
- drm/i915: split 9xx refclk & sdvo tv code out.
- agp/intel: Add pci id for hostbridge from has/qemu.
- drm/i915: there is no pipe CxSR on ironlake.
- drm/i915: Only look for matching clocks for LVDS downclock.
- drm/i915: Silence _DSM errors.
- commit 8a19397
* Tue Feb 12 2013 msrb@novell.com
- drm exynos: use drm_fb_helper_set_par directly.
- drm/exynos: Fix fb_videomode <-> drm_mode_modeinfo conversion.
- drm/exynos: fix runtime_pm fimd device state on probe.
- drm/exynos: use correct 'exynos-drm' name for platform device.
- drm/radeon/kms: fix hdmi duallink checks.
- drm/i915: support 32 bit BGR formats in sprite planes.
- drm/i915: fix color order for BGR formats on SNB.
- drm/radeon: deal with errors from framebuffer init path.
- drm/radeon: fix a semaphore deadlock on pre cayman asics.
- drm/radeon/kms/vm: fix possible bug in radeon_vm_bo_rmv().
- drm/radeon: fix uninitialized variable.
- drm/radeon/kms: fix radeon_dp_get_modes for LVDS bridges (v2).
- drm/i915: Remove use of the autoreported ringbuffer HEAD
  position.
- drm/i915: fix a sprite watermark computation to avoid divide
  by zero if xpos<0.
- drm/i915: fix mode set on load pipe. (v2).
- drm/radeon/kms/atom: dpms bios scratch reg updates.
- drm/radeon/kms: properly set accel working flag and bailout
  when false.
- drm/radeon: Only create additional ring debugfs files on Cayman
  or newer.
- drm/exynos: exynos_drm.h header file fixes.
- drm/exynos: added panel physical size.
- drm/exynos: added postclose to release resource.
- drm/exynos: removed exynos_drm_fbdev_recreate function.
- drm/exynos: fixed page flip issue.
- drm/exynos: added possible_clones setup function.
- drm/exynos: removed pageflip_event_list init code when closed.
- drm/exynos: changed priority of mixer layers.
- drm/exynos: Fix typo in exynos_mixer.c.
- drm/radeon/kms/atom: bios scratch reg handling updates.
- drm/radeon/kms: drop lock in return path of
  radeon_fence_count_emitted.
- drm/i915: fixup interlaced bits clearing in PIPECONF on
  PCH_SPLIT (v2).
- drm/radeon: do not continue after error from r600_ib_test.
- drivers/gpu/drm/drm_ioc32.c: initialize all fields.
- drm/radeon/kms/blit: fix blit copy for very large buffers.
- drm/radeon/kms: fix TRAVIS panel setup.
- drm/radeon: fix use after free in ATRM bios reading code.
- drm/radeon/kms: Fix device tree linkage of DP i2c buses too.
- drm/nv50/pm: signedness bug in nv50_pm_clocks_pre().
- drm/nouveau: fix typo on mxmdcb option.
- drm/nouveau/mxm: pretend to succeed, even if we can't shadow
  the MXM-SIS.
- drm/nouveau/disp: check that panel power gpio is enabled at
  init time.
- commit b20d52f
* Tue Feb 12 2013 msrb@novell.com
- staging: delete gma500 driver.
- Refresh patches.drivers/mei_move_to_misc.patch.
- commit 931abc3
* Tue Feb 12 2013 msrb@novell.com
- drm/radeon/kms: Fix device tree linkage of i2c buses.
- drm: Pass the real error code back during GEM bo initialisation.
- Revert "drm/i810: cleanup reclaim_buffers".
- drm/i915:: Disable FBC on SandyBridge.
- drm/exynos: fixed pm feature for fimd module.
- drm/exynos: fixed build dependency for DRM_EXYNOS_FIMD.
- drm/exynos: fix build dependency for DRM_EXYNOS_HDMI.
- drm/exynos: use release_mem_region instead of release_resource.
- drm/ttm: fix two regressions since move_notify changes.
- drm/i915: fixup forcewake spinlock fallout in drpc debugfs
  function.
- drm/radeon: avoid deadlock if GPU lockup is detected in
  ib_pool_get.
- drm/radeon: silence out possible lock dependency warning.
- drm/i915: debugfs: show semaphore registers also on gen7.
- drm/i915: Correct debugfs printout for RC1e.
- drm/radeon/kms: refine TMDS dual link checks.
- drm/radeon/kms: use drm_detect_hdmi_monitor for picking
  encoder mode.
- drm/radeon/kms: rework modeset sequence for DCE41 and DCE5.
- drm/radeon/kms: move panel mode setup into encoder mode set.
- drm/radeon/kms: move disp eng pll setup to init path.
- drm/radeon: finish getting bios earlier.
- drm/radeon: fix invalid memory access in radeon_atrm_get_bios().
- drm/radeon/kms: add some missing semaphore init.
- gpu, drm, sis: Don't return uninitialized variable from
  sis_driver_load().
- Revert "drm/i915: Work around gen7 BLT ring synchronization
  issues.".
- drm/i915: sprite init failure on pre-SNB is not a failure.
- nouveau: Support Optimus models for vga_switcheroo.
- dma-buf: Documentation update for Kconfig select.
- nouveau: properly check for _DSM function support.
- radeon: Call pci_clear_master() instead of open-coding it.
- drm: bump DRM_CONNECTOR_MAX_ENCODER from 2 to 3.
- drm/radeon/kms: Fix module parameter description format.
- drm/radeon/kms/ni: fix packet2 handling for VM IB parser.
- ttm/dma: Remove the WARN() which is not useful.
- module_param: make bool parameters really bool (drivers & misc).
- drm/i915: Add Clientron E830 to the ignore LVDS list.
- CHROMIUM: i915: Add DMI override to skip CRT initialization
  on ZGB.
- drm/nouveau/pm: fix build with HWMON off.
- drm/ttm: fix condition (and vs or).
- drm/i915: Print debugfs object list sizes in KiB instead
  of bytes.
- drm/radeon: double lock typo in radeon_vm_bo_rmv().
- drm/radeon: use after free in radeon_vm_bo_add().
- drm/sis|via: don't return stack garbage from free_mem ioctl.
- drm/radeon/kms: remove pointless CS flags priority struct.
- drm/radeon/kms: check if vm is supported in VA ioctl.
- drm/i915: Removing TV Out modes.
- dma-buf: Documentation for buffer sharing framework.
- dma-buf: Introduce dma buffer sharing mechanism.
- drm: introduce drm_can_sleep and use in intel/radeon
  drivers. (v2).
- ttm: fix agp since ttm tt rework.
- agp: Fix multi-line warning message whitespace.
- drm/ttm/dma: Fix accounting error when calling
  ttm_mem_global_free_page and don't try to free freed pages.
- drm/ttm/dma: Only call set_pages_array_wb when the page is
  not in WB pool.
- drm/radeon/kms: sync across multiple rings when doing bo
  moves v3.
- drm/radeon/kms: Add support for multi-ring sync in CS ioctl
  (v2).
- drm/radeon: GPU virtual memory support v22.
- drm: make DRM_UNLOCKED ioctls with their own mutex.
- drm: no need to hold global mutex for static data.
- drm/radeon/benchmark: common modes sweep ignores 640x480@32.
- drm/radeon: allocate semaphore from the ib pool.
- drm/radeon: make ib size variable.
- drm/radeon/kms: add missing ring ready check in sync tests.
- drm: add support for private planes.
- drm: disconnect plane from fb/crtc when disabled.
- drm/i915: Work around gen7 BLT ring synchronization issues.
- drm/i915: add color key support v4.
- drm/i915: track sprite coverage and disable primary plane
  if possible.
- drm/i915: add SNB and IVB video sprite support v6.
- drm/i915: drpc debugfs update for gen6.
- drm/radeon/kms: define TMDS/LVTM HDMI enabling bits.
- drm/radeon/kms: setup HDMI mode on Evergreen encoders.
- drm/exynos: added hdmi display support.
- drm/exynos: added mutex lock and code clean.
- drm/exynos: extend vblank off delay time.
- drm/exynos: change driver name.
- drm/exynos: Support multi buffers.
- drm: Add multi buffer plane pixel formats.
- drm/exynos: added pm support.
- drm/exynos: remove buffer creation of fbdev from drm framebuffer
  creation.
- drm/exynos: Split creation of gem object and gem handle.
- drm/exynos: Fix a fake mmap offset creation.
- drm/exynos: gem code cleanup.
- drm: add missing exports for i810 driver.
- drm/i810: don't acces hw regs in lastclose.
- drm/i810: cleanup reclaim_buffers.
- drm/nouveau/ttm: fix crash as a result of a recent ttm change.
- drm: kill drm_sman.
- drm/sis: use drm_mm instead of drm_sman.
- drm/via: use drm_mm instead of drm_sman.
- drm/sman: kill user_hash_tab.
- drm/sis: track user->memblock mapping with idr.
- drm/via: track user->memblock mapping with idr.
- drm/sman: rip out owner tracking.
- drm/sman: kill owner tracking interface functions.
- commit bab22a6
* Tue Feb 12 2013 tiwai@suse.de
- patches.drivers/alsa-sp3-pre-693-Apply-mic-mute-LED-fixup-for-new-HP-laptops:
  ALSA: hda - Apply mic-mute LED fixup for new HP laptops
  (bnc#796418).
- commit 5794dec
* Tue Feb 12 2013 msrb@novell.com
- drm/via: track obj->drm_fd relations in the driver.
- drm/sis: track obj->drm_fd relations in the driver.
- drm/nouveau: Fix notifier blocks over the 4GB mark.
- drm/nouveau: Fix pushbufs over the 4GB mark.
- drm/nvc0/pm: initial engine reclocking.
- drm/nouveau: move hpd enable/disable to common code.
- drm/nv40/disp: implement support for hotplug irq.
- drm/nouveau/gpio: reimplement as nouveau_gpio.c, fixing a
  number of issues.
- drm/nouveau: just pass gpio line to pwm_*, not entire gpio
  struct.
- drm/nouveau/hwsq: remove some magic, give proper opcode names.
- drm/nv50/pm: introduce hwsq-based memory reclocking.
- drm/nv04/disp: handle dual-link spwg panels without needing
  quirks.
- drm/nouveau/dp: remove broken display depth function, use the
  improved one.
- drm/nouveau/mxm: implement ROM shadow method.
- drm/nouveau/mxm: implement _DSM shadow method.
- drm/nouveau/mxm: implement wmi shadow method.
- drm/nouveau/mxm: initial implementation of dcb sanitisation.
- drm/nouveau/disp: parse connector info directly in
  nouveau_connector.c.
- drm/nouveau/i2c: handle bit-banging ourselves.
- drm/nouveau/i2c: fix debug message.
- drm/nouveau/i2c: tidy up bit-bang helpers, also fixing nv50
  setsda bug.
- drm/nouveau/i2c: do parsing of i2c-related vbios info in
  nouveau_i2c.c.
- drm/nouveau/bios: start refactoring dcb routines.
- drm/nouveau/bios: fold fixup_legacy_i2c.
- drm/nouveau/bios: pass drm_device to ROMPTR, rather than nvbios.
- drm/nvd0/disp: use single, shared, sync bo for all evo channels.
- drm/nvd0/disp: rename sync channel to flip channel.
- drm/nvd0/disp: handle yet another interrupt.
- drm/nvd0/disp: initialise overlay channels.
- drm/nvd0/disp: add support for page flipping.
- drm/nvd0/disp: make it clearer that the cursor regs are pio
  evo channels.
- drm/nvd0/disp: have evo names now, use them.
- drm/nvd0/disp: init display sync channels.
- drm/nvd0/disp: scaler updates, overscan compensation etc.
- drm/nvd0/disp: update crtc timing calculations for
  interlace/doublescan.
- drm/nouveau: shutdown display on suspend/hibernate.
- drm/nv50/disp: fix evo for create/init + destroy/fini split.
- drm/nouveau: re-jig fbcon suspend/resume process a little.
- drm/nouveau/disp: introduce proper init/fini, separate from
  create/destroy.
- drm/nouveau/pm: fix missing volt changes when boot voltage
  is undefined.
- commit 07f52ec
* Tue Feb 12 2013 msrb@novell.com
- drm/nv50/pm: fix a typo in clock calculation.
- commit bbcd3e1
* Tue Feb 12 2013 msrb@novell.com
- drm/nvd0/disp: enable hdmi audio.
- drm/nvd0/disp: hook evo up to debugging.
- drm/nvd0/disp: enable hdmi on sor if hdmi monitor present.
- drm/nvd0/disp: send eld to the audio codec.
- drm/nouveau/hdmi: enable audio for nva3:nvd0 chipsets.
- drm/nv50: fix page faulting for 128MB page table sizes.
- drm/nouveau: print correct engine number which failed to
  unload/idle.
- drm/nva3/copy: fix typo in fuc which caused host to not
  recieve exceptions.
- drm/nva3/copy: update fuc source for latest envytools.
- drm/nv50/pm: only touch 0x611200 on nv92-.
- drm/nv50/pm: stabilise transition to 100MHz mclk a bit.
- drm/nv50/pm: avoid touching dom6/vdec clocks if perflvl doesn't
  define it.
- drm/nv50/pm: fix thinko which lead to clocks being slightly
  off sometimes.
- drm/nv50/pm: 0x84/0x86 can't use "1" for nvclk src, need
  0x50 method.
- drm/nvc0/gr: add initial support for nvd9, not quite there yet..
- drm/nvc0/gr: update fuc source to assemble with latest envyas.
- drm/nv50/disp: stricter check for evo being active on init.
- drm/nv50/pm: free state struct after setting clocks.
- drm/nouveau/pm: change volt/fan before upclock, but after
  downclock.
- drm/nouveau/pm: remove the older interfaces completely.
- drm/nv04-nv30/pm: port to newer interfaces.
- drm/nv50/pm: rewrite clock management, and switch to the new
  pm hooks.
- drm/nv50/pm: s/PLL_UNK05/PLL_VDEC/.
- drm/nouveau/pm: make clocks_set return an error code clocks_set
  can fail.
- drm/nvd0: read temperature as we did on nv84+ boards.
- drm/nv50/disp: fix scaling of doublescan modes.
- drm/nv50/disp: rewrite crtc timing calculation, with proper
  names and fixes.
- drm/nouveau/disp: kill off nouveau_crtc.mode.
- drm/nv50/disp: allow interlaced and doublescan modes on
  digital outputs.
- drm/nouveau: don't pretend to support the DVI-I 'select
  subconnector' prop.
- drm/nouveau: improve dithering properties, and implement proper
  auto mode.
- drm/nouveau: no need to pass parameters into set_scale/dither.
- drm/nouveau: determine a value for display_info.bpc if edid
  doesn't.
- drm/nv50/disp: wait for encoder disconnect to complete before
  link training.
- drm/nv50/disp: disconnect encoders before reprogramming them.
- drm/nv50/disp: completely reset disp if master evo channel
  active at init.
- drm/nv50/disp: synchronise display right after init.
- drm/nv50/disp: move sync routine to where it can be used by
  other modules.
- commit 51bf7d5
* Tue Feb 12 2013 msrb@novell.com
- drm/nouveau: restore cursors after restoring mode.
- drm/nouveau: restore performance mode a bit later.
- drm/nouveau: disable output polling through suspend.
- drm/nv50: also report errors in MP1/MP2 when they happen.
- drm/nouveau: add overscan compensation connector properties.
- drm/nouveau: move master modesetting init to nouveau_display.
- drm/nv50/crtc: disable flip overlay around scaling mode changes.
- drm/nouveau/hdmi: enable sending of avi/audio infoframes.
- drm/nouveau/hdmi: add hdmi register accessors to handle hdmi
  block move.
- drm/nouveau/hdmi: build ELD from EDID, notify audio driver of
  its presence.
- drm/nv50/pm: s/unk05/vdec/.
- drm/nouveau/pm: remove defunct fanspeed_set/get from pm table.
- drm/nv40/pm: convert to new pwm hooks, also fixing pwm type
  detection.
- drm/nv50/pm: convert to new fanspeed pwm controller hooks.
- drm/nouveau/pm: introduce generic handler for on-chip fan
  controller.
- drm/nouveau/gpio: remove invert flag, use state everywhere.
- drm/nv50/pm: mostly nailed down fan pwm frequency selection.
- drm/nouveau/pm: manual pwm fanspeed management for nv40+ boards.
- drm/nv50/pm: add support for pwm fan control.
- drm/nouveau/vdec: implement stub modules for the known engines.
- drm/nouveau/pm: hook up fanspeed get/set if they're present.
- drm/nv41/pm: implement a second type of fanspeed pwm.
- drm/nv40/pm: implement first type of pwm fanspeed funcs.
- drm/nv40/pm: parse fan pwm divisor from vbios tables.
- drm/exynos: Add plane support with fimd.
- drm/exynos: add runtime pm feature for fimd.
- drm/exynos: updated crtc and encoder dpms framework.
- drm/exynos: Use struct drm_mode_fb_cmd2.
- drm/exynos: Fix compile errors.
- drm: Add drm_format_num_planes() utility function.
- drm: call connector dpms fxn, when setting config.
- drm/radeon/kms: don't use 0 bpc for adjusting hdmi clock.
- drm/radeon: introduce a sub allocator and convert ib pool to
  it v4.
- drm/radeon/kms: add support for per-ring fence interrupts.
- drm/radeon/kms: add cayman specific fence_ring_emit.
- drm/radeon/kms: add some new ring params to better handle
  other ring types.
- drm/radeon: improve radeon_test_syncing function.
- drm/radeon: precompute fence cpu/gpu addr once v3.
- drm/radeon: move ring debugfs into radeon_ring.c.
- drm/radeon: rename struct radeon_cp to radeon_ring.
- drm/radeon: disable compute rings on cayman for now.
- drm/radeon: add radeon_fence_count_emited function.
- drm/radeon: make some asic pointers per ring.
- drm/radeon: Add radeon_test_syncing function v2.
- drm/radeon: make cp variable an array.
- drm/radeon: make ring rptr and wptr register offsets variable.
- drm/radeon: make all functions work with multiple rings.
- drm/radeon/kms: add support for semaphores v3.
- drm/radeon/kms: add support for multiple fence queues v2.
- drm/radeon: fix a spelling mistake.
- drm/radeon: no need to check all relocs for duplicates.
- drm/radeon: fix debugfs handling v3.
- drm: Replace pitch with pitches in drm_framebuffer.
- drm: Check that the requested pixel format is valid.
- drm: plane: Check that the fb pixel format is supported by
  the plane.
- drm: plane: Make 'formats' parameter to drm_plane_init() const.
- drm: plane: Check crtc coordinates against integer overflows
  in setplane ioctl.
- drm: plane: Check source coordinates.
- drm: plane: Clear plane.crtc and plane.fb after disable_plane().
- drm: Fix __user sparse warnings.
- drm: plane: mutex_unlock() was missing.
- drm: fourcc: Use __u32 instead of u32.
- drm: Install drm_fourcc.h.
- drm: Add a missing ')'.
- Fix wrong assumptions in cea_for_each_detailed_block v2.
- drm_edid_to_eld: check for CEA data blocks only from structure
  revision 3 on.
- drm/radeon/kms: support for audio on Evergreen.
- drm/radeon/kms: minor HDMI audio cleanups.
- drm/radeon/kms: do not force DVI mode on DCE4 if audio is on.
- drm/edid: support CEA video modes.
- drm/ttm: callback move_notify any time bo placement change v4.
- drm/ttm: simplify memory accounting for ttm user v2.
- drm/ttm: isolate dma data from ttm_tt V4.
- drm/nouveau: enable the ttm dma pool when swiotlb is active V3.
- drm/radeon/kms: enable the ttm dma pool if swiotlb is on V4.
- drm/ttm: provide dma aware ttm page pool code V9.
- drm/ttm: introduce callback for ttm_tt populate & unpopulate V4.
- drm/ttm: merge ttm_backend and ttm_tt V5.
- commit 0a7320c
* Tue Feb 12 2013 msrb@novell.com
- drm/ttm: page allocation use page array instead of list.
- Refresh patches.xen/xen3-patch-2.6.35.
- commit e306136
* Tue Feb 12 2013 msrb@novell.com
- drm/ttm: test for dma_address array allocation failure.
- drm/ttm: use ttm put pages function to properly restore cache
  attribute.
- commit 811ff5b
* Tue Feb 12 2013 msrb@novell.com
- drm/ttm: remove unused backend flags field.
- drm/ttm: remove split btw highmen and lowmem page.
- commit 051eb5e
* Tue Feb 12 2013 msrb@novell.com
- drm/ttm: remove userspace backed ttm object support.
- swiotlb: Expose swiotlb_nr_tlb function to modules.
- drm: remove some potentially dangerous DRM_ERRORs.
- drm: document the drm_mode_config structure.
- drm: document the drm_mode_group structure.
- drm: document and cleanup drm_mode_config_funcs.
- drm: document drm_mode_set structure.
- drm: remove unused fields in drm_connector and document
  the rest.
- drm: add drm_encoder comments.
- drm: add comments for drm_encoder_funcs.
- drm: fix comments for drm_crtc struct.
- drm: remove unused connector_count field from drm_display_mode.
- drm: Redefine pixel formats.
- drm: move the fb bpp/depth helper into the core.
- drm/radeon/kms: fix up for BIG ENDIAN breakage.
- drm: add an fb creation ioctl that takes a pixel format v5.
- drm: add plane support v3.
- commit 44de9d7
* Tue Feb 12 2013 msrb@novell.com
- drm: Make the per-driver file_operations struct const.
- Refresh patches.xen/xen3-patch-2.6.29.
- commit 0f8495d
* Tue Feb 12 2013 bpoirier@suse.de
- cxgb4vf: Fix extraction of cpl_rx_pkt from the response queue
  descriptor (bnc#784800 FATE#314296).
- cxgb4: set coalesce parameters on all queues (bnc#784800
  FATE#314296).
- commit 91596c2
* Tue Feb 12 2013 msrb@novell.com
- drm: avoid switching to text console if there is no panic timeout.
- commit 3d97358
* Tue Feb 12 2013 msrb@novell.com
- vmwgfx: fix incorrect VRAM size check in vmw_kms_fb_create().
- vmwgfx: Clip cliprects against screen boundaries in present
  and dirty.
- vmwgfx: Resend the cursor after legacy modeset.
- vmwgfx: Do better culling of presents.
- vmwgfx: Refactor kms code to use vmw_user_lookup_handle helper.
- vmwgfx: Add helper function to get surface or dmabuf.
- vmwgfx: Refactor cursor update.
- vmwgfx: Remove dmabuf check in present ioctl.
- vmwgfx: Use the revised fifo hw version register when present.
- Revert "drm/i915: fix infinite recursion on unbind due to ilk
  vt-d w/a".
- drm/i915: add PCH info to i915_capabilities.
- drm/i915: no-lvds quirk for ASUS AT5NM10T-I.
- vmwgfx: Use kcalloc instead of kzalloc to allocate array.
- drm/i915: fix infinite recursion on unbind due to ilk vt-d w/a.
- drm/radeon/kms: fix return type for
  radeon_encoder_get_dp_bridge_encoder_id.
- vmwgfx: integer overflow in vmw_kms_update_layout_ioctl().
- drm/radeon/kms: fix 2D tiling CS support on EG/CM.
- drm/radeon/kms: fix scanout of 2D tiled buffers on EG/CM.
- drm: Fix lack of CRTC disable for
  drm_crtc_helper_set_config(.fb=NULL).
- drm/radeon/kms: Skip ACPI call to ATIF when possible.
- drm/radeon/kms: Hide debugging message.
- drm/nv50/disp: silence compiler warning.
- drm/nouveau: fix oopses caused by clear being called on
  unpopulated ttms.
- drm/nouveau: Keep RAMIN heap within the channel.
- drm/nvd0/disp: fix sor dpms typo, preventing dpms on in some
  situations.
- drm/nvc0/gr: fix TP init for transform feedback offset queries.
- drm/nouveau: add dumb ioctl support.
- drm/radeon/kms/atom: unify i2c gpio table handling.
- ttm: Don't return the bo reserved on error path.
- drm/radeon/kms: add a CS ioctl flag not to rewrite tiling
  flags in the CS.
- drm/i915: Fix inconsistent backlight level during disabled.
- drm/i915: Remove trailing white space.
- drm/exynos: fixed wrong err ptr usage and destroy call in
  exeception.
- drm/exynos: Add disable of manager.
- drm/radeon/kms: fix segfault in pm rework.
- drm/exynos: include linux/module.h.
- drm/exynos: fix vblank bug.
- drm/exynos: changed buffer structure.
- drm/exynos: removed unnecessary variable.
- drm/exynos: use gem create function generically.
- drm/exynos: checked for null pointer.
- drm/exynos: added crtc dpms for disable crtc.
- commit c741d55
* Tue Feb 12 2013 msrb@novell.com
- drm/exynos: removed meaningless parameter from fbdev update.
- drm/exynos: restored kernel_fb_list when reiniting fb_helper.
- drm/exynos: changed exynos_drm_display to
  exynos_drm_display_ops.
- drm/exynos: added manager object to connector.
- drm/exynos: fixed converting between display mode and timing.
- drm/exynos: fixed connector flag with hpd and interlace scan
  for hdmi.
- drm/exynos: added kms poll for handling hpd event.
- drm: Remove utterly bogus preempt_disable() sections.
- drm/radeon/kms/combios: fix dynamic allocation of PM clock
  modes.
- drm/radeon/kms/pm: switch to dynamically allocating clock
  mode array.
- drm/radeon/kms: optimize r600_pm_profile_init.
- drm/radeon/kms/pm: add a proper pm profile init function
  for fusion.
- drm/radeon/kms: remove extraneous calls to
  radeon_pm_compute_clocks().
- drm/exynos: added padding to be 64-bit align.
- drm: fix kconfig unmet dependency warning.
- drm: add some comments to drm_wait_vblank and
  drm_queue_vblank_event.
- drm/radeon/benchmark: signedness bug in radeon_benchmark_move().
- drm: do not sleep on vblank while holding a mutex.
- drm: drop select of SLOW_WORK.
- drm: serialize access to list of debugfs files.
- drm/radeon/kms: fix use of vram scratch page on evergreen/ni.
- drm/radeon: Make sure CS mutex is held across GPU reset.
- drm: Ensure string is null terminated.
- vmwgfx: Only allow 64x64 cursors.
- vmwgfx: Initialize clip rect loop correctly in surface dirty.
- vmwgfx: Close screen object system.
- drm/nouveau: Fix bandwidth calculation for DisplayPort.
- drm/nouveau: by default use low bpp framebuffer on low memory
  cards.
- drm/nv10: Change the BO size threshold determining the memory
  placement range.
- drm/nvc0: enable acceleration for nvc1 by default.
- drm/nvc0/gr: fixup the mmio list register writes for 0xc1.
- drm/nvc1: hacky workaround to fix accel issues.
- drm/nvc0/gr: fix some bugs in grctx generation.
- drm/nvc0: enable acceleration on 0xc8 by default.
- drm/nvc0/vram: skip disabled PBFB subunits.
- drm/nv40/pm: fix issues on igp chipsets, which don't have
  memory.
- drm/nouveau: testing the wrong variable.
- drm/nvc0/vram: storage type 0xc3 is not compressed.
- drm/nv50: fix stability issue on NV86.
- drm/nv50/vram: fix incorrect detection of bank count on newer
  chipsets.
- drm/nv50/gr: typo fix, how about we not reset fifo during
  graph init?.
- drm/nv50/bios: fixup mpll programming from the init table
  parser.
- drm/nouveau: fix oops if i2c bus not found in
  nouveau_i2c_identify().
- drm: make sure drm_vblank_init() has been called before
  touching vbl_lock.
- vmwgfx: Snoop DMA transfers with non-covering sizes.
- vmwgfx: Move the prefered mode first in the list.
- vmwgfx: Unreference surface on cursor error path.
- vmwgfx: Free prefered mode on error path.
- vmwgfx: Use pointer return error codes.
- vmwgfx: Fix hw cursor position.
- vmwgfx: Infrastructure for explicit placement.
- vmwgfx: Make the preferred autofit mode have a 60Hz vrefresh.
- vmwgfx: Remove screen object active list.
- vmwgfx: Screen object cleanups.
- drm/radeon/kms: consolidate GART code, fix segfault after GPU
  lockup V2.
- drm/radeon/kms: don't poll forever if MC GDDR link training
  fails.
- drm/radeon/kms: fix DP setup on TRAVIS bridges.
- drm/i915: add constants to size fence arrays and fields.
- drm/i915: forcewake warning fixes in debugfs.
- vmwgfx: Reinstate the update_layout ioctl.
- drm/radeon/kms: always do extended edid probe.
- drm/radeon/kms: remove useless radeon_ddc_dump().
- drm/radeon/kms: make atombios_dig_transmitter_setup() version
  based.
- drm/radeon/kms: make atombios_dig_encoder_setup() version based.
- drm/radeon/kms: make atombios_dvo_setup() version based.
- drm/radeon/kms: move atom encoder setup to a new file.
- drm/radeon/kms: allocate vram scratch page on 6xx+.
- drm/radeon/kms: check for DP MST mode in a few more places (v2).
- drm/radeon/kms/atom: rework encoder dpms.
- drm/radeon/kms: only require 2.7 Ghz DP clock for NUTMEG.
- drm/radeon/kms: rework DP bridge checks.
- drm/radeon/kms: use defined constants for crtc/hpd count
  instead of hard-coded value 6.
- drm/radeon: flush read cache for gtt with fence on r6xx and
  newer GPU V3.
- drm/radeon/kms: cleanup atombios_adjust_pll().
- drm/radeon/kms/cayman/blit: specify CP_COHER_CNTL2 with
  surface_sync.
- drm/radeon/kms: rework texture cache flush in r6xx+ blit code.
- vmwgfx: Use "Virtual" connectors and encoders rather than
  "LVDS".
- drm: Introduce "Virtual" connectors and encoders.
- treewide: use __printf not __attribute__((format(printf,...))).
- include: replace linux/module.h with "struct module" wherever
  possible.
- gpu: add moduleparam.h to drivers/gpu/drm/drm_crtc_helper.c.
- gpu: add module.h to drivers/gpu files as required.
- agp: iommu_gfx_mapped only available if CONFIG_INTEL_IOMMU
  is set.
- drm/i915: fix if statement (bogus semi-colon).
- drm/i915: intel_choose_pipe_bpp_dither messages should be
  DRM_DEBUG_KMS.
- Revert "drm/ttm: add a way to bo_wait for either the last read
  or last write".
- Revert "drm/radeon/kms: add a new gem_wait ioctl with read/write
  flags".
- vmwgfx: Don't pass unused arguments to do_dirty functions.
- vmwgfx: Emulate depth 32 framebuffers.
- drm/radeon: Lower the severity of the radeon lockup messages.
- drm/i915: if transcoder disable fails, say which.
- drm: Add Panel Self Refresh DP addresses.
- drm/i915: drop KM_USER0 argument to k(un)map_atomic.
- drm: drm_ioctl() should zero-init extra data.
- vmwgfx: information leak in vmw_execbuf_copy_fence_user().
- vmwgfx: memory leaks caused by double allocation.
- vmwgfx: return -EFAULT instead of number of bytes remaining.
- drm: simplify error printing in drm_debugfs_create_files.
- drm: fix error message about failed procfs file registration.
- drm/radeon/kms: make r600-NI blit suspend code common.
- drm/radeon/kms: blit code commoning.
- drm/radeon/kms: rename a variable for consistency.
- drm/radeon/kms: cleanup r600 blit code.
- drm/radeon/kms: add more elaborate benchmarks.
- drm/radeon/kms: cleanup benchmark code.
- drm/radeon/kms: demystify r600 blit code.
- drm/radeon/kms: demystify evergreen blit code.
- drm/radeon/kms: simplify r6xx blit code.
- drm/radeon/kms: simplify evergreen blit code.
- drm/radeon/kms: Simplify I2C post_xfer function.
- drm/exynos: fixed build warnings and comments.
- drm/exynos: fixed page flip bug.
- drm/exynos: added comments and code clean.
- drm/exynos: fixed bug to exynos_drm_fb_dev_reinit().
- drm/exynos: added device object as argument of subdrv_probe().
- drm/exynos: fixed overlay updating time at page flip.
- drm/exynos: fixed overlay data updating.
- drm/radeon: Move r100_*_*reg out of line.
- drm/radeon: Move more code out of line.
- drm/radeon: Remove more bogus inlines in the radeon driver.
- drm/radeon: Remove now unused functions in radeon driver.
- drm/radeon: drop inlines in r600_blit.c.
- drm/radeon: Drop inlines from evergreen_cs.c / r600_cs.c.
- vmwgfx: Add vblank stubs.
- vmwgfx: Whitespace & code style in display unit.
- vmwgfx: Fix display system init & close functions.
- drm/radeon: allow pcie gen2 speed on Cayman.
- drm/radeon: allow pcie gen2 speed on NI.
- vmwgfx: Take the driver out of staging.
- drm: Add KMS debug printk's for encoder and crtc fixup failure.
- vmwgfx: Wrap drm_read and drm_poll.
- vmwgfx: Add fence events.
- vmwgfx: Break out and comment vmw_execbuf_copy_fence_user.
- drm/radeon/kms: set DMA mask properly on newer PCI asics.
- DRM: bug: RADEON_DEBUGFS_MAX_{NUM_FILES => COMPONENTS}.
- vmwgfx: Don't use virtual coords when using screen objects.
- vmwgfx: Implement memory accounting for resources.
- DRM: add DRM Driver for Samsung SoC EXYNOS4210.
- vmwgfx: Minor cleanups.
- vmwgfx: Bump driver minor to advertise support for new ioctls.
- vmwgfx: Be more strict with fb depths when using screen objects.
- vmwgfx: Handle device surface memory limit.
- vmwgfx: Make sure we always have a user-space handle to use
  for objects that are backing kms framebuffers.
- vmwgfx: Optimize the command submission resource list.
- vmwgfx: Fix up query processing.
- vmwgfx: Allow reference and unreference of NULL fence objects.
- vmwgfx: minor dmabuf utilities cleanup.
- vmwgfx: Disallow user space to send present and readback
  commands.
- vmwgfx: Add present and readback ioctls.
- vmwgfx: Place overlays in GMR area if we can.
- vmwgfx: Drop 3D Legacy Display Unit support.
- vmwgfx: Require HWV8 for 3d support.
- vmwgfx: Add screen object support.
- vmwgfx: Add dmabuf helper functions for pinning.
- vmwgfx: Refactor common display unit functions to shared file.
- vmwgfx: Expand the command checker to cover screen object
  commands.
- vmwgfx: Break out dirty submission code.
- vmwgfx: Break out execbuf command processing.
- vmwgfx: Some comments and BUG_ON.
- vmwgfx: Make sure the reserved area is at the start of vram.
- vmwgfx: Add comments for buffer pinning code.
- vmwgfx: Document vmw_fifo_reserve.
- vmwgfx: Update register files to latest from vmware-sdk.
- ttm: export ttm_bo_create.
- drm/i915: Use DRM_DEBUG_KMS for all messages in intel_bios.c.
- drm/i915: broken copyright encoding in intel_bios.c.
- drm/nouveau: remove allocations from gart populate() hook.
- drm/nvc0/fb: slightly improve PMFB intr handling, move out
  of nvc0_graph.c.
- drm/nvc0/fifo: avoid touching missing subfifos.
- drm/nvd9/disp: bail out of mode_set_base if no fb bound to crtc.
- drm/nvd9/disp: stub some more api hooks so we don't oops
  on resume.
- drm/nouveau: fix printk typo in ioremap failure path.
- drm/nvc0/pm: minor clock readback fixes.
- drm/nv40/pm: execute memory reset script from vbios.
- drm/nv50/gr: refactor initialisation.
- drm/nouveau: if requested, try harder at disabling sysmem
  pushbufs.
- drm/nv50/gr: enable ctxprog xfer only when we need it to
  save power.
- drm/nouveau/dp: add support for displayport table 0x30.
- drm/nouveau/dp: return master dp table pointer too when looking
  up encoder.
- drm/nouveau/bios: simplify U/d table hash matching func to
  just match.
- drm/nouveau/dp: preserve non-pattern bits in
  DP_TRAINING_PATTERN_SET.
- drm/nvc0/gr: remove MODULE_FIRMWARE() lines.
- drm/nouveau/dp: use alternate lane mask for nvaf.
- drm/nouveau/dp: link rate scripts are selected with a comparison
  table.
- drm/nv40/pm: write nv40-specific reclocking routines.
- drm/nv40/pm: parse geometric delta clock from vbios.
- drm/nouveau/dp: enable down-spread if vbios and sink support it.
- drm/nouveau/dp: execute some more vbios tables relating to
  link rate.
- drm/nouveau/dp: store unencoded link_bw everywhere.
- drm/nouveau/dp: restructure link training code.
- drm/nouveau/dp: pass in required datarate to link training.
- drm/nouveau/bios: check for null script pointers in parser.
- drm/nva3/backlight: add suppport for newer style backlight regs.
- drm/nv50/backlight: express brightness level in percent.
- drm/nv50/backlight: take the sor into account when bashing regs.
- drm/nouveau/backlight: make more consistent with rest of
  driver style.
- drm/nouveau: tidy connector hotplug handler, punt messages
  to debug.
- drm/nouveau/dp: remove reliance on vbios for native displayport.
- drm/nouveau/dp: rewrite auxch transaction routines.
- drm/nouveau: workaround semaphore hw bug causing unnecessary
  interrupts.
- drm/nouveau/tmr: fix miscalculation of ratio on pre-nv4x
  chipsets.
- drm/nva3/pm: fixup for NVAF special.
- drm/nva3/pm: use crystal freq where appropriate.
- drm/nouveau: determine timing crystal freq from straps.
- drm/nva3/pm: pll disabled if bit 0 of ctrl not set.
- drm/nouveau: magic to make auxch on new macbooks booted in
  EFI mode work.
- drm/nouveau/pm: Document and expose CL and WR for 0x1002Cx.
- drm/nouveau/pm: add initial NV3x/NVCx memtiming support,
  improve other cards.
- drm/nouveau: remove special-casing of hotplug detection type.
- drm/nvd0: no page flipping at the moment.
- drm/nvc0/gr: remove max tpc count info.
- drm/nvd0: lets not attempt to dereference a nv50_display
  pointer.
- drm/nouveau: enable hwmon support when both nouveau/hwmon are
  built as modules.
- drm/nvd0/disp: tidy up what we have so far.
- drm/nvd0/disp: rewrite irq handler, should be somewhat
  sturdier now.
- drm/nvd0/disp: do modeset irq handling from tasklet.
- drm/nvd0/disp: untested LVDS support.
- drm/nvd0/disp: track down fb positioning method.
- drm/nvd0/disp: determine U table config in or_mode_set().
- drm/nvd0/disp: dac load detect.
- drm/nvd0/disp: handle sync polarity, kill off some unknown.
- drm/nvd0/disp: scaling.
- drm/nvd0/disp: push the update button in mode_set_base().
- drm/nvd0/disp: fixup clut so it actually works.
- drm/nvd0/disp: initial attempt at modeset irq handling.
- drm/nvd0/disp: stub dac load detect, prevents oops.
- drm/nvd0/disp: dac encoder module.
- drm/nvd0/disp: extend the init voodoo to cover crtcs.
- drm/nvd0/disp: remove lp reordering from vram dmaobj, create
  fb dmaobjs.
- drm/nvd0/disp: some magic to make evo happeir.
- drm/nvd0/disp: they moved the linear flag..
- drm/nvd0/disp: initial crtc object implementation.
- drm/nvd0/disp: skeletal handling of modeset interrupts.
- drm/nvd0/disp: start on SOR encoder functions.
- drm/nvd0/disp: setup a couple of dma objects we'll need.
- drm/nvd0/disp: start on interrupt handling.
- drm/nvd0/disp: whip up some basic dma handling for the evo
  channels.
- drm/nvd0/disp: very initial evo setup.
- drm/nouveau/bios: allow passing in crtc to the init table
  parser.
- drm/nvd0/pm: enable clock/voltage hooks.
- drm/nouveau/bios: fix INIT_GPIO for new chipsets.
- drm/nvd0/gpio: initial implementation.
- drm/nvd0/i2c: initial implementation.
- drm/nouveau: initial chipset description for nvdX chipsets.
- drm/nouveau: allow modeset module option to select 'headless
  mode'.
- drm/nouveau: fixup init/fini sequence to deal with no CRTCs.
- drm/nouveau: make general drm modesetting init common.
- drm/nvd0: add a card_type for 0xdX chipsets.
- drm/nv04/pm: recalibrate timer on nvclk changes.
- drm/nouveau/tmr: calibrate for ns timestamps on init.
- drm/nvc0/gr: unblacklist nvcf acceleration.
- drm/nouveau: don't complain for disabled timingset entries.
- drm/nvc0/gr: copy GPC mpart config from PFFB.
- drm/nvc0/vram: support non-uniform memory size per controller.
- drm/nvc0/gr: add support for nvcf chipset.
- drm/nouveau: allow a nouveau_mm to be created with holes.
- drm/nouveau: embed nouveau_mm.
- drm/nv31/mpeg: support for a single class3174 user.
- drm/nouveau: rename nv40_mpeg to nv31_mpeg.
- drm/nvc0/pm: more complete parsing of clock domains.
- drm/nvc0/pm: initial implementation of clocks_get().
- drm/nva3/pm: idle graphics engine before changing clocks.
- drm/nouveau: add function to wait until a callback returns true.
- drm/nv50/gr: insert set/clr of a ctxprog flag at start/end
  of ctxprog.
- drm/nva3/pm: tidy and add some comments here and there.
- drm/nva3/pm: parse/reclock vdec/41a0 clocks.
- drm/nva3/pm: rewrite clock_set, and switch to new interfaces.
- drm/nouveau/pm: add hooks to get/set *all* clocks at once.
- drm/nva3/pm: rewrite clock readback functions, far more
  correct now.
- drm/nouveau/pm: some fermi chipsets still use volt 0x30.
- drm/nouveau/pm: allow voltage-only perflvl set, enable nvc0.
- drm/nvc0/pm: enable voltage_get.
- drm/nouveau/pm: show any info we can manage to glean on
  current perflvl.
- drm/nouveau/pm: add support for parsing perflvl voltage on
  fermi chips.
- drm/nouveau/pm: add yet another vid gpio tag.
- drm/nouveau/pm: initial attempt at parsing volt 0x40.
- drm/nouveau/pm: store voltage in microvolts.
- Drivers: i915: Fix all space related issues.
- treewide: remove extra semicolons from various parts of
  the kernel.
- char: Convert vmalloc/memset to vzalloc.
- drm/radeon: Print gart initialization details on all chipsets.
- vmwgfx: Bump major.
- vmwgfx: Implement fence objects.
- vmwgfx: Make vmw_wait_seqno a bit more readable.
- vmwgfx: Fix confusion caused by using "fence" in various places.
- vmwgfx: Add functionality to get 3D caps.
- vmwgfx: Remove the possibility to map the fifo from user-space.
- vmwgfx: Remove the update layout IOCTL.
- vmwgfx: Remove the fifo debug ioctl.
- vmwgfx: Implement GMR2.
- vmwgfx: Update register definitions for HWV8 and print out
  new capabilities.
- vmwgfx: Restrict number of GMR pages to device limit.
- vmwgfx: Switch to VGA when we drop master and vmwgfx fbdev is
  not active.
- vmwgfx: Fix potential execbuf deadlocks.
- vmwgfx: Print error diagnostics if depth doesn't match the
  host expectation.
- vmwgfx: Fix 'bbp' typo.
- vmwgfx: Don't write to read-only registers.
- vmwgfx: Add support for depth 8.
- vmwgfx: Let SVGA_REG_NUM_DISPLAYS determine output connectivity.
- drm/radeon/kms: add a new gem_wait ioctl with read/write flags.
- drm/ttm: add a way to bo_wait for either the last read or
  last write.
- drm/i915: use common functions for mmap offset creation.
- drm/gem: add functions for mmap offset creation.
- DocBook/drm: Clean up code comment.
- agp/hp-agp: Allow binding user memory to the AGP GART.
- drm/radeon/kms/DCE4.1: fix Select_CrtcSource EncodeMode setting
  for DP bridges (v2).
- drm/radeon/kms/DCE4.1: ss is not supported on the internal
  pplls.
- drm/radeon/kms/DCE4.1: fix dig encoder to transmitter mapping.
- ttm: Fix error-path using an uninitialized value.
- drm/radeon/kms: fix dp_detect handling for DP bridge chips.
- drm/radeon: Set cursor x/y to 0 when x/yorigin > 0.
- drm/radeon: Simplify cursor x/yorigin calculation.
- drm/radeon/kms: fix cursor image off-by-one error.
- drm/radeon: Unreference GEM object outside of spinlock in page
  flip error path.
- drm: Remove duplicate "return" statement.
- drm/nv04/crtc: Bail out if FB is not bound to crtc.
- drm/nouveau: fix nv04_sgdma_bind on non-"4kB pages" archs.
- drm/nouveau: fix oops on pre-semaphore hardware.
- drm/nv50/crtc: Bail out if FB is not bound to crtc.
- drm/radeon/kms: fix DP detect and EDID fetch for DP bridges.
- drm: Fix the number of connector and encoder to cleanup
  functions.
- drm/radeon: Make vramlimit parameter actually work.
- drm/radeon: Explicitly print GTT/VRAM offsets on test failure.
- drm/radeon: Take IH ring into account for test size calculation.
- drm/radeon/alpha: Add Alpha support to Radeon DRM code.
- drm/i915: Can't do accurate vblank timestamps with UMS.
- drm/radeon: re-POST the asic on Apple hardware when booted
  via EFI.
- drm/radeon: Allow panel preferred EDID to override BIOS
  native mode.
- drm/radeon/kms: make some watermark messages debug only.
- drm: Add NULL check about irq functions.
- drm: Fix irq install error handling.
- drm/radeon: fix potential NULL dereference in
  drivers/gpu/drm/radeon/atom.c.
- drm/radeon: clean reg header files.
- drm/debugfs: Initialise empty variable.
- drm/radeon/kms: add thermal chip quirk for asus 9600xt.
- drm/radeon: off by one in check_reg() functions.
- drm/radeon/kms: fix version comment due to merge timing.
- drm: track CEA version number if present.
- Revert "drm/i915/dp: Zero the DPCD data before connection
  probe".
- drm/i915: Add quirk to disable SSC on Sony Vaio Y2.
- drm/i915: add GPU max frequency control file.
- i915: add Dell OptiPlex FX170 to intel_no_lvds.
- atomic: use <linux/atomic.h>.
- drivers: use kzalloc/kcalloc instead of 'kmalloc+memset',
  where possible.
- drm/i915/dp: Zero the DPCD data before connection probe.
- drm/radeon: Add a rmb() in IH processing.
- drm/radeon: ATOM Endian fix for atombios_crtc_program_pll().
- drm/radeon: Fix the definition of RADEON_BUF_SWAP_32BIT.
- drm/radeon: Do an MMIO read on interrupts when not uisng MSIs.
- drm/radeon: Writeback endian fixes.
- drm/radeon: Remove a bunch of useless _iomem casts.
- drm/gem: add support for private objects.
- DRM: clean up and document parsing of video= parameter.
- DRM: Radeon: Fix section mismatch.
- drm: really make debug levels match in edid failure code.
- drm/nouveau/gr: disable fifo access and idle before suspend
  ctx unload.
- drm/nouveau: pass flag to engine fini() method on suspend.
- drm/nouveau: replace nv04_graph_fifo_access() use with direct
  reg bashing.
- drm/nv40/gr: rewrite/split context takedown functions.
- drm/nouveau: detect disabled device in irq handler and return
  IRQ_NONE.
- drm/nouveau: ignore connector type when deciding digital/analog
  on DVI-I.
- drm/nouveau: Add a quirk for Gigabyte NX86T.
- drm/nouveau: do not leak in nv20_graph_create.
- drm/nv50/dp: fix hack to work for macbooks booted via EFI.
- drm/i915: provide more error output when mode sets fail.
- treewide: fix potentially dangerous trailing ';' in #defined
  values/expressions.
- drm/radeon/kms: add info query for backend map.
- drm: platform multi-device support.
- drm/radeon: Don't clobber error return value in page flipping
  cleanup paths.
- drm/radeon: Don't generate new fence for page flip.
- drm/i915: provide module parameter description.
- drm/i915: add module parameter compiler hints.
- DRM: remove drm_pci_device_is_pcie.
- drm/i915: Enable i915 frame buffer compression by default.
- drm/i915: hangcheck disable parameter.
- drm/nouveau: error paths leak in nvc0_graph_construct_context().
- drm/nouveau: Calculate reserved VRAM for PRAMIN value before
  use.
- drm/nouveau: fix nouveau_vma object leak.
- drm/nouveau: fix nouveau_mem object leak.
- drm/nouveau: fix fetching vbios from above 4GiB vram addresses.
- drm/nouveau: fix off-by-one.
- drm/nouveau/temp: Add default calibration values for nv67.
- drm/nouveau/temp: Fix signed/unsigned int logic.
- drm/nvc0: push prunk140 irq messages to debug loglevel.
- drm/nouveau: un-blacklist nvce accel.
- drm/nouveau: fix null pointer deref on pre-nv50 chipsets.
- drm/nouveau: rework vram init/fini ordering a little.
- drm/nouveau: shut lockdep up if last vm ref needs to destroy
  pgd.
- drm/nouveau: fix display takedown order to match reverse
  init order.
- drm/nvc0: enable per-client address spaces.
- drm/nouveau: add some debug output if nouveau_mm busy at
  destroy time.
- drm/nv50: enable use of per-client gpu address space.
- drm/nouveau: remove implicit mapping of every bo into chan_vm.
- drm/nouveau: remove 'chan' argument from nouveau_bo_new.
- drm/nouveau: fixup gem_info ioctl to return client-specific
  bo virtual.
- drm/nvc0: explicitly map PDISP semaphore buffer into each
  channel's vm.
- drm/nv50-nvc0: lookup pushbuf virtual address on dma_push.
- drm/nv84-nvc0: explicitly map semaphore buffer into channel vm.
- drm/nv50-nvc0: explicitly map pushbuf bo into channel vm.
- drm/nv50-nvc0: explicitly map notifier bo into channel vm.
- drm/nv50-nvc0: explicitly map fbcon fb into channel vm.
- drm/nouveau: initial changes to support multiple VMAs per
  buffer object.
- drm/nv50-nvc0: completely disable relocs.
- drm/nouveau: convert bo.mem.start usage to bo.offset.
- drm/nouveau: convert some bo.offset use to vma.offset.
- drm/nouveau: create temp vmas for both src and dst of bo moves.
- drm/nouveau: store bo's page size in nouveau_bo.
- drm/nouveau: skip move_notify() if bo does not have a vma
  attached.
- drm/nouveau: will need to specify channel for vm-ful gpuobj
  allocations.
- drm/nouveau: initialise any vm for a channel before
  pushbuf/ntfy.
- drm/nouveau: modify gpuobj/ntfy takedown ordering.
- drm/nouveau/gem: implement stub hooks for GEM object open/close.
- drm/nouveau: remove 'chan' argument from nouveau_gem_new.
- drm/nv50-nvc0/chan: inherit vm from fpriv, rather than chan_vm
  directly.
- drm/nv50-nvc0/vm: take client reference on shared channel vm.
- drm/nv50-nvc0/vm: don't touch chan_vm.
- drm/nouveau: no need to update bo.offset from vma after
  validate.
- drm/nouveau: store a per-client channel list.
- drm/nouveau: use NULL file_priv for DRM-created channels.
- drm/nouveau: allocate structure to store per-client data.
- drm/nouveau: silence error for missing dac loadval table.
- drm/nv50: DCB table quirks for another busted XFX board.
- drm/nouveau: log if accel is disabled by default on a chipset.
- drm/nvc0/gr: fill in some more data for 0xc1/0xc8/0xce.
- drm/nvc0/gr: fix typo in class9197 init.
- drm/nvc0/gr: calculate magicgpc918 ourselves.
- drm/nvc0/gr: add some missing magics for 0xc1/0xc8/0xce.
- drm/nvc0/gr: import and use our own fuc by default.
- drm/nvc0: fix suspend/resume of PGRAPH/PCOPYn.
- drm/nouveau: default to noaccel on 0xc1/0xc8/0xce for now.
- drm/nvc1/gr: switch on acceleration support.
- drm/nvc0/gr: enable 0xc8/0xce support, no idea if it works
  or not..
- drm/nvc0/gr: some initial state modifications.
- drm/nvc0/gr: 0x9197/0x9297 state init.
- drm/nvc0/gr: macro to determine fermi class, will use it in
  a few places.
- drm/nvc0/fifo: fix typos in unload_context.
- drm/nvc0/fb: allocate page for some unknown PFFB object.
- drm/nvc0: Read temperature on Fermi like we do on nv84+.
- drm/radeon/kms: add initial CS checker support for compute.
- ttm: Fix spelling mistakes and remove unused #ifdef.
- drm/radeon/kms: set dma_copy to NULL for r6xx+.
- drm/gem: add hooks to notify driver when object handle is
  created/destroyed.
- treewide: remove duplicate includes.
- drm/i915: enable ring freq scaling, RC6 and graphics turbo on
  Ivy Bridge v3.
- commit bad8109
* Tue Feb 12 2013 mkubecek@suse.cz
- patches.kernel.org/patch-3.0.59-60: Update references
  (add bnc#799270).
- commit 931a1cb
* Tue Feb 12 2013 msrb@novell.com
- Remove some DRM patches from patches.drivers.
  They will be added in proper place in patches.drm series.
  * patches.drivers/DRM-i915-Don-t-clone-SDVO-LVDS-with-analog.patch
  * patches.drivers/DRM-i915-Restore-sdvo_flags-after-dtd-mode-dtd-Roundrtrip.patch
  * patches.drivers/drm-Export-drm_probe_ddc
  * patches.drivers/drm-dp-Document-DP-spec-versions-for-various-DPCD-re
  * patches.drivers/drm-dp-Make-sink-count-DP-1.2-aware
  * patches.drivers/drm-dp-Update-DPCD-defines
  * patches.drivers/drm-i915-Implement-workaround-for-broken-CS-tlb-on-i830-845.patch
  * patches.drivers/drm-i915-dp-Be-smarter-about-connection-sense
  * patches.drivers/drm-i915-dp-Fetch-downstream-port-info
  * patches.drivers/drm-i915-enable-plain-RC6-on-Sandy-Bridge-by-default.patch
  * patches.drivers/drm-i915-lvds-add-standard-modes.diff
  * patches.drivers/drm-intel-do-not-delete-dpll-multiplier-during-dac-init.patch
  * patches.drivers/drm_i915_Fix_backlight_control_for_systems_which_have_bl_polarity_reversed.patch
- commit 7531049
* Tue Feb 12 2013 mgorman@suse.de
- mlx4: Use all GFP_NOFS calls during the ipoib TX path when creating the QP
  (Fixes hang when using NFS with IPoIB bnc#752528).
- commit 5da7302
* Tue Feb 12 2013 jdelvare@suse.de
- patches.drivers/revert-libata-implement-on-demand-hpa-unlocking:
  Fix references.
- commit 337dc0c
* Tue Feb 12 2013 mgorman@suse.de
- patches.suse/SoN-0025-mm-net-allow-some-SOCK_MEMALLOC-traffic-through.patch:
  mm: net: Allow some !SOCK_MEMALLOC traffic through even if skb_pfmemalloc
  (Allow GPFS network traffic despite PF_MEMALLOC misuse (bnc#786900)).
- commit a78bfd6
* Mon Feb 11 2013 jslaby@suse.cz
- Linux 3.0.63.
- commit 2f2efc0
* Mon Feb 11 2013 jeffm@suse.com
- patches.suse/block-add-dev_check_rdonly-and-friends-for-lustre-testing:
  Update to final version (FATE#314679 bnc#802764).
- commit a02cc11
* Mon Feb 11 2013 mhocko@suse.cz
- kexec: add the values related to buddy system for filtering
  free pages (bnc#802204).
- commit cc849a8
* Mon Feb 11 2013 jslaby@suse.cz
- patches.fixes/kernel-resource.c-fix-stack-overflow-in-__reserve_re.patch:
  kernel/resource.c: fix stack overflow in
  __reserve_region_with_split() (bnc#801782).
- commit 308f7f7
* Mon Feb 11 2013 mgorman@suse.de
- mm/huge_memory: fix copying user highpage
  (THP fixlet).
- commit 12822e1
* Mon Feb 11 2013 ohering@suse.de
- Drivers: hv: balloon: Prevent the host from ballooning the
  guest too low.
- Drivers: hv: balloon: Add a parameter to delay pressure
  reporting.
- commit 2571877
* Mon Feb 11 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Adapt for new pesign-obs-integration package.
- commit 8a5fc4a
* Mon Feb 11 2013 jslaby@suse.cz
- scripts/stable*: add stable management scripts
  For history, see:
  https://github.com/jirislaby/slaby-scripts/
- commit a737dc2
* Fri Feb  8 2013 jeffm@suse.com
- Lustre enablement patches
  - patches.suse/block-add-dev_check_rdonly-and-friends-for-lustre-testing:
    block: add dev_check_rdonly and friends for Lustre testing
    (FATE#314679 bnc#802764).
  - patches.suse/dcache-add-dcache_lustre_invalid-flag-for-lustre-to-handle-its-own-invalidation:
    dcache: Add DCACHE_LUSTRE_INVALID flag for Lustre to handle
    its own invalidation (FATE#314679 bnc#802764).
  - patches.suse/lsm-export-security_inode_unlink: lsm: export
    security_inode_unlink (FATE#315679 bnc#802764).
  - patches.suse/lustre-add-lustre-kernel-version: lustre: Add
    lustre kernel version (FATE#314679 bnc#802764).
- commit 584b95b
* Fri Feb  8 2013 ohering@suse.de
- hv: fix and reenable vmbus interrupt delivery to all vcpus
- commit 393bc68
* Fri Feb  8 2013 tiwai@suse.de
- ALSA: hda - Add fixup for Haswell to enable all pin and
  convertor widgets (bnc#801713).
- ALSA: hda - Support rereading widgets under the function group
  (bnc#801713).
- commit d855c43
* Fri Feb  8 2013 tiwai@suse.de
- Renamed
  patches.drivers/alsa-sp3-pre-692-Yet-another-fix-for-broken-HSW-HDMI-pin.
- commit 017e815
* Fri Feb  8 2013 jdelvare@suse.de
- supported.conf: i2c-ismt is supported (FATE#313511.)
- commit b3b9d2e
* Thu Feb  7 2013 ohering@suse.de
- hv: disable vmbus interrupt delivery to all vcpus, does not
  work with 3.0 baseline yet
- commit b3ece72
* Thu Feb  7 2013 oneukum@suse.de
- Add a void* suse_kabi_padding placeholder to some USB structures
  (fate#312013).
- commit 1126ad5
* Thu Feb  7 2013 duwe@suse.de
- powerpc/perf: Use perf_instruction_pointer in callchains
  (bnc#796891).
- powerpc/perf: Always use pt_regs for userspace samples
  (bnc#796891).
- powerpc/perf: Move code to select SIAR or pt_regs into
  perf_read_regs (bnc#796891).
- powerpc/perf: Create mmcra_sihv/mmcra_sipv helpers (bnc#796891).
- powerpc/perf: Fix instruction address sampling on 970 and Power4
  (bnc#796891).
- commit e9ef612
* Thu Feb  7 2013 ohering@suse.de
- supported.conf: mark drivers/hv/hv_balloon.ko as supported
- commit 4013dad
* Thu Feb  7 2013 jdelvare@suse.de
- patches.fixes/st-fix-memory-leak-with-1mb-tape-i-o.patch: st:
  fix memory leak with >1MB tape I/O (bnc#798921).
- commit 173db04
* Thu Feb  7 2013 dsterba@suse.cz
- crc32c: add slice-by-8 algorithm
- crc32: optimize inner loop (FATE#312888).
- crc32: simplify unit test code (FATE#312888).
- crc32: miscellaneous cleanups (FATE#312888).
- crc32: fix mixing of endian-specific types (FATE#312888).
- crc32: make CRC_*_BITS definition correspond to actual bit
  counts (FATE#312888).
- crc32: add slice-by-8 algorithm to existing code (FATE#312888).
- crc32: optimize loop counter for x86 (FATE#312888).
- crc32: bolt on crc32c (FATE#312888).
- crc32: add self-test code for crc32c (FATE#312888).
- crc32: select an algorithm via Kconfig (FATE#312888).
- Update config files.
- commit 3e94910
* Thu Feb  7 2013 duwe@suse.de
- pseries/iommu: remove DDW on kexec (bnc#793678).
- pseries/iommu: restore_default_window does not use liobn
  parameter (bnc#793678).
- dlpar: invoke notifier chains before removing /proc nodes
  (bnc#793678).
- pseries/iommu: Ensure TCEs are cleared with non-huge DDW
  (bnc#793678).
- pseries/iommu: Fix iteration in DDW TCE clearrange (bnc#793678).
- commit 12192a5
* Thu Feb  7 2013 mgorman@suse.de
- mm: do not sleep in balance_pgdat if there's no i/o congestion
  (Page reclaim functionality).
- mm: remove swap token code (Page reclaim functionality).
- mm/vmscan.c: avoid possible deadlock caused by too_many_isolated()
  (Page reclaim functionality).
- mm,vmscan: only evict file pages when we have plenty
  (Page reclaim functionality.)
- commit ba99ab6
* Thu Feb  7 2013 mgorman@suse.de
- thp: avoid VM_BUG_ON page_count(page) false positives in __collapse_huge_page_copy
  (MM fixes 3.6-rc1 to 3.8-rc6 not in -stable)
- commit 8fa1886
* Thu Feb  7 2013 mgorman@suse.de
- patches.fixes/mm-check-if-PTE-is-already-allocated-during-page-fault.patch.
  (Update upstream git commit ID.)
- commit 0630b2a
* Thu Feb  7 2013 mgorman@suse.de
- patches.fixes/mm-compaction-acquire-the-zone--lock-as-late-as-possible.patch.
  (Refresh for series2git)
- commit b4cffb0
* Thu Feb  7 2013 hare@suse.de
- qla2xxx: Update version number to 8.04.00.13.11.3-k
  (FATE#313901,bnc#801745).
- qla2xxx: Wait for IDC complete event to finish loopback
  operation (FATE#313901,bnc#801745).
- qla2xxx: Don't process state change aen for reset owner
  (FATE#313901,bnc#801745).
- qla2xxx: Don't process RSCNs for a vport on the same physical
  adapter (FATE#313901,bnc#801745).
- qla2xxx: Correction of comment in MBC opcode defines
  (FATE#313901,bnc#801745).
- qla2xxx: Correct list-iteration bug in Report-ID Acquisition
  codes (FATE#313901,bnc#801745).
- Revert "qla2xxx: Optimize existing port name server query
  matching." (FATE#313901,bnc#801745).
- Revert "qla2xxx: Avoid losing any fc ports when loop id's are
  exhausted." (FATE#313901,bnc#801745).
- qla2xxx: Update the copyright information
  (FATE#313901,bnc#801745).
- qla2xxx: Display the lock owner on lock acquire failure
  (FATE#313901,bnc#801745).
- qla2xxx: Move loopback mode reset after chip reset check
  (FATE#313901,bnc#801745).
- qla2xxx: Extra loopback error handling for ISP83xx
  (FATE#313901,bnc#801745).
- qla2xxx: Unload hangs after issuing BSG commands to vport
  (FATE#313901,bnc#801745).
- qla2xxx: Do MPI reset only for 81xx (FATE#313901,bnc#801745).
- qla2xxx: Do link initialization on get loop id failure
  (FATE#313901,bnc#801745).
- qla2xxx: Update the FTP site references in the driver sources
  (FATE#313901,bnc#801745).
- qla2xxx: Reject loopback request if one is already in progress
  (FATE#313901,bnc#801745).
- qla2xxx: Print thermal unsupported message
  (FATE#313901,bnc#801745).
- qla2xxx: Avoid null pointer dereference in shutdown routine
  (FATE#313901,bnc#801745).
- qla2xxx: Get VPD information from common location for CNA
  (FATE#313901,bnc#801745).
- qla2xxx: Correct race in loop_state assignment during reset
  handling (FATE#313901,bnc#801745).
- qla2xxx: Obtain loopback iteration count from bsg request
  (FATE#313901,bnc#801745).
- commit 19ef283
* Thu Feb  7 2013 mgorman@suse.de
- block: remove plugging at buffered write time
  (VM/FS performance.)
- commit 6f66808
* Thu Feb  7 2013 jbeulich@suse.com
- Update Xen patches to 3.0.61 and c/s 1222.
- commit a711016
* Thu Feb  7 2013 jlee@suse.com
- X.509: Support parse long form of length octets in Authority
  Key Identifier (bnc#801248).
- ASN.1: Define indefinite length marker constant (bnc#801248).
- commit d90e5d4
* Thu Feb  7 2013 brogers@suse.com
- x86, apicv: add virtual interrupt delivery support
  (fate#313618).
- x86, apicv: add virtual x2apic support (fate#313618).
- x86, apicv: add APICv register virtualization support
  (fate#313618).
- KVM: remove unused variable (fate#313618).
- KVM: inject ExtINT interrupt before APIC interrupts
  (fate#313618).
- KVM: apic: fix LDR calculation in x2apic mode (fate#313618).
- KVM: optimize apic interrupt delivery (fate#313618).
- KVM: x86: lapic: Clean up find_highest_vector() and
  count_vectors() (fate#313618).
- KVM: correctly detect APIC SW state in
  kvm_apic_post_state_restore() (fate#313618).
- KVM: mark apic enabled on start up (fate#313618).
- KVM: use kvm_lapic_set_base() to change apic_base (fate#313618).
- KVM: optimize ISR lookups (fate#313618).
- KVM: dont clear TMR on EOI (fate#313618).
- commit ce595c2
* Wed Feb  6 2013 dsterba@suse.cz
- btrfs: don't try to notify udev about missing devices
  (FATE#312888).
- Btrfs: do not merge logged extents if we've removed them from
  the tree (FATE#312888).
- Btrfs: fix wrong sync_writers decrement in
  btrfs_file_aio_write() (FATE#312888).
- Btrfs: fix missing release of the space/qgroup reservation in
  start_transaction() (FATE#312888).
- Btrfs: fix race between snapshot deletion and getting inode
  (FATE#312888).
- Btrfs: fix missing i_size update (FATE#312888).
- Btrfs: fix possible stale data exposure (FATE#312888).
- Btrfs: fix EDQUOT handling in btrfs_delalloc_reserve_metadata
  (FATE#312888).
- Btrfs: move d_instantiate outside the transaction during
  mksubvol (FATE#312888).
- Delete patches.suse/btrfs-8306-disable-qgroup-id-0.patch.
- commit 08c721d
* Wed Feb  6 2013 ohering@suse.de
- hv: replace IS_ENABLED with ifdef to fix compile errors
- commit 5cd00a8
* Wed Feb  6 2013 jjolly@suse.de
- [BZ 88366] dasd: oops when DASD modules are unloaded and loaded
  (bnc#801772, LTC#88366).
- commit e77ce35
* Wed Feb  6 2013 jjolly@suse.de
- zcore: Add hsa file (bnc#801772, LTC#88198).
- commit eaadef2
* Wed Feb  6 2013 jjolly@suse.de
- ipl: Implement diag308 loop for zfcpdump (bnc#801772,
  LTC#88197).
- commit b52e8c5
* Wed Feb  6 2013 ohering@suse.de
- X86: Handle Hyper-V vmbus interrupts as special hypervisor
  interrupts (fate#314665).
- Drivers: hv: Bind all vmbus interrupts to the boot CPU
  (fate#314665).
- Drivers: hv: vmbus: Use the new infrastructure for delivering
  VMBUS interrupts (fate#314665).
- commit 9d85be8
* Wed Feb  6 2013 ohering@suse.de
- Refresh patch headers of many hyperv patches, no code changes
- commit b06a34b
* Wed Feb  6 2013 jjolly@suse.de
- IB/qib: Fix for broken sparse warning fix (bnc#800617).
- commit d38b210
* Wed Feb  6 2013 bp@suse.de
- x86/mce: Fix 32-bit build.
- x86/bitops: Move BIT_64() for a wider use.
- commit b5a9e0e
* Wed Feb  6 2013 dsterba@suse.cz
- Btrfs: ignore orphan qgroup relations (FATE#312888).
- vfs: remove DCACHE_NEED_LOOKUP (FATE#312888).
- Btrfs: prevent qgroup destroy when there are still relations
  (FATE#312888).
- Btrfs: fix memory leak in name_cache_insert() (FATE#312888).
- btrfs: get the device in write mode when deleting it
  (FATE#312888).
- Btrfs: disable qgroup id 0 (FATE#312888).
- Btrfs: do not delete a subvolume which is in a R/O subvolume
  (FATE#312888).
- Btrfs: reset path lock state to zero (FATE#312888).
- Btrfs: fix off-by-one in lseek (FATE#312888).
- Btrfs: fix resize a readonly device (FATE#312888).
- Btrfs: fix missing write access release in btrfs_ioctl_resize()
  (FATE#312888).
- btrfs: fix btrfs_cont_expand() freeing IS_ERR em (FATE#312888).
- Btrfs: set flushing if we're limited flushing (FATE#312888).
- Btrfs: add orphan before truncating pagecache (FATE#312888).
- btrfs: update timestamps on truncate() (FATE#312888).
- Btrfs: let allocation start from the right raid type
  (FATE#312888).
- Btrfs: fix a bug when llseek for delalloc bytes behind prealloc
  extents (FATE#312888).
- Btrfs: bring back balance pause/resume logic (FATE#312888).
- Btrfs: fix "mutually exclusive op is running" error code
  (FATE#312888).
- Btrfs: fix unlock order in btrfs_ioctl_resize (FATE#312888).
- Btrfs: fix unlock order in btrfs_ioctl_rm_dev (FATE#312888).
- Btrfs: reorder locks and sanity checks in btrfs_ioctl_defrag
  (FATE#312888).
- Btrfs: fix a regression in balance usage filter (FATE#312888).
- Btrfs: put csums on the right ordered extent (FATE#312888).
- Btrfs: do not allow logged extents to be merged or removed
  (FATE#312888).
- Btrfs: fix panic when recovering tree log (FATE#312888).
- Btrfs: use right range to find checksum for compressed extents
  (FATE#312888).
- Btrfs: Add ACCESS_ONCE() to transaction->abort accesses
  (FATE#312888).
- Btrfs: fix missed transaction->aborted check (FATE#312888).
- Btrfs: fix wrong max device number for single profile
  (FATE#312888).
- Btrfs: fix repeated delalloc work allocation (FATE#312888).
- Refresh
  patches.suse/btrfs-0956-fix-a-bug-of-per-file-nocow.patch.
- Delete
  patches.suse/btrfs-8201-do-not-delete-a-subvolume-which-is-in-a-R-O-su.patch.
- Delete
  patches.suse/btrfs-8204-reset-path-lock-state-to-zero.patch.
- Delete patches.suse/btrfs-8205-fix-off-by-one-in-lseek.patch.
- Delete
  patches.suse/btrfs-8206-fix-btrfs_cont_expand-freeing-IS_ERR-em.patch.
- Delete
  patches.suse/btrfs-8207-update-timestamps-on-truncate.patch.
- Delete
  patches.suse/btrfs-8208-put-csums-on-the-right-ordered-extent.patch.
- Delete
  patches.suse/btrfs-8305-fix-memory-leak-in-name_cache_insert.patch.
- commit 737fac9
* Wed Feb  6 2013 bpoirier@suse.de
- intel: Move the Intel wired LAN drivers (bnc#795301
  FATE#313663).
- Update config files.
- supported.conf:
- commit d8aa6ef
* Wed Feb  6 2013 bpoirier@suse.de
- drivers/net: fix up function prototypes after __dev* removals
  (bnc#795301 FATE#313663).
- net/intel: remove __dev* attributes (bnc#795301 FATE#313663).
- ixgbevf: Add checksum statistics counters to rings (bnc#795301
  FATE#313663).
- ixgbevf: Remove unneeded and obsolete comment (bnc#795301
  FATE#313663).
- ixgbevf: White space and comments clean up (bnc#795301
  FATE#313663).
- ixgbevf: Remove mailbox spinlock from the reset function
  (bnc#795301 FATE#313663).
- ixgbevf: Remove checking for mac.ops function pointers
  (bnc#795301 FATE#313663).
- ixgbevf: Remove the ring adapter pointer value (bnc#795301
  FATE#313663).
- ixgbevf: Fix unnecessary dereference where local var is
  available (bnc#795301 FATE#313663).
- ixgbevf: Streamline the rx buffer allocation (bnc#795301
  FATE#313663).
- ixgbevf: Reduce size of maximum rx buffer (bnc#795301
  FATE#313663).
- ixgbevf: Add flag to indicate when rx is in net poll (bnc#795301
  FATE#313663).
- ixgbevf: fix possible use of uninitialized variable (bnc#795301
  FATE#313663).
- ixgbevf: make sure probe fails on MSI-X enable error (bnc#795301
  FATE#313663).
- eth: Make is_link_local() consistent with other address tests
  (bnc#795301 FATE#313663).
- ixgbe: add setlink, getlink support to ixgbe and ixgbevf
  (bnc#795301 FATE#313663).
- ixgbevf: Do not forward LLDP type frames (bnc#795301
  FATE#313663).
- net, ixgbe: handle link local multicast addresses in SR-IOV mode
  (bnc#795301 FATE#313663).
- ixgbevf: Update version string (bnc#795301 FATE#313663).
- ixgbevf: fix softirq-safe to unsafe splat on internal mbx_lock
  (bnc#795301 FATE#313663).
- ixgbevf: Check for error on dma_map_single call (bnc#795301
  FATE#313663).
- ixgbevf: make netif_napi_add and netif_napi_del symmetric
  (bnc#795301 FATE#313663).
- ixgbevf: Add VF DCB + SR-IOV support (bnc#795301 FATE#313663).
- ixgbe/ixgbevf: Limit maximum jumbo frame size to 9.5K to avoid
  Tx hangs (bnc#795301 FATE#313663).
- ixgbevf: Set the netdev number of Tx queues (bnc#795301
  FATE#313663).
- ixgbevf: Add fix to VF to handle multi-descriptor buffers
  (bnc#795301 FATE#313663).
- ixgbevf: Fix AIM (Adaptive Interrupt Moderation) (bnc#795301
  FATE#313663).
- ixgbevf - Remove unused parameter in ixgbevf_receive_skb
  (bnc#795301 FATE#313663).
- ixgbevf: Fix code for handling timeout (bnc#795301 FATE#313663).
- ixgbevf: scheduling while atomic in reset hw path (bnc#795301
  FATE#313663).
- ixgbevf: Add support for VF API negotiation (bnc#795301
  FATE#313663).
- netdev: make pci_error_handlers const (bnc#795301 FATE#313663).
- ixgbevf: Cleanup handling of configuration for jumbo frames
  (bnc#795301 FATE#313663).
- ixgbevf: Add suspend and resume support to the VF (bnc#795301
  FATE#313663).
- netvm: propagate page->pfmemalloc from skb_alloc_page to skb
  (bnc#795301 FATE#313663).
- ixgbevf: Fix namespace issue with ixgbe_write_eitr (bnc#795301
  FATE#313663).
- ixgbevf: Add support for PCI error handling (bnc#795301
  FATE#313663).
- ixgbevf: Add lock around mailbox ops to prevent simultaneous
  access (bnc#795301 FATE#313663).
- ixgbevf: Fix multiple issues in ixgbevf_get/set_ringparam
  (bnc#795301 FATE#313663).
- ixgbevf: Consolidate Tx context descriptor creation code
  (bnc#795301 FATE#313663).
- ixgbevf: Add netdev to ring structure (bnc#795301 FATE#313663).
- ixgbevf: Do not rewind the Rx ring before bumping tail
  (bnc#795301 FATE#313663).
- ixgbevf: fix VF untagging when 802.1 prio is set (bnc#795301
  FATE#313663).
- ixgbevf: Update descriptor macros to accept pointers and drop
  _ADV suffix (bnc#795301 FATE#313663).
- ixgbevf: Use igb style interrupt masks instead of ixgbe style
  (bnc#795301 FATE#313663).
- ixgbevf: Move Tx clean-up into NAPI context (bnc#795301
  FATE#313663).
- ixgbevf: Update q_vector to contain ring pointers instead of
  bitmaps (bnc#795301 FATE#313663).
- ixgbevf: Fix panic when loading driver (bnc#795301 FATE#313663).
- ixgbevf: Cleanup accounting for space needed at start of
  xmit_frame (bnc#795301 FATE#313663).
- ixgbevf: Drop use of eitr_low and eitr_high for hard coded
  values (bnc#795301 FATE#313663).
- ixgbevf: Make use of NETIF_F_RXCSUM instead of keeping our
  own flag (bnc#795301 FATE#313663).
- ixgbevf: Drop netdev_registered value since that is already
  stored in netdev (bnc#795301 FATE#313663).
- ixgbevf: Drop all dead or unnecessary code (bnc#795301
  FATE#313663).
- ixgbevf: Prevent RX/TX statistics getting reset to zero
  (bnc#795301 FATE#313663).
- drivers/net/ethernet: Fix (nearly-)kernel-doc comments for
  various functions (bnc#795301 FATE#313663).
- ixgbevf: Update version string (bnc#795301 FATE#313663).
- ixgbevf: Make sure jumbo frames are set correctly after PF reset
  (bnc#795301 FATE#313663).
- ixgbevf: Add support to recognize 100mb link speed (bnc#795301
  FATE#313663).
- intel: make wired ethernet driver message level consistent
  (rev2) (bnc#795301 FATE#313663).
- ixgbevf: print MAC via printk format specifier (bnc#795301
  FATE#313663).
- rename dev_hw_addr_random and remove redundant second
  (bnc#795301 FATE#313663).
- ixgbevf: Update copyright notices (bnc#795301 FATE#313663).
- ixgbevf: Fix mailbox interrupt ack bug (bnc#795301 FATE#313663).
- drivers/net: Remove unnecessary k.alloc/v.alloc OOM messages
  (bnc#795301 FATE#313663).
- ixgbevf: make operations tables const (bnc#795301 FATE#313663).
- ixgbevf: fix sparse warnings (bnc#795301 FATE#313663).
- ixgbevf: make ethtool ops and strings const (bnc#795301
  FATE#313663).
- ixgbevf: Prevent possible race condition by checking for message
  (bnc#795301 FATE#313663).
- ixgbevf: Fix register defines to correctly handle complex
  expressions (bnc#795301 FATE#313663).
- net: remove netdev_alloc_page and use __GFP_COLD (bnc#795301
  FATE#313663).
- Sweep away N/A fw_version dustbunnies from the .get_drvinfo
  routine of a number of drivers (bnc#795301 FATE#313663).
- intel: Convert <FOO>_LENGTH_OF_ADDRESS to ETH_ALEN (bnc#795301
  FATE#313663).
- ixgbevf: Convert printks to pr_<level> (bnc#795301 FATE#313663).
- ixgbevf: Update release version (bnc#795301 FATE#313663).
- net: add skb frag size accessors (bnc#795301 FATE#313663).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#795301 FATE#313663).
- ixgbevf: Fix broken trunk vlan (bnc#795301 FATE#313663).
- intel: convert to SKB paged frag API (bnc#795301 FATE#313663).
- ixgbevf: convert to ndo_fix_features (bnc#795301 FATE#313663).
- ixgbevf: provide 64 bit statistics (bnc#795301 FATE#313663).
- ixgbevf: Check if EOP has changed before using it (bnc#795301
  FATE#313663).
- commit 9a53bf0
* Wed Feb  6 2013 bpoirier@suse.de
- intel: Move the Intel wired LAN drivers (bnc#795301
  FATE#313663).
- Update config files.
- supported.conf:
- commit 65c9bec
* Wed Feb  6 2013 bpoirier@suse.de
- treewide: Correct spelling of successfully in comments
  (bnc#795301 FATE#313663).
- ixgbevf: do vlan cleanup (bnc#795301 FATE#313663).
- ixgbevf: remove unnecessary ampersands (bnc#795301 FATE#313663).
- ixgbevf: Fix bungled declaration of ixgbevf_mbx_ops (bnc#795301
  FATE#313663).
- ixgbevf: Update the driver string (bnc#795301 FATE#313663).
- drivers/net: fix up function prototypes after __dev* removals
  (bnc#795299 FATE#313657).
- net/intel: remove __dev* attributes (bnc#795299 FATE#313657).
- igbvf: update version number (bnc#795299 FATE#313657).
- igbvf: work around i350 erratum (bnc#795299 FATE#313657).
- igbvf: Fix trunk vlan (bnc#795299 FATE#313657).
- igbvf: Check for error on dma_map_single call (bnc#795299
  FATE#313657).
- netdev: make pci_error_handlers const (bnc#795299 FATE#313657).
- igbvf: fix divide by zero (bnc#795299 FATE#313657).
- igbvf: fix the bug when initializing the igbvf (bnc#795299
  FATE#313657).
- intel: make wired ethernet driver message level consistent
  (rev2) (bnc#795299 FATE#313657).
- igbvf: Use ETH_ALEN (bnc#795299 FATE#313657).
- igbvf: reset netdevice addr_assign_type if changed (bnc#795299
  FATE#313657).
- rename dev_hw_addr_random and remove redundant second
  (bnc#795299 FATE#313657).
- igbvf: refactor Interrupt Throttle Rate code (bnc#795299
  FATE#313657).
- igbvf: change copyright date (bnc#795299 FATE#313657).
- igbvf: Remove unnecessary irq disable/enable (bnc#795299
  FATE#313657).
- igbvf: remove unneeded cast (bnc#795299 FATE#313657).
- Sweep away N/A fw_version dustbunnies from the .get_drvinfo
  routine of a number of drivers (bnc#795299 FATE#313657).
- igbvf: Convert printks to pr_<level> (bnc#795299 FATE#313657).
- Sweep the last of the active .get_drvinfo floors under ethernet/
  (bnc#795299 FATE#313657).
- igbvf: Update module identification strings (bnc#795299
  FATE#313657).
- igbvf: fix truesize underestimation (bnc#795299 FATE#313657).
- igbvf: convert to ndo_fix_features (bnc#795299 FATE#313657).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#795299 FATE#313657).
- intel: convert to SKB paged frag API (bnc#795299 FATE#313657).
- commit 36f0eb9
* Wed Feb  6 2013 bpoirier@suse.de
- intel: Move the Intel wired LAN drivers (bnc#795299
  FATE#313657).
- Update config files.
- supported.conf:
- commit 5da48c0
* Wed Feb  6 2013 bpoirier@suse.de
- intel drivers: repair missing flush operations (bnc#795299
  FATE#313657).
- igbvf: do vlan cleanup (bnc#795299 FATE#313657).
- commit 1549a94
* Wed Feb  6 2013 dsterba@suse.cz
- Btrfs: do not warn_on io_ctl->cur in io_ctl_map_page
  (FATE#312888).
- Btrfs: pass root object into btrfs_ioctl_{start, wait}_sync()
  (FATE#312888).
- Btrfs: fix wrong return value of btrfs_wait_for_commit()
  (FATE#312888).
- Btrfs: get write access when setting the default subvolume
  (FATE#312888).
- Btrfs: get write access when doing resize fs (FATE#312888).
- Btrfs: get write access when removing a device (FATE#312888).
- Btrfs: get write access for scrub (FATE#312888).
- Btrfs: get write access for qgroup operations (FATE#312888).
- Btrfs: use slabs for auto defrag allocation (FATE#312888).
- Btrfs: fix unprotected defragable inode insertion (FATE#312888).
- Btrfs: restructure btrfs_run_defrag_inodes() (FATE#312888).
- Btrfs: fix freeze vs auto defrag (FATE#312888).
- Btrfs: fix race in check-integrity caused by usage of bitfield
  (FATE#312888).
- Btrfs: fix a scrub regression in case of write errors
  (FATE#312888).
- Btrfs: use existing align macros in btrfs_allocate()
  (FATE#312888).
- Btrfs: fix off-by-one error of the reserved size of
  btrfs_allocate() (FATE#312888).
- Btrfs: skip adding an acl attribute if we don't have to
  (FATE#312888).
- Btrfs: don't add a NULL extended attribute (FATE#312888).
- Btrfs: add fiemap's flag check (FATE#312888).
- Btrfs: refactor error handling to drop inode in btrfs_create()
  (FATE#312888).
- Btrfs: use ctl->unit for free space calculation instead of
  block_group->sectorsize (FATE#312888).
- Btrfs: don't auto defrag a file when doing directIO
  (FATE#312888).
- Btrfs: fix missing reserved space release in error path of
  delalloc reservation (FATE#312888).
- Btrfs: fix off-by-one error of the same page check in
  btrfs_punch_hole() (FATE#312888).
- Btrfs: fix the page that is beyond EOF (FATE#312888).
- Btrfs: punch hole past the end of the file (FATE#312888).
- Btrfs: fix wrong return value of btrfs_truncate_page()
  (FATE#312888).
- btrfs: Notify udev when removing device (FATE#312888).
- Btrfs: rename root_times_lock to root_item_lock (FATE#312888).
- Btrfs: only log the inode item if we can get away with it
  (FATE#312888).
- Btrfs: don't bother copying if we're only logging the inode
  (FATE#312888).
- Btrfs: inline csums if we're fsyncing (FATE#312888).
- Btrfs: move checks in set_page_dirty under DEBUG (FATE#312888).
- Btrfs: keep track of the extents original block length
  (FATE#312888).
- Btrfs: do not mark ems as prealloc if we are writing to them
  (FATE#312888).
- Btrfs: add path->really_keep_locks (FATE#312888).
- Btrfs: log changed inodes based on the extent map tree
  (FATE#312888).
- Btrfs: only clear dirty on the buffer if it is marked as dirty
  (FATE#312888).
- Btrfs: don't memset new tokens (FATE#312888).
- Btrfs: optimize leaf_space_used (FATE#312888).
- Btrfs: use tokens where we can in the tree log (FATE#312888).
- Btrfs: only unlock and relock if we have to (FATE#312888).
- Btrfs: do not call file_update_time in aio_write (FATE#312888).
- Btrfs: fix BUG() in scrub when first superblock reading gives
  EIO (FATE#312888).
- Btrfs: put raid properties into global table (FATE#312888).
- Btrfs: fix permissions of empty files not affected by umask
  (FATE#312888).
- Btrfs: fix autodefrag and umount lockup (FATE#312888).
- Btrfs: don't take inode delalloc mutex if we're a free space
  inode (FATE#312888).
- Btrfs: fix hash overflow handling (FATE#312888).
- Btrfs: fix a bug of per-file nocow (FATE#312888).
- Refresh
  patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch.
- Refresh
  patches.suse/btrfs-8024-workaround-for-cleaner-deadlock.patch.
- Refresh
  patches.suse/btrfs-8077-stop-defrag-the-files-automatically-when-doin-.patch.
- Refresh
  patches.suse/btrfs-8094-flush-all-the-dirty-pages-if-try_to_writeback_.patch.
- Refresh patches.suse/btrfs-8306-disable-qgroup-id-0.patch.
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- Delete
  patches.suse/btrfs-8095-use-writeback_inodes_sb-_nr-_if_idle.patch.
- Delete
  patches.suse/btrfs-8157-fix-a-bug-of-per-file-nocow.patch.
- Delete
  patches.suse/btrfs-8191-use-existing-align-macros-in-btrfs_allocate.patch.
- Delete
  patches.suse/btrfs-8192-fix-off-by-one-error-of-the-reserved-size-of-b.patch.
- Delete patches.suse/btrfs-8193-add-fiemap-s-flag-check.patch.
- Delete
  patches.suse/btrfs-8195-don-t-auto-defrag-a-file-when-doing-directIO.patch.
- Delete
  patches.suse/btrfs-8196-fix-wrong-return-value-of-btrfs_truncate_page.patch.
- Delete
  patches.suse/btrfs-8197-Notify-udev-when-removing-device.patch.
- Delete
  patches.suse/btrfs-8199-fix-permissions-of-empty-files-not-affected-by.patch.
- Delete patches.suse/btrfs-8200-fix-hash-overflow-handling.patch.
- Delete
  patches.suse/btrfs-8300-fix-off-by-one-error-of-the-same-page-check-in.patch.
- Delete patches.suse/btrfs-8301-don-t-memset-new-tokens.patch.
- Delete patches.suse/btrfs-8302-optimize-leaf_space_used.patch.
- Delete
  patches.suse/btrfs-8303-use-tokens-where-we-can-in-the-tree-log.patch.
- Delete
  patches.suse/btrfs-8304-do-not-call-file_update_time-in-aio_write.patch.
- commit bd946bb
* Wed Feb  6 2013 jjolly@suse.de
- IB/mlx4: Check iboe netdev pointer before dereferencing it
  (bnc#795204,FATE#314065,LTC#83200).
- commit 2092a93
* Wed Feb  6 2013 jjolly@suse.de
- mlx4: Add support for EEH error recovery
  (bnc#795204,FATE#314065,LTC#83200).
- commit 2e541b2
* Wed Feb  6 2013 dsterba@suse.cz
- Btrfs: Don't trust the superblock label and simply printk("%%s")
  it (FATE#312888).
- Btrfs: set hole punching time properly (FATE#312888).
- Btrfs: merge inode_list in __merge_refs (FATE#312888).
- Btrfs: cleanup for btrfs_btree_balance_dirty (FATE#312888).
- Btrfs: protect devices list with its mutex (FATE#312888).
- Btrfs: rename the scrub context structure (FATE#312888).
- Btrfs: remove the block device pointer from the scrub context
  struct (FATE#312888).
- Btrfs: make the scrub page array dynamically allocated
  (FATE#312888).
- Btrfs: in scrub repair code, optimize the reading of mirrors
  (FATE#312888).
- Btrfs: in scrub repair code, simplify alloc error handling
  (FATE#312888).
- Btrfs: cleanup scrub bio and worker wait code (FATE#312888).
- Btrfs: move some common code into a subfunction (FATE#312888).
- Btrfs: add two more find_device() methods (FATE#312888).
- Btrfs: Pass fs_info to btrfs_num_copies() instead of
  mapping_tree (FATE#312888).
- Btrfs: pass fs_info to btrfs_map_block() instead of mapping_tree
  (FATE#312888).
- Btrfs: add btrfs_scratch_superblock() function (FATE#312888).
- Btrfs: pass fs_info instead of root (FATE#312888).
- Btrfs: avoid risk of a deadlock in btrfs_handle_error
  (FATE#312888).
- Btrfs: enhance btrfs structures for device replace support
  (FATE#312888).
- Btrfs: introduce a btrfs_dev_replace_item type (FATE#312888).
- Btrfs: disallow mutually exclusive admin operations from user
  mode (FATE#312888).
- Btrfs: disallow some operations on the device replace target
  device (FATE#312888).
- Btrfs: handle errors from btrfs_map_bio() everywhere
  (FATE#312888).
- Btrfs: add code to scrub to copy read data to another disk
  (FATE#312888).
- Btrfs: add new sources for device replace code (FATE#312888).
- Btrfs: change core code of btrfs to support the device replace
  operations (FATE#312888).
- Btrfs: introduce GET_READ_MIRRORS functionality for
  btrfs_map_block() (FATE#312888).
- Btrfs: changes to live filesystem are also written to
  replacement disk (FATE#312888).
- Btrfs: optionally avoid reads from device replace source drive
  (FATE#312888).
- Btrfs: increase BTRFS_MAX_MIRRORS by one for dev replace
  (FATE#312888).
- Btrfs: allow repair code to include target disk when searching
  mirrors (FATE#312888).
- Btrfs: add support for device replace ioctls (FATE#312888).
- Refresh
  patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch.
- Refresh
  patches.suse/btrfs-8021-Prefix-mount-messages-with-btrfs-for-clarity.patch.
- Refresh
  patches.suse/btrfs-8062-push-up-errors-in-btrfs-num-copies.patch.
- Refresh
  patches.suse/btrfs-8077-stop-defrag-the-files-automatically-when-doin-.patch.
- Refresh
  patches.suse/btrfs-8197-Notify-udev-when-removing-device.patch.
- Refresh
  patches.suse/btrfs-8300-fix-off-by-one-error-of-the-same-page-check-in.patch.
- Refresh patches.suse/btrfs-8306-disable-qgroup-id-0.patch.
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- Delete
  patches.suse/btrfs-8188-Don-t-trust-the-superblock-label-and-simply-pr.patch.
- commit 2bbe01c
* Wed Feb  6 2013 tiwai@suse.de
- ALSA: hda - Apply mic-mute LED fixup for new HP laptops
  (bnc#796418).
- commit 9568594
* Wed Feb  6 2013 tiwai@suse.de
- Delete patches.arch/ppc-ipic-suspend-without-83xx-fix.
  It was supposed to be a temporarily fix but surprsingly survived in
  half a decade in our tree.  A fix already in the upstream.  RIP.
- commit 917b745
* Wed Feb  6 2013 mhocko@suse.cz
- patches.fixes/proc-enable-writing-to-proc-pid-mem-revert.patch:
  Refresh.
- commit c259ac6
* Wed Feb  6 2013 jdelvare@suse.de
- patches.drivers/parport-release-io-region-properly.patch:
  Update upstream references.
- commit 24f318a
* Wed Feb  6 2013 jdelvare@suse.de
- Fix patch-mainline tag
- commit 2c5586e
* Wed Feb  6 2013 sjayaraman@suse.com
- patches.fixes/cifs-lower-default-wsize-when-unix-extensions-are-no.patch:
  cifs: lower default wsize when unix extensions are not used
  (bnc#799578).
- commit 3d246c2
* Wed Feb  6 2013 jlee@suse.com
- kexec: Disable in a secure boot environment (fate#314486).
- commit 04336c5
* Wed Feb  6 2013 lduncan@suse.de
- qla4xxx: v5.03.00.01.11.3-k0 (BZ#802095, FATE#313902).
- qla4xxx: Fix return code for qla4xxx_session_get_param
  (BZ#802095, FATE#313902).
- qla4xxx: wait for boot target login response during probe
  (BZ#802095, FATE#313902).
- qla4xxx: Added support for force firmware dump (BZ#802095,
  FATE#313902).
- qla4xxx: Re-register IRQ handler while retrying initialize of
  adapter (BZ#802095, FATE#313902).
- qla4xxx: Throttle active IOCBs to firmware limits (BZ#802095,
  FATE#313902).
- qla4xxx: Remove unnecessary code from qla4xxx_init_local_data
  (BZ#802095, FATE#313902).
- qla4xxx: Quiesce driver activities while loopback (BZ#802095,
  FATE#313902).
- qla4xxx: Rename MBOX_ASTS_IDC_NOTIFY to
  MBOX_ASTS_IDC_REQUEST_NOTIFICATION (BZ#802095, FATE#313902).
- qla4xxx: Add spurious interrupt messages under debug level 2
  (BZ#802095, FATE#313902).
- scsi_transport_iscsi: export iscsi class session's target_id
  in sysfs (BZ#802095, FATE#313902).
- commit fe97e08
* Tue Feb  5 2013 jdelvare@suse.de
- i2c: Adding support for Intel iSMT SMBus 2.0 host controller (FATE#313511).
- Update config files.
- commit 644edb1
* Tue Feb  5 2013 lduncan@suse.de
- cxgb4i: Remove the scsi host device when removing device
  (FATE#314297).
- cxgb4i: tcp push bit fix (FATE#314297).
- commit a4e1ed9
* Tue Feb  5 2013 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit a52e890
* Tue Feb  5 2013 bp@suse.de
- ata_generic: Skip is_intel_ider() check when ata_generic=1 is
  set (bnc#777616).
- commit 681bda8
* Tue Feb  5 2013 bp@suse.de
- patches.drivers/0001-ata_generic-Skip-is_intel_ider-check-when-ata_generi.patch:
  ata_generic: Skip is_intel_ider() check when ata_generic=1 is
  set (bnc#777616).
- commit 4130ba8
* Tue Feb  5 2013 trenn@suse.de
- X86 Intel microcode: Do not request firmware by default
  (bnc#777887,bnc#719291).
- commit 06cee31
* Tue Feb  5 2013 bpoirier@suse.de
- Revert "Refresh"
  This reverts commit ff5854104c016d142338dda1c8537897b0dedb36.
  This was meant to go in at the same time as igbvf and ixgbevf updates.
- commit ba19335
* Tue Feb  5 2013 jeffm@suse.com
- patches.fixes/quota-autoload-the-quota_v2-module-for-qfmt_vfs_v1-quota-format:
  quota: autoload the quota_v2 module for QFMT_VFS_V1 quota format
  (bnc#802153).
- commit 4db7985
* Tue Feb  5 2013 jbeulich@suse.com
- patches.xen/1215-vcpu-availability-field-width.patch: properly
  bound buffer access when parsing cpu/*/availability.
- patches.xen/1219-netback-garbage-ring.patch: netback:
  shutdown the ring if it contains garbage (CVE-2013-0216 XSA-39
  bnc#800280).
- patches.xen/1220-netback-wrap-around.patch: netback: correct
  netbk_tx_err() to handle wrap around (CVE-2013-0216 XSA-39
  bnc#800280).
- patches.xen/1221-pciback-ratelimit.patch: pciback: rate limit
  error message from pciback_enable_msi() (CVE-2013-0231 XSA-43
  bnc#801178).
- patches.xen/1222-backends-cond-resched.patch: scsiback/usbback:
  move cond_resched() invocations to proper place.
- Refresh other Xen patches.
- commit 81f846c
* Tue Feb  5 2013 dsterba@suse.cz
- Btrfs: cleanup duplicated division functions (FATE#312888).
- Btrfs: improve the noflush reservation (FATE#312888).
- Btrfs: recheck bio against block device when we map the bio
  (FATE#312888).
- Btrfs: fix unnecessary while loop when search the free space,
  cache (FATE#312888).
- Btrfs: kill unnecessary arguments in del_ptr (FATE#312888).
- Btrfs: cleanup unused arguments (FATE#312888).
- Btrfs: fill the global reserve when unpinning space
  (FATE#312888).
- Btrfs: make delalloc inodes be flushed by multi-task
  (FATE#312888).
- Btrfs: make ordered operations be handled by multi-task
  (FATE#312888).
- Btrfs: make ordered extent be flushed by multi-task
  (FATE#312888).
- Btrfs: Remove the invalid shrink size check up from
  btrfs_shrink_dev() (FATE#312888).
- Btrfs: don't allow degraded mount if too many devices are
  missing (FATE#312888).
- Btrfs: do not log extents when we only log new names
  (FATE#312888).
- Btrfs: get right arguments for btrfs_wait_ordered_range
  (FATE#312888).
- Btrfs: cleanup for btrfs_wait_order_range (FATE#312888).
- Btrfs: fix joining the same transaction handler more than 2
  times (FATE#312888).
- Btrfs: fix missing flush when committing a transaction
  (FATE#312888).
- Btrfs: fix wrong file extent length (FATE#312888).
- Btrfs: fix unprotected extent map operation when logging file
  extents (FATE#312888).
- Btrfs: fix missing log when BTRFS_INODE_NEEDS_FULL_SYNC is set
  (FATE#312888).
- fs/btrfs: use WARN (FATE#312888).
- fs/btrfs: drop if around WARN_ON (FATE#312888).
- Btrfs: fix a deadlock in aborting transaction due to ENOSPC
  (FATE#312888).
- Btrfs: fix a double free on pending snapshots in error handling
  (FATE#312888).
- Refresh patches.suse/btrfs-8202-Fix-typo-in-fs-btrfs.patch.
- Refresh patches.suse/btrfs-enospc-debugging-messages.patch.
- Refresh patches.suse/btrfs-update-message-levels.patch.
- Delete
  patches.suse/btrfs-8181-fix-unnecessary-while-loop-when-search-the-fre.patch.
- Delete
  patches.suse/btrfs-8184-fill-the-global-reserve-when-unpinning-space.patch.
- Delete
  patches.suse/btrfs-8185-don-t-allow-degraded-mount-if-too-many-devices.patch.
- Delete
  patches.suse/btrfs-8187-fix-a-double-free-on-pending-snapshots-in-erro.patch.
- commit 6cf091c
* Tue Feb  5 2013 dsterba@suse.cz
- clean dead patches
- Delete
  patches.suse/btrfs-0394-increase-the-global-block-reserve-estimates.patch.
- Delete
  patches.suse/btrfs-0701-switch-btrfs_ioctl_snap_create_transid-to-fget_light.patch.
- Delete
  patches.suse/btrfs-0702-switch-btrfs_ioctl_clone-to-fget_light.patch.
- Delete
  patches.suse/btrfs-8042-make-btrfs_truncate_inode_items-more-readable.patch.
- Delete
  patches.suse/btrfs-8043-improve-truncation-of-btrfs.patch.
- Delete
  patches.suse/btrfs-8052-fix-wrong-information-of-the-directory-in-the-.patch.
- Delete
  patches.suse/btrfs-revert-partial-truncate-improvements.patch.
- commit b5e99bb
* Tue Feb  5 2013 jbeulich@suse.com
- Fix up obviously malformed line in
  patches.drivers/tg3-Remove-IS_ENABLED-CONFIG_HWMON-check.patch.
- commit bf82bf0
* Mon Feb  4 2013 bpoirier@suse.de
- tg3: Remove IS_ENABLED(CONFIG_HWMON) check (bnc#790588
  FATE#313912).
- commit 33e149c
* Mon Feb  4 2013 dsterba@suse.cz
- Btrfs: fix race with freeze and free space inodes (FATE#312888).
- Refresh
  patches.suse/btrfs-0776-fix-race-in-sync-and-freeze-again.patch.
- Refresh
  patches.suse/btrfs-0779-kill-obsolete-arguments-in-btrfs_wait_ordered_.patch.
- Refresh
  patches.suse/btrfs-0793-fix-memory-leak-in-start_transaction.patch.
- Refresh
  patches.suse/btrfs-0794-add-a-type-field-for-the-transaction-handle.patch.
- Refresh
  patches.suse/btrfs-0795-fix-orphan-transaction-on-the-freezed-filesyst.patch.
- commit e7e7197
* Mon Feb  4 2013 dsterba@suse.cz
- Update patches.suse/btrfs-0740-add-hole-punching.patch (FATE#312888 bnc#797607).
- commit 3b7a770
* Mon Feb  4 2013 dsterba@suse.cz
- Refresh patches.suse/btrfs-add-no-file-data-flag-to-btrfs-send-ioctl.patch
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch
- commit c6b591c
* Mon Feb  4 2013 eich@suse.com
- patches.drivers/drm-i915-Implement-workaround-for-broken-CS-tlb-on-i830-845.patch:
  drm/i915: Implement workaround for broken CS tlb on i830/845
  (bnc #758040).
- commit cadefbb
* Mon Feb  4 2013 jslaby@suse.cz
- Linux 3.0.62.
- commit 7536c8e
* Fri Feb  1 2013 bpoirier@suse.de
- Refresh
  patches.drivers/rename-dev_hw_addr_random-and-remove-redundant-secon.patch.
- commit 2351946
* Fri Feb  1 2013 bpoirier@suse.de
- Refresh
  patches.drivers/igb-0132-igb-Support-for-modifying-UDP-RSS-flow-hashing.patch.
  Fix warning.
- commit 6cdddaa
* Fri Feb  1 2013 ohering@suse.de
- patches.suse/suse-hv-Drivers-scsi-storvsc-Initialize-the-sglist.patch:
  Drivers: scsi: storvsc: Initialize the sglist.
- commit 3546284
* Fri Feb  1 2013 bpoirier@suse.de
- supported.conf: Fix qlcnic entry
- commit 0770ef1
* Fri Feb  1 2013 bpoirier@suse.de
- qlcnic: Bump up the version to 5.1.33 (bnc#800999 FATE#313899).
- qlcnic: Fix RX/TX checksum setting for some adapter types
  (bnc#800999 FATE#313899).
- qlcnic: Fix minidump in NPAR mode (bnc#800999 FATE#313899).
- qlcnic: driver LRO bug fix (bnc#800999 FATE#313899).
- qlcnic: Free irq for mailbox interrupts (bnc#800999
  FATE#313899).
- qlcnic: Fix bug in reading HW reset template (bnc#800999
  FATE#313899).
- qlcnic: Fix sparse check endian warnings (bnc#800999
  FATE#313899).
- qlcnic: Bump up the version to 5.1.32 (bnc#800999 FATE#313899).
- qlcnic: sleeping function called from invalid context
  (bnc#800999 FATE#313899).
- qlcnic: Fix LED/Beaconing tests to work on all ports of an
  adapter (bnc#800999 FATE#313899).
- qlcnic: avoid mixed mode interrupts for some adapter types
  (bnc#800999 FATE#313899).
- qlcnic: enable RSS for TCP over IPv6 (bnc#800999 FATE#313899).
- qlcnic: enable LRO on IPv6 without dest ip check (bnc#800999
  FATE#313899).
- qlcnic: set driver version in firmware (bnc#800999 FATE#313899).
- remove init of dev->perm_addr in drivers (bnc#800999
  FATE#313899).
- qlcnic: guard __vlan_find_dev_deep() by rcu_read_lock
  (bnc#800999 FATE#313899).
- qlcnic: fix build error (bnc#800999 FATE#313899).
- qlcnic: do not duplicate infrastructure functions (bnc#800999
  FATE#313899).
- qlcnic: update driver version (bnc#800999 FATE#313899).
- qlcnic: remove unused definitions from header file (bnc#800999
  FATE#313899).
- qlcnic: 83xx ethtool interface routines (bnc#800999
  FATE#313899).
- qlcnic: 83xx register dump routines (bnc#800999 FATE#313899).
- qlcnic: enable 83xx virtual NIC mode (bnc#800999 FATE#313899).
- qlcnic: flash template based firmware reset recovery (bnc#800999
  FATE#313899).
- qlcnic: 83xx CNA inter driver communication mechanism
  (bnc#800999 FATE#313899).
- qlcnic: 83xx adpater flash interface routines (bnc#800999
  FATE#313899).
- qlcnic: 83xx sysfs routines (bnc#800999 FATE#313899).
- qlcnic: 83xx base driver (bnc#800999 FATE#313899).
- qlcnic: 83xx data path routines (bnc#800999 FATE#313899).
- qlcnic: 83xx memory map and HW access routines (bnc#800999
  FATE#313899).
- qlcnic: macros for common register access (bnc#800999
  FATE#313899).
- qlcnic: change driver hardware interface mechanism (bnc#800999
  FATE#313899).
- qlcnic: update driver version (bnc#800999 FATE#313899).
- qlcnic: fix unused variable warnings (bnc#800999 FATE#313899).
- qlcnic: rename module params with module_param_named (bnc#800999
  FATE#313899).
- qlcnic: fix bug in LRO descriptor access macro (bnc#800999
  FATE#313899).
- qlcnic: update NIC partition interface routines (bnc#800999
  FATE#313899).
- qlcnic: get board name API (bnc#800999 FATE#313899).
- qlcnic: modify PCI and register access routines (bnc#800999
  FATE#313899).
- qlcnic: move HW specific data to seperate structure (bnc#800999
  FATE#313899).
- qlcnic: add 82xx adapter specific checks (bnc#800999
  FATE#313899).
- qlcnic: remove __dev* attributes (bnc#800999 FATE#313899).
- qlcnic: remove duplicated include from qlcnic_sysfs.c
  (bnc#800999 FATE#313899).
- qlcnic: fix coding style issues in qlcnic_minidump.c (bnc#800999
  FATE#313899).
- qlcnic: create file qlcnic_minidump.c for dump utility
  (bnc#800999 FATE#313899).
- qlcnic: fix style issues in qlcnic_sysfs.c file (bnc#800999
  FATE#313899).
- qlcnic: create file qlcnic_sysfs.c for sysfs routines
  (bnc#800999 FATE#313899).
- qlcnic: fix coding style issues in qlcnic_io.c (bnc#800999
  FATE#313899).
- qlcnic: create file qlcnic_io.c for datapath routines
  (bnc#800999 FATE#313899).
- qlcnic: fix sparse check endian warnings (bnc#800999
  FATE#313899).
- qlcnic: fix sparse warnings (bnc#800999 FATE#313899).
- qlcnic: fix compiler warnings (bnc#800999 FATE#313899).
- drivers/net/ethernet/qlogic/qlcnic/qlcnic_main.c: fix error
  return code (bnc#800999 FATE#313899).
- qlcnic: Fix scheduling while atomic bug (bnc#800999
  FATE#313899).
- qlcnic: remove unnecessary setting of skb->dev (bnc#800999
  FATE#313899).
- qlcnic: off by one in qlcnic_init_pci_info() (bnc#800999
  FATE#313899).
- commit a6f7b54
* Fri Feb  1 2013 jkosina@suse.cz
- Upstream TIPC update, from Ericsson
- tipc: Convert fatal broadcast sanity check to non-fatal check
  (bnc#797455).
- tipc: Remove unused sanity test macro (bnc#797455).
- tipc: Standardize exit logic for message rejection handling
  (bnc#797455).
- tipc: Add sanity check to detect rejection of non-payload
  messages (bnc#797455).
- tipc: Optimize routing of returned payload messages
  (bnc#797455).
- tipc: Optimizations & corrections to message rejection
  (bnc#797455).
- tipc: Eliminate message header routines for caching destination
  node (bnc#797455).
- tipc: Eliminate redundant masking in message header routines
  (bnc#797455).
- tipc: Partition name table instance array info into two parts
  (bnc#797455).
- tipc: Convert name table publication lists to standard kernel
  lists (bnc#797455).
- tipc: Eliminate checks for empty zone list during name
  translation (bnc#797455).
- tipc: Correct typo in link statistics output (bnc#797455).
- tipc: Eliminate unused field in bearer structure (bnc#797455).
- tipc: Remove unnecessary includes in socket code (bnc#797455).
- tipc: Eliminate useless check when creating internal message
  (bnc#797455).
- tipc: Cleanup of message header size terminology (bnc#797455).
- tipc: Optimize creation of FIN messages (bnc#797455).
- tipc: Reject connection protocol message sent to unconnected
  port (bnc#797455).
- tipc: Don't create payload message using connection protocol
  routine (bnc#797455).
- tipc: Optimize creation of connection protocol messages
  (bnc#797455).
- atomic: use <linux/atomic.h> (bnc#797455).
- tipc: Remove obsolete manipulation of message re-route count
  field (bnc#797455).
- tipc: Eliminate obsolete filter for unexpected unicast messages
  (bnc#797455).
- tipc: Display meaningful peer interface name during link
  creation (bnc#797455).
- tipc: Initialize peer session field of newly created link
  endpoint (bnc#797455).
- tipc: Enhance filtering of out-dated link reset messages
  (bnc#797455).
- tipc: Update obsolete references to multicast link (bnc#797455).
- tipc: Cosmetic changes to broadcast bearer send routine
  (bnc#797455).
- tipc: Remove non-executable code to handle broadcast bearer
  congestion (bnc#797455).
- tipc: Enhance cleanup of broadcast link when contact with node
  is lost (bnc#797455).
- tipc: Prevent broadcast link stalling when another node fails
  (bnc#797455).
- tipc: Fix node lock problems during broadcast message reception
  (bnc#797455).
- tipc: Remove deferred queue head caching during broadcast
  message reception (bnc#797455).
- tipc: Discard incoming broadcast messages that are unexpected
  (bnc#797455).
- tipc: Remove obsolete congestion handling when sending a
  broadcast NACK (bnc#797455).
- tipc: Eliminate redundant check when sending messages
  (bnc#797455).
- tipc: Prevent rounding issues when saving connect timeout option
  (bnc#797455).
- tipc: Ensure congested links receive bearer status updates
  (bnc#797455).
- tipc: Ensure both nodes recognize loss of contact between them
  (bnc#797455).
- tipc: Fix unsafe device list search when enabling bearer
  (bnc#797455).
- tipc: Remove redundant search when enabling bearer (bnc#797455).
- tipc: Lower limits for number of bearers and media types
  (bnc#797455).
- tipc: Prevent fragmented messages during initial name table
  exchange (bnc#797455).
- tipc: relocate/coalesce node cast in tipc_named_node_up
  (bnc#797455).
- tipc: Enhance sending of bulk name table messages (bnc#797455).
- tipc: Add support for SO_SNDTIMEO socket option (bnc#797455).
- tipc: Simplify prohibition of listen and accept for
  connectionless sockets (bnc#797455).
- tipc: Remove callback field from subscription structure
  (bnc#797455).
- tipc: Remove unused link event tracking code (bnc#797455).
- net: Fix files explicitly needing to include module.h
  (bnc#797455).
- net: two vzalloc() cleanups (bnc#797455).
- tipc: Enable use by containers having their own network
  namespace (bnc#797455).
- tipc: Register new media using pre-compiled structure
  (bnc#797455).
- tipc: Optimize detection of duplicate media registration
  (bnc#797455).
- tipc: Eliminate duplication of media structures (bnc#797455).
- tipc: Streamline media registration error checking (bnc#797455).
- tipc: Improve handling of media address printing errors
  (bnc#797455).
- tipc: Add new address conversion routines for Ethernet media
  (bnc#797455).
- tipc: Hide media-specific addressing details from generic
  bearer code (bnc#797455).
- tipc: Ignore neighbor discovery messages containing invalid
  address (bnc#797455).
- tipc: Allow run-time alteration of default link settings
  (bnc#797455).
- tipc: Revise comment justifying release of configuration
  spinlock (bnc#797455).
- tipc: Minor optimization to deactivation of Ethernet media
  suppot (bnc#797455).
- tipc: Do timely cleanup of disabled Ethernet bearer resources
  (bnc#797455).
- tipc: Eliminate useless memset operations in Ethernet media
  support (bnc#797455).
- tipc: Minor correction to TIPC module unloading (bnc#797455).
- tipc: Eliminate useless check when network address is assigned
  (bnc#797455).
- tipc: Eliminate dynamic allocation of broadcast link data
  structures (bnc#797455).
- tipc: Ensure broadcast link spinlock is held when updating
  node map (bnc#797455).
- tipc: Handle broadcast attempt when no neighboring nodes exist
  (bnc#797455).
- tipc: Minor optimization of broadcast link transmit queue
  statistic (bnc#797455).
- tipc: Flush unsent broadcast messages when contact with last
  node is lost (bnc#797455).
- tipc: Ignore broadcast acknowledgements that are out-of-range
  (bnc#797455).
- tipc: Allow use of buf_seqno() helper routine by unicast links
  (bnc#797455).
- tipc: rename struct media to struct tipc_media (bnc#797455).
- tipc: rename struct port_list to struct tipc_port_list
  (bnc#797455).
- tipc: rename struct subscription to struct tipc_subscription
  (bnc#797455).
- tipc: rename struct subscriber to struct tipc_subscriber
  (bnc#797455).
- tipc: rename struct bclink to struct tipc_bclink (bnc#797455).
- tipc: rename struct bcbearer* to tipc_bcbearer* (bnc#797455).
- tipc: rename struct link* to struct tipc_link* (bnc#797455).
- tipc: rename struct bearer_name to struct tipc_bearer_names
  (bnc#797455).
- tipc: improve the link deferred queue insertion algorithm
  (bnc#797455).
- tipc: Prevent transmission of outdated link protocol messages
  (bnc#797455).
- tipc: Prevent broadcast link stalling in dual LAN environments
  (bnc#797455).
- tipc: Ensure broadcast link re-acquires node after link failure
  (bnc#797455).
- tipc: Fix problem with broadcast link synchronization between
  nodes (bnc#797455).
- tipc: Add missing broadcast link lock when sending NACK
  (bnc#797455).
- tipc: Fix node lock reclamation issues in broadcast link
  reception (bnc#797455).
- tipc: Fix bug in broadcast link duplicate message statistics
  (bnc#797455).
- tipc: Add missing locks in broadcast link statistics
  accumulation (bnc#797455).
- tipc: Major redesign of broadcast link ACK/NACK algorithms
  (bnc#797455).
- tipc: Remove obsolete broadcast tag capability (bnc#797455).
- tipc: Prevent loss of fragmented messages over unicast links
  (bnc#797455).
- tipc: Prevent loss of fragmented messages over broadcast link
  (bnc#797455).
- tipc: Eliminate alteration of publication key during name
  table purging (bnc#797455).
- tipc: Minor optimization to rejection of connection-based
  messages (bnc#797455).
- tipc: Introduce node signature field in neighbor discovery
  message (bnc#797455).
- tipc: Detect duplicate nodes using different network interfaces
  (bnc#797455).
- tipc: Remove duplicate check of message destination node
  (bnc#797455).
- tipc: Simplify enforcement of reserved name type prohibition
  (bnc#797455).
- tipc: Add check to prevent insertion of duplicate name table
  entries (bnc#797455).
- tipc: nuke the delimit static inline function (bnc#797455).
- tipc: Eliminate a test for negative unsigned quantities
  (bnc#797455).
- tipc: Hide internal details of node table implementation
  (bnc#797455).
- tipc: Eliminate trivial buffer manipulation helper routines
  (bnc#797455).
- tipc: Remove obsolete comments about routing table updates
  (bnc#797455).
- tipc: Minor optimization to broadcast link synchronization logic
  (bnc#797455).
- tipc: Revert name table translation optimization (bnc#797455).
- tipc: Eliminate obsolete support for "not running" mode
  (bnc#797455).
- tipc: Eliminate support for tipc_mode global variable
  (bnc#797455).
- tipc: Un-inline port routine for processing incoming messages
  (bnc#797455).
- tipc: Eliminate obsolete code for re-sending a message
  (bnc#797455).
- tipc: Optimize setting of immutable payload message header
  fields (bnc#797455).
- net: cleanup unsigned to unsigned int (bnc#797455).
- tipc: introduce publication lists struct (bnc#797455).
- tipc: Factor out name publication code to a separate function
  (bnc#797455).
- tipc: Separate cluster-scope and zone-scope names into distinct
  lists (bnc#797455).
- tipc: Update node-scope publications when network address is
  assigned (bnc#797455).
- tipc: Don't record failed publication attempt as a success
  (bnc#797455).
- tipc: Add routines for safe checking of node's network address
  (bnc#797455).
- tipc: Ensure network address change doesn't impact name table
  updates (bnc#797455).
- tipc: Optimize re-initialization of port message header
  templates (bnc#797455).
- tipc: Ensure network address change doesn't impact new port
  (bnc#797455).
- tipc: delete duplicate peerport/peernode helper functions
  (bnc#797455).
- tipc: Ensure network address change doesn't impact local
  connections (bnc#797455).
- tipc: take lock while updating node network address
  (bnc#797455).
- tipc: properly handle off-node send requests with invalid addr
  (bnc#797455).
- tipc: handle <0.0.0> as an alias for this node on outgoing msgs
  (bnc#797455).
- tipc: Ensure network address change doesn't impact rejected
  message (bnc#797455).
- tipc: Ensure network address change doesn't impact configuration
  service (bnc#797455).
- tipc: remove inline instances from C source files (bnc#797455).
- tipc: Optimize re-initialization of configuration service
  (bnc#797455).
- tipc: Optimize initialization of configuration service
  (bnc#797455).
- tipc: Optimize termination of configuration service
  (bnc#797455).
- tipc: Enhance re-initialization of network topology service
  (bnc#797455).
- tipc: Optimize initialization of network topology service
  (bnc#797455).
- tipc: remove redundant memset and stale comment from subscr.c
  (bnc#797455).
- tipc: Create helper routine to delete unused name sequence
  structure (bnc#797455).
- tipc: Enhance error checking of published names (bnc#797455).
- tipc: Reject payload messages with invalid message type
  (bnc#797455).
- tipc: compress out gratuitous extra carriage returns
  (bnc#797455).
- net: Remove casts to same type (bnc#797455).
- net: Fix (nearly-)kernel-doc comments for various functions
  (bnc#797455).
- net: Fix non-kernel-doc comments with kernel-doc start marker
  (bnc#797455).
- tipc: factor stats struct out of the larger link struct
  (bnc#797455).
- tipc: limit error messages relating to memory leak to one line
  (bnc#797455).
- tipc: use standard printk shortcut macros (pr_err
  etc.) (bnc#797455).
- tipc: remove TIPC packet debugging functions and macros
  (bnc#797455).
- tipc: simplify link_print by divorcing it from using tipc_printf
  (bnc#797455).
- tipc: simplify print buffer handling in tipc_printf
  (bnc#797455).
- tipc: phase out most of the struct print_buf usage (bnc#797455).
- tipc: remove print_buf and deprecated log buffer code
  (bnc#797455).
- tipc: optimize the initialization of network device notifier
  (bnc#797455).
- tipc: fix lockdep warning during bearer initialization
  (bnc#797455).
- tipc: remove pointless name sanity check and tipc_alphabet array
  (bnc#797455).
- tipc: manually inline single use media_name_valid routine
  (bnc#797455).
- tipc: change tipc_net_start routine return value type
  (bnc#797455).
- tipc: convert tipc_nametbl_size type from variable to macro
  (bnc#797455).
- tipc: add __read_mostly annotations to several global variables
  (bnc#797455).
- tipc: eliminate configuration for maximum number of name
  subscriptions (bnc#797455).
- tipc: eliminate configuration for maximum number of name
  publications (bnc#797455).
- net/tipc/name_table.c: Remove unecessary semicolon (bnc#797455).
- tipc: prevent dropped connections due to rcvbuf overflow
  (bnc#797455).
- tipc: do not use tasklet_disable before tasklet_kill
  (bnc#797455).
- tipc: fix race/inefficiencies in poll/wait behaviour
  (bnc#797455).
- tipc: return POLLOUT for sockets in an unconnected state
  (bnc#797455).
- tipc: wake up all waiting threads at socket shutdown
  (bnc#797455).
- tipc: remove the bearer congestion mechanism (bnc#797455).
- tipc: remove supportable flag from bclink structure
  (bnc#797455).
- tipc: rename supported flag to recv_permitted (bnc#797455).
- tipc: introduce message to synchronize broadcast link
  (bnc#797455).
- tipc: eliminate an unnecessary cast of node variable
  (bnc#797455).
- tipc: delete TIPC_ADVANCED Kconfig variable (bnc#797455).
- tipc: remove obsolete flush of stale reassembly buffer
  (bnc#797455).
- tipc: eliminate aggregate sk_receive_queue limit (bnc#797455).
- tipc: change sk_receive_queue upper limit (bnc#797455).
- tipc: standardize across connect/disconnect function naming
  (bnc#797455).
- tipc: consolidate connection-oriented message reception in
  one function (bnc#797455).
- tipc: introduce non-blocking socket connect (bnc#797455).
- tipc: eliminate connection setup for implied connect in
  recv_msg() (bnc#797455).
- tipc: add lock nesting notation to quiet lockdep warning
  (bnc#797455).
- tipc: refactor accept() code for improved readability
  (bnc#797455).
- Update config files.
- commit 20dba75
* Fri Feb  1 2013 tiwai@suse.de
- ALSA: hda - Yet another fix for broken HSW HDMI pin connections
  (bnc#801713).
- ALSA: hda - Release assigned pin/cvt at error path of
  hdmi_pcm_open() (bnc#801713).
- ALSA - HDA: New PCI ID for Haswell ULT (bnc#801713).
- commit 261e6f9
* Thu Jan 31 2013 bpoirier@suse.de
- drivers/net: fix up function prototypes after __dev* removals
  (bnc#795297 FATE#313656).
- igb: Update igb version to 4.1.2 (bnc#795297 FATE#313656).
- igb: release already assigned MSI-X interrupts if setup fails
  (bnc#795297 FATE#313656).
- igb: remove duplicate code for fallback interrupt initialization
  (bnc#795297 FATE#313656).
- net/intel: remove __dev* attributes (bnc#795297 FATE#313656).
- igb: Fix SerDes autoneg flow control (bnc#795297 FATE#313656).
- igb: Unset sigdetect for SERDES loopback on 82580 and i350
  (bnc#795297 FATE#313656).
- igb: Workaround for global device reset problem on 82580
  (bnc#795297 FATE#313656).
- igb: Refactoring of i210 file (bnc#795297 FATE#313656).
- igb: Acquire, release semaphore for writing each EEPROM page
  (bnc#795297 FATE#313656).
- igb: Updates to read nvm function for i211 device (bnc#795297
  FATE#313656).
- igb: Use a 32-bit mask when calculating the flow control
  watermarks (bnc#795297 FATE#313656).
- igb: Do not parse past IP header on fragments beyond the first
  (bnc#795297 FATE#313656).
- igb: No longer rely on APME to determine WoL settings
  (bnc#795297 FATE#313656).
- igb: Update PTP Rx filters (bnc#795297 FATE#313656).
- igb: Improve performance and reduce size of igb_tx_map
  (bnc#795297 FATE#313656).
- igb: Update igb Tx flags to improve code efficiency (bnc#795297
  FATE#313656).
- igb: Make TSO check for CHECKSUM_PARTIAL to avoid skb_is_gso
  check (bnc#795297 FATE#313656).
- igb: Support for modifying UDP RSS flow hashing (bnc#795297
  FATE#313656).
- igb: Clear Go Link Disconnect for 82580 and later devices
  (bnc#795297 FATE#313656).
- igb: Fix EEPROM writes via ethtool on i210 (bnc#795297
  FATE#313656).
- igb: Add function to read i211's invm version (bnc#795297
  FATE#313656).
- igb: Remove workaround for EEE configuration on i210/I211
  (bnc#795297 FATE#313656).
- igb: Fix sparse warning in igb_ptp_rx_pktstamp (bnc#795297
  FATE#313656).
- igb: Update firmware version info for ethtool output (bnc#795297
  FATE#313656).
- igb: Enable auto-crossover during forced operation on 82580
  and above (bnc#795297 FATE#313656).
- igb: Update get cable length function for i210/i211 (bnc#795297
  FATE#313656).
- igb: Split igb_update_dca into separate Tx and Rx functions
  (bnc#795297 FATE#313656).
- igb: Move the calls to set the Tx and Rx queues into igb_open
  (bnc#795297 FATE#313656).
- igb: Combine q_vector and ring allocation into a single function
  (bnc#795297 FATE#313656).
- igb: Lock buffer size at 2K even on systems with larger pages
  (bnc#795297 FATE#313656).
- igb: Move rx_buffer related code in Rx cleanup path into
  separate function (bnc#795297 FATE#313656).
- igb: Map entire page and sync half instead of mapping and
  unmapping half pages (bnc#795297 FATE#313656).
- igb: Combine post-processing of skb into a single function
  (bnc#795297 FATE#313656).
- igb: Do not use header split, instead receive all frames into
  a single buffer (bnc#795297 FATE#313656).
- igb: Split Rx timestamping into two separate functions
  (bnc#795297 FATE#313656).
- igb: Correcting and improving small packet check and padding
  (bnc#795297 FATE#313656).
- igb: Use dma_unmap_addr and dma_unmap_len defines (bnc#795297
  FATE#313656).
- igb: Simplify how we populate the RSS key (bnc#795297
  FATE#313656).
- igb: Change how we populate the RSS indirection table
  (bnc#795297 FATE#313656).
- igb: Change Tx cleanup loop to do/while instead of for
  (bnc#795297 FATE#313656).
- igb: Remove logic that was doing NUMA pseudo-aware allocations
  (bnc#795297 FATE#313656).
- igb: Fix stats output on i210/i211 parts (bnc#795297
  FATE#313656).
- igb: Change how we check for pre-existing and assigned VFs
  (bnc#795297 FATE#313656).
- igb: Support to enable EEE on all eee_supported devices
  (bnc#795297 FATE#313656).
- igb: Remove artificial restriction on RQDPC stat reading
  (bnc#795297 FATE#313656).
- igb: Add 1588 support to I210/I211 (bnc#795297 FATE#313656).
- igb: Prevent dropped Tx timestamps via work items and interrupts
  (bnc#795297 FATE#313656).
- igb: Store the MAC address in the name in the PTP struct
  (bnc#795297 FATE#313656).
- igb: Correct PTP support query from ethtool (bnc#795297
  FATE#313656).
- igb: Update PTP function names/variables and locations
  (bnc#795297 FATE#313656).
- igb: Tidy up wrapping for CONFIG_IGB_PTP (bnc#795297
  FATE#313656).
- netdev: make pci_error_handlers const (bnc#795297 FATE#313656).
- igb: Supported and Advertised Pause Frame (bnc#795297
  FATE#313656).
- igb: reduce Rx header size (bnc#795297 FATE#313656).
- igb: Add loopback test support for i210 (bnc#795297
  FATE#313656).
- igb: Use PCI Express Capability accessors (bnc#795297
  FATE#313656).
- igb: update to allow reading/setting MDI state (bnc#795297
  FATE#313656).
- igb: implement 580 MDI setting support (bnc#795297 FATE#313656).
- igb: Fix register defines for all non-82575 hardware (bnc#795297
  FATE#313656).
- igb: fix panic while dumping packets on Tx hang with IOMMU
  (bnc#795297 FATE#313656).
- igb: add delay to allow igb loopback test to succeed on
  8086:10c9 (bnc#795297 FATE#313656).
- igb: don't break user visible strings over multiple lines in
  igb_ethtool.c (bnc#795297 FATE#313656).
- igb: correct hardware type (i210/i211) check in
  igb_loopback_test() (bnc#795297 FATE#313656).
- igb: Fix for failure to init on some 82576 devices (bnc#795297
  FATE#313656).
- igb: reset PHY in the link_up process to recover PHY setting
  after power down (bnc#795297 FATE#313656).
- igb: Update firmware info output (bnc#795297 FATE#313656).
- igb: Streamline RSS queue and queue pairing assignment logic
  (bnc#795297 FATE#313656).
- igb: Support the get_ts_info ethtool method (bnc#795297
  FATE#313656).
- igb: Add switch case for supported hardware to igb_ptp_remove
  (bnc#795297 FATE#313656).
- igb: A fix to VF TX rate limit (bnc#795297 FATE#313656).
- igb: Fix incorrect RAR address entries for i210/i211 device
  (bnc#795297 FATE#313656).
- igb: Disable the BMC-to-OS Watchdog Enable bit for DMAC
  (bnc#795297 FATE#313656).
- igb: Add Support for new i210/i211 devices (bnc#795297
  FATE#313656).
- igb: Add function and pointers for 82580 low power state
  settings (bnc#795297 FATE#313656).
- igb: fix rtnl race in PM resume path (bnc#795297 FATE#313656).
- igb: output register's information related to RX/TX queue
  (bnc#795297 FATE#313656).
- igb: Force flow control off during reset when forcing speed
  (bnc#795297 FATE#313656).
- igb: offer a PTP Hardware Clock instead of the timecompare
  method (bnc#795297 FATE#313656).
- commit 2cdc0bd
* Thu Jan 31 2013 bpoirier@suse.de
- igb: add PTP Hardware Clock code (bnc#795297 FATE#313656).
- intel: make wired ethernet driver message level consistent
  (rev2) (bnc#795297 FATE#313656).
- igb: Support sending custom Ethernet FCS (bnc#795297
  FATE#313656).
- igb: fix ethtool offline test (bnc#795297 FATE#313656).
- igb: fix warning about unused function (bnc#795297 FATE#313656).
- igb: fix vf lookup (bnc#795297 FATE#313656).
- igb: Update Copyright on all Intel copyrighted files (bnc#795297
  FATE#313656).
- igb: make local functions static (bnc#795297 FATE#313656).
- igb: add basic runtime PM support (bnc#795297 FATE#313656).
- igb: Add support for byte queue limits (bnc#795297 FATE#313656).
- igb: Add flow control advertising to ethtool setting (bnc#795297
  FATE#313656).
- igb: Update DMA Coalescing threshold calculation (bnc#795297
  FATE#313656).
- igb: Convert bare printk to pr_notice (bnc#795297 FATE#313656).
- igb: Convert printks to pr_<level> (bnc#795297 FATE#313656).
- Sweep the last of the active .get_drvinfo floors under ethernet/
  (bnc#795297 FATE#313656).
- igb: Fix for I347AT4 PHY cable length unit detection (bnc#795297
  FATE#313656).
- igb: VFTA Table Fix for i350 devices (bnc#795297 FATE#313656).
- igb: Move DMA Coalescing init code to separate function
  (bnc#795297 FATE#313656).
- igb: fix a compile warning (bnc#795297 FATE#313656).
- net: add skb frag size accessors (bnc#795297 FATE#313656).
- igb: Check if subordinate VFs are assigned to virtual machines
  (bnc#795297 FATE#313656).
- igb: enable l4 timestamping for v2 event packets (bnc#795297
  FATE#313656).
- igb: fix skb truesize underestimation (bnc#795297 FATE#313656).
- igb: Loopback functionality supports for i350 devices
  (bnc#795297 FATE#313656).
- igb: fix static function warnings reported by sparse (bnc#795297
  FATE#313656).
- igb: Add workaround for byte swapped VLAN on i350 local traffic
  (bnc#795297 FATE#313656).
- igb: Drop unnecessary write of E1000_IMS from igb_msix_other
  (bnc#795297 FATE#313656).
- igb: Fix features that are currently 82580 only and should
  also be i350 (bnc#795297 FATE#313656).
- igb: Make certain one vector is always assigned in
  igb_request_irq (bnc#795297 FATE#313656).
- igb: avoid unnecessarily creating a local copy of the q_vector
  (bnc#795297 FATE#313656).
- igb: add support for NETIF_F_RXHASH (bnc#795297 FATE#313656).
- igb: move TX hang check flag into ring->flags (bnc#795297
  FATE#313656).
- igb: leave staterr in place and instead us a helper function
  to check bits (bnc#795297 FATE#313656).
- igb: retire the RX_CSUM flag and use the netdev flag instead
  (bnc#795297 FATE#313656).
- igb: cleanup IVAR configuration (bnc#795297 FATE#313656).
- igb: Move ITR related data into work container within the
  q_vector (bnc#795297 FATE#313656).
- igb: Consolidate all of the ring feature flags into a single
  value (bnc#795297 FATE#313656).
- igb: avoid unnecessary conversions from u16 to int (bnc#795297
  FATE#313656).
- igb: Use node specific allocations for the q_vectors and rings
  (bnc#795297 FATE#313656).
- igb: push data into first igb_tx_buffer sooner to reduce stack
  usage (bnc#795297 FATE#313656).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#795297 FATE#313656).
- igb: consolidate creation of Tx buffer info and data descriptor
  (bnc#795297 FATE#313656).
- igb: Combine all flag info fields into a single tx_flags
  structure (bnc#795297 FATE#313656).
- igb: Cleanup protocol handling in transmit path (bnc#795297
  FATE#313656).
- igb: Create separate functions for generating cmd_type and
  olinfo (bnc#795297 FATE#313656).
- igb: Make first and tx_buffer_info->next_to_watch into pointers
  (bnc#795297 FATE#313656).
- igb: Consolidate creation of Tx context descriptors into a
  single function (bnc#795297 FATE#313656).
- igb: split buffer_info into tx_buffer_info and rx_buffer_info
  (bnc#795297 FATE#313656).
- igb: Make Tx budget for NAPI user adjustable (bnc#795297
  FATE#313656).
- igb: Alternate MAC Address Updates for Func2&3 (bnc#795297
  FATE#313656).
- igb: Alternate MAC Address EEPROM Updates (bnc#795297
  FATE#313656).
- igb: Code to prevent overwriting SFP I2C (bnc#795297
  FATE#313656).
- igb: Remove multi_tx_table and simplify igb_xmit_frame
  (bnc#795297 FATE#313656).
- igb: Replace E1000_XX_DESC_ADV with IGB_XX_DESC (bnc#795297
  FATE#313656).
- igb: drop the "adv" off function names relating to descriptors
  (bnc#795297 FATE#313656).
- igb: Refactor clean_rx_irq to reduce overhead and improve
  performance (bnc#795297 FATE#313656).
- igb: update ring and adapter structure to improve performance
  (bnc#795297 FATE#313656).
- igb: streamline Rx buffer allocation and cleanup (bnc#795297
  FATE#313656).
- igb: drop support for single buffer mode (bnc#795297
  FATE#313656).
- igb: Update max_frame_size to account for an optional VLAN
  tag if present (bnc#795297 FATE#313656).
- igb: Update RXDCTL/TXDCTL configurations (bnc#795297
  FATE#313656).
- intel: convert to SKB paged frag API (bnc#795297 FATE#313656).
- commit 60b37c7
* Thu Jan 31 2013 bpoirier@suse.de
- intel: Move the Intel wired LAN drivers (bnc#795297
  FATE#313656).
- Update config files.
- supported.conf:
- commit 8938618
* Thu Jan 31 2013 bpoirier@suse.de
- intel drivers: repair missing flush operations (bnc#795297
  FATE#313656).
- igb: remove duplicated #include (bnc#795297 FATE#313656).
- igb: Fix for DH89xxCC near end loopback test (bnc#795297
  FATE#313656).
- igb: Add support of SerDes Forced mode for certain hardware
  (bnc#795297 FATE#313656).
- igb: Update copyright on all igb driver files (bnc#795297
  FATE#313656).
- net: igb: Use is_multicast_ether_addr helper (bnc#795297
  FATE#313656).
- igb: remove unnecessary reads of PCI_CAP_ID_EXP (bnc#795297
  FATE#313656).
- igb: Change version to remove number after -k in kernel versions
  (bnc#795297 FATE#313656).
- commit 9fce65e
* Thu Jan 31 2013 oneukum@suse.de
- patches.suse/0001-elousb-really-long-delays-for-broken-devices.patch:
  elousb: really long delays for broken devices (bnc#795269).
- commit c2424da
* Thu Jan 31 2013 oneukum@suse.de
- patches.drivers/0001-xhci-Fix-conditional-check-in-bandwidth-calculation.patch:
  xhci: Fix conditional check in bandwidth calculation
  (bnc#795961).
- commit f2c06a3
* Thu Jan 31 2013 oneukum@suse.de
- patches.drivers/0001-xHCI-Fix-TD-Size-calculation-on-1.0-hosts.patch:
  xHCI: Fix TD Size calculation on 1.0 hosts (bnc#795957).
- commit 9b64d2c
* Thu Jan 31 2013 brogers@suse.com
- Update config files.
- commit b509c0e
* Thu Jan 31 2013 jeffm@suse.com
- patches.suse/block-add-dev_check_rdonly-and-friends-for-lustre-testing: Fixed
  NULL deref during __blkdev_put.
- commit 5b63dec
* Wed Jan 30 2013 brogers@suse.com
- capabilities: introduce security_capable_noaudit (FATE#313982
  bnc#799030).
- Add PR_{GET,SET}_NO_NEW_PRIVS to prevent execve from granting
  privs (FATE#313982 bnc#799030).
- Fix execve behavior apparmor for PR_{GET,SET}_NO_NEW_PRIVS
  (FATE#313982 bnc#799030).
- sk_run_filter: add BPF_S_ANC_SECCOMP_LD_W (FATE#313982
  bnc#799030).
- net/compat.c,linux/filter.h: share compat_sock_fprog
  (FATE#313982 bnc#799030).
- seccomp: kill the seccomp_t typedef (FATE#313982 bnc#799030).
- asm/syscall.h: add syscall_get_arch (FATE#313982 bnc#799030).
- arch/x86: add syscall_get_arch to syscall.h (FATE#313982
  bnc#799030).
- seccomp: add system call filtering using BPF (FATE#313982
  bnc#799030).
- seccomp: remove duplicated failure logging (FATE#313982
  bnc#799030).
- seccomp: add SECCOMP_RET_ERRNO (FATE#313982 bnc#799030).
- signal, x86: add SIGSYS info and make it synchronous
  (FATE#313982 bnc#799030).
- seccomp: Add SECCOMP_RET_TRAP (FATE#313982 bnc#799030).
- ptrace,seccomp: Add PTRACE_SECCOMP support (FATE#313982
  bnc#799030).
- x86: Enable HAVE_ARCH_SECCOMP_FILTER (FATE#313982 bnc#799030).
- Documentation: prctl/seccomp_filter (FATE#313982 bnc#799030).
- Update config files.
- Refresh patches.arch/000-apei_fixes.patch.
- commit c53d1d7
* Wed Jan 30 2013 bpoirier@suse.de
- ixgbe: Fix overwriting of rx_mtrl in ixgbe_ptp_hwtstamp_ioctl
  (bnc#795303 FATE#313662).
- ixgbe: only compile ixgbe_debugfs.o when enabled (bnc#795303
  FATE#313662).
- drivers/net: fix up function prototypes after __dev* removals
  (bnc#795303 FATE#313662).
- ixgbe: check whether thermal sensor is enabled (bnc#795303
  FATE#313662).
- ixgbe: Use is_valid_ether_addr (bnc#795303 FATE#313662).
- net/intel: remove __dev* attributes (bnc#795303 FATE#313662).
- ixgbe: Do not parse past IP header on fragments beyond the first
  (bnc#795303 FATE#313662).
- ixgbe: eliminate Smatch warnings in ixgbe_debugfs.c (bnc#795303
  FATE#313662).
- ixgbe: bump version number (bnc#795303 FATE#313662).
- ixgbe: Make the bridge mode setting sticky (bnc#795303
  FATE#313662).
- ixgbe: Fix incorrect disabling of Tx hang check in case of PFC
  (bnc#795303 FATE#313662).
- ixgbe: Drop RLPML configuration from x540 RXDCTL register
  configuration (bnc#795303 FATE#313662).
- ixgbe: fdb: only allow NUD_PERM fdb entries (bnc#795303
  FATE#313662).
- ixgbe: ethtool correctly identify autoneg setting (bnc#795303
  FATE#313662).
- ixgbe: remove needless queuing for L4 ptp packets (bnc#795303
  FATE#313662).
- ixgbe: use ETQF filter name instead of magic number (bnc#795303
  FATE#313662).
- ixgbe: convert to use simple_open() (bnc#795303 FATE#313662).
- ixgbe: Reformat output of ixgbe_dump (bnc#795303 FATE#313662).
- ixgbe: Do not use DCA to prefetch the entire packet into the
  cache (bnc#795303 FATE#313662).
- eth: Make is_link_local() consistent with other address tests
  (bnc#795303 FATE#313662).
- bridge: Use is_link_local() in store_group_addr() (bnc#795303
  FATE#313662).
- ixgbe: PTP get_ts_info missing software support (bnc#795303
  FATE#313662).
- ixgbe: fix default setting of TXDCTL.WTHRESH (bnc#795303
  FATE#313662).
- ixgbe: fix uninitialized event.type in ixgbe_ptp_check_pps_event
  (bnc#795303 FATE#313662).
- ixgbe: add setlink, getlink support to ixgbe and ixgbevf
  (bnc#795303 FATE#313662).
- net: fix bridge notify hook to manage flags correctly
  (bnc#795303 FATE#313662).
- net: Fix continued iteration in rtnl_bridge_getlink()
  (bnc#795303 FATE#313662).
- net: set and query VEB/VEPA bridge mode via PF_BRIDGE
  (bnc#795303 FATE#313662).
- net: create generic bridge ops (bnc#795303 FATE#313662).
- ixgbe: reduce PTP rx path overhead (bnc#795303 FATE#313662).
- ixgbe: add/update descriptor maps in comments (bnc#795303
  FATE#313662).
- ixgbe: Do not decrement budget in ixgbe_clean_rx_irq (bnc#795303
  FATE#313662).
- ixgbe: Return success or failure on VF MAC filter set
  (bnc#795303 FATE#313662).
- ixgbe: clean up the condition for turning on/off the laser
  (bnc#795303 FATE#313662).
- net, ixgbe: handle link local multicast addresses in SR-IOV mode
  (bnc#795303 FATE#313662).
- ixgbe: Fix return value from macvlan filter function (bnc#795303
  FATE#313662).
- ixgbe: Add support for pipeline reset (bnc#795303 FATE#313662).
- ixgbe: Fix possible memory leak in ixgbe_set_ringparam
  (bnc#795303 FATE#313662).
- ixgbe: Add function ixgbe_reset_pipeline_82599 (bnc#795303
  FATE#313662).
- ixgbe: Drop unnecessary addition from ixgbe_set_rx_buffer_len
  (bnc#795303 FATE#313662).
- ixgbe: Correcting small packet padding (bnc#795303 FATE#313662).
- ixgbe: using is_zero_ether_addr() to simplify the code
  (bnc#795303 FATE#313662).
- ixgbe: (PTP) refactor init, cyclecounter and reset (bnc#795303
  FATE#313662).
- ixgbe: add WOL support for new subdevice id (bnc#795303
  FATE#313662).
- ixgbe: Enable support for VF API version 1.1 in the PF
  (bnc#795303 FATE#313662).
- ixgbe: Add support for GET_QUEUES message to get DCB
  configuration (bnc#795303 FATE#313662).
- ixgbe: Add support for tracking the default user priority to
  SR-IOV (bnc#795303 FATE#313662).
- ixgbe: Add support for IPv6 and UDP to ixgbe_get_headlen
  (bnc#795303 FATE#313662).
- ixgbe: Add mailbox API version negotiation support to ixgbe PF
  (bnc#795303 FATE#313662).
- ixgbe: Move message handling routines into their own functions
  (bnc#795303 FATE#313662).
- ixgbe: Enable jumbo frames support w/ SR-IOV (bnc#795303
  FATE#313662).
- ixgbe: Initialize q_vector cpu and affinity masks correctly
  (bnc#795303 FATE#313662).
- ixgbe/ixgbevf: Limit maximum jumbo frame size to 9.5K to avoid
  Tx hangs (bnc#795303 FATE#313662).
- ixgbe: add support for X540-AT1 (bnc#795303 FATE#313662).
- ixgbe: fix poll loop for FDIRCTRL.INIT_DONE bit (bnc#795303
  FATE#313662).
- ixgbe: fix PTP ethtool timestamping function (bnc#795303
  FATE#313662).
- ixgbe: (PTP) Fix PPS interrupt code (bnc#795303 FATE#313662).
- ixgbe: Fix PTP X540 SDP alignment code for PPS signal
  (bnc#795303 FATE#313662).
- netlink: add attributes to fdb interface (bnc#795303
  FATE#313662).
- ixgbe: Do not read the spoofed packets counter when not in
  IOV mode (bnc#795303 FATE#313662).
- netdev: make address const in device address management
  (bnc#795303 FATE#313662).
- ixgbe: Improve statistics accuracy for DDP traffic (bnc#795303
  FATE#313662).
- ixgbe: added reg_ops file to debugfs (bnc#795303 FATE#313662).
- ixgbe: added netdev_ops file to debugfs (bnc#795303
  FATE#313662).
- ixgbe: add debugfs support (bnc#795303 FATE#313662).
- ixgbe: fix reporting of spoofed packets (bnc#795303
  FATE#313662).
- ixgbe: Fix VF rate limiting to correctly account for more
  queues per VF (bnc#795303 FATE#313662).
- ixgbe: Fix ordering of things so that PF correctly configures
  its VLANs (bnc#795303 FATE#313662).
- netdev: make pci_error_handlers const (bnc#795303 FATE#313662).
- ixgbe: remove old init remnant (bnc#795303 FATE#313662).
- PCI: Introduce pci_pcie_type(dev) to replace pci_dev->pcie_type
  (bnc#795303 FATE#313662).
- ixgbe: Rewrite code related to configuring IFCS bit in Tx
  descriptor (bnc#795303 FATE#313662).
- ixgbe: Roll RSC code into non-EOP code (bnc#795303 FATE#313662).
- ixgbe: Make allocating skb and placing data in it a separate
  function (bnc#795303 FATE#313662).
- ixgbe: Copybreak sooner to avoid get_page/put_page and offset
  change overhead (bnc#795303 FATE#313662).
- ixgbe: Make pull tail function separate from rest of
  cleanup_headers (bnc#795303 FATE#313662).
- ixgbe: Have the CPU take ownership of the buffers sooner
  (bnc#795303 FATE#313662).
- ixgbe: Only use double buffering if page size is less than 8K
  (bnc#795303 FATE#313662).
- ixgbe: combine ixgbe_add_rx_frag and ixgbe_can_reuse_page
  (bnc#795303 FATE#313662).
- net: add a truesize parameter to skb_add_rx_frag() (bnc#795303
  FATE#313662).
- f_phonet: fix page offset of first received fragment (bnc#795303
  FATE#313662).
- ixgbe: Remove code that was initializing Rx page offset
  (bnc#795303 FATE#313662).
- ixgbe: add missing braces (bnc#795303 FATE#313662).
- netvm: propagate page->pfmemalloc from skb_alloc_page to skb
  (bnc#795303 FATE#313662).
- ixgbe: fix panic while dumping packets on Tx hang with IOMMU
  (bnc#795303 FATE#313662).
- ixgbe: Use 1TC DCB instead of disabling DCB for MSI and legacy
  interrupts (bnc#795303 FATE#313662).
- ixgbe: add support for new 82599 device (bnc#795303
  FATE#313662).
- ixgbe: remove extra unused queues in DCB + FCoE case (bnc#795303
  FATE#313662).
- ixgbe: fix RAR entry counting for generic and fdb_add()
  (bnc#795303 FATE#313662).
- ixgbe: Use num_tcs.pg_tcs as upper limit for TC when checking
  based on UP (bnc#795303 FATE#313662).
- ixgbe: Reduce Rx header size to what is actually used
  (bnc#795303 FATE#313662).
- ixgbe: Fix handling of FDIR_HASH flag (bnc#795303 FATE#313662).
- ixgbe: Fix build with PCI_IOV enabled (bnc#795303 FATE#313662).
- ixgbe: Change how we check for pre-existing and assigned VFs
  (bnc#795303 FATE#313662).
- ixgbe: Drop probe_vf and merge functionality into
  ixgbe_enable_sriov (bnc#795303 FATE#313662).
- ixgbe: use PCI_VENDOR_ID_INTEL (bnc#795303 FATE#313662).
- ixgbe: Enable FCoE FSO and CRC offloads based on CAPABLE
  instead of ENABLED flag (bnc#795303 FATE#313662).
- ixgbe: Only enable anti-spoof on VF pools (bnc#795303
  FATE#313662).
- ixgbe: Correctly set SAN MAC RAR pool to default pool of PF
  (bnc#795303 FATE#313662).
- ixgbe: Make FCoE allocation and configuration closer to how
  rings work (bnc#795303 FATE#313662).
- ixgbe: Merge all FCoE percpu values into a single structure
  (bnc#795303 FATE#313662).
- ixgbe: Cleanup configuration of FCoE registers (bnc#795303
  FATE#313662).
- ixgbe: Drop references to deprecated pci_ DMA api and instead
  use dma_ API (bnc#795303 FATE#313662).
- ixgbe: Fix memory leak when SR-IOV VFs are direct assigned
  (bnc#795303 FATE#313662).
- ixgbe: Use VMDq offset to indicate the default pool (bnc#795303
  FATE#313662).
- ixgbe: Cleanup holes in flags after removing several of them
  (bnc#795303 FATE#313662).
- ixgbe: Retire RSS enabled and capable flags (bnc#795303
  FATE#313662).
- ixgbe: Add support for SR-IOV w/ DCB or RSS (bnc#795303
  FATE#313662).
- ixgbe: Update configure virtualization to allow for multiple
  PF pools (bnc#795303 FATE#313662).
- ixgbe: Cleanup logic for MRQC and MTQC configuration (bnc#795303
  FATE#313662).
- ixgbe: Update the logic for ixgbe_cache_ring_dcb and DCB RSS
  configuration (bnc#795303 FATE#313662).
- ixgbe: Move configuration of set_real_num_rx/tx_queues into open
  (bnc#795303 FATE#313662).
- ixgbe: Handle failures in the ixgbe_setup_rx/tx_resources calls
  (bnc#795303 FATE#313662).
- ixgbe: Ping the VFs on link status change to trigger link change
  (bnc#795303 FATE#313662).
- etherdevice: Rename random_ether_addr to eth_random_addr
  (bnc#795303 FATE#313662).
- rename dev_hw_addr_random and remove redundant second
  (bnc#795303 FATE#313662).
- ethernet: Use eth_random_addr (bnc#795303 FATE#313662).
- ixgbe: Merge FCoE set_num and cache_ring calls into RSS/DCB
  config (bnc#795303 FATE#313662).
- ixgbe: Add function for obtaining FCoE TC based on FCoE user
  priority (bnc#795303 FATE#313662).
- ixgbe: Populate the prio_tc_map in ixgbe_setup_tc (bnc#795303
  FATE#313662).
- ixgbe: Cleanup unpacking code for DCB (bnc#795303 FATE#313662).
- ixgbe: Simplify logic for getting traffic class from user
  priority (bnc#795303 FATE#313662).
- ixgbe: Merge RSS and flow director ring register caching and
  configuration (bnc#795303 FATE#313662).
- ixgbe: Clean up a useless switch statement and dead code in
  configure_srrctl (bnc#795303 FATE#313662).
- ixgbe: Add feature offset value to ring features (bnc#795303
  FATE#313662).
- ixgbe: Add upper limit to ring features (bnc#795303
  FATE#313662).
- ixgbe: count q_vectors instead of MSI-X vectors (bnc#795303
  FATE#313662).
- drivers/net/ethernet: Fix (nearly-)kernel-doc comments for
  various functions (bnc#795303 FATE#313662).
- ixgbe: DCB and SR-IOV can not co-exist and will cause hangs
  (bnc#795303 FATE#313662).
- ixgbe: Do not pad FCoE frames as this can cause issues with
  FCoE DDP (bnc#795303 FATE#313662).
- ixgbe: simplify padding and length checks (bnc#795303
  FATE#313662).
- ixgbe: clean up ixgbe_get_settings ethtool function (bnc#795303
  FATE#313662).
- ixgbe: add support for 1G SX modules (bnc#795303 FATE#313662).
- ixgbe: Fix memory leak in ixgbe when receiving traffic on DDP
  enabled rings (bnc#795303 FATE#313662).
- ixgbe: Fix PHC loophole allowing misconfiguration of increment
  register (bnc#795303 FATE#313662).
- ixgbe: Check PTP Rx timestamps via BPF filter (bnc#795303
  FATE#313662).
- ixgbe: PTP Fix hwtstamp mode settings (bnc#795303 FATE#313662).
- ixgbe: ptp code cleanup (bnc#795303 FATE#313662).
- ixgbe: do not compile ixgbe_sysfs.c when CONFIG_IXGBE_HWMON
  is not set (bnc#795303 FATE#313662).
- ixgbe: align flow control DV macros with datasheet (bnc#795303
  FATE#313662).
- ixgbe: IXGBE_RXD_STAT_VP set even with Rx stripping enabled
  (bnc#795303 FATE#313662).
- ixgbe: fix_features rxvlan is independent of DCB and needs to
  be set (bnc#795303 FATE#313662).
- ixgbe: update version number (bnc#795303 FATE#313662).
- ixgbe: cleanup the hwmon function calls (bnc#795303
  FATE#313662).
- ixgbe: support software timestamping (bnc#795303 FATE#313662).
- ixgbe: add support for get_ts_info (bnc#795303 FATE#313662).
- ptp: Add a method for obtaining the device index (bnc#795303
  FATE#313662).
- ixgbe: correct disable_rx_buff timeout (bnc#795303 FATE#313662).
- ixgbe: Enable timesync clock-out feature for PPS support on X540
  (bnc#795303 FATE#313662).
- ixgbe: Hardware Timestamping + PTP Hardware Clock (PHC)
  (bnc#795303 FATE#313662).
- commit f3dff6c
* Wed Jan 30 2013 bpoirier@suse.de
- ixgbe: Fix bogus error message (bnc#795303 FATE#313662).
- ixgbe: Set Drop_EN bit when multiple Rx queues are present
  w/o flow control (bnc#795303 FATE#313662).
- ixgbe: Clean up priority based flow control (bnc#795303
  FATE#313662).
- ixgbe: Exit on error case in VF message processing (bnc#795303
  FATE#313662).
- ixgbe: dcb: IEEE PFC stats and reset logic incorrect (bnc#795303
  FATE#313662).
- igb, ixgbe: netdev_tx_reset_queue incorrectly called from tx
  init path (bnc#795303 FATE#313662).
- ixgbe: Update link flow control to correctly handle multiple
  packet buffer DCB (bnc#795303 FATE#313662).
- ixgbe: Reorder link flow control functions in ixgbe_common.c
  (bnc#795303 FATE#313662).
- ixgbe: Use __free_pages instead of put_page to release pages
  (bnc#795303 FATE#313662).
- ixgbe: Make ixgbe_fc_autoneg return void and always set
  current_mode (bnc#795303 FATE#313662).
- ixgbe: Reorder the ring to q_vector mapping to improve
  performance (bnc#795303 FATE#313662).
- ixgbe: Track instances of buffer available but no DMA resources
  present (bnc#795303 FATE#313662).
- ixgbe: dcb: BIT_APP_UPCHG not set by ixgbe_copy_dcb_cfg()
  (bnc#795303 FATE#313662).
- ixgbe: fix race condition with shutdown (bnc#795303
  FATE#313662).
- ixgbe: Fix use after free on module remove (bnc#795303
  FATE#313662).
- ixgbe: Reset max_vfs to zero when user request is out of range
  (bnc#795303 FATE#313662).
- ixgbe: Deny MACVLAN requests from VFs with admin set MAC
  (bnc#795303 FATE#313662).
- commit f800b92
* Wed Jan 30 2013 bpoirier@suse.de
- ixgbe: add hwmon interface to export thermal data (bnc#795303
  FATE#313662).
- Update config files.
- commit 6050db6
* Wed Jan 30 2013 bpoirier@suse.de
- ixgbe: add support functions to access thermal data (bnc#795303
  FATE#313662).
- ixgbe: fix calling skb_put on nonlinear skb assertion bug
  (bnc#795303 FATE#313662).
- ixgbe: Fix a memory leak in IEEE DCB (bnc#795303 FATE#313662).
- ixgbe: check for WoL support in single function (bnc#795303
  FATE#313662).
- ixgbe: Identify FCoE rings earlier to resolve memory corruption
  w/ FCoE (bnc#795303 FATE#313662).
- ixgbe: add missing rtnl_lock in PM resume path (bnc#795303
  FATE#313662).
- ixgbe: UTA table incorrectly programmed (bnc#795303
  FATE#313662).
- ixgbe: allow RAR table to be updated in promisc mode (bnc#795303
  FATE#313662).
- ixgbe: enable FDB netdevice ops (bnc#795303 FATE#313662).
- net: add fdb generic dump routine (bnc#795303 FATE#313662).
- net: addr_list: add exclusive dev_uc_add and dev_mc_add
  (bnc#795303 FATE#313662).
- net: add generic PF_BRIDGE:RTM_ FDB hooks (bnc#795303
  FATE#313662).
- ixgbe: add I2C clock stretching (bnc#795303 FATE#313662).
- ixgbe: fix WoL issue with fiber (bnc#795303 FATE#313662).
- ixgbe: consolidate reporting of MSIX vectors into a single
  function (bnc#795303 FATE#313662).
- ixgbe: driver fix for link flap (bnc#795303 FATE#313662).
- ixgbe: update version number (bnc#795303 FATE#313662).
- ixgbe: fix typo in enumeration name (bnc#795303 FATE#313662).
- intel: make wired ethernet driver message level consistent
  (rev2) (bnc#795303 FATE#313662).
- ixgbe: Fix issues with SR-IOV loopback when flow control is
  disabled (bnc#795303 FATE#313662).
- ixgbe: fix namespace issues when FCoE/DCB is not enabled
  (bnc#795303 FATE#313662).
- ixgbe: Correct flag values set by ixgbe_fix_features (bnc#795303
  FATE#313662).
- ixgbe: Add support for enabling UDP RSS via the ethtool
  rx-flow-hash command (bnc#795303 FATE#313662).
- ixgbe: Whitespace cleanups (bnc#795303 FATE#313662).
- ixgbe: Two minor fixes for RSS and FDIR set queues functions
  (bnc#795303 FATE#313662).
- ixgbe: drop err_eeprom tag which is at same location as
  err_sw_init (bnc#795303 FATE#313662).
- ixgbe: Move poll routine in order to improve readability
  (bnc#795303 FATE#313662).
- ixgbe: cleanup logic for the service timer and VF hang detection
  (bnc#795303 FATE#313662).
- ixgbe: Update layout of ixgbe_ring structure to improve cache
  performance (bnc#795303 FATE#313662).
- ixgbe: Store Tx flags and protocol information to tx_buffer
  sooner (bnc#795303 FATE#313662).
- ixgbe: always write DMA for single_mapped value with skb
  (bnc#795303 FATE#313662).
- ixgbe: Write gso_segs and bytcount to the ring sooner
  (bnc#795303 FATE#313662).
- ixgbe: Place skb on first buffer_info structure to avoid using
  stack space (bnc#795303 FATE#313662).
- ixgbe: Use packets to track Tx completions instead of a seperate
  value (bnc#795303 FATE#313662).
- ixgbe: Modify setup of descriptor flags to avoid conditional
  jumps (bnc#795303 FATE#313662).
- ixgbe: Make certain that all frames fit minimum size
  requirements (bnc#795303 FATE#313662).
- ixgbe: cleanup logic in ixgbe_change_mtu (bnc#795303
  FATE#313662).
- ixgbe: Replace standard receive path with a page based receive
  (bnc#795303 FATE#313662).
- ixgbe: Support sending custom Ethernet FCS (bnc#795303
  FATE#313662).
- ixgbe: dcb: use DCB config values for FCoE traffic class on open
  (bnc#795303 FATE#313662).
- ixgbe: Fix race condition where RX buffer could become corrupted
  (bnc#795303 FATE#313662).
- ixgbe: use typed min/max functions where possible (bnc#795303
  FATE#313662).
- ixgbe: fix obvious return value bug (bnc#795303 FATE#313662).
- ixgbe: Replace eitr_low and eitr_high with static values in
  ixgbe_update_itr (bnc#795303 FATE#313662).
- ixgbe: Do not disable read relaxed ordering when DCA is enabled
  (bnc#795303 FATE#313662).
- ixgbe: Simplify logic for ethtool loopback frame creation and
  testing (bnc#795303 FATE#313662).
- ixgbe: Add iterator for cycling through rings on a q_vector
  (bnc#795303 FATE#313662).
- ixgbe: Allocate rings as part of the q_vector (bnc#795303
  FATE#313662).
- ixgbe: Drop unnecessary napi_schedule_prep and spare blank
  line from ixgbe_intr (bnc#795303 FATE#313662).
- ixgbe: Default to queue pairs when number of queues is less
  than CPUs (bnc#795303 FATE#313662).
- ixgbe: Correct Adaptive Interrupt Moderation so that it will
  change values (bnc#795303 FATE#313662).
- ixgbe: Address issues with Tx WHTRESH value not being set
  correctly (bnc#795303 FATE#313662).
- ixgbe: Reorder adapter contents for better cache utilization
  (bnc#795303 FATE#313662).
- ixgbe: Do no clear Tx status bits since eop_desc provides
  enough info (bnc#795303 FATE#313662).
- ixgbe: add support for byte queue limits (bnc#795303
  FATE#313662).
- ixgbe: remove tie between NAPI work limits and interrupt
  moderation (bnc#795303 FATE#313662).
- net: dcb: getnumtcs()/setnumtcs() should return an int
  (bnc#795303 FATE#313662).
- ixgbe: dcb: check setup_tc return codes (bnc#795303
  FATE#313662).
- ixgbe: Fix comments that are out of date or formatted
  incorrectly (bnc#795303 FATE#313662).
- ixgbe: fix spelling errors (bnc#795303 FATE#313662).
- ixgbe: Minor formatting and comment corrections for
  ixgbe_xmit_frame_ring (bnc#795303 FATE#313662).
- drivers/net: Remove boolean comparisons to true/false
  (bnc#795303 FATE#313662).
- ixgbe: Combine post-DMA processing of sk_buff fields into
  single function (bnc#795303 FATE#313662).
- ixgbe: Drop the _ADV of descriptor macros since all ixgbe
  descriptors are ADV (bnc#795303 FATE#313662).
- ixgbe: Add function for testing status bits in Rx descriptor
  (bnc#795303 FATE#313662).
- ixgbe: Let the Rx buffer allocation clear status bits instead
  of cleanup (bnc#795303 FATE#313662).
- ixgbe: Address fact that RSC was not setting GSO size for
  incoming frames (bnc#795303 FATE#313662).
- ixgbe: Minor refactor of RSC (bnc#795303 FATE#313662).
- ixgbe: ethtool: stats user buffer overrun (bnc#795303
  FATE#313662).
- ixgbe: dcb: up2tc mapping lost on disable/enable CEE DCB state
  (bnc#795303 FATE#313662).
- ixgbe: do not update real num queues when netdev is going away
  (bnc#795303 FATE#313662).
- ixgbe: Fix broken dependency on MAX_SKB_FRAGS being related
  to page size (bnc#795303 FATE#313662).
- ixgbe: Fix case of Tx Hang in PF with 32 VFs (bnc#795303
  FATE#313662).
- ixgbe: fix vf lookup (bnc#795303 FATE#313662).
- ixgbe: Fix typo in ixgbe_common.h (bnc#795303 FATE#313662).
- ixgbe: make ethtool strings table const (bnc#795303
  FATE#313662).
- ixgbe: Add warning when no space left for more MAC filters
  (bnc#795303 FATE#313662).
- ixgbe: update copyright to 2012 (bnc#795303 FATE#313662).
- ixgbe: Add module parameter to allow untested and unsafe SFP+
  modules (bnc#795303 FATE#313662).
- ixgbe: Fix register defines to correctly handle complex
  expressions (bnc#795303 FATE#313662).
- ixgbe: FCoE: Add support for ndo_get_fcoe_hbainfo() call
  (bnc#795303 FATE#313662).
- ixgbe: add support for new 82599 device (bnc#795303
  FATE#313662).
- ixgbe: add support for new 82599 device id (bnc#795303
  FATE#313662).
- ixgbe: add write flush in ixgbe_clock_out_i2c_byte() (bnc#795303
  FATE#313662).
- ixgbe: fix typo's (bnc#795303 FATE#313662).
- ixgbe: fix incorrect PHY register reads (bnc#795303
  FATE#313662).
- net: fix assignment of 0/1 to bool variables (bnc#795303
  FATE#313662).
- ixgbe: Remove function prototype for non-existent function
  (bnc#795303 FATE#313662).
- ixgbe: DCB: IEEE transitions may fail to reprogram hardware
  (bnc#795303 FATE#313662).
- ixgbe: DCBnl set_all, order of operations fix (bnc#795303
  FATE#313662).
- net: remove netdev_alloc_page and use __GFP_COLD (bnc#795303
  FATE#313662).
- intel: Convert <FOO>_LENGTH_OF_ADDRESS to ETH_ALEN (bnc#795303
  FATE#313662).
- ixgbe: fix LED blink logic to check for link (bnc#795303
  FATE#313662).
- Sweep the last of the active .get_drvinfo floors under ethernet/
  (bnc#795303 FATE#313662).
- ixgbe: Fix compile for kernel without CONFIG_PCI_IOV defined
  (bnc#795303 FATE#313662).
- ixgbe: DCB, return max for IEEE traffic classes (bnc#795303
  FATE#313662).
- ixgbe: fix reading of the buffer returned by the firmware
  (bnc#795303 FATE#313662).
- ixgbe: Fix compiler warnings (bnc#795303 FATE#313662).
- ixgbe: fix smatch splat due to missing NULL check (bnc#795303
  FATE#313662).
- ixgbe: fix disabling of Tx laser at probe (bnc#795303
  FATE#313662).
- ixgbe: Fix link issues caused by a reset while interface is down
  (bnc#795303 FATE#313662).
- net: add skb frag size accessors (bnc#795303 FATE#313662).
- ixgbe: change the eeprom version reported by ethtool (bnc#795303
  FATE#313662).
- ixgbe: allow eeprom writes via ethtool (bnc#795303 FATE#313662).
- ixgbe: fix endianess when writing driver version to firmware
  (bnc#795303 FATE#313662).
- ixgbe: Add new netdev op to turn spoof checking on or off per VF
  (bnc#795303 FATE#313662).
- if_link: Add additional parameter to IFLA_VF_INFO for spoof
  checking (bnc#795303 FATE#313662).
- ixgbe: fix skb truesize underestimation (bnc#795303
  FATE#313662).
- ixgbe: Correct check for change in FCoE priority (bnc#795303
  FATE#313662).
- ixgbe: Add FCoE DDP allocation failure counters to ethtool stats
  (bnc#795303 FATE#313662).
- ixgbe: Add protection from VF invalid target DMA (bnc#795303
  FATE#313662).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#795303 FATE#313662).
- ixgbe: bump version number (bnc#795303 FATE#313662).
- ixgbe: X540 devices RX PFC frames pause traffic even if disabled
  (bnc#795303 FATE#313662).
- ixgbe: DCB X540 devices support max traffic class of 4
  (bnc#795303 FATE#313662).
- ixgbe: fixup hard dependencies on supporting 8 traffic classes
  (bnc#795303 FATE#313662).
- ixgbe: Fix PFC mask generation (bnc#795303 FATE#313662).
- ixgbe: remove instances of ixgbe_phy_aq for 82598 and 82599
  (bnc#795303 FATE#313662).
- ixgbe: get pauseparam autoneg (bnc#795303 FATE#313662).
- ixgbe: do not disable flow control in ixgbe_check_mac_link
  (bnc#795303 FATE#313662).
- ixgbe: send MFLCN to ethtool (bnc#795303 FATE#313662).
- ixgbe: add support for new 82599 device (bnc#795303
  FATE#313662).
- ixgbe: fix driver version initialization in firmware (bnc#795303
  FATE#313662).
- ixgbe: remove return code for functions that always return 0
  (bnc#795303 FATE#313662).
- ixgbe: clear the data field in ixgbe_read_i2c_byte_generic
  (bnc#795303 FATE#313662).
- ixgbe: prevent link checks while resetting (bnc#795303
  FATE#313662).
- ixgbe: add ECC warning for legacy interrupts (bnc#795303
  FATE#313662).
- ixgbe: cleanup ixgbe_setup_gpie() for X540 (bnc#795303
  FATE#313662).
- ixgbe add thermal sensor support for x540 hardware (bnc#795303
  FATE#313662).
- ixgbe: update {P}FC thresholds to account for X540 and loopback
  (bnc#795303 FATE#313662).
- ixgbe: disable LLI for FCoE (bnc#795303 FATE#313662).
- ixgbe: Cleanup q_vector interrupt throttle rate logic
  (bnc#795303 FATE#313662).
- treewide: Correct spelling of successfully in comments
  (bnc#795303 FATE#313662).
- ixgbe: remove global reset to the MAC (bnc#795303 FATE#313662).
- ixgbe: add WOL support for X540 (bnc#795303 FATE#313662).
- ixgbe: avoid HW lockup when adapter is reset with Tx work
  pending (bnc#795303 FATE#313662).
- ixgbe: dcb, set priority to traffic class mappings (bnc#795303
  FATE#313662).
- ixgbe: cleanup X540 interrupt enablement (bnc#795303
  FATE#313662).
- ixgbe: DCB, do not call set_state() from IEEE mode (bnc#795303
  FATE#313662).
- ixgbe: Reconfigure SR-IOV Init (bnc#795303 FATE#313662).
- ixgbe: fix possible null buffer error (bnc#795303 FATE#313662).
- ixgbe: remove duplicate netif_tx_start_all_queues (bnc#795303
  FATE#313662).
- ixgbe: fix FCRTL/H register dump for X540 (bnc#795303
  FATE#313662).
- ixgbe: cleanup some register reads (bnc#795303 FATE#313662).
- ixgbe: Make better use of memory allocations in one-buffer
  mode w/ RSC (bnc#795303 FATE#313662).
- ixgbe: drop adapter from ixgbe_fso call documentation
  (bnc#795303 FATE#313662).
- ixgbe: Add SFP support for missed 82598 PHY (bnc#795303
  FATE#313662).
- ixgbe: Add missing code for enabling overheat sensor interrupt
  (bnc#795303 FATE#313662).
- ixgbe: make ixgbe_up and ixgbe_up_complete void functions
  (bnc#795303 FATE#313662).
- v2 ixgbe: Update packet buffer reservation to correct fdir
  headroom size (bnc#795303 FATE#313662).
- ixgbe: remove redundant configuration of tx_sample_rate
  (bnc#795303 FATE#313662).
- ethtool: Update ethtool_rxnfc::rule_cnt on return from
  ETHTOOL_GRXCLSRLALL (bnc#795303 FATE#313662).
- ixgbe: Correctly name and handle MSI-X other interrupt
  (bnc#795303 FATE#313662).
- ixgbe: cleanup configuration of EITRSEL and VF reset path
  (bnc#795303 FATE#313662).
- ixgbe: cleanup reset paths (bnc#795303 FATE#313662).
- ixgbe: Update TXDCTL configuration to correctly handle WTHRESH
  (bnc#795303 FATE#313662).
- ixgbe: combine PCI_VDEVICE and board declaration to same line
  (bnc#795303 FATE#313662).
- ixgbe: Drop unnecessary adapter->hw dereference in loopback
  test setup (bnc#795303 FATE#313662).
- ixgbe: commonize ixgbe_map_rings_to_vectors to work for all
  interrupt types (bnc#795303 FATE#313662).
- ixgbe: Use ring->dev instead of adapter->pdev->dev when updating
  DCA (bnc#795303 FATE#313662).
- ixgbe: cleanup allocation and freeing of IRQ affinity hint
  (bnc#795303 FATE#313662).
- v2 ixgbe: consolidate all MSI-X ring interrupts and poll
  routines into one (bnc#795303 FATE#313662).
- ixgbe: Change default Tx work limit size to 256 buffers
  (bnc#795303 FATE#313662).
- intel: convert to SKB paged frag API (bnc#795303 FATE#313662).
- ixgbe: clear RNBC only for 82598 (bnc#795303 FATE#313662).
- ixgbe: add check for supported modes (bnc#795303 FATE#313662).
- ixgbe: fix ixgbe_fc_autoneg_fiber bug (bnc#795303 FATE#313662).
- ixgbe: cleanup feature flags in ixgbe_probe (bnc#795303
  FATE#313662).
- ixgbe: PFC not cleared on X540 devices (bnc#795303 FATE#313662).
- ixgbe: consolidate, setup for multiple traffic classes
  (bnc#795303 FATE#313662).
- ixgbe: remove unneeded fdir pb alloc case (bnc#795303
  FATE#313662).
- ixgbe: fixup remaining call sites for arbitrary TCs (bnc#795303
  FATE#313662).
- ixgbe: Always tag VLAN tagged packets (bnc#795303 FATE#313662).
- ixgbe: Add support for setting CC bit when SR-IOV is enabled
  (bnc#795303 FATE#313662).
- ixgbe: convert rings from q_vector bit indexed array to linked
  list (bnc#795303 FATE#313662).
- ixgbe: Simplify transmit cleanup path (bnc#795303 FATE#313662).
- ixgbe: Cleanup FCOE and VLAN handling in xmit_frame_ring
  (bnc#795303 FATE#313662).
- ixgbe: replace reference to CONFIG_FCOE with IXGBE_FCOE
  (bnc#795303 FATE#313662).
- ixgbe: Refactor transmit map and cleanup routines (bnc#795303
  FATE#313662).
- ixgbe - DDP last user buffer - error to warn (bnc#795303
  FATE#313662).
- ixgbe: Fix FCOE memory leak for DDP packets (bnc#795303
  FATE#313662).
- commit 6e6c57e
* Wed Jan 30 2013 bpoirier@suse.de
- intel: Move the Intel wired LAN drivers (bnc#795303
  FATE#313662).
- Update config files.
- supported.conf:
- commit 7d23257
* Wed Jan 30 2013 bpoirier@suse.de
- ixgbe: fix PHY link setup for 82599 (bnc#795303 FATE#313662).
- ixgbe: fix __ixgbe_notify_dca() bail out code (bnc#795303
  FATE#313662).
- intel drivers: repair missing flush operations (bnc#795303
  FATE#313662).
- ixgbe: convert to ndo_fix_features (bnc#795303 FATE#313662).
- ixgbe: only enable WoL for magic packet by default (bnc#795303
  FATE#313662).
- ixgbe: remove ifdef check for non-existent define (bnc#795303
  FATE#313662).
- ixgbe: Pass staterr instead of re-reading status and error
  bits from descriptor (bnc#795303 FATE#313662).
- ixgbe: Move interrupt related values out of ring and into
  q_vector (bnc#795303 FATE#313662).
- ixgbe: add structure for containing RX/TX rings to q_vector
  (bnc#795303 FATE#313662).
- ixgbe: inline the ixgbe_maybe_stop_tx function (bnc#795303
  FATE#313662).
- ixgbe: Update ATR to use recorded TX queues instead of CPU
  for routing (bnc#795303 FATE#313662).
- ixgbe: Make certain to initialize the fdir_perfect_lock in
  all cases (bnc#795303 FATE#313662).
- ixgbe: implement DCB ops dcb_ieee_del() (bnc#795303
  FATE#313662).
- ixgbe: remove unused fcoe.tc field and fcoe_setapp() (bnc#795303
  FATE#313662).
- ixgbe: complete FCoE initialization from setapp() routine
  (bnc#795303 FATE#313662).
- ixgbe: A fix to VF TX rate limit (bnc#795303 FATE#313662).
- ixgbe: Update method used for determining descriptor count
  for an skb (bnc#795303 FATE#313662).
- ixgbe: Add one function that handles most of context descriptor
  setup (bnc#795303 FATE#313662).
- ixgbe: Move all values that deal with count, next_to_use,
  next_to_clean to u16 (bnc#795303 FATE#313662).
- ixgbe: Convert IXGBE_DESC_UNUSED from macro to static inline
  function (bnc#795303 FATE#313662).
- ixgbe: pass adapter struct instead of netdev for interrupt data
  (bnc#795303 FATE#313662).
- ixgbe: update driver version string (bnc#795303 FATE#313662).
- ixgbe: fix ring assignment issues for SR-IOV and drop cases
  (bnc#795303 FATE#313662).
- ixgbe: disable RSC when Rx checksum is off (bnc#795303
  FATE#313662).
- ixgbe: move reset code into a separate function (bnc#795303
  FATE#313662).
- ixgbe: move setting RSC into a separate function (bnc#795303
  FATE#313662).
- ixgbe: add support for nfc addition and removal of filters
  (bnc#795303 FATE#313662).
- ixgbe: add support for displaying ntuple filters via the nfc
  interface (bnc#795303 FATE#313662).
- ixgbe: add basic support for setting and getting nfc controls
  (bnc#795303 FATE#313662).
- ixgbe: update perfect filter framework to support retaining
  filters (bnc#795303 FATE#313662).
- ixgbe: fix flags relating to perfect filters to support
  coexistence (bnc#795303 FATE#313662).
- ixgbe: remove ntuple filtering (bnc#795303 FATE#313662).
- ixgbe: setup per CPU PCI pool for FCoE DDP (bnc#795303
  FATE#313662).
- ixgbe: add support for Dell CEM (bnc#795303 FATE#313662).
- ixgbe: DCB, remove unneeded ixgbe_dcb_txq_to_tc() routine
  (bnc#795303 FATE#313662).
- ixgbe: DCB and perfect filters can coexist (bnc#795303
  FATE#313662).
- ixgbe: fix bit mask for DCB version (bnc#795303 FATE#313662).
- ixgbe: setup redirection table for multiple packet buffers
  (bnc#795303 FATE#313662).
- ixgbe: DCB 82598 devices, tx_idx and rx_idx swapped (bnc#795303
  FATE#313662).
- ixgbe: DCB use existing TX and RX queues (bnc#795303
  FATE#313662).
- ixgbe: configure minimal packet buffers to support TC
  (bnc#795303 FATE#313662).
- ixgbe: consolidate MRQC and MTQC handling (bnc#795303
  FATE#313662).
- ixgbe: consolidate packet buffer allocation (bnc#795303
  FATE#313662).
- ixgbe: dcbnl reduce duplicated code and indentation (bnc#795303
  FATE#313662).
- net: remove interrupt.h inclusion from netdevice.h (bnc#795303
  FATE#313662).
- drivers/net: Remove unnecessary semicolons (bnc#795303
  FATE#313662).
- Revert "ixgbe: fix possible null buffer error" (bnc#795303
  FATE#313662).
- Revert "ixgbe: add support for X540-AT1" (bnc#795303
  FATE#313662).
- Revert "ixgbe: add support for new 82599 device" (bnc#795303
  FATE#313662).
- Revert "ixgbe: add support for new 82599 device id" (bnc#795303
  FATE#313662).
- commit dbd57f5
* Wed Jan 30 2013 bp@suse.de
- Delete
  patches.drivers/0001-EDAC-MCE-AMD-Make-MC2-decoding-per-family.patch.
- Delete
  patches.drivers/0002-EDAC-MCE-AMD-Add-MCE-decoding-support-for-Family-16h.patch.
  Remove old bnc#798781 backported versions.
- commit 59ce22e
* Wed Jan 30 2013 bp@suse.de
- Refresh
  patches.drivers/i7core_edac-don-t-enable-memory-scrubbing-for-xeon-35xx.patch.
  restore it after having removed it by accident
- commit c0eb8a9
* Wed Jan 30 2013 bp@suse.de
- EDAC, MCE, AMD: Drop local coreid reporting
  (bnc#798781,fate#314148).
- EDAC, MCE, AMD: Simplify NB MCE decoder interface
  (bnc#798781,fate#314148).
- x86, mce: Add wrappers for registering on the decode chain
  (bnc#798781,fate#314148).
- MCE, AMD: Correct some MC0 error types (bnc#798781,fate#314148).
- MCE, AMD: Correct ucode patch buffer description
  (bnc#798781,fate#314148).
- MCE, AMD: Correct VB data error description
  (bnc#798781,fate#314148).
- MCE, AMD: Rework NB MCE signatures (bnc#798781,fate#314148).
- MCE, AMD: Correct bank 5 error signatures
  (bnc#798781,fate#314148).
- MCE, AMD: Constify error tables (bnc#798781,fate#314148).
- MCE, AMD: Remove functional unit references
  (bnc#798781,fate#314148).
- MCE, AMD: Dump CPU f/m/s triple with the error
  (bnc#798781,fate#314148).
- MCE, AMD: Report decoded error type first
  (bnc#798781,fate#314148).
- MCE, AMD: Dump error status (bnc#798781,fate#314148).
- EDAC, MCE, AMD: Make MC2 decoding per-family
  (bnc#798781,fate#314148).
- EDAC, MCE, AMD: Add MCE decoding support for Family 16h
  (bnc#798781,fate#314148).
- EDAC, MCE, AMD: Remove unneeded exports
  (bnc#798781,fate#314148).
- commit 1d8ea9c
* Wed Jan 30 2013 oneukum@suse.de
- patches.drivers/0001-From-c52804a472649b2e5005342308739434cbd51119-Mon-Se.patch:
  xhci: avoid "dead ports", add roothub port polling (bnc#799197).
- commit 98f453b
* Wed Jan 30 2013 mmarek@suse.cz
- KMP signing support (fate#314511)
- rpm/kernel-syms.spec.in: Require pesign-obs-integration so that KMPs
  do not have to list it as dependency explicitly.
- rpm/macros.kernel-source: Define %%sign_files to "/lib/firmware *.ko"
  in the %%kernel_module_package macro.
- KMPs only need to add "# needssslcertforbuild" to the specfile, so
  that the right certificate is available during build.
- commit 66e7283
* Wed Jan 30 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Only sign vmlinuz if CONFIG_EFI_STUB is set.
- commit 2771b65
* Wed Jan 30 2013 jlee@suse.com
- mmc: sdio: print correct UHS mode during card detection
  (bnc#799019,fate#313948).
- mmc: sdio: Fix SDIO 3.0 UHS-I initialization sequence
  (bnc#799019,fate#313948).
- mmc: bus: print bus speed mode of UHS-I card
  (bnc#799019,fate#313948).
- mmc: core: reset signal voltage on power up
  (bnc#799019,fate#313948).
- mmc: sdio: fix setting card data bus width as 4-bit
  (bnc#799019,fate#313948).
- mmc: core: UHS sdio card that fails should not exceed 50MHz
  (bnc#799019,fate#313948).
- mmc: sdhci: Deal with failure case in sdhci_suspend_host
  (bnc#799019,fate#313948).
- mmc: sdio: support SDIO UHS cards (bnc#799019,fate#313948).
- mmc: core: Set non-default Drive Strength via platform hook
  (bnc#799019,fate#313948).
- mmc: recognise SDIO cards with SDIO_CCCR_REV 3.00
  (bnc#799019,fate#313948).
- commit 1be993a
* Wed Jan 30 2013 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-032-Fix-non-snoop-page-handling:
  ALSA: hda - Fix non-snoop page handling (bnc#800701).
- commit 5821d28
* Wed Jan 30 2013 oneukum@suse.de
- patches.drivers/0006-USB-Handle-warm-reset-failure-on-empty-port.patch:
  USB: Handle warm reset failure on empty port (bnc#799926).
- commit 9de7390
* Wed Jan 30 2013 oneukum@suse.de
- patches.drivers/0005-USB-Ignore-port-state-until-reset-completes.patch:
  USB: Ignore port state until reset completes (bnc#799926).
- commit 86a4c1f
* Wed Jan 30 2013 oneukum@suse.de
- patches.drivers/0003-From-41e7e056cdc662f704fa9262e5c6e213b4ab45dd-Mon-Se.patch:
  Allow USB 3.0 ports to be disabled (bnc#799926).
- commit 4ff008c
* Wed Jan 30 2013 oneukum@suse.de
- patches.drivers/0002-USB-Ignore-xHCI-Reset-Device-status.patch:
  USB: Ignore xHCI Reset Device status (bnc#799926).
- commit c5061ed
* Wed Jan 30 2013 oneukum@suse.de
- patches.drivers/0001-USB-Handle-auto-transition-from-hot-to-warm-reset.patch:
  USB: Handle auto-transition from hot to warm reset (bnc#799926).
- commit 834a97b
* Tue Jan 29 2013 rgoldwyn@suse.de
- patches.fixes/ocfs2-use-spinlock-irqsave-for-downconvert-lock.patch:
  Update references (bnc#795928).
- commit ab31669
* Tue Jan 29 2013 jeffm@suse.com
- patches.suse/block-add-dev_check_rdonly-and-friends-for-lustre-testing: Temporarily disabled.
- commit 17680cf
* Tue Jan 29 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Specify full path to the vmlinuz image, so
  that the pattern does not match the vmlinuz-*.hmac file.
- commit a6c4965
* Tue Jan 29 2013 tiwai@suse.de
- Refresh patches.drivers/alsa-sp3-dsp-001-Make-snd_sgbuf_get_-ptr-addr-available.
  Fixed missing inclusion of linux/export.h.
- commit 9b37ad1
* Tue Jan 29 2013 ohering@suse.de
- tools/hv: Fix string types.
- Tools: hv: Don't return loopback addresses.
- tools: hv: Netlink source address validation allows DoS.
- tools: hv: Return the full kernel version.
- Drivers: hv: remove unused variable from channel_mgmt.c.
- hyperv: Add an error message to rndis_filter_set_device_mac().
- net/hyperv: fix wrong length of mac address.
- Drivers: hv: Get rid of unnecessary forward declarations.
- hyperv: Remove unnecessary comments in rndis_filter_receive_data().
- commit 8cb01ad
* Tue Jan 29 2013 tiwai@suse.de
- Update config files.
  Enable CONFIG_SND_HDA_DSP_LOADER=y
- commit 9e51e32
* Tue Jan 29 2013 tiwai@suse.de
- ALSA: hda - Change return value for load_dsp_prepare() to
  - ENOSYS (FATE#314291).
- ALSA: hda - Add new DSP loader callback routines (FATE#314291).
- ALSA: Make snd_sgbuf_get_{ptr|addr}() available for non-SG cases
  (FATE#314291).
- commit 8662988
* Tue Jan 29 2013 ohering@suse.de
- hv: hv_balloon: mark a function static. (fate#314663)
- commit 6e280a0
* Tue Jan 29 2013 ohering@suse.de
- hv: update patch headers for fate314663 related patches
- commit e0da194
* Tue Jan 29 2013 jeffm@suse.com
- patches.suse/block-add-dev_check_rdonly-and-friends-for-lustre-testing:
  Save flags in __put_blkdev case.
- commit 728cdf4
* Tue Jan 29 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Sign the kernel in the buildservice
  (fate#314552).
- commit 9583d05
* Tue Jan 29 2013 trenn@suse.de
- Updated patches as they went into x86-tip (only changelog
  and meta data changes):
- Refresh patches.drivers/pci_aer_cleanup_log_output.patch.
- aerdrv: Trace Event for PCI Express Advanced Error Reporting
  (fate#314197 bnc#799040).
- Refresh patches.drivers/pci_aer_use_trace_event.patch.
- commit b231e5f
* Tue Jan 29 2013 hare@suse.de
- patches.suse/block-add-dev_check_rdonly-and-friends-for-lustre-testing:
  correct argument for spin_lock_irq/spin_unlock_irq.
- commit 434361e
* Mon Jan 28 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Avoid generating a new keypair during build.
- commit f2acc4a
* Mon Jan 28 2013 mmarek@suse.cz
- Add the SLE UEFI certificate and OBS project certificate to the kernel.
- commit 0cda338
* Mon Jan 28 2013 bpoirier@suse.de
- Refresh
  patches.drivers/ethtool-Update-ethtool_rxnfc-rule_cnt-on-return-from.patch.
- Delete
  patches.drivers/0003-ixgbe-consolidate-MRQC-and-MTQC-handling.patch.
- Delete
  patches.drivers/0004-ixgbe-dcbnl-reduce-duplicated-code-and-indentation.patch.
- Delete
  patches.drivers/0005-ixgbe-configure-minimal-packet-buffers-to-support-TC.patch.
- Delete
  patches.drivers/0006-ixgbe-consolidate-packet-buffer-allocation.patch.
- Delete
  patches.drivers/0007-ixgbe-add-basic-support-for-setting-and-getting-nfc-.patch.
- Delete
  patches.drivers/0008-ixgbe-DCB-use-existing-TX-and-RX-queues.patch.
- Delete
  patches.drivers/0009-ixgbe-add-support-for-displaying-ntuple-filters-via-.patch.
- Delete
  patches.drivers/0010-ixgbe-fix-flags-relating-to-perfect-filters-to-suppo.patch.
- Delete patches.drivers/0011-ixgbe-remove-ntuple-filtering.patch.
- Delete
  patches.drivers/0012-ixgbe-update-perfect-filter-framework-to-support-ret.patch.
- Delete
  patches.drivers/0013-ixgbe-add-support-for-nfc-addition-and-removal-of-fi.patch.
- Delete
  patches.drivers/0014-ixgbe-remove-redundant-configuration-of-tx_sample_ra.patch.
- Delete
  patches.drivers/0015-ixgbe-PFC-not-cleared-on-X540-devices.patch.
- Delete
  patches.drivers/0016-ixgbe-DCB-and-perfect-filters-can-coexist.patch.
- Delete
  patches.drivers/0017-ixgbe-consolidate-setup-for-multiple-traffic-classes.patch.
- Delete
  patches.drivers/0018-v2-ixgbe-Update-packet-buffer-reservation-to-correct.patch.
- Delete
  patches.drivers/0019-ixgbe-update-P-FC-thresholds-to-account-for-X540-and.patch.
- Delete
  patches.drivers/0020-ixgbe-Make-certain-to-initialize-the-fdir_perfect_lo.patch.
- Delete
  patches.drivers/0021-ixgbe-complete-FCoE-initialization-from-setapp-routi.patch.
- Delete
  patches.drivers/0022-ixgbe-DCB-do-not-call-set_state-from-IEEE-mode.patch.
- Delete
  patches.drivers/0023-ixgbe-add-structure-for-containing-RX-TX-rings-to-q_.patch.
- Delete
  patches.drivers/0024-ixgbe-Move-interrupt-related-values-out-of-ring-and-.patch.
- Delete
  patches.drivers/0025-ixgbe-DCB-X540-devices-support-max-traffic-class-of-.patch.
- Delete
  patches.drivers/0026-ixgbe-Move-all-values-that-deal-with-count-next_to_u.patch.
- Delete
  patches.drivers/0027-ixgbe-Update-method-used-for-determining-descriptor-.patch.
- Delete
  patches.drivers/0028-ixgbe-Add-one-function-that-handles-most-of-context-.patch.
- Delete
  patches.drivers/0029-ixgbe-Refactor-transmit-map-and-cleanup-routines.patch.
- Delete
  patches.drivers/0030-ixgbe-Cleanup-FCOE-and-VLAN-handling-in-xmit_frame_r.patch.
- Delete
  patches.drivers/0031-ixgbe-Always-tag-VLAN-tagged-packets.patch.
- Delete
  patches.drivers/0032-ixgbe-fixup-hard-dependencies-on-supporting-8-traffi.patch.
- Delete
  patches.drivers/ixgbe-Address-fact-that-RSC-was-not-setting-GSO-size.patch.
- Delete
  patches.drivers/ixgbe-FCoE-Add-support-for-ndo_get_fcoe_hbainfo-call.patch.
- Delete
  patches.drivers/ixgbe-Fix-FCOE-memory-leak-for-DDP-packets.patch.
- Delete patches.drivers/ixgbe-add-WOL-support-for-X540.
- Delete
  patches.drivers/ixgbe-add-missing-rtnl_lock-in-PM-resume-path.patch.
- Delete
  patches.drivers/ixgbe-change-the-eeprom-version-reported-by-ethtool.patch.
- Delete
  patches.drivers/ixgbe-fix-ring-assignment-issues-for-SR-IOV-and-drop.patch.
- Delete
  patches.drivers/ixgbe-only-enable-WoL-for-magic-packet-by-default.patch.
- Delete
  patches.drivers/ixgbe-resolve-errors-with-many-to-one-mappings.patch.
- Delete
  patches.drivers/ixgbe-setup-per-CPU-PCI-pool-for-FCoE-DDP.patch.
- commit f340eea
* Mon Jan 28 2013 bpoirier@suse.de
- Refresh
  patches.drivers/bnx2x-0048-bnx2x-Support-loading-cnic-resources-at-run-time.patch.
- commit 04d7e11
* Mon Jan 28 2013 bp@suse.de
- i7core_edac: Don't enable memory scrubbing for Xeon 35xx
  (bnc#800339).
- commit b9fb00e
* Mon Jan 28 2013 jkosina@suse.cz
- x86, fpu: always use kernel_fpu_begin/end() for in-kernel FPU
  usage (bnc#795398).
- Refresh patches.xen/xen3-auto-arch-x86_64.diff.
- commit c65bab1
* Mon Jan 28 2013 jslaby@suse.cz
- patches.arch/x86-pci-Increase-the-number-of-iommus-supported-to-be-MAX_IO_APICS.patch:
  Refresh.
- commit 9ef1cd9
* Mon Jan 28 2013 mmarek@suse.cz
- Get rid of colons in patch names.
- commit eb1add0
* Mon Jan 28 2013 ohering@suse.de
- Drivers: hv: balloon: Make adjustments to the pressure report.
- commit 950f3f1
* Mon Jan 28 2013 jslaby@suse.cz
- Linux 3.0.61 (bnc#776787).
- patches.kernel.org/revert-PCI-Allow-pcie_aspm-force-even-when-FADT-indi.patch:
  Revert "PCI: Allow pcie_aspm=force even when FADT indicates
  it is unsupported".
- patches.fixes/sd-init_sd-reshuffle.patch: Delete.
- commit 332caa6
* Mon Jan 28 2013 mmarek@suse.cz
- Update config files.
- commit 6be622a
* Mon Jan 28 2013 jslaby@suse.cz
- Linux 3.0.60 (bnc#799275, LTC#87978).
- patches.arch/s390-63-02-sched-clock.patch: Delete.
- commit fdcafb9
* Mon Jan 28 2013 mmarek@suse.cz
- MODSIGN: Simplify Makefile with a Kconfig helper.
- MODSIGN: Specify the hash algorithm on sign-file command line.
- MODSIGN: Add -s <signature> option to sign-file.
- patches.suse/0001-firmware:_Add_the_firmware_signing_support_to_scripts_sign-file.patch:
  Rebase.
- patches.suse/0004-firmware:_Install_firmware_signature_files_automatically.patch:
  Refresh and add dependency on CONFIG_MODULE_SIG_ALL.
- Refresh
  patches.suse/0005-MODSIGN-Add-module-certificate-blacklist-keyring.patch.
- patches.fixes/MODSIGN-Add-option-to-not-sign-modules-during-build.patch:
  Replace with upstream patch.
- Delete
  patches.suse/0002-firmware:_Add_-a_option_to_scripts_sign-file.patch.
- commit a01e2b9
* Mon Jan 28 2013 mmarek@suse.cz
- patches.fixes/0003-MODSIGN-Drop-ccache-hack.patch: Clarify mainline
  status.
- commit 5c8117b
* Mon Jan 28 2013 jslaby@suse.cz
- Linux 3.0.59 (bnc#793671).
- patches.drivers/USB3-0128-usbcore-refine-warm-reset-logic.patch:
  Refresh.
- patches.drivers/USB3-0131-USB-When-hot-reset-for-USB3-fails-try-warm-reset.patch:
  Refresh.
- patches.drivers/qla2xxx-0003-Code-changes-to-support-new-dynamic-logging.patch:
  Refresh.
- patches.kabi/revert-rtnetlink-Fix-problem-with-buffer-allocation.patch:
  Revert "rtnetlink: Fix problem with buffer allocation".
- patches.kabi/revert-rtnetlink-fix-rtnl_calcit-and-rtnl_dump_ifinf.patch:
  Revert "rtnetlink: fix rtnl_calcit() and rtnl_dump_ifinfo()".
- patches.drivers/rtnetlink-compute-and-store-minimum-ifinfo-dump-size:
  Delete.
- patches.fixes/thp-memcg-split-hugepage-for-memcg-oom-on-cow.patch:
  Delete.
- commit 17b2537
* Mon Jan 28 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Copy *.x509 files to the builddir
- commit 4499af8
* Mon Jan 28 2013 mmarek@suse.cz
- KEYS: Load *.x509 files into kernel keyring.
- MODSIGN: Fix kbuild output when using default
  extra_certificates.
- commit e48370f
* Sun Jan 27 2013 mmarek@suse.cz
- Replace two modsign patches with upstream commits:
- patches.fixes/0001-MODSIGN-Fix-comparison-erros-in-scripts-sign-file.patch
- patches.fixes/0002-MODSIGN-Avoid-using-.incbin-in-C-source.patch.
- commit 992c7e7
* Sat Jan 26 2013 jeffm@suse.com
- Fix building with patches.suse/block-add-dev_check_rdonly-and-friends-for-lustre-testing properly. Silly cut-n-paste.
- commit 0b4a5ce
* Sat Jan 26 2013 jeffm@suse.com
- Fixed build with patches.suse/block-add-dev_check_rdonly-and-friends-for-lustre-testing
- commit 2f67d36
* Fri Jan 25 2013 jeffm@suse.com
- patches.suse/block-add-dev_check_rdonly-and-friends-for-lustre-testing: Re-worked to not take a global spinlock in generic_make_request().
- commit 283e348
* Fri Jan 25 2013 bpoirier@suse.de
- Delete patches.drivers/e1000e-fix-tx-hang-recovery.
- commit 549c4b7
* Fri Jan 25 2013 bpoirier@suse.de
- drivers/net: fix up function prototypes after __dev* removals
  (bnc#795174 FATE#313648).
- net/intel: remove __dev* attributes (bnc#795174 FATE#313648).
- e1000e: cosmetic cleanup of comments (bnc#795174 FATE#313648).
- e1000e: Minimum packet size must be 17 bytes (bnc#795174
  FATE#313648).
- e1000e: Change wthresh to 1 to avoid possible Tx stalls
  (bnc#795174 FATE#313648).
- e1000e: add device IDs for i218 (bnc#795174 FATE#313648).
- netdev: make pci_error_handlers const (bnc#795174 FATE#313648).
- e1000e: update driver version number (bnc#795174 FATE#313648).
- e1000e: cleanup - remove unnecessary variable (bnc#795174
  FATE#313648).
- e1000e: cleanup - remove inapplicable comment (bnc#795174
  FATE#313648).
- e1000e: cleanup strict checkpatch check (bnc#795174
  FATE#313648).
- e1000e: cleanup strict checkpatch MEMORY_BARRIER checks
  (bnc#795174 FATE#313648).
- e1000e: use correct type for read of 32-bit register (bnc#795174
  FATE#313648).
- e1000e: DoS while TSO enabled caused by link partner with
  small MSS (bnc#795174 FATE#313648).
- e1000e: Use PCI Express Capability accessors (bnc#795174
  FATE#313648).
- e1000e: implement MDI/MDI-X control (bnc#795174 FATE#313648).
- e1000e: implement 82577/579 MDI setting support (bnc#795174
  FATE#313648).
- e1000e: fix panic while dumping packets on Tx hang with IOMMU
  (bnc#795174 FATE#313648).
- e1000e: 82571 Tx Data Corruption during Tx hang recovery
  (bnc#795174 FATE#313648).
- e1000e: advertise transmit time stamping (bnc#795174
  FATE#313648).
- e1000e: Program the correct register for ITR when using MSI-X
  (bnc#795174 FATE#313648).
- e1000e: Cleanup code logic in
  e1000_check_for_serdes_link_82571() (bnc#795174 FATE#313648).
- e1000e: fix test for PHY being accessible on 82577/8/9 and I217
  (bnc#795174 FATE#313648).
- drivers/net/ethernet: Fix (nearly-)kernel-doc comments for
  various functions (bnc#795174 FATE#313648).
- e1000e: remove use of IP payload checksum (bnc#795174
  FATE#313648).
- e1000e: use more informative logging macros when netdev not
  yet registered (bnc#795174 FATE#313648).
- e1000e: test for valid check_reset_block function pointer
  (bnc#795174 FATE#313648).
- e1000e: fix Rapid Start Technology support for i217 (bnc#795174
  FATE#313648).
- e1000e: fix typo in definition of E1000_CTRL_EXT_FORCE_SMBUS
  (bnc#795174 FATE#313648).
- e1000e: Fix merge conflict (net->net-next) (bnc#795174
  FATE#313648).
- e1000e: increase version number (bnc#795174 FATE#313648).
- e1000e: clear REQ and GNT in EECD (82571 && 82572) (bnc#795174
  FATE#313648).
- e1000e: enable forced master/slave on 82577 (bnc#795174
  FATE#313648).
- e1000e: initial support for i217 (bnc#795174 FATE#313648).
- e1000e: Update driver version number (bnc#795174 FATE#313648).
- e1000e: Remove special case for 82573/82574 ASPM L1 disablement
  (bnc#795174 FATE#313648).
- e1000e: Driver workaround for IPv6 Header Extension Erratum
  (bnc#795174 FATE#313648).
- e1000e: Resolve intermittent negotiation issue on 82574/82583
  (bnc#795174 FATE#313648).
- e1000e: cleanup long [read|write]_reg_locked PHY ops function
  pointers (bnc#795174 FATE#313648).
- e1000e: suggest a possible workaround to a device hang on
  82577/8 (bnc#795174 FATE#313648).
- e1000e: fix .ndo_set_rx_mode for 82579 (bnc#795174 FATE#313648).
- e1000e: PHY initialization flow changes for 82577/8/9
  (bnc#795174 FATE#313648).
- e1000e: workaround EEPROM configuration change on 82579
  (bnc#795174 FATE#313648).
- e1000e: add transmit timestamping support (bnc#795174
  FATE#313648).
- e1000e: 82579 potential system hang on stress when ME enabled
  (bnc#795174 FATE#313648).
- e1000e: 82579 packet drop workaround (bnc#795174 FATE#313648).
- e1000e: Enable DMA Burst Mode on 82574 by default (bnc#795174
  FATE#313648).
- e1000e: Disable Far-End LoopBack following reset on 80003ES2LAN
  (bnc#795174 FATE#313648).
- e1000e: Fix default interrupt throttle rate not set in NIC HW
  (bnc#795174 FATE#313648).
- e1000e: MSI interrupt test failed, using legacy interrupt
  (bnc#795174 FATE#313648).
- e1000e: cleanup boolean logic (bnc#795174 FATE#313648).
- e1000e: cleanup remaining strings split across multiple lines
  (bnc#795174 FATE#313648).
- e1000e: issues in Sx on 82577/8/9 (bnc#795174 FATE#313648).
- e1000e: update driver version number (bnc#795174 FATE#313648).
- e1000e: cleanup indexed register arrays (bnc#795174
  FATE#313648).
- e1000e: cleanup NAPI routine (bnc#795174 FATE#313648).
- e1000e: Minor comment clean-up (bnc#795174 FATE#313648).
- e1000e: Guarantee descriptor writeback flush success (bnc#795174
  FATE#313648).
- e1000e: prevent oops when adapter is being closed and reset
  simultaneously (bnc#795174 FATE#313648).
- intel: make wired ethernet driver message level consistent
  (rev2) (bnc#795174 FATE#313648).
- e1000e: use msleep instead of mdelay (bnc#795174 FATE#313648).
- e1000e: cleanup whitespace and indentation (bnc#795174
  FATE#313648).
- e1000e: cleanup incorrect filename in comment (bnc#795174
  FATE#313648).
- e1000e: rename e1000e_reload_nvm() and call as function pointer
  (bnc#795174 FATE#313648).
- e1000e: cleanup - remove unnecessary variable (bnc#795174
  FATE#313648).
- e1000e: use true/false for boolean send_xon, do not assume
  always true (bnc#795174 FATE#313648).
- e1000e: cleanup comment in e1000_hash_mc_addr() (bnc#795174
  FATE#313648).
- e1000e: rename e1000e_config_collision_dist() and call as
  function pointer (bnc#795174 FATE#313648).
- e1000e: comment correction in
  e1000e_set_kmrn_lock_loss_workaround_ich8lan (bnc#795174
  FATE#313648).
- e1000e: cleanup calls to setup_physical_interface function
  pointer (bnc#795174 FATE#313648).
- e1000e: cleanup use of check_reset_block function pointer
  (bnc#795174 FATE#313648).
- e1000e: cleanup use of check_mng_mode function pointer
  (bnc#795174 FATE#313648).
- e1000e: cleanup: rename e1000e_setup_link() and call as function
  pointer (bnc#795174 FATE#313648).
- e1000e: cleanup: rename e1000e_id_led_init() and call as
  function pointer (bnc#795174 FATE#313648).
- e1000e: cosmetic comment changes to make lines less than 80
  characters (bnc#795174 FATE#313648).
- e1000e: cosmetic change to boolean comparisons (bnc#795174
  FATE#313648).
- e1000e: Support sending custom Ethernet CRC (bnc#795174
  FATE#313648).
- e1000e: cleanup goto statements to exit points without common
  work (bnc#795174 FATE#313648).
- e1000e: potentially incorrect return for
  e1000e_setup_fiber_serdes_link (bnc#795174 FATE#313648).
- e1000e: potentially incorrect return for e1000_init_hw_ich8lan
  (bnc#795174 FATE#313648).
- e1000e: cleanup: minor whitespace addition (insert blank line
  separator) (bnc#795174 FATE#313648).
- e1000e: cleanup: remove unnecessary variable initializations
  (bnc#795174 FATE#313648).
- e1000e: cleanup: remove unnecessary test and return (bnc#795174
  FATE#313648).
- e1000e: cleanup: remove unnecessary variable ret_val (bnc#795174
  FATE#313648).
- e1000e: cleanup: remove unreachable statement (bnc#795174
  FATE#313648).
- e1000e: potentially incorrect return for
  e1000_set_d3_lplu_state_ich8lan (bnc#795174 FATE#313648).
- e1000e: cleanup: always return 0 (bnc#795174 FATE#313648).
- e1000e: cleanup: remove unnecessary assignments just before
  returning (bnc#795174 FATE#313648).
- e1000e: potential incorrect return for
  e1000_setup_copper_link_80003es2lan (bnc#795174 FATE#313648).
- e1000e: potentially incorrect return for
  e1000_cfg_kmrn_10_100_80003es2lan (bnc#795174 FATE#313648).
- e1000e: cleanup: rename goto labels to be more meaningful
  (bnc#795174 FATE#313648).
- e1000e: cleanup: use goto for common work needed by multiple
  exit points (bnc#795174 FATE#313648).
- e1000e: replace '1' with 'true' for boolean get_link_status
  (bnc#795174 FATE#313648).
- e1000e: pass pointer to hw struct for
  e1000_init_mac_params_XXX() (bnc#795174 FATE#313648).
- e1000e: use true/false for bool autoneg_false (bnc#795174
  FATE#313648).
- e1000e: remove unnecessary parentheses (bnc#795174 FATE#313648).
- e1000e: remove unnecessary returns from void functions
  (bnc#795174 FATE#313648).
- e1000e: remove test that is always false (bnc#795174
  FATE#313648).
- e1000e: minor whitespace and indentation cleanup (bnc#795174
  FATE#313648).
- e1000e: fix sparse warnings with -D__CHECK_ENDIAN__ (bnc#795174
  FATE#313648).
- e1000e: fix checkpatch warning from MINMAX test (bnc#795174
  FATE#313648).
- e1000e: cleanup - use braces in both branches of a conditional
  statement (bnc#795174 FATE#313648).
- e1000e: cleanup e1000_set_phys_id (bnc#795174 FATE#313648).
- e1000e: cleanup e1000_init_mac_params_82571() (bnc#795174
  FATE#313648).
- e1000e: cleanup e1000_init_mac_params_80003es2lan() (bnc#795174
  FATE#313648).
- e1000e: cleanup - check return values consistently (bnc#795174
  FATE#313648).
- e1000e: add missing initializers reported when compiling with
  W=1 (bnc#795174 FATE#313648).
- e1000e: update copyright year (bnc#795174 FATE#313648).
- e1000e: split lib.c into three more-appropriate files
  (bnc#795174 FATE#313648).
- e1000e: call er16flash() instead of __er16flash() (bnc#795174
  FATE#313648).
- e1000e: increase version number (bnc#795174 FATE#313648).
- e1000e: convert final strncpy() to strlcpy() (bnc#795174
  FATE#313648).
- e1000e: concatenate long debug strings which span multiple lines
  (bnc#795174 FATE#313648).
- e1000e: conditionally restart autoneg on 82577/8/9 when setting
  LPLU state (bnc#795174 FATE#313648).
- e1000e: increase Rx PBA to prevent dropping received packets
  on 82566/82567 (bnc#795174 FATE#313648).
- e1000e: ICHx/PCHx LOMs should use LPLU setting in NVM when
  going to Sx (bnc#795174 FATE#313648).
- e1000e: update workaround for 82579 intermittently disabled
  during S0->Sx (bnc#795174 FATE#313648).
- e1000e: disable Early Receive DMA on ICH LOMs (bnc#795174
  FATE#313648).
- e1000e: Need to include vmalloc.h (bnc#795174 FATE#313648).
- e1000e: 82574/82583 Tx hang workaround (bnc#795174 FATE#313648).
- e1000e: use hardware default values for Transmit Control
  register (bnc#795174 FATE#313648).
- e1000e: use default settings for Tx Inter Packet Gap timer
  (bnc#795174 FATE#313648).
- e1000e: 82579: workaround for link drop issue (bnc#795174
  FATE#313648).
- e1000e: always set transmit descriptor control registers the
  same (bnc#795174 FATE#313648).
- e1000e: default IntMode based on kernel config & available
  hardware support (bnc#795174 FATE#313648).
- e1000e: re-factor ethtool get/set ring parameter (bnc#795174
  FATE#313648).
- e1000e: pass pointer to ring struct instead of adapter struct
  (bnc#795174 FATE#313648).
- e1000e: convert head, tail and itr_register offsets to __iomem
  pointers (bnc#795174 FATE#313648).
- e1000e: re-enable alternate MAC address for all devices which
  support it (bnc#795174 FATE#313648).
- e1000e: add Receive Packet Steering (RPS) support (bnc#795174
  FATE#313648).
- e1000e: cleanup Rx checksum offload code (bnc#795174
  FATE#313648).
- net: fix assignment of 0/1 to bool variables (bnc#795174
  FATE#313648).
- e1000e: hitting BUG_ON() from napi_enable (bnc#795174
  FATE#313648).
- e1000e: Support for byte queue limits (bnc#795174 FATE#313648).
- net: sweep-up some straglers in strlcpy conversion of
  .get_drvinfo routines (bnc#795174 FATE#313648).
- e1000e: Convert printks to pr_<level> (bnc#795174 FATE#313648).
- Sweep the last of the active .get_drvinfo floors under ethernet/
  (bnc#795174 FATE#313648).
- e1000e: demote a debugging WARN to a debug log message
  (bnc#795174 FATE#313648).
- drivers/net: Add module.h to drivers who were implicitly using
  it (bnc#795174 FATE#313648).
- net: add skb frag size accessors (bnc#795174 FATE#313648).
- e1000e: locking bug introduced by commit 67fd4fcb (bnc#795174
  FATE#313648).
- e1000e: fix skb truesize underestimation (bnc#795174
  FATE#313648).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#795174 FATE#313648).
- e1000e: bad short packets received when jumbos enabled on 82579
  (bnc#795174 FATE#313648).
- e1000e: WoL fails on device ID 0x1501 (bnc#795174 FATE#313648).
- e1000e: WoL can fail on 82578DM (bnc#795174 FATE#313648).
- e1000e: make function tables const (bnc#795174 FATE#313648).
- intel: convert to SKB paged frag API (bnc#795174 FATE#313648).
- e1000e: convert to netdev features/hw_features API (bnc#795174
  FATE#313648).
- e1000e: bump driver version number (bnc#795174 FATE#313648).
- e1000e: convert driver to use extended descriptors (bnc#795174
  FATE#313648).
- e1000e: workaround invalid Tx/Rx tail descriptor register write
  (bnc#795174 FATE#313648).
- e1000e: Spurious interrupts & dropped packets with 82577/8/9
  in half-duplex (bnc#795174 FATE#313648).
- e1000e: increase driver version number (bnc#795174 FATE#313648).
- e1000e: alternate MAC address update (bnc#795174 FATE#313648).
- e1000e: do not disable receiver on 82574/82583 (bnc#795174
  FATE#313648).
- commit 575f0c3
* Fri Jan 25 2013 bpoirier@suse.de
- intel: Move the Intel wired LAN drivers (bnc#795174
  FATE#313648).
- Update config files.
- supported.conf:
- commit bd7567f
* Fri Jan 25 2013 bpoirier@suse.de
- e1000e: minor re-order of #include files (bnc#795174
  FATE#313648).
- e1000e: remove unnecessary check for NULL pointer (bnc#795174
  FATE#313648).
- intel drivers: repair missing flush operations (bnc#795174
  FATE#313648).
- e1000e: use GFP_KERNEL allocations at init time (bnc#795174
  FATE#313648).
- e1000e: Add Jumbo Frame support to 82583 devices (bnc#795174
  FATE#313648).
- e1000e: remove e1000_queue_stats (bnc#795174 FATE#313648).
- net: e1000e: Use is_multicast_ether_addr helper (bnc#795174
  FATE#313648).
- e1000e: remove unnecessary reads of PCI_CAP_ID_EXP (bnc#795174
  FATE#313648).
- e1000e: update driver version (bnc#795174 FATE#313648).
- e1000e: Clear host wakeup bit on 82577/8 without touching PHY
  page 800 (bnc#795174 FATE#313648).
- e1000e: access multiple PHY registers on same page at the same
  time (bnc#795174 FATE#313648).
- e1000e: do not schedule the Tx queue until ready (bnc#795174
  FATE#313648).
- e1000e: log when swflag is cleared unexpectedly on ICH/PCH
  devices (bnc#795174 FATE#313648).
- e1000e: 82579 intermittently disabled during S0->Sx (bnc#795174
  FATE#313648).
- e1000e: disable far-end loopback mode on ESB2 (bnc#795174
  FATE#313648).
- net: remove interrupt.h inclusion from netdevice.h (bnc#795174
  FATE#313648).
- commit 171a518
* Fri Jan 25 2013 bpoirier@suse.de
- Delete
  patches.drivers/0217-e1000e-disable-far-end-loopback-mode-on-ESB2.patch.
- Delete
  patches.drivers/0218-e1000e-82579-intermittently-disabled-during-S0-Sx.patch.
- Delete
  patches.drivers/0219-e1000e-log-when-swflag-is-cleared-unexpectedly-on-IC.patch.
- Delete
  patches.drivers/0221-e1000e-access-multiple-PHY-registers-on-same-page-at.patch.
- Delete
  patches.drivers/0222-e1000e-Clear-host-wakeup-bit-on-82577-8-without-touc.patch.
- Delete patches.drivers/0223-e1000e-update-driver-version.patch.
- Delete
  patches.drivers/0224-e1000e-remove-unnecessary-reads-of-PCI_CAP_ID_EXP.patch.
- Delete
  patches.drivers/0226-e1000e-remove-e1000_queue_stats.patch.
- Delete patches.drivers/e1000e-EECD-clear-REQ-and-GNT.patch.
- commit 13afab6
* Fri Jan 25 2013 duwe@suse.de
- e1000e: 82571 Fix Tx Data Corruption during Tx hang recovery
  (bnc#790867).
- commit 111c4e0
* Fri Jan 25 2013 duwe@suse.de
- patches.drivers/e1000e-fix-tx-hang-recovery: e1000e: 82571
  Fix Tx Data Corruption during Tx hang recovery (bnc#790867).
- commit be91972
* Fri Jan 25 2013 agraf@suse.de
- patches.fixes/kvm-set-irq.patch: KVM: Fix buffer overflow in
  kvm_set_irq() (bnc#767612 CVE-2012-2137).
- commit 10d2bba
* Fri Jan 25 2013 jkosina@suse.cz
- supported.conf: add transitive dependencies of dm-thin-pool (dm_bufio,
  dm_bufio) (bnc#800369 FATE#313903)
- commit e32e12e
* Fri Jan 25 2013 jkosina@suse.cz
- supported.conf: add dm-thin-pool (bnc#800369 FATE#313903)
- commit 4549694
* Fri Jan 25 2013 ohering@suse.de
- patches.suse/suse-hv-register-clocksource-only-if-its-adverti.patch:
  x86: Hyper-V: register clocksource only if its advertised
  (bnc#792500).
- commit cdbd6a7
* Fri Jan 25 2013 dsterba@suse.cz
- patches.suse/btrfs-8202-Fix-typo-in-fs-btrfs.patch: Btrfs:
  Fix typo in fs/btrfs.
- patches.suse/btrfs-8204-reset-path-lock-state-to-zero.patch:
  Btrfs: reset path lock state to zero.
- patches.suse/btrfs-8205-fix-off-by-one-in-lseek.patch: Btrfs:
  fix off-by-one in lseek.
- patches.suse/btrfs-8206-fix-btrfs_cont_expand-freeing-IS_ERR-em.patch:
  btrfs: fix btrfs_cont_expand() freeing IS_ERR em.
- patches.suse/btrfs-8207-update-timestamps-on-truncate.patch:
  btrfs: update timestamps on truncate().
- patches.suse/btrfs-8208-put-csums-on-the-right-ordered-extent.patch:
  Btrfs: put csums on the right ordered extent.
- patches.suse/btrfs-8194-fix-permissions-of-empty-files-not-affected-by.patch:
  Delete.
- commit 7726746
* Thu Jan 24 2013 dsterba@suse.cz
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
  fix build under non-enterprise support config
- commit 9eed393
* Thu Jan 24 2013 bpoirier@suse.de
- Update config files.
  commit "f683b6d Remove PTP from tg3" should also have disabled
  CONFIG_PTP_1588_CLOCK
- commit ffb4715
* Thu Jan 24 2013 bpoirier@suse.de
- supported.conf: Update for all network drivers which were already moved
- commit 0bad19a
* Thu Jan 24 2013 jeffm@suse.com
- block: add dev_check_rdonly and friends for Lustre testing
  (FATE#314679).
- dcache: Add DCACHE_LUSTRE_INVALID flag for Lustre to handle
  its own invalidation (FATE#314679).
- lsm: export security_inode_unlink (FATE#315679).
- lustre: Add lustre kernel version (FATE#314679).
- commit fba4cc9
* Thu Jan 24 2013 mhocko@suse.cz
- drop_caches: add some documentation and info message
  (fate#313766).
- commit ff8ca6d
* Thu Jan 24 2013 bpoirier@suse.de
- Update
  patches.drivers/ixgbe-FCoE-Add-support-for-ndo_get_fcoe_hbainfo-call.patch
  (FATE#313795).
- Update
  patches.drivers/ixgbe-change-the-eeprom-version-reported-by-ethtool.patch
  (FATE#313795).
- Update
  patches.drivers/netdev-FCoE-Add-new-ndo_get_fcoe_hbainfo-call.patch
  (FATE#313795).
- commit e391a2f
* Thu Jan 24 2013 mkubecek@suse.cz
- patches.fixes/xfrm-fix-freed-block-size-calculation-in-xfrm_policy.patch:
  xfrm: fix freed block size calculation in xfrm_policy_fini()
  (bnc#798960).
- commit caa15e8
* Thu Jan 24 2013 mkubecek@suse.cz
- patches.fixes/bonding-in-balance-rr-mode-set-curr_active_slave-onl.patch:
  bonding: in balance-rr mode, set curr_active_slave only if it
  is up (bnc#789648).
- commit e9591f5
* Thu Jan 24 2013 jjolly@suse.de
- patches.arch/s390-63-01-irq-stat.patch: kernel: broken interrupt
  statistics (bnc#799275, LTC#87893).
- patches.arch/s390-63-02-sched-clock.patch: kernel: sched_clock()
  overflow (bnc#799275, LTC#87978).
- commit 348573a
* Wed Jan 23 2013 mfasheh@suse.de
- btrfs: add "no file data" flag to btrfs send ioctl
  (fate#311399).
- commit 47981b8
* Wed Jan 23 2013 mmarek@suse.cz
- MODSIGN: Add option to not sign modules during build.
- Update config files: Disable CONFIG_MODULE_SIG_ALL, the modules will
  be signed separately (fate#314552).
- commit b999d97
* Wed Jan 23 2013 mhocko@suse.cz
- patches.fixes/mm-call-sleep_on_page_killable-in-__wait_on_page_locked_killable.patch:
  mm: call sleep_on_page_killable from
  __wait_on_page_locked_killable (bnc#799909).
- commit 0a60801
* Tue Jan 22 2013 jslaby@suse.cz
- patches.fixes/TTY-do-not-reset-master-s-packet-mode.patch:
  TTY: do not reset master's packet mode (bnc#797042).
- commit 4b3c91b
* Tue Jan 22 2013 bpoirier@suse.de
- sfc: Make module parameters really boolean (bnc#786035
  FATE#314299).
- sfc: Fix timekeeping in efx_mcdi_poll() (bnc#786035
  FATE#314299).
- sfc: lock TX queues when calling netif_device_detach()
  (bnc#786035 FATE#314299).
- sfc: Work-around flush timeout when flushes have completed
  (bnc#786035 FATE#314299).
- sfc: Reset driver's MAC stats after MC reboot seen (bnc#786035
  FATE#314299).
- sfc: Do not initialise buffer in efx_alloc_special_buffer()
  (bnc#786035 FATE#314299).
- sfc: Correctly initialise reset_method in siena_test_chip()
  (bnc#786035 FATE#314299).
- sfc: Remove confusing MMIO functions (bnc#786035 FATE#314299).
- sfc: Fix check for failure of MC_CMD_FLUSH_RX_QUEUES (bnc#786035
  FATE#314299).
- sfc: Delete redundant page_addr variable from
  efx_init_rx_buffers_page() (bnc#786035 FATE#314299).
- sfc: Really disable flow control while flushing (bnc#786035
  FATE#314299).
- sfc: Fix byte order warning in self-test (bnc#786035
  FATE#314299).
- sfc: Fix byte order warnings for ethtool RX filter interface
  (bnc#786035 FATE#314299).
- net: Remove bogus dependencies on INET (bnc#786035 FATE#314299).
- commit 549caf9
* Tue Jan 22 2013 mmarek@suse.cz
- patches.suse/kbuild-record-built-in-o: Avoid using printf(1) in
  Makefile.build
- rpm/built-in-where.mk: Do not rely on the *.parts file to be
  newline-separated.
- commit 53af1e0
* Tue Jan 22 2013 jlee@suse.com
- [libata] replace sata_settings with devslp_timing (fate#313946,
  bnc#783331).
- commit ebe147a
* Mon Jan 21 2013 bpoirier@suse.de
- drivers/net: fix up function prototypes after __dev* removals
  (bnc#798929 FATE#313650).
- net/intel: remove __dev* attributes (bnc#798929 FATE#313650).
- netdev: make pci_error_handlers const (bnc#798929 FATE#313650).
- net: e100: ucode is optional in some cases (bnc#798929
  FATE#313650).
- e100: enable transmit time stamping (bnc#798929 FATE#313650).
- e100: Support the get_ts_info ethtool method (bnc#798929
  FATE#313650).
- e100: Show short v/s long rx length errors in ethtool stats
  (bnc#798929 FATE#313650).
- e100: Fix rx-over-length statistics (bnc#798929 FATE#313650).
- e100: Support sending custom Ethernet CRC (bnc#798929
  FATE#313650).
- drivers/net: Remove alloc_etherdev error messages (bnc#798929
  FATE#313650).
- Sweep away N/A fw_version dustbunnies from the .get_drvinfo
  routine of a number of drivers (bnc#798929 FATE#313650).
- Sweep additional floors of strcpy in .get_drvinfo routines
  (bnc#798929 FATE#313650).
- e100: make sure vlan support isn't advertised on old adapters
  (bnc#798929 FATE#313650).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#798929 FATE#313650).
- commit 9b8c81c
* Mon Jan 21 2013 bpoirier@suse.de
- intel: Move the Intel wired LAN drivers (bnc#798929
  FATE#313650).
- Update config files.
- commit 6ecbb08
* Mon Jan 21 2013 bpoirier@suse.de
- net: remove interrupt.h inclusion from netdevice.h (bnc#798929
  FATE#313650).
- commit 59bf3c7
* Mon Jan 21 2013 hare@suse.de
- Update DASD blk_timeout patches after review from IBM (FATE#311379):
  * patches.suse/blk-timeout-no-round: Refresh.
  * patches.suse/dasd-Abort-all-requests-from-ioctl.patch: dasd:
    Abort all requests from ioctl (FATE#311379).
  * patches.suse/dasd-Disable-block-timeouts-per-default.patch:
    dasd: Disable block timeouts per default (FATE#311379).
  * patches.suse/dasd-Reduce-amount-of-messages-for-specific-errors.patch:
    dasd: Reduce amount of messages for specific errors
    (FATE#311379).
  * patches.suse/dasd-Rename-ioctls.patch: dasd: Rename ioctls
    (FATE#311379).
  * patches.suse/dasd-check-blk_noretry_request-in-dasd_times_out.patch:
    dasd: check blk_noretry_request in dasd_times_out()
    (FATE#311379).
  * patches.suse/dasd-lock-ccw-queue-in-dasd_times_out.patch:
    dasd: lock ccw queue in dasd_times_out() (FATE#311379).
  * patches.suse/dasd-make-DASD_FLAG_TIMEOUT-setting-more-robust.patch:
    dasd: make DASD_FLAG_TIMEOUT setting more robust (FATE#311379).
  * patches.suse/dasd-rename-flag-to-abortall.patch: dasd: rename
    flag to 'abortall' (FATE#311379).
  * patches.suse/dasd-fail-all-requests-on-dasd_times_out.patch:
    Delete.
  * patches.suse/dasd-set-and-unset-TIMEOUT-flag.patch: Delete.
- commit c8bc8a3
* Mon Jan 21 2013 jkosina@suse.cz
- Update config files.
- supported.conf: support w83627ehf.ko on x86_32 (FATE#314103)
- commit f59802d
* Mon Jan 21 2013 jankit@suse.de
- patches.drivers/lpfc-8.3.32-Correct-successful-aborts-returning-error-status.patch:
  lpfc 8.3.32: Correct successful aborts returning error status
  (bnc#793593).
- patches.drivers/lpfc-8.3.34-Correct-lock-handling-to-eliminate-reset-escalation-on-io-abort.patch:
  lpfc 8.3.34: Correct lock handling to eliminate reset escalation
  on I/O abort (bnc#793593).
- patches.drivers/lpfc-8.3.34-Streamline-fcp-underrun-message-printing.patch:
  lpfc 8.3.34: Streamline fcp underrun message printing
  (bnc#793593).
- patches.drivers/lpfc-8.3.5.48.3p-update: Update lpfc version
  for 8.3.5.48.3p driver release (bnc#793593).
- commit 3899060
* Mon Jan 21 2013 mmarek@suse.cz
- scripts/sequence-patch.sh: Fix the symlink if SCRATCH_AREA ends with "/"
  The default value of $PATCH_DIR is defined as $SCRATCH_AREA/linux-...,
  so we need to subtract $SCRATCH_AREA/ to get the subdirectory name.
  Otherwise, sequence-patch.sh -d /path/ would result in a /linux-...
  symlink.
- commit b779ee3
* Mon Jan 21 2013 jjolly@suse.de
- Refresh
  patches.arch/s390-kvm-0039-KVM-s390-Add-support-for-machine-checks.patch.
- Refresh
  patches.arch/s390-sles11sp3-14-01-cpu_runtime_instrumentation.patch.
- commit f7724f4
* Mon Jan 21 2013 neilb@suse.de
- patches.fixes/bug-795354_Allow-sec-none-mounts-in-certain-cases.patch:
  NFS: Allow sec=none mounts in certain cases (bnc#795354).
- commit e1deaf3
* Sun Jan 20 2013 ohering@suse.de
- hyperv: force vmbus interrupts to cpu 0.
  (instead of forcing ws2008 during vmbus negotiation.)
- commit b77fc66
* Sat Jan 19 2013 brogers@suse.com
- KVM: x86: Fix invalid secondary exec controls in
  vmx_cpuid_update() (bnc#799412, fate#313826).
- KVM: x86: Check INVPCID feature bit in EBX of leaf 7
  (bnc#799412, fate#313826).
- commit 58aabfd
* Fri Jan 18 2013 bpoirier@suse.de
- patches.fixes/bridge-Pull-ip-header-into-skb-data-before-looking-i.patch:
  bridge: Pull ip header into skb->data before looking into ip
  header (bnc#799209).
- commit 9fa3fa3
* Fri Jan 18 2013 tonyj@suse.de
- Update FATE references in intel perf-event patches. Drop reference to
  fate#313762 in all patches, add reference to 314605 in select patches.
- commit cf6170b
* Fri Jan 18 2013 bpoirier@suse.de
- cxgb3: Fix Tx csum stats (bnc#784800 FATE#314296).
- commit 182d3e9
* Fri Jan 18 2013 brogers@suse.com
- KVM: x86: Emulate IA32_TSC_ADJUST MSR (fate#313619).
- KVM: x86: Add code to track call origin for msr assignment
  (fate#313619).
- KVM: x86: add kvm_arch_vcpu_postcreate callback, move TSC
  initialization (fate#313619).
- commit a4418b6
* Fri Jan 18 2013 trenn@suse.de
- aerdrv: Cleanup log output for AER (fate#314197 bnc#799040).
- aerdrv: Enhanced AER logging (fate#314197 bnc#799040).
- aerdrv: Trace Event for AER (fate#314197 bnc#799040).
- commit ff758cc
* Fri Jan 18 2013 rw@suse.de
- x86, MCE, AMD: Hide interrupt_enable sysfs node. (fate#314150)
- x86, MCE, AMD: Disable error thresholding bank 4 on some models.
  (fate#314150)
- commit 62de317
* Fri Jan 18 2013 jkosina@suse.cz
- Refresh
  patches.fixes/i7core_edac-Fix-compilation-on-32-bits-arch.patch.
- commit 3bfe41f
* Fri Jan 18 2013 trenn@suse.de
- PCI/AER: Print completion message at KERN_INFO to match starting
  message (fate#314197).
- ACPI: Add new sysfs interface to export device description
  (fate#314197).
- commit 551e8dc
* Fri Jan 18 2013 rw@suse.de
- EDAC, MCE, AMD: Add MCE decoding support for Family 16h.
  (fate#314148, bnc#798781)
- EDAC, MCE, AMD: Make MC2 decoding per-family. (fate#314148, bnc#798781)
- commit 4efa46c
* Fri Jan 18 2013 jkosina@suse.cz
- i7core_edac: Fix compilation on 32 bits arch (FATE#313939).
- Refresh patches.fixes/i7core_edac-scrcrubbing-fixups.patch.
- commit 22d99cd
* Fri Jan 18 2013 mmarek@suse.cz
- Change the module signature digest to sha256 to match the EFI binaries.
- commit a7ea076
* Fri Jan 18 2013 jbohac@suse.cz
- Refresh
  patches.fixes/ipvs-Fix-faulty-IPv6-extension-header-handling-in-IP.patch.
- commit 8fee7e8
* Fri Jan 18 2013 hare@suse.de
- bnx2fc: v2: Support software fcoe target
  (FATE#313818,bnc#798931).
- commit e4dee20
* Fri Jan 18 2013 bpoirier@suse.de
- bridge: Pull ip header into skb->data before looking into ip
  header (bnc#799063).
- commit 396cd2c
* Fri Jan 18 2013 bpoirier@suse.de
- Refresh
  patches.drivers/bna-0038-bna-Driver-Version-Updated-to-3.1.2.1.patch.
- commit 8ae9588
* Fri Jan 18 2013 bpoirier@suse.de
- bna: Driver Version Updated to 3.1.2.1 (bnc#780242 FATE#313822).
- bna: Firmware update (bnc#780242 FATE#313822).
- bna: Add RX State (bnc#780242 FATE#313822).
- bna: Rx Page Based Allocation (bnc#780242 FATE#313822).
- bna: TX Intr Coalescing Fix (bnc#780242 FATE#313822).
- bna: Tx and Rx Optimizations (bnc#780242 FATE#313822).
- bna: Code Cleanup and Enhancements (bnc#780242 FATE#313822).
- bna: remove __dev* attributes (bnc#780242 FATE#313822).
- bna: remove useless calls to memset() (bnc#780242 FATE#313822).
- bna: Fix warning false positive (bnc#780242 FATE#313822).
- drivers/net/ethernet: Fix non-kernel-doc comments with
  kernel-doc start markers (bnc#780242 FATE#313822).
- drivers/net/ethernet: Fix (nearly-)kernel-doc comments for
  various functions (bnc#780242 FATE#313822).
- ethernet: Remove casts to same type (bnc#780242 FATE#313822).
- bna: remove redundant NULL test before release_firmware()
  (bnc#780242 FATE#313822).
- bna: Update driver version to 3.0.23.0 (bnc#780242 FATE#313822).
- bna: Function name changes and cleanups (bnc#780242
  FATE#313822).
- bna: Remove tx tasklet (bnc#780242 FATE#313822).
- bna: tx rx cleanup fix (bnc#780242 FATE#313822).
- bna: ioc cleanups (bnc#780242 FATE#313822).
- bna: Flash controller ioc pll init fixes (bnc#780242
  FATE#313822).
- bna: Serialize smem access during adapter initialization
  (bnc#780242 FATE#313822).
- debugfs-related mode_t whack-a-mole (bnc#780242 FATE#313822).
- drivers/net: Remove boolean comparisons to true/false
  (bnc#780242 FATE#313822).
- bna: fix error handling of bnad_get_flash_partition_by_offset()
  (bnc#780242 FATE#313822).
- bna: Implement ethtool flash_device entry point (bnc#780242
  FATE#313822).
- drivers/net: Remove alloc_etherdev error messages (bnc#780242
  FATE#313822).
- drivers/net: Remove unnecessary k.alloc/v.alloc OOM messages
  (bnc#780242 FATE#313822).
- bna: fix sparse warnings/errors (bnc#780242 FATE#313822).
- bna: make ethtool_ops and strings const (bnc#780242
  FATE#313822).
- bna: Add debugfs interface (bnc#780242 FATE#313822).
- bna: Added flash sub-module and ethtool eeprom entry points
  (bnc#780242 FATE#313822).
- net: fix assignment of 0/1 to bool variables (bnc#780242
  FATE#313822).
- bna: Convert MAC_ADDRLEN uses to ETH_ALEN (bnc#780242
  FATE#313822).
- sweep the floors and convert some .get_drvinfo routines to
  strlcpy (bnc#780242 FATE#313822).
- drivers/net: Add module.h to drivers who were implicitly using
  it (bnc#780242 FATE#313822).
- net: add skb frag size accessors (bnc#780242 FATE#313822).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#780242 FATE#313822).
- commit 06c7dd1
* Fri Jan 18 2013 bpoirier@suse.de
- bna: Move the Brocade driver (bnc#780242 FATE#313822).
- Update config files.
- commit d2e4894
* Fri Jan 18 2013 dsterba@suse.cz
- Btrfs: disable qgroup id 0 (FATE#312888).
- Btrfs: fix memory leak in name_cache_insert() (FATE#312888).
- Btrfs: do not call file_update_time in aio_write (FATE#312888).
- Btrfs: use tokens where we can in the tree log (FATE#312888).
- Btrfs: optimize leaf_space_used (FATE#312888).
- Btrfs: don't memset new tokens (FATE#312888).
- Btrfs: fix off-by-one error of the same page check in
  btrfs_punch_hole() (FATE#312888).
- commit e13a21b
* Fri Jan 18 2013 dsterba@suse.cz
- patches.suse/btrfs-8191-use-existing-align-macros-in-btrfs_allocate.patch:
  Btrfs: use existing align macros in btrfs_allocate()
- patches.suse/btrfs-8192-fix-off-by-one-error-of-the-reserved-size-of-b.patch:
  Btrfs: fix off-by-one error of the reserved size of
  btrfs_allocate()
- patches.suse/btrfs-8193-add-fiemap-s-flag-check.patch: Btrfs:
  add fiemap's flag check
- patches.suse/btrfs-8194-fix-permissions-of-empty-files-not-affected-by.patch:
  Btrfs: fix permissions of empty files not affected by umask
- patches.suse/btrfs-8195-don-t-auto-defrag-a-file-when-doing-directIO.patch:
  Btrfs: don't auto defrag a file when doing directIO
- patches.suse/btrfs-8196-fix-wrong-return-value-of-btrfs_truncate_page.patch:
  Btrfs: fix wrong return value of btrfs_truncate_page()
- patches.suse/btrfs-8197-Notify-udev-when-removing-device.patch:
  btrfs: Notify udev when removing device
- patches.suse/btrfs-8199-fix-permissions-of-empty-files-not-affected-by.patch:
  Btrfs: fix permissions of empty files not affected by umask
- patches.suse/btrfs-8200-fix-hash-overflow-handling.patch:
  Btrfs: fix hash overflow handling
- patches.suse/btrfs-8201-do-not-delete-a-subvolume-which-is-in-a-R-O-su.patch:
  Btrfs: do not delete a subvolume which is in a R/O subvolume
- patches.suse/fs-fix-how-we-clear-DCACHE_NEED_LOOKUP.patch:
  Delete.
- commit d860544
* Fri Jan 18 2013 dsterba@suse.cz
- btrfs: add allow_unsupported module parameter (fate#314697).
- commit 1c5a83a
* Thu Jan 17 2013 jbohac@suse.cz
- ipvs: Complete IPv6 fragment handling for IPVS (fate#313479).
- ipvs: Fix faulty IPv6 extension header handling in IPVS
  (fate#313479).
- netfilter: ip6_tables: add flags parameter to ipv6_find_hdr()
  (fate#313479).
- commit 33653bb
* Thu Jan 17 2013 brogers@suse.com
- KVM: Don't automatically expose the TSC deadline timer in cpuid
  (fate313642).
- KVM: emulate lapic tsc deadline timer for guest (fate313642).
- KVM: x86: Add module parameter for lapic periodic timer limit
  (fate313642).
- x86: TSC deadline definitions (fate313642).
- KVM: nVMX: Fix nested VMX TSC emulation (fate314655).
- KVM: L1 TSC handling (fate314655).
- commit 872b27e
* Thu Jan 17 2013 bpoirier@suse.de
- netxen_nic: restrict force firmware dump when dump is disabled
  (bnc#784815 FATE#313898).
- netxen: Error return off by one for XG port (bnc#784815
  FATE#313898).
- netxen: Error return off by one in 'netxen_nic_set_pauseparam()'
  (bnc#784815 FATE#313898).
- netxen_nic: Fix estimation of recv MSS in case of LRO
  (bnc#784815 FATE#313898).
- netxen: added miniDIMM support in driver (bnc#784815
  FATE#313898).
- netxen_nic: Allow only useful and recommended firmware dump
  capture mask values (bnc#784815 FATE#313898).
- netxen_nic: disable minidump by default (bnc#784815
  FATE#313898).
- qlogic: get rid of a redundant test for NULL before call to
  release_firmware() (bnc#784815 FATE#313898).
- netxen: qlogic ethernet : Fix endian bug (bnc#784815
  FATE#313898).
- ethernet: unify return value of .ndo_set_mac_address if address
  is invalid (bnc#784815 FATE#313898).
- netxen_nic: signedness bug in netxen_md_entry_err_chk()
  (bnc#784815 FATE#313898).
- netdev: ethernet dev_alloc_skb to netdev_alloc_skb (bnc#784815
  FATE#313898).
- netxen: report valid speed and duplex status when link is down
  (bnc#784815 FATE#313898).
- netxen: Fix a panic during driver unload in device_remove_file
  (bnc#784815 FATE#313898).
- netxen_nic: Error logging on firmware hang (bnc#784815
  FATE#313898).
- netxen_nic: Fix phy link status (bnc#784815 FATE#313898).
- netxen_nic: fw dump support (bnc#784815 FATE#313898).
- netxen_nic: fix cdrp race condition (bnc#784815 FATE#313898).
- drivers/net: Remove alloc_etherdev error messages (bnc#784815
  FATE#313898).
- drivers/net: Remove unnecessary k.alloc/v.alloc OOM messages
  (bnc#784815 FATE#313898).
- sweep the floors and convert some .get_drvinfo routines to
  strlcpy (bnc#784815 FATE#313898).
- net: add skb frag size accessors (bnc#784815 FATE#313898).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#784815 FATE#313898).
- net: use DMA_x_DEVICE and dma_mapping_error with
  skb_frag_dma_map (bnc#784815 FATE#313898).
- netxen: convert to SKB paged frag API (bnc#784815 FATE#313898).
- commit fdba5bc
* Thu Jan 17 2013 bpoirier@suse.de
- ptp: use list_move instead of list_del/list_add (bnc#786035
  FATE#314299).
- sfc: Fix the reported priorities of different filter types
  (bnc#786035 FATE#314299).
- sfc: Remove EFX_FILTER_FLAG_RX_OVERRIDE_IP (bnc#786035
  FATE#314299).
- sfc: Fix loopback self-test with separate_tx_channels=1
  (bnc#786035 FATE#314299).
- sfc: Fix MCDI structure field lookup (bnc#786035 FATE#314299).
- sfc: Add parentheses around use of bitfield macro arguments
  (bnc#786035 FATE#314299).
- sfc: Fix null function pointer in efx_sriov_channel_type
  (bnc#786035 FATE#314299).
- sfc: Avoid generating over-length MC_CMD_FLUSH_RX_QUEUES request
  (bnc#786035 FATE#314299).
- sfc: Bump version to 3.2 (bnc#786035 FATE#314299).
- sfc: Expose FPGA bitfile partition through MTD (bnc#786035
  FATE#314299).
- sfc: Support variable-length response to MCDI GET_BOARD_CFG
  (bnc#786035 FATE#314299).
- sfc: Convert firmware subtypes to native byte order in
  efx_mcdi_get_board_cfg() (bnc#786035 FATE#314299).
- commit 0101cbd
* Thu Jan 17 2013 bpoirier@suse.de
- sfc: Add support for IEEE-1588 PTP (bnc#786035 FATE#314299).
- Update config files.
- commit f71d9e2
* Thu Jan 17 2013 bpoirier@suse.de
- sfc: Fix maximum array sizes for various MCDI commands
  (bnc#786035 FATE#314299).
- sfc: Allow efx_mcdi_rpc to be called in two parts (bnc#786035
  FATE#314299).
- sfc: Add channel specific receive_skb handler and post_remove
  callback (bnc#786035 FATE#314299).
- sfc: Add explicit RX queue flag to channel (bnc#786035
  FATE#314299).
- sfc: Assign efx and efx->type as early as possible in
  efx_pci_probe() (bnc#786035 FATE#314299).
- sfc: Remove bogus comment about MTU change and RX buffer overrun
  (bnc#786035 FATE#314299).
- sfc: Remove overly paranoid locking assertions from netdev
  operations (bnc#786035 FATE#314299).
- sfc: Fix reset vs probe/remove/PM races involving efx_nic::state
  (bnc#786035 FATE#314299).
- sfc: Improve log messages in case we abort probe due to a
  pending reset (bnc#786035 FATE#314299).
- sfc: Never try to stop and start a NIC that is disabled
  (bnc#786035 FATE#314299).
- sfc: Hold RTNL lock (only) when calling efx_stop_interrupts()
  (bnc#786035 FATE#314299).
- sfc: Keep disabled NICs quiescent during suspend/resume
  (bnc#786035 FATE#314299).
- sfc: Hold the RTNL lock for more of the suspend/resume cycle
  (bnc#786035 FATE#314299).
- sfc: Change state names to be clearer, and comment them
  (bnc#786035 FATE#314299).
- sfc: Stash header offsets for TSO in struct tso_state
  (bnc#786035 FATE#314299).
- sfc: Replace tso_state::full_packet_space with ip_base_len
  (bnc#786035 FATE#314299).
- sfc: Simplify TSO header buffer allocation (bnc#786035
  FATE#314299).
- sfc: Stop TX queues before they fill up (bnc#786035
  FATE#314299).
- sfc: Refactor struct efx_tx_buffer to use a flags field
  (bnc#786035 FATE#314299).
- sfc: Fix reporting of IPv4 full filters through ethtool
  (bnc#786035 FATE#314299).
- sfc: initialize dynamic sysfs attributes for lockdep (bnc#786035
  FATE#314299).
- sfc: Correct some comments on enum reset_type (bnc#786035
  FATE#314299).
- sfc: Fix interface statistics running backward (bnc#786035
  FATE#314299).
- sfc: Disable VF queues during register self-test (bnc#786035
  FATE#314299).
- sfc: Explain why efx_mcdi_exit_assertion() ignores result of
  efx_mcdi_rpc() (bnc#786035 FATE#314299).
- sfc: Use dev_kfree_skb() in efx_end_loopback() (bnc#786035
  FATE#314299).
- sfc: Use strlcpy() to copy ethtool stats names (bnc#786035
  FATE#314299).
- sfc: Stop changing header offsets on TX (bnc#786035
  FATE#314299).
- sfc: Remove dead write to tso_state::packet_space (bnc#786035
  FATE#314299).
- sfc: Use generic DMA API, not PCI-DMA API (bnc#786035
  FATE#314299).
- sfc: Work around bogus 'uninitialised variable' warning
  (bnc#786035 FATE#314299).
- drivers/net/ethernet: Fix non-kernel-doc comments with
  kernel-doc start markers (bnc#786035 FATE#314299).
- drivers/net/ethernet: Fix (nearly-)kernel-doc comments for
  various functions (bnc#786035 FATE#314299).
- sfc: By default refill RX rings as soon as space for a batch
  (bnc#786035 FATE#314299).
- sfc: Fill RX rings completely full, rather than to 95%% full
  (bnc#786035 FATE#314299).
- sfc: Fix missing cleanup in failure path of efx_pci_probe()
  (bnc#786035 FATE#314299).
- sfc: Do not attempt to flush queues if DMA is disabled
  (bnc#786035 FATE#314299).
- sfc: Fix division by zero when using one RX channel and no
  SR-IOV (bnc#786035 FATE#314299).
- sfc: mtd: Use MTD_FAIL_ADDR_UNKNOWN instead of 0xffffffff
  (bnc#786035 FATE#314299).
- sfc: Log the part number on probe (bnc#786035 FATE#314299).
- sfc: Remove efx_channel::last_eventq_read_ptr (bnc#786035
  FATE#314299).
- sfc: Run event/IRQ self-test asynchronously when interface is
  brought up (bnc#786035 FATE#314299).
- sfc: Encapsulate access to efx_{channel,nic}::last_irq_cpu in
  self-test (bnc#786035 FATE#314299).
- sfc: Test all event queues in parallel (bnc#786035 FATE#314299).
- sfc: Raise self-test timeouts (bnc#786035 FATE#314299).
- sfc: Remove TX completions from adaptive IRQ scoring (bnc#786035
  FATE#314299).
- sfc: Update comments on efx_rx_packet_gro() (bnc#786035
  FATE#314299).
- sfc: Remove redundant function efx_nic_has_mc() (bnc#786035
  FATE#314299).
- sfc: Fix calculation of vf_i in map_vi_index() (bnc#786035
  FATE#314299).
- ethernet: unify return value of .ndo_set_mac_address if address
  is invalid (bnc#786035 FATE#314299).
- sfc: Correct efx_for_each_possible_channel_tx_queue() to skip
  non-TX channels (bnc#786035 FATE#314299).
- sfc: Minor formatting cleanup (bnc#786035 FATE#314299).
- sfc: Reverse initial buffer table allocation to allow for
  later resizing (bnc#786035 FATE#314299).
- sfc: Correct validation of peer_page_count in
  efx_vfdi_set_status_page() (bnc#786035 FATE#314299).
- sfc: Specify that the VFDI status page has page alignment and
  size (bnc#786035 FATE#314299).
- commit db0425c
* Thu Jan 17 2013 bpoirier@suse.de
- sfc: Add SR-IOV back-end support for SFC9000 family (bnc#786035
  FATE#314299).
- Update config files.
- commit daa342d
* Thu Jan 17 2013 bpoirier@suse.de
- sfc: Allocate SRAM between buffer table and descriptor caches
  at init time (bnc#786035 FATE#314299).
- sfc: Pass NIC structure into efx_wanted_parallelism()
  (bnc#786035 FATE#314299).
- sfc: Add support for 'extra' channel types (bnc#786035
  FATE#314299).
- sfc: Make all CPU/IRQ/channel/queue counts unsigned (bnc#786035
  FATE#314299).
- sfc: Make buffer table indices and counts consistently unsigned
  (bnc#786035 FATE#314299).
- sfc: Disable flow control during flushes (bnc#786035
  FATE#314299).
- sfc: Generalise event generation to cover VF-owned event queues
  (bnc#786035 FATE#314299).
- sfc: Use proper function to test for RX channel in efx_poll()
  (bnc#786035 FATE#314299).
- sfc: Leave interrupts and event queues enabled whenever we can
  (bnc#786035 FATE#314299).
- sfc: Generate RX fill events based on RX queues, not channels
  (bnc#786035 FATE#314299).
- sfc: Generalise driver event generation (bnc#786035
  FATE#314299).
- sfc: Correct MAC filter bitfield definitions (bnc#786035
  FATE#314299).
- sfc: Add support for TX MAC filters (bnc#786035 FATE#314299).
- sfc: Add support for configuring RX unicast/multicast default
  filters (bnc#786035 FATE#314299).
- sfc: Warn if unable to create MTDs (bnc#786035 FATE#314299).
- sfc: Replace some literal constants with
  EFX_PAGE_SIZE/EFX_BUF_SIZE (bnc#786035 FATE#314299).
- sfc: Do not retry hardware probe if it schedules a reset
  (bnc#786035 FATE#314299).
- sfc: Skip RX end-of-batch work on channels without an RX queue
  (bnc#786035 FATE#314299).
- sfc: Use a more sensible cast in efx_rx_buf_offset() (bnc#786035
  FATE#314299).
- sfc: Replace efx_rx_buffer::is_page and other booleans with
  a flags field (bnc#786035 FATE#314299).
- sfc: Move the end of the non-GRO RX path into its own function
  (bnc#786035 FATE#314299).
- sfc: Make all MAC statistics consistently 64 bits wide
  (bnc#786035 FATE#314299).
- sfc: Remove redundant 'rc' variable, always set to 0 (bnc#786035
  FATE#314299).
- sfc: Minor formatting fixes (bnc#786035 FATE#314299).
- sfc: Use existing local variables instead of repeated indirect
  lookups (bnc#786035 FATE#314299).
- sfc: Remove remnants of on-load self-test (bnc#786035
  FATE#314299).
- sfc: Remove obsolete function efx_dev_name() (bnc#786035
  FATE#314299).
- sfc: Update the description of SFC_MTD (bnc#786035 FATE#314299).
- commit aafce3c
* Thu Jan 17 2013 bpoirier@suse.de
- sfc: Add hwmon driver for boards using SFC9000-family
  controllers (bnc#786035 FATE#314299).
- Update config files.
- commit e767daa
* Thu Jan 17 2013 bpoirier@suse.de
- sfc: Clean up test interrupt handling (bnc#786035 FATE#314299).
- Partly revert "sfc: Handle serious errors in exactly one
  interrupt handler" (bnc#786035 FATE#314299).
- sfc: Remove dependence on NAPI polling in efx_test_eventq_irq()
  (bnc#786035 FATE#314299).
- sfc: Correct interrupt timer quantum for Siena (normal and
  turbo mode) (bnc#786035 FATE#314299).
- sfc: Support extraction of CAPABILITIES from GET_BOARD_CFG
  response (bnc#786035 FATE#314299).
- sfc: Consistently test DEBUG macro, not EFX_ENABLE_DEBUG
  (bnc#786035 FATE#314299).
- sfc: Remove efx_nic_type::push_multicast_hash operation
  (bnc#786035 FATE#314299).
- sfc: Merge efx_mcdi_mac_check_fault() and
  efx_mcdi_get_mac_faults() (bnc#786035 FATE#314299).
- sfc: Merge efx_mac_operations into efx_nic_type (bnc#786035
  FATE#314299).
- sfc: Hold efx_nic::stats_lock while reading efx_nic::mac_stats
  (bnc#786035 FATE#314299).
- sfc: Use new names for MC shared memory layout constants
  (bnc#786035 FATE#314299).
- sfc: Make handling of MC reboot more reliable (bnc#786035
  FATE#314299).
- sfc: Remove fallback for invalid permanent MAC address
  (bnc#786035 FATE#314299).
- sfc: Set default parallelism to per-core by default (bnc#786035
  FATE#314299).
- sfc: Rename efx_wanted_channels() to efx_wanted_parallelism()
  (bnc#786035 FATE#314299).
- sfc: Update MCDI (firmware interface) definitions (bnc#786035
  FATE#314299).
- sfc: Remove unnecessary inclusion of <asm/io.h>, prompted by
  checkpatch (bnc#786035 FATE#314299).
- sfc: Const-qualify static data as appropriate, partly prompted
  by checkpatch (bnc#786035 FATE#314299).
- sfc: Remove parentheses around return expressions, reported
  by checkpatch (bnc#786035 FATE#314299).
- sfc: Avoid assignment in an if-statement, reported by checkpatch
  (bnc#786035 FATE#314299).
- sfc: Fix some formatting errors reported by checkpatch
  (bnc#786035 FATE#314299).
- sfc: Remove now-unused filter function (bnc#786035 FATE#314299).
- sfc: Implement ethtool RX NFC rules API instead of n-tuple API
  (bnc#786035 FATE#314299).
- sfc: Add support for retrieving and removing filters by ID
  (bnc#786035 FATE#314299).
- sfc: Use consistent types for filter IDs, indices and search
  depths (bnc#786035 FATE#314299).
- sfc: Change filter ID generation to satisfy priority semantics
  of RX NFC (bnc#786035 FATE#314299).
- net: fix assignment of 0/1 to bool variables (bnc#786035
  FATE#314299).
- sfc: Use skb_fill_page_desc() to simplify passing of page
  buffers to GRO (bnc#786035 FATE#314299).
- sfc: Use kcalloc instead of kzalloc to allocate array
  (bnc#786035 FATE#314299).
- net: add skb frag size accessors (bnc#786035 FATE#314299).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#786035 FATE#314299).
- net: use DMA_x_DEVICE and dma_mapping_error with
  skb_frag_dma_map (bnc#786035 FATE#314299).
- sfc: convert to SKB paged frag API (bnc#786035 FATE#314299).
- sfc: Use correct fields of struct ethtool_coalesce (bnc#786035
  FATE#314299).
- sfc: Validate IRQ moderation parameters in
  efx_init_irq_moderation() (bnc#786035 FATE#314299).
- sfc: Correct reporting and validation of TX interrupt coalescing
  (bnc#786035 FATE#314299).
- sfc: Use consistent types for interrupt coalescing parameters
  (bnc#786035 FATE#314299).
- sfc: Correct error code for unsupported interrupt coalescing
  parameters (bnc#786035 FATE#314299).
- commit 8d5aacb
* Thu Jan 17 2013 bpoirier@suse.de
- sfc: Move the Solarflare drivers (bnc#786035 FATE#314299).
- Update config files.
- commit 333ec3b
* Thu Jan 17 2013 bpoirier@suse.de
- sfc: Use 64-bit writes for TX push where possible (bnc#786035
  FATE#314299).
- sfc: Remove 'Communications' after 'Solarflare' in references
  to hardware (bnc#786035 FATE#314299).
- sfc: Remove 'Solarstorm' from Kconfig descriptions (bnc#786035
  FATE#314299).
- sfc: Fix assertions in efx_filter_rfs() (bnc#786035
  FATE#314299).
- sfc: Fix Siena mac statistics on big endian platforms
  (bnc#786035 FATE#314299).
- sfc: Fix mapping of reset reasons and flags to methods
  (bnc#786035 FATE#314299).
- sfc: Allow resets to be upgraded; use atomic ops for safety
  (bnc#786035 FATE#314299).
- sfc: Fix loop condition for efx_filter_search() when !for_insert
  (bnc#786035 FATE#314299).
- pps/ptp: Allow PHC devices to adjust PPS events for known delay
  (bnc#786035 FATE#314299).
- ethtool: Allow drivers to select RX NFC rule locations
  (bnc#786035 FATE#314299).
- rtnetlink: fix rtnl_calcit() and rtnl_dump_ifinfo() (bnc#786035
  FATE#314299).
- rtnetlink: Fix problem with buffer allocation (bnc#786035
  FATE#314299).
- ethtool: Update ethtool_rxnfc::rule_cnt on return from
  ETHTOOL_GRXCLSRLALL (bnc#786035 FATE#314299).
- ethtool: Explicitly state that RX NFC rule locations are
  priorities (bnc#786035 FATE#314299).
- ethtool: Make struct ethtool_rxnfc kernel-doc more
  self-consistent (bnc#786035 FATE#314299).
- commit 6f69a65
* Thu Jan 17 2013 jkosina@suse.cz
- i7core_edac: scrubbing fixups (FATE#313939).
- i7core_edac: Add scrubbing support (FATE#313939).
- edac: i5100 fix erroneous define for M1Err (FATE#313938).
- edac: i5100 ack error detection register after each read
  (FATE#313938).
- commit 4873878
* Thu Jan 17 2013 jkosina@suse.cz
- amd64_edac: Fix K8 revD and later chip select sizes
  (FATE##313937).
- supported.conf: add edac_amd64
- commit e0feb0d
* Thu Jan 17 2013 brogers@suse.com
- KVM: Add instruction fetch checking when walking guest page
  table (fate#313612).
- KVM: Add SMEP support when setting CR4 (fate#313826,
  fate#313612).
- KVM: expose latest Intel cpu new features (BMI1/BMI2/FMA/AVX2)
  to guest (fate#313616).
- KVM: Mask function7 ebx against host capability word9
  (fate#313826, fate#313612).
- KVM: nVMX: Add "nested" module option to kvm_intel
  (fate#314655).
- KVM: nVMX: Add VMCS fields to the vmcs12 (fate#314655).
- KVM: nVMX: Add VMX to list of supported cpuid features
  (fate#314655).
- KVM: nVMX: Additional TSC-offset handling (fate#314655).
- KVM: nVMX: Allow setting the VMXE bit in CR4 (fate#314655).
- KVM: nVMX: Correct handling of exception injection
  (fate#314655).
- KVM: nVMX: Correct handling of idt vectoring info (fate#314655).
- KVM: nVMX: Correct handling of interrupt injection
  (fate#314655).
- KVM: nVMX: Deciding if L0 or L1 should handle an L2 exit
  (fate#314655).
- KVM: nVMX: Decoding memory operands of VMX instructions
  (fate#314655).
- KVM: nVMX: Documentation (fate#314655).
- KVM: nVMX: Exiting from L2 to L1 (fate#314655).
- KVM: nVMX: Fix bug preventing more than two levels of nesting
  (fate#314655).
- KVM: nVMX: Further fixes for lazy FPU loading (fate#314655).
- KVM: nVMX: Handling of CR0 and CR4 modifying instructions
  (fate#314655).
- KVM: nVMX: Implement reading and writing of VMX MSRs
  (fate#314655).
- KVM: nVMX: Implement VMCLEAR (fate#314655).
- KVM: nVMX: Implement VMLAUNCH and VMRESUME (fate#314655).
- KVM: nVMX: Implement VMPTRLD (fate#314655).
- KVM: nVMX: Implement VMPTRST (fate#314655).
- KVM: nVMX: Implement VMREAD and VMWRITE (fate#314655).
- KVM: nVMX: Implement VMXON and VMXOFF (fate#314655).
- KVM: nVMX: Introduce vmcs02: VMCS used to run L2 (fate#314655).
- KVM: nVMX: Introduce vmcs12: a VMCS structure for L1
  (fate#314655).
- KVM: nVMX: Miscellenous small corrections (fate#314655).
- KVM: nVMX: Move control field setup to functions (fate#314655).
- KVM: nVMX: Move host-state field setup to a function
  (fate#314655).
- KVM: nVMX: No need for handle_vmx_insn function any more
  (fate#314655).
- KVM: nVMX: Prepare vmcs02 from vmcs01 and vmcs12 (fate#314655).
- KVM: nVMX: Success/failure of VMX instructions (fate#314655).
- KVM: nVMX: vmcs12 checks on nested entry (fate#314655).
- KVM: Remove SMEP bit from CR4_RESERVED_BITS (fate#313826,
  fate#313612).
- KVM: VMX: Add EPT A/D bits definitions (fate#313615).
- KVM: VMX: Add parameter to control A/D bits support, default
  is on (fate#313615).
- KVM: VMX: Enable EPT A/D bits if supported by turning on
  relevant bit in EPTP (fate#313615).
- KVM: VMX: Keep list of loaded VMCSs, instead of vcpus
  (fate#314655).
- KVM: VMX: Use EPT Access bit in response to memory notifiers
  (fate#313615).
- KVM: x86: change PT_FIRST_AVAIL_BITS_SHIFT to avoid conflict
  with EPT Dirty bit (fate#313615).
- KVM: x86: expose Intel cpu new features (HLE, RTM) to guest
  (fate#313616).
- KVM: x86: increase recommended max vcpus to 160 (fate#314371).
- Delete patches.arch/x86-kvm-invpcid-prereq-1.patch.
- Delete patches.arch/x86-kvm-invpcid-prereq-2.patch.
- Delete patches.arch/x86-kvm-invpcid-prereq-3.patch.
- commit d97fa51
* Thu Jan 17 2013 jkosina@suse.cz
- lpc_sch: Add Intel Centerton Multifunction Device support
  (FATE#313512).
- mfd: Add tunnelcreek watchdog to lpc_sch devices (FATE#313512).
- pci_ids: Add Intel Centerton Legacy Block DeviceID
  (FATE#313512).
- commit 336f823
* Thu Jan 17 2013 bpoirier@suse.de
- Rename a patch that touches many drivers
- commit 14edf54
* Thu Jan 17 2013 jbohac@suse.cz
- netfilter: nfnetlink_queue: do not allow to set unsupported flag
  (fate#313984).
- netfilter: Add fail-open support (fate#313984).
- commit cc55304
* Thu Jan 17 2013 hare@suse.de
- megaraid: fix BUG_ON() from incorrect use of delayed work
  (FATE#313894).
- megaraid_sas: Version, Changelog, Copyright update
  (FATE#313894).
- megaraid_sas: Remove duplicate code (FATE#313894).
- megaraid_sas: Add SystemPD FastPath support (FATE#313894).
- megaraid_sas: Add array boundary check for SystemPD
  (FATE#313894).
- megaraid_sas: Load io_request DataLength in bytes (FATE#313894).
- megaraid_sas: Add module param for configurable MSI-X vector
  count (FATE#313894).
- megaraid_sas: Remove un-needed completion_lock spinlock calls
  (FATE#313894).
- megaraid_sas: combine kmalloc+memset into kzalloc (FATE#313894).
- megaraid_sas: Version and Changelog update (FATE#313894).
- megaraid_sas: Add resetwaittime module parameter (FATE#313894).
- megaraid_sas: Add throttlequeuedepth module parameter
  (FATE#313894).
- megaraid_sas: Version and Changelog update (FATE#313894).
- megaraid_sas: Add fpRead/WriteCapable, fpRead/WriteAcrossStripe
  checks (FATE#313894).
- megaraid_sas: Optimize HostMSIxVectors setting (FATE#313894).
- megaraid_sas: Version and Changelog update (FATE#313894).
- megaraid_sas: remove poll_mode_io code (FATE#313894).
- megaraid_sas: mask off flags in ioctl path (FATE#313894).
- megaraid_sas: Fix reglockFlags for degraded raid5/6
  (FATE#313894).
- megaraid_sas: Changelog and version update (FATE#313894).
- megaraid_sas: Add driver workaround for PERC5/1068 kdump kernel
  panic (FATE#313894).
- megaraid_sas: Add multiple MSI-X vector/multiple reply queue
  support (FATE#313894).
- megaraid_sas: Add support for MegaRAID 9360/9380 12GB/s
  controllers (FATE#313894).
- megaraid_sas: Clear FUSION_IN_RESET before enabling interrupts
  (FATE#313894).
- megaraid_sas: Clear state change interrupts (FATE#313894).
- megaraid_sas: Remove some unnecessary code (FATE#313894).
- megaraid_sas: Fix mismatch in megasas_reset_fusion() mutex
  lock-unlock (FATE#313894).
- megaraid_sas: Increase default cmds per lun to 256
  (FATE#313894).
- megaraid_sas Version to 5.40-rc1 and Changelog update
  (FATE#313894).
- megaraid_sas: Add .change_queue_depth support (FATE#313894).
- megaraid_sas: Fix FastPath I/O to work on degraded raid 1
  (FATE#313894).
- commit 69ae9bd
* Thu Jan 17 2013 hare@suse.de
- Update lpfc version for 8.3.7.7.1p driver release (FATE#313818,
  bnc#777561).
- lpfc 8.3.37: Provide support for change_queue_type method in
  scsi_host_template (FATE#313818, bnc#777561).
- lpfc 8.3.37: Fixed infinite loop in
  lpfc_sli4_fcf_rr_next_index_get (FATE#313818, bnc#777561).
- lpfc 8.3.37: Fixed system crash due to SLI Port provisioning
  of invalid resource count (FATE#313818, bnc#777561).
- lpfc 8.3.37: Provide support for FCoE protocol dual-chute
  (ULP) operation (FATE#313818, bnc#777561).
- lpfc 8.3.37: Fixed processing stale ndlp state when the node
  is marked for deferred removal (FATE#313818, bnc#777561).
- lpfc 8.3.37: Fix potential memory corruption bug (FATE#313818,
  bnc#777561).
- lpfc 8.3.37: Fixed no-context ABTS received on unsolicited
  receive queue failed with BA_RJT (FATE#313818, bnc#777561).
- lpfc 8.3.37: Removed use of NOP mailboxes for interrupt
  verification in pci_probe_one_s4 (FATE#313818, bnc#777561).
- lpfc 8.3.37: Fixed exhausted retry for plogi to nameserver
  (FATE#313818, bnc#777561).
- lpfc 8.3.37: Fixed not properly handle ELS_REC received on
  the unsolicited receive queue (FATE#313818, bnc#777561).
- commit 69f1082
* Thu Jan 17 2013 hare@suse.de
- lpfc 8.3.36: Correct mask error (FATE#313818).
- lpfc 8.3.36: Correct buffer length overrun (FATE#313818).
- lpfc 8.3.36: Fixed setting sequential delivery bit
  (FATE#313818).
- lpfc 8.3.36: Update DIF support for passthru/strip/insert
  (FATE#313818).
- lpfc 8.3.36: Fix bug with Target Resets and FCP2 devices
  (FATE#313818).
- lpfc 8.3.36: Fixed boot from san failure (FATE#313818).
- lpfc 8.3.35: Fixed not reporting logical link speed to SCSI
  midlayer when QoS not on (FATE#313818).
- lpfc 8.3.35: Fix error with fabric service parameters causing
  performance issues (FATE#313818).
- lpfc 8.3.35: Fixed SCSI host create showing wrong link speed
  on SLI3 HBA ports (FATE#313818).
- lpfc 8.3.35: Fixed not checking solicition in progress bit
  when verifying FCF record for use (FATE#313818).
- lpfc 8.3.35: Fixed messages for misconfigured port errors
  (FATE#313818).
- lpfc 8.3.35: Fixed kernel warning on spinlock usage on some
  distributions (FATE#313818).
- lpfc 8.3.35: Fixed PRLI not being retried if a LS_RJT with a
  reason (FATE#313818).
- lpfc 8.3.35: Correct request_firmware use that was increasing
  boot times (FATE#313818).
- lpfc 8.3.35: Fix FCP2 Retries for non-r/w commands
  (FATE#313818).
- lpfc 8.3.35: Fixed Linux generic firmware download on SLI4
  devices with longer module names (FATE#313818).
- lpfc 8.3.35: Expand I/O channel support for large systems
  (FATE#313818).
- lpfc 8.3.35: Correct missing queue destroy on function reset
  (FATE#313818).
- lpfc 8.3.35: Fix incorrect comment in T10 DIF attributes
  (FATE#313818).
- lpfc 8.3.35: Added checking BMBX register for RDY bit before
  writing the first address in (FATE#313818).
- lpfc 8.3.35: Fix interrupt delay multipler conversion for
  eq_create (FATE#313818).
- lpfc 8.3.34: Fixed leaking memory from pci dma pool
  (FATE#313818).
- lpfc 8.3.34: Correct lock handling to eliminate reset escalation
  on I/O abort (FATE#313818).
- lpfc 8.3.34: Adjust IO Channels to 1 when INTx (FATE#313818).
- lpfc 8.3.34: Add XRI to abort handler timeout log message
  (FATE#313818).
- lpfc 8.3.34: Streamline fcp underrun message printing
  (FATE#313818).
- lpfc 8.3.34: Correct typecasts for snprintf messages
  (FATE#313818).
- lpfc 8.3.34: Simplify BlockGuard lpfc_printf_vlog messages
  (FATE#313818).
- lpfc 8.3.34: Fix parameter field in CQE to mask for LOCAL_REJECT
  status (FATE#313818).
- lpfc 8.3.34: Fix number of IO channels to match CPUs
  (FATE#313818).
- lpfc 8.3.34: Add SLI-4 V1 Capacity and Resource Descriptor
  support (FATE#313818).
- lpfc 8.3.34: Add LOGO support after ABTS compliance
  (FATE#313818).
- lpfc 8.3.33: Fixed incomplete list of SLI4 commands with
  extended timeout value (FATE#313818).
- lpfc 8.3.33: Fixed debugfs queInfo to include queue stats
  (FATE#313818).
- lpfc 8.3.33: Add lpfc_fcp_look_ahead module parameter
  (FATE#313818).
- lpfc 8.3.33: Make I/O to hw queue distribution algorithm a
  module parameter (FATE#313818).
- lpfc 8.3.33: Change Naming convention for SLI4 Interrupt vector
  (FATE#313818).
- lpfc 8.3.33: Allow per-hba interrupt rate tuning (FATE#313818).
- lpfc 8.3.33: Tie parallel I/O queues into separate MSIX vectors
  (FATE#313818).
- lpfc 8.3.33: Add Interrupts per second stats via debugfs
  (FATE#313818).
- lpfc 8.3.33: Parallelize SLI-4 Q distribution (FATE#313818).
- lpfc 8.3.33: Misc changes to optimize critical path
  (FATE#313818).
- lpfc 8.3.33: Formally separate lpfc_sli_ring SLI-3 and SLI-4
  variantions (FATE#313818).
- lpfc 8.3.33: Convert to no SCSI host lock in queuecommand
  (FATE#313818).
- lpfc 8.3.33: Add debugfs interface to display SLI queue
  information (FATE#313818).
- lpfc 8.3.33: Fix error when remote port switches address
  (FATE#313818).
- lpfc 8.3.33: Fix scsi_eh escalation panic by checking the
  proper return status (FATE#313818).
- lpfc 8.3.33: Check data transfer amount on write commands
  (FATE#313818).
- lpfc 8.3.33: Fix error of not reiniting mbx cmd before reissue
  (FATE#313818).
- lpfc 8.3.33: Fix bug with rrq_pool not being destroyed during
  driver removal (FATE#313818).
- lpfc 8.3.33: Enable attachment to OCe14000 adapters
  (FATE#313818).
- lpfc 8.3.33: When doing loopback testing, set the diag valid
  bit (FATE#313818).
- lpfc: fix problems with -Werror (FATE#313818).
- commit b9390c0
* Wed Jan 16 2013 bpoirier@suse.de
- Move a core patch from patches.drivers to patches.fixes
- commit 60decef
* Wed Jan 16 2013 bpoirier@suse.de
- qlcnic: Fix protcol type in case of inband vlan (bnc#784817
  FATE#313899).
- qlcnic: fix unsupported CDRP command error message (bnc#784817
  FATE#313899).
- qlcnic: Fix estimation of recv MSS in case of LRO (bnc#784817
  FATE#313899).
- qlcnic-ethtool: set the ethtool_dump flag by ETH_FW_DUMP_DISABLE
  value that is zero, if firmware dump is disabled (bnc#784817
  FATE#313899).
- qlogic: get rid of a redundant test for NULL before call to
  release_firmware() (bnc#784817 FATE#313899).
- linux/ethtool: Added macro ETH_FW_DUMP_DISABLE (bnc#784817
  FATE#313899).
- qlcnic: Allow a predefined set of capture masks for FW dump
  (bnc#784817 FATE#313899).
- qlcnic: Adding mac statistics to ethtool (bnc#784817
  FATE#313899).
- qlcnic: Register device in FAILED state (bnc#784817
  FATE#313899).
- qlcnic: Bug fix for LRO (bnc#784817 FATE#313899).
- ethernet: unify return value of .ndo_set_mac_address if address
  is invalid (bnc#784817 FATE#313899).
- netdev: ethernet dev_alloc_skb to netdev_alloc_skb (bnc#784817
  FATE#313899).
- qlcnic: Fix API unlock (bnc#784817 FATE#313899).
- qlcnic: Fix firmware abort code check (bnc#784817 FATE#313899).
- qlcnic: report valid speed and duplex status when link is down
  (bnc#784817 FATE#313899).
- qlcnic: Stop pause ctrl frames on fw hang (bnc#784817
  FATE#313899).
- drivers/net: Remove alloc_etherdev error messages (bnc#784817
  FATE#313899).
- sweep the floors and convert some .get_drvinfo routines to
  strlcpy (bnc#784817 FATE#313899).
- qlcnic: fix beacon and LED test (bnc#784817 FATE#313899).
- qlcnic: updated reset sequence (bnc#784817 FATE#313899).
- qlcnic: reset loopback mode if promiscous mode setting fails
  (bnc#784817 FATE#313899).
- qlcnic: skip IDC ack check in fw reset path (bnc#784817
  FATE#313899).
- net: add skb frag size accessors (bnc#784817 FATE#313899).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#784817 FATE#313899).
- net: use DMA_x_DEVICE and dma_mapping_error with
  skb_frag_dma_map (bnc#784817 FATE#313899).
- qlcnic: convert to SKB paged frag API (bnc#784817 FATE#313899).
- commit a3e0fb0
* Wed Jan 16 2013 bpoirier@suse.de
- qlge: Bumped driver version to 1.00.00.31 (bnc#784811
  FATE#313897).
- qlge: Refactoring of ethtool stats (bnc#784811 FATE#313897).
- qlge: Moving low level frame error to ethtool statistics
  (bnc#784811 FATE#313897).
- qlge: Fixed double pci free upon tx_ring->q allocation failure
  (bnc#784811 FATE#313897).
- qlge: Added missing case statement to ethtool get_strings
  (bnc#784811 FATE#313897).
- qlge: Clean up ethtool set WOL routine (bnc#784811 FATE#313897).
- qlge: Fix ethtool WOL calls to operate only on devices that
  support WOL (bnc#784811 FATE#313897).
- qlge: Cleanup atomic queue threshold check (bnc#784811
  FATE#313897).
- qlge: Fix TX queue stoppage due to full condition (bnc#784811
  FATE#313897).
- qlge: remove unnecessary setting of skb->dev (bnc#784811
  FATE#313897).
- qlge: set maximal number of default RSS queues (bnc#784811
  FATE#313897).
- qlge: Bumped driver version to 1.00.00.30 (bnc#784811
  FATE#313897).
- qlge: Fix memory leak in the process of refill (bnc#784811
  FATE#313897).
- qlge: Fixed invalid reference to ip header (bnc#784811
  FATE#313897).
- drivers/net: Remove unnecessary k.alloc/v.alloc OOM messages
  (bnc#784811 FATE#313897).
- sweep the floors and convert some .get_drvinfo routines to
  strlcpy (bnc#784811 FATE#313897).
- net: add skb frag size accessors (bnc#784811 FATE#313897).
- net: use DMA_x_DEVICE and dma_mapping_error with
  skb_frag_dma_map (bnc#784811 FATE#313897).
- qlge: convert to SKB paged frag API (bnc#784811 FATE#313897).
- net: remove use of ndo_set_multicast_list in drivers (bnc#784811
  FATE#313897).
- commit 09cd3d0
* Wed Jan 16 2013 bpoirier@suse.de
- qlogic: Move the QLogic drivers (bnc#784811 FATE#313897).
- smsc: Move the SMC (SMSC) drivers (bnc#784811 FATE#313897).
- Update config files.
- commit f8d0194
* Wed Jan 16 2013 bpoirier@suse.de
- qlge: remove duplicated #include (bnc#784811 FATE#313897).
- qlge: do vlan cleanup (bnc#784811 FATE#313897).
- net: remove interrupt.h inclusion from netdevice.h (bnc#784811
  FATE#313897).
- qlge: remove unecessary if statement (bnc#784811 FATE#313897).
- qlge: Updating Schultz LICENSE.qlge file (bnc#784811
  FATE#313897).
- commit 55f44be
* Wed Jan 16 2013 bpoirier@suse.de
- tg3: Fix crc errors on jumbo frame receive (bnc#790588
  FATE#313912).
- tg3: Avoid null pointer dereference in tg3_interrupt in
  netconsole mode (bnc#790588 FATE#313912).
- commit 1354180
* Wed Jan 16 2013 bpoirier@suse.de
- bnx2: Fix accidental reversions (bnc#790592 FATE#313914).
- cnic, bnx2x, bnx2: Simplify cnic probing (bnc#790592
  FATE#313914).
- cnic: Include bnx2x.h (bnc#790592 FATE#313914).
- bnx2: Add BNX2 prefix to CHIP ID and name macros (bnc#790592
  FATE#313914).
- bnx2: Add BNX2 prefix to descriptor structures and macros
  (bnc#790592 FATE#313914).
- cnic: Fix rare race condition during iSCSI disconnect
  (bnc#790592 FATE#313914).
- cnic: Reset iSCSI EQ during shutdown (bnc#790592 FATE#313914).
- commit f76f537
* Wed Jan 16 2013 bpoirier@suse.de
- bnx2x: Cosmetic changes to align to upstream kernel (bnc#790597
  FATE#313915).
- bnx2x: use ARRAY_SIZE where possible (bnc#790597 FATE#313915).
- bnx2x: Prevent link flaps when booting from SAN (bnc#790597
  FATE#313915).
- bnx2x: recognize fan failure (bnc#790597 FATE#313915).
- bnx2x: Correct PFC disablement (bnc#790597 FATE#313915).
- bnx2x: fix 'Ethtool -A' when autoneg (bnc#790597 FATE#313915).
- bnx2x: prevent DCB if disabled in nvram (bnc#790597
  FATE#313915).
- bnx2x: Handle a rarely missed interrupt (bnc#790597
  FATE#313915).
- bnx2x: mask CPL_OF interrupt (bnc#790597 FATE#313915).
- bnx2x: IGU parse error cause probe failure (bnc#790597
  FATE#313915).
- bnx2x: Ext. config accessed only on non-E1x (bnc#790597
  FATE#313915).
- bnx2x: nvram enables dropless flow control (bnc#790597
  FATE#313915).
- bnx2x: Correct advertised speed/duplex (bnc#790597 FATE#313915).
- bnx2x: Filter packets on FCoE rings (bnc#790597 FATE#313915).
- bnx2x: Management can control PFC/ETS (bnc#790597 FATE#313915).
- bnx2x: parity recovery flow enhancement (bnc#790597
  FATE#313915).
- bnx2x: revised and corrected SPIO access (bnc#790597
  FATE#313915).
- bnx2x: Change duplex setting in EEE function (bnc#790597
  FATE#313915).
- bnx2x: Add warning message in case of non-10G SFP module
  (bnc#790597 FATE#313915).
- bnx2x: Cosmetic changes (bnc#790597 FATE#313915).
- bnx2x: Always take PHY lock (bnc#790597 FATE#313915).
- bnx2x: Add support for BCM84834 (bnc#790597 FATE#313915).
- bnx2x: Fix SFP+ current leakage (bnc#790597 FATE#313915).
- bnx2x: Change MDIO clock settings (bnc#790597 FATE#313915).
- bnx2x: Add support for 20G-KR2 (bnc#790597 FATE#313915).
- bnx2x: Activate LFA (bnc#790597 FATE#313915).
- bnx2x: remove redundant warning log (bnc#790597 FATE#313915).
- bnx2x: Remove duplicate inclusion of bnx2x_hsi.h (bnc#790597
  FATE#313915).
- bnx2x: Add static declaration to several functions (bnc#790597
  FATE#313915).
- bnx2x: Support loading cnic resources at run-time (bnc#790597
  FATE#313915).
- bnx2x: HSI change for 'update' ramrod (bnc#790597 FATE#313915).
- net: bnx2x: Fix typo in bnx2x driver (bnc#790597 FATE#313915).
- bnx2x: fix HW initialization using fw 7.8.x (bnc#790597
  FATE#313915).
- bnx2x: Disable FCoE for 57840 since not yet supported by FW
  (bnc#790597 FATE#313915).
- bnx2x: Fix no link on 577xx 10G-baseT (bnc#790597 FATE#313915).
- bnx2x: Fix unrecognized SFP+ module after driver is loaded
  (bnc#790597 FATE#313915).
- bnx2x: Fix potential incorrect link speed provision (bnc#790597
  FATE#313915).
- bnx2x: Restore global registers back to default (bnc#790597
  FATE#313915).
- bnx2x: Fix link down in 57712 following LFA (bnc#790597
  FATE#313915).
- bnx2x: Fix 57810 1G-KR link against certain switches (bnc#790597
  FATE#313915).
- bnx2x: fix handling mf storage modes (bnc#790597 FATE#313915).
- bnx2x: fix ring size for 10G functions (bnc#790597 FATE#313915).
- bnx2x: use strlcpy() to copy a string (bnc#790597 FATE#313915).
- bnx2x: update version to 1.78.00-0 (bnc#790597 FATE#313915).
- bnx2x,cnic: use FW 7.8.2 (bnc#790597 FATE#313915).
- bnx2x: Improve code around bnx2x_tests_str_arr (bnc#790597
  FATE#313915).
- bnx2x: remove false warning regarding interrupt number
  (bnc#790597 FATE#313915).
- bnx2x: fix rx checksum validation for IPv6 (bnc#790597
  FATE#313915).
- bnx2x: Add missing afex code (bnc#790597 FATE#313915).
- bnx2x: fix registers dumped (bnc#790597 FATE#313915).
- bnx2x: correct advertisement of pause capabilities (bnc#790597
  FATE#313915).
- bnx2x: display the correct duplex value (bnc#790597
  FATE#313915).
- bnx2x: prevent timeouts when using PFC (bnc#790597 FATE#313915).
- bnx2x: fix stats copying logic (bnc#790597 FATE#313915).
- bnx2x: Avoid sending multiple statistics queries (bnc#790597
  FATE#313915).
- bnx2x: Utilize Link Flap Avoidance (bnc#790597 FATE#313915).
- bnx2x: Link Flap Avoidance (bnc#790597 FATE#313915).
- bnx2x: link code refactoring (bnc#790597 FATE#313915).
- netdev: make pci_error_handlers const (bnc#790597 FATE#313915).
- bnx2x: use native EEE instead of auto-greeen (bnc#790597
  FATE#313915).
- bnx2x: correct & clean 10G EEE requirements (bnc#790597
  FATE#313915).
- bnx2x: EEE code refactoring (bnc#790597 FATE#313915).
- bnx2x: add EEE support for 4-port devices (bnc#790597
  FATE#313915).
- bnx2x: EEE status is read locally (bnc#790597 FATE#313915).
- bnx2x: use list_move_tail instead of list_del/list_add_tail
  (bnc#790597 FATE#313915).
- bnx2x: Correct the ndo_poll_controller call (bnc#790597
  FATE#313915).
- bnx2x: Move netif_napi_add to the open call (bnc#790597
  FATE#313915).
- bnx2x: fix 57840_MF pci id (bnc#790597 FATE#313915).
- bnx2x: Use PCI Express Capability accessors (bnc#790597
  FATE#313915).
- bnx2x: Fix recovery flow cleanup during probe (bnc#790597
  FATE#313915).
- bnx2x: fix unload previous driver flow when flr-capable
  (bnc#790597 FATE#313915).
- bnx2x: fix mem leak when command is unknown (bnc#790597
  FATE#313915).
- bnx2x: remove cast around the kmalloc in bnx2x_prev_mark_path
  (bnc#790597 FATE#313915).
- bnx2x: Correct EEE statistics gathering (bnc#790597
  FATE#313915).
- bnx2x: Add new 57840 device IDs (bnc#790597 FATE#313915).
- bnx2x: organize BDs calculation for stop/resume (bnc#790597
  FATE#313915).
- bnx2x: set maximal number of default RSS queues (bnc#790597
  FATE#313915).
- commit 2e86a89
* Wed Jan 16 2013 bpoirier@suse.de
- cnic: Allocate UIO resources only on devices that support iSCSI
  (bnc#790592 FATE#313914).
- cnic: Allocate kcq resource only on devices that support FCoE
  (bnc#790592 FATE#313914).
- cnic: Add function pointers to arm IRQ for different devices
  (bnc#790592 FATE#313914).
- cnic: Free UIO rings when the device is closed (bnc#790592
  FATE#313914).
- cnic: Add functions to allocate and free UIO rings (bnc#790592
  FATE#313914).
- drivers/net/ethernet: Fix non-kernel-doc comments with
  kernel-doc start markers (bnc#790592 FATE#313914).
- drivers/net/ethernet/broadcom/cnic.c: remove invalid reference
  to list iterator variable (bnc#790592 FATE#313914).
- cnic: Fix mmap regression (bnc#790592 FATE#313914).
- cnic: Handle RAMROD_CMD_ID_CLOSE error (bnc#790592 FATE#313914).
- cnic: Remove uio mem[0] (bnc#790592 FATE#313914).
- cnic: Read bnx2x function number from internal register
  (bnc#790592 FATE#313914).
- cnic: Fix occasional NULL pointer dereference during reboot
  (bnc#790592 FATE#313914).
- commit 98dfc0b
* Wed Jan 16 2013 bpoirier@suse.de
- bnx2i: use strlcpy() instead of memcpy() for strings (bnc#790592
  FATE#313914 bnc#790593 FATE#313916).
- bnx2x, bnx2fc, bnx2i, cnic: Add statistics support and FCoE
  capabilities advertisement (bnc#790592 FATE#313914 bnc#790593
  FATE#313916).
- bnx2x, bnx2fc, bnx2i, cnic: Add statistics support and FCoE
  capabilities advertisement (bnc#790592 FATE#313914).
- ethernet: Remove casts to same type (bnc#790592 FATE#313914).
- cnic: Fix parity error code conflict (bnc#790592 FATE#313914).
- ethernet/broadcom: ip6_route_output() never returns NULL
  (bnc#790592 FATE#313914).
- cnic: update for FW 7.2.xx (bnc#790592 FATE#313914).
- commit 9192bf6
* Wed Jan 16 2013 bpoirier@suse.de
- bnx2x: Change bnx2x_tests_str_arr to static char (bnc#790597
  FATE#313915).
- bnx2x: 1G sfp+ module handling (bnc#790597 FATE#313915).
- bnx2x: revised link register access (bnc#790597 FATE#313915).
- bnx2x: treat 0 speed as link down (copper) (bnc#790597
  FATE#313915).
- bnx2x: link cleanup (bnc#790597 FATE#313915).
- bnx2x: sfp+ Tx fault detection added (bnc#790597 FATE#313915).
- bnx2x: Change date and version to 1.72.51-0 (bnc#790597
  FATE#313915).
- bnx2x: Support DCBX for all functions (bnc#790597 FATE#313915).
- bnx2x: Add support for ethtool -L (bnc#790597 FATE#313915).
- bnx2x: Allow up to 63 RSS queues (bnc#790597 FATE#313915).
- bnx2x: Split the FP structure (bnc#790597 FATE#313915).
- bnx2x: Move the CNIC L2 CIDs to be right after the RSS CIDs
  (bnc#790597 FATE#313915).
- bnx2x: Make the transmission queues adjacent (bnc#790597
  FATE#313915).
- bnx2x: Allow more than 64 L2 CIDs (bnc#790597 FATE#313915).
- bnx2x: Add support for 4-tupple UDP RSS (bnc#790597
  FATE#313915).
- bnx2x: Return only online tests for MF (bnc#790597 FATE#313915).
- bnx2x: Add support for external LB (bnc#790597 FATE#313915).
- bnx2x: correct LPI pass-through configuration (bnc#790597
  FATE#313915).
- bnx2x: fix link for BCM57711 with 84823 phy (bnc#790597
  FATE#313915).
- bnx2x: fix I2C non-respondent issue (bnc#790597 FATE#313915).
- bnx2x: Added EEE support (bnc#790597 FATE#313915).
- bnx2x: bug fix when loading after SAN boot (bnc#790597
  FATE#313915).
- bnx2x: fix handling single MSIX mode for 57710/57711 (bnc#790597
  FATE#313915).
- bnx2x: remove some bloat (bnc#790597 FATE#313915).
- bnx2x: add transmit timestamping support (bnc#790597
  FATE#313915).
- bnx2x: Update driver version to 1.72.50-0 (bnc#790597
  FATE#313915).
- bnx2x: add afex support (bnc#790597 FATE#313915).
- bnx2x: off by one in bnx2x_ets_e3b0_sp_pri_to_cos_set()
  (bnc#790597 FATE#313915).
- bnx2x: Fix BCM57711+BCM84823 link issue (bnc#790597
  FATE#313915).
- bnx2x: Clear BCM84833 LED after fan failure (bnc#790597
  FATE#313915).
- bnx2x: Fix BCM84833 PHY FW version presentation (bnc#790597
  FATE#313915).
- bnx2x: Restore 1G LED on BCM57712+BCM8727 designs (bnc#790597
  FATE#313915).
- bnx2x: Fix BCM57810-KR FC (bnc#790597 FATE#313915).
- bnx2x: add missing parenthesis to prevent u32 overflow
  (bnc#790597 FATE#313915).
- bnx2x: Change to driver version 1.72.10-0 (bnc#790597
  FATE#313915).
- bnx2x: Change comments and white spaces (bnc#790597
  FATE#313915).
- bnx2x: change to the rss engine (bnc#790597 FATE#313915).
- bnx2x: congestion management re-organization (bnc#790597
  FATE#313915).
- bnx2x: Added support for a new device - 57811 (bnc#790597
  FATE#313915).
- bnx2x: Add remote-fault link detection (bnc#790597 FATE#313915).
- bnx2x: added support for working with one msix irq (bnc#790597
  FATE#313915).
- bnx2x: enable inta on the pci bus when used (bnc#790597
  FATE#313915).
- bnx2x: remove unnecessary dmae code (bnc#790597 FATE#313915).
- bnx2x: remove unnecessary .h dependencies (bnc#790597
  FATE#313915).
- bnx2x: correction to firmware interface (bnc#790597
  FATE#313915).
- bnx2x: fix vector traveling while looking for an empty entry
  (bnc#790597 FATE#313915).
- bnx2x: validate FW trace prior to its printing (bnc#790597
  FATE#313915).
- bnx2x: consistent statistics for old FW (bnc#790597
  FATE#313915).
- bnx2x: changed iscsi/fcoe mac init and macros (bnc#790597
  FATE#313915).
- bnx2x: added TLV_NOT_FOUND flags to the dcb (bnc#790597
  FATE#313915).
- bnx2x: changed initial dcb configuration (bnc#790597
  FATE#313915).
- bnx2x: removed dcb unused code (bnc#790597 FATE#313915).
- bnx2x: reduced sparse warnings (bnc#790597 FATE#313915).
- bnx2x: revised driver prints (bnc#790597 FATE#313915).
- bnx2x: fix memory leak in bnx2x_init_firmware() (bnc#790597
  FATE#313915).
- bnx2x: fix a crash on corrupt firmware file (bnc#790597
  FATE#313915).
- bnx2x: code doesn't use stats for allocating Rx BDs (bnc#790597
  FATE#313915).
- bnx2x: ethtool returns req. AN even when AN fails (bnc#790597
  FATE#313915).
- bnx2x: ethtool now returns unknown speed/duplex (bnc#790597
  FATE#313915).
- bnx2x: mark functions as loaded on shared memory (bnc#790597
  FATE#313915).
- bnx2x: use param's id instead of sp_obj's id (bnc#790597
  FATE#313915).
- bnx2x: set_one_mac_e1x uses raw's state as input (bnc#790597
  FATE#313915).
- bnx2x: removed unused function bnx2x_queue_set_cos_cid
  (bnc#790597 FATE#313915).
- bnx2x: move LLH_CAM to header, apply naming conventions
  (bnc#790597 FATE#313915).
- bnx2x: FCoE statistics id fixed (bnc#790597 FATE#313915).
- bnx2x: dcb bit indices flags used as bits (bnc#790597
  FATE#313915).
- bnx2x: added cpu_to_le16 when preparing ramrod's data
  (bnc#790597 FATE#313915).
- bnx2x: pfc statistics counts pfc events twice (bnc#790597
  FATE#313915).
- bnx2x: update driver version to 1.72.10-0 (bnc#790597
  FATE#313915).
- use FW 7.2.16 (bnc#790597 FATE#313915).
- bnx2x: make bnx2x_close() static again (bnc#790597 FATE#313915).
- bnx2x: allow all functions to display the phy FW version
  (bnc#790597 FATE#313915).
- bnx2x: removed code re-checking memory base after device open
  (bnc#790597 FATE#313915).
- bnx2x: allow BCM84833 phy to advertise 100Base-T speeds
  (bnc#790597 FATE#313915).
- bnx2x: notify cnic of address of info-to-the-mcp (bnc#790597
  FATE#313915).
- bnx2x: allocate smaller Rx rings for 1G functions (bnc#790597
  FATE#313915).
- bnx2x: allocate memory dynamically in ethtool self-test
  (bnc#790597 FATE#313915).
- bnx2x: force 10G on 84833 phy should be autoneg with only 10G
  advertised (bnc#790597 FATE#313915).
- bnx2x: added autoneg-restart after link advertisement changes
  (bnc#790597 FATE#313915).
- bnx2x: ethtool publishes link partners speed and FC (bnc#790597
  FATE#313915).
- bnx2x: half duplex support added for several boards (bnc#790597
  FATE#313915).
- bnx2x: consistent statistics after internal driver reload
  (bnc#790597 FATE#313915).
- bnx2x: remove the 'poll' module option (bnc#790597 FATE#313915).
- drivers/net: Remove unnecessary k.alloc/v.alloc OOM messages
  (bnc#790597 FATE#313915).
- drivers/net: Remove alloc_etherdev error messages (bnc#790597
  FATE#313915).
- bnx2x: Function Level Reset Final Cleanup (bnc#790597
  FATE#313915).
- bnx2x: fix bnx2x_storm_stats_update() on big endian (bnc#790597
  FATE#313915).
- bnx2x: Update version to 1.72.0 and copyrights (bnc#790597
  FATE#313915).
- bnx2x: Recoverable and unrecoverable error statistics
  (bnc#790597 FATE#313915).
- bnx2x: Recovery flow bug fixes (bnc#790597 FATE#313915).
- bnx2x: Track active PFs with bitmap (bnc#790597 FATE#313915).
- bnx2x: Lock PF-common resources (bnc#790597 FATE#313915).
- bnx2x: Obtain Bus Device Function from register (bnc#790597
  FATE#313915).
- bnx2x: Removing indirect register access (bnc#790597
  FATE#313915).
- bnx2x: Support Queue Per Cos in 5771xx devices (bnc#790597
  FATE#313915).
- bnx2x: unlock before returning an error (bnc#790597
  FATE#313915).
- bnx2x: fix compilation error with SOE in fw_dump (bnc#790597
  FATE#313915).
- bnx2x: handle CHIP_REVISION during init_one (bnc#790597
  FATE#313915).
- bnx2x: allow user to change ring size in ISCSI SD mode
  (bnc#790597 FATE#313915).
- bnx2x: fix Big-Endianess in ethtool -t (bnc#790597 FATE#313915).
- bnx2x: fixed ethtool statistics for MF modes (bnc#790597
  FATE#313915).
- bnx2x: credit-leakage fixup on vlan_mac_del_all (bnc#790597
  FATE#313915).
- bnx2x: Disable AN KR work-around for BCM57810 (bnc#790597
  FATE#313915).
- bnx2x: Remove AutoGrEEEn for BCM84833 (bnc#790597 FATE#313915).
- bnx2x: Remove 100Mb force speed for BCM84833 (bnc#790597
  FATE#313915).
- bnx2x: Fix PFC setting on BCM57840 (bnc#790597 FATE#313915).
- bnx2x: Fix Super-Isolate mode for BCM84833 (bnc#790597
  FATE#313915).
- bnx2x: handle vpd data longer than 128 bytes (bnc#790597
  FATE#313915).
- bnx2x: properly initialize L5 features (bnc#790597 FATE#313915).
- bnx2x: fix typo in fcoe stats collection (bnc#790597
  FATE#313915).
- bnx2x: Fix compile errors if CONFIG_CNIC is not set (bnc#790597
  FATE#313915).
- commit ad41aae
* Wed Jan 16 2013 bpoirier@suse.de
- cnic: Update VLAN ID during ISCSI_UEVENT_PATH_UPDATE (bnc#790592
  FATE#313914).
- cnic: set error flag when iSCSI connection fails (bnc#790592
  FATE#313914).
- cnic: Add FCoE parity error recovery (bnc#790592 FATE#313914).
- cnic: Improve error recovery on bnx2x devices (bnc#790592
  FATE#313914).
- cnic: Re-init dev->stats_addr after chip reset (bnc#790592
  FATE#313914).
- commit 6c6271d
* Wed Jan 16 2013 bpoirier@suse.de
- bnx2: Rename register read and write macros (bnc#790590
  FATE#313913).
- bnx2: Clean up remaining iounmap (bnc#790590 FATE#313913).
- netdev: make pci_error_handlers const (bnc#790590 FATE#313913).
- bnx2: Try to recover from PCI block reset (bnc#790590
  FATE#313913).
- bnx2: set maximal number of default RSS queues (bnc#790590
  FATE#313913).
- bnx2: Add missing netif_tx_disable() in bnx2_close() (bnc#790590
  FATE#313913).
- bnx2: Add "fall through" comments (bnc#790590 FATE#313913).
- bnx2: Update version 2.2.2 (bnc#790590 FATE#313913).
- bnx2: Read PCI function number from internal register
  (bnc#790590 FATE#313913).
- bnx2: Dump additional BC_STATE during firmware sync timeout
  (bnc#790590 FATE#313913).
- bnx2: Dump all FTQ_CTL registers during tx_timeout (bnc#790590
  FATE#313913).
- ethernet: Remove casts to same type (bnc#790590 FATE#313913).
- broadcom: replace open-coded ARRAY_SIZE with macro (bnc#790590
  FATE#313913).
- bnx2: stop using net_device.{base_addr, irq} (bnc#790590
  FATE#313913).
- ethernet: unify return value of .ndo_set_mac_address if address
  is invalid (bnc#790590 FATE#313913).
- bnx2: Add missing memory barrier in bnx2_start_xmit()
  (bnc#790590 FATE#313913).
- bnx2: Add support for ethtool --show-channels|--set-channels
  (bnc#790590 FATE#313913).
- drivers/net: Remove unnecessary k.alloc/v.alloc OOM messages
  (bnc#790590 FATE#313913).
- bnx2: Update driver to use new mips firmware (bnc#790590
  FATE#313913).
- net: Change mii to ethtool advertisement function names
  (bnc#790590 FATE#313913).
- net: Add ethtool to mii advertisment conversion helpers
  (bnc#790590 FATE#313913).
- sweep the floors and convert some .get_drvinfo routines to
  strlcpy (bnc#790590 FATE#313913).
- net: add skb frag size accessors (bnc#790590 FATE#313913).
- bnx2: fix skb truesize underestimation (bnc#790590 FATE#313913).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#790590 FATE#313913).
- net: use DMA_x_DEVICE and dma_mapping_error with
  skb_frag_dma_map (bnc#790590 FATE#313913).
- bnx2: convert to SKB paged frag API (bnc#790590 FATE#313913).
- commit 97c28c1
* Wed Jan 16 2013 bpoirier@suse.de
- bnx2x, cnic: support DRV_INFO upon FW request (bnc#790597
  FATE#313915).
- bnx2x: support classification config query (bnc#790597
  FATE#313915).
- bnx2x: add fcoe statistics (bnc#790597 FATE#313915).
- bnx2x: add PFC statistics (bnc#790597 FATE#313915).
- bnx2x: Use kcalloc instead of kzalloc to allocate array
  (bnc#790597 FATE#313915).
- bnx2x: handle iSCSI SD mode (bnc#790597 FATE#313915).
- bnx2x: Change value comparison order (bnc#790597 FATE#313915).
- bnx2x: Cosmetic changes (bnc#790597 FATE#313915).
- bnx2x: Fix self test of BCM57800 (bnc#790597 FATE#313915).
- bnx2x: Add known PHY type check (bnc#790597 FATE#313915).
- bnx2x: Change Warpcore MDIO work around mode (bnc#790597
  FATE#313915).
- bnx2x: Fix BCM84833 link and LED behavior (bnc#790597
  FATE#313915).
- bnx2x: Warpcore HW reset following fan failure (bnc#790597
  FATE#313915).
- bnx2x: ETS changes (bnc#790597 FATE#313915).
- bnx2x: PFC changes (bnc#790597 FATE#313915).
- bnx2x: Fix 5461x LED (bnc#790597 FATE#313915).
- net: remove ipv6_addr_copy() (bnc#790597 FATE#313915).
- bnx2x: allow FCoE and DCB for 578xx (bnc#790597 FATE#313915).
- sweep the floors and convert some .get_drvinfo routines to
  strlcpy (bnc#790597 FATE#313915).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#790597 FATE#313915).
- bnx2x: remove some dead code (bnc#790597 FATE#313915).
- cnic: Fix select dependencies in bnx2fc/bnx2i Kconfig
  (bnc#790597 FATE#313915).
- commit 7eb6682
* Wed Jan 16 2013 bpoirier@suse.de
- broadcom: Move the Broadcom drivers (bnc#790597 FATE#313915).
- Update config files.
- Refresh
  patches.drivers/bnx2fc-Reduce-object-size-by-consolidating-form.patch.
- commit eda7f59
* Wed Jan 16 2013 bpoirier@suse.de
- net: fix warning of versioncheck (bnc#790597 FATE#313915).
- bnx2x: use bnx2x_reload_if_running (bnc#790597 FATE#313915).
- commit 60616c2
* Wed Jan 16 2013 agraf@suse.de
- Refresh
  patches.arch/s390-kvm-0039-KVM-s390-Add-support-for-machine-checks.patch.
- commit 87752ee
* Wed Jan 16 2013 agraf@suse.de
- KVM: s390: Gracefully handle busy conditions on ccw_device_start
  (FATE#314101,FATE#310914).
- KVM: s390: Dynamic allocation of virtio-ccw I/O data
  (FATE#314101,FATE#310914).
- KVM: s390: Add a channel I/O based virtio transport driver
  (FATE#314101,FATE#310914).
- s390/ccwdev: Include asm/schid.h (FATE#314101,FATE#310914).
- s390: Add a mechanism to get the subchannel id
  (FATE#314101,FATE#310914).
- KVM: s390: Handle hosts not supporting s390-virtio
  (FATE#314101,FATE#310914).
- KVM: s390: Perform early event mask processing during boot
  (FATE#314101,FATE#310914).
- KVM: s390: Add support for channel I/O instructions
  (FATE#314101,FATE#310914).
- KVM: s390: Base infrastructure for enabling capabilities
  (FATE#314101,FATE#310914).
- KVM: s390: In-kernel handling of I/O instructions
  (FATE#314101,FATE#310914).
- KVM: s390: Add support for machine checks
  (FATE#314101,FATE#310914).
- KVM: s390: Support for I/O interrupts (FATE#314101,FATE#310914).
- KVM: s390: Decoding helper functions (FATE#314101,FATE#310914).
- KVM: s390: Constify intercept handler tables
  (FATE#314101,FATE#310914).
- s390/kvm: dont announce RRBM support (FATE#314101,FATE#310914).
- s390/kvm: Interrupt injection bugfix (FATE#314101,FATE#310914).
- KVM: s390: Fix vcpu_load handling in interrupt code
  (FATE#314101,FATE#310914).
- KVM: s390: Fix sigp sense handling (FATE#314101,FATE#310914).
- KVM: s390: fix sigp set prefix status stored cases
  (FATE#314101,FATE#310914).
- KVM: s390: Set CPU in stopped state on initial cpu reset
  (FATE#314101,FATE#310914).
- KVM: s390: onereg for timer related registers
  (FATE#314101,FATE#310914).
- KVM: s390: epoch difference and TOD programmable field
  (FATE#314101,FATE#310914).
- KVM: s390: KVM_GET/SET_ONEREG for s390
  (FATE#314101,FATE#310914).
- KVM: s390: implement KVM_CAP_NR/MAX_VCPUS
  (FATE#314101,FATE#310914).
- KVM: s390: Handle sckpf instruction (FATE#314101,FATE#310914).
- KVM: s390: Implement the directed yield (diag 9c) hypervisor
  call for KVM (FATE#314101,FATE#310914).
- KVM: s390: provide control registers via kvm_run
  (FATE#314101,FATE#310914).
- KVM: s390: add stop_on_stop flag when doing stop and store
  (FATE#314101,FATE#310914).
- KVM: s390: ignore sigp stop overinitiative
  (FATE#314101,FATE#310914).
- KVM: s390: make sigp restart return busy when stop pending
  (FATE#314101,FATE#310914).
- KVM: s390: Sanitize fpc registers for KVM_SET_FPU
  (FATE#314101,FATE#310914).
- KVM: s390: provide access guest registers via kvm_run
  (FATE#314101,FATE#310914).
- KVM: s390: provide general purpose guest registers via kvm_run
  (FATE#314101,FATE#310914).
- KVM: s390: provide the prefix register via kvm_run
  (FATE#314101,FATE#310914).
- KVM: s390: rework code that sets the prefix
  (FATE#314101,FATE#310914).
- KVM: s390: Fix return code for unknown ioctl numbers
  (FATE#314101,FATE#310914).
- KVM: s390: announce SYNC_MMU (FATE#314101,FATE#310914).
- KVM: s390: Fix tprot locking (FATE#314101,FATE#310914).
- KVM: s390: handle SIGP sense running intercepts
  (FATE#314101,FATE#310914).
- KVM: s390: implement sigp external call
  (FATE#314101,FATE#310914).
- KVM: s390: Fix RUNNING flag misinterpretation
  (FATE#314101,FATE#310914).
- KVM: s390: fix register setting (FATE#314101,FATE#310914).
- KVM: s390: fix return value of kvm_arch_init_vm
  (FATE#314101,FATE#310914).
- kvm: make sigp emerg smp capable (FATE#314101,FATE#310914).
- move sie code to entry.S (FATE#314101,FATE#310914).
- KVM: PPC: Add generic single register ioctls
  (FATE#314101,FATE#310914).
- KVM: provide synchronous registers in kvm_run
  (FATE#314101,FATE#310914).
- kvm: handle tprot intercepts (FATE#314101,FATE#310914).
- commit 3a82498
* Wed Jan 16 2013 duwe@suse.de
- ipr: Fix several unlock issues in ipr driver (bnc#794550).
- ipr: Driver version 2.6.0 (bnc#794550,fate#314040).
- ipr: Implement block iopoll (bnc#794550,fate#314040).
- commit 4e017f9
* Wed Jan 16 2013 ptesarik@suse.cz
- Update config: Revert commit 42e5b13 for vanilla.
- commit 6ad311f
* Wed Jan 16 2013 duwe@suse.de
- powerpc: Add DSCR support to ptrace (fate#314228,bnc#795581).
- commit 3d49866
* Wed Jan 16 2013 jbeulich@suse.com
- Update Xen patches to 3.0.57 and c/s 1214.
- allow non-pv-ops kernel to be built as bzImage (FATE#313527
  FATE#314491).
- EFI: Add in-kernel variable to determine if Secure Boot is
  enabled (fate#314574).
- Update x86_64/xen config file.
- rpm/kernel-binary.spec.in: Allow for Xen kernel to use bzImage.
- commit 7fc3100
* Wed Jan 16 2013 mmarek@suse.cz
- patches.suse/intel-perf-event-0098-x86-cpu-rename-checking_wrmsrl-to-wrmsrl_safe.patch:
  Rename one more occurence of checking_wrmsrl.
- commit 3c62108
* Wed Jan 16 2013 ptesarik@suse.cz
- Update config: Enable fadump on ppc64.
- commit 42e5b13
* Wed Jan 16 2013 ptesarik@suse.cz
- fadump: Remove the phyp assisted dump code.
  (FATE#314024, bnc#794840).
- commit 493651a
* Wed Jan 16 2013 ptesarik@suse.cz
- fadump: Invalidate the fadump registration during machine shutdown.
  (FATE#314024, bnc#794840).
- commit f654295
* Wed Jan 16 2013 ptesarik@suse.cz
- fadump: Invalidate registration and release reserved memory for general
  use. (FATE#314024, bnc#794840).
- commit 495056f
* Wed Jan 16 2013 ptesarik@suse.cz
- fadump: Introduce cleanup routine to invalidate /proc/vmcore.
  (FATE#314024, bnc#794840).
- commit 2559a5a
* Wed Jan 16 2013 ptesarik@suse.cz
- fadump: Add PT_NOTE program header for vmcoreinfo
  (FATE#314024, bnc#794840).
- commit ed97fae
* Wed Jan 16 2013 ptesarik@suse.cz
- fadump: Convert firmware-assisted cpu state dump data into elf notes.
  (FATE#314024, bnc#794840).
- commit ecd82bd
* Wed Jan 16 2013 ptesarik@suse.cz
- fadump: Initialize elfcore header and add PT_LOAD program headers.
  (FATE#314024, bnc#794840).
- commit 8bf8f7d
* Wed Jan 16 2013 ptesarik@suse.cz
- fadump: Register for firmware assisted dump.
  (FATE#314024, bnc#794840).
- commit 1a34b31
* Wed Jan 16 2013 ptesarik@suse.cz
- fadump: Reserve the memory for firmware assisted dump.
  (FATE#314024, bnc#794840).
- commit e2d7d5c
* Wed Jan 16 2013 ptesarik@suse.cz
- fadump: Add documentation for firmware-assisted dump.
  (FATE#314024, bnc#794840)
- commit d582985
* Wed Jan 16 2013 jlee@suse.com
- Refresh
  patches.suse/0005-MODSIGN-Add-module-certificate-blacklist-keyring.patch.
  (fate#314574)
- commit b709bb7
* Tue Jan 15 2013 bpoirier@suse.de
- Refresh
  patches.drivers/0330-bnx2x-disable-fairness-if-ETS-is-enabled.patch.
- commit b1aee5a
* Tue Jan 15 2013 duwe@suse.de
- ipr: Reduce lock contention (bnc#794550,fate#314040).
- ipr: Add support for MSI-X and distributed completion
  (bnc#794550,fate#314040).
- ipr: Resource path error logging cleanup
  (bnc#794550,fate#314040).
- ipr: Handler ID memory allocation failure
  (bnc#794550,fate#314040).
- ipr: Add sereral new CCIN definitions for new adapters support
  (bnc#794550,fate#314040).
- ipr: fix small coding style issues (bnc#794550,fate#314040).
- ipr: Increase max concurrent oustanding commands
  (bnc#794550,fate#314040).
- ipr: Remove unnecessary interrupt clearing on new adapters
  (bnc#794550,fate#314040).
- ipr: update PCI ID definitions for new adapters
  (bnc#794550,fate#314040).
- commit 409aed2
* Tue Jan 15 2013 hare@suse.de
- [SCSI] qla2xxx: Display that driver is operating in legacy
  interrupt mode (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Dont clear drv active on iospace config failure
  (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Update ql2xextended_error_logging parameter
  description with new option (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Parameterize the link speed of hba rather than
  fcport (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Add 16Gb/s case to get port speed capability
  (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Move marking fcport online ahead of setting
  iiDMA speed (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Add acquiring of risc semaphore before doing
  ISP reset (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Ignore driver ack bit if corresponding presence
  bit is not set (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Fix typo in qla83xx_fw_dump function
  (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Add Gen3 PCIe speed 8GT/s to the log message
  (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Use correct Request-Q-Out register during
  bidirectional request processing (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Move noisy Start scsi failed messages to
  verbose logging level (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Fix coccinelle warnings in qla2x00_relogin
  (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: No fcport FC-4 type assignment in GA_NXT
  response (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Fix for warnings reported by sparse
  (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Honor status value of 2 for report-id
  acquisition (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Remove spurious taking of ha->vport_slock
  spinlock (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Clear unsupported 'states' during Get-FW-State
  queries (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Update the driver version to 8.04.00.08-k
  (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Free rsp_data even on error in
  qla2x00_process_loopback() (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Change in setting UNLOADING flag and FC
  vports logout sequence while unloading qla2xxx driver
  (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Test and clear FCPORT_UPDATE_NEEDED atomically
  (FATE#313901,bnc#784820).
- [SCSI] qla2xxx: Properly set result field of bsg_job reply
  structure for success and failure (FATE#313901,bnc#784820).
- qla2xxx: Fix typo in qla2xxx drivers (FATE#313901,bnc#784820).
- commit ed950d7
* Tue Jan 15 2013 jslaby@suse.cz
- Fix vanilla builds by moving reverts to patches.kabi/
- commit 6d9fc4c
* Tue Jan 15 2013 bpoirier@suse.de
- enic: remove unnecessary setting of skb->dev (bnc#794210
  FATE#314013).
- enic: replace open-coded ARRAY_SIZE with macro (bnc#794210
  FATE#314013).
- enic: Stop using NLA_PUT*() (bnc#794210 FATE#314013).
- enic: Fix addr valid check in enic_set_vf_mac (bnc#794210
  FATE#314013).
- enic: fix an endian bug in enic_probe() (bnc#794210
  FATE#314013).
- enic: Fix endianness bug (bnc#794210 FATE#314013).
- enic: Add support for fw init command on sriov vf's (bnc#794210
  FATE#314013).
- enic: Fix ndo_set_vf_mac and ndo_set_vf_port to set/get the
  sriov vf's mac (bnc#794210 FATE#314013).
- enic: Add new fw devcmd to set mac address of an interface
  (bnc#794210 FATE#314013).
- enic: rename CMD_MAC_ADDR to CMD_GET_MAC_ADDR (bnc#794210
  FATE#314013).
- enic: remove assignment of random mac on enic vf (bnc#794210
  FATE#314013).
- enic: Fix address deregistration for sriov vf during port
  profile disassociate (bnc#794210 FATE#314013).
- enic: Check firmware capability before issuing firmware commands
  (bnc#794210 FATE#314013).
- enic: Enable support for multiple hardware receive queues
  (bnc#794210 FATE#314013).
- enic: fix compile when CONFIG_PCI_IOV is not enabled (bnc#794210
  FATE#314013).
- enic: fix location of vnic dev unregister in enic_probe cleanup
  code (bnc#794210 FATE#314013).
- enic: rearrange some of the port profile code (bnc#794210
  FATE#314013).
- enic: Add sriov vf device id checks in port profile code
  (bnc#794210 FATE#314013).
- enic: This patch adds pci id 0x71 for SRIOV VF's (bnc#794210
  FATE#314013).
- enic: Use kcalloc instead of kzalloc to allocate array
  (bnc#794210 FATE#314013).
- enic: Add support for port profile association on a enic SRIOV
  VF (bnc#794210 FATE#314013).
- enic: Helper code for SRIOV proxy commands (bnc#794210
  FATE#314013).
- enic: Add SRIOV support (bnc#794210 FATE#314013).
- enic: convert to SKB paged frag API (bnc#794210 FATE#314013).
- commit 1732ff2
* Tue Jan 15 2013 bpoirier@suse.de
- enic: Move the Cisco driver (bnc#794210 FATE#314013).
- Update config files.
- commit 9925709
* Tue Jan 15 2013 bpoirier@suse.de
- enic: do vlan cleanup (bnc#794210 FATE#314013).
- enic: Add support to configure hardware interrupt coalesce
  timers in a platform independent way (bnc#794210 FATE#314013).
- enic: Get/Set interrupt resource index for transmit and receive
  queues (bnc#794210 FATE#314013).
- enic: Log device configuration in detail during driver load
  (bnc#794210 FATE#314013).
- enic: Pass 802.1p bits for packets tagged with vlan zero
  (bnc#794210 FATE#314013).
- enic: update to support 64 bit stats (bnc#794210 FATE#314013).
- enic: Add support for MTU change via port profile on a dynamic
  vnic (bnc#794210 FATE#314013).
- commit aeec2e9
* Mon Jan 14 2013 bpoirier@suse.de
- cxgb4: Fix incorrect PFVF CMASK (bnc#784800 FATE#314296).
- commit 7da235c
* Mon Jan 14 2013 jjolly@suse.de
- Commented out patches.arch/s390-sles11sp3-14-01... until s390 build
  break is resolved. (bnc#794527)
- commit 1e5f9d6
* Mon Jan 14 2013 jjolly@suse.de
- IB/rds: Correct ib_api use with gs_dma_address/sg_dma_len
  (bnc#780244,FATE#314303).
- commit 2126c34
* Mon Jan 14 2013 jjolly@suse.de
- qeth: Support VEPA mode (bnc#794532,FATE#314595).
- commit 4ebf553
* Mon Jan 14 2013 jjolly@suse.de
- [FEAT NET1213] qeth: Support VEPA mode (bnc#794532,FATE#314595).
- commit a459825
* Mon Jan 14 2013 jjolly@suse.de
- kernel: support for CPU runtime instrumentation
  (bnc#794527,FATE#314142).
- commit 55911c8
* Mon Jan 14 2013 jjolly@suse.de
- kernel: add support for transactional execution
  (bnc#794527,FATE#314142).
- commit bfadec4
* Mon Jan 14 2013 bpoirier@suse.de
- drivers/net: fix up function prototypes after __dev* removals
  (bnc#795304 FATE#313649).
- net/intel: remove __dev* attributes (bnc#795304 FATE#313649).
- treewide: fix typo of "suppport" in various comments (bnc#795304
  FATE#313649).
- e1000: fix concurrent accesses to PHY from watchdog and ethtool
  (bnc#795304 FATE#313649).
- e1000: Small packets may get corrupted during padding by HW
  (bnc#795304 FATE#313649).
- e1000: add byte queue limits (bnc#795304 FATE#313649).
- net: Add netdev interfaces for recording sends/comp (bnc#795304
  FATE#313649).
- netdev: make pci_error_handlers const (bnc#795304 FATE#313649).
- e1000: configure and read MDI settings (bnc#795304 FATE#313649).
- ethtool.h: MDI setting support (bnc#795304 FATE#313649).
- e1000: advertise transmit time stamping (bnc#795304
  FATE#313649).
- ethtool: Add a common function for drivers with transmit time
  stamping (bnc#795304 FATE#313649).
- ethtool: Introduce a method for getting time stamping
  capabilities (bnc#795304 FATE#313649).
- drivers/net/ethernet: Fix non-kernel-doc comments with
  kernel-doc start markers (bnc#795304 FATE#313649).
- drivers/net/ethernet: Fix (nearly-)kernel-doc comments for
  various functions (bnc#795304 FATE#313649).
- e1000: Combining Bitwise OR in one expression (bnc#795304
  FATE#313649).
- e1000: look into the page instead of skb->data for
  e1000_tbi_adjust_stats() (bnc#795304 FATE#313649).
- e1000: Prevent reset task killing itself (bnc#795304
  FATE#313649).
- e1000: look in the page and not in skb->data for the last byte
  (bnc#795304 FATE#313649).
- e1000: remove workaround for Errata 23 from jumbo alloc
  (bnc#795304 FATE#313649).
- e1000: Silence sparse warnings by correcting type (bnc#795304
  FATE#313649).
- e1000: add transmit timestamping support (bnc#795304
  FATE#313649).
- intel: make wired ethernet driver message level consistent
  (rev2) (bnc#795304 FATE#313649).
- v2 e1000: Neaten e1000_dump function (bnc#795304 FATE#313649).
- e1000: Neaten e1000_config_dsp_after_link_change (bnc#795304
  FATE#313649).
- e1000: Support sending custom Ethernet CRC (bnc#795304
  FATE#313649).
- net: Add framework to allow sending packets with customized CRC
  (bnc#795304 FATE#313649).
- e1000: add dropped DMA receive enable back in for WoL
  (bnc#795304 FATE#313649).
- e1000: Adding e1000_dump function (bnc#795304 FATE#313649).
- drivers/net: Remove unnecessary k.alloc/v.alloc OOM messages
  (bnc#795304 FATE#313649).
- e1000: cleanup CE4100 MDIO registers access (bnc#795304
  FATE#313649).
- e1000: unmap ce4100_gbe_mdio_base_virt in e1000_remove
  (bnc#795304 FATE#313649).
- e1000: fix lockdep splat in shutdown handler (bnc#795304
  FATE#313649).
- net: fix assignment of 0/1 to bool variables (bnc#795304
  FATE#313649).
- Sweep away N/A fw_version dustbunnies from the .get_drvinfo
  routine of a number of drivers (bnc#795304 FATE#313649).
- intel: Convert <FOO>_LENGTH_OF_ADDRESS to ETH_ALEN (bnc#795304
  FATE#313649).
- Sweep the last of the active .get_drvinfo floors under ethernet/
  (bnc#795304 FATE#313649).
- net: add skb frag size accessors (bnc#795304 FATE#313649).
- e1000: fix skb truesize underestimation (bnc#795304
  FATE#313649).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#795304 FATE#313649).
- e1000: convert to private mutex from rtnl (bnc#795304
  FATE#313649).
- e1000: convert mdelay to msleep (bnc#795304 FATE#313649).
- e1000: convert hardware management from timers to threads
  (bnc#795304 FATE#313649).
- e1000: don't enable dma receives until after dma address has
  been setup (bnc#795304 FATE#313649).
- intel: convert to SKB paged frag API (bnc#795304 FATE#313649).
- commit 8be14ae
* Mon Jan 14 2013 bpoirier@suse.de
- intel: Move the Intel wired LAN drivers (bnc#795304
  FATE#313649).
- Update config files.
- commit e7d635c
* Mon Jan 14 2013 jjolly@suse.de
- zcryt: Handle AP configuration changes (bnc#793692,FATE#314126).
- commit 8366e58
* Mon Jan 14 2013 bpoirier@suse.de
- intel drivers: repair missing flush operations (bnc#795304
  FATE#313649).
- e1000: always call e1000_check_for_link() on e1000_ce4100 MACs
  (bnc#795304 FATE#313649).
- e1000: do vlan cleanup (bnc#795304 FATE#313649).
- e1000: convert to ndo_fix_features (bnc#795304 FATE#313649).
- e1000: remove unnecessary code (bnc#795304 FATE#313649).
- commit b8a0073
* Mon Jan 14 2013 jjolly@suse.de
- zcrypt: Add support for CEX4 crypto card
  (bnc#793683,FATE#314097).
- commit 8fa640c
* Mon Jan 14 2013 jjolly@suse.de
- zcrypt: Separate msgtype implementation from card  modules
  (bnc#793683,FATE#314097).
- commit 5c060cd
* Mon Jan 14 2013 jjolly@suse.de
- zcrypt: Add function facility information as AP device attribute
  (bnc#793683,FATE#314097).
- commit 462e2f6
* Mon Jan 14 2013 jjolly@suse.de
- zcrypt: AP configuration information exploitation
  (bnc#793683,FATE#314097).
- commit 4b30b8a
* Mon Jan 14 2013 hare@suse.de
- patches.fixes/dm-mpath-only-retry-ioctl-when-no-paths-if-queue_if_.patch:
  Fixup initialization.
- commit 521f233
* Mon Jan 14 2013 hare@suse.de
- patches.fixes/dm-mpath-allow-ioctls-to-trigger-pg-init.patch:
  dm mpath: allow ioctls to trigger pg init (bnc#787348).
- patches.fixes/dm-mpath-only-retry-ioctl-when-no-paths-if-queue_if_.patch:
  dm mpath: only retry ioctl when no paths if queue_if_no_path
  set (bnc#787348).
- commit abf52c8
* Mon Jan 14 2013 jjolly@suse.de
- dasd: add safe offline interface (bnc#792956,FATE#314555).
- commit d02683a
* Mon Jan 14 2013 jjolly@suse.de
- dasd: add shutdown action (bnc#792956,FATE#314555).
- commit 51e1df6
* Mon Jan 14 2013 hare@suse.de
- hpsa: update version number to 3.2.0 (FATE#313833).
- hpsa: remove pre gen 8 controller PCI IDs (FATE#313833).
- hpsa: Add new PCI IDs (FATE#313833).
- hpsa: use WARN-ON return value directly (FATE#313833).
- hpsa: fix wrong return value from hpsa_find_cfgtables
  (FATE#313833).
- hpsa: add __devinit annotation to hpsa_wait_for_board_state
  (FATE#313833).
- hpsa: remove unintentional exporting of hpsa_init_one
  (FATE#313833).
- hpsa: Remove gratuitous cosmetic diffs vs. kernel.org
  (FATE#313833).
- hpsa: remove unnecessary pci id skipping code (FATE#313833).
- Move hpsa_wait_for_board_state function to more closely match
  kernel.org code (FATE#313833).
- hpsa: delete old unused padding garbage (FATE#313833).
- commit 996f2ff
* Mon Jan 14 2013 jlee@suse.com
- Refresh patches.xen/xen-x86-EFI.
- commit ede4b8d
* Mon Jan 14 2013 jlee@suse.com
- efivarfs: Make efivarfs_fill_super() static (fate#314499,
  fate#313527).
- efivarfs: Use query_variable_info() to limit kmalloc()
  (fate#314499, fate#313527).
- efivarfs: Fix return value of efivarfs_file_write()
  (fate#314499, fate#313527).
- efivarfs: Return a consistent error when efivarfs_get_inode()
  fails (fate#314499, fate#313527).
- efivarfs: Make 'datasize' unsigned long (fate#314499,
  fate#313527).
- efivarfs: Add unique magic number (fate#314499, fate#313527).
- efivarfs: Replace magic number with sizeof(attributes)
  (fate#314499, fate#313527).
- efi: Clarify GUID length calculations (fate#314499,
  fate#313527).
- efivarfs: Return an error if we fail to read a variable
  (fate#314499, fate#313527).
- x86, efi: Convert efi_phys_get_time() args to physical addresses
  (fate#314499, fate#314500).
- x86: Serialize EFI time accesses on rtc_lock (fate#314499,
  fate#314500).
- x86, efi: Add infrastructure for UEFI 2.0 runtime services
  (fate#314499, fate#314500).
- x86, efi: Fix argument types for SetVariable() (fate#314499,
  fate#314500).
- commit 0bea6f2
* Mon Jan 14 2013 hare@suse.de
- fnic: Incremented driver version (FATE#314014).
- fnic: Kernel panic due to FIP mode misconfiguration
  (FATE#314014).
- fnic: FIP VLAN Discovery Feature Support (FATE#314014).
- fnic: Fnic Trace Utility (FATE#314014).
- fnic: New debug flags and debug log messages (FATE#314014).
- fnic: fnic driver may hit BUG_ON on device reset (FATE#314014).
- fnic: Fix SGEs limit (FATE#314014).
- fnic:fixing issues in device and firmware reset code
  (FATE#314014).
- fnic: fix for trusted cos (FATE#314014).
- fnic: updated MAINTAINERS list (FATE#314014).
- commit 16fccb7
* Mon Jan 14 2013 jjolly@suse.de
- s390/ccwgroup: remove ccwgroup_create_from_string (bnc#790870).
- commit 548c2cf
* Mon Jan 14 2013 jjolly@suse.de
- s390/qeth: stop using struct ccwgroup driver for discipline
  callbacks (bnc#790870).
- commit 2eb4ed1
* Mon Jan 14 2013 jjolly@suse.de
- s390/qeth: switch to ccwgroup_create_dev (bnc#790870).
- commit 10fda14
* Mon Jan 14 2013 jjolly@suse.de
- s390/claw: switch to ccwgroup_create_dev (bnc#790870).
- commit 46a60f3
* Mon Jan 14 2013 jjolly@suse.de
- s390/lcs: switch to ccwgroup_create_dev (bnc#790870).
- commit 36ff4fd
* Mon Jan 14 2013 jjolly@suse.de
- s390/ctcm: switch to ccwgroup_create_dev (bnc#790870).
- commit 344ae95
* Mon Jan 14 2013 jjolly@suse.de
- s390/ccwgroup: exploit ccwdev_by_dev_id (bnc#790870).
- commit 8eb1239
* Mon Jan 14 2013 jjolly@suse.de
- s390/ccwgroup: introduce ccwgroup_create_dev (bnc#790870).
- commit f284c2e
* Mon Jan 14 2013 jjolly@suse.de
- ccwgroup: cleanup (bnc#790870).
- commit 31358b8
* Mon Jan 14 2013 jjolly@suse.de
- revert patches.arch/ccwgroup-fix-uevent-vs-dev-attrs-race.patch
  (bnc#790870).
- commit 4ac3034
* Sat Jan 12 2013 jslaby@suse.cz
- Linux 3.0.58 (bnc#791853 bnc#791904).
- patches.kabi/0001-Revert-tcp-RFC-5961-5.2-Blind-Data-Injection-Attack-.patch:
  Revert "tcp: RFC 5961 5.2 Blind Data Injection Attack
  Mitigation".
- patches.kabi/0002-Revert-tcp-tcp_replace_ts_recent-should-not-be-calle.patch:
  Revert "tcp: tcp_replace_ts_recent() should not be called
  from tcp_validate_incoming()".
- patches.kabi/0003-Revert-tcp-refine-SYN-handling-in-tcp_validate_incom.patch:
  Revert "tcp: refine SYN handling in tcp_validate_incoming".
- patches.kabi/0004-Revert-tcp-implement-RFC-5961-4.2.patch:
  Revert "tcp: implement RFC 5961 4.2".
- patches.kabi/0005-Revert-tcp-implement-RFC-5961-3.2.patch:
  Revert "tcp: implement RFC 5961 3.2".
- patches.kabi/revert-bonding-Bonding-driver-does-not-consider-the-.patch:
  kABI: Revert "bonding: Bonding driver does not consider the
  gso_max_size/gso_max_segs setting of slave devices.".
- patches.drivers/0001-xhci-Add-Lynx-Point-LP-to-list-of-Intel-switchable-h.patch:
  Delete.
- patches.fixes/mm-limit-mmu_gather-batching-to-fix-soft-lockups-on-.patch:
  Delete.
- commit 3e4e79b
* Fri Jan 11 2013 dsterba@suse.cz
- patches.suse/btrfs-8186-continue-after-abort-during-snapshot-drop.patch:
  extend the error condition.
- commit eddac70
* Fri Jan 11 2013 duwe@suse.de
- powerpc: Implement PPR save/restore (bnc#795905,fate#314033).
- powerpc: Macros for saving/restore PPR (bnc#795905,fate#314033).
- powerpc: Define ppr in thread_struct (bnc#795905,fate#314033).
- powerpc: Increase exceptions arrays in paca struct to save PPR
  (bnc#795905,fate#314033).
- powerpc: Enable PPR save/restore (bnc#795905,fate#314033).
- powerpc: Move branch instruction from ACCOUNT_CPU_USER_ENTRY
  to caller (bnc#795905,fate#314033).
- commit d2db58f
* Fri Jan 11 2013 dsterba@suse.cz
- patches.suse/btrfs-8168-kill-obsolete-arguments-in-btrfs_wait_ordered_.patch:
  Refresh.
- commit 7ada4f9
* Fri Jan 11 2013 duwe@suse.de
- powerpc/iommu: Fix iommu pool initialization
  (bnc#795789,fate#314056 IBM:83657).
- powerpc/iommu: Fix multiple issues with IOMMU pools code
  (bnc#795789,fate#314056 IBM:83657).
- powerpc/iommu: Implement IOMMU pools to improve multiqueue
  adapter performan (bnc#795789,fate#314056 IBM:83657).
- powerpc/iommu: Push spinlock into iommu_range_alloc and
  __iommu_free (bnc#795789,fate#314056 IBM:83657).
- commit 88ea300
* Fri Jan 11 2013 duwe@suse.de
- powerpc/iommu: Reduce spinlock coverage in iommu_free
  (bnc#795789,fate#314056 IBM:83657).
- powerpc/pseries: Disable interrupts around IOMMU percpu data
  accesses (bnc#795789,fate#314056 IBM:83657).
- commit 11946bb
* Fri Jan 11 2013 duwe@suse.de
- powerpc/pseries/iommu: remove default window before attempting
  DDW manipulat (fate#314062,bnc#793678 IBM:82244).
- POWER7 optimised copy_to_user/copy_from_user using VMX
  (fate#314026,bnc#794537).
- commit f699b67
* Fri Jan 11 2013 bpoirier@suse.de
- RDMA/cxgb4: Use correct QID in insert_recv_cqe() (bnc#784800
  FATE#314296).
- commit d7d554e
* Fri Jan 11 2013 dsterba@suse.cz
- patches.suse/btrfs-8094-flush-all-the-dirty-pages-if-try_to_writeback_.patch:
  remove call to btrfs_wait_ordered_extents to avoid potential deadlock.
- commit c2bbee0
* Fri Jan 11 2013 bpoirier@suse.de
- Remove PTP from tg3
- Refresh
  patches.drivers/tg3-0103-tg3-Add-support-for-new-5762-ASIC.patch.
- Refresh
  patches.drivers/tg3-0104-tg3-Add-NVRAM-support-for-5762.patch.
- Refresh
  patches.drivers/tg3-0105-tg3-Improve-PCI-function-number-detection.patch.
- Delete
  patches.drivers/tg3-0098-tg3-PTP-Add-header-definitions-initialization-and-hw.patch.
- Delete
  patches.drivers/tg3-0099-tg3-PTP-Implement-the-ptp-api-and-ethtool-functions.patch.
- Delete
  patches.drivers/tg3-0100-tg3-PTP-Add-the-hardware-timestamp-ioctl.patch.
- Delete
  patches.drivers/tg3-0101-tg3-PTP-Enable-the-timestamping-feature-in-hardware-.patch.
- commit f683b6d
* Fri Jan 11 2013 hare@suse.de
- bnx2fc: Bumped version to 1.0.13 (FATE#313818,bnc#790595).
- bnx2fc: Support max IO size to 512KB (FATE#313818,bnc#790595).
- bnx2fc: Tx/Rx byte counts reset to 0 when exceeding 32 bit
  values (FATE#313818,bnc#790595).
- bnx2fc: Map the doorbell register between offload and enable
  requests (FATE#313818,bnc#790595).
- bnx2fc: Move offload/upload wait logic into a function
  (FATE#313818,bnc#790595).
- bnx2fc: support software fcoe target (FATE#313818,bnc#790595).
- bnx2fc: Remove potential NULL dereference
  (FATE#313818,bnc#790595).
- bnx2fc: remove useless calls to memset()
  (FATE#313818,bnc#790595).
- commit 64692fe
* Fri Jan 11 2013 jjolly@suse.de
- IB/mlx4: Configure extended active speeds.
- commit 8a9c665
* Fri Jan 11 2013 jjolly@suse.de
- mlx4_core: Add extended port capabilities support.
- commit d8ca2dd
* Fri Jan 11 2013 jjolly@suse.de
- IB: Add new InfiniBand link speeds.
- commit f13faf4
* Thu Jan 10 2013 jack@suse.cz
- patches.fixes/lib-radix-tree-fix-preload-vector-size.patch:
  radix-tree: fix preload vector size (bnc#763463).
- commit 25cb7f6
* Thu Jan 10 2013 bpoirier@suse.de
- tg3: Improve PCI function number detection (bnc#790588
  FATE#313912).
- tg3: Add NVRAM support for 5762 (bnc#790588 FATE#313912).
- tg3: Add support for new 5762 ASIC (bnc#790588 FATE#313912).
- ethernet/broadcom/tg3: Fix sparse warning: constant
  0x7fffffffffffffff is so big it is long long (bnc#790588
  FATE#313912).
- tg3: PTP - Enable the timestamping feature in hardware and
  fill skb tx/rx timestamps (bnc#790588 FATE#313912).
- tg3: PTP - Add the hardware timestamp ioctl (bnc#790588
  FATE#313912).
- tg3: PTP - Implement the ptp api and ethtool functions
  (bnc#790588 FATE#313912).
- tg3: PTP - Add header definitions, initialization and hw access
  functions (bnc#790588 FATE#313912).
- tg3: Fix inconsistent locking for tg3_netif_start() (bnc#790588
  FATE#313912).
- tg3: Use tp->rxq_cnt when checking RSS tables (bnc#790588
  FATE#313912).
- tg3: Cleanup hardcoded ethtool test array indexes (bnc#790588
  FATE#313912).
- tg3: Prevent spurious tx timeout by setting carrier off before
  tx disable (bnc#790588 FATE#313912).
- tg3: Set 10_100_ONLY flag for additional 10/100 Mbps devices
  (bnc#790588 FATE#313912).
- tg3: Call tg3_netif_stop() from tg3_stop() (bnc#790588
  FATE#313912).
- tg3: Support 5717 C0 (bnc#790588 FATE#313912).
- tg3: Fix sparse warnings (bnc#790588 FATE#313912).
- tg3: unconditionally select HWMON support when tg3 is enabled
  (bnc#790588 FATE#313912).
- tg3: Allow number of rx and tx rings to be set independently
  (bnc#790588 FATE#313912).
- netdev: make pci_error_handlers const (bnc#790588 FATE#313912).
- tg3: Use PCI Express Capability accessors (bnc#790588
  FATE#313912).
- tg3: Fix race condition in tg3_get_stats64() (bnc#790588
  FATE#313912).
- tg3: Add New 5719 Read DMA workaround (bnc#790588 FATE#313912).
- tg3: Fix Read DMA workaround for 5719 A0 (bnc#790588
  FATE#313912).
- tg3: Request APE_LOCK_PHY before PHY access (bnc#790588
  FATE#313912).
- tg3: Add hwmon support for temperature (bnc#790588 FATE#313912).
- tg3: Add APE scratchpad read function (bnc#790588 FATE#313912).
- tg3: Add common function tg3_ape_event_lock() (bnc#790588
  FATE#313912).
- tg3: Fix the setting of the APE_HAS_NCSI flag (bnc#790588
  FATE#313912).
- tg3: add device id of Apple Thunderbolt Ethernet device
  (bnc#790588 FATE#313912).
- tg3: remove redundant NULL test before release_firmware() call
  (bnc#790588 FATE#313912).
- Remove all #inclusions of asm/system.h (bnc#790588 FATE#313912).
- tg3: Recode PCI MRRS adjustment as a PCI quirk (bnc#790588
  FATE#313912).
- tg3: Add memory barriers to sync BD data (bnc#790588
  FATE#313912).
- tg3: Fix jumbo loopback test on 5719 (bnc#790588 FATE#313912).
- ethernet: unify return value of .ndo_set_mac_address if address
  is invalid (bnc#790588 FATE#313912).
- tg3: Create timer helper functions (bnc#790588 FATE#313912).
- tg3: Clear RECOVERY_PENDING with reset_task_cancel (bnc#790588
  FATE#313912).
- tg3: Remove SPEED_UNKNOWN checks (bnc#790588 FATE#313912).
- tg3: Fix link check in tg3_adjust_link (bnc#790588 FATE#313912).
- tg3: remove IRQF_SAMPLE_RANDOM flag (bnc#790588 FATE#313912).
- tg3: Update copyright (bnc#790588 FATE#313912).
- tg3: Use *_UNKNOWN ethtool definitions (bnc#790588 FATE#313912).
- tg3: Remove unneeded link_config.orig_... members (bnc#790588
  FATE#313912).
- tg3: Remove unused link config code (bnc#790588 FATE#313912).
- tg3: Consolidate ASIC rev detection code (bnc#790588
  FATE#313912).
- tg3: Reduce UMP event collision window (bnc#790588 FATE#313912).
- tg3: Fix NVRAM page writes on newer devices (bnc#790588
  FATE#313912).
- tg3: Fix copper autoneg adv checks (bnc#790588 FATE#313912).
- tg3: Fix stats while interface is down (bnc#790588 FATE#313912).
- tg3: Disable new DMA engine for 57766 (bnc#790588 FATE#313912).
- tg3: Move transmit comment to a better location (bnc#790588
  FATE#313912).
- tg3: Eliminate unneeded prototype (bnc#790588 FATE#313912).
- tg3: Relocate tg3_find_peer (bnc#790588 FATE#313912).
- tg3: Move tg3_nvram_write_block functions (bnc#790588
  FATE#313912).
- tg3: Move tg3_set_rx_mode (bnc#790588 FATE#313912).
- tg3: Move tg3_change_mtu to a better location (bnc#790588
  FATE#313912).
- tg3: Relocate tg3_reset_task (bnc#790588 FATE#313912).
- tg3: Move tg3_restart_hw to a better location (bnc#790588
  FATE#313912).
- drivers/net: Remove alloc_etherdev error messages (bnc#790588
  FATE#313912).
- tg3: Fix tg3_get_stats64 for 5700 / 5701 devs (bnc#790588
  FATE#313912).
- net: fix assignment of 0/1 to bool variables (bnc#790588
  FATE#313912).
- tg3: Make the RSS indir tbl admin configurable (bnc#790588
  FATE#313912).
- tg3: Break out RSS indir table init and assignment (bnc#790588
  FATE#313912).
- tg3: Use mii_advertise_flowctrl (bnc#790588 FATE#313912).
- tg3: Add 57766 ASIC rev support (bnc#790588 FATE#313912).
- tg3: Make the TX BD DMA limit configurable (bnc#790588
  FATE#313912).
- tg3: Enable EEE support for capable 10/100 devs (bnc#790588
  FATE#313912).
- tg3: Update version to 3.122 (bnc#790588 FATE#313912).
- tg3: Return flowctrl config through ethtool (bnc#790588
  FATE#313912).
- tg3: Track LP advertising (bnc#790588 FATE#313912).
- tg3: Integrate flowctrl check into AN adv check (bnc#790588
  FATE#313912).
- tg3: Save stats across chip resets (bnc#790588 FATE#313912).
- tg3: Remove ethtool stats member from dev struct (bnc#790588
  FATE#313912).
- tg3: Add MDI-X reporting (bnc#790588 FATE#313912).
- tg3: Restrict large prod ring cap devices (bnc#790588
  FATE#313912).
- tg3: Adjust BD replenish thresholds (bnc#790588 FATE#313912).
- tg3: Make 1000Base-X FC resolution look like 1000T (bnc#790588
  FATE#313912).
- tg3: Fix advertisement handling (bnc#790588 FATE#313912).
- net: Add ethtool to mii advertisment conversion helpers
  (bnc#790588 FATE#313912).
- sweep the floors and convert some .get_drvinfo routines to
  strlcpy (bnc#790588 FATE#313912).
- tg3: Update version to 3.121 (bnc#790588 FATE#313912).
- tg3: Eliminate timer race with reset_task (bnc#790588
  FATE#313912).
- tg3: Schedule at most one tg3_reset_task run (bnc#790588
  FATE#313912).
- tg3: Fix APE mutex init and use (bnc#790588 FATE#313912).
- |PATCH net-next] tg3: add tx_dropped counter (bnc#790588
  FATE#313912).
- net: add skb frag size accessors (bnc#790588 FATE#313912).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#790588 FATE#313912).
- net: use DMA_x_DEVICE and dma_mapping_error with
  skb_frag_dma_map (bnc#790588 FATE#313912).
- tg3: Code movement (bnc#790588 FATE#313912).
- tg3: Eliminate tg3_halt_cpu() prototype (bnc#790588
  FATE#313912).
- tg3: Eliminate tg3_write_sig_post_reset() prototype (bnc#790588
  FATE#313912).
- tg3: Eliminate tg3_stop_fw() prototype (bnc#790588 FATE#313912).
- tg3: Add ability to turn off 1shot MSI (bnc#790588 FATE#313912).
- tg3: Remove tp->rx_offset term when unneeded (bnc#790588
  FATE#313912).
- tg3: Fix missed MSI workaround (bnc#790588 FATE#313912).
- tg3: Check all adv bits when checking config (bnc#790588
  FATE#313912).
- tg3: convert to SKB paged frag API (bnc#790588 FATE#313912).
- tg3: Update version to 3.120 (bnc#790588 FATE#313912).
- tg3: Add external loopback support to selftest (bnc#790588
  FATE#313912).
- tg3: Restructure tg3_test_loopback (bnc#790588 FATE#313912).
- tg3: Pull phy int lpbk setup into separate func (bnc#790588
  FATE#313912).
- tg3: Consilidate MAC loopback code (bnc#790588 FATE#313912).
- tg3: Remove dead code (bnc#790588 FATE#313912).
- net: remove use of ndo_set_multicast_list in drivers (bnc#790588
  FATE#313912).
- commit 3682ea4
* Thu Jan 10 2013 bpoirier@suse.de
- broadcom: Move the Broadcom drivers (bnc#790588 FATE#313912).
- Update config files.
- commit a9f91ff
* Thu Jan 10 2013 jjolly@suse.de
- s390/scm_blk: add kmsg descriptions (bnc#792703,FATE#314095).
- commit 18822f9
* Thu Jan 10 2013 jjolly@suse.de
- s390/scm: reorder scm_remove (bnc#792703,FATE#314095).
- commit 0439fce
* Thu Jan 10 2013 jjolly@suse.de
- s390/scm: remove superfluous lock (bnc#792703,FATE#314095).
- commit 48ef1a8
* Thu Jan 10 2013 jjolly@suse.de
- s390/scm_block: force cluster writes (bnc#792703,FATE#314095).
- Update config files.
- commit 5d1b28c
* Thu Jan 10 2013 jjolly@suse.de
- s390: add scm block driver (bnc#792703,FATE#314095).
- Update config files.
- commit 9cd490f
* Thu Jan 10 2013 jjolly@suse.de
- s390/eadm_sch: add support for irq statistics
  (bnc#792703,FATE#314095).
- commit bd4d3e9
* Thu Jan 10 2013 jjolly@suse.de
- s390/cio: add eadm subchannel driver (bnc#792703,FATE#314095).
- Update config files.
- commit c434540
* Thu Jan 10 2013 jjolly@suse.de
- s390: add scm notification (bnc#792703,FATE#314095).
- commit b664ca6
* Thu Jan 10 2013 jjolly@suse.de
- s390: add scm bus driver (bnc#792703,FATE#314095).
- Update config files.
- commit 37602fd
* Thu Jan 10 2013 jjolly@suse.de
- s390/chsc: implement store SCM information
  (bnc#792703,FATE#314095).
- commit d988626
* Thu Jan 10 2013 jjolly@suse.de
- s390: add eadm related structures (bnc#792703,FATE#314095).
- commit 5f70bef
* Thu Jan 10 2013 jjolly@suse.de
- s390: add eadm facility bits (bnc#792703,FATE#314095).
- commit db0d49f
* Thu Jan 10 2013 jjolly@suse.de
- s390/css: export css_sched_sch_todo (bnc#792703,FATE#314095).
- commit 3361be7
* Thu Jan 10 2013 jjolly@suse.de
- hibernate: directly trigger subchannel evaluation
  (bnc#792703,FATE#314095).
- commit b431d5a
* Thu Jan 10 2013 duwe@suse.de
- Fix cut+paste error that broke compilation on power even when CONFIG_PSERIES_IDLE is not set.
- commit acaf889
* Thu Jan 10 2013 jjolly@suse.de
- Commit a60395f4 added LTC patchset #62, but the series.conf was not
  properly updated. This commit adds the correct references to
  series.conf (bnc#792656)
- commit 90774b9
* Thu Jan 10 2013 mmarek@suse.cz
- Drop 32bit PPC configs, they are not used in SLE11
- commit 31a2fd5
* Thu Jan 10 2013 jbeulich@suse.com
- x86, cacheinfo: Determine number of cache leafs usingCPUID
  0x8000001d on AMD (fate#314145 bnc#794648).
- Update EC2 config files.
- commit ca8696a
* Wed Jan  9 2013 bp@suse.de
- Correct AMD F16h patches to fit SUSE patch formatting
- Update
  patches.arch/0001-x86-cacheinfo-Determine-number-of-cache-leafs-using-.patch
  (fate#314145 bnc#794648).
- Update
  patches.arch/0002-x86-cacheinfo-Make-use-of-CPUID-0x8000001d-for-cache.patch
  (fate#314145 bnc#794648).
- Update
  patches.arch/0003-x86-cacheinfo-Base-cache-sharing-info-on-CPUID-0x800.patch
  (fate#314145 bnc#794648).
- commit 8dc1ca8
* Wed Jan  9 2013 mgorman@suse.de
- Delete
  patches.fixes/mm-compaction-capture-a-suitable-high-order-page-immediately-when-it-is-made-available.patch.
- Delete
  patches.fixes/mm-fix-incorrect-NR_FREE_PAGES-accounting-appears-like-memory-leak.patch.
- Refresh
  patches.fixes/mm-compaction-abort-compaction-loop-if-lock-is-contended-or-run-too-long.patch.
- Refresh
  patches.fixes/mm-compaction-acquire-the-zone--lock-as-late-as-possible.patch.
- Refresh
  patches.fixes/mm-compaction-clear-PG_migrate_skip-based-on-compaction-and-reclaim-activity.patch.
- Refresh
  patches.suse/mm-only-set-page--pfmemalloc-when-ALLOC_NO_WATERMARKS-was-used.patch.
  Benefit of capturing a page is marginal and there are issues with the implementation.
- commit a819ced
* Wed Jan  9 2013 mgalbraith@suse.de
- Another upstream throttle bugfix that never went to -stable.
- patches.fixes/sched-rt-Unthrottle-rt-runqueues-in-__disable_runtime.patch:
  sched, rt: Unthrottle rt runqueues in __disable_runtime().
- commit b54ac2a
* Wed Jan  9 2013 mgalbraith@suse.de
- Add upstream group scheduling starvation fix.
- patches.fixes/sched-rt-Fix-SCHED_RR-across-cgroups.patch:
  sched/rt: Fix SCHED_RR across cgroups.
- commit f71ae2e
* Wed Jan  9 2013 mgalbraith@suse.de
- Move fixes only present in the stable-rt tree to the parent
  tree.  They belong in both.
- patches.fixes/sched-Do-not-throttle-due-to-PI-boosting.patch:
  sched/rt: Do not throttle when PI boosting.
- patches.fixes/sched-Keep-period-timer-ticking-when-throttling-active.patch:
  sched/rt: Keep period timer ticking when rt throttling is active.
- patches.fixes/sched-prevent-idle-boost.patch:
  sched/rt: Prevent idle task boosting.
- commit 38c43b6
* Wed Jan  9 2013 hare@suse.de
- Remove duplicate call to blk_cleanup_queue() (FATE#313629).
- commit c3230c0
* Wed Jan  9 2013 mmarek@suse.cz
- Delete patches.kabi/* workarounds
- commit c287b10
* Tue Jan  8 2013 bpoirier@suse.de
- be2net: Update driver version (bnc#777565 FATE#313819).
- drivers/net: fix up function prototypes after __dev* removals
  (bnc#777565 FATE#313819).
- be2net: remove __dev* attributes (bnc#777565 FATE#313819).
- be2net: fix INTx ISR for interrupt behaviour on BE2 (bnc#777565
  FATE#313819).
- be2net: fix a possible events_get() race on BE2 (bnc#777565
  FATE#313819).
- net: Remove bogus dependencies on INET (bnc#777565 FATE#313819).
- be2net: remove adapter->eq_next_idx (bnc#777565 FATE#313819).
- be2net: remove roce on lancer (bnc#777565 FATE#313819).
- be2net: fix access to SEMAPHORE reg (bnc#777565 FATE#313819).
- be2net: re-factor bar mapping code (bnc#777565 FATE#313819).
- be2net: do not use sli_family to identify skyhawk-R chip
  (bnc#777565 FATE#313819).
- be2net: fix wrong usage of adapter->generation (bnc#777565
  FATE#313819).
- be2net: remove LANCER A0 workaround (bnc#777565 FATE#313819).
- be2net: Fix smatch warnings in be_main.c (bnc#777565
  FATE#313819).
- be2net: Fix skyhawk VF PCI Device ID (bnc#777565 FATE#313819).
- be2net: Fix FW flashing on Skyhawk-R (bnc#777565 FATE#313819).
- be2net: Enabling Wake-on-LAN is not supported in S5 state
  (bnc#777565 FATE#313819).
- be2net: Fix VF driver load on newer Lancer FW (bnc#777565
  FATE#313819).
- be2net: Fix unnecessary delay in PCI EEH (bnc#777565
  FATE#313819).
- be2net: Fix issues in error recovery due to wrong queue state
  (bnc#777565 FATE#313819).
- be2net: Fix ethtool get_settings output for VF (bnc#777565
  FATE#313819).
- be2net: Fix error messages while driver load for VFs (bnc#777565
  FATE#313819).
- be2net: Fix configuring VLAN for VF for Lancer (bnc#777565
  FATE#313819).
- be2net: Wait till resources are available for VF in error
  recovery (bnc#777565 FATE#313819).
- be2net: Fix change MAC operation for VF for Lancer (bnc#777565
  FATE#313819).
- be2net: Fix setting QoS for VF for Lancer (bnc#777565
  FATE#313819).
- be2net: Fix driver load failure for different FW configs in
  Lancer (bnc#777565 FATE#313819).
- be2net: Remove code that stops further access to BE NIC based
  on UE bits (bnc#777565 FATE#313819).
- be2net: fix vfs enumeration (bnc#777565 FATE#313819).
- be2net: fixup log messages (bnc#777565 FATE#313819).
- be2net: cleanup code related to be_link_status_query()
  (bnc#777565 FATE#313819).
- be2net: fix wrong handling of be_setup() failure in be_probe()
  (bnc#777565 FATE#313819).
- be2net: remove type argument of be_cmd_mac_addr_query()
  (bnc#777565 FATE#313819).
- Revert "be2net: fix vfs enumeration" (bnc#777565 FATE#313819).
- be2net: fix vfs enumeration (bnc#777565 FATE#313819).
- netdev: make pci_error_handlers const (bnc#777565 FATE#313819).
- be2net: use PCIe AER capability (bnc#777565 FATE#313819).
- be2net: modify log msg for lack of privilege error (bnc#777565
  FATE#313819).
- be2net: fixup malloc/free of adapter->pmac_id (bnc#777565
  FATE#313819).
- be2net: fix FW default for VF tx-rate (bnc#777565 FATE#313819).
- be2net: fix max VFs reported by HW (bnc#777565 FATE#313819).
- be2net: create RSS rings even in multi-channel configs
  (bnc#777565 FATE#313819).
- netpoll: revert 6bdb7fe3104 and fix be_poll() instead
  (bnc#777565 FATE#313819).
- emulex: benet: Add a missing CR in the end of message
  (bnc#777565 FATE#313819).
- be2net: Fix to parse RSS hash from Receive completions correctly
  (bnc#777565 FATE#313819).
- be2net: Missing byteswap in be_get_fw_log_level causes oops
  on PowerPC (bnc#777565 FATE#313819).
- be2net: Ignore physical link async event for Lancer (bnc#777565
  FATE#313819).
- be2net: Fix VF driver load for Lancer (bnc#777565 FATE#313819).
- be2net: dont pull too much data in skb linear part (bnc#777565
  FATE#313819).
- be2net: Add description about various RSS hash types (bnc#777565
  FATE#313819).
- be2net: Enable RSS UDP hashing for Lancer and Skyhawk
  (bnc#777565 FATE#313819).
- be2net: Fix port name in message during driver load (bnc#777565
  FATE#313819).
- be2net: Fix cleanup path when EQ creation fails (bnc#777565
  FATE#313819).
- be2net: Activate new FW after FW download for Lancer (bnc#777565
  FATE#313819).
- be2net: Fix initialization sequence for Lancer (bnc#777565
  FATE#313819).
- be2net : Fix die temperature stat for Lancer (bnc#777565
  FATE#313819).
- be2net: Fix error while toggling autoneg of pause parameters
  (bnc#777565 FATE#313819).
- be2net: Fix Endian (bnc#777565 FATE#313819).
- be2net: set maximal number of default RSS queues (bnc#777565
  FATE#313819).
- be2net: Fix to trim skb for padded vlan packets to workaround
  an ASIC Bug (bnc#777565 FATE#313819).
- be2net: Regression bug wherein VFs creation broken for multiple
  cards (bnc#777565 FATE#313819).
- be2net: Explicitly clear the reserved field in the Tx Descriptor
  (bnc#777565 FATE#313819).
- be2net: Increase statistics structure size for skyhawk
  (bnc#777565 FATE#313819).
- be2net: Modify error message to incorporate subsystem
  (bnc#777565 FATE#313819).
- be2net: reduce gso_max_size setting to account for ethernet
  header (bnc#777565 FATE#313819).
- be2net: Fix driver load for VFs for Lancer (bnc#777565
  FATE#313819).
- be2net: do not use SCRATCHPAD register (bnc#777565 FATE#313819).
- be2net: remove unnecessary usage of unlikely() (bnc#777565
  FATE#313819).
- be2net: fix reporting number of actual rx queues (bnc#777565
  FATE#313819).
- be2net: do not modify PCI MaxReadReq size (bnc#777565
  FATE#313819).
- be2net: cleanup be_vid_config() (bnc#777565 FATE#313819).
- be2net: don't call vid_config() when there's no vlan config
  (bnc#777565 FATE#313819).
- be2net: Fix to allow get/set of debug levels in the firmware
  (bnc#777565 FATE#313819).
- be2net: avoid disabling sriov while VFs are assigned (bnc#777565
  FATE#313819).
- be2net: Add functionality to support RoCE driver (bnc#777565
  FATE#313819).
- be2net: Add function to issue mailbox cmd on MQ (bnc#777565
  FATE#313819).
- be2net: Record receive queue index in skb to aid RPS (bnc#777565
  FATE#313819).
- be2net: Fix to apply duplex value as unknown when link is down
  (bnc#777565 FATE#313819).
- be2net: Fix to not set link speed for disabled functions of
  a UMC card (bnc#777565 FATE#313819).
- be2net: fix speed displayed by ethtool on certain SKUs
  (bnc#777565 FATE#313819).
- be2net: Ignore status of some ioctls during driver load
  (bnc#777565 FATE#313819).
- be2net: Fix FW download for BE (bnc#777565 FATE#313819).
- be2net: Fix wrong status getting returned for MCC commands
  (bnc#777565 FATE#313819).
- be2net: Fix Lancer statistics (bnc#777565 FATE#313819).
- be2net: Fix traffic stall INTx mode (bnc#777565 FATE#313819).
- be2net: Fix ethtool self test for Lancer (bnc#777565
  FATE#313819).
- be2net: Fix FW download in Lancer (bnc#777565 FATE#313819).
- be2net: Fix VLAN/multicast packet reception (bnc#777565
  FATE#313819).
- be2net: fix ethtool get settings (bnc#777565 FATE#313819).
- be2net: fix programming of VLAN tags for VF (bnc#777565
  FATE#313819).
- be2net: Fix number of vlan slots in flex mode (bnc#777565
  FATE#313819).
- be2net: Program secondary UC MAC address into MAC filter
  (bnc#777565 FATE#313819).
- be2net: enable WOL by default if h/w supports it (bnc#777565
  FATE#313819).
- be2net: Remove unused OFFSET_IN_PAGE() macro (bnc#777565
  FATE#313819).
- be2net: enable RSS for ipv6 pkts (bnc#777565 FATE#313819).
- be2net: reset queue address after freeing (bnc#777565
  FATE#313819).
- be2net: fix tx completion cleanup (bnc#777565 FATE#313819).
- be2net: cancel be_worker during EEH recovery (bnc#777565
  FATE#313819).
- be2net: event queue re-design (bnc#777565 FATE#313819).
- be2net: Use new implementation of get mac list command
  (bnc#777565 FATE#313819).
- be2net: Fix link status query command (bnc#777565 FATE#313819).
- ethtool: Null-terminate filename passed to
  ethtool_ops::flash_device (bnc#777565 FATE#313819).
- be2net: add descriptions for stat counters reported via ethtool
  (bnc#777565 FATE#313819).
- be2net: allocate more headroom in incoming skbs (bnc#777565
  FATE#313819).
- be2net: create RSS rings even in multi-channel configs
  (bnc#777565 FATE#313819).
- netdev: make net_device_ops const (bnc#777565 FATE#313819).
- be2net: query link status in be_open() (bnc#777565 FATE#313819).
- be2net: fix range check for set_qos for a VF (bnc#777565
  FATE#313819).
- be2net: Fix INTx processing for Lancer (bnc#777565 FATE#313819).
- be2net: Add support for Skyhawk cards (bnc#777565 FATE#313819).
- be2net: refactor/cleanup vf configuration code (bnc#777565
  FATE#313819).
- be2net: fix ethtool ringparam reporting (bnc#777565
  FATE#313819).
- be2net: workaround to fix a bug in BE (bnc#777565 FATE#313819).
- be2net: update some counters to display via ethtool (bnc#777565
  FATE#313819).
- be2net: netpoll support (bnc#777565 FATE#313819).
- be2net: Fix non utilization of RX queues (bnc#777565
  FATE#313819).
- be2net: Use new hash key (bnc#777565 FATE#313819).
- be2net: Add error handling for Lancer (bnc#777565 FATE#313819).
- be2net: Fix error recovery paths (bnc#777565 FATE#313819).
- be2net: Move to new SR-IOV implementation in Lancer (bnc#777565
  FATE#313819).
- be2net: Use V1 query link status command for lancer (bnc#777565
  FATE#313819).
- be2net: Fix VLAN promiscous mode for Lancer (bnc#777565
  FATE#313819).
- be2net: Add EEPROM dump feature for Lancer (bnc#777565
  FATE#313819).
- be2net: add register dump feature for Lancer (bnc#777565
  FATE#313819).
- be2net: Fix TX queue create for Lancer (bnc#777565 FATE#313819).
- be2net: stop issuing FW cmds if any cmd times out (bnc#777565
  FATE#313819).
- be2net: don't log more than one error on detecting EEH/UE errors
  (bnc#777565 FATE#313819).
- be2net: stop checking the UE registers after an EEH error
  (bnc#777565 FATE#313819).
- be2net: init (vf)_if_handle/vf_pmac_id to handle failure
  scenarios (bnc#777565 FATE#313819).
- sweep the floors and convert some .get_drvinfo routines to
  strlcpy (bnc#777565 FATE#313819).
- be2net: Add detect UE feature for Lancer (bnc#777565
  FATE#313819).
- be2net: Prevent CQ full condition for Lancer (bnc#777565
  FATE#313819).
- be2net: Fix disabling multicast promiscous mode (bnc#777565
  FATE#313819).
- be2net: Fix endian issue in RX filter command (bnc#777565
  FATE#313819).
- drivers/net: Add module.h to drivers who were implicitly using
  it (bnc#777565 FATE#313819).
- be2net: Changing MAC Address of a VF was broken (bnc#777565
  FATE#313819).
- be2net: Refactored be_cmds.c file (bnc#777565 FATE#313819).
- be2net: don't create multiple RX/TX rings in multi channel mode
  (bnc#777565 FATE#313819).
- be2net: refactor VF setup/teardown code into be_vf_setup/clear()
  (bnc#777565 FATE#313819).
- be2net: add vlan/rx-mode/flow-control config to be_setup()
  (bnc#777565 FATE#313819).
- net: add skb frag size accessors (bnc#777565 FATE#313819).
- be2net: fix truesize errors (bnc#777565 FATE#313819).
- commit eb9c6bb
* Tue Jan  8 2013 bpoirier@suse.de
- be2net: Move the Emulex driver (bnc#777565 FATE#313819).
- Update config files.
- commit cf11490
* Tue Jan  8 2013 jeffm@suse.com
- supported.conf: Mark jfs.ko unsupported (FATE#314422).
- commit 9c0a77c
* Tue Jan  8 2013 mhocko@suse.cz
- patches.fixes/mm-limit-mmu_gather-batching-to-fix-soft-lockups-on-.patch:
  mm: limit mmu_gather batching to fix soft lockups on
  !CONFIG_PREEMPT (bnc#791904).
- patches.kabi/mm-limit-mmu_gather-batching-to-fix-soft-lockups-on-kabi.patch:
  kabi fixup for mm: limit mmu_gather batching to fix soft
  lockups on !CONFIG_PREEMPT (bnc#791904).
- commit 83fd276
* Tue Jan  8 2013 jjolly@suse.de
- kdump: Add kmsg descriptions for kdump (bnc#786471).
- commit 50bf094
* Tue Jan  8 2013 mgorman@suse.de
- patches.fixes/mm-compaction-Abort-async-compaction-if-locks-are-contended-or-taking-too-long.patch:
  mm: compaction: Abort async compaction if locks are contended or taking too long.
- patches.fixes/mm-compaction-abort-compaction-loop-if-lock-is-contended-or-run-too-long.patch:
  mm: compaction: abort compaction loop if lock is contended or run too long.
- patches.fixes/mm-compaction-acquire-the-zone--lock-as-late-as-possible.patch:
  mm: compaction: acquire the zone->lock as late as possible.
- patches.fixes/mm-compaction-acquire-the-zone--lru_lock-as-late-as-possible.patch:
  mm: compaction: acquire the zone->lru_lock as late as possible.
- patches.fixes/mm-compaction-move-fatal-signal-check-out-of-compact_checklock_irqsave.patch:
  mm: compaction: move fatal signal check out of compact_checklock_irqsave.
  Reduce LRU and zone lock contention when compacting memory for THP (bnc#796823).
- commit 017ef1c
* Tue Jan  8 2013 jbeulich@suse.com
- Refresh Xen patches after update to 3.0.57.
- commit 53d0e24
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix local access validation for user MRs
  (bnc#780244,FATE#314303).
- commit 9642b74
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Add a qib driver version (bnc#780244,FATE#314303).
- commit bb00457
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix failure of compliance test C14-024#06_LocalPortNum
  (bnc#780244,FATE#314303).
- commit 110ea33
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix error return code in qib_init_7322_variables()
  (bnc#780244,FATE#314303).
- commit 994a697
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix size of cc_supported_table_entries
  (bnc#780244,FATE#314303).
- commit 87505d9
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: checkpatch fixes (bnc#780244,FATE#314303).
- commit 946623e
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Add congestion control agent implementation
  (bnc#780244,FATE#314303).
- commit b665870
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Reduce sdma_lock contention (bnc#780244,FATE#314303).
- commit dca09f7
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix an incorrect log message (bnc#780244,FATE#314303).
- commit 53d0d6d
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix QP RCU sparse warnings (bnc#780244,FATE#314303).
- commit 2b7a53e
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix sparse RCU warnings in qib_keys.c
  (bnc#780244,FATE#314303).
- commit 48c1f65
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: RCU locking for MR validation (bnc#780244,FATE#314303).
- commit d165550
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Avoid returning EBUSY from MR deregister
  (bnc#780244,FATE#314303).
- commit a46cdd3
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix UC MR refs for immediate operations
  (bnc#780244,FATE#314303).
- commit 22329a2
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Add cache line awareness to qib_qp and qib_devdata
  structures (bnc#780244,FATE#314303).
- commit ed35918
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: MADs with misset M_Keys should return failure
  (bnc#780244,FATE#314303).
- commit 1d91db7
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix M_Key lease timeout handling
  (bnc#780244,FATE#314303).
- commit cdfadc5
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix QLE734X link cycling (bnc#780244,FATE#314303).
- commit 17c5f48
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Display correct value for number of contexts
  (bnc#780244,FATE#314303).
- commit c1864ad
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Correct ordering of reregister vs. port active events
  (bnc#780244,FATE#314303).
- commit c229391
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Optimize pio ack buffer allocation
  (bnc#780244,FATE#314303).
- commit 1e93263
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Add prefetch for eager buffers (bnc#780244,FATE#314303).
- commit 0829c89
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Avoid filtering LID on SMA portinfo
  (bnc#780244,FATE#314303).
- commit 503a522
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Add logic for affinity hint (bnc#780244,FATE#314303).
- commit c2ec937
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Roll back PCIe tuning change (bnc#780244,FATE#314303).
- commit 91f02b8
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Use GFP_ATOMIC when locks are held
  (bnc#780244,FATE#314303).
- commit 8bd115e
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Default some module parameters optimally
  (bnc#780244,FATE#314303).
- commit dd5c536
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Optimize locking for get_txreq()
  (bnc#780244,FATE#314303).
- commit d1c5e14
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Eliminate 64-bit jiffies use (bnc#780244,FATE#314303).
- commit cd6b96f
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix style issues (bnc#780244,FATE#314303).
- commit db90285
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Correct sense on freectxts increment and decrement
  (bnc#780244,FATE#314303).
- commit ee70224
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix over-scheduling of QSFP work
  (bnc#780244,FATE#314303).
- commit f49ffc8
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Don't use schedule_work() (bnc#780244,FATE#314303).
- commit b3ab3b6
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix panic in RC error flushing logic
  (bnc#780244,FATE#314303).
- commit 477fe54
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix issue with link states and QSFP cables
  (bnc#780244,FATE#314303).
- commit 1deee4e
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Hold links until tuning data is available
  (bnc#780244,FATE#314303).
- commit e8a0ac0
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Clean up checkpatch issue (bnc#780244,FATE#314303).
- commit 55ae6cb
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Remove s_lock around header validation
  (bnc#780244,FATE#314303).
- commit 6115204
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Precompute timeout jiffies to optimize latency
  (bnc#780244,FATE#314303).
- commit ed7aa14
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Use RCU for qpn lookup (bnc#780244,FATE#314303).
- commit e6f44b1
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Eliminate divide/mod in converting idx to egr buf
  pointer (bnc#780244,FATE#314303).
- commit cd85016
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Decode path MTU optimization (bnc#780244,FATE#314303).
- commit e8992df
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Optimize RC/UC code by IB operation
  (bnc#780244,FATE#314303).
- commit a405cb8
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Correct nfreectxts for multiple HCAs
  (bnc#780244,FATE#314303).
- commit 503490b
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Defer HCA error events to tasklet
  (bnc#780244,FATE#314303).
- commit f8b5bbd
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Update active link width (bnc#780244,FATE#314303).
- commit 4cf13e4
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Fix potential deadlock with link down interrupt
  (bnc#780244,FATE#314303).
- commit 421414e
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Add sysfs interface to read free contexts
  (bnc#780244,FATE#314303).
- commit 9a3eb6b
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Remove double define (bnc#780244,FATE#314303).
- commit d8617cd
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Remove unnecessary read of PCI_CAP_ID_EXP
  (bnc#780244,FATE#314303).
- commit fb3e56c
* Tue Jan  8 2013 jjolly@suse.de
- IB/qib: Convert old cpumask api into new one
  (bnc#780244,FATE#314303).
- commit 1adf41b
* Mon Jan  7 2013 jjolly@suse.de
- dasd: add kmsg descriptions (bnc#791717,FATE#314091).
- commit 1916c34
* Mon Jan  7 2013 jjolly@suse.de
- dasd: Fix resume path verification (bnc#791717,FATE#314091).
- Refresh patches.suse/dasd-fail-all-requests-after-timeout.patch.
- commit 02ae8af
* Mon Jan  7 2013 jjolly@suse.de
- dasd: fix unaccessible device after resume
  (bnc#791717,FATE#314091).
- commit 9e95a42
* Mon Jan  7 2013 jjolly@suse.de
- dasd: add sanity check to detect path connection error
  (bnc#791717,FATE#314091).
- commit 3ac3260
* Mon Jan  7 2013 bpetkov@suse.de
- x86, cacheinfo: Base cache sharing info on CPUID  0x8000001d
  on AMD.
- x86, cacheinfo: Make use of CPUID 0x8000001d for cache
  information on AMD.
- x86, cacheinfo: Determine number of cache leafs using  CPUID
  0x8000001d on AMD.
- commit 53e8d30
* Mon Jan  7 2013 ohering@suse.de
- force ws2008 during vmbus negotiation.
- commit 920f7e4
* Mon Jan  7 2013 hare@suse.de
- mptfusion: Bump driver vesion to v4.28.00.01suse (bnc#784805,
  FATE#313895).
- mptfusion: unlock on error in mpt_config() (bnc#784805,
  FATE#313895).
- mptsas: Add device ID for SAS1068_820XELP (bnc#784805,
  FATE#313895).
- mptfusion: Added check for SILI bit in READ_16 CDB for DATA
  UNDERRUN ERRATA (bnc#784805, FATE#313895).
- commit 29a8436
* Fri Jan  4 2013 bpoirier@suse.de
- net: do not take an additional reference in skb_frag_set_page
  (bnc#784800 FATE#314296).
- commit 2a1f9f2
* Fri Jan  4 2013 bpoirier@suse.de
- pci: Add flag indicating device has been assigned by KVM
  (bnc#777565 FATE#313819).
- commit 3db1a5e
* Fri Jan  4 2013 duwe@suse.de
- Update config files.
- commit dd805a6
* Fri Jan  4 2013 duwe@suse.de
- powerpc/cpuidle: Use pm_idle to call on to cpuidle framework
  (fate#314019,bnc#795230).
- cpuidle/powerpc: Fix snooze state problem in the cpuidle design
  on pseries (fate#314019,bnc#795230).
- cpuidle/powerpc: Fix smt_snooze_delay functionality
  (fate#314019,bnc#795230).
- cpuidle/powerpc: Fix target residency initialisation in pseries
  cpuidle (fate#314019,bnc#795230).
- powerpc/cpuidle: Fixes for pseries_idle hotplug notifier
  (fate#314019,bnc#795230).
- powerpc/pseries/cpuidle: Replace pseries_notify_cpuidle_add
  call with notifier (fate#314019,bnc#795230).
- powerpc: Fix broken cpu_idle_wait() implementation
  (fate#314019,bnc#795230).
- powerpc/cpuidle: Make it a bool, not a tristate
  (fate#314019,bnc#795230).
- powerpc/cpuidle: Handle power_save=off (fate#314019,bnc#795230).
- powerpc/cpuidle: Enable cpuidle and directly call
  cpuidle_idle_call() for pSeries (fate#314019,bnc#795230).
- powerpc/cpuidle: cpuidle driver for pSeries
  (fate#314019,bnc#795230).
- powerpc/cpuidle: Add cpu_idle_wait() to allow switching of
  idle routines (fate#314019,bnc#795230).
- commit b5bd7a4
* Fri Jan  4 2013 mgorman@suse.de
- Refresh
  patches.suse/ia64-mm-wire-up-cross-memory-attach-syscalls.patch.
- commit dd23cae
* Fri Jan  4 2013 jjolly@suse.de
- perf: Add kmsg descriptions (bnc#790713,FATE#314094).
- commit c3679f9
* Fri Jan  4 2013 jjolly@suse.de
- perf_cpum_cf: Add support for counters available with IBM zEC12
  (bnc#790713,FATE#314094).
- Refresh
  patches.suse/intel-perf-event-0054-perf-arch-rework-perf_event_index.patch.
- commit 869fbdb
* Fri Jan  4 2013 jjolly@suse.de
- cpum_cf: get rid of compile warnings (bnc#790713,FATE#314094).
- commit 2e2eefa
* Fri Jan  4 2013 jjolly@suse.de
- perf: add support for s390x CPU counters
  (bnc#790713,FATE#314094).
- Refresh
  patches.suse/intel-perf-event-0054-perf-arch-rework-perf_event_index.patch.
- commit 6d09978
* Fri Jan  4 2013 jjolly@suse.de
- oprofile: Allow multiple users of the measurement alert
  interrupt (bnc#790713,FATE#314094).
- commit 7e638a7
* Fri Jan  4 2013 mmarek@suse.cz
- Refresh
  patches.drivers/0021-isci-oem-parameter-format-v1.1-ssc-select.patch
  to match the upstream commit
- Delete
  patches.drivers/0152-isci-fix-isci_pci_probe-generates-warning-on-efi-fai.patch,
  as the commit is in stable already.
- commit 2ff34dd
* Fri Jan  4 2013 mkubecek@suse.cz
- patches.kernel.org/patch-3.0.55-56: Update references
  (add bnc#778136).
- commit 4ded12f
* Fri Jan  4 2013 tiwai@suse.de
- ALSA: hda - bug fix for invalid connection list of Haswell
  HDMI codec pins (FATE#313695).
- ALSA: hda - Always turn on pins for HDMI/DP (FATE#313695).
- commit 98ba624
* Fri Jan  4 2013 jjolly@suse.de
- drivers/s390/block/dasd_ioctl.c: add missing kfree (bnc#790513).
- commit 7171d13
* Fri Jan  4 2013 jjolly@suse.de
- dasd: use vmalloc for statistics input buffer
  (bnc#790513,FATE#314075).
- commit a740df1
* Fri Jan  4 2013 jjolly@suse.de
- dasd: add enhanced DASD statistics interface
  (bnc#790513,FATE#314075).
- commit 2376851
* Fri Jan  4 2013 jjolly@suse.de
- s390/kernel: Introduce memcpy_absolute() function
  (bnc#789799,FATE#314098).
- commit 49e0263
* Fri Jan  4 2013 jjolly@suse.de
- s390: allow absolute memory access for /dev/mem
  (bnc#789799,FATE#314098).
- commit 9407d54
* Fri Jan  4 2013 jjolly@suse.de
- zfcp: Bounds checking for deferred error trace
  (bnc#790512,FATE#312255).
- commit 6bdfe8b
* Fri Jan  4 2013 jjolly@suse.de
- zfcp: support for hardware data router (bnc#790512,FATE#312255).
- commit f94a67b
* Fri Jan  4 2013 jjolly@suse.de
- qdio: base support for hardware data router with zfcp
  (bnc#790512,FATE#312255).
- commit f5b79c4
* Fri Jan  4 2013 lduncan@suse.de
- qla4xxx: v5.03.00.00.11.3-k1 (bnc#796370).
- qla4xxx: Correct the validation to check in get_sys_info mailbox
  (bnc#796370).
- qla4xxx: Pass correct function param to qla4_8xxx_rd_direct
  (bnc#796370).
- qla4xxx: Fix memory corruption issue in qla4xxx_get_ep_fwdb
  (bnc#796370).
- qla4xxx: Allow reset in link down case (bnc#796370).
- qla4xxx: Fix MBOX intr switching from polling to intr mode
  for ISP83XX (bnc#796370).
- commit d469803
* Thu Jan  3 2013 bpoirier@suse.de
- Refresh patches.drivers/drivers-net-Remove-casts-of-void.patch.
- commit a552d8b
* Thu Jan  3 2013 ohering@suse.de
- supported.conf: mark virtio_scsi as supported (fate#314135)
- commit b71d4c3
* Wed Jan  2 2013 jslaby@suse.cz
- Linux 3.0.57 (bnc#762158).
- patches.drivers/0001-USB-OHCI-workaround-for-hardware-bug-retired-TDs-not.patch:
  Delete.
- patches.drivers/USB3-0157-usb-xhci-refactor-xhci_pci_setup.patch:
  Refresh.
- patches.fixes/tmpfs-distribute-interleave-better-across-nodes.patch:
  Refresh.
- commit b6bcd75
* Wed Jan  2 2013 jslaby@suse.cz
- Linux 3.0.56 (bnc#758104 bnc#789993).
- patches.fixes/workqueue_exit_rescuer_thread_as_TASK_RUNNING.patch:
  Delete.
- patches.suse/scsi-silence-ioctl-warnings.patch: Delete.
- patches.fixes/net-prevent-NULL-dereference-in-check_peer_redir.patch:
  Refresh.
- patches.kabi/revert-net-fix-NULL-dereferences-in-check_peer_redir.patch:
  Refresh.
- commit 58e2e9a
* Wed Jan  2 2013 jslaby@suse.cz
- Linux 3.0.55.
- commit 572c76d
* Wed Jan  2 2013 jslaby@suse.cz
- Linux 3.0.54 (bnc#790935 bnc#745876 bnc#791498 fate#314145).
- patches.arch/x86_amd_fam16h_microcode_fix.patch: Delete.
- patches.arch/x86_thermal_throttle_avoid_fake_mces.patch: Delete.
- patches.fixes/jbd-Fix-lock-ordering-bug-in-journal_unmap_buffer.patch:
  Delete.
- commit 68c8e06
* Wed Jan  2 2013 jlee@suse.com
- Refresh Git-commit and Patch-mainlin tag of UEFI variable filesystem
  patches
- Refresh
  patches.drivers/0003-efi-Add-support-for-a-UEFI-variable-filesystem.patch.
- Refresh
  patches.drivers/0004-efi-Handle-deletions-and-size-changes-in-efivarfs_w.patch.
- Refresh
  patches.drivers/0005-efi-add-efivars-kobject-to-efi-sysfs-folder.patch.
- Refresh
  patches.drivers/0006-efivarfs-Add-documentation-for-the-EFI-variable-fil.patch.
- Refresh
  patches.drivers/0007-efivarfs-efivarfs_file_read-ensure-we-free-data-in.patch.
- Refresh
  patches.drivers/0008-efivarfs-efivarfs_create-ensure-we-drop-our-refer.patch.
- Refresh
  patches.drivers/0009-efivarfs-efivarfs_fill_super-fix-inode-reference.patch.
- Refresh
  patches.drivers/0010-efivarfs-efivarfs_fill_super-ensure-we-free-our-t.patch.
- Refresh
  patches.drivers/0011-efivarfs-efivarfs_fill_super-ensure-we-clean-up-c.patch.
- Refresh
  patches.drivers/0012-efivarfs-Implement-exclusive-access-for-get-set-_v.patch.
- commit 03a410f
* Thu Dec 27 2012 rgoldwyn@suse.de
- patches.fixes/aio-make-kiocb-private-NULL-in-init_sync_kiocb:
  aio: make kiocb->private NUll in init_sync_kiocb() (bnc#794231).
- commit eda41cb
* Thu Dec 27 2012 dsterba@suse.cz
- Refresh
  patches.suse/btrfs-0395-fix-compiler-warnings-on-32-bit-systems.patch.
- Refresh
  patches.suse/btrfs-0618-remove-redundant-r-o-check-for-superblock.patch.
- Refresh
  patches.suse/btrfs-0644-add-helper-for-tree-enumeration.patch.
- Delete
  patches.suse/btrfs-0619-use-mnt_want_write_file-instead-of-mnt_want_wr.patch.
- commit f2d8491
* Thu Dec 27 2012 dsterba@suse.cz
- patches.suse/btrfs-_add_reloc_root-error-push-up: Refresh.
- patches.suse/btrfs-clean_tree_block-should-panic-on-error-and-return-void:
  Refresh.
- patches.suse/btrfs-handle-EIO: Refresh.
- patches.suse/btrfs-8119-fix-error-handling-in-__add_reloc_root.patch:
  Refresh.
- commit a7bec86
* Thu Dec 27 2012 jjolly@suse.de
- patches.arch/s390-62-01-qeth_fix_retries_on_hardsetup.patch:
  qeth: Fix retry logic in hardsetup (bnc#792656,LTC#87080).
- patches.arch/s390-62-02-netiucv_fix_device_naming.patch:
  netiucv: reinsert dev_alloc_name for device naming
  (bnc#792656,LTC#87086).
- patches.arch/s390-62-03-qeth-mac-cb.patch: qeth: set new mac
  even if old mac is gone (2) (bnc#792656,LTC#87138).
- commit a60395f
* Thu Dec 27 2012 rgoldwyn@suse.de
- patches.fixes/ocfs2-use-spinlock-irqsave-for-downconvert-lock.patch:
  ocfs2: use spinlock irqsave for downconvert lock.patch
  (bnc#794824).
- commit b073a01
* Mon Dec 24 2012 bpoirier@suse.de
- Refresh
  patches.drivers/0026-qlcnic-fix-cdrp-race-condition.patch.
- Refresh patches.drivers/0029-qlcnic-Change-CDRP-function.patch.
- Refresh patches.drivers/drivers-net-Remove-casts-of-void.patch.
- Delete
  patches.drivers/0001-drivers-net-Remove-casts-of-void.patch.
- Delete
  patches.drivers/0003-drivers-net-netxen-Remove-casts-of-void.patch.
- Delete
  patches.drivers/cxgb3-0001-drivers-net-Remove-casts-of-void.patch.
- commit aad2bc8
* Fri Dec 21 2012 bpoirier@suse.de
- Move the broadcom network driver patches from the iscsi to the network section
  ... in preparation for the forthcoming driver updates
- Refresh
  patches.drivers/0008-bnx2fc-Handle-NETDEV_UNREGISTER-for-vlan-devices.patch.
- Refresh
  patches.drivers/0335-New-7.0-FW-bnx2x-cnic-bnx2i-bnx2fc.patch.
- Refresh
  patches.drivers/bnx2fc-Introduce-interface-structure-for-each-vlan.patch.
- Refresh
  patches.drivers/cnic-Add-VLAN-ID-as-a-parameter-during-netevent-upca.patch.
- Refresh
  patches.drivers/cxgb4-0007-ethtool-Centralise-validation-of-ETHTOOL_-G-S-RXFHIN.patch.
- Refresh
  patches.drivers/netdev-FCoE-Add-new-ndo_get_fcoe_hbainfo-call.patch.
- Refresh
  patches.fixes/net-dev-define-NETDEV_FCOE_WWNN-only-when-LIBFCOE-enabled.
- commit 38d893a
* Fri Dec 21 2012 rgoldwyn@suse.de
- patches.fixes/af_netlink-force-credentials-passing: af_netlink:
  force credentials passing (bnc#779577).
- patches.fixes/af_unix-dnt-send-SCM_CREDENTIALS-by-default:
  af_unix: dont send SCM_CREDENTIALS by default (bnc#779577).
- commit 278f1eb
* Thu Dec 20 2012 bpoirier@suse.de
- drivers/net: Remove casts of void * (bnc#697255).
- net: Remove unneeded version.h includes from drivers/net/
  (bnc#697255).
- Refresh
  patches.drivers/cxgb3-0004-chelsio-Move-the-Chelsio-drivers.patch.
- Delete
  patches.drivers/0003-drivers-net-Remove-casts-of-void.patch.
- commit 8bca017
* Thu Dec 20 2012 brogers@suse.com
- KVM: VMX: Implement PCID/INVPCID for guests with EPT
  (fate#313826).
- x86, cpufeature: Add CPU features from Intel document
  319433-012A (fate#313826).
- x86, cpu: Add cpufeature flag for PCIDs (fate#313826).
- KVM: SVM: Add support for AMD's OSVW feature in guests
  (fate#314217).
- KVM: Mask function7 ebx against host capability word9
  (fate#313826).
- KVM: Add SMEP support when setting CR4 (fate#313826).
- KVM: Remove SMEP bit from CR4_RESERVED_BITS (fate#313826).
- commit 919ceb5
* Thu Dec 20 2012 duwe@suse.de
- ipr: remove an unneeded check (bnc#794550,fate#314040 "rc"
  is always zero here, so there is no need to check.).
- ipr: missing unlock before a return (bnc#794550,fate#314040).
- ipr: Reduce interrupt lock time (bnc#794550,fate#314040).
- ipr: Reduce queuecommand lock time (bnc#794550,fate#314040).
- ipr: Increase alignment boundary of command blocks
  (bnc#794550,fate#314040).
- ipr: Remove unnecessary memory barriers (bnc#794550,fate#314040
- ipr: Fix target id allocation re-use problem
  (bnc#794550,fate#314040).
- powerpc/prom: Remove limit on maximum size of properties
  (bnc#793088,fate#314226).
- commit b6883fe
* Wed Dec 19 2012 dsterba@suse.cz
- Refresh
  patches.suse/btrfs-0739-remove-unused-hint-byte-argument-for-btrfs_dro.patch.
  and fix build failure.
- commit 3f17c78
* Wed Dec 19 2012 dsterba@suse.cz
- update btrfs to 3.7
- btrfs: fix the commment for the action flags in delayed-ref.h
  (FATE#312888).
- switch btrfs_ioctl_snap_create_transid() to fget_light()
  (FATE#312888).
- switch btrfs_ioctl_clone() to fget_light() (FATE#312888).
- btrfs: reada_extent doesn't need kref for refcount
  (FATE#312888).
- Btrfs: add rdev to get_inode_info in send/receive (FATE#312888).
- Btrfs: fix cur_ino < parent_ino case for send/receive
  (FATE#312888).
- Btrfs: add missing check for dir != tmp_dir to is_first_ref
  (FATE#312888).
- Btrfs: add correct parent to check_dirs when dir got moved
  (FATE#312888).
- Btrfs: remove unused use_list from send/receive code
  (FATE#312888).
- Btrfs: rename backref_ctx::found_in_send_root to found_itself
  (FATE#312888).
- Btrfs: use kmalloc instead of stack for backref_ctx
  (FATE#312888).
- Btrfs: use normal return path for root == send_root case
  (FATE#312888).
- Btrfs: don't break in the final loop of find_extent_clone
  (FATE#312888).
- Btrfs: fix memory leak for name_cache in send/receive
  (FATE#312888).
- Btrfs: fix use of radix_tree for name_cache in send/receive
  (FATE#312888).
- Btrfs: make aux field of ulist 64 bit (FATE#312888).
- Btrfs: update send_progress at correct places (FATE#312888).
- Btrfs: add/fix comments/documentation for send/receive
  (FATE#312888).
- Btrfs: code cleanups for send/receive (FATE#312888).
- Btrfs: remove unused tmp_path from iterate_dir_item
  (FATE#312888).
- Btrfs: free nce and nce_head on error in name_cache_insert
  (FATE#312888).
- Btrfs: fix check for changed extent in is_extent_unchanged
  (FATE#312888).
- Btrfs: use <= instead of < in is_extent_unchanged (FATE#312888).
- Btrfs: pass root instead of parent_root to iterate_inode_ref
  (FATE#312888).
- Btrfs: ignore non-FS inodes for send/receive (FATE#312888).
- Btrfs: don't treat top/root directory inode as deleted/reused
  (FATE#312888).
- Btrfs: fix btrfs send for inline items and compression
  (FATE#312888).
- Btrfs: fix gcc warnings for 32bit compiles (FATE#312888).
- Btrfs: update last trans if we don't update the inode
  (FATE#312888).
- Btrfs: do not allocate chunks as agressively (FATE#312888).
- Btrfs: fix possible corruption when fsyncing written prealloced
  extents (FATE#312888).
- Btrfs: turbo charge fsync (FATE#312888).
- Btrfs: only warn if we hit an error when doing the tree logging
  (FATE#312888).
- Btrfs: cleanup extents after we finish logging inode
  (FATE#312888).
- Btrfs: do not needlessly restart the transaction for enospc
  (FATE#312888).
- Btrfs: improve fsync by filtering extents that we want
  (FATE#312888).
- Btrfs: fix a bug in checking whether a inode is already in log
  (FATE#312888).
- Btrfs: check if an inode has no checksum when logging it
  (FATE#312888).
- Btrfs: remove unused hint byte argument for btrfs_drop_extents
  (FATE#312888).
- Btrfs: add hole punching (FATE#312888).
- Btrfs: set journal_info in async trans commit worker
  (FATE#312888).
- Btrfs: do not take cleanup_work_sem in btrfs_run_delayed_iputs()
  (FATE#312888).
- Btrfs: btrfs_drop_extent_cache should never fail (FATE#312888).
- Btrfs: fix possible memory leak in scrub_setup_recheck_block()
  (FATE#312888).
- Btrfs: fix error path in create_pending_snapshot()
  (FATE#312888).
- Btrfs: fix full backref problem when inserting shared block
  reference (FATE#312888).
- Btrfs: fix file extent discount problem in the, snapshot
  (FATE#312888).
- Btrfs: use a slab for ordered extents allocation (FATE#312888).
- Btrfs: add a new "type" field into the block reservation
  structure (FATE#312888).
- Btrfs: fix the snapshot that should not exist (FATE#312888).
- Btrfs: fix wrong size for the reservation of the, snapshot
  creation (FATE#312888).
- Btrfs: fix unprotected ->log_batch (FATE#312888).
- Btrfs: output more information when aborting a unused
  transaction handle (FATE#312888).
- Btrfs: fix wrong size for the reservation when doing, file
  pre-allocation (FATE#312888).
- Btrfs: fix error handling in delete_block_group_cache()
  (FATE#312888).
- Btrfs: check return value of ulist_alloc() properly
  (FATE#312888).
- Btrfs: use flag EXTENT_DEFRAG for snapshot-aware defrag
  (FATE#312888).
- Btrfs: wait on async pages when shrinking delalloc
  (FATE#312888).
- Btrfs: fix our overcommit math (FATE#312888).
- btrfs: polish names of kmem caches (FATE#312888).
- Btrfs: fix corrupted metadata in the snapshot (FATE#312888).
- Btrfs: cleanup for unused ref cache stuff (FATE#312888).
- Btrfs: fix a bug in parsing return value in logical resolve
  (FATE#312888).
- Btrfs: use helper for logical resolve (FATE#312888).
- Btrfs: use larger limit for translation of logical to inode
  (FATE#312888).
- Btrfs: create a pinned em when writing to a prealloc range in
  DIO (FATE#312888).
- Btrfs: fix unnecessary warning when the fragments make the
  space alloc fail (FATE#312888).
- Btrfs: delay block group item insertion (FATE#312888).
- Btrfs: remove bytes argument from do_chunk_alloc (FATE#312888).
- Revert "Btrfs: do not do filemap_write_and_wait_range in fsync"
  (FATE#312888).
- Btrfs: cleanup of error processing in btree_get_extent()
  (FATE#312888).
- Btrfs: remove unnecessary code in btree_get_extent()
  (FATE#312888).
- Btrfs: write_buf is now callable outside send.c (FATE#312888).
- btrfs: return EPERM upon rmdir on a subvolume (FATE#312888).
- Btrfs: fix race in sync and freeze again (FATE#312888).
- Btrfs: cleanup for duplicated code in find_free_extent
  (FATE#312888).
- Btrfs: cleanup fs_info->hashers (FATE#312888).
- Btrfs: kill obsolete arguments in btrfs_wait_ordered_extents
  (FATE#312888).
- Btrfs: do not hold the write_lock on the extent tree while
  logging (FATE#312888).
- Btrfs: fix race when getting the eb out of page->private
  (FATE#312888).
- Btrfs: remove unused write cache pages hook (FATE#312888).
- Btrfs: don't do anything in our ->freeze_fs and ->unfreeze_fs
  (FATE#312888).
- Btrfs: fix punch hole when no extent exists (FATE#312888).
- btrfs: allow setting NOCOW for a zero sized file via ioctl
  (FATE#312888).
- Btrfs: fix off-by-one in file clone (FATE#312888).
- Btrfs: fix the missing error information in
  create_pending_snapshot() (FATE#312888).
- btrfs: move transaction aborts to the point of failure
  (FATE#312888).
- Btrfs: handle not finding the extent exactly when logging
  changed extents (FATE#312888).
- btrfs: improved readablity for add_inode_ref (FATE#312888).
- btrfs: extended inode refs (FATE#312888).
- btrfs: extended inode ref iteration (FATE#312888).
- Btrfs: fix memory leak in start_transaction() (FATE#312888).
- Btrfs: add a type field for the transaction handle
  (FATE#312888).
- Btrfs: fix orphan transaction on the freezed filesystem
  (FATE#312888).
- Btrfs: run delayed refs first when out of space (FATE#312888).
- btrfs: fix min csum item size warnings in 32bit (FATE#312888).
- Btrfs: do not async metadata csumming in certain situations
  (FATE#312888).
- Btrfs: do not hold the file extent leaf locked when adding
  extent item (FATE#312888).
- Btrfs: cache extent state when writing out dirty metadata pages
  (FATE#312888).
- Btrfs: don't lookup csums for prealloc extents (FATE#312888).
- Btrfs: be smarter about dropping things from the tree log
  (FATE#312888).
- Btrfs: confirmation of value is added before
  trace_btrfs_get_extent() is called (FATE#312888).
- Btrfs: don't commit instead of overcommitting (FATE#312888).
- btrfs: remove unused function btrfs_insert_some_items()
  (FATE#312888).
- Btrfs: remove unnecessary IS_ERR in bio_readpage_error()
  (FATE#312888).
- btrfs: move inline function code to header file (FATE#312888).
- Btrfs: don't bother committing delayed inode updates when
  fsyncing (FATE#312888).
- btrfs: fix message printing (FATE#312888).
- Btrfs: make compress and nodatacow mount options mutually
  exclusive (FATE#312888).
- Btrfs: detect corrupted filesystem after write I/O errors
  (FATE#312888).
- Btrfs: make filesystem read-only when submitting barrier fails
  (FATE#312888).
- Btrfs: cleanup pages properly when ENOMEM in compression
  (FATE#312888).
- Btrfs: don't bug on enomem in readpage (FATE#312888).
- Btrfs: do not warn_on when we cannot alloc a page for an extent
  buffer (FATE#312888).
- Btrfs: fix page leakage (FATE#312888).
- Btrfs: remove repeated eb->pages check in,
  disk-io.c/csum_dirty_buffer (FATE#312888).
- Fix a sign bug causing invalid memory access in the ino_paths
  ioctl (FATE#312888).
- Btrfs: Fix wrong error handling code (FATE#312888).
- Btrfs: extended inode refs support for send mechanism
  (FATE#312888).
- Btrfs: send correct rdev and mode in btrfs-send (FATE#312888).
- Btrfs: fix memory leak in btrfs_quota_enable() (FATE#312888).
- btrfs: Return EINVAL when length to trim is less than FSB
  (FATE#312888).
- Btrfs: fix deadlock caused by the nested chunk allocation
  (FATE#312888).
- Btrfs: Send: preserve ownership (uid and gid) also for symlinks
  (FATE#312888).
- Btrfs: Use btrfs_update_inode_fallback when creating a snapshot
  (FATE#312888).
- Btrfs: don't put removals from push_node_left into tree mod
  log twice (FATE#312888).
- Btrfs: fix a tree mod logging issue for root replacement
  operations (FATE#312888).
- Btrfs: tree mod log's old roots could still be part of the tree
  (FATE#312888).
- Btrfs: determine level of old roots (FATE#312888).
- Btrfs: fix extent buffer reference for tree mod log roots
  (FATE#312888).
- Btrfs: comment for loop in tree_mod_log_insert_move
  (FATE#312888).
- Btrfs: fix memory leak when cloning root's node (FATE#312888).
- Btrfs: do not bug when we fail to commit the transaction
  (FATE#312888).
- Refresh
  patches.suse/btrfs-0512-fix-how-we-deal-with-the-orphan-block-rsv.patch.
- Refresh
  patches.suse/btrfs-8015-make-lzo-the-default-compression-scheme.patch.
- Refresh
  patches.suse/btrfs-8094-flush-all-the-dirty-pages-if-try_to_writeback_.patch.
- Refresh
  patches.suse/btrfs-8095-use-writeback_inodes_sb-_nr-_if_idle.patch.
- Refresh
  patches.suse/btrfs-8185-don-t-allow-degraded-mount-if-too-many-devices.patch.
- Refresh
  patches.suse/btrfs-8190-limit-fallocate-extent-reservation-to-256MB.patch.
- Refresh patches.suse/btrfs-enospc-debugging-messages.patch.
- Refresh patches.suse/btrfs-update-message-levels.patch.
- Delete
  patches.suse/btrfs-8126-cleanup-for-unused-ref-cache-stuff.patch.
- Delete
  patches.suse/btrfs-8134-update-last-trans-if-we-don-t-update-the-inode.patch.
- Delete
  patches.suse/btrfs-8135-fix-possible-corruption-when-fsyncing-written-.patch.
- Delete
  patches.suse/btrfs-8137-set-journal_info-in-async-trans-commit-worker.patch.
- Delete
  patches.suse/btrfs-8138-fix-a-bug-in-parsing-return-value-in-logical-r.patch.
- Delete
  patches.suse/btrfs-8139-use-helper-for-logical-resolve.patch.
- Delete
  patches.suse/btrfs-8140-use-larger-limit-for-translation-of-logical-to.patch.
- Delete
  patches.suse/btrfs-8141-use-a-slab-for-ordered-extents-allocation.patch.
- Delete patches.suse/btrfs-8142-fix-unprotected-log_batch.patch.
- Delete
  patches.suse/btrfs-8143-output-more-information-when-aborting-a-unused.patch.
- Delete
  patches.suse/btrfs-8144-fix-wrong-size-for-the-reservation-when-doing-.patch.
- Delete
  patches.suse/btrfs-8146-fix-error-path-in-create_pending_snapshot.patch.
- Delete
  patches.suse/btrfs-8147-fix-full-backref-problem-when-inserting-shared.patch.
- Delete
  patches.suse/btrfs-8148-fix-wrong-size-for-the-reservation-of-the-snap.patch.
- Delete
  patches.suse/btrfs-8149-fix-error-handling-in-delete_block_group_cache.patch.
- Delete
  patches.suse/btrfs-8150-polish-names-of-kmem-caches.patch.
- Delete patches.suse/btrfs-8151-use-vfree-instead-of-kfree.patch.
- Delete
  patches.suse/btrfs-8152-fix-unnecessary-warning-when-the-fragments-mak.patch.
- Delete
  patches.suse/btrfs-8153-return-EPERM-upon-rmdir-on-a-subvolume.patch.
- Delete
  patches.suse/btrfs-8154-cleanup-for-duplicated-code-in-find_free_exten.patch.
- Delete patches.suse/btrfs-8155-cleanup-fs_info-hashers.patch.
- Delete
  patches.suse/btrfs-8156-allow-setting-NOCOW-for-a-zero-sized-file-via-.patch.
- Delete
  patches.suse/btrfs-8158-fix-the-missing-error-information-in-create_pe.patch.
- Delete
  patches.suse/btrfs-8159-fix-off-by-one-in-file-clone.patch.
- Delete
  patches.suse/btrfs-8160-move-transaction-aborts-to-the-point-of-failur.patch.
- Delete
  patches.suse/btrfs-8161-do-not-allocate-chunks-as-agressively.patch.
- Delete
  patches.suse/btrfs-8162-btrfs_drop_extent_cache-should-never-fail.patch.
- Delete
  patches.suse/btrfs-8163-fix-full-backref-problem-when-inserting-shared.patch.
- Delete
  patches.suse/btrfs-8164-wait-on-async-pages-when-shrinking-delalloc.patch.
- Delete
  patches.suse/btrfs-8165-remove-bytes-argument-from-do_chunk_alloc.patch.
- Delete
  patches.suse/btrfs-8166-cleanup-of-error-processing-in-btree_get_exten.patch.
- Delete
  patches.suse/btrfs-8167-remove-unnecessary-code-in-btree_get_extent.patch.
- Delete
  patches.suse/btrfs-8168-kill-obsolete-arguments-in-btrfs_wait_ordered_.patch.
- Delete
  patches.suse/btrfs-8169-don-t-do-anything-in-our-freeze_fs-and-unfreez.patch.
- Delete
  patches.suse/btrfs-8170-do-not-async-metadata-csumming-in-certain-situ.patch.
- Delete
  patches.suse/btrfs-8171-do-not-hold-the-file-extent-leaf-locked-when-a.patch.
- Delete
  patches.suse/btrfs-8172-cache-extent-state-when-writing-out-dirty-meta.patch.
- Delete
  patches.suse/btrfs-8173-don-t-lookup-csums-for-prealloc-extents.patch.
- Delete
  patches.suse/btrfs-8174-be-smarter-about-dropping-things-from-the-tree.patch.
- Delete
  patches.suse/btrfs-8175-confirmation-of-value-is-added-before-trace_bt.patch.
- Delete
  patches.suse/btrfs-8176-make-filesystem-read-only-when-submitting-barr.patch.
- Delete
  patches.suse/btrfs-8177-cleanup-pages-properly-when-ENOMEM-in-compress.patch.
- Delete
  patches.suse/btrfs-8178-don-t-bug-on-enomem-in-readpage.patch.
- Delete
  patches.suse/btrfs-8179-do-not-warn_on-when-we-cannot-alloc-a-page-for.patch.
- Delete
  patches.suse/btrfs-8180-Return-EINVAL-when-length-to-trim-is-less-than.patch.
- Delete
  patches.suse/btrfs-8182-Use-btrfs_update_inode_fallback-when-creating-.patch.
- Delete
  patches.suse/btrfs-8183-do-not-bug-when-we-fail-to-commit-the-transact.patch.
- Delete
  patches.suse/btrfs-8191-fix-btrfs-send-for-inline-items-and-compressio.patch.
- commit cf88af1
* Wed Dec 19 2012 jlee@suse.com
- Update config files. (fate#314574)
  Also disable blacklist of kernel module sign key and get the key
  from MokList on i368/ec2 and x86_64/ec2 architecture:
  Add the following flag to config/i368/xen
  +# CONFIG_MODULE_SIG_BLACKLIST is not set
  +# CONFIG_EFI_SIGNATURE_LIST_PARSER is not set
- commit 1815176
* Wed Dec 19 2012 jlee@suse.com
- Update config files. (fate#314574)
  Also disable blacklist of kernel module sign key and get the key from
  MokList on i368/xen architecture:
  Add the following flag to config/i368/xen
    +# CONFIG_MODULE_SIG_BLACKLIST is not set
    +# CONFIG_EFI_SIGNATURE_LIST_PARSER is not set
- commit 04177cd
* Tue Dec 18 2012 bpoirier@suse.de
- cxgb4vf: Add support for Chelsio's T480-CR and T440-LP-CR
  adapters (bnc#784800 FATE#314296).
- drivers/net: Remove alloc_etherdev error messages (bnc#784800
  FATE#314296).
- treewide: Fix comment and string typo 'bufer' (bnc#784800
  FATE#314296).
- cxgb4vf: convert to SKB paged frag API (bnc#784800 FATE#314296).
- cxgb4vf: do vlan cleanup (bnc#784800 FATE#314296).
- netdevice: Kill 'feature' test macros (bnc#784800 FATE#314296).
- net: Remove unneeded version.h includes from drivers/net/
  (bnc#784800 FATE#314296).
- net: remove interrupt.h inclusion from netdevice.h (bnc#784800
  FATE#314296).
- commit 5667d2e
* Tue Dec 18 2012 bpoirier@suse.de
- RDMA/cxgb4: Don't free chunk that we have failed to allocate
  (bnc#784800 FATE#314296).
- RDMA/cxgb4: Fix error handling in create_qp() (bnc#784800
  FATE#314296).
- RDMA/cxgb4: Move dereference below NULL test (bnc#784800
  FATE#314296).
- RDMA/cxgb4: Update RDMA/cxgb4 due to macro definition removal
  in cxgb4 driver (bnc#784800 FATE#314296).
- RDMA/cxgb4: Fix endianness of addition to mpa->private_data_size
  (bnc#784800 FATE#314296).
- RDMA/cxgb4: Fix crash when peer address is 0.0.0.0 (bnc#784800
  FATE#314296).
- RDMA/cxgb4: Include vmalloc.h for vmalloc and vfree (bnc#784800
  FATE#314296).
- RDMA/cxgb4: Add query_qp support (bnc#784800 FATE#314296).
- RDMA/cxgb4: Remove kfifo usage (bnc#784800 FATE#314296).
- RDMA/cxgb4: Use vmalloc() for debugfs QP dump (bnc#784800
  FATE#314296).
- RDMA/cxgb4: DB Drop Recovery for RDMA and LLD queues (bnc#784800
  FATE#314296).
- RDMA/cxgb4: Disable interrupts in c4iw_ev_dispatch() (bnc#784800
  FATE#314296).
- RDMA/cxgb4: Add DB Overflow Avoidance (bnc#784800 FATE#314296).
- RDMA/cxgb4: Add debugfs RDMA memory stats (bnc#784800
  FATE#314296).
- RDMA/cxgb4: Always wake up waiters in c4iw_peer_abort_intr()
  (bnc#784800 FATE#314296).
- RDMA/cxgb4: Use dst parameter in import_ep() (bnc#784800
  FATE#314296).
- RDMA/cxgb4: Add missing peer2peer check in MPAv2 code
  (bnc#784800 FATE#314296).
- infiniband: cxgb4: Consolidate 3 copies of the same operation
  into 1 helper function (bnc#784800 FATE#314296).
- RDMA/cxgb4: Fix retry with MPAv1 logic for MPAv2 (bnc#784800
  FATE#314296).
- RDMA/cxgb4: Fix iw_cxgb4 count_rcqes() logic (bnc#784800
  FATE#314296).
- infiniband: Fix up module files that need to include module.h
  (bnc#784800 FATE#314296).
- RDMA/cxgb4: Mark QP in error before disabling the queue in
  firmware (bnc#784800 FATE#314296).
- RDMA/cxgb4: Add support for MPAv2 Enhanced RDMA Negotiation
  (bnc#784800 FATE#314296).
- RDMA/cxgb4: Fail RDMA initialization for unsupported cards
  (bnc#784800 FATE#314296).
- RDMA/cxgb4: Use printk_ratelimited() instead of
  printk_ratelimit() (bnc#784800 FATE#314296).
- commit 1b16b73
* Tue Dec 18 2012 dsterba@suse.cz
  add References tag to a few patches
- Update
  patches.suse/btrfs-0490-ctree.c-remove-the-unnecessary-return-1-at-the.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0491-fix-btrfs_release_extent_buffer_page-with-the-.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0492-fix-the-comment-for-find_first_extent_bit.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0493-remove-the-useless-assignment-to-entry-in-func.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0494-change-integrity-checker-to-support-big-blocks.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0495-cleanup-use-consistent-lock-naming.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0496-use-i_version-instead-of-our-own-sequence.patch
  (FATE#312888).
- Update patches.suse/btrfs-0497-cache-no-acl-on-new-inodes.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0498-remove-useless-waiting-and-extra-filemap-work.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0499-do-not-do-filemap_write_and_wait_range-in-fsyn.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0500-allow-changing-thread_pool-size-at-remount-tim.patch
  (FATE#312888).
- Update patches.suse/btrfs-0501-fix-minor-type-issues.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0502-avoid-buffer-overrun-in-btrfs_printk.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0503-NUL-terminate-path-buffer-in-DEV_INFO-ioctl-re.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0504-avoid-buffer-overrun-in-mount-option-handling.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0505-do-not-check-delalloc-when-updating-disk_i_siz.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0506-finish-ordered-extents-in-their-own-thread.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0507-fix-wrong-error-returned-by-adding-a-device.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0508-use-fastpath-in-extent-state-ops-as-much-as-po.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0509-do-not-do-balance-in-readonly-mode.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0510-merge-contigous-regions-when-loading-free-spac.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0511-convert-the-inode-bit-field-to-use-the-actual-.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0512-fix-how-we-deal-with-the-orphan-block-rsv.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0513-fall-back-to-non-inline-if-we-don-t-have-enoug.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0514-fix-the-same-inode-id-problem-when-doing-auto-.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0515-Drop-unused-function-btrfs_abort_devices.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0516-add-device-counters-for-detected-IO-and-checks.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0517-add-ioctl-to-get-and-reset-the-device-stats.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0518-read-device-stats-on-mount-write-modified-ones.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0519-return-value-of-btrfs_read_buffer-is-checked-c.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0520-check-to-see-if-the-inode-is-in-the-log-before.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0521-fix-return-code-in-drop_objectid_items.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0522-set-ioprio-of-scrub-readahead-to-idle.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0523-fix-runtime-warning-in-check-integrity-check-d.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0524-fix-false-positive-in-check-integrity-on-unmou.patch
  (FATE#312888).
- Update patches.suse/btrfs-0525-ulist-realloc-bugfix.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0526-bugfix-in-btrfs_find_parent_nodes.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0527-bugfix-ignore-the-wrong-key-for-indirect-tree-.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0528-look-into-the-extent-during-find_all_leafs.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0529-don-t-set-for_cow-parameter-for-tree-block-fun.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0530-move-struct-seq_list-to-ctree.h.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0531-dummy-extent-buffers-for-tree-mod-log.patch
  (FATE#312888).
- Update patches.suse/btrfs-0532-add-tree-mod-log-to-fs_info.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0533-add-tree-modification-log-functions.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0534-put-all-block-modifications-into-the-tree-mod-.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0535-add-del_ptr-and-insert_ptr-modifications-to-th.patch
  (FATE#312888).
- Update patches.suse/btrfs-0536-add-btrfs_search_old_slot.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0537-use-the-tree-modification-log-for-backref-reso.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0538-fs_info-variable-for-join_transaction.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0539-tree-mod-log-sanity-checks-in-join_transaction.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0540-use-delayed-ref-sequence-numbers-for-all-fs-tr.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0541-add-inodes-before-dropping-the-extent-lock-in-.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0542-add-missing-spin_lock-for-insertion-into-tree-.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0543-add-tree_mod_dont_log-helper.patch
  (FATE#312888).
- Update patches.suse/btrfs-0544-fix-tree-mod-log-del_ptr.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0545-fix-tree-mod-log-rewinded-level-and-rewinding-.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0546-trivial-endianness-annotations.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0547-move-over-to-use-update_time.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0548-pass-locked_page-into-extent_clear_unlock_dela.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0549-fix-locking-in-btrfs_destroy_delayed_refs.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0550-wake-up-transaction-waiters-when-aborting-a-tr.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0551-abort-the-transaction-if-the-commit-fails.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0552-fix-btrfs_destroy_marked_extents.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0553-unlock-everything-properly-in-the-error-case-f.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0554-use-rcu-to-protect-device-name.patch
  (FATE#312888).
- Update patches.suse/btrfs-0555-implement-show_devname.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0556-keep-inode-pinned-when-compressing-writes.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0557-call-filemap_fdatawrite-twice-for-compression.patch
  (FATE#312888).
- Update patches.suse/btrfs-0558-fix-defrag-regression.patch
  (FATE#312888).
- Update patches.suse/btrfs-0559-fix-incompat-flags-setting.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0560-remove-call-to-btrfs_header_nritems-with-no-ef.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0561-remove-obsolete-btrfs_next_leaf-call-from-__re.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0562-use-btrfs_read_lock_root_node-in-get_old_root.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0563-fix-return-value-for-__tree_mod_log_oldest_roo.patch
  (FATE#312888).
- Update patches.suse/btrfs-0564-add-btrfs_next_old_leaf.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0565-fix-race-in-tree-mod-log-addition.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0566-fix-missing-inherited-flag-in-rename.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0567-do-not-resize-a-seeding-device.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0568-avoid-memory-leak-of-extent-state-in-error-han.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0569-make-sure-that-we-ve-made-everything-in-pinned.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0570-destroy-the-items-of-the-delayed-inodes-in-err.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0572-cast-devid-to-unsigned-long-long-for-printk-ll.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0573-introduce-btrfs_next_old_item.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0574-don-t-assume-to-be-on-the-correct-extent-in-ad.patch
  (FATE#312888).
- Update patches.suse/btrfs-0575-add-a-missing-spin_lock.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0576-delay-iput-with-async-extents.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0577-avoid-waiting-for-delayed-refs-when-we-must-no.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0578-support-root-level-changes-in-__resolve_indire.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0579-fix-tree-mod-log-for-root-replacements-at-leaf.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0580-always-put-insert_ptr-modifications-into-the-t.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0581-leave-critical-region-in-btrfs_find_all_roots-.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0582-fix-tree-mod-log-rewind-of-ADD-operations.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0583-resolve-tree-mod-log-locking-issue-in-btrfs_ne.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0584-don-t-count-I-O-statistic-read-errors-for-miss.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0585-fix-dio-write-vs-buffered-read-race.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0586-restore-restriper-state-on-all-mounts.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0587-resume-balance-on-rw-re-mounts-properly.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0588-use-_IOR-for-btrfs_IOC_SUBVOL_GETFLAGS.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0589-fix-wrong-check-during-log-recovery.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0590-fix-tree-log-remove-space-corner-case.patch
  (FATE#312888).
- Update
  patches.suse/btrfs-0591-hold-a-ref-on-the-inode-during-writepages.patch
  (FATE#312888).
- commit ac65e3e
* Tue Dec 18 2012 bpoirier@suse.de
- cxgb4: Use PCI Express Capability accessors (bnc#784800
  FATE#314296).
- cxgb3: Use PCI Express Capability accessors (bnc#784800
  FATE#314296).
- commit d956f92
* Tue Dec 18 2012 jlee@suse.com
- Update config files. (fate#314574)
  enable the following config to x86_64 and i386 architecture (exclude
  x86_64/xen):
  +CONFIG_MODULE_SIG_BLACKLIST=y
  +CONFIG_MODULE_SIG_UEFI=y
  +CONFIG_EFI_SIGNATURE_LIST_PARSER=y
  For other architecture, add not set flag:
  +# CONFIG_MODULE_SIG_BLACKLIST is not set
  +# CONFIG_EFI_SIGNATURE_LIST_PARSER is not set
- commit 05fb22e
* Tue Dec 18 2012 jlee@suse.com
- Don't soft lockup on bad EFI signature lists (fate#314574).
- MODSIGN: Import certificates from UEFI Secure Boot
  (fate#314574).
- MODSIGN: Add module certificate blacklist keyring (fate#314574).
- EFI: Add in-kernel variable to determine if Secure Boot is
  enabled (fate#314574).
- Add an EFI signature blob parser and key loader.  X.509
  certificates are loaded into the specified keyring as asymmetric
  type keys (fate#314574).
- Add EFI signature data types, such as are used for containing
  hashes, keys and certificates for cryptographic verification
  (fate#314574).
- modsign: Always enforce module signing in a Secure Boot
  environment (fate#314574).
- commit 56a479d
* Mon Dec 17 2012 bpoirier@suse.de
- PCI: Add accessors for PCI Express Capability (bnc#794673).
- commit 0b724e3
* Mon Dec 17 2012 bpoirier@suse.de
- PCI: Add pcie_flags_reg to cache PCIe capabilities register
  (bnc#794673).
- Refresh
  patches.fixes/pci-set-pci-e-max-payload-size-on-fabric.patch.
- commit 9439c8e
* Mon Dec 17 2012 bpoirier@suse.de
- pci_regs: define LNKSTA2 pcie cap + bits (bnc#794673).
- commit 02fb0ff
* Mon Dec 17 2012 bpoirier@suse.de
- Refresh
  patches.fixes/net-Add-ethtool-to-mii-advertisment-conversion-helpe.patch.
- Refresh
  patches.fixes/net-Change-mii-to-ethtool-advertisement-function-nam.patch.
- commit ae6d110
* Mon Dec 17 2012 bpoirier@suse.de
- net: Change mii to ethtool advertisement function names
  (bnc#794672).
- net: Add ethtool to mii advertisment conversion helpers
  (bnc#794672).
- commit 79a02d2
* Mon Dec 17 2012 trenn@suse.de
- x86, MCE: Remove bios_cmci_threshold sysfs attribute.
- Refresh (bnc#794798)
  patches.arch/x86-mce-Provide-boot-argument-to-honour-bios-set-CMC.patch.
- commit 7ddc374
* Mon Dec 17 2012 sjayaraman@suse.com
- patches.fixes/sunrpc-increase-max-slot-table.patch: SUNRPC:
  increase maximum slots to use (bnc#775685).
- commit 766e8be
* Mon Dec 17 2012 jack@suse.cz
- patches.fixes/bio-allocation-failure-due-to-bio_get_nr_vecs.patch:
  bio allocation failure due to bio_get_nr_vecs() (bnc#792270).
- patches.fixes/bio-don-t-overflow-in-bio_get_nr_vecs.patch:
  bio: don't overflow in bio_get_nr_vecs() (bnc#792270).
- commit 6a5da7c
* Mon Dec 17 2012 jlee@suse.com
- mfd: lpc_ich: Add Device IDs for Intel Lynx Point-LP PCH. (fate#313810)
- commit dd5419d
* Sat Dec 15 2012 lduncan@suse.de
- [PATCH] [SCSI] bnx2i: Updated version to 2.7.6.2 (FATE#313916).
- [PATCH] [SCSI] bnx2i: removed the individual PCI DEVICE ID
  checking (FATE#313916).
- [PATCH] [SCSI] bnx2i: Removed the reference to the
  netdev->base_addr (FATE#313916 brc#826295).
- [PATCH] [SCSI] bnx2i: Updated version and copyright year
  (FATE#313916 brc#816376).
- [PATCH] [SCSI] bnx2i: Added the setting of target can_queue
  via  target_alloc (FATE#313916 brc#816376).
- [PATCH] [SCSI] bnx2i: Fixed the override of the error_mask
  module  param (FATE#313916 brc#796827).
- [PATCH] [SCSI] bnx2i: use kthread_create_on_node()
  (FATE#313916).
- commit 9bea1fb
* Fri Dec 14 2012 bpoirier@suse.de
- Clean up certain patches that did not work with git apply
- Refresh patches.drivers/011-watchdog_driver.patch.
- Refresh
  patches.suse/intel-perf-event-0066-ftrace-perf-add-support-to-use-function-tracepoint-in-perf.patch.
- Refresh
  patches.suse/intel-perf-event-0098-x86-cpu-rename-checking_wrmsrl-to-wrmsrl_safe.patch.
- Refresh
  patches.suse/intel-perf-event-0113-perf-x86-rename-intel-specific-macros.patch.
- Refresh
  patches.suse/intel-perf-event-0129-perf-x86-fix-user-kernel-tagging-of-samples-properly.patch.
- commit 5f97a6c
* Fri Dec 14 2012 bpoirier@suse.de
- scripts: Add a symlink to the most recently expanded source tree
  After working with multiple branches the scratch area is filled with
  linux-<version>[.orig|-<branch>] directories which makes tab completion less
  useful. Since the workflow is often:
  $ ./scripts/sequence-patch.sh
  $ cd <tree from the current branch>
  add a symlink to that tree with a unique prefix, "current":
  $ ./scripts/sequence-patch.sh
  $ cd tmp/c<tab>
  ... much less typing :)
- commit ddd8bd4
* Fri Dec 14 2012 bpoirier@suse.de
- Refresh
  patches.drivers/cxgb3-0004-chelsio-Move-the-Chelsio-drivers.patch.
- Refresh
  patches.drivers/cxgb3-0017-cxgb3-update-firmware-version.patch.
- Refresh patches.xen/xen-cxgb3.
- commit 934ba06
* Fri Dec 14 2012 hare@suse.de
- Refresh
  patches.drivers/mpt3sas-add-new-driver-supporting-12GB-SAS.patch.
- commit b8f0c32
* Fri Dec 14 2012 duwe@suse.de
- Update config files.
- commit 7f16185
* Fri Dec 14 2012 duwe@suse.de
- powerpc/crypto: Enable the PFO-based encryption device
  (fate#314588,bnc#792863).
- powerpc/crypto: Build files for the nx device driver
  (fate#314588,bnc#792863).
- powerpc/crypto: debugfs routines and docs for the nx device
  driver (fate#314588,bnc#792863).
- powerpc/crypto: SHA512 hash routines for nx encryption
  (fate#314588,bnc#792863).
- powerpc/crypto: SHA256 hash routines for nx encryption
  (fate#314588,bnc#792863).
- powerpc/crypto: AES-XCBC mode routines for nx encryption
  (fate#314588,bnc#792863).
- powerpc/crypto: AES-GCM mode routines for nx encryption
  (fate#314588,bnc#792863).
- powerpc/crypto: AES-ECB mode routines for nx encryption
  (fate#314588,bnc#792863).
- powerpc/crypto: AES-CTR mode routines for nx encryption
  (fate#314588,bnc#792863).
- powerpc/crypto: AES-CCM mode routines for nx encryption
  (fate#314588,bnc#792863).
- powerpc/crypto: AES-CBC mode routines for nx encryption
  (fate#314588,bnc#792863).
- powerpc/crypto: nx driver code supporting nx encryption
  (fate#314588,bnc#792863).
- commit 40d3c9b
* Fri Dec 14 2012 hare@suse.de
- Update config files.
- supported.conf: mark mpt3sas as supported
- commit 83d83fe
* Fri Dec 14 2012 hare@suse.de
- mpt3sas: add new driver supporting 12GB SAS (FATE#314302).
- scsi_transport_sas: add 12GB definitions for mpt3sas
  (FATE#314302).
- miscdevice: Adding support for MPT3SAS_MINOR(222) (FATE#314302).
- commit 0e65e4f
* Fri Dec 14 2012 hare@suse.de
- pm8001: raise host can queue (FATE#314144).
- pm8001: fix endian issue with code optimization (FATE#314144).
- pm8001: Use spin_lock_irqsave() for task_state (FATE#314144).
- pm8001: fix endian issue with code optimization (FATE#314144).
- pm8001: Fix possible racing condition (FATE#314144).
- pm8001: Fix bogus interrupt state flag issue (FATE#314144).
- pm8001: deficient responses to IO_XFER_ERROR_BREAK and
  IO_XFER_OPEN_RETRY_TIMEOUT (FATE#314144).
- pm8001: Add FUNC_GET_EVENTS (FATE#314144).
- pm8001: fix lockup on phy_control hard reset (FATE#314144).
- pm8001: fix printk typo in pm8001_hwi.c (FATE#314144).
- commit 3001799
* Fri Dec 14 2012 hare@suse.de
- SCSI, pmcraid: Fix spelling error in a pmcraid_err() call
  (FATE#314144).
- pmcraid: pmcraid_chr_ioctl uses incorrect argument order to
  kmalloc() (FATE#314144).
- commit 9d93d95
* Fri Dec 14 2012 hare@suse.de
- mtip32xx: Fix padding issue (FATE#311167).
- mtip32xx: fix potential NULL pointer dereference in
  mtip_timeout_function() (FATE#311167).
- mtip32xx: fix shift larger than type warning (FATE#311167).
- mtip32xx: Fix incorrect mask used for erase mode (FATE#311167).
- mtip32xx: Fix to make lba address correct in big-endian systems
  (FATE#311167).
- mtip32xx: fix potential crash on SEC_ERASE_UNIT (FATE#311167).
- commit b6989ac
* Thu Dec 13 2012 dsterba@suse.cz
  update btrfs to 3.6
- btrfs: switch btrfs_ioctl_balance() to mnt_want_write_file()
  (FATE#312888).
- Btrfs: don't wait around for new log writers on an SSD
  (FATE#312888).
- Btrfs: reduce calls to wake_up on uncontended locks
  (FATE#312888).
- Btrfs: remove ->dirty_inode (FATE#312888).
- Btrfs: allow mount -o remount,compress=no (FATE#312888).
- Btrfs: don't update atime on RO subvolumes (FATE#312888).
- Btrfs: small naming cleanup in join_transaction() (FATE#312888).
- btrfs: ignore unfragmented file checks in defrag when
  compression enabled - rebased (FATE#312888).
- btrfs: join DEV_STATS ioctls to one (FATE#312888).
- Btrfs: flush delayed inodes if we're short on space
  (FATE#312888).
- Btrfs: add DEVICE_READY ioctl (FATE#312888).
- Btrfs: do not return EINVAL instead of ENOMEM from open_ctree()
  (FATE#312888).
- Btrfs: do not ignore errors from btrfs_cleanup_fs_roots()
  when mounting (FATE#312888).
- Btrfs: fix error handling in __add_reloc_root() (FATE#312888).
- Btrfs: return error of btrfs_update_inode() to caller
  (FATE#312888).
- Btrfs: change how we indicate we're adding csums (FATE#312888).
- Btrfs: fix typo in cow_file_range_async and async_cow_submit
  (FATE#312888).
- Btrfs: check write access to mount earlier while creating
  snapshots (FATE#312888).
- Btrfs: remove redundant r/o check for superblock (FATE#312888).
- Btrfs: use mnt_want_write_file instead of mnt_want_write
  (FATE#312888).
- Btrfs: do not set subvolume flags in readonly mode
  (FATE#312888).
- Btrfs: rework shrink_delalloc (FATE#312888).
- Btrfs: avoid I/O repair BUG() from
  btree_read_extent_buffer_pages() (FATE#312888).
- Btrfs: fix btrfs_is_free_space_inode to recognize btree inode
  (FATE#312888).
- Btrfs: kill root from btrfs_is_free_space_inode (FATE#312888).
- Btrfs: do not abort transaction in prealloc case (FATE#312888).
- Btrfs: fix a bug of writting free space cache during balance
  (FATE#312888).
- Btrfs: add ro notification to dump_space_info (FATE#312888).
- Btrfs: do not count in readonly bytes (FATE#312888).
- Btrfs: fix buffer leak in btrfs_next_old_leaf (FATE#312888).
- btrfs read error corrected message floods the console during
  recovery (FATE#312888).
- Btrfs: kill free_space pointer from inode structure
  (FATE#312888).
- Btrfs: zero unused bytes in inode item (FATE#312888).
- Btrfs: rewrite BTRFS_SETGET_FUNCS (FATE#312888).
- Btrfs: remove unwanted printk() for btrfs device I/O stats
  (FATE#312888).
- Btrfs: suppress printk() if all device I/O stats are zero
  (FATE#312888).
- Btrfs: don't return true in releasepage unless we actually
  freed the eb (FATE#312888).
- Btrfs: fix potential race in extent buffer freeing
  (FATE#312888).
- Btrfs: lock the transition from dirty to writeback for an eb
  (FATE#312888).
- Btrfs: make btrfs's allocation smoothly with preallocation
  (FATE#312888).
- Btrfs: improve multi-thread buffer read (FATE#312888).
- Btrfs: join tree mod log code with the code holding back
  delayed refs (FATE#312888).
- Btrfs: qgroup on-disk format (FATE#312888).
- Btrfs: add helper for tree enumeration (FATE#312888).
- Btrfs: check the root passed to btrfs_end_transaction
  (FATE#312888).
- Btrfs: added helper to create new trees (FATE#312888).
- Btrfs: qgroup state and initialization (FATE#312888).
- Btrfs: Test code to change the order of delayed-ref processing
  (FATE#312888).
- Btrfs: qgroup implementation and prototypes (FATE#312888).
- Btrfs: call the qgroup accounting functions (FATE#312888).
- Btrfs: quota tree support and startup (FATE#312888).
- Btrfs: hooks for qgroup to record delayed refs (FATE#312888).
- Btrfs: hooks to reserve qgroup space (FATE#312888).
- Btrfs: add qgroup ioctls (FATE#312888).
- Btrfs: add qgroup inheritance (FATE#312888).
- Btrfs: Check INCOMPAT flags on remount and add helper function
  (FATE#312888).
- Btrfs: add a barrier before a waitqueue_active check
  (FATE#312888).
- btrfs: allow cross-subvolume file clone (FATE#312888
  bnc#698540).
- Btrfs: make iref_to_path non static (FATE#312888).
- Btrfs: introduce subvol uuids and times (FATE#312888).
- Btrfs: add btrfs_compare_trees function (FATE#312888).
- Btrfs: introduce BTRFS_IOC_SEND for btrfs send/receive
  (FATE#312888).
- Btrfs: uninit variable fixes in send/receive (FATE#312888).
- btrfs: Push mnt_want_write() outside of i_mutex (FATE#312888).
- Btrfs: remove mnt_want_write call in btrfs_mksubvol
  (FATE#312888).
- Btrfs: fix a misplaced address operator in a condition
  (FATE#312888).
- Btrfs: checking for NULL instead of IS_ERR (FATE#312888).
- Btrfs: unlock on error in btrfs_delalloc_reserve_metadata()
  (FATE#312888).
- Btrfs: fix some endian bugs handling the root times
  (FATE#312888).
- Btrfs: lock extents as we map them in DIO (FATE#312888).
- Btrfs: fix that error value is changed by mistake (FATE#312888).
- Btrfs: do not use missing devices when showing devname
  (FATE#312888).
- Btrfs: do not strdup non existent strings (FATE#312888).
- Btrfs: don't allocate a seperate csums array for direct reads
  (FATE#312888).
- btrfs: fix second lock in btrfs_delete_delayed_items()
  (FATE#312888).
- Btrfs: fix deadlock in wait_for_more_refs (FATE#312888).
- Btrfs: barrier before waitqueue_active (FATE#312888).
- Btrfs: increase the size of the free space cache (FATE#312888).
- Btrfs: don't run __tree_mod_log_free_eb on leaves (FATE#312888).
- Btrfs: fix race in run_clustered_refs (FATE#312888).
- Btrfs: fix wrong mtime and ctime when creating snapshots
  (FATE#312888).
- Btrfs: fix enospc problems when deleting a subvol (FATE#312888).
- Btrfs: allow delayed refs to be merged (FATE#312888).
- Btrfs: remove superblock writing after fatal error
  (FATE#312888).
- Btrfs: revert checksum error statistic which can cause a BUG()
  (FATE#312888).
- Btrfs: fix deadlock with freeze and sync V2 (FATE#312888).
- Btrfs: fix a dio write regression (FATE#312888).
- Btrfs: fix ordered extent leak when failing to start a
  transaction (FATE#312888).
- Btrfs: fix that repair code is spuriously executed for transid
  failures (FATE#312888).
- Btrfs: fix btrfs send for inline items and compression.
- vfs: mnt_drop_write_file().
- Refresh
  patches.suse/btrfs-8007-lock-and-disable-irq-during-space-alloc.patch.
- Refresh
  patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch.
- Refresh
  patches.suse/btrfs-8015-make-lzo-the-default-compression-scheme.patch.
- Refresh
  patches.suse/btrfs-8021-Prefix-mount-messages-with-btrfs-for-clarity.patch.
- Refresh
  patches.suse/btrfs-8024-workaround-for-cleaner-deadlock.patch.
- Refresh
  patches.suse/btrfs-8076-fix-deadlock-when-the-process-of-delayed-refs-.patch.
- Refresh
  patches.suse/btrfs-8077-stop-defrag-the-files-automatically-when-doin-.patch.
- Refresh
  patches.suse/btrfs-8094-flush-all-the-dirty-pages-if-try_to_writeback_.patch.
- Refresh
  patches.suse/btrfs-8095-use-writeback_inodes_sb-_nr-_if_idle.patch.
- Refresh
  patches.suse/btrfs-8138-fix-a-bug-in-parsing-return-value-in-logical-r.patch.
- Refresh
  patches.suse/btrfs-8146-fix-error-path-in-create_pending_snapshot.patch.
- Refresh
  patches.suse/btrfs-8148-fix-wrong-size-for-the-reservation-of-the-snap.patch.
- Refresh
  patches.suse/btrfs-8160-move-transaction-aborts-to-the-point-of-failur.patch.
- Refresh
  patches.suse/btrfs-8164-wait-on-async-pages-when-shrinking-delalloc.patch.
- Refresh
  patches.suse/btrfs-8165-remove-bytes-argument-from-do_chunk_alloc.patch.
- Refresh
  patches.suse/btrfs-8168-kill-obsolete-arguments-in-btrfs_wait_ordered_.patch.
- Refresh
  patches.suse/btrfs-8176-make-filesystem-read-only-when-submitting-barr.patch.
- Refresh
  patches.suse/btrfs-8188-Don-t-trust-the-superblock-label-and-simply-pr.patch.
- Refresh patches.suse/btrfs-update-message-levels.patch.
- Delete
  patches.suse/btrfs-8117-do-not-return-EINVAL-instead-of-ENOMEM-from-op.patch.
- Delete
  patches.suse/btrfs-8118-do-not-ignore-errors-from-btrfs_cleanup_fs_roo.patch.
- Delete
  patches.suse/btrfs-8119-fix-error-handling-in-__add_reloc_root.patch.
- Delete
  patches.suse/btrfs-8120-return-error-of-btrfs_update_inode-to-caller.patch.
- Delete
  patches.suse/btrfs-8121-fix-typo-in-cow_file_range_async-and-async_cow.patch.
- Delete
  patches.suse/btrfs-8122-fix-btrfs_is_free_space_inode-to-recognize-btr.patch.
- Delete
  patches.suse/btrfs-8123-kill-root-from-btrfs_is_free_space_inode.patch.
- Delete
  patches.suse/btrfs-8125-zero-unused-bytes-in-inode-item.patch.
- Delete
  patches.suse/btrfs-8127-fix-a-misplaced-address-operator-in-a-conditio.patch.
- Delete
  patches.suse/btrfs-8128-fix-that-error-value-is-changed-by-mistake.patch.
- Delete
  patches.suse/btrfs-8129-fix-second-lock-in-btrfs_delete_delayed_items.patch.
- Delete
  patches.suse/btrfs-8130-increase-the-size-of-the-free-space-cache.patch.
- Delete
  patches.suse/btrfs-8131-fix-enospc-problems-when-deleting-a-subvol.patch.
- Delete
  patches.suse/btrfs-8132-fix-wrong-mtime-and-ctime-when-creating-snapsh.patch.
- Delete
  patches.suse/btrfs-8133-fix-race-in-run_clustered_refs.patch.
- Delete
  patches.suse/btrfs-allow-cross-subvolume-file-clone.patch.
- commit b8b6812
* Thu Dec 13 2012 bpoirier@suse.de
- drivers/net/ethernet: Add ethernet dir and config option
  (bnc#786035 FATE#314299).
- Refresh
  patches.drivers/cxgb3-0004-chelsio-Move-the-Chelsio-drivers.patch.
- commit 22cc7af
* Thu Dec 13 2012 bpoirier@suse.de
- drivers/net: Add README about driver re-organization
  (FATE#314296).
- commit ac3d8ef
* Thu Dec 13 2012 dsterba@suse.cz
- patches.suse/btrfs-handle-EIO: Refresh.
- commit d678373
* Thu Dec 13 2012 jbeulich@suse.com
- Update Xen patches to c/s 1211.
- x86: Lock down IO port access in secure boot environments
  (fate#314486).
- virtio: expose for non-virtualization users too (FATE#314135).
- Restrict /dev/mem and /dev/kmem in secure boot setups
  (fate#314486).
- efi: Enable secure boot lockdown automatically when enabled
  in firmware (fate#314486).
- x86, efi: EFI boot stub support.
- Btrfs: change scrub to support big blocks.
- Cross Memory Attach.
- [SCSI] scsi_error: classify some ILLEGAL_REQUEST sense as a
  permanent TARGET_ERROR (FATE#313629).
- x86/mce: Cleanup timer mess (bnc#786450).
- Update Xen config files.
- commit 6c6e1f2
* Thu Dec 13 2012 trenn@suse.de
- ACPI, APEI, EINJ: Add missed ACPI5 support for error trigger
  table (bnc#788160).
- commit e8dba89
* Thu Dec 13 2012 lduncan@suse.de
- qla4xxx: v5.03.00.00.11.3-k0 (FATE#313902).
- scsi: fix various printk and comment typos (FATE#313902).
- qla4xxx: Disable generating pause frames for ISP83XX
  (FATE#313902).
- qla4xxx: Fix double clearing of risc_intr for ISP83XX
  (FATE#313902).
- qla4xxx: IDC implementation for Loopback (FATE#313902).
- qla4xxx: Fix panic while rmmod (FATE#313902).
- qla4xxx: Fail probe_adapter if IRQ allocation fails
  (FATE#313902).
- qla4xxx: Prevent MSI/MSI-X falling back to INTx for ISP82XX
  (FATE#313902).
- qla4xxx: Update idc reg in case of PCI AER (FATE#313902).
- qla4xxx: Fix double IDC locking in qla4_8xxx_error_recovery
  (FATE#313902).
- qla4xxx: Clear interrupt while unloading driver for ISP83XX
  (FATE#313902).
- qla4xxx: Print correct IDC version (FATE#313902).
- qla4xxx: Added new mbox cmd to pass driver version to FW
  (FATE#313902).
- qla4xxx: Update Copyright header (FATE#313902).
- qla4xxx: Added support for ISP83XX (FATE#313902).
- qla4xxx: Added new function qla4_8xxx_get_minidump
  (FATE#313902).
- qla4xxx: Set IDC version in correct way (FATE#313902).
- qla4xxx: Replace all !is_qla8022() with is_qla40XX()
  (FATE#313902).
- qla4xxx: Added new functions in isp_ops (FATE#313902).
- qla4xxx: Clean-up and optimize macros (FATE#313902).
- qla4xxx: Rename 82XX macros (FATE#313902).
- qla4xxx: Update func name from ql4_ to qla4_ (FATE#313902).
- qla4xxx: Update structure and variable names (FATE#313902).
- qla4xxx: Update function name from 8xxx to 82xx (FATE#313902).
- qla4xxx: Wait for cmd to complete before chip reset for ISP40XX
  (FATE#313902).
- qla4xxx: Clear interrupt while unloading driver (FATE#313902).
- qla4xxx: Fix lockdep warning in qla4xxx_post_work()
  (FATE#313902).
- qla4xxx: Properly handle SCSI underrun while processing status
  IOCBs (FATE#313902).
- qla4xxx: Fix multiple conn login event issue during session
  recovery (FATE#313902).
- qla4xxx: Fix gcc warning for x86 system (FATE#313902).
- qla4xxx: Fix memory corruption issue in qla4xxx_ep_connect
  (FATE#313902).
- qla4xxx: remove unnecessary read of PCI_CAP_ID_EXP
  (FATE#313902).
- qla4xxx: Fix Spell check (FATE#313902).
- qla4xxx: Fix a Sparse warning message (FATE#313902).
- qla4xxx: multi-session fix for flash ddbs (FATE#313902).
- qla4xxx: Add missing spaces to error messages (FATE#313902).
- qla4xxx: Remove unused code (FATE#313902).
- qla4xxx: Capture minidump for ISP82XX on firmware failure
  (FATE#313902).
- qla4xxx: Add change_queue_depth API support (FATE#313902).
- qla4xxx: Fix clear ddb mbx command failure issue (FATE#313902).
- qla4xxx: Fix kernel panic during discovery logout (FATE#313902).
- qla4xxx: Correct early completion of pending mbox (FATE#313902).
- atp870u, mpt2sas, qla4xxx use pci_dev->revision (FATE#313902).
- qla4xxx: Removed packed attr from struct iscsi_chap_rec
  (FATE#313902).
- iscsi_transport: Added error status code for ping comp event
  (FATE#313902).
- qla4xxx: assign correct address for iscsi_cls_host
  (FATE#313902).
- qla4xxx: trivial cleanup (FATE#313902).
- qla4xxx: Fix sparse warning (FATE#313902).
- qla4xxx: Add support for multiple session per host
  (FATE#313902).
- qla4xxx: Export CHAP index as sysfs attribute (FATE#313902).
- scsi_transport: Export CHAP index as sysfs attribute
  (FATE#313902).
- qla4xxx: Add support to display CHAP list and delete CHAP entry
  (FATE#313902).
- iscsi_transport: Add support to display CHAP list and delete
  CHAP entry (FATE#313902).
- qla4xxx: Added support to show port_state and port_speed in
  sysfs (FATE#313902).
- scsi_transport_iscsi: Added support to show port_state and
  port_speed in sysfs (FATE#313902).
- qla4xxx: Added support to show targetalias in sysfs
  (FATE#313902).
- libiscsi: Added support to show targetalias in sysfs
  (FATE#313902).
- qla4xxx: Added ping support (FATE#313902).
- iscsi_transport: Added Ping support (FATE#313902).
- qla4xxx: added support for host event (FATE#313902).
- scsi_transport_iscsi: added support for host event
  (FATE#313902).
- qla4xxx: Proper detection of firmware abort error code for
  ISP82xx (FATE#313902).
- qla4xxx: Modified debug log messages for boot info
  (FATE#313902).
- commit 43bce06
* Wed Dec 12 2012 dsterba@suse.cz
  update btrfs to 3.5
- btrfs/ctree.c: remove the unnecessary 'return -1;' at the end
  of bin_search.
- Btrfs: fix btrfs_release_extent_buffer_page with the right
  usage of num_extent_pages.
- Btrfs: fix the comment for find_first_extent_bit.
- Btrfs: remove the useless assignment to *entry in function
  tree_insert of file extent_io.c.
- Btrfs: change integrity checker to support big blocks.
- Btrfs: cleanup: use consistent lock naming.
- Btrfs: use i_version instead of our own sequence.
- Btrfs: cache no acl on new inodes.
- Btrfs: remove useless waiting and extra filemap work.
- Btrfs: do not do filemap_write_and_wait_range in fsync.
- btrfs: allow changing 'thread_pool' size at remount time.
- Fix minor type issues.
- Btrfs: avoid buffer overrun in btrfs_printk.
- Btrfs: NUL-terminate path buffer in DEV_INFO ioctl result.
- Btrfs: avoid buffer overrun in mount option handling.
- Btrfs: do not check delalloc when updating disk_i_size.
- Btrfs: finish ordered extents in their own thread.
- Btrfs: fix wrong error returned by adding a device.
- Btrfs: use fastpath in extent state ops as much as possible.
- Btrfs: do not do balance in readonly mode.
- Btrfs: merge contigous regions when loading free space cache.
- Btrfs: convert the inode bit field to use the actual bit
  operations.
- Btrfs: fix how we deal with the orphan block rsv.
- Btrfs: fall back to non-inline if we don't have enough space.
- Btrfs: fix the same inode id problem when doing auto defragment.
- btrfs: Drop unused function btrfs_abort_devices().
- Btrfs: add device counters for detected IO and checksum errors.
- Btrfs: add ioctl to get and reset the device stats.
- Btrfs: read device stats on mount, write modified ones during
  commit.
- Btrfs: return value of btrfs_read_buffer is checked correctly.
- Btrfs: check to see if the inode is in the log before fsyncing.
- Btrfs: fix return code in drop_objectid_items.
- Btrfs: set ioprio of scrub readahead to idle.
- Btrfs: fix runtime warning in check-integrity check data mode.
- Btrfs: fix false positive in check-integrity on unmount.
- Btrfs: ulist realloc bugfix.
- Btrfs: bugfix in btrfs_find_parent_nodes.
- Btrfs: bugfix: ignore the wrong key for indirect tree block
  backrefs.
- Btrfs: look into the extent during find_all_leafs.
- Btrfs: don't set for_cow parameter for tree block functions.
- Btrfs: move struct seq_list to ctree.h.
- Btrfs: dummy extent buffers for tree mod log.
- Btrfs: add tree mod log to fs_info.
- Btrfs: add tree modification log functions.
- Btrfs: put all block modifications into the tree mod log.
- Btrfs: add del_ptr and insert_ptr modifications to the tree
  mod log.
- Btrfs: add btrfs_search_old_slot.
- Btrfs: use the tree modification log for backref resolving.
- Btrfs: fs_info variable for join_transaction.
- Btrfs: tree mod log sanity checks in join_transaction.
- Btrfs: use delayed ref sequence numbers for all fs-tree updates.
- Btrfs: add inodes before dropping the extent lock in
  find_all_leafs.
- Btrfs: add missing spin_lock for insertion into tree mod log.
- Btrfs: add tree_mod_dont_log helper.
- Btrfs: fix tree mod log del_ptr.
- Btrfs: fix tree mod log rewinded level and rewinding of
  moved keys.
- btrfs: trivial endianness annotations.
- Btrfs: move over to use ->update_time.
- Btrfs: pass locked_page into extent_clear_unlock_delalloc if
  theres an error.
- Btrfs: fix locking in btrfs_destroy_delayed_refs.
- Btrfs: wake up transaction waiters when aborting a transaction.
- Btrfs: abort the transaction if the commit fails.
- Btrfs: fix btrfs_destroy_marked_extents.
- Btrfs: unlock everything properly in the error case for nocow.
- Btrfs: use rcu to protect device->name.
- Btrfs: implement ->show_devname.
- Btrfs: keep inode pinned when compressing writes.
- Btrfs: call filemap_fdatawrite twice for compression.
- Btrfs: fix defrag regression.
- Btrfs: fix incompat flags setting.
- Btrfs: remove call to btrfs_header_nritems with no effect.
- Btrfs: remove obsolete btrfs_next_leaf call from
  __resolve_indirect_ref.
- Btrfs: use btrfs_read_lock_root_node in get_old_root.
- Btrfs: fix return value for __tree_mod_log_oldest_root.
- Btrfs: add btrfs_next_old_leaf.
- Btrfs: fix race in tree mod log addition.
- Btrfs: fix missing inherited flag in rename.
- Btrfs: do not resize a seeding device.
- Btrfs: avoid memory leak of extent state in error handling
  routine.
- Btrfs: make sure that we've made everything in pinned tree
  clean.
- Btrfs: destroy the items of the delayed inodes in error
  handling routine.
- Btrfs: cast devid to unsigned long long for printk %%llu.
- Btrfs: introduce btrfs_next_old_item.
- Btrfs: don't assume to be on the correct extent in
  add_all_parents.
- Btrfs: add a missing spin_lock.
- Btrfs: delay iput with async extents.
- Btrfs: avoid waiting for delayed refs when we must not.
- Btrfs: support root level changes in __resolve_indirect_ref.
- Btrfs: fix tree mod log for root replacements at leaf level.
- Btrfs: always put insert_ptr modifications into the tree
  mod log.
- Btrfs: leave critical region in btrfs_find_all_roots as soon
  as possible.
- Btrfs: fix tree mod log rewind of ADD operations.
- Btrfs: resolve tree mod log locking issue in btrfs_next_leaf.
- Btrfs: don't count I/O statistic read errors for missing
  devices.
- Btrfs: fix dio write vs buffered read race.
- Btrfs: restore restriper state on all mounts.
- Btrfs: resume balance on rw (re)mounts properly.
- Btrfs: use _IOR for BTRFS_IOC_SUBVOL_GETFLAGS.
- Btrfs: fix wrong check during log recovery.
- Btrfs: fix tree log remove space corner case.
- Btrfs: hold a ref on the inode during writepages.
- fs: introduce inode operation ->update_time.
- Refresh
  patches.suse/0002-btrfs-Introduce-btrfs_get_maps_dev.patch.
- Refresh
  patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch.
- Refresh
  patches.suse/btrfs-8018-use-irqsave-spinlocks-everywhere.patch.
- Refresh
  patches.suse/btrfs-8076-fix-deadlock-when-the-process-of-delayed-refs-.patch.
- Refresh
  patches.suse/btrfs-8120-return-error-of-btrfs_update_inode-to-caller.patch.
- Refresh
  patches.suse/btrfs-8123-kill-root-from-btrfs_is_free_space_inode.patch.
- Refresh
  patches.suse/btrfs-8131-fix-enospc-problems-when-deleting-a-subvol.patch.
- Refresh
  patches.suse/btrfs-8134-update-last-trans-if-we-don-t-update-the-inode.patch.
- Refresh patches.suse/btrfs-8142-fix-unprotected-log_batch.patch.
- Refresh
  patches.suse/btrfs-8160-move-transaction-aborts-to-the-point-of-failur.patch.
- Refresh
  patches.suse/btrfs-8170-do-not-async-metadata-csumming-in-certain-situ.patch.
- Refresh
  patches.suse/btrfs-8172-cache-extent-state-when-writing-out-dirty-meta.patch.
- Refresh
  patches.suse/btrfs-8176-make-filesystem-read-only-when-submitting-barr.patch.
- Refresh patches.suse/btrfs-update-message-levels.patch.
- Delete
  patches.suse/btrfs-8050-set-ioprio-of-scrub-readahead-to-idle.patch.
- Delete
  patches.suse/btrfs-8066-avoid-buffer-overrun-in-btrfs_printk.patch.
- Delete
  patches.suse/btrfs-8066-fall-back-to-non-inline-if-we-don-t-have-enoug.patch.
- Delete
  patches.suse/btrfs-8067-NUL-terminate-path-buffer-in-DEV_INFO-ioctl-re.patch.
- Delete
  patches.suse/btrfs-8068-avoid-buffer-overrun-in-mount-option-handling.patch.
- Delete
  patches.suse/btrfs-8070-do-not-do-balance-in-readonly-mode.patch.
- Delete
  patches.suse/btrfs-8072-fix-the-same-inode-id-problem-when-doing-auto-.patch.
- Delete
  patches.suse/btrfs-8073-fix-wrong-error-returned-by-adding-a-device.patch.
- Delete
  patches.suse/btrfs-8074-use-fastpath-in-extent-state-ops-as-much-as-po.patch.
- Delete
  patches.suse/btrfs-8075-convert-the-inode-bit-field-to-use-the-actual-.patch.
- Delete
  patches.suse/btrfs-8078-avoid-memory-leak-of-extent-state-in-error-han.patch.
- Delete
  patches.suse/btrfs-8079-make-sure-that-we-ve-made-everything-in-pinned.patch.
- Delete
  patches.suse/btrfs-8080-destroy-the-items-of-the-delayed-inodes-in-err.patch.
- Delete patches.suse/btrfs-8081-ulist-realloc-bugfix.patch.
- Delete
  patches.suse/btrfs-8082-bugfix-in-btrfs_find_parent_nodes.patch.
- Delete
  patches.suse/btrfs-8083-bugfix-ignore-the-wrong-key-for-indirect-tree-.patch.
- Delete
  patches.suse/btrfs-8084-do-not-update-atime-for-RO-snapshots.patch.
- Delete
  patches.suse/btrfs-8085-fix-return-code-in-drop_objectid_items.patch.
- Delete
  patches.suse/btrfs-8086-check-to-see-if-the-inode-is-in-the-log-before.patch.
- Delete
  patches.suse/btrfs-8087-pass-locked_page-into-extent_clear_unlock_dela.patch.
- Delete
  patches.suse/btrfs-8089-fix-locking-in-btrfs_destroy_delayed_refs.patch.
- Delete
  patches.suse/btrfs-8090-wake-up-transaction-waiters-when-aborting-a-tr.patch.
- Delete
  patches.suse/btrfs-8091-abort-the-transaction-if-the-commit-fails.patch.
- Delete
  patches.suse/btrfs-8092-fix-btrfs_destroy_marked_extents.patch.
- Delete
  patches.suse/btrfs-8093-unlock-everything-properly-in-the-error-case-f.patch.
- Delete
  patches.suse/btrfs-8097-fix-btrfs_release_extent_buffer_page-with-the-.patch.
- Delete
  patches.suse/btrfs-8098-do-not-check-delalloc-when-updating-disk_i_siz.patch.
- Delete
  patches.suse/btrfs-8102-look-into-the-extent-during-find_all_leafs.patch.
- Delete
  patches.suse/btrfs-8103-don-t-set-for_cow-parameter-for-tree-block-fun.patch.
- Delete patches.suse/btrfs-8105-fix-defrag-regression.patch.
- Delete
  patches.suse/btrfs-8106-fix-missing-inherited-flag-in-rename.patch.
- Delete
  patches.suse/btrfs-8107-do-not-resize-a-seeding-device.patch.
- Delete
  patches.suse/btrfs-8108-cast-devid-to-unsigned-long-long-for-printk-ll.patch.
- Delete patches.suse/btrfs-8109-add-a-missing-spin_lock.patch.
- Delete
  patches.suse/btrfs-8111-restore-restriper-state-on-all-mounts.patch.
- Delete
  patches.suse/btrfs-8112-resume-balance-on-rw-re-mounts-properly.patch.
- Delete
  patches.suse/btrfs-8114-fix-tree-log-remove-space-corner-case.patch.
- Delete
  patches.suse/btrfs-8115-hold-a-ref-on-the-inode-during-writepages.patch.
- commit 3be3e04
* Wed Dec 12 2012 mgorman@suse.de
- Refresh patches.suse/ia64-mm-wire-up-cross-memory-attach-syscalls.patch.
- Refresh patches.suse/mm-Cross-Memory-Attach.patch.
- Refresh patches.suse/mm-Fix-race-in-process_vm_rw_core.patch.
- Refresh patches.suse/mm-aio-vfs-cleanup-of-rw_copy_check_uvector-and-compat_rw_copy_check_uvector.patch.
- Refresh patches.suse/s390-mm-wire-up-cross-memory-attach-syscalls.patch.
  Correct format of Patch-mainline metatag
- commit 1ed51f0
* Wed Dec 12 2012 dsterba@suse.cz
- Refresh patches.suse/btrfs-0429-check-return-value-of-bio_alloc-properly.patch.
- Refresh
  patches.suse/btrfs-0473-ensure-an-entire-eb-is-written-at-once.patch.
- commit 806ed08
* Wed Dec 12 2012 neilb@suse.de
- patches.fixes/NFS-fix-recent-breakage-to-NFS-error-handling.patch:
  NFS - fix recent breakage to NFS error handling (bnc#793104).
- patches.fixes/md-close-remove-add-race: md: close race between
  removing and adding a device (bnc#787848).
- commit cc60902
* Wed Dec 12 2012 dsterba@suse.cz
- patches.suse/btrfs-0441-don-t-return-EINTR.patch: Refresh.
- patches.suse/btrfs-0450-avoid-deadlocks-from-GFP_KERNEL-allocations-du.patch:
  Refresh.
- patches.suse/btrfs-0457-fix-race-in-reada.patch: Refresh.
- patches.suse/btrfs-enospc-debugging-messages.patch: Refresh.
- patches.suse/btrfs-handle-EIO: Refresh.
- patches.suse/btrfs-update-message-levels.patch: Refresh.
- commit 82a3380
* Tue Dec 11 2012 ohering@suse.de
- Drivers: hv: balloon: Fix a memory leak.
- commit f54b59a
* Tue Dec 11 2012 bpoirier@suse.de
- cxgb4: Fix initialization of SGE_CONTROL register (bnc#784800
  FATE#314296).
- cxgb4: Initialize data structures before using (bnc#784800
  FATE#314296).
- cxgb4: Fix unable to get UP event from the LLD (bnc#784800
  FATE#314296).
- cxgb4: Remove unnecessary #ifdef condition (bnc#784800
  FATE#314296).
- ethtool: Define and apply a default policy for RX flow hash
  indirection (bnc#784800 FATE#314296).
- ethtool: Clarify use of size field for ETHTOOL_GRXFHINDIR
  (bnc#784800 FATE#314296).
- commit 43729e2
* Tue Dec 11 2012 dsterba@suse.cz
- Btrfs: fix warning for 32-bit build of
  fs/btrfs/check-integrity.c.
- Btrfs: fix uninit warning in backref.c.
- Refresh
  patches.suse/btrfs-8083-bugfix-ignore-the-wrong-key-for-indirect-tree-.patch.
- commit f7a4225
* Tue Dec 11 2012 ohering@suse.de
- Update patch headers for fate314663 and fate314665 changes
- commit e13df45
* Tue Dec 11 2012 mmarek@suse.cz
- rpm/gitlog-fixups: Fix some changelog entries
- commit 4440128
* Tue Dec 11 2012 mgorman@suse.de
- s390/compat: fix compat wrappers for process_vm system calls -fix.
- commit 0c0fb6f
* Tue Dec 11 2012 hare@suse.de
- mpt2sas: Bump driver vesion to 14.100.00.00 (FATE#313896).
- mpt2sas: Fix for With post diag reset same set of device gets
  added, removed and then again gets added with new target ids
  (FATE#313896).
- mpt2sas: Fix for staged device discovery functionality of
  driver not working (FATE#313896).
- mpt2sas : MPI 2.0 Rev V(2.0.14) specification (FATE#313896).
- mpt2sas: Fix for max_sectors warning message is stating the
  incorrect range (FATE#313896).
- mpt2sas: Provide sysfs attribute to report Backup Rail Monitor
  Status (FATE#313896).
- mpt2sas: To include more Intel Branding (FATE#313896).
- mpt2sas: 2012 source code copyright (FATE#313896).
- mpt2sas: Fix for hard drive going OFFLINE when hard reset
  issued and simultaneously another hard drive is hot unplugged
  (FATE#313896).
- mpt2sas: Set the phy identifier of the end device to the phy
  number of the parent device it is linked to (FATE#313896).
- mpt2sas : While enabling phy, read the current port number
  from sas iounit page 0 instead of page 1 (FATE#313896).
- mpt2sas: Fix linux driver sparse errors (FATE#313896).
- mpt2sas: Fix security scan issues reported by source code
  analysis tool (FATE#313896).
- mpt2sas: Improvement were made to better protect the sas_device,
  raid_device, and expander_device lists (FATE#313896).
- mpt2sas : Perform Target Reset instead of HBA reset when a
  SATA_PASSTHROUGH cmd timeout happens (FATE#313896).
- mpt2sas: Added multisegment mode support for Linux BSG Driver
  (FATE#313896).
- mpt2sas: Removed redundant global mutex for IOCTLs
  (FATE#313896).
- mpt2sas: MPI next revision header update (FATE#313896).
- mpt2sas: remove extraneous sas_log_info messages (FATE#313896).
- mpt2sas: spell "primitive" correctly in function prototype
  (FATE#313896).
- mpt2sas: add missing allocation check (FATE#313896).
- mpt2sas: Fix mismatch in mpt2sas_base_hard_reset_handler()
  mutex lock-unlock (FATE#313896).
- mpt2sas: Removed redundant calling of _scsih_probe_devices()
  from _scsih_probe (FATE#313896).
- mpt2sas: Remove unused duplicate diag_buffer_enable param
  (FATE#313896).
- mpt2sas: Fix possible integer truncation of cpu_count
  (FATE#313896).
- mpt2sas: Fix leak on mpt2sas_base_attach() error path
  (FATE#313896).
- mpt2sas: Do not retry a timed out direct IO for warpdrive
  (FATE#313896).
- mpt2sas: MPI next revision header update (FATE#313896).
- mpt2sas: Added support for customer specific branding
  (FATE#313896).
- mpt2sas: Increase max transfer support from 4MB to 16MB
  (FATE#313896).
- mpt2sas: Support for greater than 2TB capacity WarpDrive
  (FATE#313896).
- mpt2sas: Do not set sas_device->starget to NULL from the
  slave_destroy callback when all the LUNS have been deleted
  (FATE#313896).
- mpt2sas: MPI next revision header update (FATE#313896).
- mpt2sas: Adding support for customer specific branding
  (FATE#313896).
- mpt2sas: When IOs are terminated, update the result to
  DID_SOFT_ERROR to avoid infinite resets (FATE#313896).
- mpt2sas: Better handling DEAD IOC (PCI-E LInk down) error
  condition (FATE#313896).
- mpt2sas: add missing allocation (FATE#313896).
- mpt2sas: Fix for Panic when inactive volume is tried deleting
  (FATE#313896).
- mpt2sas: Fix for issue Port Reset taking long time(around
  5 mins) to complete while issued during creating a volume
  (FATE#313896).
- mpt2sas: Fix for deadlock between hot plug worker threads and
  host reset context (FATE#313896).
- mpt2sas: Fix for dead lock occurring between host_lock and
  sas_device_lock (FATE#313896).
- mpt2sas: Fix drives not getting properly deleted if sas cable
  is removed while host reset is active (FATE#313896).
- mpt2sas: Fix failure message displayed during diag reset
  (FATE#313896).
- mpt2sas: New feature - Fast Load Support (FATE#313896).
- mpt2sas: MPI next revision header update (FATE#313896).
- mpt2sas: take size of pointed value, not pointer (FATE#313896).
- mpt2sas: Added NUNA IO support in driver which uses multi-reply
  queue support of the HBA (FATE#313896).
- mpt2sas: WarpDrive Infinite command retries due to wrong scsi
  command entry in MPI message (FATE#313896).
- commit 1e83ea7
* Tue Dec 11 2012 mgorman@suse.de
- Cross Memory Attach.
- ia64: Wire up cross memory attach syscalls.
- Fix race in process_vm_rw_core.
- aio/vfs: cleanup of rw_copy_check_uvector() and compat_rw_copy_check_uvector().
- s390/compat: fix compat wrappers for process_vm system calls.
- s390: wire up process_vm syscalls.
- Refresh patches.suse/perfmon2-remove_syscalls.patch.
- Refresh patches.suse/perfmon2.patch.
  Cross Memory Attach (fate#314115,fate#314242)
- commit 19fc474
* Mon Dec 10 2012 dsterba@suse.cz
  fix build error in btrfs
- Refresh
  patches.suse/btrfs-0473-ensure-an-entire-eb-is-written-at-once.patch.
- Refresh
  patches.suse/btrfs-0477-deal-with-read-errors-on-extent-buffers-differ.patch.
- Refresh
  patches.suse/btrfs-8170-do-not-async-metadata-csumming-in-certain-situ.patch.
- Refresh
  patches.suse/btrfs-8182-Use-btrfs_update_inode_fallback-when-creating-.patch.
- Delete
  patches.suse/btrfs-0482-fix-uninit-variable-in-repair_eb_io_failure.patch.
- commit eb4da07
* Mon Dec 10 2012 dsterba@suse.cz
  add btrfs features up to 3.4
- Btrfs: allow metadata blocks larger than the page size.
- Btrfs: set page->private to the eb.
- Btrfs: only use the existing eb if it's count isn't 0.
- Btrfs: introduce free_extent_buffer_stale.
- Btrfs: introduce mark_extent_buffer_accessed.
- Btrfs: ensure an entire eb is written at once.
- Btrfs: add the ability to cache a pointer into the eb.
- Btrfs: loop waiting on writeback.
- Btrfs: don't use threaded IO completion helpers for metadata
  writes.
- Btrfs: deal with read errors on extent buffers differently.
- Btrfs: introduce common define for max number of mirrors.
- Btrfs: minor cleanup in scrub.
- Btrfs: change scrub to support big blocks.
- Btrfs: don't use crc items bigger than 4KB.
- Btrfs: fix uninit variable in repair_eb_io_failure.
- Btrfs: always store the mirror we read the eb from.
- Btrfs: don't count CRC or header errors twice while scrubbing.
- Btrfs: fix page leak when allocing extent buffers.
- Btrfs: fix crash in scrub repair code when device is missing.
- Refresh
  patches.suse/btrfs-0427-update-the-checks-for-mixed-block-groups-with-.patch.
- Refresh
  patches.suse/btrfs-0429-check-return-value-of-bio_alloc-properly.patch.
- Refresh
  patches.suse/btrfs-0444-fix-that-check_int_data-mount-option-was-ignor.patch.
- Refresh
  patches.suse/btrfs-0462-avoid-sleeping-in-verify_parent_transid-while-.patch.
- Refresh
  patches.suse/btrfs-8018-use-irqsave-spinlocks-everywhere.patch.
- Refresh
  patches.suse/btrfs-8020-simplify-move_pages-and-copy_pages.patch.
- Refresh
  patches.suse/btrfs-8062-push-up-errors-in-btrfs-num-copies.patch.
- Refresh
  patches.suse/btrfs-8097-fix-btrfs_release_extent_buffer_page-with-the-.patch.
- Refresh
  patches.suse/btrfs-8103-don-t-set-for_cow-parameter-for-tree-block-fun.patch.
- Refresh
  patches.suse/btrfs-8160-move-transaction-aborts-to-the-point-of-failur.patch.
- Refresh
  patches.suse/btrfs-8170-do-not-async-metadata-csumming-in-certain-situ.patch.
- Refresh
  patches.suse/btrfs-8179-do-not-warn_on-when-we-cannot-alloc-a-page-for.patch.
- Refresh patches.suse/btrfs-add-btrfs_panic.
- Refresh patches.suse/btrfs-scrub-functions-should-return-void.
- Refresh patches.suse/btrfs-update-message-levels.patch.
- Refresh
  patches.suse/btrfs-volumes-schedule_bio-should-return-void.
- commit 684a899
* Mon Dec 10 2012 mhocko@suse.cz
- patches.fixes/thp-memcg-split-hugepage-for-memcg-oom-on-cow.patch:
  thp, memcg: split hugepage for memcg oom on cow (bnc#793671).
- commit dc3e908
* Mon Dec 10 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Copy any module signing files from
  %%_sourcedir, not just extra_certificates (fate#314508).
- commit 49eee26
* Fri Dec  7 2012 dsterba@suse.cz
- Btrfs: add optional integrity check code.
- Btrfs: add config option to enable btrfs integrity check.
- Btrfs: Makefile changes to optionally include btrfs integrity
  check.
- Btrfs: integrate integrity check module into btrfs.
- Update config files.
- commit b88b20d
* Fri Dec  7 2012 trenn@suse.de
- Delete patches.drivers/023-mei_driver_updates.patch.
- Delete patches.drivers/041-mei_driver_updates.patch.
- commit 3be8c3f
* Fri Dec  7 2012 jbohac@suse.cz
- patches.fixes/bonding-delete-migrated-IP-addresses-from-the-rlb-ha.patch:
  bonding: delete migrated IP addresses from the rlb hash table
  (bnc#729854).
- commit 7ebe928
* Fri Dec  7 2012 trenn@suse.de
- ACPI, APEI, EINJ, new parameter to control trigger action
  (bnc#788160).
- ACPI, APEI, EINJ, limit the range of einj_param (bnc#788160).
- Use acpi_os_map_memory() instead of ioremap() in einj driver
  (bnc#788160).
- ACPI, APEI, EINJ, cleanup 0 vs NULL confusion (bnc#788160).
- acpi/apei/einj: Add extensions to EINJ from rev 5.0 of acpi spec
  (bnc#788160).
- ACPI, APEI, EINJ Allow empty Trigger Error Action Table
  (bnc#788160).
- ACPI, APEI, EINJ, Refine the fix of resource conflict
  (bnc#788160).
- ACPI, APEI, EINJ, Fix resource conflict on some machine
  (bnc#788160).
- ACPI, APEI, Print resource errors in conventional format
  (bnc#788160).
- commit 9cc1799
* Fri Dec  7 2012 dsterba@suse.cz
- Refresh
  patches.suse/btrfs-0409-add-__get_block_group_index-helper.patch.
- Refresh
  patches.suse/btrfs-8165-remove-bytes-argument-from-do_chunk_alloc.patch.
- Refresh patches.suse/btrfs-handle-EIO.
- commit 27c4327
* Fri Dec  7 2012 dsterba@suse.cz
- enable two btrfs patches (remove ideal space caching mode)
- commit f6c7dbb
* Fri Dec  7 2012 hare@suse.de
- supported.conf: mark nvme as unsupported (FATE#313627)
- commit 903b075
* Fri Dec  7 2012 tonyj@suse.de
- x86, intel: Output microcode revision in /proc/cpuinfo
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- x86, perf: Clean up perf_event cpu code (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: Remove the nmi parameter from the swevent and overflow
  interface (bnc#789200, fate#313753, fate#312066, fate#313762).
- commit 590ba01
* Fri Dec  7 2012 jlee@suse.com
- trusted-keys: check hex2bin result (fate#314508).
- commit 4329c9b
* Fri Dec  7 2012 tonyj@suse.de
- perf: Split up buffer handling from core code (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf_events: Fix perf buffer watermark setting (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: Remove 64-bit alignment padding from perf_event_context
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- events: Add note to update_event_times comment about holding
  ctx->lock (bnc#789200, fate#313753, fate#312066, fate#313762).
- events: Move lockless timer calculation into helper function
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- events: Ensure that timers are updated without requiring read()
  call (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf, x86: Add hw_watchdog_set_attr() in a sake of nmi-watchdog
  on P4 (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Remove the nmi parameter from the swevent and overflow
  interface (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf, powerpc: Fix build borkage (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf: Remove the perf_output_begin(.sample) argument
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf_events: Update Intel extra regs shared constraints
  management (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf_events: Fix validation of events using an extra reg
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf_events: Add Intel Sandy Bridge offcore_response low-level
  support (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf, intel: Try alternative OFFCORE encodings (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf, arch: Add generic NODE cache events (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: Add context field to perf_event (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- x86, perf: Add constraints for architectural PMU (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: export perf_event_refresh() to modules (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf, x86: P4 PMU - Introduce event alias feature (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- x86, perf: P4 PMU - Fix typos in comments and style cleanup
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Remove perf_event_attr::type check (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- x86, perf: Make copy_from_user_nmi() a library function
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf, x86: Avoid kfree() in CPU_STARTING (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: provide PMU when initing events (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf_event: Fix broken calc_timer_values() (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- x86, perf: Clean up perf_event cpu code (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- x86: Perf_event_amd.c needs <asm/apicdef.h> (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf, core: Introduce attrs to count in either host or guest
  mode (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf, amd: Use GO/HO bits in perf-ctr (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf, intel: Use GO/HO bits in perf-ctr (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- x86, intel: Output microcode revision in /proc/cpuinfo
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- mm: distinguish between mlocked and pinned pages (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: Don't use -ENOSPC for out of PMU resources (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Enable raw event access to Intel offcore events
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Carve out callchain functionality (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- events: Don't divide events if it has field period (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf, x86: Disable PEBS on SandyBridge chips (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: Fix loss of notification with multi-event (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: Avoid a useless pmu_disable() in the perf-tick
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf, x86: Implement event scheduler helper functions
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf, x86: Fix event scheduler for constraints with overlapping
  counters (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf, x86: Prefer fixed-purpose counters when scheduling
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Remove superfluous arguments (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf: Fix enable_on_exec for sibling events (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- x86, perf: Disable non available architectural events
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf, x86: Implement arch event mask as quirk (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf, x86: Expose perf capability to other modules (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf events: Fix ring_buffer_wakeup() brown paperbag bug
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf events: Enable raw event support for Intel
  unhalted_reference_cycles event (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf events: Add PERF_COUNT_HW_REF_CPU_CYCLES generic PMU event
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf events: Add Intel x86 mapping for
  PERF_COUNT_HW_REF_CPU_CYCLES (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf: Update the mmap control page on mmap() (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf, arch: Rework perf_event_index() (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf: Fix mmap_page::offset computation (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf, x86: Implement user-space RDPMC support, to allow fast,
  user-space access to self-monitoring counters (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf, x86: Provide means for disabling userspace RDPMC
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Extend the mmap control page with time (TSC) fields
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Fix raw_spin_unlock_irqrestore() usage (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: Don't call release_callchain_buffers() if allocation fails
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Call perf_cgroup_event_time() directly (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: Fix broken interrupt rate throttling (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: Remove deprecated WARN_ON_ONCE() (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf: Fix double start/stop in x86_pmu_start() (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- ftrace: Add FTRACE_ENTRY_REG macro to allow event registration
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- ftrace, perf: Add support to use function tracepoint in perf
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- ftrace: Fix dynamic selftest failure on some archs (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- tracing: Still trace filtered irq functions when irq trace is
  disabled (bnc#789200, fate#313753, fate#312066, fate#313762).
- tracing/kprobes: Rename probe_* to trace_probe_* (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- tracing/kprobes: Merge trace probe enable/disable functions
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- ftrace: Add enable/disable ftrace_ops control interface
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- ftrace, perf: Add open/close tracepoint perf registration
  actions (bnc#789200, fate#313753, fate#312066, fate#313762).
- ftrace, perf: Add add/del tracepoint perf registration actions
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/hwbp: Fix a possible memory leak (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf: Add generic taken branch sampling support (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Add Intel LBR MSR definitions (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Add Intel LBR sharing logic (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf/x86: Sync branch stack sampling with precise_sampling
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Add Intel LBR mappings for PERF_SAMPLE_BRANCH filters
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Disable LBR support for older Intel Atom processors
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Implement PERF_SAMPLE_BRANCH for Intel CPUs
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Add LBR software filter support for Intel CPUs
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Add callback to flush branch_stack on context switch
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Fix local vs remote memory events for NHM/WSM
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Prettify pmu config literals (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf: Adding sysfs group format attribute for pmu device
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86/kvm: Fix Host-Only/Guest-Only counting with SVM
  disabled (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Fix mmap_page capabilities and docs (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- bitops: rename for_each_set_bit_cont() in favor of analogous
  list.h function (bnc#789200, fate#313753, fate#312066,
  fate#313762).
- perf: Move mmap page data_head offset assertion out of header
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86/p4: Add format attributes (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf: Fix perf_event_for_each() to use sibling (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: Trivial cleanup of duplicate code (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf: Pass last sampling period to perf_sample_data_init()
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- x86: use generic strncpy_from_user routine (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Fix Intel shared extra MSR allocation (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Implement cycles:p for SNB/IVB (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Enable/Add IvyBridge hardware support (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Update SNB PEBS constraints (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf/x86: Allow multiple stacks (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf/x86: Check if user fp is valid (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf/x86: Fix wrmsrl() debug wrapper (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- x86: Add rdpmcl() (bnc#789200, fate#313753, fate#312066,
  fate#313762).
- perf/x86: Use rdpmc() rather than rdmsr() when possible in
  the kernel (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Don't assume there can be only 4 PEBS events
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- x86, cpu: Rename checking_wrmsrl() to wrmsrl_safe() (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Convert obsolete simple_strtoul() usage to kstrtoul()
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86/amd: Fix RDPMC index calculation for AMD family 15h
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Use css_tryget() to avoid propping up css refcount
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Export perf_assign_events() (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf: Avoid race between cpu hotplug and installing event
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Allow the PMU driver to choose the CPU on which to install
  events (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Introduce perf_pmu_migrate_context() (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Add generic Intel uncore PMU support (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Add Intel Nehalem and Sandy Bridge uncore PMU support
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Add generic PCI uncore PMU device support (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Add Intel Nehalem and Sandy Bridge-EP uncore support
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Lowercase uncore PMU event names (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Fix section mismatch in uncore_pci_init() (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Fix USER/KERNEL tagging of samples (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Rename Intel specific macros (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf/x86: Move Intel specific code to intel_pmu_init()
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Improve debug output in check_hw_exists() (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Add a microcode revision check for SNB-PEBS
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Save a few bytes in 'struct x86_pmu' (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Use 0xff as pseudo code for fixed uncore event
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Fix event constraint for SandyBridge-EP C-Box
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Detect number of instances of uncore CBox (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Uncore filter support for SandyBridge-EP (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Fix intel_perfmon_event_mapformatting (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Fix typo in format definition of uncore PCU filter
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Add Intel Nehalem-EX uncore support (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Fix LLC-* and node-* events on Intel SandyBridge
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Make bitfield unsigned (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf/x86: Fix format definition of SNB-EP uncore QPI box
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86/intel/uncore: Make UNCORE_PMU_HRTIMER_INTERVAL 64-bit
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Fix USER/KERNEL tagging of samples properly
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/trace: Add ability to set a target task for events
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf: Fix counter of ftrace events (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- perf, x86: Fix uncore_types_exit section mismatch (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Fixes for Nehalem-EX uncore driver (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Add Intel Westmere-EX uncore support (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: disable PEBS on a guest entry (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/x86: Enable Intel Cedarview Atom suppport (bnc#789200,
  fate#313753, fate#312066, fate#313762).
- perf/hwpb: Invoke __perf_event_disable() if interrupts are
  already disabled (bnc#789200, fate#313753, fate#312066,
  fate#313762).
- perf/x86: Export Sandy Bridge uncore clockticks event in sysfs
  (bnc#789200, fate#313753, fate#312066, fate#313762).
- perf/x86: Fix Intel Ivy Bridge support (bnc#789200, fate#313753,
  fate#312066, fate#313762).
- Refresh patches.xen/xen3-patch-2.6.39.
- commit 8901fb6
* Fri Dec  7 2012 jlee@suse.com
- efi: Build EFI stub with EFI-appropriate options.
- commit 9729df4
* Thu Dec  6 2012 dsterba@suse.cz
  reorder btrfs patches to match 3.4 state
- patches.suse/btrfs-0404-stop-silently-switching-single-chunks-to-raid0.patch:
  Refresh.
- patches.suse/btrfs-0405-add-wrappers-for-working-with-alloc-profiles.patch:
  Refresh.
- patches.suse/btrfs-0406-make-profile_is_valid-check-more-strict.patch:
  Refresh.
- patches.suse/btrfs-0407-move-alloc_profile_is_valid-to-volumes.c.patch:
  Refresh.
- patches.suse/btrfs-0408-add-get_restripe_target-helper.patch:
  Refresh.
- patches.suse/btrfs-0409-add-__get_block_group_index-helper.patch:
  Refresh.
- patches.suse/btrfs-0410-improve-the-logic-in-btrfs_can_relocate.patch:
  Refresh.
- patches.suse/btrfs-0411-validate-target-profiles-only-if-we-are-going-.patch:
  Refresh.
- patches.suse/btrfs-0412-allow-dup-for-data-chunks-in-mixed-mode.patch:
  Refresh.
- patches.suse/btrfs-0413-fix-memory-leak-in-resolver-code.patch:
  Refresh.
- patches.suse/btrfs-0414-fix-infinite-loop-in-btrfs_shrink_device.patch:
  Refresh.
- patches.suse/btrfs-0415-actually-call-btrfs_init_lockdep.patch:
  Refresh.
- patches.suse/btrfs-0417-fix-regression-in-scrub-path-resolving.patch:
  Refresh.
- patches.suse/btrfs-0418-show-useful-info-in-space-reservation-tracepoi.patch:
  Refresh.
- patches.suse/btrfs-0419-flush-out-and-clean-up-any-block-device-pages-.patch:
  Refresh.
- patches.suse/btrfs-0420-fix-deadlock-during-allocating-chunks.patch:
  Refresh.
- patches.suse/btrfs-0421-fix-race-between-direct-io-and-autodefrag.patch:
  Refresh.
- patches.suse/btrfs-0422-fix-the-mismatch-of-page-mapping.patch:
  Refresh.
- patches.suse/btrfs-0423-fix-recursive-defragment-with-autodefrag-optio.patch:
  Refresh.
- patches.suse/btrfs-0424-add-a-check-to-decide-if-we-should-defrag-the-.patch:
  Refresh.
- patches.suse/btrfs-0425-do-not-bother-to-defrag-an-extent-if-it-is-a-b.patch:
  Refresh.
- patches.suse/btrfs-0426-update-to-the-right-index-of-defragment.patch:
  Refresh.
- patches.suse/btrfs-0427-update-the-checks-for-mixed-block-groups-with-.patch:
  Btrfs: update the checks for mixed block groups with big
  metadata blocks (FATE#306586).
- patches.suse/btrfs-0428-fix-eof-while-discarding-extents.patch:
  Refresh.
- patches.suse/btrfs-0429-check-return-value-of-bio_alloc-properly.patch:
  Refresh.
- patches.suse/btrfs-0430-add-missing-free_fs_devices.patch:
  (FATE#306586 FATE#306586).
- patches.suse/btrfs-0431-retrurn-void-from-clear_state_bit.patch:
  Refresh.
- patches.suse/btrfs-0432-avoid-possible-use-after-free-in-clear_extent_.patch:
  Refresh.
- patches.suse/btrfs-0433-Make-free_ipath-deal-gracefully-with-NULL-poin.patch:
  Refresh.
- patches.suse/btrfs-0434-don-t-call-free_extent_buffer-twice-in-iterate.patch:
  Refresh.
- patches.suse/btrfs-0435-add-missing-read-locks-in-backref.c.patch:
  Refresh.
- patches.suse/btrfs-0436-fix-max-chunk-size-check-in-chunk-allocator.patch:
  Refresh.
- patches.suse/btrfs-0440-double-unlock-bug-in-error-handling.patch:
  Refresh.
- patches.suse/btrfs-0441-don-t-return-EINTR.patch: Refresh.
- patches.suse/btrfs-0442-fix-btrfs_ioctl_dev_info-crash-on-missing-devi.patch:
  Refresh.
- patches.suse/btrfs-0444-fix-that-check_int_data-mount-option-was-ignor.patch:
  Refresh.
- patches.suse/btrfs-0445-do-not-start-delalloc-inodes-during-sync.patch:
  Refresh.
- patches.suse/btrfs-0446-fix-repair-code-for-RAID10.patch:
  Refresh.
- patches.suse/btrfs-0447-Prevent-root_list-corruption.patch:
  Refresh.
- patches.suse/btrfs-0448-fix-block_rsv-and-space_info-lock-ordering.patch:
  Refresh.
- patches.suse/btrfs-0449-Fix-space-checking-during-fs-resize.patch:
  Refresh.
- patches.suse/btrfs-0450-avoid-deadlocks-from-GFP_KERNEL-allocations-du.patch:
  Refresh.
- patches.suse/btrfs-0451-reduce-lock-contention-during-extent-insertion.patch:
  Refresh.
- patches.suse/btrfs-0452-Add-properly-locking-around-add_root_to_dirty_.patch:
  Refresh.
- patches.suse/btrfs-0453-Fix-mismatching-struct-members-in-ioctl.h.patch:
  Refresh.
- patches.suse/btrfs-0454-Fix-use-after-free-in-__btrfs_end_transaction.patch:
  btrfs: Fix use-after-free in __btrfs_end_transaction
  (FATE#306586).
- patches.suse/btrfs-0455-use-commit-root-when-loading-free-space-cache.patch:
  Btrfs: use commit root when loading free space cache.
- patches.suse/btrfs-0456-avoid-setting-d_op-twice.patch: Btrfs:
  avoid setting ->d_op twice (FATE#306586 bnc#731387).
- patches.suse/btrfs-0457-fix-race-in-reada.patch: btrfs: fix
  race in reada (FATE#306586).
- patches.suse/btrfs-0458-don-t-add-both-copies-of-DUP-to-reada-extent-t.patch:
  btrfs: don't add both copies of DUP to reada extent tree
  (FATE#306586).
- patches.suse/btrfs-0459-do-not-mount-when-we-have-a-sectorsize-unequal.patch:
  Btrfs: do not mount when we have a sectorsize unequal to
  PAGE_SIZE (FATE#306586).
- patches.suse/btrfs-0460-add-missing-unlocks-to-transaction-abort.patch:
  btrfs: add missing unlocks to transaction abort paths
  (FATE#306586).
- patches.suse/btrfs-0462-avoid-sleeping-in-verify_parent_transid-while-.patch:
  Btrfs: avoid sleeping in verify_parent_transid while atomic
  (FATE#306586).
- patches.suse/btrfs-8061-handle-errors-from-read_tree_block.patch:
  Refresh.
- patches.suse/btrfs-8051-avoid-setting-d_op-twice.patch: Delete.
- patches.suse/btrfs-8053-fix-race-in-reada.patch: Delete.
- patches.suse/btrfs-8054-don-t-add-both-copies-of-DUP-to-reada-extent-t.patch:
  Delete.
- patches.suse/btrfs-8063-error-handling-locking-fixup.patch:
  Delete.
- patches.suse/btrfs-8064-Fix-use-after-free-in-__btrfs_end_transaction.patch:
  Delete.
- patches.suse/btrfs-8065-do-not-mount-when-we-have-a-sectorsize-unequal.patch:
  Delete.
- patches.suse/btrfs-8096-avoid-sleeping-in-verify_parent_transid-while-.patch:
  Delete.
- commit 7e99feb
* Thu Dec  6 2012 jeffm@suse.de
- patches.fixes/xfs-fix-re-use-of-ewouldblock-during-read-on-dm-mirror:
  xfs: Fix re-use of EWOULDBLOCK during read on dm-mirror
  (bnc#736255).
- commit aa6cf9a
* Thu Dec  6 2012 ohering@suse.de
- hyper-v memory ballooning support (fate#314663)
- mm: Export a function to get vm committed memory.
- Drivers: hv: Add Hyper-V balloon driver.
- Drivers: hv: balloon: Fix a bug in the definition of struct
  dm_info_msg.
- Update config files.
  hyper-v: Update the Vmbus protocol (fate#314665)
- Drivers: hv: Implement routines for read side signaling
  optimization.
- Drivers: hv: Add state to manage batched reading.
- Drivers: hv: Turn off batched reading for util drivers.
- Drivers: hv: Optimize signaling in the read path.
- Drivers: hv: Optimize the signaling on the write path.
- Drivers: hv: Get rid of hv_get_ringbuffer_interrupt_mask().
- Drivers: hv: Support handling multiple VMBUS versions.
- Drivers: hv: Update the ring buffer structure to match win8
  functionality.
- Drivers: hv: Extend/modify vmbus_channel_offer_channel for
  win7 and beyond.
- Drivers: hv: Save and export negotiated vmbus version.
- Drivers: hv: Change the signature for hv_signal_event().
- Drivers: hv: Change the signature of vmbus_set_event().
- Drivers: hv: Move vmbus version definitions to hyperv.h.
- Drivers: hv: Manage signaling state on a per-connection basis.
- Drivers: hv: Cleanup vmbus_set_event() to support win7 and
  beyond.
- Drivers: hv: Setup a mapping for Hyper-V's notion cpu ID.
- Drivers: hv: Add state to manage incoming channel interrupt
  load.
- Drivers: hv: Modify the interrupt handling code to support
  win8 and beyond.
- Drivers: hv: Add code to distribute channel interrupt load.
- Drivers: hv: Get rid of the unused global signaling state.
- Drivers: hv: Get rid of unnecessary request for offers.
- Drivers: hv: Manage event tasklets on per-cpu basis.
- Drivers: hv: Handle vmbus interrupts concurrently on all cpus.
- Drivers: hv: Add a check to deal with spurious interrupts.
- Drivers: hv: Enable protocol negotiation with win8 hosts.
- Drivers: hv: Implement flow management on the send side.
- Drivers: hv: Capture the host build information.
- Drivers: hv: Cleanup and consolidate reporting of build/version
  info.
- commit 5289b91
* Thu Dec  6 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add support for additional signing
  certificates stored in an extra_certificates file in the source
  package.
- commit dab5680
* Thu Dec  6 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Install modules in paralel
  With the module signing, make modules_install became a CPU intensive
  task.
- commit bd0401e
* Thu Dec  6 2012 dsterba@suse.cz
  move btrfs error handling patches to the right upstream sequence
- patches.suse/btrfs-0418-show-useful-info-in-space-reservation-tracepoi.patch:
  Refresh.
- patches.suse/btrfs-0441-don-t-return-EINTR.patch: Refresh.
- patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch:
  Refresh.
- patches.suse/btrfs-8018-use-irqsave-spinlocks-everywhere.patch:
  Refresh.
- patches.suse/btrfs-8042-make-btrfs_truncate_inode_items-more-readable.patch:
  Refresh.
- patches.suse/btrfs-async_thread-btrfs_stop_workers-should-return-void:
  Refresh.
- patches.suse/btrfs-btrfs_destroy_ordered_extents-should-return-void:
  Refresh.
- patches.suse/btrfs-btrfs_destroy_ordered_operations-should-return-void:
  Refresh.
- patches.suse/btrfs-btrfs_truncate_item-should-return-void:
  Refresh.
- patches.suse/btrfs-disallow-unequal-data-metadata-blocksize-for-m.patch:
  btrfs: disallow unequal data/metadata blocksize for mixed
  block groups (FATE#306586).
- patches.suse/btrfs-drop-gfp_t-from-lock_extent: Refresh.
- patches.suse/btrfs-enhance-superblock-sanity-checks.patch:
  Btrfs: enhance superblock sanity checks (FATE#306586
  bnc#749651).
- patches.suse/btrfs-handle-EIO: Refresh.
- patches.suse/btrfs-8058-disallow-unequal-data-metadata-blocksize-for-m.patch:
  Delete.
- patches.suse/btrfs-superblock-sanity-checks.patch: Delete.
- commit 6bb3068
* Thu Dec  6 2012 hare@suse.de
- patches.drivers/qla2xxx-Determine-the-number-of-outstanding-commands.patch:
  qla2xxx: Determine the number of outstanding commands based
  on available resources (bnc#782721).
- patches.drivers/qla2xxx-Ramp-down-queue-depth-for-attached-SCSI-devi.patch:
  qla2xxx: Ramp down queue depth for attached SCSI devices
  (bnc#782721).
- commit 06de3d0
* Thu Dec  6 2012 tiwai@suse.de
- patches.drivers/drm-i915-EBUSY-status-handling-added-to-i915_gem_fau:
  drm/i915: EBUSY status handling added to i915_gem_fault()
  (bnc#793139).
- patches.drivers/drm-i915-Only-clear-the-GPU-domains-upon-a-successfu:
  drm/i915: Only clear the GPU domains upon a successful finish
  (bnc#793139).
- patches.drivers/drm-i915-always-use-RPNSWREQ-for-turbo-change-reques:
  drm/i915: always use RPNSWREQ for turbo change requests
  (bnc#793139).
- patches.drivers/drm-i915-don-t-call-modeset_init_hw-in-i915_reset:
  drm/i915: don't call modeset_init_hw in i915_reset (bnc#793139).
- patches.drivers/drm-i915-don-t-hang-userspace-when-the-gpu-reset-is-:
  drm/i915: don't hang userspace when the gpu reset is stuck
  (bnc#793139).
- patches.drivers/drm-i915-don-t-trylock-in-the-gpu-reset-code:
  drm/i915: don't trylock in the gpu reset code (bnc#793139).
- patches.drivers/drm-i915-re-init-modeset-hw-state-after-gpu-reset:
  drm/i915: re-init modeset hw state after gpu reset (bnc#793139).
- commit f4622da
* Thu Dec  6 2012 mmarek@suse.cz
- Update config files.
- commit 15d460d
* Thu Dec  6 2012 neilb@suse.de
- md: raid 10 supports TRIM (FATE#313625).
- md: raid 1 supports TRIM (FATE#313625).
- md: raid 0 supports TRIM (FATE#313625).
- md: linear supports TRIM (FATE#313625).
- commit 5acfe5a
* Wed Dec  5 2012 jeffm@suse.de
- patches.fixes/autofs4-fix-lockdep-splat-in-autofs: autofs4 -
  fix lockdep splat in autofs (bnc#792834).
- commit 3d33392
* Wed Dec  5 2012 bpoirier@suse.de
- cxgb4: Address various sparse warnings (bnc#784800 FATE#314296).
- cxgb4: allocate enough data in t4_memory_rw() (bnc#784800
  FATE#314296).
- cxgb4: Fix build error due to missing linux/vmalloc.h include
  (bnc#784800 FATE#314296).
- cxgb4: Dynamically allocate memory in t4_memory_rw() and
  get_vpd_params() (bnc#784800 FATE#314296).
- cxgb4: Don't attempt to upgrade T4 firmware when cxgb4 will
  end up as a slave (bnc#784800 FATE#314296).
- cxgb4: Inform caller if driver didn't upgrade firmware
  (bnc#784800 FATE#314296).
- cxgb4: Add support for T4 hardwired driver configuration
  settings (bnc#784800 FATE#314296).
- cxgb4: Add support for T4 configuration file (bnc#784800
  FATE#314296).
- cxgb4/cxgb4vf: Code cleanup to enable T4 Configuration File
  support (bnc#784800 FATE#314296).
- cxgb4: Add functions to read memory via PCIE memory window
  (bnc#784800 FATE#314296).
- cxgb4: Fix incorrect values for MEMWIN*_APERTURE and
  MEMWIN*_BASE (bnc#784800 FATE#314296).
- cxgb4: Remove duplicate register definitions (bnc#784800
  FATE#314296).
- drivers/net/ethernet: Fix (nearly-)kernel-doc comments for
  various functions (bnc#784800 FATE#314296).
- cxgb4: set maximal number of default RSS queues (bnc#784800
  FATE#314296).
- cxgb4: DB Drop Recovery for RDMA and LLD queues (bnc#784800
  FATE#314296).
- cxgb4: Common platform specific changes for DB Drop Recovery
  (bnc#784800 FATE#314296).
- cxgb4: Detect DB FULL events and notify RDMA ULD (bnc#784800
  FATE#314296).
- simple_open: automatically convert to simple_open() (bnc#784800
  FATE#314296).
- cxgb4: Add support for Chelsio's T480-CR and T440-LP-CR adapters
  (bnc#784800 FATE#314296).
- net: make ethtool_ops const (bnc#784800 FATE#314296).
- module_param: make bool parameters really bool (net &
  drivers/net) (bnc#784800 FATE#314296).
- commit bab5e22
* Wed Dec  5 2012 bpoirier@suse.de
- ethtool: Centralise validation of ETHTOOL_{G, S}RXFHINDIR
  parameters (bnc#784800 FATE#314296).
- Refresh
  patches.drivers/0335-New-7.0-FW-bnx2x-cnic-bnx2i-bnx2fc.patch.
- commit f63bb90
* Wed Dec  5 2012 bpoirier@suse.de
- drivers/net: fix mislocated headers in cxgb4/l2t.c (bnc#784800
  FATE#314296).
- cxgb4: convert to SKB paged frag API (bnc#784800 FATE#314296).
- mm: add a "struct page_frag" type containing a page, offset
  and length (bnc#784800 FATE#314296).
- cxgb4: Fix EEH on IBM P7IOC (bnc#784800 FATE#314296).
- cxgb4: remove forgotten unused vlan_group (bnc#784800
  FATE#314296).
- drivers/net: Remove unnecessary semicolons (bnc#784800
  FATE#314296).
- commit 2fb0914
* Wed Dec  5 2012 dsterba@suse.cz
- patches.suse/btrfs-2000-sanitizing-fs_info-parts-1-5.patch:
  btrfs: sanitizing ->fs_info, parts 1-5.
- patches.suse/btrfs-2001-make-open_ctree-return-int.patch:
  btrfs: make open_ctree() return int.
- patches.suse/btrfs-2002-kill-pointless-reassignment-of-s_fs_info-in-bt.patch:
  btrfs: kill pointless reassignment of ->s_fs_info in
  btrfs_fill_super().
- patches.suse/btrfs-2003-merge-free_fs_info-calls-on-fill_super-failure.patch:
  btrfs: merge free_fs_info() calls on fill_super failures.
- patches.suse/btrfs-2004-make-free_fs_info-call-kill_sb-unconditional.patch:
  btrfs: make free_fs_info() call ->kill_sb() unconditional.
- patches.suse/btrfs-2005-consolidate-failure-exits-in-btrfs_mount-a-bit.patch:
  btrfs: consolidate failure exits in btrfs_mount() a bit.
- patches.suse/btrfs-2006-let-s_fs_info-point-to-fs_info-not-root.patch:
  btrfs: let ->s_fs_info point to fs_info, not root...
- patches.suse/btrfs-2007-take-allocation-of-tree_root-into-open_ctree.patch:
  btrfs: take allocation of ->tree_root into open_ctree().
- patches.suse/btrfs-8077-stop-defrag-the-files-automatically-when-doin-.patch:
  Refresh.
- patches.suse/btrfs-8111-restore-restriper-state-on-all-mounts.patch:
  Refresh.
- patches.suse/btrfs-8112-resume-balance-on-rw-re-mounts-properly.patch:
  Refresh.
- patches.suse/btrfs-8169-don-t-do-anything-in-our-freeze_fs-and-unfreez.patch:
  Refresh.
- patches.suse/btrfs-8185-don-t-allow-degraded-mount-if-too-many-devices.patch:
  Refresh.
- patches.suse/btrfs-add-btrfs_panic: Refresh.
- patches.suse/btrfs-btrfs_set_item_key_safe-should-bug-and-return-void:
  Refresh.
- patches.suse/btrfs-catch-locking-failures-in-set-clear-extent_bit:
  Refresh.
- patches.suse/btrfs-clean_tree_block-should-panic-on-error-and-return-void:
  Refresh.
- patches.suse/btrfs-handle-EIO: Refresh.
- patches.suse/btrfs-panic-on-bad-rbtree-operations: Refresh.
- patches.suse/btrfs-update-message-levels.patch: Refresh.
- commit e11c447
* Wed Dec  5 2012 jbohac@suse.cz
- patches.fixes/ipv6-tcp-fix-panic-in-SYN-processing.patch:
  ipv6: tcp: fix panic in SYN processing (bnc#789115).
- commit 3371478
* Wed Dec  5 2012 lduncan@suse.de
- be2iscsi: Bump the driver version (FATE#313820).
- be2iscsi: Fix a kernel panic because of TCP RST/FIN received
  (FATE#313820).
- be2iscsi: Configure VLAN paramters of the adapter (FATE#313820).
- be2iscsi: Format the MAC_ADDR with sysfs_format_mac
  (FATE#313820).
- be2iscsi: Fix Logging mechanism for the driver (FATE#313820).
- be2iscsi: Issue MBX Cmd for login to boot target in crashdump
  mode (FATE#313820).
- be2iscsi: Removing the iscsi_data_pdu setting (FATE#313820).
- be2iscsi: fix dma free size mismatch regression (FATE#313820).
- be2iscsi: Configure Network paramters of adapter using iscsiadm
  (FATE#313820).
- be2iscsi: Fix bsg interface for be2iscsi (FATE#313820).
- be2iscsi: Get Initiator Name for the iSCSI_Host (FATE#313820).
- be2iscsi: Return async handle of unknown opcode to free list
  (FATE#313820).
- be2iscsi: Check ASYNC PDU Handle corresponds to HDR/DATA Handle
  (FATE#313820).
- be2iscsi: Update external Branding to Emulex (FATE#313820).
- be2iscsi: Fix the function return values (FATE#313820).
- be2iscsi: Code cleanup, removing the goto statement
  (FATE#313820).
- be2iscsi: Fix double free of MCCQ info memory (FATE#313820).
- be2iscsi: Set num_cpu = 1 if pci_enable_msix fails
  (FATE#313820).
- be2iscsi: Fix typo function name mismatch (FATE#313820).
- be2iscsi: Freeing of WRB and SGL Handle in cleanup task
  (FATE#313820).
- be2iscsi: WRB Initialization and Failure code path change
  (FATE#313820).
- be2iscsi: Fix in the Asynchronous Code Path (FATE#313820).
- be2iscsi: Remove unused OFFSET_IN_PAGE() macro (FATE#313820).
- be2iscsi: cleanup a min_t() call (FATE#313820).
- be2iscsi: Fix for kdump failure (FATE#313820).
- be2iscsi: do pci_disable when unloading the driver
  (FATE#313820).
- be2iscsi: implementing struct pci_driver shutdown routine
  (FATE#313820).
- commit ff102c8
* Wed Dec  5 2012 hare@suse.de
- aacraid: Series 7 Async. (performance) mode support
  (FATE#314143).
- aacraid: Fix endian issues in core and SRC portions of driver
  (FATE#314143).
- aacraid: Relax the tight timeout loop on fib commands
  (FATE#314143).
- aacraid: Better handling of in-flight events on thread stop
  (FATE#314143).
- aacraid: Use resource_size_t for IO mem pointers and offsets
  (FATE#314143).
- aacraid: add an iounmap call to aac_src_ioremap (FATE#314143).
- aacraid: Added Sync.mode to support series 7/8/9 controllers
  (FATE#314143).
- drivers/scsi/aacraid/commctrl.c: fix mem leak in
  aac_send_raw_srb() (FATE#314143).
- aacraid: use lower snprintf() limit (FATE#314143).
- commit 09a4efc
* Wed Dec  5 2012 hare@suse.de
- hpsa: gen8plus Smart Array IDs (FATE#313833).
- hpsa: use ioremap_nocache instead of ioremap (FATE#313833).
- hpsa: fix incorrect abort diagnostic message (FATE#313833).
- hpsa: dial down lockup detection during firmware flash
  (FATE#313833).
- hpsa: removed unused member maxQsinceinit (FATE#313833).
- hpsa: add new RAID level "1(ADM)" (FATE#313833).
- hpsa: factor out hpsa_free_irqs_and_disable_msix (FATE#313833).
- hpsa: refine interrupt handler locking for greater concurrency
  (FATE#313833).
- hpsa: use multiple reply queues (FATE#313833).
- hpsa: factor out tail calls to next_command() in
  process_(non)indexed_cmd() (FATE#313833).
- hpsa: do aborts two ways (FATE#313833).
- hpsa: add abort error handler function (FATE#313833).
- hpsa: remove unused parameter from finish_cmd (FATE#313833).
- hpsa: do not give up retry of driver cmds after only 3 retries
  (FATE#313833).
- hpsa: retry driver initiated commands on busy status
  (FATE#313833).
- hpsa: do not read from controller unnecessarily in completion
  code (FATE#313833).
- hpsa: suppress excessively chatty error messages (FATE#313833).
- hpsa: enable bus master bit after pci_enable_device
  (FATE#313833).
- hpsa: do not skip disabled devices (FATE#313833).
- hpsa: call pci_disable_device on driver unload (FATE#313833).
- hpsa: use check_signature (FATE#313833).
- hpsa: add some older controllers to the kdump blacklist
  (FATE#313833).
- hpsa: use find_first_zero_bit (FATE#313833).
- hpsa: update device attributes when they change (FATE#313833).
- hpsa: improve naming on external target device functions
  (FATE#313833).
- hpsa: eliminate 8 external target limitation (FATE#313833).
- hpsa: refactor hpsa_figure_bus_target_lun (FATE#313833).
- hpsa: make target and lun match what SCSI REPORT LUNs returns
  (FATE#313833).
- hpsa: factor out driver name (FATE#313833).
- hpsa: combine hpsa_scsi_detect and hpsa_register_scsi
  (FATE#313833).
- hpsa: removed unneeded structure member max_sg_entries and
  fix badly named constant MAXSGENTRIES (FATE#313833).
- hpsa: fix per device memory leak on driver unload (FATE#313833).
- hpsa: do not sleep in atomic context in rmmod path
  (FATE#313833).
- hpsa: add the Smart Array 5i to the kdump blacklist
  (FATE#313833).
- hpsa: detect controller lockup (FATE#313833).
- hpsa: fix flush cache transfer length (FATE#313833).
- hpsa: fix potential array overflow in hpsa_update_scsi_devices
  (FATE#313833).
- hpsa: rename HPSA_MAX_SCSI_DEVS_PER_HBA (FATE#313833).
- hpsa: remove unused busy_initializing and busy_scanning
  (FATE#313833).
- hpsa: set max sectors instead of taking the default
  (FATE#313833).
- hpsa: change confusing message to be more clear (FATE#313833).
- hpsa: retry commands completing with status of UNSOLICITED_ABORT
  (FATE#313833).
- commit 9f1a88c
* Wed Dec  5 2012 hare@suse.de
- cciss: remove unneeded memset() (FATE#313833).
- cciss: fix flush cache transfer length (FATE#313833).
- cciss: auto engage SCSI mid layer at driver load time
  (FATE#313833).
- The Windows driver .inf disables ASPM on all cciss devices. Do
  the same (FATE#313833).
- cciss: add transport mode attribute to sys (FATE#313833).
- commit 4f78182
* Wed Dec  5 2012 hare@suse.de
- bfa: Update the driver version to 3.1.2.1 (FATE#313821).
- bfa: Firmware image naming convention update (FATE#313821).
- bfa: Add support to read/update the FRU data (FATE#313821).
- bfa: Support Power on Hours display and diag temp sensor fixes
  (FATE#313821).
- bfa: Add support to configure min/max bandwidth for a pcifn
  (FATE#313821).
- bfa: Add support for IO throttling at port level (FATE#313821).
- bfa: Add support for user to configure bandwidth on QoS
  priorities (FATE#313821).
- bfa: Fabric Assigned Address implementation fix (FATE#313821).
- bfa: Add diagnostic port (D-Port) support (FATE#313821).
- bfa: Fix to handle firmware tskim abort request response
  (FATE#313821).
- bfa: Fix few attributes in the RHBA CT passthru command
  (FATE#313821).
- bfa: Add support to have mfg date as part of adapter attributes
  (FATE#313821).
- bfa: Flash Controller PLL initialization fixes (FATE#313821).
- bfa: IOCFC state machine enhancements (FATE#313821).
- bfa: Add support for FC Arbitrated Loop topology (FATE#313821).
- bfa: Update the driver version to v3.1.2.0 (FATE#313821).
- bfa: Add support for max target ports discovery (FATE#313821).
- bfa: Add support to register node symbolic name with name server
  (FATE#313821).
- bfa: Fix to process mbox interrupts only if interrupts are
  enabled in INTx mode (FATE#313821).
- bfa: Add PowerPC support and enable PCIE AER handling
  (FATE#313821).
- bfa: Add new hardware model info to sysfs model description
  routine (FATE#313821).
- bfa: Make changes to FCXP resource management (FATE#313821).
- bfa: FCS remote port enhancements (FATE#313821).
- bfa: Support vport symbolic name change from sysfs
  (FATE#313821).
- bfa: Fix to set correct return error codes and misc cleanup
  (FATE#313821).
- bfa: squelch lockdep complaint with a spin_lock_init
  (FATE#313821).
- bfa: dereferencing freed memory in bfad_im_probe()
  (FATE#313821).
- bfa: off by one in bfa_ioc_mbox_isr() (FATE#313821).
- bfa: Fix to set vport FC host sysfs entries (FATE#313821).
- bfa: Fix bfa logging for Logical port state change notification
  (FATE#313821).
- bfa: sysfs model description fix (FATE#313821).
- bfa: Fix to defer vport delete handler invocation till firmware
  logo response (FATE#313821).
- bfa: Update the driver version to 3.0.23.0 (FATE#313821).
- bfa: BSG and User interface fixes (FATE#313821).
- bfa: Fix to avoid vport delete hang on request queue full
  scenario (FATE#313821).
- bfa: Move service parameter programming logic into firmware
  (FATE#313821).
- bfa: Revised Fabric Assigned Address(FAA) feature implementation
  (FATE#313821).
- bfa: Flash controller IOC pll init fixes (FATE#313821).
- bfa: Serialize the IOC hw semaphore unlock logic (FATE#313821).
- bfa: Modify ISR to process pending completions (FATE#313821).
- bfa: Add fc host issue lip support (FATE#313821).
- bfa: Fix endian bug in bfad_iocmd_debug_fw_core() (FATE#313821).
- bfa: don't leak mem in bfad_im_bsg_els_ct_request()
  (FATE#313821).
- bfa: Implement LUN Masking feature using the SCSI Slave Callouts
  (FATE#313821).
- bfa: Revert back the current LUN Masking Implementation
  (FATE#313821).
- bfa: Fix possible NULL pointer dereference in lunmask add/delete
  (FATE#313821).
- bfa: fix endian and bit field check bug (FATE#313821).
- bfa: fix formating and checkpatch issues (FATE#313821).
- commit 8f2e2ee
* Wed Dec  5 2012 hare@suse.de
- block: drop unnecessary blk_get/put_queue() in scsi_cmd_ioctl()
  and blk_get_tg() (FATE#313629).
- commit 622802b
* Wed Dec  5 2012 trenn@suse.de
- fate#311770: Bring mei driver to latest mainline code base
  The watchdog interface (drivers/watchdog/watchdog_{core,dev}.[hc])
  was also needed for that. It should be safe because mei is the only user.
  config changes:
  +CONFIG_INTEL_MEI=m
  +CONFIG_WATCHDOG_CORE=y
  on i386 and x86_64 flavors (not on ec2). Otherwise these newly introduced
  ones are unset.
- mei: use pr_err instead of printk(KERN_ERR (fate#311770).
- watchdog: WatchDog Timer Driver Core - Add basic framework
  (fate#311770).
- mei: pci_probe/remove: use dev_err instead of printk(KERN_ERR
  (fate#311770).
- watchdog: WatchDog Timer Driver Core - Add basic ioctl
  functionality (fate#311770).
- mei: export mei.h for the user space (fate#311770).
- watchdog: WatchDog Timer Driver Core - Add WDIOC_KEEPALIVE ioctl
  (fate#311770).
- mei: move doc files Documentation/misc-devices/mei
  (fate#311770).
- watchdog: WatchDog Timer Driver Core - Add WDIOC_SETOPTIONS
  ioctl (fate#311770).
- misc: mei: set IRQF_ONESHOT for msi request_threaded_irq
  (fate#311770).
- watchdog: WatchDog Timer Driver Core - Add WDIOC_SETTIMEOUT
  and WDIOC_GETTIMEOUT ioctl (fate#311770).
- misc: mei: unregister misc device in pci_remove function
  (fate#311770).
- watchdog: WatchDog Timer Driver Core - Add Magic Close feature
  (fate#311770).
- misc: mei: fix stalled read (fate#311770).
- watchdog: WatchDog Timer Driver Core - Add nowayout feature
  (fate#311770).
- misc: mei: Disable MSI when IRQ registration fails
  (fate#311770).
- watchdog: WatchDog Timer Driver Core - Add ioctl call
  (fate#311770).
- misc: mei: set WDIOF_ALARMONLY on mei watchdog (fate#311770).
- watchdog: WatchDog Timer Driver Core - Add minimum and max
  timeout (fate#311770).
- mei: check for error codes that mei_flow_ctrl_creds retuns
  (fate#311770).
- watchdog: WatchDog Timer Driver Core - use passed
  watchdog_device (fate#311770).
- mei: make mei_write_message more readable (fate#311770).
- watchdog: add nowayout helpers to Watchdog Timer Driver Kernel
  API (fate#311770).
- mei: mei_irq_thread_write_handler check for overflow
  (fate#311770).
- watchdog: Use pr_<fmt> and pr_<level> (fate#311770).
- mei: group wd_interface_reg with watchdog variables within
  struct mei_device (fate#311770).
- mei: don't query HCSR for host buffer depth (fate#311770).
- watchdog: watchdog_dev: Let the driver update the timeout
  field on set_timeout success (fate#311770).
- mei: revamp host buffer interface function (fate#311770).
- watchdog: Add support for WDIOC_GETTIMELEFT IOCTL in watchdog
  core (fate#311770).
- mei: pci_resume: set IRQF_ONESHOT for msi request_threaded_irq
  (fate#311770).
- watchdog: Add watchdog_active() routine (fate#311770).
- mei: mei_device can be const for mei register access functions
  (fate#311770).
- watchdog: watchdog_dev: include private header to pickup global
  symbol prototypes.
- mei: remove write only wariable wd_due_counter (fate#311770).
- watchdog: correct the name of the watchdog_core inlude file.
- mei: mei_wd_host_init: update the comment (fate#311770).
- watchdog: watchdog_core.h: make functions extern.
- mei: introduce mei_data2slots wrapper (fate#311770).
- watchdog: Add multiple device support (fate#311770).
- mei: streamline the _mei_irq_thread_close/ioctol functions
  (fate#311770).
- watchdog: Add a flag to indicate the watchdog doesn't reboot
  things (fate#311770).
- mei: mei_irq_thread_write_handler - line break fix
  (fate#311770).
- watchdog: create all the proper device files (fate#311770).
- mei: use module_pci_driver (fate#311770).
- watchdog: use dev_ functions (fate#311770).
- mei: revamp me client search function (fate#311770).
- watchdog: watchdog_dev: Rewrite wrapper code (fate#311770).
- mei: add mei_quirk_probe function (fate#311770).
- watchdog: Add Locking support (fate#311770).
- mei: use KBUILD_MODNAME when allocating resources from the OS
  (fate#311770).
- watchdog: Add support for dynamically allocated watchdog_device
  structs (fate#311770).
- mei: style : reformat PCI device IDs (fate#311770).
- watchdog: core: fix WDIOC_GETSTATUS return value (fate#311770).
- mei: name space for mei device state (fate#311770).
- watchdog: move the dereference below the NULL test
  (fate#311770).
- mei: fix device stall after wd is stopped (fate#311770).
- mei: wd: add option WDIOF_SETTIMEOUT (fate#311770).
- mei: wd: rename watchdog constants to be more descriptive
  (fate#311770).
- mei: wd: decouple and revamp watchdog state machine
  (fate#311770).
- mei: wd: use watchdog_set/get_drvdata for passing mei_device
  (fate#311770).
- mei: rename struct pci_dev *mei_device to mei_pdev
  (fate#311770).
- mei: fix max number of open handles (fate#311770).
- mei: add lynx point pci device ids (fate#311770).
- mei: add error messages for open count errors (fate#311770).
- mei: struct mei_message_data doesn't have to be packed
  (fate#311770).
- mei: don't print buffer as a string (fate#311770).
- char/misc: remove CONFIG_EXPERIMENTAL dependencies
  (fate#311770).
- Move mei driver from staging to drivers/misc/mei/ (fate#311770).
- Update config files.
- supported.conf:
- commit 99fe2fe
* Tue Dec  4 2012 tiwai@suse.de
- Refresh patches.fixes/0002-MODSIGN-Avoid-using-.incbin-in-C-source.patch.
  Hopefully the build errors on non-x86 architectures are fixed now.
- commit 3c6de1b
* Tue Dec  4 2012 dsterba@suse.cz
  refresh btrfs balancer patchset
  (no functional change)
- patches.suse/btrfs-0306-get-rid-of-_alloc_profile-fields.patch:
  Btrfs: get rid of *_alloc_profile fields.
- patches.suse/btrfs-0307-introduce-masks-for-chunk-type-and-profile.patch:
  Btrfs: introduce masks for chunk type and profile.
- patches.suse/btrfs-0308-add-btrfs_AVAIL_ALLOC_BIT_SINGLE-bit.patch:
  Btrfs: add BTRFS_AVAIL_ALLOC_BIT_SINGLE bit.
- patches.suse/btrfs-0309-make-avail_-_alloc_bits-fields-dynamic.patch:
  Btrfs: make avail_*_alloc_bits fields dynamic.
- patches.suse/btrfs-0310-add-basic-restriper-infrastructure.patch:
  Btrfs: add basic restriper infrastructure.
- patches.suse/btrfs-0311-add-basic-infrastructure-for-selective-balanci.patch:
  Btrfs: add basic infrastructure for selective balancing.
- patches.suse/btrfs-0312-profiles-filter.patch: Btrfs: profiles
  filter.
- patches.suse/btrfs-0313-usage-filter.patch: Btrfs: usage filter.
- patches.suse/btrfs-0314-devid-filter.patch: Btrfs: devid filter.
- patches.suse/btrfs-0315-devid-subset-filter.patch: Btrfs:
  devid subset filter.
- patches.suse/btrfs-0316-virtual-address-space-subset-filter.patch:
  Btrfs: virtual address space subset filter.
- patches.suse/btrfs-0317-do-not-reduce-profile-in-do_chunk_alloc.patch:
  Btrfs: do not reduce profile in do_chunk_alloc().
- patches.suse/btrfs-0318-implement-online-profile-changing.patch:
  Btrfs: implement online profile changing.
- patches.suse/btrfs-0319-soft-profile-changing-mode-aka-soft-convert.patch:
  Btrfs: soft profile changing mode (aka soft convert).
- patches.suse/btrfs-0320-save-balance-parameters-to-disk.patch:
  Btrfs: save balance parameters to disk.
- patches.suse/btrfs-0321-recover-balance-on-mount.patch: Btrfs:
  recover balance on mount.
- patches.suse/btrfs-0322-add-skip_balance-mount-option.patch:
  Btrfs: add skip_balance mount option.
- patches.suse/btrfs-0323-allow-for-pausing-restriper.patch:
  Btrfs: allow for pausing restriper.
- patches.suse/btrfs-0324-allow-for-canceling-restriper.patch:
  Btrfs: allow for canceling restriper.
- patches.suse/btrfs-0325-allow-for-resuming-restriper-after-it-was-paus.patch:
  Btrfs: allow for resuming restriper after it was paused.
- patches.suse/btrfs-0326-add-balance-progress-reporting.patch:
  Btrfs: add balance progress reporting.
- patches.suse/btrfs-0333-don-t-pass-a-trans-handle-unnecessarily-in-vol.patch:
  Refresh.
- patches.suse/btrfs-0334-don-t-pre-allocate-btrfs-bio.patch:
  Refresh.
- patches.suse/btrfs-0359-preparation-to-fixing-mount-umount-race.patch:
  Refresh.
- patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch:
  Refresh.
- patches.suse/btrfs-add-btrfs_panic: Refresh.
- patches.suse/btrfs-update-message-levels.patch: Refresh.
- patches.suse/btrfs-1000-get-rid-of-_alloc_profile-fields.patch:
  Delete.
- patches.suse/btrfs-1001-introduce-masks-for-chunk-type-and-profile.patch:
  Delete.
- patches.suse/btrfs-1002-add-btrfs_AVAIL_ALLOC_BIT_SINGLE-bit.patch:
  Delete.
- patches.suse/btrfs-1003-make-avail_-_alloc_bits-fields-dynamic.patch:
  Delete.
- patches.suse/btrfs-1004-add-basic-restriper-infrastructure.patch:
  Delete.
- patches.suse/btrfs-1005-add-basic-infrastructure-for-selective-balanci.patch:
  Delete.
- patches.suse/btrfs-1006-profiles-filter.patch: Delete.
- patches.suse/btrfs-1007-usage-filter.patch: Delete.
- patches.suse/btrfs-1008-devid-filter.patch: Delete.
- patches.suse/btrfs-1009-devid-subset-filter.patch: Delete.
- patches.suse/btrfs-1010-virtual-address-space-subset-filter.patch:
  Delete.
- patches.suse/btrfs-1011-do-not-reduce-profile-in-do_chunk_alloc.patch:
  Delete.
- patches.suse/btrfs-1012-implement-online-profile-changing.patch:
  Delete.
- patches.suse/btrfs-1013-soft-profile-changing-mode-aka-soft-convert.patch:
  Delete.
- patches.suse/btrfs-1014-save-balance-parameters-to-disk.patch:
  Delete.
- patches.suse/btrfs-1015-recover-balance-on-mount.patch: Delete.
- patches.suse/btrfs-1016-add-skip_balance-mount-option.patch:
  Delete.
- patches.suse/btrfs-1017-allow-for-pausing-restriper.patch:
  Delete.
- patches.suse/btrfs-1018-allow-for-cancelling-restriper.patch:
  Delete.
- patches.suse/btrfs-1019-allow-for-resuming-restriper-after-it-was-paus.patch:
  Delete.
- patches.suse/btrfs-1020-add-balance-progress-reporting.patch:
  Delete.
- patches.suse/btrfs-1021-restriper-updates-v2.patch: Delete.
- commit 1342cc9
* Tue Dec  4 2012 hare@suse.de
- asm-generic: architecture independent readq/writeq for 32bit
  environment (FATE#311167).
- Update config files.
- Refresh
  patches.drivers/mtip32xx-0001-Add-driver-for-Micron-RealSSD-pcie-flash-cards.patch.
- Refresh patches.suse/twofish-2.6.
- Refresh patches.xen/xen3-patch-3.0.
- supported.conf: mark nvme and mtip32xx as supported
- commit 3803c28
* Tue Dec  4 2012 hare@suse.de
- mtip32xx:Added appropriate timeout value for secure erase
  (FATE#311167).
- mtip32xx: fix user_buffer check in exec_drive_command
  (FATE#311167).
- mtip32xx: Remove dead code (FATE#311167).
- mtip32xx: Change printk to pr_xxxx (FATE#311167).
- mtip32xx: Proper reporting of write protect status on big-endian
  (FATE#311167).
- mtip32xx: Increase timeout for standby command (FATE#311167).
- mtip32xx: Handle NCQ commands during the security locked state
  (FATE#311167).
- mtip32xx: Add support for new devices (FATE#311167).
- mtip32xx: Create debugfs entries for troubleshooting
  (FATE#311167).
- mtip32xx: Remove 'registers' and 'flags' from sysfs
  (FATE#311167).
- mtip32xx: Changes to sysfs entries (FATE#311167).
- mtip32xx: Convert macro definitions for flag bits to enum
  (FATE#311167).
- mtip32xx: minor performance tweak (FATE#311167).
- mtip32xx: Fix to support more than one sector in
  exec_drive_command() (FATE#311167).
- mtip32xx: Use plain spinlock for 'cmd_issue_lock' (FATE#311167).
- mtip32xx: Set block queue boundary variables (FATE#311167).
- mtip32xx: Fix to handle TFE for PIO(IOCTL/internal) commands
  (FATE#311167).
- mtip32xx: Change HDIO_GET_IDENTITY to return stored data
  (FATE#311167).
- mtip32xx: Set custom timeouts for PIO commands (FATE#311167).
- mtip32xx: fix clearing an incorrect register in mtip_init_port
  (FATE#311167).
- mtip32xx: release the semaphore on an error path (FATE#311167).
- block: mtip32xx: remove HOTPLUG_PCI_PCIE dependancy
  (FATE#311167).
- mtip32xx: dump tagmap on failure (FATE#311167).
- mtip32xx: fix handling of commands in various scenarios
  (FATE#311167).
- mtip32xx: Shorten macro names (FATE#311167).
- mtip32xx: misc changes (FATE#311167).
- mtip32xx: Add new sysfs entry 'status' (FATE#311167).
- mtip32xx: make setting comp_time as common (FATE#311167).
- mtip32xx: Add new bitwise flag 'dd_flag' (FATE#311167).
- mtip32xx: fix error handling in mtip_init() (FATE#311167).
- mtip32xx: fix incorrect value set for drv_cleanup_done,
  and re-initialize and start port in mtip_restart_port()
  (FATE#311167).
- mtip32xx: removed the irrelevant argument of mtip_hw_submit_io()
  and the unused member of struct driver_data (FATE#311167).
- mtip32xx: do rebuild monitoring asynchronously (FATE#311167).
- mtip32xx: uninitialized variable in mtip_quiesce_io()
  (FATE#311167).
- mtip32xx: updates based on feedback (FATE#311167).
- mtip32xx: mark a few more items static (FATE#311167).
- mtip32xx: ensure that all local functions are static
  (FATE#311167).
- mtip32xx: cleanup compat ioctl handling (FATE#311167).
- mtip32xx: fix warnings/errors on 32-bit compiles (FATE#311167).
- block: Add driver for Micron RealSSD pcie flash cards
  (FATE#311167).
- libfs: add simple_open() (FATE#311167).
- commit 7680c5c
* Tue Dec  4 2012 ohering@suse.de
- add splash=black option to bootsplash code,
  to keep a black background, useful for remote access to VMs
  (bnc#773487)
- commit 0375f46
* Tue Dec  4 2012 hare@suse.de
- NVMe backport (FATE#313627)
- NVMe: New driver (FATE#313627).
- NVMe: Factor out queue_request_irq() (FATE#313627).
- NVMe: Reduce set_queue_count arguments by one (FATE#313627).
- NVMe: Implement per-CPU queues (FATE#313627).
- NVMe: Rename 'cycle' to 'phase' (FATE#313627).
- NVMe: Fix admin IRQ claim on real hardware (FATE#313627).
- NVMe: Use PRP2 for the nvme_identify ioctl (FATE#313627).
- NVMe: Make nvme_common_command more featureful (FATE#313627).
- NVMe: Add nvme_setup_prps() (FATE#313627).
- NVMe: Zero the command before we send it (FATE#313627).
- NVMe: Change NVME_IOCTL_GET_RANGE_TYPE to return all the ranges
  (FATE#313627).
- NVMe: Create nvme_map_user_pages() and nvme_unmap_user_pages()
  (FATE#313627).
- NVMe: Add NVME_IOCTL_SUBMIT_IO (FATE#313627).
- NVMe: Read the model, serial & firmware rev from the controller
  (FATE#313627).
- NVMe: Remove 'node' from nvme_dev (FATE#313627).
- NVMe: Check returns from nvme_alloc_queue() (FATE#313627).
- NVMe: Enable and disable the PCI device (FATE#313627).
- NVMe: Enable device DMA (FATE#313627).
- NVMe: Allow queues to be allocated above 4GB (FATE#313627).
- NVMe: Request I/O regions (FATE#313627).
- NVMe: Disable the device before we write the admin queues
  (FATE#313627).
- NVMe: Move sysfs entries to the right place (FATE#313627).
- NVMe: Add remaining status codes (FATE#313627).
- NVMe: Add download / activate firmware ioctls (FATE#313627).
- NVMe: Release 0.2 (FATE#313627).
- NVMe: Allow fatal signals to interrupt I/O (FATE#313627).
- NVMe: Call put_nvmeq() before calling nvme_submit_sync_cmd()
  (FATE#313627).
- NVMe: Add a module parameter to use a threaded interrupt
  (FATE#313627).
- NVMe: Use a symbolic name to represent cancelled commands
  instead of 0 (FATE#313627).
- NVMe: Detect commands that are completed twice (FATE#313627).
- NVMe: Detect command IDs completing that are out of range
  (FATE#313627).
- NVMe: Need to lock queue during interrupt handling
  (FATE#313627).
- NVMe: Record the timeout for each command (FATE#313627).
- NVMe: Handle the congestion list a little better (FATE#313627).
- NVMe: Renumber the special context values (FATE#313627).
- NVMe: Advance the sg pointer when filling in an sg list
  (FATE#313627).
- NVMe: Initial PRP List support (FATE#313627).
- NVMe: Rename nvme_req_info to nvme_bio (FATE#313627).
- NVMe: Switch to use DMA Pool API (FATE#313627).
- NVMe: Optimise memory usage for I/Os between 4k and 128k
  (FATE#313627).
- NVMe: Pass the nvme_dev to nvme_free_prps and nvme_setup_prps
  (FATE#313627).
- NVMe: Check for DMA mapping failure (FATE#313627).
- NVMe: Handle physical merging of bvec entries (FATE#313627).
- NVMe: Update BAR structure to match the current spec
  (FATE#313627).
- NVMe: Handle failures differently in nvme_submit_bio_queue()
  (FATE#313627).
- NVMe: Add a kthread to handle the congestion list (FATE#313627).
- NVMe: Release 0.3 (FATE#313627).
- NVMe: Remove setting of 'flags' in rw command (FATE#313627).
- NVMe: Rename nr_queues to nr_io_queues (FATE#313627).
- NVMe: Let the kthread take care of devices earlier
  (FATE#313627).
- NVMe: Correct SQ doorbell semantics (FATE#313627).
- NVMe: Mark CMD_CTX_CANCELLED as being unlikely (FATE#313627).
- NVMe: Implement Flush (FATE#313627).
- NVMe: Handle bios that contain non-virtually contiguous
  addresses (FATE#313627).
- NVMe: Fix discontiguous accesses (FATE#313627).
- NVMe: Reduce maximum queue depth by 1 (FATE#313627).
- NVMe: Version 0.4 (FATE#313627).
- NVMe: Update admin opcodes to match the 1.0RC spec
  (FATE#313627).
- NVMe: Convert comments to kernel-doc notation (FATE#313627).
- NVMe: Fix comment formatting (FATE#313627).
- NVMe: Remove outdated comments (FATE#313627).
- NVMe: Fix interpretation of 'Number of Namespaces' field
  (FATE#313627).
- NVMe: Fix off-by-one when filling in PRP lists (FATE#313627).
- NVMe: Remove the kthread from the wait queue (FATE#313627).
- NVMe: Simplify queue lookup (FATE#313627).
- NVMe: Add compat_ioctl (FATE#313627).
- NVMe: Correct the definitions of two ioctls (FATE#313627).
- NVMe: Change the definition of nvme_user_io (FATE#313627).
- NVMe: Version 0.5 (FATE#313627).
- NVMe: Correct the Controller Configuration settings
  (FATE#313627).
- NVMe: Fix warning in free_irq (FATE#313627).
- NVMe: Time out initialisation after a few seconds (FATE#313627).
- NVMe: Fix bug in error handling (FATE#313627).
- NVMe: Rename cancel_cmdid_data to cancel_cmdid (FATE#313627).
- NVMe: Add support for timing out I/Os (FATE#313627).
- NVMe: Add include of delay.h for msleep (FATE#313627).
- NVMe: Use an IDA to allocate minor numbers (FATE#313627).
- NVMe: Handle failures from memory allocations in nvme_setup_prps
  (FATE#313627).
- NVMe: Add a few calling convention notes (FATE#313627).
- NVMe: Version 0.6 (FATE#313627).
- NVMe: Return real error from nvme_create_queue (FATE#313627).
- NVMe: Add the nvme thread to the wait queue before waking it up
  (FATE#313627).
- NVMe: Rework ioctls (FATE#313627).
- Fix bug in NVME_IOCTL_SUBMIT_IO (FATE#313627).
- NVMe: Correct sg list setup in nvme_map_user_pages
  (FATE#313627).
- NVMe: Fix calls to dma_unmap_sg (FATE#313627).
- NVMe: Fix memory leak in nvme_dev_add() (FATE#313627).
- NVMe: Create nvme_identify and nvme_get_features functions
  (FATE#313627).
- Fix calculation of number of pages in a PRP List (FATE#313627).
- NVMe: Don't probe namespace 0 (FATE#313627).
- NVMe: Version 0.7 (FATE#313627).
- NVMe: Implement doorbell stride capability (FATE#313627).
- NVMe: Update Identify Controller data structure (FATE#313627).
- NVMe: Simplify completion handling (FATE#313627).
- NVMe: Change get_nvmeq to take a dev instead of a namespace
  (FATE#313627).
- NVMe: Change nvme_completion_fn to take a dev (FATE#313627).
- NVMe: Merge the nvme_bio and nvme_prp data structures
  (FATE#313627).
- NVMe: Rename IO_TIMEOUT to NVME_IO_TIMEOUT (FATE#313627).
- NVMe: Fix DMA mapping for admin commands (FATE#313627).
- NVMe: Mark the end of the sg list (FATE#313627).
- NVMe: Simplify nvme_unmap_user_pages (FATE#313627).
- NVMe: Set queue flags correctly (FATE#313627).
- NVMe: Version 0.8 (FATE#313627).
- NVMe: Set number of queues correctly (FATE#313627).
- NVM Express: Remove unneeded include of linux/version.h from
  nvme.c (FATE#313627).
- NVMe: Set request queue logical block size (FATE#313627).
- NVMe: Fix nvme module init when nvme_major is set (FATE#313627).
- NVMe: replace nvme_ns with nvme_dev for user admin
  (FATE#313627).
- NVMe: use namespace id for nvme_get_features (FATE#313627).
- NVMe: Set block queue max sectors (FATE#313627).
- NVMe: Do not set IO queue depth beyond device max (FATE#313627).
- NVMe: Fix uninitialized iod compiler warning (FATE#313627).
- NVMe: handle allocation failure in nvme_map_user_pages()
  (FATE#313627).
- NVMe: Fix whitespace damage in nvme_init (FATE#313627).
- NVMe: Use ida for nvme device instance (FATE#313627).
- NVMe: Free admin queue memory on initialisation failure
  (FATE#313627).
- NVMe: Cancel outstanding IOs on queue deletion (FATE#313627).
- Update config files.
- commit 3acc1eb
* Tue Dec  4 2012 mmarek@suse.cz
- Enable CONFIG_FIRMWARE_SIG (fate#314574)
- commit 0bda813
* Tue Dec  4 2012 mmarek@suse.cz
- patches.suse/fix-build-modsign_pubkey: Remove now duplicate patch
  (sorry).
- commit 96f58f1
* Tue Dec  4 2012 mmarek@suse.cz
- Enable CONFIG_MODULE_SIG again (fate#314508)
- commit 44794ea
* Tue Dec  4 2012 mmarek@suse.cz
- MODSIGN: Drop ccache hack.
- MODSIGN: Avoid using .incbin in C source.
- MODSIGN: Fix comparison erros in scripts/sign-file.
- commit dba71c3
* Tue Dec  4 2012 tiwai@suse.de
- Fix build of modsign_pubkey.c with icrecream (#790477).
- commit 6c424ab
* Tue Dec  4 2012 jlee@suse.com
- firmware: Install firmware signature files automatically
  (fate#314574).
- firmware: Add support for signature checks (fate#314574).
- firmware: Add -a option to scripts/sign-file (fate#314574).
- firmware: Add the firmware signing support to scripts/sign-file
  (fate#314574).
- firmware loader: let direct loading back on 'firmware_buf'
  (fate#314574).
- firmware loader: fix one reqeust_firmware race (fate#314574).
- firmware loader: cancel uncache work before caching firmware
  (fate#314574).
- firmware: use 'kernel_read()' to read firmware into kernel
  buffer (fate#314574).
- firmware: teach the kernel to load firmware files directly
  from the filesystem (fate#314574).
- firmware loader: fix compile warning when CONFIG_PM=n
  (fate#314574).
- firmware loader: let caching firmware piggyback on loading
  firmware (fate#314574).
- firmware loader: fix firmware -ENOENT situations (fate#314574).
- firmware loader: fix build failure if FW_LOADER is m
  (fate#314574).
- PM / Sleep: introduce dpm_for_each_dev (fate#314574).
- firmware loader: fix compile failure if !PM (fate#314574).
- firmware loader: cache devices firmware during suspend/resume
  cycle (fate#314574).
- firmware loader: use small timeout for cache device firmware
  (fate#314574).
- firmware: introduce device_cache/uncache_fw_images
  (fate#314574).
- driver core: devres: introduce devres_for_each_res
  (fate#314574).
- firmware loader: store firmware name into devres list
  (fate#314574).
- firmware loader: fix comments on request_firmware_nowait
  (fate#314574).
- firmware loader: fix device lifetime (fate#314574).
- firmware loader: introduce cache_firmware and uncache_firmware
  (fate#314574).
- firmware loader: always let firmware_buf own the pages buffer
  (fate#314574).
- firmware loader: introduce firmware_buf (fate#314574).
- firmware loader: fix creation failure of fw loader device
  (fate#314574).
- firmware loader: remove unnecessary wmb() (fate#314574).
- firmware loader: fix races during loading firmware
  (fate#314574).
- firmware loader: simplify pages ownership transfer
  (fate#314574).
- firmware_class: Move request_firmware_nowait() to workqueues
  (fate#314574).
- firmware_class: Reorganize fw_create_instance() (fate#314574).
- firmware_class: Do not warn that system is not ready from
  async loads (fate#314574).
- firmware_class: Split _request_firmware() into three functions,
  v2 (fate#314574).
- firmware_class: Rework usermodehelper check (fate#314574).
- PM / Sleep: Fix read_unlock_usermodehelper() call (fate#314574).
- PM / Sleep: Fix freezer failures due to racy
  usermodehelper_is_disabled() (fate#314574).
- commit e6449db
* Tue Dec  4 2012 jlee@suse.com
- misc: hpilo: ignore auxiliary HP iLO BMC's (fate#313893,
  bnc#783330).
- misc: hpilo: increase number of max supported channels
  (fate#313893, bnc#783330).
- commit ff64dc8
* Mon Dec  3 2012 oneukum@suse.de
- xhci: Export Latency Tolerance Messaging capabilities
  (FATE#313690).
- USB: Enable Latency Tolerance Messaging (LTM) (FATE#313690).
- USB: Add a sysfs file to show LTM capabilities (FATE#313690).
- commit 70baade
* Fri Nov 30 2012 bpoirier@suse.de
- IB: Fix typos in infiniband drivers (bnc#784800 FATE#314296).
- RDMA/cxgb3: Don't pass irq flags to flush_qp() (bnc#784800
  FATE#314296).
- IB: Use central enum for speed instead of hard-coded values
  (bnc#784800 FATE#314296).
- RDMA/cxgb3: Serialize calls to CQ's comp_handler (bnc#784800
  FATE#314296).
- RDMA/{amso1100,cxgb3}: Minimal MPAv2 support (bnc#784800
  FATE#314296).
- RDMA/iwcm: Propagate ird/ord values upwards (bnc#784800
  FATE#314296).
- RDMA: Allow for NULL .modify_device() and .modify_port()
  methods (bnc#784800 FATE#314296).
- commit 2ef63ff
* Fri Nov 30 2012 hare@suse.de
- lpfc 8.3.32: Fix error reporting of misconfigured ports
  (FATE#313818).
- lpfc 8.3.32: Fix system panic due to node state change
  (FATE#313818).
- lpfc 8.3.32: Fix ability to change FCP EQ delay multiplier
  (FATE#313818).
- lpfc 8.3.32: Correct successful aborts returning error status
  (FATE#313818).
- lpfc 8.3.32: Correct provisioning change failure on local
  function (FATE#313818).
- lpfc 8.3.32: Correct host DIF configuration that hung system
  (FATE#313818).
- lpfc 8.3.32: Fix CQ and EQ dump failure for debugfs
  (FATE#313818).
- lpfc 8.3.32: Correct null pointer Error in lpfc_sli.c
  (FATE#313818).
- lpfc 8.3.32: lpfc_sli.c: add missing jumps to mempool_free
  (FATE#313818).
- lpfc 8.3.31: Fixed system crash due to not providing SCSI
  error-handling host reset handler (FATE#313818).
- lpfc 8.3.31: Fix bug with driver using the wrong xritag when
  sending an els echo (FATE#313818).
- lpfc 8.3.31: Debug helper utility routines for dumping various
  SLI4 queues (FATE#313818).
- lpfc 8.3.31: Fix unsol abts xri lookup (FATE#313818).
- lpfc 8.3.31: Correct point-to-point mode discovery errors on
  LPe16xxx (FATE#313818).
- lpfc 8.3.31: Reregister VPI for SLI3 after cable moved to new
  Saturn port (FATE#313818).
- lpfc 8.3.31: Fix driver crash during back-to-back ramp events
  (FATE#313818).
- lpfc 8.3.31: Fix log message for Mailbox command when no error
  is detected (FATE#313818).
- lpfc 8.3.31: Revise FCP LOG for easier Finisar trace correlation
  (FATE#313818).
- lpfc 8.3.31: Fix build warnings when debugfs is not defined
  (FATE#313818).
- lpfc 8.3.31: Fix kernel panic when going into to sleep state
  (FATE#313818).
- lpfc 8.3.31: Fix error message displayed even when not an error
  (FATE#313818).
- lpfc 8.3.31: Fix Read Link status data (FATE#313818).
- lpfc 8.3.31: Fixed system panic due to midlayer abort and
  driver complete race on SCSI cmd (FATE#313818).
- lpfc 8.3.31: Fix unable to create vports on FCoE SLI4 adapter
  (FATE#313818).
- lpfc 8.3.31: Fix initiator sending flogi after acking flogi
  from target (FATE#313818).
- lpfc 8.3.31: Fix bug with driver not supporting the get
  controller attributes command (FATE#313818).
- lpfc 8.3.31: Correct handling of SLI4-port XRI
  resource-provisioning profile change (FATE#313818).
- lpfc 8.3.31: Fix bug with driver unload leaving a scsi host
  for a vport around (FATE#313818).
- lpfc 8.3.30: Revert fix for Link Pull Causes I/O Failures
  (FATE#313818).
- lpfc 8.3.30: Added more T10 DIF debugfs error injection
  (FATE#313818).
- lpfc 8.3.30: Fix handling of REG_VFI and cable pull
  (FATE#313818).
- lpfc 8.3.30: Enhancements for T10 DIF debugfs error injection
  (FATE#313818).
- lpfc 8.3.30: Change default DA_ID support from disabled to
  enabled (FATE#313818).
- lpfc 8.3.30: Flush reset register write (FATE#313818).
- lpfc 8.3.30: Update copyright date for files modified in 2012
  (FATE#313818).
- lpfc 8.3.30: Fixed panic with extents and small blocks
  (FATE#313818).
- lpfc 8.3.30: Add -Werror compilation flag (FATE#313818).
- lpfc 8.3.30: Fixed the system panic during EEH recovery
  (FATE#313818).
- lpfc 8.3.30: Fix resource leak when acc fails for received plogi
  (FATE#313818).
- lpfc 8.3.30: Fix SLI4 driver module load and unload
  (FATE#313818).
- lpfc 8.3.30: Fixed missing CVL event causing FCF failover
  (FATE#313818).
- lpfc 8.3.30: Fix deadlock during adapter offline request
  (FATE#313818).
- lpfc 8.3.30: Fix RPI registered multiple times after HBA reset
  (FATE#313818).
- lpfc 8.3.30: Fix driver handling of XRI Aborted CQE response
  (FATE#313818).
- lpfc 8.3.30: Fix port and system failure in SLI4 FC function
  reset (FATE#313818).
- lpfc 8.3.30: Fix lack of LOGO with vport delete (FATE#313818).
- lpfc 8.3.30: Make BA_ACC work on a fully qualified exchange
  (FATE#313818).
- lpfc 8.3.29: Remove GFP_KERNEL allocation while lock is held
  (FATE#313818).
- lpfc 8.3.29: Locking fix and Memory leak Fixes (FATE#313818).
- lpfc 8.3.29: FC Discovery state machine fixes (FATE#313818).
- lpfc 8.3.29: T10 Diff fixes and enhancements (FATE#313818).
- lpfc 8.3.29: SLI related fixes (FATE#313818).
- lpfc 8.3.29: BSG and User interface fixes (FATE#313818).
- lpfc 8.3.28: Add Loopback support for SLI4 adapters
  (FATE#313818).
- lpfc 8.3.28: Critical Miscellaneous fixes (FATE#313818).
- Lpfc 8.3.28: FC and SCSI Discovery Fixes (FATE#313818).
- lpfc 8.3.28: Add support for ABTS failure handling
  (FATE#313818).
- lpfc 8.3.28: SLI fixes and added SLI4 support (FATE#313818).
- lpfc 8.3.28: Miscellaneous fixes in sysfs and mgmt interfaces
  (FATE#313818).
- lpfc 8.3.27: T10 additions for SLI4 (FATE#313818).
- lpfc 8.3.27: Miscellanous logic and interface fixes
  (FATE#313818).
- lpfc: Silence DEBUG_STRICT_USER_COPY_CHECKS=y warning
  (FATE#313818).
- commit 3533c3c
* Fri Nov 30 2012 hare@suse.de
- Delete patches.drivers/ufs-use-module_pci_driver.patch.
- commit c60411b
* Thu Nov 29 2012 jbohac@suse.cz
- patches.kabi/netfilter-ipset-ignore-kabi-changes.patch:
  netfilter: ipset: ignore KABI changes.
- commit c065cfa
* Thu Nov 29 2012 dsterba@suse.cz
- patches.suse/btrfs-0288-fix-double-mntput-in-mount_subvol.patch:
  Refresh.
- commit dc316e8
* Thu Nov 29 2012 dsterba@suse.cz
- patches.suse/btrfs-0211-btrfs_multi_bio-replaced-with-btrfs_bio.patch:
  Refresh.
- patches.suse/btrfs-0288-fix-double-mntput-in-mount_subvol.patch:
  btrfs: fix double mntput() in mount_subvol().
- commit a0e4c7a
* Thu Nov 29 2012 jbohac@suse.cz
- patches.fixes/netfilter-ipset-fix-adding-ranges-to-hash-types.patch:
  Refresh.
- patches.fixes/netfilter-ipset-timeout-can-be-modified-for-already.patch:
  netfilter: ipset: timeout can be modified for already added
  elements (bnc#790457).
- commit d9f6a3f
* Thu Nov 29 2012 jbohac@suse.cz
- patches.fixes/netfilter-ipset-fix-adding-ranges-to-hash-types.patch:
  netfilter: ipset: fix adding ranges to hash types (bnc#790498).
- commit 68a5264
* Thu Nov 29 2012 hare@suse.de
- Refresh
  patches.drivers/bnx2fc-Reduce-object-size-by-consolidating-form.patch.
- commit 3456540
* Thu Nov 29 2012 hare@suse.de
- Fix incorrect memset in bnx2fc_parse_fcp_rsp (FATE#313793).
- bnx2fc: Bumped version to 1.0.12 (FATE#313917).
- bnx2fc: use list_entry instead of explicit cast (FATE#313917).
- bnx2fc: Improve error recovery by handling parity errors
  (FATE#313917).
- bnx2fc: Support interface creation on non-VLAN interface also
  (FATE#313917).
- bnx2fc: Reduce object size by consolidating formats
  (FATE#313917).
- bnx2fc: use kthread_create_on_node (FATE#313917).
- libfc: fix lun reset failure bugs in fc_fcp_resp handling of
  FCP_RSP_INFO (FATE#313793).
- fcoe: Fix write errors on NPIV ports (FATE#313793).
- libfc: fix sending REC after FCP_RESP is received (FATE#313793).
- libfc: fix retries with FDMI lport states (FATE#313793).
- libfc: don't exch_done() on invalid sequence ptr (FATE#313793).
- fcoe: Cleanup locking on fcoe_percpu_receive_thread
  (FATE#313793).
- fcoe: Remove redundant 'less than zero' check (FATE#313793).
- libfc: add exch timer debug info (FATE#313793).
- libfcoe: Fix section mismatch (FATE#313793).
- libfc: update fcp and exch stats (FATE#313793).
- libfc: adds FCP failures stats (FATE#313793).
- libfc, fcoe, bnx2fc: cleanup fcoe_dev_stats (FATE#313793).
- fcoe, bnx2fc, libfcoe: SW FCoE and bnx2fc use FCoE Syfs
  (FATE#313793).
- libfcoe: Add fcoe_sysfs (FATE#313793).
- bnx2fc: Allocate fcoe_ctlr with bnx2fc_interface, not as a
  member (FATE#313917).
- fcoe: Allocate fcoe_ctlr with fcoe_interface, not as a member
  (FATE#313793).
- bnx2fc: Bumped version to 1.0.11 (FATE#313917).
- bnx2fc: cleanup task management IO when it times out
  (FATE#313917).
- bnx2fc: Decrememnt io ref count when abort times out
  (FATE#313917).
- bnx2fc: Allow FLOGI to be retried when receiving bad responses
  (FATE#313917).
- bnx2fc: Remove bh disable in softirq context (FATE#313917).
- bnx2fc: HSI dependent changes for 7.2.xx FW (FATE#313917).
- bnx2fc: Bumped version to 1.0.10 (FATE#313917).
- bnx2fc: NPIV ports go offline when interface is brought down &
  up (FATE#313917).
- bnx2fc: Handle LOGO flooding from the target (FATE#313917).
- bnx2fc: fix panic in bnx2fc_post_io_req (FATE#313917).
- commit ab25590
* Thu Nov 29 2012 mgalbraith@suse.de
- patches.fixes/workqueue_exit_rescuer_thread_as_TASK_RUNNING.patch:
  workqueue: exit rescuer_thread() as TASK_RUNNING (bnc#789993).
- commit 4590387
* Thu Nov 29 2012 oneukum@suse.de
- patches.drivers/0001-xhci-Add-Lynx-Point-LP-to-list-of-Intel-switchable-h.patch:
  xhci: Add Lynx Point LP to list of Intel switchable hosts
  (bnc#791853).
- commit e9d176d
* Thu Nov 29 2012 hare@suse.de
- fcoe: remove a stray unlock (FATE#313793).
- libfcoe: fix VN2VN N_Port_ID Beacon source MAC (FATE#313793).
- fcoe: Don't hold rtnl_mutex in fcoe_update_src_mac
  (FATE#313793).
- libfc: defer releasing master lport until complete fcoe
  interface cleanuped up (FATE#313793).
- libfc: flush lport worker after its disabled (FATE#313793).
- fcoe: remove lport from net device before doing per cpu rx
  thread cleanup (FATE#313793).
- libfc: update mfs boundry checking (FATE#313793).
- fcoe: Drop the rtnl_mutex before calling fcoe_ctlr_link_up
  (FATE#313793).
- libfc: fcoe_transport_create fails in single-CPU environment
  (FATE#313793).
- fcoe: reduce contention for fcoe_rx_list lock (FATE#313793).
- fcoe: remove frame dropping code from fcoe_percpu_clean
  (FATE#313793).
- foce: remove bh disable from fcoe sw transport rcv function
  (FATE#313793).
- libfcoe: Support extra MAC descriptor to be used as FCoE MAC
  (FATE#313793).
- libfc: update fc_host mfs along with updating lport->mfs
  (FATE#313793).
- libfcoe: Do not sends FDISCs before FLOGI during CVL
  (FATE#313793).
- fcoe: Ensure fcoe_recv_frame is always called in process context
  (FATE#313793).
- fcoe: use CHECKSUM_UNNECESSARY instead of CHECKSUM_PARTIAL on tx
  (FATE#313793).
- libfc: Handle discovery failure during ctlr link down
  (FATE#313793).
- libfc: Fix panic in fc_exch_recv (FATE#313793).
- fcoe: Remove reference counting on 'stuct fcoe_interface'
  (FATE#313793).
- fcoe: Do not switch context in vport_delete callback
  (FATE#313793).
- fcoe: Rename out_nomod label to out_putmod (FATE#313793).
- fcoe: Allow exposing FDMI attributes via sysfs (FATE#313793).
- libfcoe: Don't KERN_ERR on netdev notification (FATE#313793).
- fcoe: Allow exposing FDMI attributes via sysfs (FATE#313793).
- fcoe: Add support for FDMI in fcoe (FATE#313793).
- libfc: Add support for FDMI (FATE#313793).
- libfc: Make the libfc Common Transport(CT) code generic
  (FATE#313793).
- scsi_transport_fc: Getting FC Port Speed in sync with FC-GS
  (FATE#313793).
- scsi_transport_fc: Add FDMI host attributes (FATE#313793).
- libfc: remove redundant timer init for fcp (FATE#313793).
- fcoe: Move fcoe_debug_logging from fcoe.h to fcoe.c
  (FATE#313793).
- libfc: Declare local functions static (FATE#313793).
- fcoe: remove double check if skb is nonlinear (FATE#313793).
- commit d0457af
* Thu Nov 29 2012 hare@suse.de
- ixgbe: FCoE: Add support for ndo_get_fcoe_hbainfo() call
  (FATE#313759).
- ixgbe: change the eeprom version reported by ethtool
  (FATE#313759).
- netdev: FCoE: Add new ndo_get_fcoe_hbainfo() call (FATE#313759).
- Refresh
  patches.fixes/net-dev-define-NETDEV_FCOE_WWNN-only-when-LIBFCOE-enabled.
- commit 1e5d448
* Thu Nov 29 2012 mmarek@suse.cz
- patches.drivers/0002-net-next-Add-netif_get_num_default_rss_queues.patch
  Move up in the series.
- commit edf59cc
* Thu Nov 29 2012 hare@suse.de
- Fixup
  patches.drivers/0070-isci-stop-interpreting-lldd_lu_reset-as-an-ata-.patch.
- commit db7a1d2
* Thu Nov 29 2012 hare@suse.de
- Refresh
  patches.drivers/0070-isci-stop-interpreting-lldd_lu_reset-as-an-ata-.patch.
- commit 13d5509
* Thu Nov 29 2012 jjolly@suse.de
- patches.arch/s390-61-01-zfcp-revert-xconf-handling.patch:
  zfcp: fix adapter (re)open recovery while link to SAN is down
  (bnc#789010,LTC#86283).
- patches.arch/s390-61-02-qeth-setmac-after-delmac-fail.patch:
  qeth: set new mac even if old mac is gone
  (bnc#789010,LTC#86643).
- patches.arch/s390-61-03-qdio-fix-kernel-panic-for-zfcp-31-bit.patch:
  qdio: fix kernel panic for zfcp 31-bit (bnc#789010,LTC#86623).
- patches.arch/s390-61-04-crypto-perffix-msgtype50.patch: Crypto:
  msgType50 (RSA-CRT) Fix (bnc#789010,LTC#86378).
- commit dcfdf2f
* Thu Nov 29 2012 jslaby@suse.cz
- Linux 3.0.53 (bnc#773831 bnc#786976 LTC#86307).
- patches.xen/pci-reserve: Refresh.
- patches.xen/xen3-patch-2.6.25: Refresh.
- patches.arch/s390-60-03-gup-task-size.patch: Delete.
- patches.rpmify/kbuild-fix-gcc-x-syntax.patch: Delete.
- commit f881ddf
* Wed Nov 28 2012 bpoirier@suse.de
- patches.drivers/0001-tg3-Introduce-separate-functions-to-allocate-free-RX.patch:
  tg3: Introduce separate functions to allocate/free RX/TX rings
  (bnc#785554).
- patches.drivers/0002-net-next-Add-netif_get_num_default_rss_queues.patch:
  net-next: Add netif_get_num_default_rss_queues (bnc#785554).
- patches.drivers/0003-tg3-set-maximal-number-of-default-RSS-queues.patch:
  tg3: set maximal number of default RSS queues (bnc#785554).
- patches.drivers/0004-tg3-Allow-number-of-rx-and-tx-rings-to-be-set-indepe.patch:
  tg3: Allow number of rx and tx rings to be set independently
  (bnc#785554).
- patches.drivers/0005-tg3-Separate-coalescing-setup-for-rx-and-tx.patch:
  tg3: Separate coalescing setup for rx and tx (bnc#785554).
- patches.drivers/0006-tg3-Refactor-tg3_open.patch: tg3: Refactor
  tg3_open() (bnc#785554).
- patches.drivers/0007-tg3-Refactor-tg3_close.patch: tg3:
  Refactor tg3_close() (bnc#785554).
- patches.drivers/0008-tg3-Add-support-for-ethtool-L-l-to-get-set-the-numbe.patch:
  tg3: Add support for ethtool -L|-l to get/set the number of
  rings (bnc#785554).
- patches.drivers/0009-tg3-Disable-multiple-TX-rings-by-default-due-to-hard.patch:
  tg3: Disable multiple TX rings by default due to hardware flaw
  (bnc#785554).
- commit 1f0b1e0
* Wed Nov 28 2012 mmarek@suse.cz
- kabi/severities: Ignore md raid exports (fate#311379).
- commit 76740a8
* Wed Nov 28 2012 hare@suse.de
- isci: copy fis 0x34 response into proper buffer (FATE#313629).
- isci: Fix interrupt coalescing assumption of active TCs
  (FATE#313629).
- isci: Allow SSP tasks into the task management path
  (FATE#313629).
- libsas, ipr: cleanup ata_host flags initialization via
  ata_host_init (FATE#313629).
- isci: implement suspend/resume support (FATE#313629).
- libsas: suspend / resume support (FATE#313629).
- libata: export ata_port suspend/resume infrastructure for sas
  (FATE#313629).
- libata: reset once (FATE#313629).
- Revert "[SCSI] fix async probe regression" (FATE#313629).
- cleanup usages of scsi_complete_async_scans (FATE#313629).
- queue async scan work to an async_schedule domain (FATE#313629).
- async: make async_synchronize_full() flush all work regardless
  of domain (FATE#313629).
- async: introduce 'async_domain' type (FATE#313629).
- mvsas: remove unused variable in mvs_task_exec() (FATE#313629).
- libsas: trim sas_task of slow path infrastructure (FATE#313629).
- libsas: drop sata port multiplier infrastructure (FATE#313629).
- libsas: sas_rediscover_dev did not look at the SMP exec status
  (FATE#313629).
- isci: use sas eh strategy handlers (FATE#313629).
- libsas: use ->lldd_I_T_nexus_reset for ->eh_bus_reset_handler
  (FATE#313629).
- libsas: add sas_eh_abort_handler (FATE#313629).
- libsas: enforce eh strategy handlers only in eh context
  (FATE#313629).
- libsas: cleanup spurious calls to scsi_schedule_eh
  (FATE#313629).
- libata, libsas: introduce sched_eh and end_eh port ops
  (FATE#313629).
- libsas: fix taskfile corruption in sas_ata_qc_fill_rtf
  (FATE#313629).
- isci: add a couple __iomem annotations (FATE#313629).
- isci: make function declaration match implementation
  (FATE#313629).
- isci: fix COMSAS negation timout workaround for WD SAS drives
  (FATE#313629).
- isci: fix isci_pci_probe() generates warning on efi failure path
  (FATE#313629).
- isci: End the RNC resumption wait when the RNC is destroyed
  (FATE#313629).
- isci: Fixed RNC bug that lost the suspension or resumption
  during destroy (FATE#313629).
- isci: Fix RNC AWAIT_SUSPENSION->INVALIDATING transition
  (FATE#313629).
- isci: Manage the IREQ_NO_AUTO_FREE_TAG under scic_lock
  (FATE#313629).
- isci: Remove obviated host callback list (FATE#313629).
- isci: Check IDEV_GONE before performing abort path operations
  (FATE#313629).
- isci: Restore the ATAPI device RNC management code
  (FATE#313629).
- isci: Don't wait for an RNC suspend if it's being destroyed
  (FATE#313629).
- isci: Change the phy control and link reset interface for HW
  reasons (FATE#313629).
- isci: Added timeouts to RNC suspensions in the abort path
  (FATE#313629).
- isci: Add protocol indicator for TMF requests (FATE#313629).
- isci: Directly control IREQ_ABORT_PATH_ACTIVE when completing
  TMFs (FATE#313629).
- isci: Wait for RNC resumption before leaving the abort path
  (FATE#313629).
- isci: Fix RNC suspend call for SCI_RESUMING state (FATE#313629).
- isci: Manage tag releases differently when aborting tasks
  (FATE#313629).
- isci: Callbacks to libsas occur under scic_lock and are
  synchronized (FATE#313629).
- isci: When in the abort path, defeat other resume calls until
  done (FATE#313629).
- isci: Implement waiting for suspend in the abort path
  (FATE#313629).
- isci: Make sure all TCs are terminated and cleaned in LUN reset
  (FATE#313629).
- isci: Manage the LLHANG timer enable/disable per-device
  (FATE#313629).
- isci: Save the suspension hint for upcoming suspensions
  (FATE#313629).
- isci: Fix the terminated I/O to not call sas_task_abort()
  (FATE#313629).
- isci: Distinguish between remote device suspension cases
  (FATE#313629).
- isci: Remove isci_device reqs_in_process and dev_node from
  isci_device (FATE#313629).
- isci: Only set IDEV_GONE in the device stop path (FATE#313629).
- isci: All pending TCs are terminated when the RNC is invalidated
  (FATE#313629).
- isci: Device access in the error path does not depend on
  IDEV_GONE (FATE#313629).
- isci: Add suspension cases for RNC INVALIDATING, POSTING states
  (FATE#313629).
- isci: Redesign device suspension, abort, cleanup (FATE#313629).
- isci: Escalate to I_T_Nexus_Reset when the device is gone
  (FATE#313629).
- isci: Remote device stop also suspends the RNC and terminates
  I/O (FATE#313629).
- isci: Remote device must be suspended for NCQ cleanup
  (FATE#313629).
- isci: Manage device suspensions during TC terminations
  (FATE#313629).
- isci: Terminate outstanding TCs on TX/RX RNC suspensions
  (FATE#313629).
- isci: Handle all suspending TC completions (FATE#313629).
- isci: Fixed bug in resumption from RNC Tx/Rx suspend state
  (FATE#313629).
- isci: Manage the link layer hang detect timer for RNC
  suspensions (FATE#313629).
- isci: enable BCN in sci_port_add_phy() (FATE#313629).
- isci: Changes in COMSAS timings enabling ISCI to detect buggy
  disc drives (FATE#313629).
- isci: kill isci_host.shost (FATE#313629).
- isci: fix interrupt disable (FATE#313629).
- isci: fix 'link-up' events occur after 'start-complete'
  (FATE#313629).
- isci: fix controller stop (FATE#313629).
- isci: refactor initialization for S3/S4 (FATE#313629).
- isci: kill isci_port.domain_dev_list (FATE#313629).
- isci: kill ->status, and ->state_lock in isci_host
  (FATE#313629).
- isci: Don't filter BROADCAST CHANGE primitives (FATE#313629).
- isci: kill sci_phy_protocol and sci_request_protocol
  (FATE#313629).
- isci: kill ->is_direct_attached (FATE#313629).
- isci: improve 'invalid state' warnings (FATE#313629).
- Revert "[SCSI] libsas: fix sas port naming" (FATE#313629).
- libsas, libata: fix start of life for a sas ata_port
  (FATE#313629).
- libata: make ata_print_id atomic (FATE#313629).
- libsas: fix ata_eh clobbering ex_phys via smp_ata_check_ready
  (FATE#313629).
- libsas: unify domain_device sas_rphy lifetimes (FATE#313629).
- libsas: fix sas_get_port_device regression (FATE#313629).
- libsas: introduce sas_work to fix sas_drain_work vs
  sas_queue_work (FATE#313629).
- isci: improvements in driver unloading routine (FATE#313629).
- isci: improve phy event warnings (FATE#313629).
- isci: debug, provide state-enum-to-string conversions
  (FATE#313629).
- libsas: don't recover end devices attached to disabled phys
  (FATE#313629).
- libsas: fixup target_port_protocols for expanders that don't
  report sata (FATE#313629).
- libsas: set attached device type and target protocols for
  local phys (FATE#313629).
- libsas: revert ata srst (FATE#313629).
- libsas: fix lifetime of SAS_HA_FROZEN (FATE#313629).
- libsas: async ata scanning (FATE#313629).
- libsas: restore scan order (FATE#313629).
- libsas: delete device on sas address changed (FATE#313629).
- libsas: let libata recover links that fail to transmit initial
  sig-fis (FATE#313629).
- libsas: fix sas port naming (FATE#313629).
- libsas: improve debug statements (FATE#313629).
- libsas: kill spurious sas_put_device (FATE#313629).
- libsas: fix sas_unregister_ports vs sas_drain_work
  (FATE#313629).
- libsas: route local link resets through ata-eh (FATE#313629).
- libsas: fix mixed topology recovery (FATE#313629).
- libsas: close scsi_remove_target() vs libata-eh race
  (FATE#313629).
- libsas: mark all domain devices gone if root port disappears
  (FATE#313629).
- libsas: pre-clean commands that won the eh vs completion race
  (FATE#313629).
- isci: remove IDEV_EH hack to disable "discovery-time" ata resets
  (FATE#313629).
- isci: remove bus and reset handlers (FATE#313629).
- isci: ->lldd_ata_check_ready handler (FATE#313629).
- isci: stop interpreting ->lldd_lu_reset() as an ata soft-reset
  (FATE#313629).
- isci: fix interpretation of "hard" reset (FATE#313629).
- isci: kill isci_port->status (FATE#313629).
- isci: kill iphy->isci_port lookups (FATE#313629).
- libsas: don't recover 'gone' devices in sas_ata_hard_reset()
  (FATE#313629).
- libsas: fix sas_find_local_phy(), take phy references
  (FATE#313629).
- libsas: check for 'gone' expanders in smp_execute_task()
  (FATE#313629).
- libsas: don't mark expanders as gone when a child device is
  removed (FATE#313629).
- libsas: poll for ata device readiness after reset (FATE#313629).
- libsas: async ata-eh (FATE#313629).
- libsas: add mutex for SMP task execution (FATE#313629).
- libsas: Remove redundant phy state notification calls
  (FATE#313629).
- libsas: sas_phy_enable via transport_sas_phy_reset
  (FATE#313629).
- libsas: execute transport link resets with libata-eh via host
  workqueue (FATE#313629).
- libsas: perform sas-transport resets in shost->workq context
  (FATE#313629).
- libsas: use libata-eh-reset for sata rediscovery fis transmit
  failures (FATE#313629).
- libsas: defer SAS_TASK_NEED_DEV_RESET commands to libata
  (FATE#313629).
- libsas: let libata handle command timeouts (FATE#313629).
- libsas: fix timeout vs completion race (FATE#313629).
- libsas: prevent double completion of scmds from eh
  (FATE#313629).
- libsas: close error handling vs sas_ata_task_done() race
  (FATE#313629).
- libsas: kill invocation of scsi_eh_finish_cmd from
  sas_ata_task_done (FATE#313629).
- libsas: use ->set_dmamode to notify lldds of NCQ parameters
  (FATE#313629).
- libsas: prevent domain rediscovery competing with ata error
  handling (FATE#313629).
- libsas: convert dev->gone to flags (FATE#313629).
- libsas: remove ata_port.lock management duties from lldds
  (FATE#313629).
- libsas: introduce sas_drain_work() (FATE#313629).
- libsas: convert ha->state to flags (FATE#313629).
- libsas: replace event locks with atomic bitops (FATE#313629).
- libsas: fix leak of dev->sata_dev.identify_[packet_]device
  (FATE#313629).
- libsas: fix domain_device leak (FATE#313629).
- libsas: kill sas_slave_destroy (FATE#313629).
- libsas: remove unused ata_task_resp fields (FATE#313629).
- isci: T10 DIF support (FATE#313629).
- isci: enable clock gating (FATE#313629).
- isci: Fix NULL ptr dereference when no firmware is being loaded
  (FATE#313629).
- SCSI, ISCSI: Just #include "host.h" once in host.c
  (FATE#313629).
- enable ata port async suspend (FATE#313629).
- isci: fix, prevent port from getting stuck in the 'configuring'
  state (FATE#313629).
- isci: fix start OOB (FATE#313629).
- isci: fix io failures while wide port links are coming up
  (FATE#313629).
- isci: allow more time for wide port targets (FATE#313629).
- isci: enable wide port targets (FATE#313629).
- isci: Fix IO fails when pull cable from phy in x4 wideport in
  MPC mode (FATE#313629).
- isci: update version to 1.1 (FATE#313629).
- isci: remove unused 'isci_tmf->device' field (FATE#313629).
- isci: link speeds default to gen 2 (FATE#313629).
- isci: performance-fix, shorten default "no outbound task"
  timeout (FATE#313629).
- isci: oem parameter format v1.3 (cable select) (FATE#313629).
- isci: oem parameter format v1.1 (ssc select) (FATE#313629).
- isci: update afe (analog-front-end) recipe for C1 (FATE#313629).
- isci: cleanup oem parameter and recipe handling (FATE#313629).
- isci, firmware: Remove isci fallback parameter blob and
  generator (FATE#313629).
- ata: add ata port hibernate callbacks (FATE#313629).
- ata: update ata port's runtime status during system resume
  (FATE#313629).
- ata: add ata port runtime PM callbacks (FATE#313629).
- ata: add ata port system PM callbacks (FATE#313629).
- ata: make ata port as parent device of scsi host (FATE#313629).
- isci: overriding max_concurr_spinup oem parameter by max(oem,
  user) (FATE#313629).
- isci: revert bcn filtering (FATE#313629).
- isci: Fix hard reset timeout conditions (FATE#313629).
- isci: No need to manage the pending reset bit on pending
  requests (FATE#313629).
- isci: Remove redundant isci_request.ttype field (FATE#313629).
- isci: Fix task management for SMP, SATA and on dev remove
  (FATE#313629).
- isci: No task_done callbacks in error handler paths
  (FATE#313629).
- isci: Handle task request timeouts correctly (FATE#313629).
- isci: Fix tag leak in tasks and terminated requests
  (FATE#313629).
- isci: Immediately fail I/O to removed devices (FATE#313629).
- isci: Lookup device references through requests in completions
  (FATE#313629).
- libsas: fix port->dev_list locking (FATE#313629).
- commit 1f51d97
* Wed Nov 28 2012 bpoirier@suse.de
- Revert "module.h: split out the EXPORT_SYMBOL into export.h"
  Some kmp packages (ex. drm-kmp) already create a dummy linux/export.h. Adding
  the real thing breaks the build for those packages.
- Refresh
  patches.drivers/cxgb3-0014-net-treewide-use-of-RCU_INIT_POINTER.patch.
- Refresh
  patches.drivers/cxgb3-0015-cxgb3-Rework-t3_l2t_get-to-take-a-dst_entry-instead-.patch.
- Refresh
  patches.drivers/cxgb3-0016-cxgb3-Handle-NULL-dst-neighbour-in-cxgb3_offload.c.patch.
- Refresh
  patches.drivers/cxgb3-0018-ethernet-unify-return-value-of-.ndo_set_mac_address-.patch.
- Refresh
  patches.drivers/cxgb3-0019-ethernet-Remove-casts-to-same-type.patch.
- Refresh
  patches.drivers/cxgb3-0020-net-next-Add-netif_get_num_default_rss_queues.patch.
- Refresh
  patches.drivers/cxgb3-0022-drivers-net-ethernet-Fix-nearly-kernel-doc-comments-.patch.
- Delete
  patches.drivers/cxgb3-0010-module.h-split-out-the-EXPORT_SYMBOL-into-export.h.patch.
- Delete
  patches.drivers/cxgb3-0011-drivers-net-Add-export.h-to-files-using-EXPORT_SYMBO.patch.
- commit 3deed40
* Wed Nov 28 2012 hare@suse.de
- workqueue: lock cwq access in drain_workqueue (FATE#313629).
- workqueue: separate out drain_workqueue() from
  destroy_workqueue() (FATE#313629).
- commit 4227049
* Wed Nov 28 2012 hare@suse.de
- Refresh
  patches.suse/0008_efi:_Enable_secure_boot_lockdown_automatically_when_enabled_in_firmware_v2.patch.
- Refresh
  patches.suse/0009_acpi:_Ignore_acpi_rsdp_kernel_parameter_in_a_secure_boot_environment_v2.patch.
- Refresh
  patches.suse/0010_SELinux:_define_mapping_for_new_Secure_Boot_capability_v2.patch.
- commit bc042ca
* Wed Nov 28 2012 brogers@suse.com
- vhost: zerocopy: poll vq in zerocopy callback (fate#314400).
- vhost_net: zerocopy: adding and signalling immediately when
  fully copied (fate#314400).
- vhost_net: zerocopy: fix possible NULL pointer dereference of
  vq->bufs (fate#314400).
- skbuff: struct ubuf_info callback type safety (fate#314400).
- vhost: fix zcopy reference counting (fate#314400).
- vhost: vhost TX zero-copy support (fate#314400).
- sock.h: Add a new sock zero-copy flag (fate#314400).
- skbuff: export skb_copy_ubufs (fate#314400).
- net: copy userspace buffers on device forwarding (fate#314400).
- skbuff: fix error handling in pskb_copy() (fate#314400).
- net: introduce __netdev_alloc_skb_ip_align (fate#314400).
- skbuff: update struct sk_buff members comments (fate#314400).
- skbuff: clear tx zero-copy flag (fate#314400).
- skbuff: skb supports zero-copy buffers (fate#314400).
- macvtap: zerocopy: validate vectors before building skb
  (fate#314400).
- macvtap: zerocopy: set SKBTX_DEV_ZEROCOPY only when skb is
  built successfully (fate#314400).
- macvtap: zerocopy: put page when fail to get all requested
  user pages (fate#314400).
- macvtap: zerocopy: fix truesize underestimation (fate#314400).
- macvtap: zerocopy: fix offset calculation when building skb
  (fate#314400).
- macvtap: Don't leak unreceived packets when we delete a macvtap
  device (fate#314400).
- macvtap: Fix macvtap_open races in the zero copy enable code
  (fate#314400).
- macvtap: Close a race between macvtap_open and macvtap_dellink
  (fate#314400).
- macvtap: macvtapTX zero-copy support (fate#314400).
- commit ed7f067
* Wed Nov 28 2012 trenn@suse.de
- patches.arch/x86_amd_fam16h_microcode_fix.patch: x86,
  microcode, AMD: Add support for family 16h processors
  (bnc#791498,fate#314145).
- commit 16f37d6
* Wed Nov 28 2012 hare@suse.de
- patches.fixes/scsi_remove_target-fix-softlockup.patch:
  Delete patch, contained in -stable update.
- commit f198603
* Wed Nov 28 2012 hare@suse.de
- patches.fixes/scsi_remove_target-fix-softlockup.patch:
  scsi_remove_target: fix softlockup regression on hot remove
  (bnc#789836).
- commit fbb0cdb
* Wed Nov 28 2012 hare@suse.de
- Remove duplicate patch entry
- commit f32e451
* Tue Nov 27 2012 bpoirier@suse.de
- drivers/net: Remove casts of void * (bnc#784800 FATE#314296).
- cxgb3: remove unnecessary read of PCI_CAP_ID_EXP (bnc#784800
  FATE#314296).
- cxgb3: do vlan cleanup (bnc#784800 FATE#314296).
- chelsio: Move the Chelsio drivers (bnc#784800 FATE#314296).
- net: add APIs for manipulating skb page fragments (bnc#784800
  FATE#314296).
- cxgb3: convert to SKB paged frag API (bnc#784800 FATE#314296).
- net: use DMA_x_DEVICE and dma_mapping_error with
  skb_frag_dma_map (bnc#784800 FATE#314296).
- net: Remove unnecessary driver assignments of ethtool_ringparam
  fields to zero (bnc#784800 FATE#314296).
- net: add skb frag size accessors (bnc#784800 FATE#314296).
- module.h: split out the EXPORT_SYMBOL into export.h (bnc#784800
  FATE#314296).
- drivers/net: Add export.h to files using
  EXPORT_SYMBOL/THIS_MODULE (bnc#784800 FATE#314296).
- Sweep additional floors of strcpy in .get_drvinfo routines
  (bnc#784800 FATE#314296).
- Sweep away N/A fw_version dustbunnies from the .get_drvinfo
  routine of a number of drivers (bnc#784800 FATE#314296).
- net: treewide use of RCU_INIT_POINTER (bnc#784800 FATE#314296).
- cxgb3: Rework t3_l2t_get to take a dst_entry instead of a
  neighbour (bnc#784800 FATE#314296).
- cxgb3: Handle NULL dst neighbour in cxgb3_offload.c (bnc#784800
  FATE#314296).
- cxgb3: update firmware version (bnc#784800 FATE#314296).
- ethernet: unify return value of .ndo_set_mac_address if address
  is invalid (bnc#784800 FATE#314296).
- ethernet: Remove casts to same type (bnc#784800 FATE#314296).
- net-next: Add netif_get_num_default_rss_queues (bnc#784800
  FATE#314296).
- cxgb3: set maximal number of default RSS queues (bnc#784800
  FATE#314296).
- drivers/net/ethernet: Fix (nearly-)kernel-doc comments for
  various functions (bnc#784800 FATE#314296).
- PCI: Add accessors for PCI Express Capability (bnc#784800
  FATE#314296).
- cxgb3: Use PCI Express Capability accessors (bnc#784800
  FATE#314296).
- PCI: Make pci_error_handlers const (bnc#784800 FATE#314296).
- netdev: make pci_error_handlers const (bnc#784800 FATE#314296).
- Update config files.
- Refresh
  patches.drivers/cxgb3-set-vlan_feature-on-net_device.patch.
- Refresh patches.xen/xen-cxgb3.
- commit 8d7ce20
* Tue Nov 27 2012 mszeredi@suse.cz
- patches.fixes/autofs4-allow-autofs-to-work-outside-the-initial-pid-namespace.patch:
  autofs4: allow autofs to work outside the initial PID namespace
  (bnc#779294).
- patches.fixes/autofs4-translate-pids-to-the-right-namespace-for-the-daemon.patch:
  autofs4: translate pids to the right namespace for the daemon
  (bnc#779294).
- commit 0b55b4c
* Tue Nov 27 2012 rgoldwyn@suse.de
- vfs: dont chain pipe/anon/socket on superblock s_inodes list
  patches.fixes/vfs-dont-chain-pipe-anon-sockets-on-superbloc-s_inodes-list
  (bnc#789703)
- commit a7a142a
* Tue Nov 27 2012 rgoldwyn@suse.de
- patches.fixes/vfs-dont-chain-pipe-anon-sockets-on-superbloc-s_inodes-list:
  vfs: dont chain pipe/anon/socket on superblock s_inodes list
  (bnc#789703)
- commit c575a68
* Tue Nov 27 2012 jeffm@suse.com
- patches.fixes/reiserfs-fix-problems-with-chowning-setuid-file-w-xattrs:
  reiserfs: fix problems with chowning setuid file w/ xattrs
  (bnc#790920).
- patches.fixes/reiserfs-fix-double-lock-while-chowning-setuid-file-w-xattrs:
  Delete.
- commit 6075aeb
* Tue Nov 27 2012 trenn@suse.de
- mwait number passed via driver_data is needed before 3.1, fixed:
- patches.arch/intel_idle_add_ivy_bridge_support.patch: Refresh.
- commit 980c094
* Tue Nov 27 2012 hare@suse.de
- Update config files to enable VIRTIO-SCSI (FATE#314135)
- commit a4bee38
* Tue Nov 27 2012 hare@suse.de
- Virtio and virtio-scsi update (FATE#314135):
  * virtio: expose for non-virtualization users too
  * Add ethtool -g support to virtio_net
  * virtio: Add module.h to drivers/virtio users
  * virtio: Dont add "config" to list for !per_vq_vector
  * virtio: Add platform bus driver for memory mapped virtio device
  * enable virtio_net to return bus_info in ethtool -i consistent
    with emulated NICs
  * virtio: add HAS_IOMEM dependency to MMIO platform bus driver
  * virtio-mmio: Correct the name of the guest features selector
  * virtio-pci: make reset operation safer
  * virtio: harsher barriers for rpmsg
  * virtio-balloon: Trivial cleanups
  * virtio: document functions better
  * fs/9p: Update zero-copy implementation in 9p
  * virtio: rename virtqueue_add_buf_gfp to virtqueue_add_buf
  * virtio: support unlocked queue kick
  * virtio: avoid modulus operation
  * virtio: expose added descriptors immediately
  * virtio: add debugging if driver doesn't kick
  * virtio: pci: switch to new PM API
  * virtio: pci: add PM notification handlers for restore, freeze,
    thaw, poweroff
  * virtio: balloon: Move vq initialization into separate function
  * virtio: balloon: Add freeze, restore handlers to support S4
  * virtio: fix typos of memory barriers
  * virtio: correct the memory barrier in virtqueue_kick_prepare()
  * virtio: balloon: leak / fill balloon across S4
  * virtio: balloon: Allow stats update after restore from S4
  * virtio: drop thaw PM operation
  * virtio-pci: drop restore_common()
  * virtio-pci: S3 support
  * virtio-pci: switch to PM ops macro to initialise PM functions
  * virtio_balloon: Fix endian bug
  * virtio_balloon: fix handling of PAGE_SIZE != 4k
  * virtio: balloon: let host know of updated balloon size before
    module removal
  * virtio: balloon: drop restore_common()
  * virtio: balloon: separate out common code between remove and
    freeze functions
  * virtio: Use ida to allocate virtio index
  * virtio-balloon: fix add/get API use
  * virtio-balloon: dependency fix
  * virtio_balloon: not EXPERIMENTAL any more
  * virtio-ring: move queue_index to vring_virtqueue
  * virtio: introduce an API to set affinity for a virtqueue
  * virtio: support reserved vqs
  * virtio: add help to CONFIG_VIRTIO option
  * virtio: remove CONFIG_VIRTIO_RING
  * virtio: don't crash when device is buggy
  * virtio_pci: fix error return code
  * virtio_mmio: fix off by one error allocating queue
  * virtio_mmio: Don't attempt to create empty virtqueues
  * virtio: Don't access index after unregister
  * [SCSI] virtio-scsi: SCSI driver for QEMU based virtual machines
  * [SCSI] virtio_scsi: fix TMF use-after-free
  * [SCSI] virtio-scsi: unlock during kick
  * [SCSI] virtio-scsi: split locking per vq
  * [SCSI] virtio-scsi: release sg_lock after add_buf
  * [SCSI] virtio-scsi: split scatterlist per target
  * [SCSI] virtio-scsi: hotplug support for virtio-scsi
  * [SCSI] virtio-scsi: Add vdrv->scan for post
    VIRTIO_CONFIG_S_DRIVER_OK LUN scanning
  * [SCSI] scsi: virtio-scsi: Fix address translation failure of
    HighMem pages used by sg list
  * [SCSI] virtio-scsi: initialize scatterlist structure
  * [SCSI] virtio-scsi: fix LUNs greater than 255
  * [SCSI] virtio-scsi: support online resizing of disks
- Refresh
  patches.suse/msft-hv-0324-Staging-hv-storvsc-Move-the-storage-driver-out-of.patch.
- commit 50678cc
* Tue Nov 27 2012 ptesarik@suse.cz
- patches.suse/hid-drff-alias.patch: Update Patch-mainline tag.
- commit 50a0b33
* Tue Nov 27 2012 jdelvare@suse.de
- patches.drivers/edac_i7core_phys_proc_id_use_socketid.patch:
  Add upstream reference.
- commit e5a053b
* Tue Nov 27 2012 mgorman@suse.de
- mm: vmscan: check for fatal signals iff the process was throttled.
- commit 07137c5
* Tue Nov 27 2012 hare@suse.de
- Update SCSI drivers from mainline (FATE#313625):
  * SCSI: ARM: make fas216_dumpinfo function conditional
  * SCSI: ARM: ncr5380/oak uses no interrupts
  * [SCSI] aha152x: Allow use on 64bit systems
  * aic7xxx: Fix typo in aic7xxx
  * aic7xxx: fix Kconfig references to READMEs
  * aic94xx: Get rid of redundant NULL check before
    release_firmware() call
  * aic94xx: Use angle brackets for system includes
  * [SCSI] arcmsr: fix misuse of | instead of &
  * floppy/scsi: fix setting of BIO flags
  * gdt: remove unnecessary #defines
  * [SCSI] hptiop: fix RR312x in hosts with >12GB
  * [SCSI] megaraid: cleanup type issue in mega_build_cmd()
  * [SCSI] megaraid: fix sparse warnings
  * [SCSI] megaraid: remove a spurious IRQ enable
  * megaraid: remove unnecessary #defines
  * [SCSI] mvumi: Add Marvell UMI driver
  * [SCSI] mvumi: Add support for Marvell SAS/SATA RAID-on-Chip(ROC)
    88RC9580
  * osd: Kconfig remove wrong FIXME
  * qla1280: Remove redundant NULL check before release_firmware()
    call
  * [SCSI] qlogicpti: Fix build warning
  * [SCSI] qlogicpti: fix timeout
  * [SCSI] aha152x: Fix sparse warning and make printing pointer
    address more portable
  * [SCSI] eesox: use __iomem pointers for MMIO
  * [SCSI] ufs: Assign UTRLBAU = upper_32_ bits(UTRLD base address)
  * [SCSI] ufs: Fix evaluation of UTP task completion code
  * [SCSI] ufs: fix incorrect return value about SUCCESS and FAILED
  * [SCSI] ufs: fix potential NULL pointer dereferencing error in
    ufshcd_prove
  * [SCSI] ufs: reverse the ufshcd_is_device_present logic
  * [SCSI] ufs: use module_pci_driver
  * [SCSI] ufshcd: UFS Host controller driver
- Update config files.
- commit ed25fa6
* Tue Nov 27 2012 tiwai@suse.de
- patches.drivers/alsa-sp3-pre-010-Fix-SSYNC-register-value-for-non-Intel-cont:
  ALSA: hda - Fix SSYNC register value for non-Intel controllers
  (fate#313409,bnc#760833).
- patches.drivers/alsa-sp3-pre-146-option-to-enable-arbitrary-buffer-period-si:
  ALSA: hda: option to enable arbitrary buffer/period sizes
  (fate#313409,bnc#760833).
- patches.drivers/alsa-sp3-pre-355-Fix-buffer-alignment-regression-with-Nvidia:
  ALSA: hda - Fix buffer-alignment regression with Nvidia HDMI
  (fate#313409,bnc#760833).
- patches.drivers/alsa-sp3-pre-388-explicitly-set-buffer-align-flag-for-Nvidia:
  ALSA: hda - explicitly set buffer-align flag for Nvidia
  controllers (fate#313409,bnc#760833).
- patches.drivers/alsa-sp3-pre-393-Add-Lynx-Point-HD-Audio-Controller-DeviceID:
  ALSA: hda - Add Lynx Point HD Audio Controller DeviceIDs
  (fate#313409,bnc#760833).
- patches.drivers/alsa-sp3-pre-596-hda_intel-Add-Device-IDs-for-Intel-Lynx-Point-L:
  ALSA: hda_intel: Add Device IDs for Intel Lynx Point-LP PCH
  (fate#313409,bnc#760833).
- commit e58939e
* Tue Nov 27 2012 hare@suse.de
- SCSI midlayer backport for SLES11 SP3 (FATE#313629):
  * [SCSI] Change return type of scsi_queue_insert() into void
  * [SCSI] Disable DIF on Hitachi Ultrastar 15K300
  * [SCSI] Ensure discard failure gets treated as a target problem
  * [SCSI] Fix device removal NULL pointer dereference
  * [SCSI] Fix error handling when no ULD is attached
  * [SCSI] Fix out of spec CD-ROM problem with media change
  * [SCSI] Fix sd_probe_domain config problem
  * [SCSI] Handle disk devices which can not process medium access
    commands
  * Make wait_for_device_probe() also do scsi_complete_async_scans()
  * [SCSI] Remove scsi_wait_scan module
  * [SCSI] Shorten the path length of scsi_cmd_to_driver()
  * [SCSI] add DID_TARGET_FAILURE and DID_NEXUS_FAILURE to
    hostbyte_table in constants.c
  * [SCSI] add flag to skip the runtime PM calls on the host
  * [SCSI] add new SDEV_TRANSPORT_OFFLINE state
  * block: drop custom queue draining used by
    scsi_transport_{iscsi|fc}
  * block: misc updates to blk_get_queue()
  * [SCSI] check runtime PM status in system PM
  * [SCSI] cleanup setting task state in scsi_error_handler()
  * [SCSI] core, classes, mpt2sas: have scsi_internal_device_unblock
    take new state
  * [SCSI] fc: add some more FC specific stats to fc_host
  * [SCSI] fix async probe regression
  * [SCSI] fix oops in all legacy host adapters caused by 6f381fa
  * [SCSI] properly initialize atomic_t
  * [SCSI] runtime resume parent for child's system-resume
  * scsi: Use vsprintf extention %%pf with builtin_return_address
  * scsi: fix comment spelling fix recory->recovery
  * scsi/sg: use printk_ratelimited instead of printk_ratelimit
  * [SCSI] scsi_debug: Add "removable" parameter
  * [SCSI] scsi_debug: Fix incorrect page length in logical block
    provisioning VPD
  * [SCSI] scsi_debug: Fix off-by-one bug when unmapping region
  * [SCSI] scsi_debug: GET LBA STATUS response length correction
  * [SCSI] scsi_debug: add LBPRZ support
  * [SCSI] scsi_dh: add scsi_dh_attached_handler_name
  * [SCSI] scsi_error: classify some ILLEGAL_REQUEST sense as a
    permanent TARGET_ERROR
  * [SCSI] scsi_lib: Set the device state from transport-offline
    to running
  * [SCSI] scsi_lib: fix scsi_io_completion's SG_IO error
    propagation
  * [SCSI] scsi_lib: use correct DMA device in __scsi_alloc_queue
  * [SCSI] scsi_pm: resume device if suspend failed
  * [SCSI] scsi_pm: set device runtime state before parent suspended
  * [SCSI] scsi_transport_fc: Clear Devloss Callback Done flag in
    fc_remote_port_rolechg
  * [SCSI] scsi_transport_spi: fix for unbalanced reference counting
  * [SCSI] sd: Add runtime pm in the sd_check_events()
  * [SCSI] sd: Allow protection_type to be overridden
  * [SCSI] sd: Avoid remapping bad reference tags
  * [SCSI] sd: Ensure we correctly disable devices with unknown
    protection type
  * [SCSI] sd: Make sure provisioning mode is reported correctly
  * [SCSI] sd: Use sd_printk() instead of printk()
  * [SCSI] sd: check runtime PM status in sd_shutdown
  * [SCSI] sd: limit the scope of the async probe domain
  * [SCSI] sd: make comment and printk string match code
  * sd: remove arbitrary SD_MAX_DISKS namespace limit
  * sections: fix section conflicts in drivers/scsi
  * [SCSI] set to WCE if usb cache quirk is present
  * [SCSI] sg: completely protect sfds
  * [SCSI] sg: constify sg_proc_leaf_arr
  * [SCSI] sg: convert to kstrtoul_from_user()
  * [SCSI] sg: prevent unwoken sleep
  * [SCSI] sg: protect sdp->exclude
  * [SCSI] sg: remove closed flag
  * [SCSI] sg: remove unnecessary indentation
  * [SCSI] sg: remove while (1) non-loop
  * [SCSI] sg: use wait_event_interruptible()
  * [SCSI] st: fix memory leak with >1MB tape I/O
  * [SCSI] st: implement PM
  * SCSI & usb-storage: add flags for VPD pages and REPORT LUNS
- Refresh patches:
  * patches.drivers/0014-iscsi-class-add-bsg-support-to-iscsi-class.patch.
  * patches.fixes/block-add-blk_queue_dead.patch.
- commit 94ab25a
* Tue Nov 27 2012 oneukum@suse.de
- patches.drivers/0001-USB-OHCI-workaround-for-hardware-bug-retired-TDs-not.patch:
  USB: OHCI: workaround for hardware bug: retired TDs not added
  to the Done Queue (bnc#762158).
- commit c7e9a28
* Tue Nov 27 2012 jlee@suse.com
- patches.drivers/0001-watchdog-iTCO_wdt-clean-up-PCI-device-ID-s.patch:
  watchdog: iTCO_wdt: clean-up PCI device ID's (fate#313409,
  bnc#760833).
- patches.drivers/0002-watchdog-iTCO_wdt-add-Intel-Lynx-Point-DeviceIDs.patch:
  watchdog: iTCO_wdt: add Intel Lynx Point DeviceIDs (fate#313409,
  bnc#760833).
- patches.drivers/0003-ahci-AHCI-mode-SATA-patch-for-Intel-Lynx-Point-Devi.patch:
  ahci: AHCI-mode SATA patch for Intel Lynx Point DeviceIDs
  (fate#313409, bnc#760833).
- patches.drivers/0004-ata_piix-IDE-mode-SATA-patch-for-Intel-Lynx-Point-D.patch:
  ata_piix: IDE-mode SATA patch for Intel Lynx Point DeviceIDs
  (fate#313409, bnc#760833).
- patches.drivers/0005-i2c-i801-Add-device-IDs-for-Intel-Lynx-Point.patch:
  i2c-i801: Add device IDs for Intel Lynx Point (fate#313409,
  bnc#760833).
- commit 203ee6e
* Mon Nov 26 2012 jslaby@suse.cz
- Linux 3.0.52 (bnc#739728 bnc#780008).
- patches.kabi/kabi-protect-sound-structs.patch: kABI: protect
  sound structures.
- patches.drivers/drm-i915-hdmi-HDMI-source-product-description-infofr:
  Refresh.
- patches.fixes/ipv6-dont-use-inetpeer-to-store-metrics-for-routes.patch:
  Refresh.
- patches.fixes/ipv6-unshare-inetpeers.patch: Refresh.
- patches.kabi/revert-net-fix-NULL-dereferences-in-check_peer_redir.patch:
  Refresh.
- patches.drivers/DRM-Radeon-Fix-Load-Detection-on-legacy-primary-DAC.patch:
  Delete.
- patches.fixes/nfs-fix-oopses-in-nfs_lookup_revalidate-and-nfs_open_revalidate.patch:
  Delete.
- commit 37138f9
* Mon Nov 26 2012 jeffm@suse.com
- patches.fixes/reiserfs-fix-double-lock-while-chowning-setuid-file-w-xattrs:
  reiserfs: fix double-lock while chowning setuid file w/ xattrs
  (bnc#790920).
- commit 5504164
* Mon Nov 26 2012 jeffm@suse.com
- patches.suse/readahead-request-tunables.patch: Fix typo.
  Shipped releases are unaffected.
- commit 096329c
* Mon Nov 26 2012 duwe@suse.de
- powerpc/perf: Sample only if SIAR-Valid bit is set in P7+
  (fate#314047,bnc#788293).
- commit 0f10eed
* Mon Nov 26 2012 jack@suse.cz
- patches.fixes/jbd-Fix-lock-ordering-bug-in-journal_unmap_buffer.patch:
  jbd: Fix lock ordering bug in journal_unmap_buffer()
  (bnc#790935).
- commit a975ef4
* Mon Nov 26 2012 mgorman@suse.de
- Fix incorrect NR_FREE_PAGES accounting (appears like memory leak).
- commit 690fc4c
* Mon Nov 26 2012 neilb@suse.de
- Remove protective tags from multiple patches to enable
  various md/raid10 and DASD enhancements.
  These make is possible for RAID10 to cope with DASD devices
  being slow for various reasons - the affected device will be
  temporarily removed from the array.
  Also support reshaping of RAID10 arrays.
  (FATE#311379)
- commit bb5734b
* Mon Nov 26 2012 neilb@suse.de
- Fix some issues with the raid10-enhancements code
  1/ Fix some compile errors on 32-bit
  2/ add a couple of minor bugfixes
  3/ Correct the tag on one patch which was causing it not to apply.
  Refresh subsequent patches to match.
- commit 0968e24
* Fri Nov 23 2012 oneukum@suse.de
- patches.drivers/0001-usb-host-xhci-Fix-Compliance-Mode-on-SN65LVPE502CP-H.patch:
  usb: host: xhci: Fix Compliance Mode on SN65LVPE502CP Hardware
  (bnc#788277).
- patches.drivers/0002-usb-host-xhci-Fix-Null-pointer-dereferencing-with-71.patch:
  usb: host: xhci: Fix Null pointer dereferencing with 71c731a
  for non-x86 systems (bnc#788277).
- commit eed81a4
* Fri Nov 23 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not remove fillup from the buildsystem
  (bnc#781327)
- commit 122b5c9
* Thu Nov 22 2012 duwe@suse.de
- powerpc: Define Power7+ PV constant PV_POWER7p
  (bnc#788293,fate#314047).
- powerpc/oprofile: Fix marked events support on Power7+ not set
  (bnc#788294,fate#314052).
- powerpc/pseries: Add PFO support to the VIO bus
  (bnc#789779,fate#314587).
- powerpc/pseries: Enable the PFO-based RNG accelerator
  (bnc#789779,fate#314587).
- powerpc/pseries/hwrng: PFO-based hwrng driver
  (bnc#789779,fate#314587).
- powerpc/vio: Remove dma not supported warnings
  (bnc#789779,fate#314587).
- Update config files.
- commit 072bbcf
* Thu Nov 22 2012 dsterba@suse.cz
- patches.suse/btrfs-8163-fix-full-backref-problem-when-inserting-shared.patch:
  Refresh.
- commit 8c0cbb2
* Wed Nov 21 2012 dsterba@suse.cz
- patches.suse/btrfs-8189-use-common-work-instead-of-delayed-work.patch:
  Btrfs: use common work instead of delayed work
- patches.suse/btrfs-8190-limit-fallocate-extent-reservation-to-256MB.patch:
  btrfs: limit fallocate extent reservation to 256MB
- commit 7e3700e
* Wed Nov 21 2012 jlee@suse.com
- [libata] export ata_dev_set_feature() (fate#313946, bnc#783331).
- ahci: implement aggressive SATA device sleep support
  (fate#313946, bnc#783331).
- ata: define enum constants for IDENTIFY DEVICE (fate#313946,
  bnc#783331).
- libata: detect Device Attention support (fate#313946,
  bnc#783331).
- commit b0accf8
* Tue Nov 20 2012 jkosina@suse.cz
- Update config files. Disable module signigng for Alpha1, it causes
  build failures in buildservice (bnc#790477)
- commit ef92197
* Tue Nov 20 2012 tiwai@suse.de
- Update patch-mainline tag
- commit 0beedf4
* Tue Nov 20 2012 tiwai@suse.de
- Update patch-mainline tag
- commit 284c708
* Tue Nov 20 2012 tiwai@suse.de
- ALSA: hda - Limit runtime PM support only to known Intel chips
  (FATE#313754).
- ALSA: hda - Fix recursive suspend/resume call (FATE#313754).
- ALSA: hda - Add new codec ALC668 and ALC900 (default name
  ALC1150) (FATE#313695).
- ALSA: hda - Improve HP depop when system enter to S3
  (FATE#313695).
- ALSA: hda - Fix invalid connections in VT1802 codec
  (FATE#314310).
- ALSA: hda - Fix empty DAC filling in patch_via.c (FATE#314310).
- ALSA: hda - Keep power link on for PantherPoint HDMI
  (FATE#313695).
- commit 529b436
* Tue Nov 20 2012 oneukum@suse.de
- usb: host: xhci: Fix Null pointer dereferencing with 71c731a
  for non-x86 systems (bnc#785562).
- commit 1de70af
* Tue Nov 20 2012 jbeulich@suse.com
- Update series.conf (missed in previous commit).
- commit 4100af1
* Tue Nov 20 2012 jbeulich@suse.com
- Update Xen patches to 3.0.51.
- commit 94fa6a9
* Tue Nov 20 2012 neilb@suse.de
- Refresh
  patches.suse/0001-md-failfast-add-failfast-flag-for-md-to-be-used-by-s.patch.
- Refresh
  patches.suse/0002-md-raid1-add-failfast-handling-for-reads.patch.
- Refresh
  patches.suse/0003-md-raid1-add-failfast-handling-for-writes.patch.
- Refresh
  patches.suse/0004-md-raid10-add-failfast-handling-for-reads.patch.
- Refresh patches.suse/md-allow-force-fail.
- Refresh patches.suse/md-allow-restarting-interrupted-recovery.
- Refresh patches.suse/md-bitmap-discard-chunk_block_shift.
- Refresh patches.suse/md-bitmap-revert-dm-log.
- Refresh
  patches.suse/md-bm-01-bitmap-disentangle-two-different-pending-flags.patch.
- Refresh
  patches.suse/md-bm-02-bitmap-add-new-space-attribute-for-bitmaps.patch.
- Refresh
  patches.suse/md-bm-03-bitmap-allow-a-bitmap-with-no-backing-storage.patch.
- Refresh
  patches.suse/md-bm-04-bitmap-centralise-allocation-of-bitmap-file-pages.patch.
- Refresh
  patches.suse/md-bm-05-bitmap-change-_page_attr-to-take-a-page-number-no.patch.
- Refresh
  patches.suse/md-bm-06-bitmap-move-some-fields-of-struct-bitmap-into-a-s.patch.
- Refresh
  patches.suse/md-bm-07-bitmap-store-bytes-in-file-rather-than-just-in-la.patch.
- Refresh
  patches.suse/md-bm-08-bitmap-separate-bitmap-file-allocation-to-its-own.patch.
- Refresh
  patches.suse/md-bm-09-bitmap-move-storage-allocation-from-bitmap_load-t.patch.
- Refresh
  patches.suse/md-bm-10-bitmap-remove-bitmap_mask_state.patch.
- Refresh
  patches.suse/md-bm-11-bitmap-remove-single-bit-manipulation-on-sb-state.patch.
- Refresh
  patches.suse/md-bm-12-bitmap-use-set_bit-test_bit-etc-for-operation-on-.patch.
- Refresh
  patches.suse/md-bm-13-bitmap-convert-some-spin_lock_irqsave-to-spin_loc.patch.
- Refresh
  patches.suse/md-bm-14-bitmap-remove-async-freeing-of-bitmap-file.patch.
- md/bitmap: merge bitmap_file_unmap and bitmap_file_put
  (fate#311379).
- Refresh
  patches.suse/md-bm-16-bitmap-make-_page_attr-bitops-atomic.patch.
- Refresh
  patches.suse/md-bm-17-bitmap-make-bitmap-bitops-atomic.patch.
- Refresh
  patches.suse/md-bm-18-bitmap-create-a-struct-bitmap_counts-substructure.patch.
- Refresh
  patches.suse/md-bm-19-bitmap-use-DIV_ROUND_UP-instead-of-open-code.patch.
- Refresh
  patches.suse/md-bm-20-bitmap-add-bitmap_resize-function-to-allow-bitmap.patch.
- Refresh
  patches.suse/md-bm-21-bitmap-make-sure-reshape-request-are-reflected-in.patch.
- Refresh
  patches.suse/md-bm-23-raid10-resize-bitmap-when-required-during-reshape.patch.
- Refresh patches.suse/md-bm-24-record-space.
- Refresh patches.suse/md-plugging-refine.
- Refresh patches.suse/md-r10-fix-on-stack-allocation.
- Refresh
  patches.suse/md-raid10-handle-merge_bvec_fn-in-member-devices.patch.
- Refresh patches.suse/md-raid10-merge_bvec_fn.fix.
- Refresh patches.suse/md-raid10-set_dev_sectors.
- Refresh patches.suse/md-raid10-shrink-remove.
- Refresh
  patches.suse/md-raid10-support-resizing-some-RAID10-arrays.patch.
- Refresh patches.suse/md-re-add-to-failed.
- Refresh
  patches.suse/r10-reshape-1-md-allow-a-reshape-operation-to-be-reversed.patch.
- Refresh
  patches.suse/r10-reshape-2-md-add-possibility-to-change-data-offset-for-devices.patch.
- Refresh
  patches.suse/r10-reshape-3-md-raid10-collect-some-geometry-fields-into-a-dedica.patch.
- Refresh
  patches.suse/r10-reshape-4-md-teach-sync_page_io-about-new_data_offset.patch.
- Refresh
  patches.suse/r10-reshape-5-md-use-resync_max_sectors-for-reshape-as-well-as-res.patch.
- Refresh
  patches.suse/r10-reshape-6-md-raid10-Introduce-prev-geometry-to-support-reshape.patch.
- Refresh
  patches.suse/r10-reshape-7-md-raid10-share-pages-between-read-and-write-bio-s-d.patch.
- Refresh
  patches.suse/r10-reshape-7-md-raid10-split-out-interpretation-of-layout-to-sepa.patch.
- Refresh
  patches.suse/r10-reshape-8-md-raid10-add-reshape-support.patch.
  Add 'Git-commit' tags to lots of md patches, and fix one buglet found
  when comparing our patches to mainline:  Reshaping an array with a bitmap
  could sometimes result in the new bitmap being very small.
- commit 4bbeb3e
* Mon Nov 19 2012 hare@suse.de
- Update qla2xxx driver (FATE#313901)
- Update LIO kernel modules (FATE#313550)
- [SCSI] qla2xxx: Remove qla2x00_wait_for_loop_ready function
  (FATE#313901).
- [SCSI] qla2xxx: Check for SCSI status on underruns
  (FATE#313901).
- [SCSI] qla2xxx: Don't call alloc_fw_dump for ISP82XX
  (FATE#313901).
- [SCSI] qla2xxx: Revert back the request queue mapping to
  request queue 0 (FATE#313901).
- [SCSI] qla2xxx: Stop unconditional completion of mailbox
  commands issued in interrupt mode during firmware hang
  (FATE#313901).
- [SCSI] qla2xxx: Enable Minidump by default with default capture
  mask 0x1f (FATE#313901).
- [SCSI] qla2xxx: Return the correct value for a mailbox command
  if 82xx is in reset recovery (FATE#313901).
- [SCSI] qla2xxx: Display IPE error message for ISP82xx
  (FATE#313901).
- [SCSI] qla2xxx: Encapsulate prematurely completing mailbox
  commands during ISP82xx firmware hang (FATE#313901).
- [SCSI] qla2xxx: Clear mailbox busy flag during premature
  mailbox completion for ISP82xx (FATE#313901).
- [SCSI] qla2xxx: Disable generating pause frames when firmware
  hang detected for ISP82xx (FATE#313901).
- [SCSI] qla2xxx: Correct fc_host port_state display
  (FATE#313901).
- [SCSI] qla2xxx: Submit all chained IOCBs for passthrough
  commands on request queue 0 (FATE#313901).
- [SCSI] qla2xxx: Update version number to 8.03.07.12-k
  (FATE#313901).
- [SCSI] qla2xxx: Use less stack to emit logging messages
  (FATE#313901).
- [SCSI] qla2xxx: Make the logging functions verify their
  arguments and fixed the current broken uses as appropriate
  (FATE#313901).
- [SCSI] qla2xxx: Update to dynamic logging (FATE#313901).
- [SCSI] qla2xxx: Proper cleanup of pass through commands when
  firmware returns error (FATE#313901).
- [SCSI] qla2xxx: Only read requested mailbox registers
  (FATE#313901).
- [SCSI] qla2xxx: Limit excessive DPC cycles (FATE#313901).
- [SCSI] qla2xxx: Fix to include FCE data as part of dump
  (FATE#313901).
- [SCSI] qla2xxx: Correct report-id acquisition check
  (FATE#313901).
- [SCSI] qla2xxx: Corrections to returned sysfs error codes
  (FATE#313901).
- [SCSI] qla2xxx: Corrected the default setting of the help text
  of Minidump capture mask (FATE#313901).
- [SCSI] qla2xxx: Corrected the display of firmware dump
  availability for ISP82xx (FATE#313901).
- [SCSI] qla2xxx: Added a new entry to ISP specific function
  pointers structure (FATE#313901).
- [SCSI] qla2xxx: Process marker IOCB request on request queue 0
  (FATE#313901).
- [SCSI] qla2xxx: Consolidated IOCB processing routines
  (FATE#313901).
- [SCSI] qla2xxx: Implement FCP priority tagging for 82xx adapters
  (FATE#313901).
- [SCSI] qla2xxx: Ensure there's enough request-queue space for
  passthru IOCBs (FATE#313901).
- [SCSI] qla2xxx: Move initialization of some variables before
  iospace_config (FATE#313901).
- [SCSI] qla2xxx: Do not check for minidump when device state
  is QLA82XX_DEV_READY (FATE#313901).
- [SCSI] qla2xxx: remove redundant semicolon (FATE#313901).
- qla2xxx: fix printk typo in qla_bsg.c (FATE#313901).
- [SCSI] qla2xxx: Propagate up abort failures (FATE#313901).
- [SCSI] qla2xxx: Add check for null fcport references in
  qla2xxx_queuecommand (FATE#313901).
- [SCSI] qla2xxx: Add an "is reset active" helper (FATE#313901).
- [SCSI] qla2xxx: Clear options-flags while issuing stop-firmware
  mbx command (FATE#313901).
- [SCSI] qla2xxx: Remove errant clearing of MBX_INTERRUPT flag
  during CT-IOCB processing (FATE#313901).
- [SCSI] qla2xxx: Correct out of bounds read of ISP2200 mailbox
  registers (FATE#313901).
- [SCSI] qla2xxx: Remove check for null fcport from host reset
  handler (FATE#313901).
- [SCSI] qla2xxx: Complete mailbox command timedout to avoid
  initialization failures during next reset cycle (FATE#313901).
- [SCSI] qla2xxx: Remove resetting memory during device
  initialization for ISP82xx (FATE#313901).
- [SCSI] qla2xxx: Proper detection of firmware abort error code
  for ISP82xx (FATE#313901).
- [SCSI] qla2xxx: Update version number to 8.03.07.13-k
  (FATE#313901).
- [SCSI] qla2xxx: Enhanced the dump routines to capture multiple
  request and response queues (FATE#313901).
- [SCSI] qla2xxx: Enhancements to support ISP83xx (FATE#313901).
- [SCSI] qla2xxx: Use a valid enode-mac if none defined
  (FATE#313901).
- [SCSI] qla2xxx: Consolidation of SRB processing (FATE#313901).
- [SCSI] qla2xxx: Use consistent DL mask for ELS/CT passthru
  requests (FATE#313901).
- [SCSI] qla2xxx: Correct print format for edc ql_log() calls
  (FATE#313901).
- [SCSI] qla2xxx: Handle change notifications based on switch
  scan results (FATE#313901).
- [SCSI] qla2xxx: Return blank sysfs string on initial get
  thermal failure (FATE#313901).
- [SCSI] qla2xxx: Increase speed of flash access in ISP82xx
  adapters to improve firmware load speed (FATE#313901).
- [SCSI] qla2xxx: Handle failure cases during fabric_login
  (FATE#313901).
- [SCSI] qla2xxx: Perform implicit logout during rport tear-down
  (FATE#313901).
- [SCSI] qla2xxx: Prep zero-length BSG data-transfer requests
  (FATE#313901).
- [SCSI] qla2xxx: Reduce mbx-command timeout for Login/Logout
  requests (FATE#313901).
- [SCSI] qla2xxx: Print mailbox command opcode and return code
  when a command times out (FATE#313901).
- [SCSI] qla2xxx: Convert remaining printk's to ql_log format
  (FATE#313901).
- [SCSI] qla2xxx: Use ql_log* #define's in ql_log() and
  ql_log_pci() (FATE#313901).
- [SCSI] qla2xxx: Fix ql_dbg arguments (FATE#313901).
- [SCSI] qla2xxx: Add new message when a new loopid is assigned
  (FATE#313901).
- [SCSI] qla2xxx: Log messages to use correct vha (FATE#313901).
- [SCSI] qla2xxx: Change the log message when previous dump is
  available to retrieve for ISP82xx (FATE#313901).
- [SCSI] qla2xxx: Perform firmware dump procedure on mailbox
  command timeout (FATE#313901).
- [SCSI] qla2xxx: Remove EDC sysfs interface (FATE#313901).
- [SCSI] qla2xxx: Cache swl during fabric discovery (FATE#313901).
- [SCSI] qla2xxx: Add ha->max_fibre_devices to keep track of
  the maximum number of targets (FATE#313901).
- [SCSI] qla2xxx: Handle device mapping changes due to device
  logout (FATE#313901).
- [SCSI] qla2xxx: Fix incorrect register access in
  qla2x00_start_iocbs() (FATE#313901).
- [SCSI] qla2xxx: Stop iteration after first failure in *_id
  functions (FATE#313901).
- [SCSI] qla2xxx: Avoid invalid request queue dereference for
  bad response packets (FATE#313901).
- [SCSI] qla2xxx: handle default case in
  qla2x00_request_firmware() (FATE#313901).
- qla2xxx: Remove redundant NULL check before release_firmware()
  call (FATE#313901).
- [SCSI] qla2xxx: Fix reset time out as qla2xxx not ack to reset
  request (FATE#313901).
- [SCSI] qla2xxx: Block flash access from application when device
  is initialized for ISP82xx (FATE#313901).
- [SCSI] qla2xxx: Proper completion to scsi-ml for scsi status
  task_set_full and busy (FATE#313901).
- [SCSI] qla2xxx: Properly check for current state after the
  fabric-login request (FATE#313901).
- [SCSI] qla2xxx: Update version number to 8.04.00.03-k
  (FATE#313901).
- [SCSI] qla2xxx: Fix typo in qla_init.c (FATE#313901).
- [SCSI] qla2xxx: Micro optimization in queuecommand handler
  (FATE#313901).
- [SCSI] qla2xxx: Fix typo in qla_mbx.c (FATE#313901).
- [SCSI] qla2xxx: Remove unneeded DPC wakeups from
  qla82xx_watchdog (FATE#313901).
- [SCSI] qla2xxx: Detect PEG errors (FATE#313901).
- [SCSI] qla2xxx: Change "Done" to "Entering" in the debug print
  statement in qla2x00_port_logout (FATE#313901).
- [SCSI] qla2xxx: Handle interrupt registration failures more
  gracefully (FATE#313901).
- [SCSI] qla2xxx: Add ql_dbg_verbose logging level (FATE#313901).
- [SCSI] qla2xxx: Stats should be different from physical and
  virtual ports (FATE#313901).
- [SCSI] qla2xxx: Fix typo in bus-reset handler (FATE#313901).
- [SCSI] qla2xxx: Display proper supported speeds for 16G FC
  adapters (FATE#313901).
- [SCSI] qla2xxx: Fixups for ISP83xx (FATE#313901).
- [SCSI] qla2xxx: Remove mirrored field vp_idx from struct fc_port
  (FATE#313901).
- [SCSI] qla2xxx: Optimize existing port name server query
  matching (FATE#313901).
- [SCSI] qla2xxx: Corrections to log messages (FATE#313901).
- [SCSI] qla2xxx: Log link up and link down messages to track
  link flops (FATE#313901).
- [SCSI] qla2xxx: Avoid losing any fc ports when loop id's are
  exhausted (FATE#313901).
- [SCSI] qla2xxx: Don't capture minidump for ISP82xx on flash
  update from application (FATE#313901).
- [SCSI] qla2xxx: Display proper firmware version when new
  minidump template is gathered for ISP82xx (FATE#313901).
- [SCSI] Revert "qla2xxx: During loopdown perform Diagnostic
  loopback." (FATE#313901).
- [SCSI] qla2xxx: Add LLD target-mode infrastructure for >=
  24xx series (FATE#313901).
- [SCSI] tcm_qla2xxx: Add >= 24xx series fabric module for
  target-core (FATE#313901).
- [SCSI] qla2xxx: don't free pool that wasn't allocated
  (FATE#313901).
- tcm_qla2xxx: Convert to TFO->put_session() usage (FATE#313901).
- tcm_qla2xxx: Clear session s_id + loop_id earlier during
  shutdown (FATE#313901).
- tcm_qla2xxx: Don't insert nacls without sessions into the btree
  (FATE#313901).
- qla2xxx: Don't crash if we can't find cmd for failed CTIO
  (FATE#313901).
- qla2xxx: Don't leak commands we give up on in qlt_do_work()
  (FATE#313901).
- tcm_qla2xxx: tcm_qla2xxx_handle_tmr() can be static
  (FATE#313901).
- tcm_qla2xxx: Handle malformed wwn strings properly
  (FATE#313901).
- qla2xxx: Remove version.h header file inclusion (FATE#313901).
- qla2xxx: print the right array elements in qlt_async_event
  (FATE#313901).
- tcm_qla2xxx: Remove duplicate header file inclusion
  (FATE#313901).
- tcm_qla2xxx: Offload WRITE I/O backend submission to tcm_qla2xxx
  wq (FATE#313901).
- qla2xxx: Get rid of redundant qla_tgt_sess.tearing_down
  (FATE#313901).
- qla2xxx: Remove racy, now-redundant check of sess_tearing_down
  (FATE#313901).
- [SCSI] qla2xxx: remove unnecessary reads of PCI_CAP_ID_EXP
  (FATE#313901).
- [SCSI] qla2xxx: Bind to ISP8031 devices (FATE#313901).
- [SCSI] qla2xxx: Add I2C BSG interface (FATE#313901).
- [SCSI] qla2xxx: Add check in qla82xx_watchdog for failed
  hardware state (FATE#313901).
- [SCSI] qla2xxx: Fix typo in qla2xxx files (FATE#313901).
- [SCSI] qla2xxx: Display mailbox failure by default
  (FATE#313901).
- qla2xxx: Fix endianness of task management response code
  (FATE#313901).
- [SCSI] qla2xxx: Use bitmap to store loop_id's for fcports
  (FATE#313901).
- [SCSI] qla2xxx: Implementation of bidirectional (FATE#313901).
- [SCSI] qla2xxx: Add FW DUMP SIZE sysfs attribute (FATE#313901).
- [SCSI] qla2xxx: IDC implementation for ISP83xx (FATE#313901).
- [SCSI] qla2xxx: Implemetation of mctp (FATE#313901).
- [SCSI] qla2xxx: Add bit to identify adapters for thermal temp
  (FATE#313901).
- [SCSI] qla2xxx: Changes for ISP83xx loopback support
  (FATE#313901).
- [SCSI] qla2xxx: Don't register to legacy interrupt for ISP82xx
  (FATE#313901).
- [SCSI] qla2xxx: Update the driver copyright (FATE#313901).
- [SCSI] qla2xxx: Only enable link up on the correct interrupt
  event (FATE#313901).
- [SCSI] qla2xxx: Fix for continuous rescan attempts in arbitrated
  loop topology (FATE#313901).
- [SCSI] qla2xxx: Implement beacon support for ISP83xx
  (FATE#313901).
- [SCSI] qla2xxx: Perform ROM mbx cmd access only after ISP
  soft-reset during f/w recovery (FATE#313901).
- [SCSI] qla2xxx: Wrong PCIe(2.5Gb/s x8) speed in the kerenel
  message for ISP82xx (FATE#313901).
- [SCSI] qla2xxx: Dont call nic restart firmware if it is already
  active and running (FATE#313901).
- [SCSI] qla2xxx: Use #defines instead of hardcoded values for
  intr status (FATE#313901).
- [SCSI] qla2xxx: Remove setting Scsi_host->this_id during
  adapter probe (FATE#313901).
- [SCSI] qla2xxx: Ensure PLOGI is sent to Fabric Management-Server
  upon request (FATE#313901).
- [SCSI] qla2xxx: Fail initialization if unable to load RISC code
  (FATE#313901).
- [SCSI] qla2xxx: Do PCI fundamental reset for ISP83xx
  (FATE#313901).
- [SCSI] qla2xxx: Do not restrict the number of NPIV ports for
  ISP83xx (FATE#313901).
- [SCSI] qla2xxx: set idc version if function is first one to come
  (FATE#313901).
- [SCSI] qla2xxx: Fix description of qla2xmaxqdepth parameter
  (FATE#313901).
- [SCSI] qla2xxx: Fix for handling some error conditions in
  loopback (FATE#313901).
- [SCSI] qla2xxx: Enclose adapter related calls in adapter check
  in failed state handler (FATE#313901).
- [SCSI] qla2xxx: Set Maximum Read Request Size to 4K
  (FATE#313901).
- [SCSI] qla2xxx: Get fcal position map should not be called
  for p2p topology (FATE#313901).
- [SCSI] qla2xxx: Enable fw attributes for ISP24xx and above
  (FATE#313901).
- [SCSI] qla2xxx: Restrict nic core reset to one function for mctp
  (FATE#313901).
- [SCSI] qla2xxx: Fix for legacy interrupts for ISP83xx
  (FATE#313901).
- [SCSI] qla2xxx: T10 DIF - ISP83xx changes (FATE#313901).
- [SCSI] qla2xxx: Fix incorrect status reporting on DIF errors
  (FATE#313901).
- [SCSI] qla2xxx: Don't toggle RISC interrupt bits after IRQ
  lines are attached (FATE#313901).
- [SCSI] qla2xxx: Allow MSI interrupt registration for ISP82xx
  (FATE#313901).
- [SCSI] qla2xxx: Use the right field for container_of
  (FATE#313901).
- [SCSI] qla2xxx: Update version number to 8.04.00.07-k
  (FATE#313901).
- [SCSI] qla2xxx: fix potential deadlock on ha->hardware_lock
  (FATE#313901).
- target: Prevent cmd->se_queue_node double add (FATE#313550).
- target: Re-org of core_tmr_lun_reset (FATE#313550).
- target: Prevent TRANSPORT_FREE_CMD_INTR processing in
  core_tmr_drain_cmd_list (FATE#313550).
- target: Fix transport_cmd_finish_abort queue removal bug
  (FATE#313550).
- target: Prevent transport_send_task_abort when CHECK_CONDITION
  status (FATE#313550).
- tfm_fc: use transport_handle_cdb_direct (FATE#313550).
- iscsi-target: always call transport_handle_cdb_direct
  (FATE#313550).
- target: remove transport_generic_handle_cdb (FATE#313550).
- target: don't opencode transport_release_cmd in
  transport_release_fe_cmd (FATE#313550).
- target: remove transport_free_se_cmd (FATE#313550).
- target: simplify transport_generic_remove (FATE#313550).
- target: simplify transport_put_cmd (FATE#313550).
- target: remove transport_generic_remove (FATE#313550).
- target: push session reinstatement out of
  transport_generic_free_cmd (FATE#313550).
- target: Remove session_reinstatement parameter from
  - >transport_wait_for_tasks (FATE#313550).
- target: simplify target_parse_naa_6h_vendor_specific()
  (FATE#313550).
- target: cleanup iblock bio submission (FATE#313550).
- target: cleanup pscsi request submission (FATE#313550).
- target: remove unused se_subsystem_api methods (FATE#313550).
- iscsi-target: use native hex2bin for chap_string_to_hex
  (FATE#313550).
- tcm_fc: remove custom hex_to_bin in ft_parse_wwn (FATE#313550).
- target: Make pscsi_create_virtdevice use ERR_CAST (FATE#313550).
- target: Have core_tmr_alloc_req() take an explicit GFP_xxx flag
  (FATE#313550).
- target: Convert ->transport_wait_for_tasks usage to
  transport_generic_free_cmd (FATE#313550).
- iscsi-target: Remove SCF_SE_LUN_CMD flag abuses (FATE#313550).
- target: Merge transport_cmd_finish_abort_tmr into
  transport_cmd_finish_abort (FATE#313550).
- target: Remove legacy + unused device active I/O shutdown code
  (FATE#313550).
- loopback: Prevent uninitialized use of tl_tpg in
  tcm_loop_queuecommand (FATE#313550).
- target: Cleanup unused target_core_base.h bits (FATE#313550).
- target: Cleanup unused se_task bits (FATE#313550).
- target: make more use of the task_flags field in se_task
  (FATE#313550).
- target: Remove unnecessary se_task members (FATE#313550).
- target: pack struct se_task more tightly (FATE#313550).
- target: make the ->get_cdb method optional (FATE#313550).
- target: replace ->get_cdb with a target_get_task_cdb helper
  (FATE#313550).
- target: remove the ->transport_split_cdb callback in se_cmd
  (FATE#313550).
- target: make iblock_emulate_sync_cache asynchronous
  (FATE#313550).
- target: clean up the backend interface to caching parameters
  (FATE#313550).
- target: remove the transport_qf_callback se_cmd callback
  (FATE#313550).
- target: remove SCF_EMULATE_QUEUE_FULL (FATE#313550).
- target: do not pass the queue object to
  transport_remove_cmd_from_queue (FATE#313550).
- target: use transport_cmd_check_stop_to_fabric consistently
  (FATE#313550).
- target: fix list walking in transport_free_dev_tasks
  (FATE#313550).
- target: factor some duplicate code for stopping a task
  (FATE#313550).
- target: remove TF_TIMER_STOP (FATE#313550).
- target: stop task timers earlier (FATE#313550).
- target: move depth_left manipulation out of
  transport_generic_request_failure (FATE#313550).
- target: remove the TRANSPORT_REMOVE state (FATE#313550).
- target: remove TRANSPORT_DEFERRED_CMD state (FATE#313550).
- target: remove unused TRANSPORT_ states (FATE#313550).
- target: use a workqueue for I/O completions (FATE#313550).
- target: transport_subsystem_check_init cleanups (FATE#313550).
- target: remove the task_sg_bidi field se_task and pSCSI BIDI
  support (FATE#313550).
- target: merge transport_new_cmd_obj into
  transport_generic_new_cmd (FATE#313550).
- target: remove transport_allocate_tasks (FATE#313550).
- target: Fix BIDI t_task_cdb handling in
  transport_generic_new_cmd (FATE#313550).
- target: re-use the command S/G list for single-task commands
  (FATE#313550).
- target: Fix incorrect transport_sent usage (FATE#313550).
- target: Remove legacy se_task->task_timer and associated logic
  (FATE#313550).
- target: Fix compile warning w/ missing module.h include
  (FATE#313550).
- tcm_loop: Add explict read buffer memset for
  SCF_SCSI_CONTROL_SG_IO_CDB (FATE#313550).
- target: Check -ENOMEM to signal QUEUE_FULL from fabric callbacks
  (FATE#313550).
- target: Fix incorrect se_cmd assignment in
  core_tmr_drain_tmr_list (FATE#313550).
- target: Fix wrong se_tmr being added to drain_tmr_list
  (FATE#313550).
- target: Minor cleanups to core_tmr_drain_tmr_list (FATE#313550).
- drivers/target: Add module.h to drivers/target files as required
  (FATE#313550).
- target: Avoid double list_del for aborted se_tmr_req
  (FATE#313550).
- iscsi-target: Add missing CMDSN_LOWER_THAN_EXP check in
  iscsit_handle_scsi_cmd (FATE#313550).
- iscsi-target: Fix non-immediate TMR handling (FATE#313550).
- target: Make TFO->check_stop_free return free status
  (FATE#313550).
- target: Remove core TRANSPORT_FREE_CMD_INTR usage (FATE#313550).
- target/pscsi: blk_make_request() returns an ERR_PTR()
  (FATE#313550).
- target: add back error handling in transport_complete_task
  (FATE#313550).
- target: Add generic active I/O shutdown logic (FATE#313550).
- target: split core_scsi2_emulate_crh (FATE#313550).
- target: split core_scsi3_emulate_pr (FATE#313550).
- target: pass the se_task to the CDB emulation callback
  (FATE#313550).
- target: refactor transport_emulate_control_cdb (FATE#313550).
- target: remove SCF_EMULATE_CDB_ASYNC (FATE#313550).
- target: use ->exectute_task for all CDB emulation (FATE#313550).
- target: Address legacy PYX_TRANSPORT_* return code breakage
  (FATE#313550).
- iscsi-target: Fix sess allocation leak in
  iscsi_login_zero_tsih_s1 (FATE#313550).
- target: Improve system responsivity during I/O (FATE#313550).
- target: Avoid compiler warnings about signed one-bit bitfields
  (FATE#313550).
- target: Get rid of unused se_cmd_cache (FATE#313550).
- target: Drop config_item_name usage in fabric TFO->free_wwn()
  (FATE#313550).
- target: remove the se_obj_ptr and se_orig_obj_ptr se_cmd fields
  (FATE#313550).
- target: remove the se_ordered_node se_cmd field (FATE#313550).
- target: remove the t_tasks_fua se_cmd field (FATE#313550).
- target: remove the t_tasks_bidi se_cmd field (FATE#313550).
- target: remove the unused t_task_pt_sgl and t_task_pt_sgl_num
  se_cmd fields (FATE#313550).
- target: Reject SCSI data overflow for fabrics using
  transport_generic_map_mem_to_cmd (FATE#313550).
- iscsi-target: Fix residual count hanlding + remove
  iscsi_cmd->residual_count (FATE#313550).
- iscsi-target: Add missing F_BIT for iscsi_tm_rsp (FATE#313550).
- iscsi-target: Use kmemdup rather than duplicating its
  implementation (FATE#313550).
- target: Don't return an error status for 0-length READ and WRITE
  (FATE#313550).
- target: Fix page length in emulated INQUIRY VPD page 86h
  (FATE#313550).
- target: remove unused struct fields (FATE#313550).
- target/file: walk properly over sg list (FATE#313550).
- target: remove the unused se_dev_list (FATE#313550).
- target/rd: simplify the page/offset computation (FATE#313550).
- target/rd: fix or rewrite the copy routine (FATE#313550).
- target: Don't return an error if disabling unsupported features
  (FATE#313550).
- target: reshuffle headers (FATE#313550).
- target: header reshuffle, part2 (FATE#313550).
- target: fold se_task.task_sense into task_flags (FATE#313550).
- target: remove the se_task task_error_status field
  (FATE#313550).
- target: make the se_task task_state_active a normal bool
  (FATE#313550).
- target: use \n as a separator for configuration (FATE#313550).
- target: Move core_scsi3_check_cdb_abort_and_preempt
  (FATE#313550).
- target: simplify target_check_cdb_and_preempt (FATE#313550).
- target: remove useless casts (FATE#313550).
- iscsi-target: fix chap identifier simple_strtoul usage
  (FATE#313550).
- target/configs: remove trailing newline from udev_path and alias
  (FATE#313550).
- tcm_loop: bump max_sectors (FATE#313550).
- target: remove overagressive ____cacheline_aligned annoations
  (FATE#313550).
- target: Make target_put_sess_cmd use target_release_cmd_kref
  (FATE#313550).
- target: Add target_submit_cmd() for process context fabric
  submission (FATE#313550).
- tcm_fc: Convert ft_send_work to use target_submit_cmd
  (FATE#313550).
- target: Remove TFO->check_release_cmd() fabric API caller
  (FATE#313550).
- target: Fix possible NULL pointer with __transport_execute_tasks
  (FATE#313550).
- target: Drop se_device TCQ queue_depth usage from I/O path
  (FATE#313550).
- target: Remove extra se_device->execute_task_lock access in
  fast path (FATE#313550).
- target: Remove __transport_execute_tasks() for each processing
  context (FATE#313550).
- target: Remove legacy device status check from
  transport_execute_tasks (FATE#313550).
- target: don't allocate bio headroom in iblock (FATE#313550).
- target: Don't zero pages used for data buffers (FATE#313550).
- target: Add workaround for zero-length control CDB handling
  (FATE#313550).
- target: avoid multiple outputs in scsi_dump_inquiry()
  (FATE#313550).
- target: use save/restore lock primitive in core_dec_lacl_count()
  (FATE#313550).
- target: fix return code of core_tpg_.*_lun (FATE#313550).
- iscsi-target: Fix reject release handling in iscsit_free_cmd()
  (FATE#313550).
- iscsi-target: Fix double list_add with iscsit_alloc_buffs reject
  (FATE#313550).
- iscsi-target: make one-bit bitfields unsigned (FATE#313550).
- iscsi-target: Fix up a few assignments (FATE#313550).
- target: Allow control CDBs with data > 1 page (FATE#313550).
- iscsi-target: Fix discovery with INADDR_ANY and IN6ADDR_ANY_INIT
  (FATE#313550).
- target: Return correct ASC for unimplemented VPD pages
  (FATE#313550).
- target: Fail INQUIRY commands with EVPD==0 but PAGE CODE!=0
  (FATE#313550).
- target: accept REQUEST_SENSE with 18bytes (FATE#313550).
- target: Change target_submit_cmd() to return void (FATE#313550).
- target: Fix target_submit_cmd() exception handling
  (FATE#313550).
- target: Fix iblock se_dev_attrib.unmap_granularity
  (FATE#313550).
- target: handle empty string writes in sysfs (FATE#313550).
- iblock: fix handling of large requests (FATE#313550).
- iscsi: use IP_FREEBIND socket option (FATE#313550).
- target: Fix unsupported WRITE_SAME sense payload (FATE#313550).
- tcm_fc: Convert call_rcu() to kfree_rcu(), drop
  ft_tport_rcu_free() (FATE#313550).
- target: replace various cmd flags with a transport state
  (FATE#313550).
- target: remove the transport_lun_active field in struct se_cmd
  (FATE#313550).
- target: remove the unused struct iblock_hba (FATE#313550).
- target: increase iblock task sizes (FATE#313550).
- target: Use LIST_HEAD()/DEFINE_MUTEX() for static objects
  (FATE#313550).
- target: Use #define for SYNCHRONIZE_CACHE_16 (FATE#313550).
- scsi: Use struct scsi_lun in fc/fcp.h (FATE#313550).
- target: fix comment typos (FATE#313550).
- target: Remove unused struct se_queue_req (FATE#313550).
- target/iscsi: Remove unneeded wrapper functions (FATE#313550).
- tcm_fc: Simplify ft_send_work for tmr path (FATE#313550).
- tcm_fc: Remove cmd->cdb data member (FATE#313550).
- target: Add SCF_SCSI_TMR_CDB usage and drop se_tmr_req_cache
  (FATE#313550).
- tcm_fc: Move core->fc code conversion earlier in ft_send_tm()
  (FATE#313550).
- tcm_fc: Call lookup_tmr_lun() for all TM types (FATE#313550).
- tcm_fc: Use transport_generic_free_cmd for ft_sess_put in
  ft_send_tm (FATE#313550).
- target: Add target_submit_tmr helper function (FATE#313550).
- tcm_fc: Convert ft_send_tm to use target_submit_tmr
  (FATE#313550).
- tcm_loop: kill tcm_loop_allocate_core_cmd (FATE#313550).
- tcm_loop: defer all command submissions to workqueue
  (FATE#313550).
- tcm_loop: switch to using transport_handle_cdb_direct
  (FATE#313550).
- target: Cleanup transport_kunmap_data_sg() (FATE#313550).
- target: Export transport_generic_request_failure symbol
  (FATE#313550).
- target: Add SCF_ACK_KREF flag for acknowledgement kref
  (FATE#313550).
- target: Make target_release_cmd_kref release on empty list
  (FATE#313550).
- target: Add TMR_ABORT_TASK task management support
  (FATE#313550).
- target: Untangle front-end and back-end meanings of max_sectors
  attribute (FATE#313550).
- target: fix use after free in target_report_luns (FATE#313550).
- target: prevent NULL pointer dereference in target_report_luns
  (FATE#313550).
- target: Fix off-by-seven in target_report_luns (FATE#313550).
- target/pscsi: fix PHV_VIRUTAL_HOST_ID typo (FATE#313550).
- iscsi-target: Fix iscsit_alloc_buffs() failure cases
  (FATE#313550).
- target: Fix target_submit_tmr LUN lookup failures (FATE#313550).
- target: Fix target_submit_tmr se_tmr_req allocation failures
  (FATE#313550).
- tcm_fc: Handle target_submit_tmr allocation failure
  (FATE#313550).
- target: Push target_submit_tmr LUN lookup failure to system_wq
  context (FATE#313550).
- target: Allow target_submit_tmr interrupt context + pass
  ABORT_TASK tag (FATE#313550).
- iscsi-target: Fix dynamic -> explict NodeACL pointer reference
  (FATE#313550).
- target: Fix typo in drivers/target (FATE#313550).
- target: Convert session_lock to irqsave (FATE#313550).
- target: Add se_sess->sess_kref + get/put helpers (FATE#313550).
- target: Add se_node_acl->acl_free_comp for NodeACL release path
  (FATE#313550).
- target: Add se_node_acl->acl_kref for ->acl_free_comp usage
  (FATE#313550).
- target: Convert se_node_acl->acl_group removal to use ->acl_kref
  (FATE#313550).
- iscsi-target: Convert to use target_put_session + sess_kref
  (FATE#313550).
- target: Drop unused legacy target_core_fabric_ops API callers
  (FATE#313550).
- target: Bump core version to v4.1.0-rc2-ml + fabric versions
  (FATE#313550).
- target: Fix compatible reservation handling (CRH=1) with legacy
  RESERVE/RELEASE (FATE#313550).
- iscsi-target: Fix reservation conflict -EBUSY response handling
  bug (FATE#313550).
- target: Remove hack to make READ CAPACITY(10) lie if thin
  provisioning is enabled (FATE#313550).
- target: Fix sense code for unsupported SERVICE ACTION IN
  (FATE#313550).
- target: Use array_zalloc for tpg_lun_list (FATE#313550).
- target: Use array_zalloc for device_list (FATE#313550).
- target: remove obvious warnings (FATE#313550).
- iscsi-target: Remove unused variables in
  iscsi_target_parameters.c (FATE#313550).
- iscsi-target: remove improper externs (FATE#313550).
- loopback: Fix transport_generic_allocate_tasks error handling
  (FATE#313550).
- target: remove the second argument of k[un]map_atomic()
  (FATE#313550).
- tcm_fc: Add abort flag for gracefully handling exchange timeout
  (FATE#313550).
- tcm_fc: Do not free tpg structure during wq allocation failure
  (FATE#313550).
- target: Remove obsolete DF_READ_ONLY usage (FATE#313550).
- target: add unknown size flag to target_submit_cmd()
  (FATE#313550).
- target: misc ramdisk backend cleanups (FATE#313550).
- target: don't limit transfer sizes for the ramdisk backend
  (FATE#313550).
- target: stop splitting commands into multiple tasks
  (FATE#313550).
- tcm_fc: Remove use of transport_do_task_sg_chain()
  (FATE#313550).
- target: Remove transport_do_task_sg_chain() and associated
  detritus (FATE#313550).
- target/iscsi: Rename iscsi_cmd.i_list to iscsi_cmd.i_conn_node
  (FATE#313550).
- target/iscsi: Misc cleanups from Agrover (round 1)
  (FATE#313550).
- target/iscsi: Remove unneeded locking from
  iscsi_target_tx_thread (FATE#313550).
- target/iscsi: Refactor target_tx_thread immediate+response
  queue loops (FATE#313550).
- target/iscsi: Misc cleanups from Agrover (round 2)
  (FATE#313550).
- target: Rename target_allocate_tasks to
  target_setup_cmd_from_cdb (FATE#313550).
- target: rewrite comment for generic_new_cmd (FATE#313550).
- target/iscsi: Inline iscsit_allocate_se_cmd and *_for_tmr
  (FATE#313550).
- target/iscsi: Move init_se_cmd closer to lookup_cmd_lun
  (FATE#313550).
- target/iscsi: Eliminate iscsi_cmd.data_length (FATE#313550).
- target/iscsi: Fold _decide_list_to_build into
  _build_pdu_and_seq_lists (FATE#313550).
- target: Call core_alua_check_nonop_delay in target_submit_cmd()
  (FATE#313550).
- target/iscsi: Go back to core allocating data buffer for cmd
  (FATE#313550).
- target/iscsi: cleanup some allocation style issues
  (FATE#313550).
- target: Handle GET_EVENT_STATUS_NOTIFICATION passthrough
  (FATE#313550).
- target: remove the unused transport_limit_task_sectors helper
  (FATE#313550).
- target: remove target_get_task_cdb (FATE#313550).
- target: remove the task_lba field in struct se_task
  (FATE#313550).
- target: remove the task_size field in struct se_task
  (FATE#313550).
- target: remove the task_sectors field in struct se_task
  (FATE#313550).
- target: Fix up handling of short INQUIRY buffers (FATE#313550).
- target: replace ->execute_task with ->execute_cmd (FATE#313550).
- target: always allocate a single task (FATE#313550).
- target: simplify command to task linkage (FATE#313550).
- target: move the state and execute lists to the command
  (FATE#313550).
- target: remove struct se_task (FATE#313550).
- target: remove the t_task_cdbs_left field in struct se_cmd
  (FATE#313550).
- target: remove the t_task_cdbs_ex_left field in struct se_cmd
  (FATE#313550).
- target: remove the t_se_count field in struct se_cmd
  (FATE#313550).
- target: Enforce hw_max_sectors for SCF_SCSI_DATA_SG_IO_CDB
  (FATE#313550).
- target: lock => unlock typo in transport_lun_wait_for_tasks
  (FATE#313550).
- target: Remove max_sectors device attribute for modern se_task
  less code (FATE#313550).
- sbp-target: Initial merge of firewire/ieee-1394 target mode
  support (FATE#313550).
- target: Drop incorrect se_lun_acl release for dynamic ->
  explict ACL conversion (FATE#313550).
- target: cleanup transport_execute_tasks() (FATE#313550).
- target: make target_put_session void (FATE#313550).
- target: Fix SPC-2 RELEASE bug for multi-session iSCSI client
  setups (FATE#313550).
- target: add support for the WRITE_VERIFY command (FATE#313550).
- target: Fix MAINTENANCE_IN service action CDB checks to use
  lower 5 bits (FATE#313550).
- target: Add MI_REPORT_TARGET_PGS ext. header +
  implict_trans_secs attribute (FATE#313550).
- target: Handle ATA_16 passthrough for pSCSI backend devices
  (FATE#313550).
- target: Fix bug in handling of FILEIO + block_device resize ops
  (FATE#313550).
- iscsi-target: remove dead code in
  iscsi_check_valuelist_for_support (FATE#313550).
- iscsi-target: Fix iov_count calculation bug in
  iscsit_allocate_iovecs (FATE#313550).
- sbp-target: rename a variable to avoid name clash (FATE#313550).
- target/file: Use O_DSYNC by default for FILEIO backends
  (FATE#313550).
- target: Add TFO->put_session() caller for HW fabric session
  shutdown (FATE#313550).
- target: Return error to initiator if SET TARGET PORT GROUPS
  emulation fails (FATE#313550).
- tcm_fc: Fix crash seen with aborts and large reads
  (FATE#313550).
- target: Clean up returning errors in PR handling code
  (FATE#313550).
- target: Fix range calculation in WRITE SAME emulation when
  num blocks == 0 (FATE#313550).
- target: move unrelated code out of
  transport_generic_cmd_sequencer (FATE#313550).
- target: remove control CDB flags (FATE#313550).
- target: split overflow and underflow checks into a helper
  (FATE#313550).
- target: split parsing of SPC commands into a separate helper
  (FATE#313550).
- target: add a parse_cdb method to the backend drivers
  (FATE#313550).
- target: move code for CDB emulation (FATE#313550).
- target: move transport_generic_prepare_cdb into pscsi
  (FATE#313550).
- target: Move MAINTENANCE_[IN,OUT] from pscsi_parse_cdb ->
  spc_parse_cdb (FATE#313550).
- target/pscsi: Only emulate REPORT_LUNS for passthrough
  (FATE#313550).
- target: remove the execute list (FATE#313550).
- target: move ref_cmd from the generic se_tmr_req into iscsi code
  (FATE#313550).
- target: Do not special-case loop and iscsi fabric module loads
  (FATE#313550).
- target/iblock: Add parameter to specify read-only devices
  (FATE#313550).
- target/iscsi: Remove dead code in lio_get_tpg_from_tpg_item()
  (FATE#313550).
- target: remove dead SCF_ flags (FATE#313550).
- target: add struct spc_ops + initial ->execute_rw pointer usage
  (FATE#313550).
- target: move sync_cache to struct spc_ops (FATE#313550).
- target: move write_same to struct spc_ops (FATE#313550).
- target: move unmap to struct spc_ops (FATE#313550).
- Revert "target: Do not special-case loop and iscsi fabric
  module loads" (FATE#313550).
- target: split transport_cmd_check_stop (FATE#313550).
- target: remove transport_generic_process_write (FATE#313550).
- target: call transport_check_aborted_status from
  target_execute_cmd (FATE#313550).
- target: merge transport_generic_write_pending into
  transport_generic_new_cmd (FATE#313550).
- iscsit: use target_execute_cmd for WRITEs (FATE#313550).
- tcm_fc: Offload WRITE I/O backend submission to tpg workqueue
  (FATE#313550).
- target: remove transport_generic_handle_data (FATE#313550).
- target: simply fabric driver queue full processing
  (FATE#313550).
- target: remove transport_generic_handle_cdb_map (FATE#313550).
- target: replace the processing thread with a TMR work queue
  (FATE#313550).
- target: Remove unneeded double parentheses (FATE#313550).
- target: Remove hba param from core_dev_add_lun (FATE#313550).
- target: Misc retval cleanups (FATE#313550).
- target: Eliminate else using boolean logic (FATE#313550).
- target: refactor core_update_device_list_for_node()
  (FATE#313550).
- target: Make core_disable_device_list_for_node use
  pre-refactoring lock ordering (FATE#313550).
- target: Un-export target_get_sess_cmd() (FATE#313550).
- sbp-target: Consolidate duplicated error path code in
  sbp_handle_command() (FATE#313550).
- target: Check sess_tearing_down in target_get_sess_cmd()
  (FATE#313550).
- target: Remove se_session.sess_wait_list (FATE#313550).
- target: Make unnecessarily global se_dev_align_max_sectors()
  static (FATE#313550).
- target: Add generation of LOGICAL BLOCK ADDRESS OUT OF RANGE
  (FATE#313550).
- target: Add range checking to UNMAP emulation (FATE#313550).
- target: Fix reading of data length fields for UNMAP commands
  (FATE#313550).
- target: Fix possible integer underflow in UNMAP emulation
  (FATE#313550).
- target: Check number of unmap descriptors against our limit
  (FATE#313550).
- target: Allow for target_submit_cmd() returning errors
  (FATE#313550).
- target: NULL dereference on error path (FATE#313550).
- iscsi-target: Drop bogus struct file usage for iSCSI/SCTP
  (FATE#313550).
- delousing target_core_file a bit (FATE#313550).
- tcm_fc: Avoid debug overhead when not debugging (FATE#313550).
- target: fix NULL pointer dereference bug alloc_page() fails
  to get memory (FATE#313550).
- target/pscsi: Fix bug with REPORT_LUNs handling for SCSI
  passthrough (FATE#313550).
- target: Fix regression bug with handling of zero-length data
  CDBs (FATE#313550).
- tcm_fc: rcu_deref outside rcu lock/unlock section (FATE#313550).
- target: Remove unused se_cmd.cmd_spdtl (FATE#313550).
- target: Fix ->data_length re-assignment bug with SCSI overflow
  (FATE#313550).
- target: Check idr_get_new return value in
  iscsi_login_zero_tsih_s1 (FATE#313550).
- target: move transport_get_sense_data (FATE#313550).
- target: simplify code around transport_get_sense_data
  (FATE#313550).
- target: fix use-after-free with PSCSI sense data (FATE#313550).
- target: go through normal processing for zero-length PSCSI
  commands (FATE#313550).
- target: report too-small parameter lists everywhere
  (FATE#313550).
- target: fail REPORT LUNS with less than 16 bytes of payload
  (FATE#313550).
- target: support zero-size allocation lengths in
  transport_kmap_data_sg (FATE#313550).
- target: support zero allocation length in REQUEST SENSE
  (FATE#313550).
- target: go through normal processing for zero-length
  REQUEST_SENSE (FATE#313550).
- target: Remove request_module for target_core_stgt
  (FATE#313550).
- target: Cleanup transport_subsystem_check_init (FATE#313550).
- target/sbp: Remove strict param from sbp_parse_wwn
  (FATE#313550).
- target: Remove unused
  target_core_fabric_ops.get_fabric_sense_len method
  (FATE#313550).
- target: Simplify fabric sense data length handling
  (FATE#313550).
- target: Fix minor spelling typos in drivers/target
  (FATE#313550).
- target/iblock: Use match_strlcpy for Opt_udev_path string
  assignment (FATE#313550).
- target/rd: Allow WriteCacheEnabled=1 operation with rd_mcp
  backends (FATE#313550).
- iscsi-target: Fix hex2bin warn_unused compile message
  (FATE#313550).
- target: check hex2bin result (FATE#313550).
- target: Drop se_subsystem_api->[write_cache,fua_write]_emulated
  flags (FATE#313550).
- target/iscsi: Don't log "iSCSI Login negotiation failed." twice
  (FATE#313550).
- target: use list_move_tail instead of list_del/list_add_tail
  (FATE#313550).
- target: support zero allocation length in INQUIRY (FATE#313550).
- target: fix truncation of mode data, support zero allocation
  length (FATE#313550).
- target: support zero allocation length in SBC commands
  (FATE#313550).
- target: do not submit a zero-bio I/O request (FATE#313550).
- target: go through normal processing for all zero-length
  commands (FATE#313550).
- tcm_fc: move the dereference below the NULL test (FATE#313550).
- target: move the dereference below the NULL test (FATE#313550).
- target: fix return code in target_core_init_configfs error path
  (FATE#313550).
- sbp-target: fix return value check in sbp_register_configfs()
  (FATE#313550).
- iscsi-target: Correctly set 0xffffffff field within
  ISCSI_OP_REJECT PDU (FATE#313550).
- target/file: Re-enable optional fd_buffered_io=1 operation
  (FATE#313550).
- iscsi-target: Add base MaxXmitDataSegmentLength code
  (FATE#313550).
- iscsi-target: Enable MaxXmitDataSegmentLength operation in
  login path (FATE#313550).
- iscsi-target: Convert incoming PDU payload checks to
  MaxXmitDataSegmentLength (FATE#313550).
- iscsi-target: Add MaxXmitDataSegmentLength connection recovery
  check (FATE#313550).
- iscsi-target: Change iscsi_target_seq_pdu_list.c to honor
  MaxXmitDataSegmentLength (FATE#313550).
- iscsi-target: Add explicit set of cache_dynamic_acls=1 for
  TPG demo-mode (FATE#313550).
- target: Add target_submit_cmd_map_sgls for SGL fabric memory
  passthrough (FATE#313550).
- tcm_loop: Convert I/O path to use target_submit_cmd_map_sgls
  (FATE#313550).
- target: Add control CDB READ payload zero work-around
  (FATE#313550).
- target/iscsi: precedence bug in
  iscsit_set_dataout_sequence_values() (FATE#313550).
- iscsit: mark various functions static (FATE#313550).
- iscsit: remove incorrect unlock in iscsit_build_sendtargets_resp
  (FATE#313550).
- iscsit: add missing endianess conversion in
  iscsit_check_inaddr_any (FATE#313550).
- iscsit: use the itt_t abstract type (FATE#313550).
- iscsit: proper endianess conversions (FATE#313550).
- iscsi-target: Bump defaults for nopin_timeout +
  nopin_response_timeout values (FATE#313550).
- target: Fix double-free of se_cmd in target_complete_tmr_failure
  (FATE#313550).
- target: reintroduce some obsolete SCSI-2 commands (FATE#313550).
- target: Re-add explict zeroing of INQUIRY bounce buffer memory
  (FATE#313550).
- target: Don't return success from module_init() if setup fails
  (FATE#313550).
- target: Avoid integer overflow in se_dev_align_max_sectors()
  (FATE#313550).
- iscsi-target: Fix missed wakeup race in TX thread (FATE#313550).
- target: Fix incorrect usage of nested IRQ spinlocks in
  ABORT_TASK path (FATE#313550).
- btree: export btree_get_prev() so modules can use btree_for_each
  (FATE#313550).
- Update config files.
- Update
  patches.fixes/scsi-update-scsi.h-with-SYNCHRONIZE_CACHE_16.patch
  (FATE#313550).
- commit 278992f
* Mon Nov 19 2012 hare@suse.de
- patches.fixes/scsi-update-scsi.h-with-SYNCHRONIZE_CACHE_16.patch:
  Delete unused patch.
- commit 57e6897
* Mon Nov 19 2012 mchang@suse.com
- x86/mce: Provide boot argument to honour bios-set CMCI threshold (fate#313970).
- commit 47645e9
* Mon Nov 19 2012 mchang@suse.com
- Refresh patches.xen/xen3-auto-arch-x86.diff.
- commit d9de4b3
* Mon Nov 19 2012 mchang@suse.com
- x86/mce: Add CMCI poll mode (bnc#786450).
- x86: mce: Split timer init (bnc#786450).
- x86: mce: Add the dropped timer interval init back (bnc#786450).
- x86/mce: Fix the MCE poll timer logic (bnc#786450).
- x86/mce: Cleanup timer mess (bnc#786450).
- commit a64f883
* Mon Nov 19 2012 mchang@suse.com
- x86/mce: Add quirk for instruction recovery on Sandy Bridge
  processors (fate#313743, fate#314744).
- x86/mce: Move MCACOD defines from mce-severity.c to <asm/mce.h>
  (fate#313743, fate#314744).
- x86/mce: Fix siginfo_t->si_addr value for non-recoverable
  memory faults (fate#313743, fate#314744).
- x86/mce: Add instruction recovery signatures to mce-severity
  table (fate#313743, fate#314744).
- x86/mce: Only restart instruction after machine check recovery
  if it is safe (fate#313743, fate#314744).
- x86/mce: Avoid reading every machine check bank register twice
  (fate#313743, fate#314744).
- x86/mce: Replace hard coded hex constants with symbolic defines
  (fate#313743, fate#314744).
- x86/mce: Recognise machine check bank signature for data path
  error (fate#313743, fate#314744).
- x86/mce: Handle "action required" errors (fate#313743,
  fate#314744).
- x86/mce: Add mechanism to safely save information in MCE handler
  (fate#313743, fate#314744).
- x86/mce: Create helper function to save addr/misc when needed
  (fate#313743, fate#314744).
- HWPOISON: Add code to handle "action required" errors
  (fate#313743, fate#314744).
- HWPOISON: Clean up memory_failure() vs. __memory_failure()
  (fate#313743, fate#314744).
- x86, mce: Replace MCM_ with MCI_MISC_ (fate#313743,
  fate#314744).
- x86, mce, severity: Clean up trivial coding style problems
  (fate#313743, fate#314744).
- x86, mce, severity: Cleanup severity table (fate#313743,
  fate#314744).
- x86, mce, severity: Make formatting a bit more readable
  (fate#313743, fate#314744).
- x86, mce, severity: Fix two severities table signatures
  (fate#313743, fate#314744).
- commit 15f2a02
* Sun Nov 18 2012 neilb@suse.de
- Refresh
  patches.suse/md-bm-20-bitmap-add-bitmap_resize-function-to-allow-bitmap.patch.
  Fix some types to match upstream and to fix problems on 32bit systems.
- commit ceb004c
* Fri Nov 16 2012 duwe@suse.de
- patches.drivers/ibmvfc-fix-double-completion-on-abort-timeout:
  ibmvfc: Fix double completion on abort timeout (bnc#788452)
- patches.drivers/ibmvfc-ignore-fabric-RSCNs-when-link-dead:
  ibmvfc: Ignore fabric RSCNs when link is dead (bnc#788452).
- commit 84de2e3
* Fri Nov 16 2012 dsterba@suse.cz
- patches.suse/btrfs-8187-fix-a-double-free-on-pending-snapshots-in-erro.patch:
  Btrfs: fix a double free on pending snapshots in error handling
- patches.suse/btrfs-8188-Don-t-trust-the-superblock-label-and-simply-pr.patch:
  Btrfs: Don't trust the superblock label and simply printk("%%s")
  it
- commit 7ab348d
* Fri Nov 16 2012 mkubecek@suse.cz
- patches.fixes/net-prevent-NULL-dereference-in-check_peer_redir.patch:
  net: prevent NULL dereference in check_peer_redir() (bnc#776044
  bnc#784576).
- commit b4b04b3
* Fri Nov 16 2012 jlee@suse.com
- i2c-i801: Add Device IDs for Intel Lynx Point-LP PCH.
- ata_piix: Add Device IDs for Intel Lynx Point-LP PCH.
- ahci: Add Device IDs for Intel Lynx Point-LP PCH.
- commit 007e886
* Fri Nov 16 2012 jlee@suse.com
- watchdog: iTCO_wdt: add Intel Lynx Point DeviceIDs (fate#313409,
  bnc#760833).
- watchdog: iTCO_wdt: clean-up PCI device ID's (fate#313409,
  bnc#760833).
- i2c-i801: Add device IDs for Intel Lynx Point (fate#313409,
  bnc#760833).
- ata_piix: IDE-mode SATA patch for Intel Lynx Point DeviceIDs
  (fate#313409, bnc#760833).
- ahci: AHCI-mode SATA patch for Intel Lynx Point DeviceIDs
  (fate#313409, bnc#760833).
- commit 0a8daac
* Thu Nov 15 2012 dsterba@suse.cz
- patches.suse/btrfs-update-message-levels.patch: Refresh.
- commit 8f4e7b4
* Thu Nov 15 2012 mgorman@suse.de
- Delete patches.fixes/mm-pagealloc-do-not-wake-kswapd-if-request-is-THP-but-deferred-fix.patch.
- Delete patches.fixes/mm-pagealloc-do-not-wake-kswapd-if-request-is-THP-but-deferred.patch.
- Delete patches.fixes/mm-remove-__GFP_NO_KSWAPD.patch.
- Refresh patches.suse/mm-introduce-__GFP_MEMALLOC-to-allow-access-to-emergency-reserves.patch.
- Refresh patches.suse/mm-sl[au]b-add-knowledge-of-PFMEMALLOC-reserve-pages.patch.
  Prevent kswapd getting into a 100%% CPU usage loop due to THP.
- commit 502d958
* Thu Nov 15 2012 dsterba@suse.cz
- patches.suse/btrfs-enospc-debugging-messages.patch: Minor updates.
- patches.suse/btrfs-update-message-levels.patch: Minor updates.
- commit 862302d
* Thu Nov 15 2012 tiwai@suse.de
- encrypted-keys: IS_ERR need include/err.h.
- commit fd6bf4a
* Thu Nov 15 2012 mmarek@suse.cz
- KEYS: linux/key-type.h needs linux/errno.h.
- commit 6a437a5
* Thu Nov 15 2012 trenn@suse.de
- CPER failed to handle generic error records with multiple
  sections (fate#311701).
- ACPI, APEI: Fixup common access width firmware bug
  (fate#311701).
- Refresh patches.arch/009-apei_fixes.patch.
- ACPI, APEI, Fix ERST header length check (fate#311701).
- commit 033fdbf
* Thu Nov 15 2012 mmarek@suse.cz
- X.509: Do not reply on implicit time.h include.
- commit 0a88801
* Thu Nov 15 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require openssl in the -devel package to sign
  external modules.
- commit 25c1b07
* Thu Nov 15 2012 mmarek@suse.cz
- Kbuild: Do not require signing key for external modules (temporary
  workaround)
- commit 5a3b661
* Thu Nov 15 2012 jlee@suse.com
- hibernate: Disable in a Secure Boot environment (fate#314486).
- SELinux: define mapping for new Secure Boot capability
  (fate#314486).
- acpi: Ignore acpi_rsdp kernel parameter in a secure boot
  environment (fate#314486).
- efi: Enable secure boot lockdown automatically when enabled
  in firmware (fate#314486).
- Secure boot: Add a dummy kernel parameter that will switch on
  Secure Boot mode (fate#314486).
- Restrict /dev/mem and /dev/kmem in secure boot setups
  (fate#314486).
- asus-wmi: Restrict debugfs interface (fate#314486).
- ACPI: Limit access to custom_method (fate#314486).
- x86: Lock down IO port access in secure boot environments
  (fate#314486).
- PCI: Lock down BAR access in secure boot environments
  (fate#314486).
- Secure boot: Add new capability (fate#314486).
- commit fd47a04
* Thu Nov 15 2012 jlee@suse.com
- x86, efi: Handover Protocol (fate#314485).
- commit 69c726c
* Wed Nov 14 2012 dsterba@suse.cz
- patches.suse/btrfs-8186-continue-after-abort-during-snapshot-drop.patch:
  btrfs: continue after abort during snapshot drop (bnc#752067).
- commit ffab490
* Wed Nov 14 2012 mmarek@suse.cz
- Update config files: Enable CONFIG_MODULE_SIG, but disable
  CONFIG_MODULE_SIG_FORCE (fate#314508).
- rpm/kernel-binary.spec.in: Add openssl to BuildRequires.
- commit d87b5ad
* Wed Nov 14 2012 trenn@suse.de
- ACPI: Fix logic for removing mappings in 'acpi_unmap'
  (fate#313747).
- Refresh patches.xen/xen3-005-acpi_atomicio.patch.
- commit 661d588
* Wed Nov 14 2012 oneukum@suse.de
- xhci: fix integer overflow (FATE#313675).
- commit 9e0514a
* Wed Nov 14 2012 jlee@suse.com
- Update config files for CONFIG_EFI_STUB (fate#313640, fate#314486)
  Add 'CONFIG_EFI_STUB=Y' to config of the following arch setup:
  config/x86_64/debug
  config/x86_64/default
  config/x86_64/trace
  config/x86_64/xen
  Add '# CONFIG_EFI_STUB is not set' to config of the following arch
  setup:
  config/i386/debug
  config/i386/default
  config/i386/pae
  config/i386/trace
- commit 2e73aa2
* Wed Nov 14 2012 jlee@suse.com
- x86, efi stub: Add .reloc section back into image (fate#313640,
  fate#314486).
- x86, efi: Fix NumberOfRvaAndSizes field in PE32 header for
  EFI_STUB (fate#313640, fate#314486).
- x86, efi: Fix .text section overlapping image header for
  EFI_STUB (fate#313640, fate#314486).
- x86, efi: Fix issue of overlapping .reloc section for EFI_STUB
  (fate#313640, fate#314486).
- x86, efi: Add EFI boot stub documentation (fate#313640,
  fate#314486).
- x86, efi; Add EFI boot stub console support (fate#313640,
  fate#314486).
- x86, efi: Only close open files in error path (fate#313640,
  fate#314486).
- commit d360483
* Wed Nov 14 2012 jlee@suse.com
- x86, efi: Add dedicated EFI stub entry point.
- x86, efi: Fix pointer math issue in handle_ramdisks().
- x86, efi: Fix endian issues and unaligned accesses.
- x86, boot: Restrict CFLAGS for hostprogs.
- x86, mkpiggy: Don't open code put_unaligned_le32().
- x86, relocs: Don't open code put_unaligned_le32().
- tools/include: Add byteshift headers for endian access.
- x86, efi: Break up large initrd reads.
- x86, efi: EFI boot stub support.
- efi: Add EFI file I/O data types.
- efi.h: Add boottime->locate_handle search types.
- efi.h: Add graphics protocol guids.
- efi.h: Add allocation types for boottime->allocate_pages().
- efi.h: Add efi_image_loaded_t.
- efi.h: Add struct definition for boot time services.
- x86: Don't use magic strings for EFI loader signature.
- x86: Add missing bzImage fields to struct setup_header.
- x86, efi: Make efi_call_phys_{prelog,epilog}
  CONFIG_RELOCATABLE-aware.
- x86, build: Do not set the root_dev field in bzImage.
- commit 5b0e68a
* Tue Nov 13 2012 mgorman@suse.de
- patches.fixes/mm-hotplug-correctly-add-zone-to-other-nodes-list.patch:
  Refresh.
- commit 11d4d74
* Tue Nov 13 2012 oneukum@suse.de
- xhci: endianness xhci_calculate_intel_u2_timeout (FATE#313675).
- commit df96473
* Tue Nov 13 2012 mgorman@suse.de
- patches.fixes/mm-hotplug-correctly-add-zone-to-other-nodes-list.patch:
  mm/hotplug: correctly add new zone to all other nodes' zone lists.
  (CVE-2012-5517 bnc#789235)
- commit 87edfe2
* Tue Nov 13 2012 oneukum@suse.de
- USB: Fix LPM disable/enable during device reset (FATE#313675).
- commit e952abb
* Tue Nov 13 2012 oneukum@suse.de
- USB: Disable LPM while the device is unconfigured (FATE#313675).
- commit 0058239
* Tue Nov 13 2012 oneukum@suse.de
- USB: Fix LPM disable count mismatch on driver unbind
  (FATE#313675).
- commit 335a22d
* Tue Nov 13 2012 jbeulich@novell.com
- Update Xen patches to 3.0.51.
- commit ea142d2
* Tue Nov 13 2012 jlee@suse.com
- module_signing: fix printk format warning (fate#314508).
- MODSIGN: Move the magic string to the end of a module and
  eliminate the search (fate#314508).
- MODSIGN: Cleanup .gitignore (fate#314508).
- MODSIGN: perlify sign-file and merge in x509keyid (fate#314508).
- kbuild: Fix module signature generation (fate#314508).
- kbuild: sign the modules at install time (fate#314508).
- X.509: Fix indefinite length element skip error handling
  (fate#314508).
- X.509: Convert some printk calls to pr_devel (fate#314508).
- asymmetric keys: fix printk format warning (fate#314508).
- MODSIGN: Fix 32-bit overflow in X.509 certificate validity
  date checking (fate#314508).
- MODSIGN: Make mrproper should remove generated files
  (fate#314508).
- MODSIGN: Use utf8 strings in signer's name in autogenerated
  X.509 certs (fate#314508).
- MODSIGN: Use the same digest for the autogen key sig as for
  the module sig (fate#314508).
- MODSIGN: Sign modules during the build process (fate#314508).
- MODSIGN: Provide a script for generating a key ID from an
  X.509 cert (fate#314508).
- MODSIGN: Implement module signature checking (fate#314508).
- MODSIGN: Provide module signing public keys to the kernel
  (fate#314508).
- MODSIGN: Automatically generate module signing keys if missing
  (fate#314508).
- MODSIGN: Provide Kconfig options (fate#314508).
- MODSIGN: Provide gitignore and make clean rules for extra files
  (fate#314508).
- MODSIGN: Add FIPS policy (fate#314508).
- module: signature checking hook (fate#314508).
- X.509: Add a crypto key parser for binary (DER) X.509
  certificates (fate#314508).
- MPILIB: Provide a function to read raw data into an MPI
  (fate#314508).
- X.509: Add an ASN.1 decoder (fate#314508).
- X.509: Add simple ASN.1 grammar compiler (fate#314508).
- X.509: Add utility functions to render OIDs as strings
  (fate#314508).
- X.509: Implement simple static OID registry (fate#314508).
- RSA: Fix signature verification for shorter signatures
  (fate#314508).
- RSA: Implement signature verification algorithm [PKCS#1 /
  RFC3447] (fate#314508).
- MPILIB: Reinstate mpi_cmp[_ui]() and export for RSA signature
  verification (fate#314508).
- KEYS: Provide signature verification with an asymmetric key
  (fate#314508).
- KEYS: Asymmetric public-key algorithm crypto key subtype
  (fate#314508).
- KEYS: Asymmetric key pluggable data parsers (fate#314508).
- KEYS: Implement asymmetric key type (fate#314508).
- KEYS: Document asymmetric key type (fate#314508).
- MPILIB: Provide count_leading/trailing_zeros() based on arch
  functions (fate#314508).
- KEYS: Add payload preparsing opportunity prior to key
  instantiate or update (fate#314508).
- userns: Add kuid_t and kgid_t and associated infrastructure
  in uidgid.h (fate#314508).
- lib: rename pack_hex_byte() to hex_byte_pack() (fate#314508).
- lib: add error checking to hex2bin (fate#314508).
- encrypted-keys: fix rcu and sparse messages (fate#314508).
- keys: fix trusted/encrypted keys sparse rcu_assign_pointer
  messages (fate#314508).
- encrypted-keys: fix error return code (fate#314508).
- security: follow rename pack_hex_byte() to hex_byte_pack()
  (fate#314508).
- encrypted-keys: module build fixes (fate#314508).
- encrypted-keys: check hex2bin result (fate#314508).
- encrypted-keys: remove trusted-keys dependency (fate#314508).
- encrypted-keys: create encrypted-keys directory (fate#314508).
- eCryptfs: export global eCryptfs definitions to
  include/linux/ecryptfs.h (fate#314508).
- encrypted-keys: add key format support (fate#314508).
- encrypted-keys: added additional debug messages (fate#314508).
- Remove unused code from MPI library (fate#314508).
- Revert "crypto: GnuPG based MPI lib - additional sources
  (part 4)" (fate#314508).
- mpi: Avoid using freed pointer in mpi_lshift_limbs()
  (fate#314508).
- lib: Fix 32-bit sparc udiv_qrnnd() definition in mpilib's
  longlong.h (fate#314508).
- lib/mpi: added missing NULL check (fate#314508).
- lib/mpi: added comment on divide by 0 case (fate#314508).
- lib/mpi: check for possible zero length (fate#314508).
- lib/mpi: removed unused functions (fate#314508).
- lib/mpi: checks for zero divisor length (fate#314508).
- lib/mpi: return error code on dividing by zero (fate#314508).
- lib/mpi: replaced MPI_NULL with normal NULL (fate#314508).
- lib/mpi: added missing NULL check (fate#314508).
- MPILIB: Add a missing ENOMEM check (fate#314508).
- mpi/mpi-mpow: NULL dereference on allocation failure
  (fate#314508).
- crypto: GnuPG based MPI lib - additional sources (part 4)
  (fate#314508).
- crypto: GnuPG based MPI lib - make files (part 3) (fate#314508).
- crypto: GnuPG based MPI lib - header files (part 2)
  (fate#314508).
- crypto: GnuPG based MPI lib - source files (part 1)
  (fate#314508).
- commit 1d7c1a2
* Mon Nov 12 2012 jlee@suse.com
- efivarfs: Implement exclusive access for {get,set}_variable.(FATE#314499, FATE#314509)
- commit dd35f07
* Mon Nov 12 2012 jlee@suse.com
- efivarfs: efivarfs_fill_super() ensure we clean up correctly on error.(FATE#314499, FATE#314509)
- commit 3a97db4
* Mon Nov 12 2012 jlee@suse.com
- efivarfs: efivarfs_fill_super() ensure we free our temporary name.(FATE#314499, FATE#314509)
- commit a5b7809
* Mon Nov 12 2012 jlee@suse.com
- efivarfs: efivarfs_fill_super() fix inode reference counts.(FATE#314499, FATE#314509)
- commit edafbb4
* Mon Nov 12 2012 jlee@suse.com
- efivarfs: efivarfs_create() ensure we drop our reference on inode on error. (FATE#314499, FATE#314509)
- commit 7529bcb
* Mon Nov 12 2012 jlee@suse.com
- efivarfs: efivarfs_file_read ensure we free data in error paths.(FATE#314499, FATE#314509)
- commit 34e832b
* Mon Nov 12 2012 jlee@suse.com
- efivarfs: Add documentation for the EFI variable filesystem.(FATE#314499, FATE#314509)
- commit 67fa539
* Mon Nov 12 2012 jlee@suse.com
- efi: add efivars kobject to efi sysfs folder.
- commit 83b4af3
* Mon Nov 12 2012 jlee@suse.com
- efi: Handle deletions and size changes in efivarfs_write_file.
- commit b2f2183
* Mon Nov 12 2012 jlee@suse.com
- efi: Add support for a UEFI variable filesystem.
- commit 382efe2
* Mon Nov 12 2012 jlee@suse.com
- vfs: new helper - d_make_root(). (FATE#314499, FATE#314509)
- commit c991d70
* Mon Nov 12 2012 jlee@suse.com
- Make ->d_sb assign-once and always non-NULL.
- commit c8c7b62
* Fri Nov  9 2012 mgorman@suse.de
- Delete
  patches.fixes/mm-vmscan-scale-number-of-pages-reclaimed-by-reclaim-compaction-based-on-failures.patch.
- Delete
  patches.fixes/mm-vmscan-scale-number-of-pages-reclaimed-by-reclaim-compaction-only-in-direct-reclaim.patch.
  Found to cause high kswapd CPU usage in some cases.
- commit c8e5863
* Thu Nov  8 2012 neilb@suse.de
- Update config files.
  Compile dm-thin (as a module).
- commit ea12583
* Thu Nov  8 2012 neilb@suse.de
- dm thin: support discard with non power of two block size
  (FATE#313903).
- dm persistent data: convert to use le32_add_cpu (FATE#313903).
- dm: use ACCESS_ONCE for sysfs values (FATE#313903).
- dm bufio: use list_move (FATE#313903).
- dm thin: fix discard support for data devices (FATE#313903).
- dm thin: tidy discard support (FATE#313903).
- dm thin: do not set discard_zeroes_data (FATE#313903).
- Fix dm-raid45 to match previous patch (FATE#313903).
- dm thin: commit before gathering status (FATE#313903).
- dm thin: add read only and fail io modes (FATE#313903).
- dm thin metadata: introduce dm_pool_abort_metadata
  (FATE#313903).
- dm thin metadata: introduce dm_pool_metadata_set_read_only
  (FATE#313903).
- dm persistent data: introduce dm_bm_set_read_only (FATE#313903).
- dm thin: reduce number of metadata commits (FATE#313903).
- dm thin metadata: add dm_thin_changed_this_transaction
  (FATE#313903).
- dm thin metadata: add format option to dm_pool_metadata_open
  (FATE#313903).
- dm thin metadata: tidy up open and format error paths
  (FATE#313903).
- dm thin metadata: only check incompat features on open
  (FATE#313903).
- dm thin metadata: remove duplicate pmd initialisation
  (FATE#313903).
- dm thin metadata: remove create parameter from
  __create_persistent_data_objects (FATE#313903).
- dm thin metadata: move __superblock_all_zeroes to
  __open_or_format_metadata (FATE#313903).
- dm thin metadata: remove nr_blocks arg from
  __create_persistent_data_objects (FATE#313903).
- dm thin metadata: split __open or format metadata (FATE#313903).
- dm thin metadata: use struct dm_pool_metadata members in
  __open_or_format_metadata (FATE#313903).
- dm thin metadata: zero unused superblock uuid (FATE#313903).
- dm thin metadata: lift __begin_transaction out of
  __write_initial_superblock (FATE#313903).
- dm thin metadata: move dm_commit_pool_metadata into
  __write_initial_superblock (FATE#313903).
- dm thin metadata: factor out __write_initial_superblock
  (FATE#313903).
- dm thin metadata: lift some initialisation out of
  __open_or_format_metadata (FATE#313903).
- dm thin metadata: factor __destroy_persistent_data out of
  dm_pool_metadata_close (FATE#313903).
- dm thin metadata: move bm creation code into
  create_persistent_data_objects (FATE#313903).
- dm thin metadata: rename init_pmd to
  __create_persistent_data_objects (FATE#313903).
- dm thin metadata: wrap superblock locking (FATE#313903).
- dm persistent data: stop using dm_bm_unlock_move when shadowing
  blocks in tm (FATE#313903).
- dm persistent data: tidy transaction manager creation fns
  (FATE#313903).
- dm thin metadata: stop tracking need for commit (FATE#313903).
- dm persistent data: create new dm_block_manager struct
  (FATE#313903).
- dm thin metadata: factor __setup_btree_details out of init_pmd
  (FATE#313903).
- dm thin: set flush_supported (FATE#313903).
- dm: allow targets to request flushes regardless of underlying
  device support (FATE#313903).
- dm persistent data: only commit space map if index changed
  (FATE#313903).
- dm persistent data: always unlock superblock in
  dm_bm_flush_and_unlock (FATE#313903).
- dm thin: avoid unnecessarily breaking sharing for flushes
  (FATE#313903).
- dm thin: fix memory leak in process_prepared_mapping error paths
  (FATE#313903).
- dm thin: optimize power of two block size (FATE#313903).
- dm thin: split discards on block boundary (FATE#313903).
- dm: introduce split_discard_requests (FATE#313903).
- dm thin: support for non power of 2 pool blocksize
  (FATE#313903).
- dm-raid45: use dm_set_target_mx_io_len instead of setting
  split_io (FATE#313903).
- dm: support non power of two target max_io_len (FATE#313903).
- dm thin: provide specific errors for two table load failure
  cases (FATE#313903).
- dm thin metadata: introduce THIN_MAX_CONCURRENT_LOCKS
  (FATE#313903).
- dm thin metadata: remove pointless label from
  __commit_transaction (FATE#313903).
- dm persistent data: remove debug space map checker
  (FATE#313903).
- dm thin: clean up compiler warning (FATE#313903).
- dm thin: reduce endio_hook pool size (FATE#313903).
- dm thin: do not send discards to shared blocks (FATE#313903).
- dm persistent data: fix allocation failure in space map checker
  init (FATE#313903).
- dm persistent data: handle space map checker creation failure
  (FATE#313903).
- dm persistent data: fix shadow_info_leak on dm_tm_destroy
  (FATE#313903).
- dm thin: commit metadata before creating metadata snapshot
  (FATE#313903).
- dm thin: provide userspace access to pool metadata
  (FATE#313903).
- dm thin: use slab mempools (FATE#313903).
- dm thin: fix table output when pool target disables discard
  passdown internally (FATE#313903).
- dm thin: correct module description (FATE#313903).
- dm thin: fix unprotected use of prepared_discards list
  (FATE#313903).
- dm thin: reinstate missing mempool_free in
  cell_release_singleton (FATE#313903).
- dm bufio: prefetch (FATE#313903).
- dm thin: add pool target flags to control discard (FATE#313903).
- dm thin: support discards (FATE#313903).
- dm thin: prepare to support discard (FATE#313903).
- dm thin: use dm_target_offset (FATE#313903).
- dm thin: support read only external snapshot origins
  (FATE#313903).
- dm thin: relax hard limit on the maximum size of a metadata
  device (FATE#313903).
- dm persistent data: remove space map ref_count entries if
  redundant (FATE#313903).
- dm thin: commit outstanding data every second (FATE#313903).
- dm thin metadata: pass correct space map to dm_sm_root_size
  (FATE#313903).
- dm persistent data: remove redundant value_size arg from
  value_ptr (FATE#313903).
- dm thin: correct comments (FATE#313903).
- dm persistent data: fix btree rebalancing after remove
  (FATE#313903).
- dm thin: fix stacked bi_next usage (FATE#313903).
- dm thin metadata: decrement counter after removing mapped block
  (FATE#313903).
- dm thin metadata: unlock superblock in init_pmd error path
  (FATE#313903).
- dm thin metadata: remove incorrect close_device on creation
  error paths (FATE#313903).
- dm-bufio.c: there's no need to include linux/version.h
  (FATE#313903).
- device-mapper: dm-bufio.c needs to include module.h
  (FATE#313903).
- dm: add thin provisioning target (FATE#313903).
- dm-btree: use "struct __dm_node_" instead of "struct node"
  (FATE#313903).
- dm: add persistent data library (FATE#313903).
- dm: linux/shrinker.h not needed in 3.0 (FATE#313903).
- dm: add bufio (FATE#313903).
- dm: export dm get md (FATE#313903).
- dm table: add immutable feature (FATE#313903).
- dm table: add always writeable feature (FATE#313903).
- dm table: add singleton feature (FATE#313903).
- dm kcopyd: add dm_kcopyd_zero to zero an area (FATE#313903).
- dm crypt: always disable discard_zeroes_data (FATE#313903).
- dm ioctl: fill in device parameters in more ioctls
  (FATE#313903).
- dm-mpath: Fix parsing of "no_partitions" flag (FATE#313903).
- dm table: share target argument parsing functions (FATE#313903).
- dm kcopyd: remove nr_pages field from job structure
  (FATE#313903).
- dm kcopyd: remove offset field from job structure (FATE#313903).
- commit 208852c
* Thu Nov  8 2012 bpoirier@suse.de
- patches.drivers/igb-fix-recent-VLAN-changes-that-would-leave-VLANs-d.patch:
  igb: fix recent VLAN changes that would leave VLANs disabled
  after reset (bnc#787168).
- commit 439f325
* Wed Nov  7 2012 eich@suse.com
- patches.drivers/DRM-Radeon-Clean-up-code-in-TV-DAC-load-detection.patch:
  Update references (bnc #739728).
- patches.drivers/DRM-Radeon-Fix-Load-Detection-on-legacy-primary-DAC.patch:
  Update references (bnc #739728).
- patches.drivers/DRM-Radeon-Fix-TV-DAC-Load-Detection-for-single-CRTC-chips.patch:
  Update references (bnc #739728).
- patches.drivers/DRM-Radeon-Fix-primary-DAC-Load-Detection-for-RV100-chips.patch:
  Update references (bnc #739728).
- patches.drivers/DRM-Radeon-On-DVI-I-use-Load-Detection-when-EDID-is-bogus.patch:
  Update references (bnc #739728).
- commit f4f3cdf
* Wed Nov  7 2012 eich@suse.com
- patches.drivers/DRM-radeon-For-single-CRTC-GPUs-move-handling-of-CRTC_CRT_ON-to-crtc_dpms.patch:
  Update references (bnc #723776).
- commit 50e8d7d
* Wed Nov  7 2012 eich@suse.com
- patches.drivers/DRM-radeon-For-single-CRTC-GPUs-move-handling-of-CRTC_CRT_ON-to-crtc_dpms.patch:
  DRM/radeon: For single CRTC GPUs move handling of CRTC_CRT_ON
  to crtc_dpms() (bnc #725152).
- commit bd4ab9d
* Wed Nov  7 2012 eich@suse.com
- patches.drivers/DRM-Radeon-Fix-TV-DAC-Load-Detection-for-single-CRTC-chips.patch:
  DRM/Radeon: Fix TV DAC Load Detection for single CRTC chips
  (bnc #725152).
- commit 074e302
* Wed Nov  7 2012 eich@suse.com
- patches.drivers/DRM-Radeon-Clean-up-code-in-TV-DAC-load-detection.patch:
  DRM/Radeon: Clean up code in TV DAC load detection (bnc #725152).
- commit f869af3
* Wed Nov  7 2012 eich@suse.com
- patches.drivers/DRM-Radeon-On-DVI-I-use-Load-Detection-when-EDID-is-bogus.patch:
  DRM/Radeon: On DVI-I use Load Detection when EDID is bogus
  (bnc #725152).
- commit 03d1a87
* Wed Nov  7 2012 eich@suse.com
- patches.drivers/DRM-Radeon-Fix-primary-DAC-Load-Detection-for-RV100-chips.patch:
  DRM/Radeon: Fix primary DAC Load Detection for RV100 chips
  (bnc #725152).
- commit 02dfd2a
* Wed Nov  7 2012 eich@suse.com
- patches.drivers/DRM-Radeon-Fix-Load-Detection-on-legacy-primary-DAC.patch:
  DRM/Radeon: Fix Load Detection on legacy primary DAC (bnc #725152).
- commit 4e93065
* Wed Nov  7 2012 jslaby@suse.cz
- patches.fixes/x86-kexec-temporary-hack-v2: Refresh.
  Fix of fix, sorry about that.
- commit 88a89f2
* Wed Nov  7 2012 jslaby@suse.cz
- patches.fixes/x86-kexec-temporary-hack-v2: Refresh.
  Fix bug in 3.0.50 merge (compiler emitted a new warning).
- commit 89b319f
* Wed Nov  7 2012 jslaby@suse.cz
- Linux 3.0.51 (bnc#762259).
- patches.kabi/x86-revert-HLT-removal.patch: x86: revert HLT
  removal.
- patches.drivers/floppy-convert-to-single-threaded-wq.patch:
  Refresh.
- patches.fixes/mm-Fix-XFS-oops-due-to-dirty-pages-without-buffers-o.patch:
  Delete.
- commit 8f91c72
* Wed Nov  7 2012 jjolly@suse.de
- patches.arch/s390-60-01-smsgiucv-resume.patch: smsgiucv:
  reestablish IUCV path after resume (bnc#786976,LTC#86245).
- patches.arch/s390-60-02-dasd_move_wake_up_call.patch: dasd:
  move wake_up call (bnc#786976,LTC#86252).
- patches.arch/s390-60-03-gup-task-size.patch: kernel: fix
  get_user_pages_fast() page table walk (bnc#786976,LTC#86307).
- commit d86cdf7
* Tue Nov  6 2012 jbohac@suse.cz
- supported.conf: mark ipset modules supported (fate#313309)
- commit 93c114d
* Tue Nov  6 2012 jjolly@suse.de
- Update s390 config files, removing invalid reference to CRASH_DUMP.
- commit ad21d2a
* Tue Nov  6 2012 jjolly@suse.de
- update default configuration (bnc#786472,ltc#82694,fate#314077).
- commit 8b74db4
* Tue Nov  6 2012 jjolly@suse.de
- s390/kexec: Move early_pgm_check_handler() to text section
  (bnc#786472,ltc#82694,fate#314077).
- commit 312edba
* Tue Nov  6 2012 jjolly@suse.de
- s390/kdump: Use real mode for PSW restart and kexec
  (bnc#786472,ltc#82694,fate#314077).
- commit 94b6d2f
* Tue Nov  6 2012 jjolly@suse.de
- s390/kdump: Account /sys/kernel/kexec_crash_size changes in
  OS info (bnc#786472,ltc#82694,fate#314077).
- commit 2dddb95
* Tue Nov  6 2012 jjolly@suse.de
- s390/kernel: Remove OS info init function call and diag 308
  for kdump (bnc#786472,ltc#82694,fate#314077).
- commit 573e678
* Tue Nov  6 2012 jjolly@suse.de
- s390: initialize backchain for ext_int_handler()
  (bnc#786472,ltc#82694,fate#314077).
- commit 331bce4
* Tue Nov  6 2012 jjolly@suse.de
- kernel: Use local_irq_save() for memcpy_real()
  (bnc#786472,ltc#82694,fate#314077).
- commit 40f968a
* Tue Nov  6 2012 jjolly@suse.de
- Ensure that vmcore_info pointer is never accessed directly
  (bnc#786472,ltc#82694,fate#314077).
- commit 50d2a1f
* Tue Nov  6 2012 jjolly@suse.de
- kernel: Add OS info memory interface
  (bnc#786472,ltc#82694,fate#314077).
- commit 6caa31f
* Tue Nov  6 2012 jjolly@suse.de
- lowcore cleanup (bnc#786472,ltc#82694,fate#314077).
- commit ee990c3
* Tue Nov  6 2012 jjolly@suse.de
- Use copy_to_absolute_zero() instead of "stura/sturg"
  (bnc#786472,ltc#82694,fate#314077).
- commit ec551f9
* Tue Nov  6 2012 jjolly@suse.de
- Fix gcc 4.6.0 compile warning
  (bnc#786472,ltc#82694,fate#314077).
- commit ec0fc69
* Tue Nov  6 2012 jjolly@suse.de
- kdump: define KEXEC_NOTE_BYTES arch specific for s390x
  (bnc#786472,ltc#82694,fate#314077).
- Refresh patches.xen/xen3-auto-common.diff.
- commit 90c069f
* Tue Nov  6 2012 jjolly@suse.de
- kdump: crashk_res init check for /sys/kernel/kexec_crash_size
  (bnc#786472,ltc#82694,fate#314077).
- commit 0d9d674
* Tue Nov  6 2012 jjolly@suse.de
- kdump: add missing RAM resource in crash_shrink_memory()
  (bnc#786472,ltc#82694,fate#314077).
- commit e9ec21b
* Tue Nov  6 2012 jjolly@suse.de
- Add s390x description to Documentation/kdump/kdump.txt
  (bnc#786472,ltc#82694,fate#314077).
- commit 35ea7fc
* Tue Nov  6 2012 jjolly@suse.de
- Add VMCOREINFO_SYMBOL(high_memory) to vmcoreinfo
  (bnc#786472,ltc#82694,fate#314077).
- commit 2187824
* Tue Nov  6 2012 jjolly@suse.de
- kernel: Fix smp_switch_to_ipl_cpu() stack frame setup
  (bnc#786472,ltc#82694,fate#314077).
- commit 65200cc
* Tue Nov  6 2012 jjolly@suse.de
- Remove useless newline in reserve_kdump_bootmem()
  (bnc#786472,ltc#82694,fate#314077).
- commit c2fe9b5
* Tue Nov  6 2012 jjolly@suse.de
- Rework create_mem_hole() function
  (bnc#786472,ltc#82694,fate#314077).
- commit 60bd6cd
* Tue Nov  6 2012 jjolly@suse.de
- kdump: Replace is_kdump_kernel() with OLDMEM_BASE check
  (bnc#786472,ltc#82694,fate#314077).
- commit 2fe7d71
* Tue Nov  6 2012 jjolly@suse.de
- zfcpdump: Do not initialize zfcpdump in kdump mode
  (bnc#786472,ltc#82694,fate#314077).
- commit 7499bb8
* Tue Nov  6 2012 jjolly@suse.de
- Kconfig: Select CONFIG_KEXEC for CONFIG_CRASH_DUMP
  (bnc#786472,ltc#82694,fate#314077).
- commit de10fbd
* Tue Nov  6 2012 jjolly@suse.de
- Remove error checking from copy_oldmem_page()
  (bnc#786472,ltc#82694,fate#314077).
- commit f07b852
* Tue Nov  6 2012 jjolly@suse.de
- Add architecture code for unmapping crashkernel memory
  (bnc#786472,ltc#82694,fate#314077).
- commit 207f21f
* Tue Nov  6 2012 jjolly@suse.de
- kdump: Add infrastructure for unmapping crashkernel memory
  (bnc#786472,ltc#82694,fate#314077).
- Refresh patches.xen/xen3-auto-common.diff.
- commit dc9f998
* Tue Nov  6 2012 dsterba@suse.cz
- series.conf: fix malformed patch names
- commit 8e7a0c0
* Tue Nov  6 2012 jjolly@suse.de
- Export vmcoreinfo note (bnc#786472,ltc#82694,fate#314077).
- commit 4f7f6e5
* Tue Nov  6 2012 jjolly@suse.de
- kdump: Initialize vmcoreinfo note at startup
  (bnc#786472,ltc#82694,fate#314077).
- Refresh patches.xen/xen3-patch-2.6.24.
- commit 486371e
* Tue Nov  6 2012 jjolly@suse.de
- kdump backend code (bnc#786472,ltc#82694,fate#314077).
- Update config files.
- commit 0253b70
* Tue Nov  6 2012 jjolly@suse.de
- Add real memory access functions
  (bnc#786472,ltc#82694,fate#314077).
- commit 5c8b81b
* Tue Nov  6 2012 jjolly@suse.de
- Force PSW restart on online CPU
  (bnc#786472,ltc#82694,fate#314077).
- commit d440a82
* Tue Nov  6 2012 jjolly@suse.de
- kdump: Add size to elfcorehdr kernel parameter
  (bnc#786472,ltc#82694,fate#314077).
- commit ec82bd1
* Tue Nov  6 2012 jjolly@suse.de
- kdump: Add KEXEC_CRASH_CONTROL_MEMORY_LIMIT
  (bnc#786472,ltc#82694,fate#314077).
- commit 61a096d
* Tue Nov  6 2012 jjolly@suse.de
- Change default action from reipl to stop for on_restart
  (bnc#786472,ltc#82694,fate#314077).
- commit 4e997fb
* Tue Nov  6 2012 jjolly@suse.de
- Use diagnose 308 for system reset
  (bnc#786472,ltc#82694,fate#314077).
- commit 22e5b0e
* Tue Nov  6 2012 jjolly@suse.de
- Add PSW restart shutdown trigger
  (bnc#786472,ltc#82694,fate#314077).
- commit fe36c81
* Tue Nov  6 2012 jjolly@suse.de
- Export store_status() function
  (bnc#786472,ltc#82694,fate#314077).
- commit 4a5db97
* Tue Nov  6 2012 jjolly@suse.de
- Revert multi-patch commit before individual submission
- commit c2f0f54
* Tue Nov  6 2012 brogers@suse.com
- patches.fixes/kvm-invalid-opcode-oops-on-SET_SREGS-with-OSXSAVE-bi.patch:
  kvm: invalid opcode oops on SET_SREGS with OSXSAVE bit set
  (bnc#787821 CVE-2012-4461).
- commit 9e8177e
* Tue Nov  6 2012 trenn@suse.de
- Add Kconfig option ARCH_HAVE_NMI_SAFE_CMPXCHG (fate#313740).
- ACPI, APEI, Remove table not found message (fate#311701).
- ACPI, APEI, GHES, Distinguish interleaved error report in
  kernel log (fate#311701).
- ACPI, APEI, Printk queued error record before panic
  (fate#311701).
- acpi/apei/einj: Add extensions to EINJ from rev 5.0 of acpi spec
  (fate#311701).
- Update config files.
- llist: Remove the platform-dependent NMI checks (fate#313740).
- llist: Move cpu_relax() to after the cmpxchg() (fate#313740).
- llist: Return whether list is empty before adding in llist_add()
  (fate#313740).
- llist: Remove cpu_relax() usage in cmpxchg loops (fate#313740).
- commit c79a8c1
* Tue Nov  6 2012 trenn@suse.de
- Adjusted CONFIG_PROC_VMCORE=y: moved downward in s390x config files.
- commit 246c857
* Tue Nov  6 2012 tiwai@suse.de
- Revert invalid kconfig changes for vanilla kernel for HD-audio updates
- commit 14c6581
* Tue Nov  6 2012 jjolly@suse.de
- Export store_status() function
  (bnc#786472,ltc#82694,fate#314077).
- Add PSW restart shutdown trigger
  (bnc#786472,ltc#82694,fate#314077).
- Use diagnose 308 for system reset
  (bnc#786472,ltc#82694,fate#314077).
- Change default action from reipl to stop for on_restart
  (bnc#786472,ltc#82694,fate#314077).
- kdump: Add KEXEC_CRASH_CONTROL_MEMORY_LIMIT
  (bnc#786472,ltc#82694,fate#314077).
- kdump: Add size to elfcorehdr kernel parameter
  (bnc#786472,ltc#82694,fate#314077).
- Force PSW restart on online CPU
  (bnc#786472,ltc#82694,fate#314077).
- Add real memory access functions
  (bnc#786472,ltc#82694,fate#314077).
- kdump backend code (bnc#786472,ltc#82694,fate#314077).
- kdump: Initialize vmcoreinfo note at startup
  (bnc#786472,ltc#82694,fate#314077).
- Export vmcoreinfo note (bnc#786472,ltc#82694,fate#314077).
- kdump: Add infrastructure for unmapping crashkernel memory
  (bnc#786472,ltc#82694,fate#314077).
- Add architecture code for unmapping crashkernel memory
  (bnc#786472,ltc#82694,fate#314077).
- Remove error checking from copy_oldmem_page()
  (bnc#786472,ltc#82694,fate#314077).
- Kconfig: Select CONFIG_KEXEC for CONFIG_CRASH_DUMP
  (bnc#786472,ltc#82694,fate#314077).
- zfcpdump: Do not initialize zfcpdump in kdump mode
  (bnc#786472,ltc#82694,fate#314077).
- kdump: Replace is_kdump_kernel() with OLDMEM_BASE check
  (bnc#786472,ltc#82694,fate#314077).
- Rework create_mem_hole() function
  (bnc#786472,ltc#82694,fate#314077).
- Remove useless newline in reserve_kdump_bootmem()
  (bnc#786472,ltc#82694,fate#314077).
- kernel: Fix smp_switch_to_ipl_cpu() stack frame setup
  (bnc#786472,ltc#82694,fate#314077).
- Add VMCOREINFO_SYMBOL(high_memory) to vmcoreinfo
  (bnc#786472,ltc#82694,fate#314077).
- Add s390x description to Documentation/kdump/kdump.txt
  (bnc#786472,ltc#82694,fate#314077).
- kdump: add missing RAM resource in crash_shrink_memory()
  (bnc#786472,ltc#82694,fate#314077).
- kdump: crashk_res init check for /sys/kernel/kexec_crash_size
  (bnc#786472,ltc#82694,fate#314077).
- kdump: define KEXEC_NOTE_BYTES arch specific for s390x
  (bnc#786472,ltc#82694,fate#314077).
- Fix gcc 4.6.0 compile warning
  (bnc#786472,ltc#82694,fate#314077).
- Use copy_to_absolute_zero() instead of "stura/sturg"
  (bnc#786472,ltc#82694,fate#314077).
- lowcore cleanup (bnc#786472,ltc#82694,fate#314077).
- kernel: Add OS info memory interface
  (bnc#786472,ltc#82694,fate#314077).
- Ensure that vmcore_info pointer is never accessed directly
  (bnc#786472,ltc#82694,fate#314077).
- kernel: Use local_irq_save() for memcpy_real()
  (bnc#786472,ltc#82694,fate#314077).
- s390: initialize backchain for ext_int_handler()
  (bnc#786472,ltc#82694,fate#314077).
- s390/kernel: Remove OS info init function call and diag 308
  for kdump (bnc#786472,ltc#82694,fate#314077).
- s390/kdump: Account /sys/kernel/kexec_crash_size changes in
  OS info (bnc#786472,ltc#82694,fate#314077).
- s390/kdump: Use real mode for PSW restart and kexec
  (bnc#786472,ltc#82694,fate#314077).
- s390/kexec: Move early_pgm_check_handler() to text section
  (bnc#786472,ltc#82694,fate#314077).
- update default configuration (bnc#786472,ltc#82694,fate#314077).
- Update config files.
- Refresh patches.xen/xen3-auto-common.diff.
- Refresh patches.xen/xen3-patch-2.6.24.
- commit d3157a1
* Tue Nov  6 2012 neilb@suse.de
- Refresh
  patches.suse/md-bm-20-bitmap-add-bitmap_resize-function-to-allow-bitmap.patch.
  use DIV_ROUND_UP_SECTOR_T to ensure it works on 32bit archs.
- commit 3b34f93
* Tue Nov  6 2012 neilb@suse.de
- patches.suse/xor-0000-add-avx-defines: add some defined needed for
  xor patches (FATE#313639).
- commit 0181957
* Tue Nov  6 2012 neilb@suse.de
- Activate enhanced-RAID10 patches for standard kernel.
  Remove the tag that excluded these patches from the standard kernel,
  refresh the patches and fix a few minor merge issues.
  This makes
  FATE#313639 RAID[5|6] enhancements to improve efficiency and performance
  part of the standard kernel.
  It provides various improvements to RAID10 including better handling of
  devices going off line or imposing delays, and also including reshaping
  of md/RAID10 arrays.
- Refresh patches.suse/md-Do-not-block-when-displaying-info.patch.
- Refresh patches.suse/md-allow-restarting-interrupted-recovery.
- Refresh patches.suse/md-bitmap-discard-chunk_block_shift.
- Refresh patches.suse/md-bitmap-revert-dm-log.
- Refresh
  patches.suse/md-bm-02-bitmap-add-new-space-attribute-for-bitmaps.patch.
- Refresh
  patches.suse/md-bm-03-bitmap-allow-a-bitmap-with-no-backing-storage.patch.
- Refresh
  patches.suse/md-bm-06-bitmap-move-some-fields-of-struct-bitmap-into-a-s.patch.
- Refresh
  patches.suse/md-bm-18-bitmap-create-a-struct-bitmap_counts-substructure.patch.
- Refresh
  patches.suse/md-bm-22-allow-array-to-be-resized-while-bitmap-is-present.patch.
- Refresh
  patches.suse/md-bm-23-raid10-resize-bitmap-when-required-during-reshape.patch.
- Refresh patches.suse/md-display-timeout-error.patch.
- Refresh patches.suse/md-r10-fix-on-stack-allocation.
- Refresh patches.suse/md-raid10-merge_bvec_fn.fix.
- Refresh patches.suse/md-raid10-set_dev_sectors.
- Refresh patches.suse/md-raid10-shrink-remove.
- Refresh
  patches.suse/md-raid10-support-resizing-some-RAID10-arrays.patch.
- Refresh patches.suse/md-support-re-add-of-recovering-devices.
- Refresh patches.suse/md-unblock-SET_DISK_FAULTY.patch.
- Refresh patches.suse/md-unlock_rdev_access.
- Refresh patches.suse/md-update-sb-async.
- Refresh
  patches.suse/r10-reshape-1-md-allow-a-reshape-operation-to-be-reversed.patch.
- Refresh
  patches.suse/r10-reshape-2-md-add-possibility-to-change-data-offset-for-devices.patch.
- Refresh
  patches.suse/r10-reshape-3-md-raid10-collect-some-geometry-fields-into-a-dedica.patch.
- Refresh
  patches.suse/r10-reshape-4-md-teach-sync_page_io-about-new_data_offset.patch.
- Refresh
  patches.suse/r10-reshape-5-md-use-resync_max_sectors-for-reshape-as-well-as-res.patch.
- Refresh
  patches.suse/r10-reshape-6-md-raid10-Introduce-prev-geometry-to-support-reshape.patch.
- Refresh
  patches.suse/r10-reshape-7-md-raid10-split-out-interpretation-of-layout-to-sepa.patch.
- Refresh
  patches.suse/r10-reshape-8-md-raid10-add-reshape-support.patch.
- commit 94f2922
* Tue Nov  6 2012 neilb@suse.de
- lib/raid6: fix sparse warnings in recovery functions
  (FATE#313639).
- lib/raid6: cleanup gen_syndrome function selection
  (FATE#313639).
- lib/raid6: update test program for recovery functions
  (FATE#313639).
- patches.suse/xor-0005-lib-raid6-Add-SSSE3-optimized-recovery-functions.patch:
- raid5: add AVX optimized RAID5 checksumming (FATE#313639).
- crypto: disable preemption while benchmarking RAID5 xor
  checksumming (FATE#313639).
- crypto: wait for a full jiffy in do_xor_speed (FATE#313639).
- commit c37d073
* Tue Nov  6 2012 neilb@suse.de
- patches.suse/md-Do-not-block-when-displaying-info.patch:
  Change 'goto' target to avoid pointless 'bug' messages in
  normal error cases. (bnc#787848)
- commit 5355798
* Mon Nov  5 2012 dsterba@suse.cz
- btrfs-8147-fix-file-extent-discount-problem-in-the-snapsh.patch: remove stale file
- commit b962f8a
* Mon Nov  5 2012 trenn@suse.de
- Add APEI patches from mainline. Mark some with +trenn to clarify things first:
- ACPI: Fix possible alignment issues with GAS 'address'
  references (fate#313747).
- PCI: PCIe AER: add aer_recover_queue (fate#313737, fate#311701).
- ACPI: Export interfaces for ioremapping/iounmapping ACPI
  registers (fate#313747).
- llist: Make some llist functions inline (fate#311701).
- ACPI APEI: Convert atomicio routines (fate#313747).
- ACPI, APEI, GHES: Add PCIe AER recovery support (fate#313737,
  fate#311701).
- ACPI, APEI: Add 64-bit read/write support for APEI on i386
  (fate#313747).
- ACPI, APEI, Remove table not found message (fate#311701).
- ACPI, APEI: Add RAM mapping support to ACPI (fate#313747).
- ACPI, APEI, GHES, Distinguish interleaved error report in
  kernel log (fate#311701).
- ACPI: Remove ./drivers/acpi/atomicio (fate#313747).
- ACPI, APEI, Printk queued error record before panic
  (fate#311701).
- ACPI, APEI, Avoid too much error reporting in runtime
  (fate#313747).
- acpi/apei/einj: Add extensions to EINJ from rev 5.0 of acpi spec
  (fate#311701).
- ACPI, APEI: Fix incorrect APEI register bit width check and
  usage (fate#313747 bnc#725592).
- Delete
  patches.drivers/apei_check_acc_width_allow_not_byte_alligned_bit_offset.patch.
- commit 2d23b9c
* Mon Nov  5 2012 tiwai@suse.de
- Update config files for the recent HD-audio updates
- commit e8d77af
* Mon Nov  5 2012 mmarek@suse.cz
- Drop kernel-desktop, it has never been used in SLE11
- commit 218dea3
* Mon Nov  5 2012 trenn@suse.de
- Revert SP2 APEI safety patches for SP3 and enable APEI by default:
- Delete patches.drivers/acpi_apei_allow_partly_enabling.patch.
- Delete patches.drivers/acpi_apei_disable_suse.patch.
- Delete patches.drivers/acpi_apei_whitelist_hest_dell.patch.
- commit 9513bc8
* Mon Nov  5 2012 trenn@suse.de
- patches.arch/intel_idle_add_ivy_bridge_support.patch:
  intel_idle: IVB support (fate#313719).
- commit f073df1
* Sat Nov  3 2012 dsterba@suse.cz
- patches.suse/btrfs-8180-Return-EINVAL-when-length-to-trim-is-less-than.patch:
  btrfs: Return EINVAL when length to trim is less than FSB
  (FATE#306586).
- patches.suse/btrfs-8181-fix-unnecessary-while-loop-when-search-the-fre.patch:
  Btrfs: fix unnecessary while loop when search the free space,
  cache (FATE#306586).
- patches.suse/btrfs-8182-Use-btrfs_update_inode_fallback-when-creating-.patch:
  Btrfs: Use btrfs_update_inode_fallback when creating a snapshot
  (FATE#306586).
- patches.suse/btrfs-8183-do-not-bug-when-we-fail-to-commit-the-transact.patch:
  Btrfs: do not bug when we fail to commit the transaction
  (FATE#306586).
- patches.suse/btrfs-8184-fill-the-global-reserve-when-unpinning-space.patch:
  Btrfs: fill the global reserve when unpinning space
  (FATE#306586).
- patches.suse/btrfs-8185-don-t-allow-degraded-mount-if-too-many-devices.patch:
  Btrfs: don't allow degraded mount if too many devices are
  missing (FATE#306586).
- commit feaa280
* Fri Nov  2 2012 brogers@suse.com
- Revert "- patches.fixes/kvm-invalid-opcode-oops-on-SET_SREGS-with-OSXSAVE-bi.patch:"
  Revert checkin since patch is embargoed.
  This reverts commit bf178e0e1f7532d7c255e537d42e4d9dba1db8ba.
- commit 0acc16d
* Fri Nov  2 2012 trenn@suse.de
- patches.arch/x86_powernow-k8-dont-complain-on-missing-cpufreq-on-hp.patch:
  X86 cpufreq: Do not complain on missing cpufreq tables on
  ProLiants (bnc#787202).
- commit a717338
* Fri Nov  2 2012 brogers@suse.com
- patches.fixes/kvm-invalid-opcode-oops-on-SET_SREGS-with-OSXSAVE-bi.patch:
  kvm: invalid opcode oops on SET_SREGS with OSXSAVE bit set
  (bnc#787821 CVE-2012-4461).
- commit bf178e0
* Fri Nov  2 2012 jslaby@suse.cz
- patches.fixes/hpilo-remove-pci_disable_device.patch: MISC:
  hpilo, remove pci_disable_device (bnc#752544).
- commit 87b2e9a
* Thu Nov  1 2012 bpoirier@suse.de
- patches.drivers/ixgbe-Address-fact-that-RSC-was-not-setting-GSO-size.patch:
  ixgbe: Address fact that RSC was not setting GSO size for
  incoming frames (bnc#776144).
- commit fe324d7
* Thu Nov  1 2012 mmarek@suse.cz
- Update kabi files.
- commit 4f6ab0a
* Thu Nov  1 2012 mmarek@suse.cz
- scripts/update-symvers: Fix handling of s390x on SLE11-SP1+
  Since SP1, s390x is treated separately from s390.
- commit e18c3ed
* Thu Nov  1 2012 ohering@suse.de
- patches.suse/msft-hv-0404-Drivers-hv-Cleanup-error-handling-in-vmbus_open.patch:
  Drivers: hv: Cleanup error handling in vmbus_open().
- patches.suse/msft-hv-0405-SCSI-storvsc-Account-for-in-transit-packets-in-the-R.patch:
  [SCSI] storvsc: Account for in-transit packets in the RESET
  path.
- patches.fixes/hv-storvsc-reset-wait.patch: Delete.
- commit 10fb6e6
* Thu Nov  1 2012 mmarek@suse.cz
- Delete patches.kabi/* workarounds.
- commit 6b38098
* Thu Nov  1 2012 jslaby@suse.cz
- Linux 3.0.50.
- patches.fixes/x86-kexec-temporary-hack-v2: Refresh.
- commit eef0d74
* Thu Nov  1 2012 jslaby@suse.cz
- patches.kabi/kabi-rmap-remove-inclusion.patch: kABI: rmap,
  remove inclusion.
- commit 4d28c98
* Wed Oct 31 2012 lduncan@suse.com
- patches.drivers/sg-remove-sg_mutex.patch: sg: remove sg_mutex.
  (bnc#785496)
- commit cb96b0a
* Wed Oct 31 2012 tonyj@suse.de
- patches.fixes/perf-do-no-try-to-schedule-task-events.patch:
  perf: Do no try to schedule task events if there are none
  (bnc#781574).
- patches.fixes/perf-do-not-set-task_ctx-pointer-in-cpuctx.patch:
  perf: Do not set task_ctx pointer in cpuctx if there are no
  events in the context (bnc#781574).
- commit 34e8ab9
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: Add a hook capability to vmaster controls (FATE#313695).
- commit 1acb472
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Fix mute-LED setup for HP dv5 laptop (FATE#313695).
- ALSA: hda - Fix silent headphone output from Toshiba P200
  (FATE#314311).
- ALSA: hda - add dock support for Thinkpad T430 (FATE#314311).
- ALSA: hda - Always check array bounds in alc_get_line_out_pfx
  (FATE#314311).
- ALSA: hda - Stop LPIB delay counting on broken hardware
  (FATE#313695).
- ALSA: hda - Add workaround for conflicting IEC958 controls
  (FATE#314311).
- ALSA: hda - Clean up superfluous position_fix list entries
  (FATE#313695).
- ALSA: hda - do not detect jack on internal speakers for Realtek
  (FATE#314311).
- ALSA: hda - Fix missing beep on ASUS X43U notebook
  (FATE#314311).
- ALSA: hda - Remove AZX_DCAPS_POSFIX_COMBO (FATE#313695).
- ALSA: hda - Warn an allocation for an uninitialized array
  (FATE#313695).
- ALSA: hda - Add missing hda_gen_spec to struct via_spec
  (FATE#314106).
- ALSA: hda - remove "Mic Jack Mode" for headset jacks (Latitude
  Exx30) (FATE#313695).
- ALSA: hda - Remove dead GPIO code for VIA codec (FATE#314106).
- ALSA: hda - Add new codec ALC283 ALC290 support (FATE#314311).
- ALSA: hda - avoid unneccesary indices on "Headphone Jack"
  controls (FATE#313695).
- ALSA: hda - fix indices on boost volume on Conexant
  (FATE#313695).
- ALSA: hda - Fix hang caused by race during suspend
  (FATE#313695).
- ALSA: hda/realtek - Fix detection of ALC271X codec
  (FATE#314311).
- ALSA: hda - Add inverted internal mic quirk for Lenovo IdeaPad
  U310 (FATE#313695).
- ALSA: hda - Yet another position_fix quirk for ASUS machines
  (FATE#313695).
- ALSA: hda - add PCI identifier for Intel 5 Series/3400
  (FATE#313695).
- ALSA: hda - use LPIB for delay estimation (FATE#313695).
- ALSA: hda - force use of SSYNC bits (FATE#313695).
- ALSA: hda/via - don't report presence on HPs with no presence
  support (FATE#314106).
- ALSA: hda - Add external mic quirk for Asus Zenbook UX31A
  (FATE#314311).
- ALSA: hda - use both input paths on Conexant auto parser
  (FATE#313695).
- ALSA: hda - avoid non-standard "Docking" name in mixers
  (FATE#313695).
- ALSA: hda - limit internal mic boost for Asus X202E
  (FATE#314106).
- ALSA: hda - Add another pci id for Haswell board (FATE#314312).
- commit 53f8d7c
* Wed Oct 31 2012 mgorman@suse.de
- patches.suse/SoN-0018-mm-swap-Implement-generic-handlers-for-swap-related-fix-2.patch:
  mm: swap: Implement generic handlers for swap-related address ops fix.
  (bnc#778334)
- commit 6d7c733
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Allow to pass position_fix=0 explicitly
  (FATE#313695).
- ALSA: hda_intel: add position_fix quirk for Asus K53E
  (FATE#313695).
- ALSA: hda - Fix Oops at codec reset/reconfig (FATE#313695).
- ALSA: hda - Fix missing Master volume for STAC9200/925x
  (FATE#313695).
- ALSA: hda - Check bit mask for codec SSID in
  snd_hda_pick_fixup() (FATE#313695).
- ALSA: hda - Avoid BDL position workaround when no_period_wakeup
  is set (FATE#313695).
- ALSA: hda - Remove ignore_misc_bit (FATE#313695).
- ALSA: hda - Move non-PCM check to per_pin in patch_hdmi.c
  (FATE#314289).
- ALSA: hda - fix control names for multiple speaker out on
  IDT/STAC (FATE#313695).
- ALSA: HDMI - Setup channel mapping for non_pcm audio
  (FATE#314289).
- ALSA: HDMI - Enable HBR feature on Intel chips (FATE#314289).
- ALSA: HDMI - Fix channel_allocation array wrong order
  (FATE#314289).
- ALSA: hda - Clean up redundant FG checks (FATE#313754).
- ALSA: hda - Yet another fix for D3 stop-clock refcounting
  (FATE#313754).
- ALSA: hda - Optimize bitfield usage in struct hda_codec
  (FATE#313754).
- ALSA: hda - Clean up CONFIG_SND_HDA_POWER_SAVE (FATE#313754).
- ALSA: hda - Fix D3 clock stop check for codecs with own
  set_power_state op (FATE#313754).
- ALSA: hda - Fix runtime PM leftover refcounts (FATE#313754).
- ALSA: hda - Don't trust codec EPSS bit for IDT 92HD83xx & co
  (FATE#313725).
- ALSA: hda - Avoid unnecessary parameter read for EPSS
  (FATE#313725).
- ALSA: hda - Do not set GPIOs for speakers on IDT if there are
  no speakers (FATE#313695).
- ALSA: hda - Make clear built-in driver optimization
  (FATE#313754).
- ALSA: hda - bug fix on references without checking
  CONFIG_SND_HDA_POWER_SAVE (FATE#313754).
- ALSA: hda - add runtime PM support (FATE#313754).
- ALSA: hda - Call snd_hda_jack_report_sync() generically in
  hda_codec.c (FATE#314311).
- ALSA: hda - Fix leftover codec->power_transition (FATE#313695).
- ALSA: hda - don't create dysfunctional mixer controls for ca0132
  (FATE#313695).
- ALSA: hda - Add missing SPDIF I/O setup for CA0132
  (FATE#313695).
- ALSA: hda - Use the standard PCM ops for CA0132 (FATE#313695).
- ALSA: hda - Fix superfluous "-in" suffix from CA0132 capture
  items (FATE#313695).
- ALSA: hda - Add codec->pcm_format_first flag (FATE#313695).
- ALSA: hda - Don't send invalid volume knob command on IDT
  92hd75bxx (FATE#313695).
- commit 413a39e
* Wed Oct 31 2012 tiwai@suse.de
- ALSA : hda - bug fix on checking the supported power states
  of a codec (FATE#313695).
- ALSA: hda_intel: Add Device IDs for Intel Lynx Point-LP PCH
  (FATE#313695).
- ALSA: hda - Add missing ifdef CONFIG_SND_HDA_POWER_SAVE to
  tracepoints (FATE#313695).
- ALSA: hda - Check the power state when power_save option is
  changed (FATE#313695).
- ALSA: hda - Implement snd_hda_power_sync() helper function
  (FATE#313695).
- ALSA: hda - Add tracepoints at snd_hda_power_up/down entrances
  (FATE#313695).
- commit 9c2219c
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - show ICT/KAE control bits (FATE#313695).
- ALSA: hda - Fix pop noise in headphones on S3 for Asus X55A,
  X55V (FATE#314106).
- ALSA: hda - Fix double quirk for Quanta FL1 / Lenovo Ideapad
  (FATE#314311).
- ALSA: hda - Fix ugly debug prints with
  CONFIG_SND_VERBOSE_PRINTK=y (FATE#313695).
- ALSA: hda - remove redundant auto quirks for conexant 506x
  (FATE#313695).
- ALSA: hda - remove quirk for Dell Vostro 1015 (FATE#313695).
- ALSA: hda - add dock support for Thinkpad X230 (FATE#314311).
- ALSA: hda - Fix regression of HDMI codec probing (FATE#313695).
- ALSA: hda - add dock support for Thinkpad T430s (FATE#314311).
- ALSA: hda - Support dock on Lenovo Thinkpad T530 with ALC269VC
  (FATE#314311).
- ALSA: hda - Fix mute-LED GPIO initialization for IDT codecs
  (FATE#313695).
- ALSA: hda - Fix polarity of mute LED on HP Mini 210
  (FATE#313695).
- ALSA: hda - Workaround for silent output on VAIO Z with ALC889
  (FATE#314311).
- ALSA: hda - Fix WARNING from HDMI/DP parser (FATE#313695).
- ALSA: hda - Detach from converter at closing in patch_hdmi.c
  (FATE#313695).
- ALSA: hda - Fix mute-LED GPIO setup for HP Mini 210
  (FATE#313695).
- ALSA: hda - Fix invalid D3 of headphone DAC on VT202x codecs
  (FATE#314106).
- ALSA: hda - add dock support for Thinkpad X230 Tablet
  (FATE#314311).
- ALSA: hda - Turn on PIN_OUT from hdmi playback prepare
  (FATE#313695).
- ALSA: Convert to new pm_ops for PCI drivers (FATE#314106).
- ALSA: hda - make sure alc268 does not OOPS on codec parse
  (FATE#313695).
- ALSA: hda - Fix index number conflicts of phantom jacks
  (FATE#313695).
- ALSA: hda - Add new GPU codec ID to snd-hda (FATE#313695).
- ALSA: hda - Fix driver type of Haswell controller to
  AZX_DRIVER_SCH (FATE#313695).
- ALSA: hda - add Haswell HDMI codec id (FATE#313695).
- ALSA: hda - Add DeviceID for Haswell HDA (FATE#313695).
- ALSA: hda - Always call standard unsolicited event for Realtek
  codecs (FATE#314311).
- ALSA: hda - give 3-pin jack the name "Headphone Mic Jack"
  (FATE#314311).
- ALSA: HDA: Support single 3-pin jack without VREF on the actual
  pin (FATE#314311).
- ALSA: hda - Remove suprefluous EAPD init verbs for ALC660vd
  (FATE#314311).
- ALSA: hda - Add inv-dmic model to possible Realtek codecs
  (FATE#314311).
- ALSA: hda - Add inverted mic quirks for Asus U41SV, Acer 1810TZ
  and AOD260 (FATE#314311).
- ALSA: hda - Add the inverted digital mic workaround to Realtek
  codecs (FATE#314311).
- ALSA: hda - Don't power up when not powered down (FATE#313695).
- ALSA: hda - Correct info print in HDMI non-intrinsic unsol event
  (FATE#313695).
- ALSA: hda - Don't rely on event tag for simple_hdmi
  (FATE#313695).
- ALSA: hda - Remove loop from simple_hdmi*() (FATE#313695).
- ALSA: hda - Move one-time init codes from generic_hdmi_init()
  (FATE#313695).
- ALSA: hda - Add missing snd_hda_jack_detect_enable() for
  simple_hdmi*() (FATE#313695).
- ALSA: hda - Fix the pin nid assignment in patch_hdmi.c
  (FATE#313695).
- ALSA: hda - Enable unsol event for ATI and Nvidia HDMI codecs
  too (FATE#313695).
- ALSA: hda - Remove invalid init verbs for Nvidia 2ch codecs
  (FATE#313695).
- commit 6c691c4
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Use common codes for ATI, Nvidia and VIA simple
  codecs (FATE#313695).
- ALSA: hda - Merge ATI/VIA HDMI simple init functions
  (FATE#313695).
- ALSA: hda - Add the support for VIA HDMI pin detection
  (FATE#313695).
- ALSA: hda_intel: activate COMBO mode for Intel client chipsets
  (FATE#313695).
- ALSA: HDA: Create phantom jacks for fixed inputs and outputs
  (FATE#313695).
- ALSA: hda - add support for HD-Audio CODECes of VIA HDMI GFX
  Cards (FATE#313695).
- ALSA: hda - add support for HD-Audio of VIA HDMI GFX Cards
  (FATE#313695).
- ALSA: hda - power setting error check
  (FATE#313695,,FATE#313725).
- ALSA: hda - check proper return value (FATE#313695,FATE#313725).
- ALSA: hda - reduce msleep time if EPSS power states supported
  (FATE#313695,FATE#313725).
- ALSA: hda - check supported power states
  (FATE#313695,FATE#313725).
- ALSA: hda - Show D3cold state in proc files (FATE#313695).
- ALSA: hda - add power states information in proc (FATE#313695).
- ALSA: hda - Fix no sound from ALC662 after Windows reboot
  (FATE#314311).
- ALSA: hda - Fix power-map regression for HP dv6 & co
  (FATE#313695).
- ALSA: hda - Initialize caches at codec reconfiguration
  (FATE#313695).
- ALSA: hda - Fix memory leaks at module unload (FATE#313695).
- ALSA: hda - Fix memory leaks in Realtek & Conexant codec parsers
  (FATE#314311).
- ALSA: hda - Remove obsoleted
  CONFIG_SND_HDA_ENABLE_REALTEK_QUIRKS (FATE#313695).
- ALSA: HDA: Add inverted internal mic quirk for Lenovo S205
  (FATE#313695).
- ALSA: hda - Fix ALC272X codec detection (FATE#314311).
- ALSA: hda - Handle open while transitioning to D3 (FATE#313695).
- ALSA: hda - Don't forget to call init verbs added by fixup list
  (FATE#314311).
- ALSA: HDA: Pin fixup for Zotac Z68 motherboard (FATE#314311).
- ALSA: hda - Fix detection of Creative SoundCore3D controllers
  (FATE#313695).
- ALSA: hda/realtek - Add new codec support for ALC269VD
  (FATE#314311).
- commit 931ac57
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - add probe_mask=0x101 automatically for WinFast
  VP200 H (FATE#313695).
- ALSA: hda/realtek - Fix unused variable compile warning
  (FATE#314311).
- ALSA: hda - Fix possible races of accesses to connection list
  array (FATE#314106).
- ALSA: hda/idt - Cache the power-map bits.
- ALSA: hda/idt - Clean up power-map check code.
- commit 8df90cc
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Disable FLOAT format support (FATE#313695).
- ALSA: hda/conexant - Correct vendor IDs for new codecs
  (FATE#313695).
- ALSA: hda - Fix concurrent hash accesses (FATE#313695).
- ALSA: hda - Protect SPDIF-related stuff via spdif_mutex
  (FATE#313695).
- ALSA: hda - Add Conexant CX20751/2/3/4 codec support
  (FATE#313695).
- ALSA: hda - More robustify the power-up/down sequence
  (FATE#313695).
- ALSA: hda - Remove pre_resume and post_suspend ops
  (FATE#313695).
- ALSA: hda - Move BIOS pin-parser code to hda_auto_parser.c
  (FATE#314106).
- ALSA: hda - Move up the fixup helper functions to the library
  module (FATE#314311).
- commit 4faa0fd
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Protect the power-saving count with spinlock
  (FATE#313695).
- ALSA: hda - Clear the power-saving states properly at reset
  (FATE#313695).
- commit 68abf67
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Fix possible access to uninitialized work struct
  (FATE#313695).
- ALSA: hda/realtek - Call a common helper for alc_spec
  initialization (FATE#314311).
- ALSA: hda - Skip pin capability sanity check for bogus values
  (FATE#313695).
- ALSA: hda - Add snd_hda_get_default_vref() helper function
  (FATE#314106).
- ALSA: hda - Introduce snd_hda_set_pin_ctl*() helper functions
  (FATE#314106).
- ALSA: hda - Fix oops caused by recent commit "Fix internal
  mic for Lenovo Ideapad U300s" (FATE#313695).
- ALSA: hda - Fix internal mic for Lenovo Ideapad U300s
  (FATE#313695).
- commit ced41d4
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda/idt - Fix power-map for speaker-pins with some HP
  laptops (FATE#313695).
- ALSA: hda/realtek - Call alc_auto_parse_customize_define()
  always after fixup (FATE#314311).
- ALSA: hda/realtek - Add missing CD-input pin for MSI-7350 mobo
  (FATE#314311).
- ALSA: hda/realtek - Add a fixup for Acer Aspire 5739G
  (FATE#314311).
- ALSA: HDA: Add external mic quirk for Asus Zenbook UX31E
  (FATE#314311).
- ALSA: hda/conexant - Set up the missing docking-station pins
  (FATE#313695).
- commit 9d341ca
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda/sigmatel - Fix inverted mute LED (FATE#313695).
- ALSA: hda/realtek - Fix regression on Quanta/Gericom KN1
  (FATE#314311).
- ALSA: hda/realtek - Fix mem leak (and rid us of trailing
  whitespace) (FATE#314311).
- ALSA: hda/realtek - Add quirk for Mac Pro 5,1 machines
  (FATE#314311).
- ALSA: hda/realtek - Add a fixup entry for Acer Aspire 8940G
  (FATE#314311).
- ALSA: hda/realtek - Fix GPIO1 setup for Acer Aspire 4930 & co
  (FATE#314311).
- ALSA: hda/realtek - Add a few ALC882 model strings back
  (FATE#314311).
- ALSA: hda - hide HDMI/ELD printks unless snd.debug=2
  (FATE#313695).
- ALSA: hda - clean up CX20549 test mixer setup (FATE#313695).
- commit b5082a0
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - CX20549 doesn't need pin_amp_workaround
  (FATE#313695).
- ALSA: hda - Remove CD control from model=benq for CX20549
  (FATE#313695).
- ALSA: hda - fix record volume controls of CX20459 ("Venice")
  (FATE#313695).
- ALSA: hda - Rename capture sources of CX20549 to match common
  conventions (FATE#313695).
- ALSA: hda - Fix proc output for ADC amp values of CX20549
  (FATE#313695).
- ALSA: hda/realtek - Fix ADC assignment with a shared HP/Mic pin
  (FATE#314311).
- ALSA: hda - Fix build with CONFIG_PM=n (FATE#313695).
- ALSA: hda - Fix build of patch_sigmatel.c without
  CONFIG_SND_HDA_POWER_SAVE (FATE#313695).
- ALSA: hda - Add expose_enum_ctl flag to
  snd_hda_add_vmaster_hook() (FATE#314311).
- ALSA: hda - Add "Mute-LED Mode" enum control (FATE#314311).
- commit a186af0
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Add EAPD control to Conexnat auto-parser
  (FATE#313695).
- ALSA: hda - Rewrite the mute-LED control with vmaster hook
  for ALC269 (FATE#314311).
- ALSA: hda - Rewrite the mute-LED hook with vmaster hook in
  patch_sigmatel.c (FATE#313695).
- ALSA: hda - Return the created kcontrol in
  __snd_hda_add_vmaster() (FATE#313695).
- ALSA: hda - Initialize vmaster slave volumes (FATE#313695).
- commit 3a8daf6
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda/realtek - Reuse init_hook for ALC269VB coef setup
  (FATE#314311).
- ALSA: hda - Add Gigabyte GA-MA790X to the beep whitelist
  (FATE#314311).
- ALSA: hda - fix broken automute/autoswitch for Realtek
  (FATE#314311).
- ALSA: hda/conexant - Clear unsol events on unused pins
  (FATE#313695).
- commit b247c59
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Enable docking-station SPDIF for Thinkpad
  (FATE#313695).
- ALSA: hda - Add position_fix=4 (COMBO) option (FATE#313695).
- ALSA: hda - add id for Atom Cedar Trail HDMI codec
  (FATE#313695).
- ALSA: hda/via - Add a few sanity checks (FATE#314106).
- ALSA: hda/via - Don't create duplicated boost controls
  (FATE#314106).
- ALSA: hda/realtek - Small code cleanups (FATE#314311).
- ALSA: hda/realtek - Fix the wrong offset for two-speaker systems
  (FATE#314311).
- ALSA: hda/realtek - Fix the possible conflicts of Bass Speaker
  name (FATE#314311).
- ALSA: hda/realtek - Create individual mute switches for shared
  DAC (FATE#314311).
- commit ec10324
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda/realtek - Fix possible Oops with NULL input_mux
  (FATE#314311).
- ALSA: hda/realtek - Parse aa-loopback items dynamically
  (FATE#314106).
- ALSA: hda/realtek - Remove the last static quirks for ALC882
  (FATE#314311).
- ALSA: hda/realtek - Add model=fixup not to apply fix-ups
  (FATE#314311).
- ALSA: hda/realtek - Drop all ALC880 static quirks (FATE#314311).
- ALSA: hda/realtek - Drop model=asus* from ALC880 (FATE#314311).
- ALSA: hda/realtek - Rewrite ALC880 model=asus-w1v with
  auto-parser (FATE#314311).
- ALSA: hda/realtek - Rewrite ALC880 model=z71v with auto-parser
  (FATE#314311).
- ALSA: hda/realtek - Rewrite ALC880 model=uniwill-dig with
  auto-parser (FATE#314311).
- ALSA: hda/realtek - Rewrite ALC880 model=uniwill with
  auto-parser (FATE#314311).
- commit 16c8c38
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda/realtek - Rewrite ALC880 model=uniwill-p53 with
  auto-parser (FATE#314311).
- ALSA: hda/realtek - Rewrite ALC880 model=F1734 with auto-parser
  (FATE#314311).
- ALSA: hda/realtek - Rewrite ALC880 model=futjisu with
  auto-parser (FATE#314311).
- ALSA: hda/realtek - Apply probe-fixup really after probing
  (FATE#314311).
- ALSA: hda/realtek - Replace ALC880 model=tcl with auto-parser
  (FATE#314311).
- ALSA: hda/realtek - Drop ALC880 model=clevo (FATE#314311).
- ALSA: hda/realtek - Refactor the DAC filler function
  (FATE#314311).
- ALSA: hda/realtek - Rewrite ALC880 model=w810 with auto-parser
  (FATE#314311).
- ALSA: hda/realtek - Rewrite ALC880 model=lg with the auto-parser
  (FATE#314311).
- ALSA: hda/realtek - Adjust badness calculation for multi-ios
  (FATE#314311).
- commit 368d66d
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda/realtek - Show multi-io pins in debug prints.
- ALSA: hda/realtek - Try harder to fit the single-connections.
- ALSA: hda/realtek - Finer tuning of auto-parser with badness
  evaluation.
- ALSA: hda/realtek - Improve the signel-connection check.
- ALSA: hda/realtek - Disable static fixups for ASUS with ALC269.
- ALSA: hda/realtek - Remove leftover static quirks for ALC260.
- ALSA: hda/realtek - Drop model=fujitsu from ALC260 static
  quirks.
- ALSA: hda/realtek - Drop model=favorit100 for ALC260.
- ALSA: hda/realtek - Add the support for HP Presario B1900.
- ALSA: hda/realtek - Replace ALC260 model=replacer with the
  auto-parser.
- commit fa607ed
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda/realtek - Replace ALC260 model=acer with the
  auto-parser (FATE#314311).
- ALSA: hda/realtek - Add the fixup codes for ALC260 model=will
  (FATE#314311).
- ALSA: hda - Add another jack-detection suppression for ASUS
  ALC892 (FATE#314311).
- ALSA: hda - Suppress auto-mute feature on some machines with
  ALC861 (FATE#314311).
- ALSA: hda - Add codec->no_jack_detect flag (FATE#313695).
- ALSA: hda - Make is_jack_detectable() as non-inlined
  (FATE#313695).
- ALSA: hda - Add Lynx Point HD Audio Controller DeviceIDs
  (FATE#313695).
- ALSA: hda - Remove a debug print in vmaster code (FATE#313695).
- ALSA: hda - Add suffix argument to snd_hda_add_vmaster()
  (FATE#314106).
- ALSA: hda - Remove fallback to model=ideapad for Lenovo with
  cx5066 (FATE#313695).
- ALSA: hda - Enable sync_write and reset for Conexant codecs
  (FATE#313695).
- commit 0fdceae
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - explicitly set buffer-align flag for Nvidia
  controllers (FATE#313695).
- Refresh
  patches.drivers/alsa-sp2-hda-028-Add-the-support-for-Creative-SoundCore3D.
- commit 5ef5aa3
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda/realtek - Fix resume of multiple input sources
  (FATE#314311).
- ALSA: hda - Kill hyphenated names (FATE#314311).
- ALSA: hda - add quirk to detect CD input on Gigabyte EP45-DS3
  (FATE#314311).
- ALSA: hda - fix printing of high HDMI sample rates
  (FATE#313695).
- commit f0cd921
* Wed Oct 31 2012 jack@suse.cz
- patches.fixes/mm-Fix-XFS-oops-due-to-dirty-pages-without-buffers-o.patch:
  mm: Fix XFS oops due to dirty pages without buffers on s390
  (bnc#762259).
- commit 39b5bad
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda/realtek - Fix surround output regression on Acer
  Aspire 5935 (FATE#314311).
- ALSA: hda/realtek - Fix overflow of vol/sw check bitmap
  (FATE#314311).
- ALSA: hda - Fix silent speaker output on Acer Aspire 6935
  (FATE#314311).
- ALSA: hda - Fix initialization of secondary capture source on
  VT1705 (FATE#314106).
- ALSA: hda - add support for Uniwill ECS M31EI notebook
  (FATE#314311).
- ALSA: hda/realtek - Fix a wrong condition (FATE#314311).
- ALSA: hda/realtek - Add missing Bass and CLFE as vmaster slaves
  (FATE#314311).
- ALSA: hda - Disable dynamic-power control for VIA as default
  (FATE#314106).
- commit 5fedb5e
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Allow analog low-current mode when dynamic
  power-control is on (FATE#314106).
- ALSA: hda - Fix the logic to detect VIA analog low-current mode
  (FATE#314106).
- ALSA: hda - Check power-state before changing in patch_via.c
  (FATE#314106).
- ALSA: HDA: Remove quirk for Toshiba Qosmio G50 (FATE#314311).
- ALSA: HDA: Fix jack creation for codecs with front and rear
  Line In (FATE#313695).
- ALSA: hda - Apply 0x0f-VREF fix to all ASUS laptops with
  ALC861/660 (FATE#314311).
- ALSA: HDA: Remove quirk for Asus N53Jq (FATE#314311).
- ALSA: hda: set mute led polarity for laptops with buggy BIOS
  based on SSID (FATE#313695).
- ALSA: HDA: Use model=auto for Thinkpad T510 (FATE#313695).
- ALSA: hda - Fix buffer-alignment regression with Nvidia HDMI
  (FATE#313695).
- ALSA: hda - Fix a unused variable warning (FATE#314311).
- snd-hda-intel: better Alienware M17x R3 quirk (FATE#313695).
- ALSA: hda/realtek - Remove use_jack_tbl field (FATE#314311).
- ALSA: hda/realtek - Avoid conflict of unsol-events with static
  quirks (FATE#314311).
- ALSA: hda/realtek - Avoid multi-ios conflicting with
  multi-speakers (FATE#314311).
- ALSA: HDA: Use LPIB position fix for Macbook Pro 7,1
  (FATE#313695).
- commit f876054
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Fix the detection of "Loopback Mixing" control
  for VIA codecs (FATE#314106).
- ALSA: hda - Use auto-parser for HP laptops with cx20459 codec
  (FATE#313695).
- ALSA: HDA: Remove Poulsbo position fix quirks (FATE#313695).
- ALSA: HDA: Fix typo for ALC269VB_FIXUP_DMIC (FATE#314311).
- commit f2b7167
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: HDA: Use LPIB position fix for Oaktrail (FATE#313695).
- ALSA: hda_intel: Add Oaktrail identifiers (FATE#313695).
- ALSA: hda - Fix left-over merge issues in patch_hdmi.c
  (FATE#313695).
- ALSA: hda - Integrate input-jack stuff into kctl-jack
  (FATE#314311).
- ALSA: hda - Don't add channel suffix for headphone pin labels
  (FATE#313695).
- ALSA: hda - Fix a typo (FATE#313695).
- ALSA: hda - Give more unique names by snd_hda_get_pin_label()
  (FATE#313695).
- commit 2b3b1de
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Add missing initialization of kctl jack status
  (FATE#313695).
- ALSA: hda/jack - Fix the assignment of input jack-type
  (FATE#313695).
- ALSA: hda/jack - Fix NULL-dereference at probing (FATE#313695).
- ALSA: HDA: Jack: Export required functions from hda_jack.c
  (FATE#313695).
- ALSA: hda - Merge input-jack helpers to hda_jack.c
  (FATE#314311).
- ALSA: Introduce common helper functions for jack-detection
  control (FATE#313695).
- ALSA: hda - Manage unsol tags in hda_jack.c (FATE#314106).
- ALSA: hda - Create jack-detection kcontrols (FATE#314106).
- ALSA: hda - Cache the jack-detection value (FATE#314106).
- ALSA: hda - Introduce snd_hda_get_pin_label() (FATE#313695).
- commit 7d1c907
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: HDA: Use LPIB Position fix for Intel SCH Poulsbo
  (FATE#313695).
- ALSA: hda: fix mute led polarity for HP laptops with buggy BIOS
  (FATE#313695).
- ALSA: HDA: Set position fix to LPIB for an Atom/Poulsbo based
  device (FATE#313695).
- commit 29753a9
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Check non-snoop in a single place (FATE#313695).
- Refresh
  patches.drivers/alsa-sp2-hda-022-Add-support-for-new-AMD-products.
- commit 59f4c64
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda: remove unused quirk for inverted mute led
  (FATE#313695).
- commit 9d394f4
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: HDA: Realtek: Take vmaster dac from multiout dac list
  (FATE#314311).
- ALSA: hda/realtek - Fix lost speaker volume controls
  (FATE#314311).
- ALSA: hda/realtek - Create "Bass Speaker" for two speaker pins
  (FATE#314311).
- ALSA: hda/realtek - Don't create extra controls with channel
  suffix.
- ALSA: hda - Increase the max number of coverters/pins in
  patch_hdmi.c.
- ALSA: hda - Supports more audio streams.
- ALSA: hda/realtek - Move ALC880 model=medion-rim to auto-parser.
- ALSA: hda/realtek - Move ALC885 macpro and imac24 models
  to auto-parser.
- ALSA: hda/realtek - Re-add the model string selection for
  ALC88x.
- commit 0bbc99e
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda/realtek - Create mono volume controls for mono-outputs
  (FATE#314311).
- ALSA: hda/realtek - Rewrite ALC882 acer-aspire-* models with
  the auto-parser (FATE#314311).
- ALSA: hda/realtek - Create multi-io jacks more aggresively
  (FATE#314311).
- ALSA: hda/realtek - Drop ALC882 desktop model quirks
  (FATE#314311).
- ALSA: hda/realtek - Remove ALC882 targa-* models (FATE#314311).
- ALSA: hda/realtek - Reorder alc882_fixup_tbl[] (FATE#314311).
- ALSA: hda/realtek - Move ALC882 model=acer-aspire to auto-parser
  (FATE#314311).
- ALSA: hda/realtek - Replace ALC882 arima, medion and laptop-eapd
  quirks (FATE#314311).
- ALSA: hda/realtek - Drop ALC882 asus-a7j and asus-a7m models
  (FATE#314311).
- ALSA: hda/realtek - Look through codec SSID for fix-up lists
  (FATE#314311).
- ALSA: hda/realtek - Move ALC888 ASUS EEE1601 config to
  auto-parser (FATE#314311).
- ALSA: hda/realtek - Rewrite ALC882 model=vaio-tt with
  auto-parser (FATE#314311).
- commit 2bf3485
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda/realtek - Remove all ALC262-quirk codes (FATE#314311).
- ALSA: hda/realtek - Add the support of shared HP/Mic
  (FATE#314311).
- ALSA: hda/realtek - Drop ALC262 model=basic static configs
  (FATE#314311).
- ALSA: hda/realtek - Convert ALC262 model=fujitsu to auto-parser
  (FATE#314311).
- ALSA: hda/realtek - Convert ALC262 benq and benq-t31 to
  fixup-lists (FATE#314311).
- ALSA: hda/realtek - Convert ALC262 lenovo-3000 quirks to
  fixup-list (FATE#314311).
- commit de3ca8e
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda/realtek - Convert ALC262 model=toshiba-rx1 to a
  fixup-list (FATE#314311).
- ALSA: hda/realtek - Convert alc262 model=tyan to a fixup-list
  (FATE#314311).
- ALSA: hda_intel - revert a quirk that affect VIA chipsets
  (FATE#313695).
- ALSA: hda - Fix jack-detection control of VT1708 (FATE#314106).
- ALSA: hda/realtek - Minor cleanup (FATE#314311).
- ALSA: hda/realtek - Fix missing inits of item indices for
  auto-mic (FATE#314311).
- commit 2b49cc6
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Check subdevice mask in
  snd_hda_check_board_codec_sid_config() (FATE#313695).
- ALSA: hda - fail ELD reading early (FATE#313695).
- ALSA: hda - repoll ELD content for multiple times (FATE#313695).
- ALSA: hda - Add pin fix for Alienware M17x R3 (FATE#313695).
- ALSA: hda - move eld->spk_alloc fixup to hdmi_update_eld()
  (FATE#313695).
- ALSA: hda - delayed ELD repoll (FATE#313695).
- ALSA: hda - fix ELD memory leak (FATE#313695).
- ALSA: hda/realtek: remove redundant semicolon (FATE#314311).
- commit f1a5212
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Re-enable the check NO_PRESENCE misc bit
  (FATE#313695).
- ALSA: hda - fix internal mic on Dell Vostro 3500 laptop
  (FATE#313695).
- ALSA: HDA: Remove quirk for Toshiba T110 (FATE#313695).
- ALSA: hda - Mute unused capture sources for Realtek codecs
  (FATE#314311).
- ALSA: hda - Revert the check of NO_PRESENCE pincfg default bit
  (FATE#313695).
- ALSA: hda - Fix a regression for DMA-position check with CA0110
  (FATE#313695).
- ALSA: hda - Fix silent output regression with ALC861
  (FATE#314311).
- commit 7fab486
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Remove unused variables (FATE#314106).
- ALSA: hda/realtek - Don't create alt-stream for capture when
  unnecessary (FATE#314311).
- ALSA: hda - Check NO_PRESENCE pincfg default bit (FATE#313695).
- ALSA: hda_hwdep: Fix possible buffer overflow (FATE#313695).
- commit 4ea4fde
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Keep EAPD turned on for old Conexant chips
  (FATE#313695).
- ALSA: hda/realtek - Fix missing volume controls with ALC260
  (FATE#314311).
- ALSA: hda - Fix pin-config for ASUS W90V (FATE#314311).
- ALSA: hda - Fix surround/CLFE headphone and speaker pins order
  (FATE#313695).
- ALSA: hda/realtek - Fix DAC assignments of multiple speakers
  (FATE#314311).
- ALSA: hda/realtek - Cache COEF 0 value (FATE#314311).
- ALSA: hda/realtek - Clean up codec renames (FATE#314311).
- ALSA: hda/realtek - Use alc_codec_rename() (FATE#314311).
- ALSA: hda - ALC888S-VC remark to ALC886 (FATE#314311).
- ALSA: hda/realtek - Check the error from alc_codec_rename()
  (FATE#314311).
- ALSA: HDA: Fixup Realtek headphone pin initialization
  (FATE#314311).
- ALSA: hda - Distinguish each substream for better sticky
  assignment (FATE#313695).
- ALSA: hda - Fix a regression of the position-buffer check
  (FATE#313695).
- ALSA: hda/realtek - Choose more cleverly the primary outputs
  (FATE#314311).
- ALSA: hda - Moved snd_print_pcm_rates() back into hda_proc.c
  (FATE#313695).
- commit 59a5e6e
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hdmi: fix printout of SAD sampling rates (FATE#313695).
- ALSA: jack - Add "Line In" input jack constants (FATE#313695).
- ALSA: HDA: Fix naming of input jacks for IDT parser
  (FATE#313695).
- ALSA: hda/hdmi: expose ELD control (FATE#313695).
- ALSA: hda - Allow patching with any vendor/subsystem ids
  (FATE#313695).
- commit 56f214b
* Wed Oct 31 2012 tiwai@suse.de
- Refresh patches.drivers/alsa-sp2-hda-021-Add-snoop-option.
- commit f90969b
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda:via - Skip creations of empty PCM streams
  (FATE#314106).
- ALSA: hda - Avoid unnecessary verbs to clear PCM formats
  (FATE#313695).
- ALSA: hda/realtek - Don't detect LO jack when identical with HP
  (FATE#314311).
- commit 775823f
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: HDA - Add Independent Headphone for all models of
  ad1988/ad1989 (FATE#313695).
- ALSA: hda: hdmi: Hint matching between input devices and pcm
  devices (FATE#313695).
- ALSA: HDA: Refactor Realtek's automute (FATE#314311).
- ALSA: hda - Terminate the recursive connection search properly
  (FATE#313695).
- ALSA: hda: Conexant: Allow different output types to share DAC
  (FATE#313695).
- commit c0c8aed
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Add Headphone Playback Volume control for
  ad1988/ad1989 (FATE#313695).
- ALSA: hda - Remove the rest of ALC662 quirks (FATE#314311).
- ALSA: hda - Remove ALC662 ASUS eeepc-ep20 model quirk
  (FATE#313695).
- ALSA: hda - Prefer multi-io to speakers for realtek auto-parser
  (FATE#314311).
- ALSA: hda - Fix Center/LFE mixer element creations for Realtek
  (FATE#314311).
- ALSA: hda - Rewrite Lenovo X200 quirk with pincfg-fix using
  auto-parser (FATE#313695).
- ALSA: hda/conexant - Enable ADC-switching for auto-mic mode,
  too (FATE#313695).
- ALSA: hda - Remove ALC662 ASUS M51VA, G71V, H13 and G50V model
  quirks (FATE#313695).
- ALSA: hda - Rewrite ALC269 laptop-amic,dmic,&co quirks with
  fixups (FATE#314311).
- ALSA: hda - Rewrite ALC662 asus-mode* models with fixups
  (FATE#314311).
- ALSA: hda - Support multiple headphones in Realtek auto-parser
  (FATE#314311).
- ALSA: hda - Add multi-headphone NIDs in multiout struct
  (FATE#313695).
- ALSA: hda - Remove all ALC861 and ALC861-VD quirks
  (FATE#314311).
- ALSA: hda - Restore VREF50 setup for ALC861-VD dallas/hp models
  (FATE#314311).
- ALSA: hda - Rename to snd_hda_parse_pin_defcfg() (FATE#313695).
- ALSA: hda - Fix initialization of multi-speaker output paths
  for Realtek (FATE#314311).
- ALSA: hda - Fix double-headphone/speaker paths for Cxt
  auto-parser (FATE#313695).
- ALSA: hda - Update jack-sense info even when no automute is set
  (FATE#314311).
- ALSA: hda - Fix output-path initialization for Realtek
  auto-parser (FATE#314311).
- ALSA: hda - Fix error check from snd_hda_get_conn_index()
  in patch_cirrus.c (FATE#313695).
- commit a6f8b0b
* Wed Oct 31 2012 trenn@suse.de
- PCI/sysfs: add per pci device msi irq listing (v5) (bnc#748340).
- Refresh patches.xen/xen3-patch-2.6.22.
- commit 7afe641
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Don't spew too many ELD errors (FATE#313695).
- ALSA: hda - Add "PCM" volume to vmaster slave list
  (FATE#314311).
- ALSA: hda - Remove ALC662 model=levono-101e model quirk
  (FATE#313695).
- ALSA: hda - Allow different assoc numbers for multiple speakers
  (FATE#313695).
- ALSA: hda - Support multiple speakers by Realtek auto-parser
  (FATE#314311).
- ALSA: hda - Remove ALC662 eeepc-p701 and ecs models
  (FATE#314311).
- ALSA: hda - Get rid of left-over chunks by previous cleanups
  (FATE#313695).
- ALSA: hda - Remove ALC861 uniwill-m31, toshiba, asus and
  asus-laptop models (FATE#313695).
- ALSA: hda - Remove ALC268 model quirks (FATE#314311).
- ALSA: hda - Replace ALC269 quanta and lifebook models with
  fixups (FATE#314311).
- ALSA: hda - Remove ALC269 model=futjisu and Acer (FATE#313695).
- ALSA: hda - Remove acer, acer-aspire and acer-dmic models for
  ALC268 (FATE#313695).
- ALSA: hda - Remove dell, dell-zm1 and samsung-nc10 models for
  ALC272 (FATE#313695).
- ALSA: hda - Remove ALC680 model quirks (FATE#314311).
- ALSA: hda - Remove ALC268 Dell, Toshiba and Zapto model quirks
  (FATE#314311).
- ALSA: hda - Remove ALC260 HP model quirks (FATE#313695).
- ALSA: hda - Remove ALC262 HP and sony-assamd quirks
  (FATE#313695).
- ALSA: hda - Add snd_hda_override_pin_caps() helper function
  (FATE#313695).
- commit 79e78f0
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Fix a complile warning in patch_via.c (FATE#314106).
- ALSA: hda - Add tracepoint for unsolicited events (FATE#314311).
- ALSA: hda: option to enable arbitrary buffer/period sizes
  (FATE#314311).
- ALSA: hda - Add basic tracepoints (FATE#314311).
- ALSA: hda - Fix digital-mic mono recording on ASUS Eee PC
  (FATE#314311).
- ALSA: hda - Fix Oops with Realtek quirks with NULL adc_nids
  (FATE#314311).
- commit 84ca318
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Fix DAC filling for multi-connection pins in
  Realtek parser.
- ALSA: hda - Remove a superfluous argument of
  via_auto_init_output() (FATE#314310).
- ALSA: hda - Fix indep-HP path (de-)activation for VT1708*
  codecs (FATE#314310).
- commit b7a97e4
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Switch HP DAC dynamically with indep-HP switch
  for VIA (FATE#314310).
- ALSA: hda - Implement dynamic loopback control for VIA codecs
  (FATE#314310).
- ALSA: hda - Re-add need_dac_fix check for multi-io jacks of
  Realtek codecs.
- ALSA: hda - fix up typos in Kconfig help for default buffer
  size introduced in acfa634f.
- ALSA: hda - Add Kconfig for the default buffer size.
- ALSA: hda - Expose secret DAC-AA connection of some VIA codecs
  (FATE#314310).
- ALSA: hda - Always read raw connections for proc output.
- ALSA: hda - Add snd_hda_override_conn_list() helper function.
- ALSA: hda - Turn on extra EAPDs on Conexant codecs.
- ALSA: hda - Preserve input pin-ctl bits in HP-automute for
  VIA codec (FATE#314310).
- commit 4530768
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Set line-out pin-ctls properly when indep-HP mode
  changes (FATE#314310).
- ALSA: hda - Via Fix speaker-mute checks in VIA driver
  (FATE#314310).
- ALSA: hda - Implement 44kHz workaround for IdeadPad as fixup.
- ALSA: hda - Merge alc*_parse_auto_config() functions in
  patch_realtek.c.
- ALSA: hda - Merge ALC260 auto-parser code.
- ALSA: hda - Merge ALC269 parser code.
- ALSA: hda - Merge ALC268/269 auto-parser codes.
- ALSA: hda - Merge ALC861 auto-parser code.
- ALSA: hda - Fix amp-cap checks in patch_realtek.c.
- ALSA: hda - Merge ALC861-VD auto-parse to the standard parser.
- commit e34a736
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Fix auto-mic detection in Realtek codec-parser.
- ALSA: hda - Fix output-path of VT1812 codec (FATE#314310).
- ALSA: hda - Fix Oops in smart51 parsing in VIA codec
  (FATE#314310).
- ALSA: hda - Provide the standard auto_init for Realtek codecs.
- ALSA: hda - Merge ALC680 auto-parser to the standard parser.
- ALSA: hda - Fix Independent-HP detection on VT2002P/1802/1812
  codecs (FATE#314310).
- ALSA: hda - Fix DAC checks for VT2002P/1802/1812 codecs
  (FATE#314310).
- ALSA: hda - Fix VIA output-path init for VT2002P/1802/1812
  (FATE#314310).
- ALSA: hda - Split quirk codes from patch_realtek.c.
- commit 89ae963
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Use common paser for digital I/O for ALC260.
- ALSA: hda - More flexible dynamic-ADC switching for Realtek
  codecs.
- ALSA: hda - Fix warning with ALC882 digital-out detection.
- ALSA: hda - Clean-up PCM assignments in patch_realtek.c.
- ALSA: hda - Unify alc*_auto_init_input_src() in patch_realtek.c.
- ALSA: hda - Parse ADCs and CAPSRCs dynamically for Realtek
  auto-parser.
- ALSA: hda - Unify alc_auto_init_analog_input() calls.
- commit 20a177b
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Parse ADCs in alc_auto_create_input_ctls().
- commit bcecaea
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Code consolidation for ALC88x and ALC662
  auto-parsers.
- ALSA: hda - Create bind-mutes appropriately for ALC662
  auto-parser.
- commit d1ce946
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Initialize DACs in ALC662 auto-parser mode.
- ALSA: hda - Parse HP and speaker DACs even for multi connections
  for ALC662.
- ALSA: hda - Don't add aa-mix for VIA surrounds (FATE#314310).
- ALSA: hda - Create HP-vol control properly for VIA codecs
  (FATE#314310).
- commit 430d3fa
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Define some constants in patch_via.c (FATE#314310).
- ALSA: hda - Fix invalid multi-channel amplifiers for VT1718S
  (FATE#314310).
- ALSA: hda - Fix issue that front can't output sound for VT1718S
  (FATE#314310).
- ALSA: hda - Fix the silent front with independent-HP for VIA
  codecs (FATE#314310).
- ALSA: hda - Fix missing initialization in alc662 auto-parser.
- commit b2bb21e
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Re-implementation of VIA Independent-HP sharing
  with side stream (FATE#314310).
- ALSA: hda - Fix jack-detection on non-VT1708 VIA codecs
  (FATE#314310).
- ALSA: hda - Fix unused variable warning.
- ALSA: hda - Enable auto-parser as default for Conexant codecs.
- ALSA: hda - Create snd_hda_get_conn_index() helper function
  (FATE#314310).
- commit 36fe119
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Fix unsol event initializations for VIA codecs
  (FATE#314310).
- ALSA: hda - Fix warnings with CONFIG_SND_POWER_SAVE=n.
- ALSA: hda - remove SND_HDA_POWER_SAVE protection of struct
  hda_loopback_check.
- ALSA: hda - More volume-init fixes for ALC267 codec.
- ALSA: hda - Fix volume-init for ALC259 with invalid widget caps.
- commit 9e2671e
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Fix volume-init of ALC299 & co.
- ALSA: hda - Simplify EAPD control in patch_realtek.c.
- ALSA: hda - Fix auto-init of output volumes of Realtek codecs.
- ALSA: hda - Implement dynamic-ADC switching for VIA codecs
  (FATE#314310).
- ALSA: hda - Auto-mute smart51 surround pins for VIA codecs
  (FATE#314310).
- commit 2764b78
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Remove redundant VT1709 and VT1708B codes
  (FATE#314310).
- ALSA: hda - VT1708 independent HP routing fix (FATE#314310).
- ALSA: hda - Fix surround-volume parsing for VT1708B codecs
  (FATE#314310).
- ALSA: hda - Fix the check of loopback-mixer element index in
  patch_via.c (FATE#314310).
- ALSA: hda - Assign smart51 only in the same stack for VIA codecs
  (FATE#314310).
- commit 982c93e
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Fix re-routing of HP-independent mode in patch_via.c
  (FATE#314310).
- ALSA: hda - Fix creations of playback volume controls in
  patch_via.c (FATE#314310).
- ALSA: hda - Revisit output_path parsing in patch_via.c
  (FATE#314310).
- ALSA: hda - Use xxx Boost Volume for VIA (FATE#314310).
- ALSA: hda - Simplify analog-low-current mode check for VIA
  codecs (FATE#314310).
- commit c770b6f
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Remove NID_MAPPING hacks in patch_via.c
  (FATE#314310).
- ALSA: hda - Remove unused defines and struct fields in
  patch_via.c (FATE#314310).
- ALSA: hda - Name the primary out as Speaker when needed for
  VIA codecs (FATE#314310).
- ALSA: hda - Create loopback-list dynamically in patch_via.c
  (FATE#314310).
- ALSA: hda - Fix smart51 handling again (FATE#314310).
- ALSA: hda - Create virtual-master control for VIA codecs
  (FATE#314310).
- commit 7ca0c07
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Initialize unsol events dynamically in patch_via.c
  (FATE#314310).
- Refresh
  patches.drivers/alsa-sp2-hda-002-Make-CONFIG_SND_HDA_POWER_SAVE-depending.
- commit f011fdf
* Wed Oct 31 2012 tiwai@suse.de
- ALSA: hda - Initialize input-path dynamically in patch_via.c
  (FATE#314310).
- ALSA: hda - Initialize output path dynamically in patch_via.c
  (FATE#314310).
- ALSA: hda - Replace with standard consts in patch_via.c
  (FATE#314310).
- commit c008a5c
* Tue Oct 30 2012 brogers@suse.com
- patches.fixes/kvm-KVM-Clean-up-error-handling-during-VCPU-creation.patch:
  KVM: Clean up error handling during VCPU creation (bnc#754898
  CVE-2012-1601).
- patches.fixes/kvm-KVM-Ensure-all-vcpus-are-consistent-with-in-kernel-i.patch:
  KVM: Ensure all vcpus are consistent with in-kernel irqchip
  settings (bnc#754898 CVE-2012-1601).
- commit 9d44772
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda - Fix independent-HP handling in patch_via.c
  (FATE#314310).
- ALSA: hda - Unify auto-parser in patch_via.c (FATE#314310).
- ALSA: hda - Return error for invalid setup for VIA
  (FATE#314310).
- ALSA: hda - Unify capture-mixer creations in patch_via.c
  (FATE#314310).
- ALSA: hda - Assign HP-independent PCM to individual stream
  (FATE#314310).
- ALSA: hda - Unify PCM assignments in patch_via.c (FATE#314310).
- ALSA: hda - Don't create secondary substream when no
  independent-hp is used (FATE#314310).
- ALSA: hda - Re-implement smart51 detection for VIA codecs
  (FATE#314310).
- ALSA: hda - Unify output-control parsing in patch_via.c
  (FATE#314310).
- commit dbffaf8
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda - Unify input-volume creations in patch_via.c
  (FATE#314310).
- commit 631ce11
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda - Auto-mute all LO and speakers in patch_via.c
  (FATE#314310).
- ALSA: hda - Change pin-ctl for auto-muting in patch_via.c
  (FATE#314310).
- ALSA: hda - Generate PCM names dynamically in patch_via.c
  (FATE#314310).
- ALSA: hda - Refactor ctl array handling in patch_via.c
  (FATE#314310).
- ALSA: hda - Defer mixer element creation to the right time in
  patch_via.c (FATE#314310).
- ALSA: hda - Fill ADCs dynamically for VIA codecs (FATE#314310).
- ALSA: hda - Add control to suppress the dynamic pin-power for
  VIA (FATE#314310).
- ALSA: hda - Check hard-wired DACs at first for ALC662 & co.
- ALSA: hda - Call proper DAC-filler function for Realtek
  auto-parser.
- commit a26e68e
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda - Reduce static init verbs for Realtek auto-parsers.
- Refresh
  patches.drivers/alsa-sp2-hda-023-Add-Realtek-ALC269VC-codec-support.
- commit e491486
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda - Add snd_hda_get_conn_list() helper function.
- ALSA: hda - Use alc_get_pfx_name() for all Realtek codecs.
- ALSA: hda - Clean up multi-channel mixer name assignment in
  patch_realtek.c.
- ALSA: hda - Add a workaround for invalid line-out setups.
- ALSA: hda - Allow multi-io with HP output for ALC662 & co.
- ALSA: hda - Remove superfluous NID_MAPPING use for smart51 mixer
  (FATE#314310).
- commit 5abbe0e
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: HDA: Remove redundant LPIB quirks for ATI chipset.
- commit d0628d1
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda: check make_exec_verb() return value.
- commit be1d039
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda - Fix SSYNC register value for non-Intel controllers.
- Refresh
  patches.drivers/alsa-sp2-hda-028-Add-the-support-for-Creative-SoundCore3D.
- commit 5b30ee4
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda - Disable SPDIF only when no pin config set for HP
  with AD1981.
- commit a6048b1
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda - Judge playback stream from stream id in
  azx_via_get_position().
- commit 7730d64
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda - Handle -1 as invalid position, too.
- commit 585a621
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda: HDMI: Support codecs with fewer cvts than pins.
- commit 9773d87
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda: hdmi_eld_update_pcm_info: update a stream in place.
- commit ecb345c
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda: Separate generic and non-generic implementations.
- commit 56fdaf7
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda: Virtualize SPDIF out controls (FATE#314310).
- commit 723248a
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda: Allow multple SPDIF controls per codec (FATE#314310).
- commit 0dfce82
* Tue Oct 30 2012 tiwai@suse.de
- ALSA: hda: Gate ELD usage only by whether ELD is valid.
- commit c47d37b
* Tue Oct 30 2012 mmarek@suse.cz
- Remove duplicate entries from the rpm changelog.
- commit 7ad85dc
* Tue Oct 30 2012 mgorman@suse.de
- mm: page_alloc: Do not wake kswapd if the request is for THP but deferred -fix
- commit 572501e
* Tue Oct 30 2012 ptesarik@suse.cz
- patches.drivers/hpwdt_only_byte_reads_writes.patch: hpwdt:
  Only BYTE reads/writes to WD Timer port 0x72.
- commit 99a94ed
* Mon Oct 29 2012 jslaby@suse.cz
- Linux 3.0.49 (bnc#722560).
- patches.drivers/USB3-0148-xHCI-test-USB2-software-LPM.patch:
  Refresh.
- patches.drivers/USB3-0152-xHCI-fix-debug-message.patch: Refresh.
- patches.drivers/USB3-0158-usb-xhci-move-xhci_gen_setup-away-from-pci.patch:
  Refresh.
- patches.fixes/0001-USB-fix-resource-leak-in-xhci-power-loss-path.patch:
  Refresh.
- patches.fixes/xhci-Don-t-free-endpoints-in-xhci_mem_cleanup:
  Refresh.
- patches.kabi/revert-net-fix-NULL-dereferences-in-check_peer_redir.patch:
  Refresh.
- patches.drivers/drm-i915-apply-timing-generator-bug-workaround-on-CP:
  Delete.
- commit 1f23eb1
* Mon Oct 29 2012 jslaby@suse.cz
- Linux 3.0.48.
- commit d096d32
* Mon Oct 29 2012 mkubecek@suse.cz
- patches.fixes/inetpeer-make-unused_peers-list-per-netns.patch:
  fix parts depending on removed kABI fix
- commit 9cd16a0
* Mon Oct 29 2012 jbeulich@novell.com
- patches.xen/1198-xenbus-dev-write-buflen.patch: xenbus: fix
  overflow check in xenbus_dev_write().
- patches.xen/1202-x86-signal-eip-corruption.patch: x86: don't
  corrupt %%eip when returning from a signal handler.
- Update Xen patches to 3.0.46.
- commit 16e75e2
* Fri Oct 26 2012 mgorman@suse.de
- patches.fixes/mm-check-if-PTE-is-already-allocated-during-page-fault.patch:
  mm: Check if PTE is already allocated during page fault.
- commit a0b0b60
* Thu Oct 25 2012 mmarek@suse.cz
- Move rpm changelog to kernel-source.changes.old
- commit b22dd51
* Wed Oct 24 2012 eich@suse.com
- patches.drivers/drm-radeon-fix-panic-on-unload.patch: Refresh:
  updated upstream commit info.
* Wed Oct 24 2012 eich@suse.com
- patches.drivers/drm-intel-do-not-delete-dpll-multiplier-during-dac-init.patch:
  Refresh: Added upstream commit note.
* Wed Oct 24 2012 eich@suse.com
- patches.drivers/DRM-i915-Restore-sdvo_flags-after-dtd-mode-dtd-Roundrtrip.patch:
  DRM/i915: Restore sdvo_flags after dtd->mode->dtd Roundrtrip
  (bnc #775577).
* Wed Oct 24 2012 eich@suse.com
- patches.drivers/DRM-i915-Don-t-clone-SDVO-LVDS-with-analog.patch:
  DRM/i915: Don't clone SDVO LVDS with analog (bnc #766410).
* Wed Oct 24 2012 eich@suse.com
- patches.drivers/drm_i915_Fix_backlight_control_for_systems_which_have_bl_polarity_reversed.patch:
  Refresh: Add mainline notice.
* Wed Oct 24 2012 jbeulich@novell.com
- Update Xen patches to 3.0.46 and c/s 1202.
- Update Xen config files.
* Mon Oct 22 2012 jslaby@suse.cz
- Linux 3.0.47 (bnc#731739).
- patches.drivers/0184-tg3-Remove-40BIT_DMA_LIMIT_BUG.patch:
  Refresh.
- patches.drivers/0185-tg3-Remove-4G_DMA_BNDRY_BUG-flag.patch:
  Refresh.
- patches.drivers/tg3-break-larger-frags-into-4k-chunks-for-5719:
  Refresh.
- patches.fixes/x86_acer_acpi_ec_call_reg_blacklist.patch:
  Refresh.
- patches.suse/0001-Revert-x86-random-Verify-RDRAND-functionality-and-al.patch:
  Revert "x86, random: Verify RDRAND functionality and allow it
  to be disabled".
- patches.suse/0002-Revert-x86-random-Architectural-inlines-to-get-rando.patch:
  Revert "x86, random: Architectural inlines to get random
  integers with RDRAND".
- patches.drivers/drm-radeon-fix-panic-on-unload.patch: Delete.
- Update config files.
- commit b752562
* Sun Oct 21 2012 mmarek@suse.cz
- patches.drivers/0001-xhci-Fix-DIV_ROUND_UP-compile-error.patch:
  xhci: Fix DIV_ROUND_UP compile error.
* Sat Oct 20 2012 jjolly@suse.de
- patches.arch/s390-59-01-qeth_Fix_IPA_CMD_QIPASSIST_rc_handling.patch:
  qeth: Fix IPA_CMD_QIPASSIST return code handling
  (bnc#785851,LTC#86101).
* Fri Oct 19 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Ignore kabi errors if
  %%%%ignore_kabi_badness is defined. This is used in the Kernel:*
  projects in the OBS.
* Thu Oct 18 2012 oneukum@suse.de
- patches.drivers/0001-USB-Add-helper-macro-for-usb_driver-boilerplate.patch:
  USB: Add helper macro for usb_driver boilerplate (FATE#313675).
- patches.drivers/0001-driver-core-Allow-additional-parameters-for-module_d.patch:
  driver-core: Allow additional parameters for module_driver
  (FATE#313675).
- patches.drivers/0001-drivercore-Generalize-module_platform_driver.patch:
  drivercore: Generalize module_platform_driver (FATE#313675).
- patches.drivers/0001-kernel-doc-fix-new-warnings-in-device.h.patch:
  kernel-doc: fix new warnings in device.h (FATE#313675).
* Thu Oct 18 2012 oneukum@suse.de
- patches.drivers/0001-USB-Add-macros-for-interrupt-endpoint-types.patch:
  USB: Add macros for interrupt endpoint types (FATE#313675).
- patches.drivers/0001-USB-Add-support-to-enable-disable-USB3-link-states.patch:
  USB: Add support to enable/disable USB3 link states
  (FATE#313675).
- patches.drivers/0001-USB-Allow-drivers-to-disable-hub-initiated-LPM.patch:
  USB: Allow drivers to disable hub-initiated LPM (FATE#313675).
- patches.drivers/0001-USB-Calculate-USB-3.0-exit-latencies-for-LPM.patch:
  USB: Calculate USB 3.0 exit latencies for LPM (FATE#313675).
- patches.drivers/0001-USB-Disable-USB-3.0-LPM-in-critical-sections.patch:
  USB: Disable USB 3.0 LPM in critical sections (FATE#313675).
- patches.drivers/0001-USB-Disable-hub-initiated-LPM-for-comms-devices.patch:
  USB: Disable hub-initiated LPM for comms devices (FATE#313675).
- patches.drivers/0001-USB-Fix-core-compile-with-CONFIG_USB_SUSPEND-n.patch:
  USB: Fix core compile with CONFIG_USB_SUSPEND=n (FATE#313675).
- patches.drivers/0001-USB-Make-sure-to-fetch-the-BOS-desc-for-roothubs.patch:
  USB: Make sure to fetch the BOS desc for roothubs (FATE#313675).
- patches.drivers/0001-USB-Refactor-code-to-set-LPM-support-flag.patch:
  USB: Refactor code to set LPM support flag (FATE#313675).
- patches.drivers/0001-USB-convert-drivers-bluetooth-to-use-module_usb_driv.patch:
  USB: convert drivers/bluetooth/* to use module_usb_driver()
  (FATE#313675).
- patches.drivers/0001-USB-convert-drivers-net-to-use-module_usb_driver.patch:
  USB: convert drivers/net/* to use module_usb_driver()
  (FATE#313675).
- patches.drivers/0001-USB-convert-some-miscellanies-drivers-to-use-module_.patch:
  USB: convert some miscellanies drivers to use
  module_usb_driver() (FATE#313675).
- patches.drivers/0001-usb-ch9-define-Set-SEL-and-Set-Isoch-Delay-macros.patch:
  usb: ch9: define Set SEL and Set Isoch Delay macros
  (FATE#313675).
- patches.drivers/0001-usb-host-xhci-Fix-Compliance-Mode-on-SN65LVPE502CP-H.patch:
  Refresh.
- patches.drivers/0001-xhci-Add-Intel-U1-U2-timeout-policy.patch:
  xhci: Add Intel U1/U2 timeout policy (FATE#313675).
- patches.drivers/0001-xhci-Add-infrastructure-for-host-specific-LPM-polici.patch:
  xhci: Add infrastructure for host-specific LPM policies
  (FATE#313675).
- patches.drivers/0001-xhci-Add-roothub-code-to-set-U1-U2-timeouts.patch:
  xhci: Add roothub code to set U1/U2 timeouts (FATE#313675).
- patches.drivers/0001-xhci-Fix-compile-with-CONFIG_USB_SUSPEND-n.patch:
  xhci: Fix compile with CONFIG_USB_SUSPEND=n (FATE#313675).
- patches.drivers/0001-xhci-Reserve-one-command-for-USB3-LPM-disable.patch:
  xhci: Reserve one command for USB3 LPM disable (FATE#313675).
- patches.drivers/0001-xhci-Some-Evaluate-Context-commands-must-succeed.patch:
  xhci: Some Evaluate Context commands must succeed (FATE#313675).
* Thu Oct 18 2012 jkosina@suse.cz
- rpm/kernel-binary.spec.in: Revert f266e647f to allow building with
  icecream again, as patches.rpmify/kbuild-fix-gcc-x-syntax.patch is
  a real fix now.
* Thu Oct 18 2012 mmarek@suse.cz
- Delete patches.kabi/* workarounds.
* Wed Oct 17 2012 dsterba@suse.cz
- patches.suse/btrfs-8112-resume-balance-on-rw-re-mounts-properly.patch:
  fix mismerge.
* Wed Oct 17 2012 jdelvare@suse.de
- patches.kabi/ipmi-use-a-tasklet-for-handling-received-messages-kABI.patch:
  Fix ipmi-use-a-tasklet-for-handling-received-messages.patch
  kABI breakage.
* Wed Oct 17 2012 jdelvare@suse.de
- patches.fixes/ipmi-decrease-the-ipmi-message-transaction-time-in-interrupt-mode.patch:
  ipmi: decrease the IPMI message transaction time in interrupt
  mode (bnc#763654).
- patches.fixes/ipmi-simplify-locking.patch: ipmi: simplify
  locking (bnc#763654).
- patches.fixes/ipmi-use-a-tasklet-for-handling-received-messages.patch:
  ipmi: use a tasklet for handling received messages (bnc#763654).
- patches.fixes/ipmi-fix-deadlock-in-start_next_msg.patch: Delete.
* Wed Oct 17 2012 jjolly@suse.de
- patches.drivers/cxgb3-set-vlan_feature-on-net_device.patch:
  cxgb3: Set vlan_feature on net_device (bnc#776127, LTC#84260).
* Wed Oct 17 2012 jjolly@suse.de
- patches.drivers/qlge-add-offload-features-to-vlan-interfaces.patch:
  Add offload features to vlan interfaces (bnc#776081,LTC#84322).
* Wed Oct 17 2012 jjolly@suse.de
- patches.drivers/0001-mlx4_en-Added-missing-iounmap-upon-releasing-a-devic.patch:
  mlx4_en: Added missing iounmap upon releasing a device
  (bnc#774964,LTC#82768).
- patches.drivers/0002-mlx4-allow-device-removal-by-fixing-dma-unmap-size.patch:
  mlx4: allow device removal by fixing dma unmap size
  (bnc#774964,LTC#82768).
* Wed Oct 17 2012 mmarek@suse.cz
- Delete patches.kabi/* workarounds.
* Tue Oct 16 2012 jslaby@suse.de
- patches.drivers/sfc-prevent-extreme-TSO-parameters-from-stalling-TX-.patch:
  Delete.
  This is fixed in a different way upstream (by -stable patches).
* Tue Oct 16 2012 jjolly@suse.de
- patches.arch/s390-58-01-qeth-recovery-bonding_deadlock.patch:
  qeth: fix deadlock between recovery and bonding driver
  (bnc#785100,LTC#85905).
* Tue Oct 16 2012 jslaby@suse.de
- patches.kernel.org/0001-Revert-tcp-Apply-device-TSO-segment-limit-earlier.patch:
  Delete.
- patches.kernel.org/0002-Revert-sfc-Fix-maximum-number-of-TSO-segments-and-mi.patch:
  Delete.
- patches.kernel.org/0003-Revert-net-Allow-driver-to-limit-number-of-GSO-segme.patch:
  Delete.
  These were not applied due to kabi breakage and no known workaround
  was available.
* Tue Oct 16 2012 jslaby@suse.de
- patches.kernel.org/revert-net-fix-a-potential-rcu_read_lock-imbalance-i.patch:
  Delete.
  This one was there to support kabi reverts. No longer needed.
* Tue Oct 16 2012 jslaby@suse.de
- patches.kernel.org/0001-Revert-i387-re-introduce-FPU-state-preloading-at-con.patch:
  Delete.
- patches.kernel.org/0002-Revert-i387-move-TS_USEDFPU-flag-from-thread_info-to.patch:
  Delete.
- patches.kernel.org/0003-Revert-i387-move-AMD-K7-K8-fpu-fxsave-fxrstor-workar.patch:
  Delete.
- patches.kernel.org/0004-Revert-i387-do-not-preload-FPU-state-at-task-switch-.patch:
  Delete.
- patches.kernel.org/0005-Revert-i387-don-t-ever-touch-TS_USEDFPU-directly-use.patch:
  Delete.
- patches.kernel.org/0006-Revert-i387-move-TS_USEDFPU-clearing-out-of-__save_i.patch:
  Delete.
- patches.kernel.org/0007-Revert-i387-fix-x86-64-preemption-unsafe-user-stack-.patch:
  Delete.
- patches.kernel.org/0008-Revert-i387-fix-sense-of-sanity-check.patch:
  Delete.
- patches.kernel.org/0009-Revert-i387-make-irq_fpu_usable-tests-more-robust.patch:
  Delete.
- patches.kernel.org/0010-Revert-i387-math_state_restore-isn-t-called-from-asm.patch:
  Delete.
  The FPU fixes. They are very appropriate for SP3. They should be in
  SP2 already, but they were too intrusive and break XEN. Yes, I know,
  I break XEN now. Jan, please fix, as I failed to do so.
* Tue Oct 16 2012 jslaby@suse.de
  Remove ASPM reverts, for SP3 they are fine.
- patches.kernel.org/revert-ASPM-Fix-pcie-devices-with-non-pcie-children.patch:
  Delete.
- patches.kernel.org/revert-PCI-Rework-ASPM-disable-code.patch:
  Delete.
- patches.kernel.org/revert-PCI-ignore-pre-1.1-ASPM-quirking-when-ASPM-is.patch:
  Delete.
* Tue Oct 16 2012 oneukum@suse.de
- patches.drivers/0001-usb-host-xhci-Fix-Compliance-Mode-on-SN65LVPE502CP-H.patch:
  usb: host: xhci: Fix Compliance Mode on SN65LVPE502CP Hardware
  (FATE#314292).
* Tue Oct 16 2012 lduncan@suse.de
- patches.fixes/st-add-st-nowait-eof-param-to-module: SCSI st:
  add st_nowait_eof param to module (bnc#775394).
* Mon Oct 15 2012 dsterba@suse.cz
- patches.suse/btrfs-8161-do-not-allocate-chunks-as-agressively.patch:
  Btrfs: do not allocate chunks as agressively (FATE#306586).
- patches.suse/btrfs-8162-btrfs_drop_extent_cache-should-never-fail.patch:
  Btrfs: btrfs_drop_extent_cache should never fail (FATE#306586).
- patches.suse/btrfs-8163-fix-full-backref-problem-when-inserting-shared.patch:
  Btrfs: fix full backref problem when inserting shared block
  reference (FATE#306586).
- patches.suse/btrfs-8164-wait-on-async-pages-when-shrinking-delalloc.patch:
  Btrfs: wait on async pages when shrinking delalloc
  (FATE#306586).
- patches.suse/btrfs-8165-remove-bytes-argument-from-do_chunk_alloc.patch:
  Btrfs: remove bytes argument from do_chunk_alloc (FATE#306586).
- patches.suse/btrfs-8166-cleanup-of-error-processing-in-btree_get_exten.patch:
  Btrfs: cleanup of error processing in btree_get_extent()
  (FATE#306586).
- patches.suse/btrfs-8167-remove-unnecessary-code-in-btree_get_extent.patch:
  Btrfs: remove unnecessary code in btree_get_extent()
  (FATE#306586).
- patches.suse/btrfs-8168-kill-obsolete-arguments-in-btrfs_wait_ordered_.patch:
  Btrfs: kill obsolete arguments in btrfs_wait_ordered_extents
  (FATE#306586).
- patches.suse/btrfs-8169-don-t-do-anything-in-our-freeze_fs-and-unfreez.patch:
  Btrfs: don't do anything in our ->freeze_fs and ->unfreeze_fs
  (FATE#306586).
- patches.suse/btrfs-8170-do-not-async-metadata-csumming-in-certain-situ.patch:
  Btrfs: do not async metadata csumming in certain situations
  (FATE#306586).
- patches.suse/btrfs-8171-do-not-hold-the-file-extent-leaf-locked-when-a.patch:
  Btrfs: do not hold the file extent leaf locked when adding
  extent item (FATE#306586).
- patches.suse/btrfs-8172-cache-extent-state-when-writing-out-dirty-meta.patch:
  Btrfs: cache extent state when writing out dirty metadata pages
  (FATE#306586).
- patches.suse/btrfs-8173-don-t-lookup-csums-for-prealloc-extents.patch:
  Btrfs: don't lookup csums for prealloc extents (FATE#306586).
- patches.suse/btrfs-8174-be-smarter-about-dropping-things-from-the-tree.patch:
  Btrfs: be smarter about dropping things from the tree log
  (FATE#306586).
- patches.suse/btrfs-8175-confirmation-of-value-is-added-before-trace_bt.patch:
  Btrfs: confirmation of value is added before
  trace_btrfs_get_extent() is called (FATE#306586).
- patches.suse/btrfs-8176-make-filesystem-read-only-when-submitting-barr.patch:
  Btrfs: make filesystem read-only when submitting barrier fails
  (FATE#306586).
- patches.suse/btrfs-8177-cleanup-pages-properly-when-ENOMEM-in-compress.patch:
  Btrfs: cleanup pages properly when ENOMEM in compression
  (FATE#306586).
- patches.suse/btrfs-8178-don-t-bug-on-enomem-in-readpage.patch:
  Btrfs: don't bug on enomem in readpage (FATE#306586).
- patches.suse/btrfs-8179-do-not-warn_on-when-we-cannot-alloc-a-page-for.patch:
  Btrfs: do not warn_on when we cannot alloc a page for an extent
  buffer (FATE#306586).
- patches.suse/btrfs-enospc-debugging-messages.patch: btrfs:
  enospc debugging messages (FATE#306586).
* Mon Oct 15 2012 mmarek@suse.cz
- Delete kabi files.
* Mon Oct 15 2012 mmarek@suse.cz
- Delete kabi workarounds.
- patches.fixes/ipv6-dont-use-inetpeer-to-store-metrics-for-routes.patch:
  Refresh.
- patches.fixes/ipv6-fix-problem-with-expired-dst-cache.patch:
  Refresh.
- patches.fixes/ipv6-unshare-inetpeers.patch: Refresh.
- patches.suse/perfmon2.patch: Refresh.
- patches.fixes/inetpeer-add-namespace-support-for-inetpeer.patch:
  Temporarily disable.
- patches.fixes/inetpeer-add-parameter-net-for-inet_getpeer_v4-v6.patch:
  Temporarily disable.
- patches.fixes/inetpeer-make-unused_peers-list-per-netns.patch:
  Temporarily disable.
* Mon Oct 15 2012 mmarek@suse.cz
- Move patches adding kabi placeholders to patches.suse, because
  we want to keep them across service packs:
  patches.suse/kabi-add-padding-to-some-important-structures
  patches.suse/kabi-add-padding-to-usb-host-structures-for-potential-security-fixes.patch
* Mon Oct 15 2012 mmarek@suse.cz
- rpm/config.sh: Build against SP3 in the ibs.
* Mon Oct 15 2012 jslaby@suse.de
- Linux 3.0.46 (bnc#781484 bnc#741814 bnc#730660 bnc#777024 bnc#774859
  bnc#780012 LTC#84816 LTC#84941 LTC#84942 LTC#85285).
- patches.kabi/kabi-protect-struct-xfrm_replay.patch: kABI:
  protect struct xfrm_replay.
- patches.fixes/pci-hotplug-do-not-register-pcie-ports-for-acpiphp.patch:
  Refresh.
- patches.arch/s390-56-01-zfcp-make-trace-record-tags-unique.patch:
  Delete.
- patches.arch/s390-56-02-zfcp-do-not-wakeup-while-suspended.patch:
  Delete.
- patches.arch/s390-56-03-zfcp-restore-port-refcount-check.patch:
  Delete.
- patches.arch/s390-57-01-zfcp-sdev-crash.patch: Delete.
- patches.drivers/r8169-fix-Config2-MSIEnable-bit-setting.patch:
  Delete.
- patches.drivers/tg3-Fix-TSO-CAP-for-5704-devs-w-ASF-enabled.patch:
  Delete.
- patches.fixes/mm-mempolicy-fix-a-memory-corruption-by-refcount-imbalance-in-alloc_pages_vma.patch:
  Delete.
- patches.fixes/mm-mempolicy-fix-a-race-in-shared_policy_replace.patch:
  Delete.
- patches.fixes/mm-mempolicy-fix-refcount-leak-in-mpol_set_shared_policy.patch:
  Delete.
- patches.fixes/mm-mempolicy-remove-mempolicy-sharing.patch:
  Delete.
- patches.fixes/mm-revert-mm-mempolicy-Let-vma_merge-and-vma_split-handle-vma-vm_policy-linkages.patch:
  Delete.
- patches.fixes/net-do-not-disable-sg-for-packets-requiring-no-check.patch:
  Delete.
- patches.fixes/tcp-flush-DMA-queue-before-sk_wait_data-if-rcv_wnd-i.patch:
  Delete.
- patches.fixes/zfcp-remove-invalid-list-iterator.patch: Delete.
* Mon Oct 15 2012 mgalbraith@suse.de
- Correct bnc typo 773688 -> 773699
- patches.fixes/sched-fix-migration-thread-accounting-woes.patch:
  Update references (bnc#773699, bnc#769251).
* Mon Oct 15 2012 jslaby@suse.de
- Linux 3.0.45 (bnc#784334).
- patches.fixes/dm-use-done-bytes-for-io-completion.patch:
  Refresh.
- patches.xen/pci-reserve: Refresh.
- patches.fixes/scsi_dh_alua-Enable-STPG-for-unavailable-ports.patch:
  Delete.
* Fri Oct 12 2012 jjolly@suse.de
- patches.drivers/rds-no-bug-in-xmit-for-loopback.patch: kernel:
  rds-ping triggering a BUG_ON() (bnc#767610,CVE-2012-2372).
* Thu Oct 11 2012 sjayaraman@suse.de
- supported.conf: mark cachefiles as supported (FATE#312793, bnc#782369).
* Thu Oct 11 2012 jack@suse.cz
- patches.fixes/ext4-race-condition-protection-for-ext4_convert_unwr.patch:
  ext4: race-condition protection for
  ext4_convert_unwritten_extents_endio (bnc#784192).
- commit 28797a7
* Thu Oct 11 2012 mgorman@suse.de
- patches.suse/mm-Serialize-access-to-min_free_kbytes.patch:
  mm: Serialize access to min_free_kbytes.
- patches.suse/mm-account-for-the-number-of-times-direct-reclaimers-get-throttled.patch:
  mm: account for the number of times direct reclaimers get throttled.
- patches.suse/mm-add-support-for-a-filesystem-to-activate-swap-files-and-use-direct_IO-for-writing-swap-pages.patch:
  mm: add support for a filesystem to activate swap files and use direct_IO for writing swap pages.
- patches.suse/mm-add-support-for-direct_IO-to-highmem-pages.patch:
  mm: add support for direct_IO to highmem pages.
- patches.suse/mm-allow-PF_MEMALLOC-from-softirq-context.patch:
  mm: allow PF_MEMALLOC from softirq context.
- patches.suse/mm-correct-page--pfmemalloc-to-fix-deactivate_slab-regression.patch:
  mm: correct page->pfmemalloc to fix deactivate_slab regression.
- patches.suse/mm-for-pinning-of-kernel-addresses-for-I-O.patch:
  mm: add get_kernel_page[s] for pinning of kernel addresses for I/O.
- patches.suse/mm-ignore-mempolicies-when-using-ALLOC_NO_WATERMARK.patch:
  mm: ignore mempolicies when using ALLOC_NO_WATERMARK.
- patches.suse/mm-introduce-__GFP_MEMALLOC-to-allow-access-to-emergency-reserves.patch:
  mm: introduce __GFP_MEMALLOC to allow access to emergency reserves.
- patches.suse/mm-methods-for-teaching-filesystems-about-PG_swapcache-pages.patch:
  mm: methods for teaching filesystems about PG_swapcache pages.
- patches.suse/mm-micro-optimise-slab-to-avoid-a-function-call.patch:
  mm: micro-optimise slab to avoid a function call.
- patches.suse/mm-nbd-set-SOCK_MEMALLOC-for-access-to-PFMEMALLOC-reserves.patch:
  nbd: set SOCK_MEMALLOC for access to PFMEMALLOC reserves.
- patches.suse/mm-net-introduce-sk_gfp_atomic-to-allow-addition-of-GFP-flags-depending-on-the-individual-socket.patch:
  net: introduce sk_gfp_atomic() to allow addition of GFP flags depending on the individual socket.
- patches.suse/mm-netvm-allow-skb-allocation-to-use-PFMEMALLOC-reserves.patch:
  netvm: allow skb allocation to use PFMEMALLOC reserves.
- patches.suse/mm-netvm-allow-the-use-of-__GFP_MEMALLOC-by-specific-sockets.patch:
  netvm: allow the use of __GFP_MEMALLOC by specific sockets.
- patches.suse/mm-netvm-prevent-a-stream-specific-deadlock.patch:
  netvm: prevent a stream-specific deadlock.
- patches.suse/mm-netvm-propagate-page--pfmemalloc-from-netdev_alloc_page-to-skb.patch:
  netvm: Propagate page->pfmemalloc from netdev_alloc_page to skb.
- patches.suse/mm-netvm-propagate-page--pfmemalloc-to-skb.patch:
  netvm: propagate page->pfmemalloc to skb.
- patches.suse/mm-netvm-set-PF_MEMALLOC-as-appropriate-during-SKB-processing.patch:
  netvm: set PF_MEMALLOC as appropriate during SKB processing.
- patches.suse/mm-nfs-disable-data-cache-revalidation-for-swapfiles.patch:
  nfs: disable data cache revalidation for swapfiles.
- patches.suse/mm-nfs-enable-swap-on-NFS.patch:
  nfs: enable swap on NFS.
- patches.suse/mm-nfs-prevent-page-allocator-recursions-with-swap-over-NFS..patch:
  nfs: prevent page allocator recursions with swap over NFS.
- patches.suse/mm-nfs-teach-the-NFS-client-how-to-treat-PG_swapcache-pages.patch:
  nfs: teach the NFS client how to treat PG_swapcache pages.
- patches.suse/mm-only-set-page--pfmemalloc-when-ALLOC_NO_WATERMARKS-was-used.patch:
  mm: only set page->pfmemalloc when ALLOC_NO_WATERMARKS was used.
- patches.suse/mm-selinux-tag-avc-cache-alloc-as-non-critical.patch:
  selinux: tag avc cache alloc as non-critical.
- patches.suse/mm-sl[au]b-add-knowledge-of-PFMEMALLOC-reserve-pages.patch:
  mm: sl[au]b: add knowledge of PFMEMALLOC reserve pages.
- patches.suse/mm-slab-do-ClearSlabPfmemalloc-for-all-pages-of-slab.patch:
  slab: do ClearSlabPfmemalloc() for all pages of slab.
- patches.suse/mm-slab-fix-starting-index-for-finding-another-object.patch:
  slab: fix starting index for finding another object.
- patches.suse/mm-swap-implement-generic-handler-for-swap_activate.patch:
  mm: swap: implement generic handler for swap_activate.
- patches.suse/mm-swapfile-avoid-dereferencing-bd_disk-during-swap_entry_free-for-network-storage.patch:
  swapfile: avoid dereferencing bd_disk during swap_entry_free for network storage.
- patches.suse/mm-throttle-direct-reclaimers-if-PF_MEMALLOC-reserves-are-low-and-swap-is-backed-by-network-storage.patch:
  mm: throttle direct reclaimers if PF_MEMALLOC reserves are low and swap is backed by network storage.
- patches.suse/SoN-0001-mm-Serialize-access-to-min_free_kbytes.patch:
  Delete.
- patches.suse/SoN-0002-mm-sl-au-b-Add-knowledge-of-PFMEMALLOC-reserve-pages.patch:
  Delete.
- patches.suse/SoN-0003-mm-Introduce-__GFP_MEMALLOC-to-allow-access-to-emerg.patch:
  Delete.
- patches.suse/SoN-0004-mm-allow-PF_MEMALLOC-from-softirq-context.patch:
  Delete.
- patches.suse/SoN-0004a-mm-allow-PF_MEMALLOC-from-softirq-context.patch:
  Delete.
- patches.suse/SoN-0005-mm-Ignore-mempolicies-when-using-ALLOC_NO_WATERMARK.patch:
  Delete.
- patches.suse/SoN-0006-net-Introduce-sk_allocation-to-allow-addition-of-GFP.patch:
  Delete.
- patches.suse/SoN-0007-netvm-Allow-the-use-of-__GFP_MEMALLOC-by-specific-so.patch:
  Delete.
- patches.suse/SoN-0008-netvm-Allow-skb-allocation-to-use-PFMEMALLOC-reserve.patch:
  Delete.
- patches.suse/SoN-0009-netvm-Propagate-page-pfmemalloc-to-skb.patch:
  Delete.
- patches.suse/SoN-0009a-limit-propagation-to-pages-without-mappings.patch:
  Delete.
- patches.suse/SoN-0009b-netvm-Propagate-page-pfmemalloc-to-skb.patch:
  Delete.
- patches.suse/SoN-0009c-netvm-Propagate-page-pfmemalloc-to-skb.patch:
  Delete.
- patches.suse/SoN-0010-netvm-Set-PF_MEMALLOC-as-appropriate-during-SKB-proc.patch:
  Delete.
- patches.suse/SoN-0010a-netvm-Ensure-release-of-RCU-lock.patch:
  Delete.
- patches.suse/SoN-0011-mm-Micro-optimise-slab-to-avoid-a-function-call.patch:
  Delete.
- patches.suse/SoN-0012-nbd-Set-SOCK_MEMALLOC-for-access-to-PFMEMALLOC-reser.patch:
  Delete.
- patches.suse/SoN-0013-mm-Throttle-direct-reclaimers-if-PF_MEMALLOC-reserve.patch:
  Delete.
- patches.suse/SoN-0013a-mm-do-not-throttle-kernel-threads.patch:
  Delete.
- patches.suse/SoN-0013b-mm-wake-throttled-processes-before-kswapd-sleeps.patch:
  Delete.
- patches.suse/SoN-0013c-mm-kswapd-awake-before-throttling.patch:
  Delete.
- patches.suse/SoN-0013d-mm-kswapd-awake-while-throttling.patch:
  Delete.
- patches.suse/SoN-0013e-mm-ensure-GFP_NOFS-does-not-block-forever.patch:
  Delete.
- patches.suse/SoN-0014-mm-Account-for-the-number-of-times-direct-reclaimers.patch:
  Delete.
- patches.suse/SoN-0015-netvm-Prevent-a-stream-specific-deadlock.patch:
  Delete.
- patches.suse/SoN-0016-selinux-tag-avc-cache-alloc-as-non-critical.patch:
  Delete.
- patches.suse/SoN-0017-mm-Add-support-for-a-filesystem-to-control-swap-file.patch:
  Delete.
- patches.suse/SoN-0018-mm-swap-Implement-generic-handlers-for-swap-related-.patch:
  Delete.
- patches.suse/SoN-0018-mm-swap-Implement-generic-handlers-for-swap-related-fix-1.patch:
  Delete.
- patches.suse/SoN-0019-mm-Methods-for-teaching-filesystems-about-PG_swapcac.patch:
  Delete.
- patches.suse/SoN-0020-nfs-teach-the-NFS-client-how-to-treat-PG_swapcache-p.patch:
  Delete.
- patches.suse/SoN-0021-nfs-disable-data-cache-revalidation-for-swapfiles.patch:
  Delete.
- patches.suse/SoN-0022-nfs-enable-swap-on-NFS.patch: Delete.
- patches.suse/SoN-0023-nfs-Prevent-page-allocator-recursions-with-swap-over.patch:
  Delete.
- patches.suse/SoN-0024-Avoid-dereferencing-bd_disk-during-swap_entry_free-f.patch:
  Delete.
- patches.fixes/net-allow-vlan-traffic-to-be-received-under-bond.patch
  Refresh.
- patches.fixes/vlan-allow-nested-vlan_do_receive.patch
  Refresh.
- patches.xen/frontswap-hooks
  Refresh.
  Replace Swap-over-NFS implementation with upstream implementation.
- commit 5faa729
* Wed Oct 10 2012 mgorman@suse.de
- patches.fixes/mm-do_migrate_pages-calls-migrate_to_node-even-if-task-is-already-on-a-correct-node.patch:
  mm: do_migrate_pages() calls migrate_to_node() even if task is already on a correct node.
- patches.fixes/mm-do_migrate_pages-rename-arguments.patch: mm:
  do_migrate_pages(): rename arguments.
- patches.fixes/mm-fix-NULL-ptr-dereference-in-migrate_pages.patch:
  mm: fix NULL ptr dereference in migrate_pages.
- patches.fixes/mm-fix-NULL-ptr-dereference-in-move_pages.patch:
  mm: fix NULL ptr dereference in move_pages.
- patches.fixes/mm-fix-move-migrate_pages-race-on-task-struct.patch:
  mm: fix move/migrate_pages() race on task struct.
  Migration functionality and performance improvements.
- commit 9ee4eeb
* Wed Oct 10 2012 mgorman@suse.de
- patches.fixes/mm-compact_pgdat-workaround-lockdep-warning-in-kswapd.patch:
  compact_pgdat: workaround lockdep warning in kswapd.
- patches.fixes/mm-compaction-Abort-async-compaction-if-locks-are-contended-or-taking-too-long.patch:
  mm: compaction: Abort async compaction if locks are contended or taking too long.
- patches.fixes/mm-compaction-Restart-compaction-from-near-where-it-left-off.patch:
  mm: compaction: Restart compaction from near where it left off.
- patches.fixes/mm-compaction-Update-try_to_compact_pageskerneldoc-comment.patch:
  mm: compaction: Update try_to_compact_pages() kerneldoc comment.
- patches.fixes/mm-compaction-abort-compaction-loop-if-lock-is-contended-or-run-too-long.patch:
  mm: compaction: abort compaction loop if lock is contended or run too long.
- patches.fixes/mm-compaction-acquire-the-zone--lock-as-late-as-possible.patch:
  mm: compaction: acquire the zone->lock as late as possible.
- patches.fixes/mm-compaction-acquire-the-zone--lru_lock-as-late-as-possible.patch:
  mm: compaction: acquire the zone->lru_lock as late as possible.
- patches.fixes/mm-compaction-cache-if-a-pageblock-was-scanned-and-no-pages-were-isolated.patch:
  mm: compaction: cache if a pageblock was scanned and no pages were isolated.
- patches.fixes/mm-compaction-capture-a-suitable-high-order-page-immediately-when-it-is-made-available.patch:
  mm: compaction: capture a suitable high-order page immediately when it is made available.
- patches.fixes/mm-compaction-clear-PG_migrate_skip-based-on-compaction-and-reclaim-activity.patch:
  mm: compaction: clear PG_migrate_skip based on compaction and reclaim activity.
- patches.fixes/mm-compaction-make-compact_control-order-signed.patch:
  mm: compaction: make compact_control order signed.
- patches.fixes/mm-compaction-move-fatal-signal-check-out-of-compact_checklock_irqsave.patch:
  mm: compaction: move fatal signal check out of compact_checklock_irqsave.
- patches.fixes/mm-compaction-update-comment-in-try_to_compact_pages.patch:
  mm: compaction: update comment in try_to_compact_pages.
- patches.fixes/mm-compaction.c-fix-deferring-compaction-mistake.patch:
  mm/compaction.c: fix deferring compaction mistake.
- patches.fixes/mm-enable-CONFIG_COMPACTION-by-default.patch:
  mm: enable CONFIG_COMPACTION by default.
- patches.fixes/mm-remove-__GFP_NO_KSWAPD.patch:
  mm: remove __GFP_NO_KSWAPD.
- patches.fixes/mm-vmscan-scale-number-of-pages-reclaimed-by-reclaim-compaction-based-on-failures.patch:
  mm: vmscan: scale number of pages reclaimed by reclaim/compaction based on failures.
- patches.fixes/mm-vmscan-scale-number-of-pages-reclaimed-by-reclaim-compaction-only-in-direct-reclaim.patch
  mm: vmscan: scale number of pages reclaimed by reclaim/compaction only in direct reclaim
- Delete patches.suse/mm-thp-limit-writes-in-direct-reclaim.patch
- Delete patches.suse/mm-vmscan-Check-if-we-isolated-a-compound-page-during-lumpy-scan.patch
- Refresh patches.suse/SoN-0013-mm-Throttle-direct-reclaimers-if-PF_MEMALLOC-reserve.patch
  Compaction functionality and performance improvements.
- commit afe8cf4
* Wed Oct 10 2012 mgorman@suse.de
- patches.fixes/mm-clear-pages_scanned-only-if-draining-a-pcp-adds-pages-to-the-buddy-allocator-again.patch:
  mm: clear pages_scanned only if draining a pcp adds pages to the buddy allocator again.
- patches.fixes/mm-ext4-warn-if-direct-reclaim-tries-to-writeback-pages.patch:
  ext4: warn if direct reclaim tries to writeback pages.
- patches.fixes/mm-forbid-lumpy-reclaim-in-shrink_active_list.patch:
  mm: forbid lumpy-reclaim in shrink_active_list().
- patches.fixes/mm-swap-allow-swap-readahead-to-be-merged.patch:
  swap: allow swap readahead to be merged.
- patches.fixes/mm-vmscan-count-pages-into-balanced-for-zone-with-good-watermark.patch:
  vmscan: count pages into balanced for zone with good watermark.
- patches.fixes/mm-vmscan-do-not-stall-on-writeback-during-memory-compaction.patch:
  mm: vmscan: do not stall on writeback during memory compaction.
- patches.fixes/mm-vmscan-do-not-writeback-filesystem-pages-in-direct-reclaim.patch:
  mm: vmscan: do not writeback filesystem pages in direct reclaim.
- patches.fixes/mm-vmscan-do-not-writeback-filesystem-pages-in-kswapd-except-in-high-priority.patch:
  mm: vmscan: do not writeback filesystem pages in kswapd except in high priority.
- patches.fixes/mm-vmscan-immediately-reclaim-end-of-LRU-dirty-pages-when-writeback-completes.patch:
  mm: vmscan: immediately reclaim end-of-LRU dirty pages when writeback completes.
- patches.fixes/mm-vmscan-kswapd-carefully-call-compaction.patch:
  vmscan: kswapd carefully call compaction.
- patches.fixes/mm-vmscan-only-defer-compaction-for-failed-order-and-higher.patch:
  vmscan: only defer compaction for failed order and higher.
- patches.fixes/mm-vmscan-reclaim-at-order-0-when-compaction-is-enabled.patch:
  vmscan: reclaim at order 0 when compaction is enabled.
- patches.fixes/mm-vmscan-remove-dead-code-related-to-lumpy-reclaim-waiting-on-pages-under-writeback.patch:
  mm: vmscan: remove dead code related to lumpy reclaim waiting on pages under writeback.
- patches.fixes/mm-vmscan-remove-lumpy-reclaim.patch:
  mm: vmscan: remove lumpy reclaim.
- patches.fixes/mm-vmscan-remove-reclaim_mode_t.patch:
  mm: vmscan: remove reclaim_mode_t.
- patches.fixes/mm-vmscan-throttle-reclaim-if-encountering-too-many-dirty-pages-under-writeback.patch:
  mm: vmscan: throttle reclaim if encountering too many dirty pages under writeback.
- patches.fixes/mm-xfs-warn-if-direct-reclaim-tries-to-writeback-pages.patch:
  xfs: warn if direct reclaim tries to writeback pages.
- Refresh patches.fixes/mm-consider-PageReclaim-for-sync-reclaim.patch
- Refresh patches.fixes/memcg-further-prevent-OOM-with-too-many-dirty-pages.patch
- Delete patches.fixes/mm-kabi-holder-for-lru-immediate.patch
- Delete patches.fixes/mm-kabi-holder-for-prioiritise-reclaim.patch
  Page reclaim functionality and performance improvements.
- commit 0567c27
* Wed Oct 10 2012 mhocko@suse.cz
- patches.fixes/mm-oom-fix-totalpages-calculation.patch: memcg:
  oom: fix totalpages calculation for swappiness==0 (bnc#783965).
* Wed Oct 10 2012 mgorman@suse.de
- patches.fixes/mm-buddy-dump-PG_compound_lock-page-flag.patch:
  mm/buddy: dump PG_compound_lock page flag.
- patches.fixes/mm-do-not-use-page_count-without-a-page-pin.patch:
  mm: do not use page_count() without a page pin.
- patches.fixes/mm-fix-free-page-check-in-zone_watermark_ok.patch:
  mm: fix free page check in zone_watermark_ok().
- patches.fixes/mm-fix-off-by-two-in-__zone_watermark_ok.patch:
  mm: fix off-by-two in __zone_watermark_ok().
- patches.fixes/mm-fix-tracing-in-free_pcppages_bulk.patch: mm:
  fix tracing in free_pcppages_bulk().
- patches.fixes/mm-smp-introduce-a-generic-on_each_cpu_mask-function.patch
  smp: introduce a generic on_each_cpu_mask() function
- patches.fixes/mm-only-IPI-CPUs-to-drain-local-pages-if-they-exist.patch:
  mm: only IPI CPUs to drain local pages if they exist.
- patches.fixes/mm-page_alloc.c-remove-pageblock_default_order.patch:
  mm/page_alloc.c: remove pageblock_default_order().
- patches.fixes/mm-setup-pageblock_order-before-its-used-by-sparsemem.patch:
  mm: setup pageblock_order before it's used by sparsemem.
  Page allocator functionality and performance improvements.
- commit c256af0
* Wed Oct 10 2012 sjayaraman@suse.de
- patches.fixes/cachefiles-add-support-for-large-files-in-filesys.patch:
  fs: cachefiles: add support for large files in filesystem
  caching (FATE#312793, bnc#782369).
* Wed Oct 10 2012 hare@suse.de
- patches.fixes/block-fix-race-on-request.end_io-invocations.patch:
  Update patch headers with mainline commit ids.
- patches.fixes/scsi-scan-dont-fail-scans-when-host-is-in-recovery.patch:
  Update patch headers with mainline commit ids.
* Wed Oct 10 2012 mgorman@suse.de
- patches.fixes/mm-mempolicy.c-use-enum-value-MPOL_REBIND_ONCE-in-mpol_rebind_policy.patch:
  mm/mempolicy.c: use enum value MPOL_REBIND_ONCE in mpol_rebind_policy().
- patches.fixes/mm-mempolicy-fix-mbind-to-do-synchronous-migration.patch:
  mm, mempolicy: fix mbind() to do synchronous migration.
- patches.fixes/mm-revert-mm-mempolicy-Let-vma_merge-and-vma_split-handle-vma-vm_policy-linkages.patch:
  revert "mm: mempolicy: Let vma_merge and vma_split handle vma->vm_policy linkages".
- patches.fixes/mm-mempolicy-fix-a-race-in-shared_policy_replace.patch:
  mempolicy: fix a race in shared_policy_replace().
- patches.fixes/mm-mempolicy-fix-refcount-leak-in-mpol_set_shared_policy.patch:
  mempolicy: fix refcount leak in mpol_set_shared_policy().
- patches.fixes/mm-mempolicy-fix-a-memory-corruption-by-refcount-imbalance-in-alloc_pages_vma.patch:
  mempolicy: fix a memory corruption by refcount imbalance in alloc_pages_vma().
- patches.fixes/mm-mempolicy-remove-mempolicy-sharing.patch:
  mempolicy: remove mempolicy sharing.
  Memory policy enhancements for robustness against fuzz attacks and force
  mbind to use synchronous migration.
* Wed Oct 10 2012 hare@suse.de
- Update patch headers with mainline commit ids:
  * patches.fixes/scsi-stop-accepting-scsi-requests.patch
  * patches.fixes/scsi_dh_alua-Optimize-stpg-command.patch
  * patches.fixes/scsi_dh_alua-Store-pref-bit-from-RTPG.patch
  * patches.fixes/scsi_dh_alua-fix-time-interval-for-alua-rtpg-commands
  * patches.fixes/scsi_dh_alua-set_params-interface.patch
- Update scsi_dh_alua to mainline version (bnc#708296, bnc#784334):
  * patches.fixes/scsi_dh_alua-Enable-STPG-for-unavailable-ports.patch
    scsi_dh_alua: Enable STPG for unavailable ports
  * patches.fixes/scsi_dh_alua-Re-enable-STPG-for-unavailable-por.patch
    scsi_dh_alua: Re-enable STPG for unavailable ports
  * patches.fixes/scsi_dh_alua-backoff-alua-rtpg-retry-linearly-v.patch
    scsi_dh_alua: backoff alua rtpg retry linearly vs. geometrically
  * patches.fixes/scsi_dh_alua-implement-implied-transition-timeout.patch:
    scsi_dh_alua: implement 'implied transition timeout'
  * patches.fixes/scsi_dh_alua-retry-rtpg-ext-hdr.patch:
    scsi_dh_alua: retry alua rtpg extended header for illegal
    request response
- Remove obsolete patches:
  * patches.fixes/scsi-dh-alua-decode-rtpg-extended-header
  * patches.fixes/scsi_dh_alua-rtpg-flood-during-state-transitioning.patch
- patches.fixes/scsi_dh_alua-Improve-error-handling.patch:
  Refresh patch to apply.
* Tue Oct  9 2012 tiwai@suse.de
- patches.drivers/drm-i915-enable-plain-RC6-on-Sandy-Bridge-by-default.patch:
  Update references, fixed a missing patch chunk (bnc#725355).
* Tue Oct  9 2012 tiwai@suse.de
- patches.drivers/drm-Export-drm_probe_ddc,
  patches.drivers/drm-dp-Update-DPCD-defines,
  patches.drivers/drm-i915-dp-Fetch-downstream-port-info,
  patches.drivers/drm-i915-dp-Be-smarter-about-connection-sense:
  Update patch tags.
- patches.drivers/drm-dp-Document-DP-spec-versions-for-various-DPCD-re:
  drm/dp: Document DP spec versions for various DPCD registers
  (bnc#780461).
- patches.drivers/drm-dp-Make-sink-count-DP-1.2-aware: drm/dp:
  Make sink count DP 1.2 aware (bnc#780461).
* Tue Oct  9 2012 ptesarik@suse.cz
- patches.kernel.org/revert-removal-of-ACPI-procfs-entries.patch:
  Revert removal of ACPI procfs entries (bnc#777283).
* Tue Oct  9 2012 ptesarik@suse.cz
- patches.arch/x86-clear-hpet-config-on-startup: x86: Clear HPET
  configuration registers on startup (bnc#748896).
* Mon Oct  8 2012 mhocko@suse.cz
- patches.drivers/megaraid-sas-boot-hangs-while-LD-is-offline.patch:
  Typo fix.
* Mon Oct  8 2012 jdelvare@suse.de
- patches.rpmify/kbuild-fix-gcc-x-syntax.patch: Update upstream
  reference.
* Mon Oct  8 2012 jslaby@suse.de
- Linux 3.0.44 (bnc#766654 bnc#772427 bnc#773267
  bnc#773383,CVE-2012-3430 bnc#774612 bnc#779699 bnc#781018).
- patches.drivers/cciss-update-to-4.6.28.patch: Refresh.
- patches.drivers/target-0031-target-Enforce-1-page-max-for-control-cdb-buffer-si.patch:
  Refresh.
- patches.kabi/kabi-protect-struct-l2tp_tunnel.patch: kABI:
  protect struct l2tp_tunnel.
- patches.kabi/kabi-protect-struct-perf_event.patch: kABI:
  protect struct perf_event.
- patches.kabi/kabi-protect-struct-task_struct-1.patch: kABI:
  protect thread_struct.
- patches.kernel.org/0001-Revert-tcp-Apply-device-TSO-segment-limit-earlier.patch:
  Revert "tcp: Apply device TSO segment limit earlier".
- patches.kernel.org/0002-Revert-sfc-Fix-maximum-number-of-TSO-segments-and-mi.patch:
  Revert "sfc: Fix maximum number of TSO segments and minimum
  TX queue size".
- patches.kernel.org/0003-Revert-net-Allow-driver-to-limit-number-of-GSO-segme.patch:
  Revert "net: Allow driver to limit number of GSO segments
  per skb".
- patches.suse/01a-md-failfast-metadata: Refresh.
- patches.suse/perfmon2.patch: Refresh.
- patches.arch/x86_mce_fix_32bit_v86_kernel_vs_user_ring.patch:
  Delete.
- patches.drivers/btusb-BCM20702A0-device-id: Delete.
- patches.drivers/rds-set-msg_namelen.patch: Delete.
- patches.drivers/xhci_Fix_a_logical_vs_bitwise_AND_bug.patch:
  Delete.
- patches.fixes/acpi_processor_fix_acpi_id_not_zero.patch: Delete.
- patches.fixes/md-raid0-size-fix: Delete.
- patches.fixes/sched-Fix-ancient-race-in-do_exit.patch: Delete.
- patches.fixes/vfs-dcache-use-dcache_dentry_killed.patch: Delete.
* Fri Oct  5 2012 ohering@suse.de
-  Hyper-V KVP IP injection (fate#31441):
- patches.suse/msft-hv-0365-drivers-net-Remove-casts-to-same-type.patch:
  drivers: net: Remove casts to same type.
- patches.suse/msft-hv-0366-drivers-hv-remove-IRQF_SAMPLE_RANDOM-which-is-now-a-.patch:
  drivers: hv: remove IRQF_SAMPLE_RANDOM which is now a no-op.
- patches.suse/msft-hv-0367-hyperv-Move-wait-completion-msg-code-into-rndis_filt.patch:
  hyperv: Move wait completion msg code into
  rndis_filter_halt_device().
- patches.suse/msft-hv-0368-hyperv-Add-comments-for-the-extended-buffer-after-RN.patch:
  hyperv: Add comments for the extended buffer after RNDIS
  message.
- patches.suse/msft-hv-0369-Drivers-hv-Cleanup-the-guest-ID-computation.patch:
  Drivers: hv: Cleanup the guest ID computation.
- patches.suse/msft-hv-0370-Drivers-hv-vmbus-Use-the-standard-format-string-to-f.patch:
  Drivers: hv: vmbus: Use the standard format string to format
  GUIDs.
- patches.suse/msft-hv-0371-Drivers-hv-Add-KVP-definitions-for-IP-address-inject.patch:
  Drivers: hv: Add KVP definitions for IP address injection.
- patches.suse/msft-hv-0372-Drivers-hv-kvp-Cleanup-error-handling-in-KVP.patch:
  Drivers: hv: kvp: Cleanup error handling in KVP.
- patches.suse/msft-hv-0374-Drivers-hv-kvp-Support-the-new-IP-injection-messages.patch:
  Drivers: hv: kvp: Support the new IP injection messages.
- patches.suse/msft-hv-0375-Tools-hv-Prepare-to-expand-kvp_get_ip_address-functi.patch:
  Tools: hv: Prepare to expand kvp_get_ip_address() functionality.
- patches.suse/msft-hv-0376-Tools-hv-Further-refactor-kvp_get_ip_address.patch:
  Tools: hv: Further refactor kvp_get_ip_address().
- patches.suse/msft-hv-0377-Tools-hv-Gather-address-family-information.patch:
  Tools: hv: Gather address family information.
- patches.suse/msft-hv-0378-Tools-hv-Gather-subnet-information.patch:
  Tools: hv: Gather subnet information.
- patches.suse/msft-hv-0379-Tools-hv-Represent-the-ipv6-mask-using-CIDR-notation.patch:
  Tools: hv: Represent the ipv6 mask using CIDR notation.
- patches.suse/msft-hv-0380-Tools-hv-Gather-ipv-4-6-gateway-information.patch:
  Tools: hv: Gather ipv[4,6] gateway information.
- patches.suse/msft-hv-0381-hv-fail-the-probing-immediately-when-we-are-not-in-h.patch:
  hv: fail the probing immediately when we are not in hyperv
  platform.
- patches.suse/msft-hv-0382-hv-vmbus_drv-detect-hyperv-through-x86_hyper.patch:
  hv: vmbus_drv: detect hyperv through x86_hyper.
- patches.suse/msft-hv-0383-Tools-hv-Get-rid-of-some-unused-variables.patch:
  Tools: hv: Get rid of some unused variables.
- patches.suse/msft-hv-0384-Tools-hv-Correctly-type-string-variables.patch:
  Tools: hv: Correctly type string variables.
- patches.suse/msft-hv-0385-Tools-hv-Add-an-example-script-to-retrieve-DNS-entri.patch:
  Tools: hv: Add an example script to retrieve DNS entries.
- patches.suse/msft-hv-0386-Tools-hv-Gather-DNS-information.patch:
  Tools: hv: Gather DNS information.
- patches.suse/msft-hv-0387-Drivers-hv-kvp-Copy-the-address-family-information.patch:
  Drivers: hv: kvp: Copy the address family information.
- patches.suse/msft-hv-0388-Tools-hv-Add-an-example-script-to-retrieve-dhcp-stat.patch:
  Tools: hv: Add an example script to retrieve dhcp state.
- patches.suse/msft-hv-0389-Tools-hv-Gather-DHCP-information.patch:
  Tools: hv: Gather DHCP information.
- patches.suse/msft-hv-0390-Tools-hv-Add-an-example-script-to-configure-an-inter.patch:
  Tools: hv: Add an example script to configure an interface.
- patches.suse/msft-hv-0391-Tools-hv-Implement-the-KVP-verb-KVP_OP_SET_IP_INFO.patch:
  Tools: hv: Implement the KVP verb - KVP_OP_SET_IP_INFO.
- patches.suse/msft-hv-0392-Tools-hv-Rename-the-function-kvp_get_ip_address.patch:
  Tools: hv: Rename the function kvp_get_ip_address().
- patches.suse/msft-hv-0393-Tools-hv-Implement-the-KVP-verb-KVP_OP_GET_IP_INFO.patch:
  Tools: hv: Implement the KVP verb - KVP_OP_GET_IP_INFO.
- patches.suse/msft-hv-0394-tools-hv-Fix-file-handle-leak.patch:
  tools/hv: Fix file handle leak.
- patches.suse/msft-hv-0395-tools-hv-Fix-exit-error-code.patch:
  tools/hv: Fix exit() error code.
- patches.suse/msft-hv-0396-tools-hv-Check-for-read-write-errors.patch:
  tools/hv: Check for read/write errors.
- patches.suse/msft-hv-0397-tools-hv-Parse-etc-os-release.patch:
  tools/hv: Parse /etc/os-release.
- patches.suse/msft-hv-0398-hyperv-Fix-the-max_xfer_size-in-RNDIS-initialization.patch:
  hyperv: Fix the max_xfer_size in RNDIS initialization.
- patches.suse/msft-hv-0399-hyperv-Fix-the-missing-return-value-in-rndis_filter_.patch:
  hyperv: Fix the missing return value in
  rndis_filter_set_packet_filter().
- patches.suse/msft-hv-0400-hyperv-Fix-page-buffer-handling-in-rndis_filter_send.patch:
  hyperv: Fix page buffer handling in rndis_filter_send_request().
- patches.suse/msft-hv-0401-hyperv-Remove-extra-allocated-space-for-recv_pkt_lis.patch:
  hyperv: Remove extra allocated space for recv_pkt_list elements.
- patches.suse/msft-hv-0402-hyperv-Report-actual-status-in-receive-completion-pa.patch:
  hyperv: Report actual status in receive completion packet.
- patches.suse/msft-hv-0403-hyperv-Add-buffer-for-extended-info-after-the-RNDIS-.patch:
  hyperv: Add buffer for extended info after the RNDIS response
  message.
- patches.suse/suse-hv-Cleanup-the-guest-ID-computation.patch:
  Delete.
* Thu Oct  4 2012 jjolly@suse.de
- patches.drivers/mlx4_en-map-entire-pages-to-increase-throughput:
  Fixed build warning, update references (bnc#774500,LTC#83966).
* Thu Oct  4 2012 jbeulich@novell.com
- patches.xen/1189-frontends-unexpected-close.patch: frontends:
  handle backend CLOSED without CLOSING.
- patches.xen/1191-pciback-find-error-paths.patch: pciback:
  properly clean up after calling pcistub_device_find().
- patches.xen/xen-netfront-poll: netfront: add netconsole support
  (bnc#763858 fate#313830).
- Refresh other Xen patches.
* Wed Oct  3 2012 jbohac@suse.cz
- patches.fixes/nf_conntrack_ipv6-fix-tracking-of-ICMPv6-error-messages-containing-fragments.patch:
  netfilter: nf_conntrack_ipv6: fix tracking of ICMPv6 error
  messages containing fragments (bnc#779750).
* Wed Oct  3 2012 jbohac@suse.cz
- patches.fixes/ipv6-xfrm-use-conntrack-reassembled-packet-for-policy-lookup.patch:
  ipv6, xfrm: use conntrack-reassembled packet for policy lookup
  (bnc#780216).
* Wed Oct  3 2012 mkubecek@suse.cz
- patches.fixes/tcp-flush-DMA-queue-before-sk_wait_data-if-rcv_wnd-i.patch:
  update mainline reference
* Tue Oct  2 2012 mkubecek@suse.cz
- patches.fixes/inetpeer-add-namespace-support-for-inetpeer.patch:
  inetpeer: add namespace support for inetpeer (bnc#779969).
- patches.fixes/inetpeer-add-parameter-net-for-inet_getpeer_v4-v6.patch:
  inetpeer: add parameter net for inet_getpeer_v4,v6 (bnc#779969).
- patches.fixes/inetpeer-make-unused_peers-list-per-netns.patch:
  inetpeer: make unused_peers list per-netns (bnc#779969).
- patches.kabi/kABI-use-net_generic-to-protect-struct-netns_ipv-4-6.patch:
  kABI: use net_generic to protect struct netns_ipv{4,6}
  (bnc#779969).
* Mon Oct  1 2012 jkosina@suse.cz
- Update config files.
  Mark tipc kernel module as externally supported (FATE#305033)
* Sat Sep 29 2012 jdelvare@suse.de
- patches.rpmify/kbuild-fix-gcc-x-syntax.patch: Fix more
  occurrences of the same.
* Fri Sep 28 2012 jjolly@suse.de
- patches.arch/s390-57-01-zfcp-sdev-crash.patch: zfcp: only access
  zfcp_scsi_dev for valid scsi_device (bnc#781484,LTC#85285).
- patches.arch/s390-57-02-dasd_check_count_address.patch:
  dasd: check count address during online setting
  (bnc#781484,LTC#85346).
- patches.arch/s390-57-03-hugetlbfs_deadlock.patch: hugetlbfs:
  fix deadlock in unmap_hugepage_range() (bnc#781484,LTC#85449).
- patches.arch/s390-57-04-huge_pgtable_walk.patch: kernel:
  make user-access pagetable walk code huge page aware
  (bnc#781484,LTC#85455).
- patches.arch/s390-57-05-hugetlbfs_tlb_invalidate.patch:
  hugetlbfs: add missing TLB invalidation (bnc#781484,LTC#85463).
* Fri Sep 28 2012 jdelvare@suse.de
- patches.rpmify/kbuild-fix-gcc-x-syntax.patch: kbuild: Fix gcc
  - x syntax (bnc#773831).
* Wed Sep 26 2012 jeffm@suse.com
- patches.suse/supported-flag: Re-enabled warning on unsupported
  module loading.
* Wed Sep 26 2012 jeffm@suse.com
- patches.fixes/nbd-clear-waiting_queue-on-shutdown: nbd: clear
  waiting_queue on shutdown (bnc#778630).
* Wed Sep 26 2012 eich@suse.de
- patches.drivers/drm-i915-enable-plain-RC6-on-Sandy-Bridge-by-default.patch:
  drm/i915: enable plain RC6 on Sandy Bridge by default
  (bnc#725355).
* Wed Sep 26 2012 jslaby@suse.de
- patches.kernel.org/patch-3.0.42-43: Update references
  (bnc#762214 bnc#779462).
* Wed Sep 26 2012 mhocko@suse.cz
- patches.fixes/nohz-fix-idle-ticks-in-cpu-summary-line-for-proc-stat.patch:
  nohz: fix idle ticks in cpu summary line of /proc/stat (follow
  up fix for bnc#767469, bnc#705551).
* Wed Sep 26 2012 jslaby@suse.de
- Linux 3.0.43.
- patches.drivers/cciss-update-to-4.6.28.patch: Refresh.
- patches.fixes/mm-hugetlbfs-Correctly-detect-if-page-tables-have-just-been-shared.patch:
  Refresh.
- patches.suse/scsi-error-test-unit-ready-timeout: Refresh.
- patches.fixes/audit-don-t-free_chunk-after-fsnotify_add_mark.patch:
  Delete.
- patches.fixes/audit-fix-refcounting-in-audit-tree.patch: Delete.
- patches.fixes/nfsd-svc_xprt_enqueue-busy-loop.fix: Delete.
* Tue Sep 25 2012 mkubecek@suse.cz
- patches.suse/fix-TAINT_NO_SUPPORT-handling-on-module-load.patch:
  fix TAINT_NO_SUPPORT handling on module load.
* Tue Sep 25 2012 sjayaraman@suse.de
- patches.fixes/nfs-fix-oopses-in-nfs_lookup_revalidate-and-nfs_open_revalidate.patch:
  NFS: Fix Oopses in nfs_lookup_revalidate and
  nfs4_lookup_revalidate (bnc#780008).
* Tue Sep 25 2012 nfbrown@suse.de
- patches.fixes/nfsd-svc_xprt_enqueue-busy-loop.fix: svcrpc:
  fix svc_xprt_enqueue/svc_recv busy-looping (bnc@779462).
* Mon Sep 24 2012 jkosina@suse.cz
- rpm/kernel-binary.spec.in: Temporarily disable icecream builds
  until miscompilation is resolved (bnc#763954 bnc#773831)
* Mon Sep 24 2012 bpoirier@suse.de
- patches.fixes/net-do-not-disable-sg-for-packets-requiring-no-check.patch:
  net: do not disable sg for packets requiring no checksum
  (bnc#774859).
* Fri Sep 21 2012 bpoirier@suse.de
- patches.drivers/sfc-prevent-extreme-TSO-parameters-from-stalling-TX-.patch:
  sfc: prevent extreme TSO parameters from stalling TX queues
  (bnc#774523 CVE-2012-3412).
- patches.drivers/net-Allow-driver-to-limit-number-of-GSO-segments-per.patch:
  Delete.
- patches.drivers/sfc-Fix-maximum-number-of-TSO-segments-and-minimum-T.patch:
  Delete.
- patches.drivers/sfc-Replace-some-literal-constants-with-EFX_PAGE_SIZ.patch:
  Delete.
- patches.drivers/tcp-Apply-device-TSO-segment-limit-earlier.patch:
  Delete.
* Fri Sep 21 2012 trenn@suse.de
- patches.arch/x86_mce_fix_32bit_v86_kernel_vs_user_ring.patch:
  X86 MCE: Fix correct ring/severity identification in V86 case
  (bnc#773267).
* Fri Sep 21 2012 hare@suse.de
- patches.fixes/scsi_dh_rdac-Add-a-new-netapp-vendor-product-string.patch:
  scsi_dh_rdac: Add a new netapp vendor/product string
  (bnc#772483).
- patches.fixes/scsi_dh_rdac-Consolidate-rdac-strings-together.patch:
  scsi_dh_rdac : Consolidate rdac strings together (bnc#772483).
- patches.fixes/scsi_dh_rdac-minor-return-fix-for-rdac.patch:
  scsi_dh_rdac : minor return fix for rdac (bnc#772483).
* Fri Sep 21 2012 mmarek@suse.de
- Update reference module symbol versions.
* Fri Sep 21 2012 hare@suse.de
- patches.fixes/scsi-dh-rdac-associate-hba-and-storage.patch:
  dh_rdac: Associate HBA and storage in rdac_controller to
  support partitions in storage (bnc#772454).
- patches.fixes/scsi-dh-rdac-fix-error-path.patch: scsi_dh_rdac:
  Fix error path (bnc#772454).
- patches.fixes/scsi-dh-rdac-fix-for-unbalanced-ref-count.patch:
  scsi_dh_rdac: Fix for unbalanced reference count (bnc#772454).
* Fri Sep 21 2012 hare@suse.de
- patches.fixes/sd-ensure-we-correctly-disable-devices.patch: sd:
  Ensure we correctly disable devices with unknown protection type
  (bnc#780876).
* Thu Sep 20 2012 bpoirier@suse.de
- patches.drivers/net-Allow-driver-to-limit-number-of-GSO-segments-per.patch:
  net: Allow driver to limit number of GSO segments per skb
  (bnc#774523 CVE-2012-3412).
- patches.drivers/sfc-Fix-maximum-number-of-TSO-segments-and-minimum-T.patch:
  sfc: Fix maximum number of TSO segments and minimum TX queue
  size (bnc#774523 CVE-2012-3412).
- patches.drivers/sfc-Replace-some-literal-constants-with-EFX_PAGE_SIZ.patch:
  sfc: Replace some literal constants with
  EFX_PAGE_SIZE/EFX_BUF_SIZE (bnc#774523 CVE-2012-3412).
- patches.drivers/tcp-Apply-device-TSO-segment-limit-earlier.patch:
  tcp: Apply device TSO segment limit earlier (bnc#774523
  CVE-2012-3412).
* Thu Sep 20 2012 jjolly@suse.de
- patches.drivers/rds-set-msg_namelen.patch: rds: set correct
  msg_namelen (bnc#773383,CVE-2012-3430).
* Thu Sep 20 2012 jeffm@suse.com
- patches.suse/no-partition-scan: Implement 'no_partition_scan'
  commandline option (FATE#303697).
* Thu Sep 20 2012 mszeredi@suse.cz
- patches.fixes/vfs-dcache-use-dcache_dentry_killed.patch: vfs:
  dcache: use DCACHE_DENTRY_KILLED instead of DCACHE_DISCONNECTED
  in d_kill() (bnc#779699).
* Thu Sep 20 2012 mkubecek@suse.cz
- patches.fixes/igb-convert-to-ndo_fix_features.patch: igb:
  convert to ndo_fix_features (bnc#777269).
- patches.fixes/igb-do-vlan-cleanup.patch: igb: do vlan cleanup
  (bnc#777269).
* Thu Sep 20 2012 mkubecek@suse.cz
- patches.fixes/tcp-flush-DMA-queue-before-sk_wait_data-if-rcv_wnd-i.patch:
  tcp: flush DMA queue before sk_wait_data if rcv_wnd is zero
  (bnc#777024).
* Thu Sep 20 2012 tiwai@suse.de
- patches.drivers/drm-Export-drm_probe_ddc: drm: Export
  drm_probe_ddc() (bnc#780461).
- patches.drivers/drm-dp-Update-DPCD-defines: drm/dp: Update
  DPCD defines (bnc#780461).
- patches.drivers/drm-i915-dp-Be-smarter-about-connection-sense:
  drm/i915/dp: Be smarter about connection sense for branch
  devices (bnc#780461).
- patches.drivers/drm-i915-dp-Fetch-downstream-port-info:
  drm/i915/dp: Fetch downstream port info if needed during DPCD
  fetch (bnc#780461).
* Thu Sep 20 2012 ohering@suse.de
- rpm/kernel-binary.spec.in:
  add Conflicts for older hyper-v hv_kvp_daemon (bnc#770763)
  the kernel-user interface changed, old binaries will busyloop
  with newer kernel
* Thu Sep 20 2012 nfbrown@suse.de
- patches.suse/md-Do-not-block-when-displaying-info.patch:
  fix so that GET_ARRAY_INFO and GET_DISK_INFO fail correctly
  when array has not "raid_disks" count yet.
* Wed Sep 19 2012 dsterba@suse.cz
  btrfs updates
- patches.suse/btrfs-8156-allow-setting-NOCOW-for-a-zero-sized-file-via-.patch:
  btrfs: allow setting NOCOW for a zero sized file via ioctl
  (FATE#306586).
- patches.suse/btrfs-8157-fix-a-bug-of-per-file-nocow.patch:
  Btrfs: fix a bug of per-file nocow (FATE#306586).
- patches.suse/btrfs-8158-fix-the-missing-error-information-in-create_pe.patch:
  Btrfs: fix the missing error information in
  create_pending_snapshot() (FATE#306586).
- patches.suse/btrfs-8159-fix-off-by-one-in-file-clone.patch:
  Btrfs: fix off-by-one in file clone (FATE#306586).
- patches.suse/btrfs-8160-move-transaction-aborts-to-the-point-of-failur.patch:
  btrfs: move transaction aborts to the point of failure
  (FATE#306586).
* Wed Sep 19 2012 mhocko@suse.cz
- patches.fixes/sched-Fix-ancient-race-in-do_exit.patch: sched:
  Fix ancient race in do_exit() (bnc#781018).
* Wed Sep 19 2012 hare@suse.de
- patches.fixes/scsi-dh-alua-retry-mode-parameters-changed.patch:
  scsi_dh_alua: Retry the check-condition in case Mode Parameters
  Changed (bnc#772473).
* Wed Sep 19 2012 hare@suse.de
- patches.drivers/megaraid-sas-boot-hangs-while-LD-is-offline.patch:
  megaraid_sas: boot hangs up while LD is offline issue
  (bnc#698102).
* Wed Sep 19 2012 mhocko@suse.cz
- patches.suse/memcg-warn-on-deeper-hierarchies-with-use_hierarchy-.patch:
  memcg: warn on deeper hierarchies with use_hierarchy==0
  (bnc#781134).
* Wed Sep 19 2012 hare@suse.de
- patches.fixes/zfcp-remove-invalid-list-iterator.patch:
  zfcp: remove invalid reference to list iterator variable
  (bnc#779461).
* Wed Sep 19 2012 hare@suse.de
- Fixup patches for series2git:
  * patches.arch/ppc-lower-min-virt-procs: Refresh.
  * patches.arch/ppc-restrict-devport-to-ISA-systems: Refresh.
- patches.fixes/scsi-update-scsi.h-with-SYNCHRONIZE_CACHE_16.patch:
  scsi: update scsi.h with SYNCHRONIZE_CACHE_16
  (FATE#313550,bnc#769195).
- patches.fixes/sd-init_sd-reshuffle.patch: sd: Reshuffle init_sd
  to avoid crash (bnc#776787).
* Tue Sep 18 2012 jjolly@suse.de
- patches.arch/s390-56-01-zfcp-make-trace-record-tags-unique.patch:
  [BZ 84941] zfcp: Make trace record tags unique
  (bnc#780012,LTC#84941).
- patches.arch/s390-56-02-zfcp-do-not-wakeup-while-suspended.patch:
  zfcp: Do not wakeup while suspended (bnc#780012,LTC#84816).
- patches.arch/s390-56-03-zfcp-restore-port-refcount-check.patch:
  zfcp: restore refcount check on port_remove
  (bnc#780012,LTC#84942).
- patches.arch/s390-56-04-zfcp-optional-port-rescan-on-rscn.patch:
  zfcp: No automatic port_rescan on events (bnc#780012,LTC#84817).
- patches.arch/s390-56-05-dasd_fix_path_group_race.patch: dasd:
  System hang after all channel were lost (bnc#780012,LTC#85025).
* Mon Sep 17 2012 dsterba@suse.cz
- patches.suse/btrfs-8152-fix-unnecessary-warning-when-the-fragments-mak.patch:
  Btrfs: fix unnecessary warning when the fragments make the
  space alloc fail (FATE#306586).
- patches.suse/btrfs-8153-return-EPERM-upon-rmdir-on-a-subvolume.patch:
  btrfs: return EPERM upon rmdir on a subvolume (FATE#306586).
- patches.suse/btrfs-8154-cleanup-for-duplicated-code-in-find_free_exten.patch:
  Btrfs: cleanup for duplicated code in find_free_extent
  (FATE#306586).
- patches.suse/btrfs-8155-cleanup-fs_info-hashers.patch: Btrfs:
  cleanup fs_info->hashers (FATE#306586).
* Fri Sep 14 2012 dsterba@suse.cz
- patches.suse/btrfs-8151-use-vfree-instead-of-kfree.patch:
  Btrfs: use vfree instead of kfree (FATE#306586).
* Fri Sep 14 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-031-Add-mic-mute-LED-control-for-HP-laptop:
  ALSA: hda - Add mic-mute LED control for HP laptop (bnc#779330).
* Wed Sep 12 2012 lduncan@suse.de
- patches.fixes/st-remove-st_mutex.patch: st: remove st_mutex
  (bnc#773007).
* Wed Sep 12 2012 dsterba@suse.cz
- patches.suse/btrfs-8146-fix-error-path-in-create_pending_snapshot.patch:
  Btrfs: fix error path in create_pending_snapshot()
  (FATE#306586).
- patches.suse/btrfs-8147-fix-file-extent-discount-problem-in-the-snapsh.patch:
  Btrfs: fix file extent discount problem in the, snapshot
  (FATE#306586).
- patches.suse/btrfs-8147-fix-full-backref-problem-when-inserting-shared.patch:
  Btrfs: fix full backref problem when inserting shared block
  reference (FATE#306586).
- patches.suse/btrfs-8148-fix-wrong-size-for-the-reservation-of-the-snap.patch:
  Btrfs: fix wrong size for the reservation of the, snapshot
  creation (FATE#306586).
- patches.suse/btrfs-8149-fix-error-handling-in-delete_block_group_cache.patch:
  Btrfs: fix error handling in delete_block_group_cache()
  (FATE#306586).
- patches.suse/btrfs-8150-polish-names-of-kmem-caches.patch:
  btrfs: polish names of kmem caches (FATE#306586).
* Wed Sep 12 2012 sjayaraman@suse.de
- patches.fixes/cifs-Assume-passwords-are-encoded-according-to-iocha.patch:
  cifs: Assume passwords are encoded according to iocharset
  (try #2) (bnc#731035).
* Mon Sep 10 2012 tiwai@suse.de
- patches.drivers/drm-fb-helper-delay-hotplug-handling-when-partially-:
  drm/fb-helper: delay hotplug handling when partially bound
  (bnc#778822).
- patches.drivers/drm-fb-helper-don-t-call-drm_crtc_helper_set_config:
  drm/fb helper: don't call drm_crtc_helper_set_config
  (bnc#778822).
* Fri Sep  7 2012 tiwai@suse.de
- patches.drivers/drm-Skip-too-big-EDID-extensions: Delete.
  Fixed in firmware, so no longer needed (bnc#764900)
* Fri Sep  7 2012 eich@suse.de
- patches.drivers/drm_i915_Fix_backlight_control_for_systems_which_have_bl_polarity_reversed.patch:
  DRM/i915: Fix backlight control for systems which have bl
  polarity reversed (bnc #766156).
* Fri Sep  7 2012 dsterba@suse.cz
- patches.suse/btrfs-update-message-levels.patch: add missing newlines
* Thu Sep  6 2012 dsterba@suse.cz
  btrfs fixes from next
- patches.suse/btrfs-8134-update-last-trans-if-we-don-t-update-the-inode.patch:
  Btrfs: update last trans if we don't update the inode
  (FATE#306586).
- patches.suse/btrfs-8135-fix-possible-corruption-when-fsyncing-written-.patch:
  Btrfs: fix possible corruption when fsyncing written prealloced
  extents (FATE#306586).
- patches.suse/btrfs-8137-set-journal_info-in-async-trans-commit-worker.patch:
  Btrfs: set journal_info in async trans commit worker
  (FATE#306586).
- patches.suse/btrfs-8138-fix-a-bug-in-parsing-return-value-in-logical-r.patch:
  Btrfs: fix a bug in parsing return value in logical resolve
  (FATE#306586).
- patches.suse/btrfs-8139-use-helper-for-logical-resolve.patch:
  Btrfs: use helper for logical resolve (FATE#306586).
- patches.suse/btrfs-8140-use-larger-limit-for-translation-of-logical-to.patch:
  Btrfs: use larger limit for translation of logical to inode
  (FATE#306586).
- patches.suse/btrfs-8141-use-a-slab-for-ordered-extents-allocation.patch:
  Btrfs: use a slab for ordered extents allocation (FATE#306586).
- patches.suse/btrfs-8142-fix-unprotected-log_batch.patch: Btrfs:
  fix unprotected ->log_batch (FATE#306586).
- patches.suse/btrfs-8143-output-more-information-when-aborting-a-unused.patch:
  Btrfs: output more information when aborting a unused
  transaction handle (FATE#306586).
- patches.suse/btrfs-8144-fix-wrong-size-for-the-reservation-when-doing-.patch:
  Btrfs: fix wrong size for the reservation when doing, file
  pre-allocation (FATE#306586).
* Thu Sep  6 2012 jslaby@suse.de
- patches.kernel.org/patch-3.0.27-28: Update references
  (bnc#770695 CVE-2012-2745).
* Thu Sep  6 2012 gzhao@suse.com
- Update serise.conf:
  adjust the location of ceph patches in serise.conf
* Wed Sep  5 2012 mmarek@suse.cz
- patches.fixes/0012-rt2x00-Add-RT5372-chipset-support.patch: Fix
  typo.
* Wed Sep  5 2012 jbeulich@novell.com
- patches.xen/1188-x86_64-hypercall-unwind-r11.patch: x86-64:
  fix hypercall page unwind info.
- patches.xen/xen3-patch-3.0.40-41: Linux 3.0.41.
- Refresh other Xen patches (bnc#776019).
* Wed Sep  5 2012 ptesarik@suse.cz
- patches.drivers/e1000e-EECD-clear-REQ-and-GNT.patch: e1000e:
  clear REQ and GNT in EECD (82571 && 82572) (bnc#762099).
* Tue Sep  4 2012 jbohac@suse.cz
- patches.fixes/bonding-add-some-slack-to-arpmon-time-limits.patch:
  bonding: add some slack to arp monitoring time limits
  (bnc#776095).
* Tue Sep  4 2012 machen@suse.com
- patches.fixes/0001-rt2x00-Remove-incorrect-led-blink.patch:
  rt2x00: Remove incorrect led blink. (bnc#774902)
- patches.fixes/0002-Revert-rt2x00-handle-spurious-pci-interrupts.patch:
  Revert "rt2x00: handle spurious pci interrupts". (bnc#774902)
- patches.fixes/0003-rt2x00-Mark-active-channel-s-survey-data-as-in-use.patch:
  rt2x00: Mark active channel's survey data as "in use". (bnc#774902)
- patches.fixes/0004-rt2x00-Convert-big-if-statements-to-switch-statemen.patch:
  rt2x00: Convert big if-statements to switch-statements. (bnc#774902)
- patches.fixes/0005-rt2800-zero-MAC_SYS_CTRL-bits-during-BBP-and-MAC-re.patch:
  rt2800: zero MAC_SYS_CTRL bits during BBP and MAC reset. (bnc#774902)
- patches.fixes/0006-rt2800lib-fix-wrong-128dBm-when-signal-is-stronger.patch:
  rt2800lib: fix wrong -128dBm when signal is stronger than
  - 12dBm. (bnc#774902)
- patches.fixes/0007-rt2800-document-RF_R03-register-bits-7-4.patch:
  rt2800: document RF_R03 register bits [7:4]. (bnc#774902)
- patches.fixes/0008-rt2x00-Introduce-concept-of-driver-data-in-struct-r.patch:
  rt2x00: Introduce concept of driver data in struct rt2x00_dev. (bnc#774902)
- patches.fixes/0009-rt2x00-Use-struct-rt2x00_dev-driver-data-in-rt2800.patch:
  rt2x00: Use struct rt2x00_dev driver data in rt2800{pci,usb}. (bnc#774902)
- patches.fixes/0010-rt2x00-fix-a-possible-NULL-pointer-dereference.patch:
  rt2x00: fix a possible NULL pointer dereference. (bnc#774902)
- patches.fixes/0011-rt2x00-Add-VCO-recalibration.patch:
  rt2x00:Add VCO recalibration. (bnc#774902)
- patches.fixes/0012-rt2x00-Add-RT5372-chipset-support.patch:
  rt2x00:Add RT5372 chipset support. (bnc#774902)
- patches.fixes/0013-rt2x00-Set-IEEE80211_HW_REPORTS_TX_ACK_STATUS-in-rt.patch:
  rt2x00: Set IEEE80211_HW_REPORTS_TX_ACK_STATUS in rt2800. (bnc#774902)
- patches.fixes/0014-rt2800-introduce-wpdma_disable-function.patch:
  rt2800: introduce wpdma_disable function. (bnc#774902)
- patches.fixes/0015-rt2800-initialize-queues-before-giving-up-due-to-DM.patch:
  rt2800: initialize queues before giving up due to DMA error. (bnc#774902)
- patches.fixes/0016-rt2800-zero-registers-of-unused-TX-rings.patch:
  rt2800: zero registers of unused TX rings. (bnc#774902)
- patches.fixes/0017-wireless-rt2x00-rt2800pci-add-more-RT539x-ids.patch:
  wireless: rt2x00: rt2800pci add more RT539x ids. (bnc#774902)
- patches.fixes/0018-rt2x00-Add-RT5392-chipset-support.patch:
  rt2x00:Add RT5392 chipset support. (bnc#774902)
* Thu Aug 30 2012 trenn@suse.de
- patches.arch/x2apic_opt_out.patch: Refresh.
* Thu Aug 30 2012 trenn@suse.de
- patches.arch/x2apic_opt_out.patch: Refresh.
  bnc#778082
* Thu Aug 30 2012 jslaby@suse.de
- Linux 3.0.42.
- patches.drivers/USB3-0094-xhci-Implement-HS-FS-LS-bandwidth-checking.patch:
  Refresh.
- patches.drivers/USB3-0095-xhci-Add-software-BW-checking-quirk-to-Intel-PPT-xHCI.patch:
  Refresh.
- patches.drivers/USB3-0155-usb-xhci-hide-MSI-code-behind-PCI-bars.patch:
  Refresh.
- patches.drivers/xhci.git-e95829f474f0db3a4d940cae1423783edd966027.patch:
  Delete.
- patches.drivers/xhci_switchback_kabi_fixup.patch: Delete.
* Thu Aug 30 2012 mmarek@suse.cz
- patches.arch/x86-mce-Do-not-call-del_timer_sync-in-IRQ-context:
  x86, mce: Do not call del_timer_sync() in IRQ context
  (bnc#776896).
* Thu Aug 30 2012 mmarek@suse.cz
- patches.arch/x86-mce-Do-not-call-del_timer_sync-in-IRQ-context:
  x86, mce: Do not call del_timer_sync() in IRQ context
  (bnc#776896).
* Thu Aug 23 2012 tonyj@suse.com
- rpm/kernel-binary.spec.in: Do not run debugedit -i, use eu-unstrip
  to retrieve the build-id instead (bnc#768504).
* Wed Aug 22 2012 jjolly@suse.de
- Added patches.arch/s390-54-01-hypfs-missing-files.patch to
  series.conf. (bnc#769407)
* Wed Aug 22 2012 trenn@suse.de
- patches.fixes/acpi_processor_fix_acpi_id_not_zero.patch:
  cpufreq / ACPI: Fix not loading acpi-cpufreq driver regression
  (bnc#766654).
- patches.xen/xen3-patch-3.0.17-18: Refresh.
* Wed Aug 22 2012 brogers@suse.com
- patches.drivers/0001-ida-simplified-functions-for-id-allocation.patch:
  Update references (bnc#740291).
- patches.drivers/0002-ida-make-ida_simple_get-put-IRQ-safe.patch:
  Update references (bnc#740291).
- patches.drivers/0003-virtio-blk-use-ida-to-allocate-disk-index.patch:
  Update references (bnc#740291).
- also fixed bnc#740291 references in kernel-source.changes.
* Wed Aug 22 2012 mszeredi@suse.cz
- patches.fixes/audit-don-t-free_chunk-after-fsnotify_add_mark.patch:
  audit: don't free_chunk() after fsnotify_add_mark()
  (bnc#762214).
- patches.fixes/audit-fix-refcounting-in-audit-tree.patch: audit:
  fix refcounting in audit-tree (bnc#762214).
* Wed Aug 22 2012 jjolly@suse.de
- patches.drivers/mlx4_en-map-entire-pages-to-increase-throughput:
  mlx4_en: map entire pages to increase throughput.
* Tue Aug 21 2012 oneukum@suse.de
- patches.drivers/0001-usb-Add-support-for-root-hub-port-status-CAS.patch:
  usb: Add support for root hub port status CAS (bnc#774289).
* Tue Aug 21 2012 sjayaraman@suse.de
- patches.fixes/nfs-slow-down-state-manager-after-an-unhandled-error.patch:
  NFS: Slow down state manager after an unhandled error (bnc#774973).
* Mon Aug 20 2012 mgalbraith@suse.de
- patches.fixes/reiserfs-unlock-superblock-before-calling-reiserfs_quota_on_mount.patch:
  fs,reiserfs: unlock superblock before calling reiserfs_quota_on_mount() (bnc#772786).
* Fri Aug 17 2012 nfbrown@suse.de
- patches.fixes/nfs-increase-callback-threads: nfs: increase
  number of permitted callback connections (bnc#771706).
* Fri Aug 17 2012 brogers@suse.com
- patches.fixes/kvm-kvmclock-apply-kvmclock-offset-to-guest-wall-clo.patch:
  Refresh.
* Thu Aug 16 2012 rjw@suse.de
- patches.fixes/Freezer-sunrpc-NFS-dont-allow-TASK_KILLABLE-sleeps-to-block-the-freezer.patch:
  Freezer / sunrpc / NFS: don't allow TASK_KILLABLE sleeps to
  block the freezer (bnc#775182).
* Thu Aug 16 2012 hare@suse.de
- patches.fixes/block-do-no-artificially-constrain-max_sectors.patch:
  Add mainline commit id.
* Thu Aug 16 2012 dsterba@suse.cz
- disable patch due to excessive warnings
  (patches.suse/btrfs-8133-fix-race-in-run_clustered_refs.patch)
* Wed Aug 15 2012 jslaby@suse.de
- Linux 3.0.41.
- patches.drivers/edac_i7core_phys_proc_id_use_socketid.patch:
  Refresh.
- patches.drivers/hwmon-coretemp-01-add-core-pkg-threshold-support-to-coretemp.patch:
  Refresh.
- patches.drivers/hwmon-coretemp-05-dont-use-threshold-registers-for-tempX_max.patch:
  Refresh.
- patches.fixes/Have-mmu_notifiers-use-SRCU-so-they-may-safely-schedule.patch:
  Refresh.
- patches.kabi/kabi-protect-struct-irq_desc.patch: kABI: protect
  struct irq_desc.
- patches.suse/zcrypt-feed-hwrandom: Refresh.
- patches.xen/xen3-patch-2.6.31: Refresh.
- patches.fixes/mm-hugetlbfs-Close-race-during-teardown-of-hugetlbfs-shared-page-tables-v3.patch:
  Delete.
* Wed Aug 15 2012 duwe@suse.de
- patches.arch/ppc-lower-min-virt-procs: powerpc/pseries: Support
  lower minimum entitlement for virtual processors (bnc#775984).
- patches.arch/ppc-restrict-devport-to-ISA-systems: powerpc:
  Disable /dev/port interface on systems without an ISA bridge
  (bnc#754670).
* Wed Aug 15 2012 jack@suse.cz
- patches.fixes/ocfs2-Add-a-missing-journal-credit-in-ocfs2_link_cre.patch:
  ocfs2: Add a missing journal credit in ocfs2_link_credits()
  - v2 (bnc#773320).
* Wed Aug 15 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-030-Add-3stack-automute-model-to-AD1882-codec:
  ALSA: hda - Add 3stack-automute model to AD1882 codec
  (bnc#775373).
* Tue Aug 14 2012 hare@suse.de
- patches.fixes/block-do-no-artificially-constrain-max_sectors.patch:
  block: do not artificially constrain max_sectors for stacking
  drivers (bnc#774073).
* Mon Aug 13 2012 oneukum@suse.de
- patches.drivers/xhci_Fix_a_logical_vs_bitwise_AND_bug.patch:
  xhci: Fix a logical vs bitwise AND bug (bnc#772427).
* Fri Aug 10 2012 bpoirier@suse.de
- patches.drivers/bnx2x-Clear-MDC-MDIO-warning-message.patch:
  bnx2x: Clear MDC/MDIO warning message (bnc#769035).
- patches.drivers/bnx2x-Fix-BCM57810-KR-AN-speed-transition.patch:
  bnx2x: Fix BCM57810-KR AN speed transition (bnc#769035).
- patches.drivers/bnx2x-Fix-BCM57810-KR-FC.patch: bnx2x: Fix
  BCM57810-KR FC (bnc#769035).
- patches.drivers/bnx2x-Fix-BCM578x0-SFI-pre-emphasis-settings.patch:
  bnx2x: Fix BCM578x0-SFI pre-emphasis settings (bnc#769035).
- patches.drivers/bnx2x-Fix-link-issue-for-BCM8727-boards.patch:
  bnx2x: Fix link issue for BCM8727 boards (bnc#769035).
- patches.drivers/bnx2x-PFC-fix.patch: bnx2x: PFC fix
  (bnc#769035).
- patches.drivers/bnx2x-fix-checksum-validation.patch: bnx2x:
  fix checksum validation (bnc#769035).
- patches.drivers/bnx2x-fix-panic-when-TX-ring-is-full.patch:
  bnx2x: fix panic when TX ring is full (bnc#769035).
- patches.drivers/bnx2x-previous-driver-unload-revised.patch:
  bnx2x: previous driver unload revised (bnc#769035).
- patches.drivers/bnx2x-remove-WARN_ON.patch: bnx2x: remove
  WARN_ON (bnc#769035).
- patches.drivers/bnx2x-update-driver-version.patch: bnx2x:
  update driver version (bnc#769035).
* Fri Aug 10 2012 oneukum@suse.de
- patches.drivers/xhci.git-e95829f474f0db3a4d940cae1423783edd966027.patch:
  xhci: Switch PPT ports to EHCI on shutdown (bnc#772427).
- patches.drivers/xhci_register_fixup.diff: introduce private
  definitions of register definitions to preserve kABI
  (bnc#772427).
- patches.drivers/xhci_switchback_kabi_fixup.patch: Introduce
  a private switchback method to preserve kABI (bnc#772427).
* Fri Aug 10 2012 mmarek@suse.cz
- config.conf: Drop reference to a s390 vanilla config that does
  not exist.
* Thu Aug  9 2012 jslaby@suse.de
- Linux 3.0.40.
- patches.suse/SoN-0022-nfs-enable-swap-on-NFS.patch: Refresh.
- patches.arch/powerpc-Fix-wrong-divisor-in-usecs_to_cputime.patch:
  Delete.
- patches.fixes/tcp-fix-MSG_TRUNC-dma-receive-offloading.patch:
  Delete.
* Thu Aug  9 2012 jeffm@suse.com
- patches.fixes/reiserfs-fix-deadlock-with-nfs-racing-on-create-lookup:
  reiserfs: fix deadlock with nfs racing on create/lookup
  (bnc#762693).
* Thu Aug  9 2012 dsterba@suse.cz
- patches.suse/btrfs-8126-cleanup-for-unused-ref-cache-stuff.patch:
  Btrfs: cleanup for unused ref cache stuff (FATE#306586).
- patches.suse/btrfs-8127-fix-a-misplaced-address-operator-in-a-conditio.patch:
  Btrfs: fix a misplaced address operator in a condition
  (FATE#306586).
- patches.suse/btrfs-8128-fix-that-error-value-is-changed-by-mistake.patch:
  Btrfs: fix that error value is changed by mistake (FATE#306586).
- patches.suse/btrfs-8129-fix-second-lock-in-btrfs_delete_delayed_items.patch:
  btrfs: fix second lock in btrfs_delete_delayed_items()
  (FATE#306586).
- patches.suse/btrfs-8130-increase-the-size-of-the-free-space-cache.patch:
  Btrfs: increase the size of the free space cache (FATE#306586).
- patches.suse/btrfs-8131-fix-enospc-problems-when-deleting-a-subvol.patch:
  Btrfs: fix enospc problems when deleting a subvol (FATE#306586).
- patches.suse/btrfs-8132-fix-wrong-mtime-and-ctime-when-creating-snapsh.patch:
  Btrfs: fix wrong mtime and ctime when creating snapshots
  (FATE#306586).
- patches.suse/btrfs-8133-fix-race-in-run_clustered_refs.patch:
  Btrfs: fix race in run_clustered_refs (FATE#306586).
* Thu Aug  9 2012 mhocko@suse.cz
- patches.fixes/tmpfs-optimize-clearing-when-writing.patch:
  tmpfs: optimize clearing when writing (VM Performance).
- patches.suse/tmpfs-simplify-filepage-swappage.patch: Refresh.
- patches.suse/tmpfs-simplify-prealloc_page.patch: Refresh.
* Thu Aug  9 2012 mgalbraith@suse.de
- patches.fixes/sched-fix-divide-by-zero-in-thread_group-and-task_times.patch:
  sched: fix divide by zero in thread_group/task_times() (bnc#761774).
* Wed Aug  8 2012 nfbrown@suse.de
- patches.fixes/block-avoid-infinite-discard-loop: block:
  eliminate potential for infinite loop in blkdev_issue_discard
  (bnc#773319).
* Wed Aug  8 2012 hare@suse.de
- patches.suse/dasd-set-and-unset-TIMEOUT-flag.patch: dasd:
  set and unset TIMEOUT flag automatically (bnc#768084).
* Tue Aug  7 2012 mgalbraith@suse.de
- Fix cosmetic (but worrisome to users) stop class accounting bug.
- patches.fixes/sched-fix-migration-thread-accounting-woes.patch:
  sched: fix migration thread runtime bogosity (bnc#773688, bnc#769251).
* Tue Aug  7 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix Obsoletes: tag for the SLE11-SP1
  realtek-r8192ce_pci-kmp package.
* Tue Aug  7 2012 machen@suse.com
- patches.fixes/0001-rt2800-Add-documentation-on-MCU-requests.patch:
  rt2800: Add documentation on MCU requests. (bnc#744198)
- patches.fixes/0002-rt2800pci-Fix-Error-MCU-request-failed-during-initia.patch:
  rt2800pci: Fix 'Error - MCU request failed' during
  initialization. (bnc#744198)
* Mon Aug  6 2012 mmarek@suse.cz
- patches.drivers/btusb-BCM20702A0-device-id: Bluetooth: Another
  vendor specific ID for BCM20702A0 [0a5c:21f1] (bnc#774612).
* Mon Aug  6 2012 mhocko@suse.cz
- patches.fixes/memcg-further-prevent-OOM-with-too-many-dirty-pages.patch:
  memcg: further prevent OOM with too many dirty pages
  (bnc#763198).
- patches.fixes/mm-consider-PageReclaim-for-sync-reclaim.patch:
  Refresh to match the upstream version.
* Mon Aug  6 2012 mhocko@suse.cz
- patches.fixes/tmpfs-distribute-interleave-better-across-nodes.patch:
  tmpfs: distribute interleave better across nodes (bnc#764209).
- patches.fixes/tmpfs-implement-NUMA-node-interleaving.patch:
  droped in favor of the upstream patch
* Fri Aug  3 2012 jjolly@suse.de
- patches.arch/s390-55-03-crst-table-downgrade-v2.patch:
  kernel: incorrect task size after fork of a 31 bit process
  (bnc#772407,LTC#83674).
- patches.arch/s390-55-03-crst-table-downgrade.patch: Deleted due
  to 31bit compile error.
* Fri Aug  3 2012 jeffm@suse.com
- patches.fixes/rt2800-add-chipset-revision-rt5390r-support:
  rt2800: add chipset revision RT5390R support (bnc#772566).
* Fri Aug  3 2012 jeffm@suse.com
- patches.fixes/reiserfs-fix-deadlock-in-quota-code: reiserfs:
  fix deadlocks with quotas (bnc#774285).
* Fri Aug  3 2012 dsterba@suse.cz
  btrfs fixes (3.3-3.5+)
- patches.suse/btrfs-8096-avoid-sleeping-in-verify_parent_transid-while-.patch:
  Btrfs: avoid sleeping in verify_parent_transid while atomic
  (FATE#306586).
- patches.suse/btrfs-8097-fix-btrfs_release_extent_buffer_page-with-the-.patch:
  Btrfs: fix btrfs_release_extent_buffer_page with the right
  usage of num_extent_pages (FATE#306586).
- patches.suse/btrfs-8098-do-not-check-delalloc-when-updating-disk_i_siz.patch:
  Btrfs: do not check delalloc when updating disk_i_size
  (FATE#306586).
- patches.suse/btrfs-8102-look-into-the-extent-during-find_all_leafs.patch:
  Btrfs: look into the extent during find_all_leafs (FATE#306586).
- patches.suse/btrfs-8103-don-t-set-for_cow-parameter-for-tree-block-fun.patch:
  Btrfs: don't set for_cow parameter for tree block functions
  (FATE#306586).
- patches.suse/btrfs-8105-fix-defrag-regression.patch: Btrfs:
  fix defrag regression (FATE#306586).
- patches.suse/btrfs-8106-fix-missing-inherited-flag-in-rename.patch:
  Btrfs: fix missing inherited flag in rename (FATE#306586).
- patches.suse/btrfs-8107-do-not-resize-a-seeding-device.patch:
  Btrfs: do not resize a seeding device (FATE#306586).
- patches.suse/btrfs-8108-cast-devid-to-unsigned-long-long-for-printk-ll.patch:
  Btrfs: cast devid to unsigned long long for printk %%llu
  (FATE#306586).
- patches.suse/btrfs-8109-add-a-missing-spin_lock.patch: Btrfs:
  add a missing spin_lock (FATE#306586).
- patches.suse/btrfs-8111-restore-restriper-state-on-all-mounts.patch:
  Btrfs: restore restriper state on all mounts (FATE#306586).
- patches.suse/btrfs-8112-resume-balance-on-rw-re-mounts-properly.patch:
  Btrfs: resume balance on rw (re)mounts properly (FATE#306586).
- patches.suse/btrfs-8114-fix-tree-log-remove-space-corner-case.patch:
  Btrfs: fix tree log remove space corner case (FATE#306586).
- patches.suse/btrfs-8115-hold-a-ref-on-the-inode-during-writepages.patch:
  Btrfs: hold a ref on the inode during writepages (FATE#306586).
- patches.suse/btrfs-8117-do-not-return-EINVAL-instead-of-ENOMEM-from-op.patch:
  Btrfs: do not return EINVAL instead of ENOMEM from open_ctree()
  (FATE#306586).
- patches.suse/btrfs-8118-do-not-ignore-errors-from-btrfs_cleanup_fs_roo.patch:
  Btrfs: do not ignore errors from btrfs_cleanup_fs_roots()
  when mounting (FATE#306586).
- patches.suse/btrfs-8119-fix-error-handling-in-__add_reloc_root.patch:
  Btrfs: fix error handling in __add_reloc_root() (FATE#306586).
- patches.suse/btrfs-8120-return-error-of-btrfs_update_inode-to-caller.patch:
  Btrfs: return error of btrfs_update_inode() to caller
  (FATE#306586).
- patches.suse/btrfs-8121-fix-typo-in-cow_file_range_async-and-async_cow.patch:
  Btrfs: fix typo in cow_file_range_async and async_cow_submit
  (FATE#306586).
- patches.suse/btrfs-8122-fix-btrfs_is_free_space_inode-to-recognize-btr.patch:
  Btrfs: fix btrfs_is_free_space_inode to recognize btree inode
  (FATE#306586).
- patches.suse/btrfs-8123-kill-root-from-btrfs_is_free_space_inode.patch:
  Btrfs: kill root from btrfs_is_free_space_inode (FATE#306586).
- patches.suse/btrfs-8125-zero-unused-bytes-in-inode-item.patch:
  Btrfs: zero unused bytes in inode item (FATE#306586).
- patches.suse/btrfs-update-message-levels.patch: Refresh.
* Fri Aug  3 2012 nfbrown@suse.de
- patches.fixes/silence-weird-name-warning: VFS: avoid
  prepend_path warning about d_obtain_alias aliases (bnc#773006).
* Fri Aug  3 2012 nfbrown@suse.de
- patches.fixes/md-raid0-size-fix: md: Don't truncate size at 4TB
  for RAID0 and Linear (email to Linux <linux@lists.novell.com>
  (Big md broken after update)).
* Thu Aug  2 2012 jbohac@suse.cz
- patches.fixes/ntp-avoid-printk-under-xtime_lock.patch: ntp:
  avoid printk under xtime_lock (bnc#767684).
* Thu Aug  2 2012 hare@suse.de
- patches.suse/dasd-fail-all-requests-after-timeout.patch:
  Use correct queue for aborting requests.
* Thu Aug  2 2012 brogers@suse.com
- patches.fixes/kvm-kvmclock-apply-kvmclock-offset-to-guest-wall-clo.patch:
  kvm: kvmclock: apply kvmclock offset to guest wall clock time
  (bnc#766445).
* Thu Aug  2 2012 jkosina@suse.cz
- patches.arch/s390-do-not-clobber-personality-flags-on-exec.patch:
  [S390] Do not clobber personality flags on exec (bnc#770034).
* Thu Aug  2 2012 jslaby@suse.de
- Linux 3.0.39.
- patches.arch/mm-avoid-bad-page-on-lru: Refresh.
- patches.arch/mm-avoid-bad-page-on-lru-fix.patch: Refresh.
- patches.fixes/cpuset-mm-optimise-put_mems_allowed-usage.patch:
  Refresh.
- patches.fixes/cpuset-mm-reduce-memory-barrier-related-damage-fix.patch:
  Update references (VM performance).
- patches.fixes/mm-vmscan-do-not-force-scan.patch: Refresh.
- patches.fixes/mm-vmscan-drop-nr_force_scan-from-get_scan_count.patch:
  Refresh.
- patches.kabi/kabi-protect-struct-task_struct.patch: kABI:
  protect thread_struct (VM performance).
- patches.suse/dm-raid45-26-Nov-2009.patch: Refresh.
- patches.suse/mm-vmscan-add-customisable-shrinker-batch-size.patch:
  Refresh.
- patches.fixes/cpuset-mm-reduce-memory-barrier-related-damage-kabi.patch:
  Delete.
- patches.fixes/cpuset-mm-reduce-memory-barrier-related-damage.patch:
  Delete.
- patches.fixes/mm-cpusets-avoid-looping-when-storing-to-mems_allowed-if-one.patch:
  Delete.
- patches.fixes/mm-cpusets-stall-when-updating-mems_allowed-for-mempolicy-or.patch:
  Delete.
- patches.fixes/mm-hotplug-check-if-pages-reserved-on-per-section-basis.patch:
  Delete.
- patches.fixes/mm-kswapd-assign-neworder-after-wakeup.patch:
  Delete.
- patches.fixes/mm-kswapd-avoid-unnecessary-rebalance.patch:
  Delete.
- patches.fixes/mm-reduce-work-done-when-updating-min_free_kbytes.patch:
  Delete.
- patches.fixes/mm-test-PageSwapBacked-in-lumpy-reclaim.patch:
  Delete.
- patches.fixes/mm-vmscan-activate-executable-pages-after-first-usage.patch:
  Delete.
- patches.fixes/mm-vmscan-clear-ZONE_CONGESTED-for-zone-with-good-watermark.patch:
  Delete.
- patches.fixes/mm-vmscan-fix-force-scanning-small-targets-without-swap.patch:
  Delete.
- patches.fixes/mm-vmscan-promote-shared-file-mapped-pages.patch:
  Delete.
- patches.fixes/mm-vmscan.c-consider-swap-space-when-deciding-whether-to-continue-reclaim.patch:
  Delete.
- patches.suse/mm-compaction-Allow-compaction-to-isolate-dirty-pages.patch:
  Delete.
- patches.suse/mm-compaction-Determine-if-dirty-pages-can-be-migrated-without-blocking-within-migratepage.patch:
  Delete.
- patches.suse/mm-compaction-introduce-sync-light-migration-hugetlbfs-fix.patch:
  Delete.
- patches.suse/mm-compaction-introduce-sync-light-migration.patch:
  Delete.
- patches.suse/mm-compaction-make-isolate_lru_page-filter-aware-again.patch:
  Delete.
- patches.suse/mm-compaction-make-isolate_lru_page-filter-aware.patch:
  Delete.
- patches.suse/mm-compaction-trivial-clean-up-in-acct_isolated.patch:
  Delete.
- patches.suse/mm-migration-clean-up-unmap_and_move.patch: Delete.
- patches.suse/mm-page-allocator-Do-not-call-direct-reclaim-for-THP-allocations-while-compaction-is-deferred.patch:
  Delete.
- patches.suse/mm-thp-abort-reclaim-compaction-if-compaction-can-proceed.patch:
  Delete.
- patches.suse/mm-thp-limit-direct-reclaim-for-high-order-allocations.patch:
  Delete.
- patches.suse/mm-vmscan-Check-if-reclaim-should-really-abort-even-if-compaction_ready-is-true-for-one-zone.patch:
  Delete.
- patches.suse/mm-vmscan-add-shrink_slab-tracepoints.patch:
  Delete.
- patches.suse/mm-vmscan-change-isolate-mode-from-define-to-bitwise-type.patch:
  Delete.
- patches.suse/mm-vmscan-do-not-OOM-if-aborting-reclaim.patch:
  Delete.
- patches.suse/mm-vmscan-ensure-sufficient-free-pages.patch:
  Delete.
- patches.suse/mm-vmscan-reduce-wind-up-shrinker--nr-when-shrinker-cant-do-work.patch:
  Delete.
- patches.suse/mm-vmscan-shrinker--nr-updates-race-and-go-wrong.patch:
  Delete.
- patches.suse/mm-vmstat-cache-align-vm_stat.patch: Delete.
- patches.suse/mm-zone_reclaim-make-isolate_lru_page-filter-aware.patch:
  Delete.
* Thu Aug  2 2012 jbeulich@novell.com
- Refresh Xen patches (bnc#772831, add spinlock.nopoll
  option).
* Thu Aug  2 2012 nfbrown@suse.de
- patches.suse/md-bitmap-unplug-fixes: md/bitmap: Don't write
  bitmap while earlier writes might be in-fligh (bnc#771398).
* Wed Aug  1 2012 hare@suse.de
- patches.suse/dasd-fail-all-requests-after-timeout.patch:
  Abort requests from correct queue.
* Wed Aug  1 2012 hare@suse.de
- patches.suse/md-abort-pending-requests: Fixup blktrace
  information.
* Wed Aug  1 2012 jdelvare@suse.de
- patches.fixes/bonding-allow-all-slave-speeds.patch: bonding:
  allow all slave speeds (bnc#771428).
- patches.fixes/bonding-comparing-a-u8-with-1-is-always-false.patch:
  Refresh.
- patches.fixes/bonding-update-speed-duplex-for-NETDEV_CHANGE.patch:
  Refresh.
* Wed Aug  1 2012 mgorman@suse.de
- patches.fixes/mm-hugetlbfs-Close-race-during-teardown-of-hugetlbfs-shared-page-tables-v3.patch:
  mm: hugetlbfs: Close race during teardown of hugetlbfs shared page tables.
- patches.fixes/mm-hugetlbfs-Correctly-detect-if-page-tables-have-just-been-shared.patch:
  mm: hugetlbfs: Correctly detect if page tables have just been shared.
- patches.fixes/mm-hugetlb-decrement-mapcount-under-page_table_lock.patch:
  Delete.
  (Fix bad PMD message displayed while using hugetlbfs (bnc#762366)).
* Wed Aug  1 2012 mhocko@suse.cz
- patches.fixes/proc-stats-Use-arch_idle_time-for-idle-and-iowait-ti.patch:
  Refresh - compile fix error
* Tue Jul 31 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-029-Evaluate-gpio_led-hints-at-the-right-moment:
  ALSA: hda - Evaluate gpio_led hints at the right moment
  (bnc#773878).
* Tue Jul 31 2012 hare@suse.de
- patches.suse/md-abort-pending-requests: Abort pending request
  for RAID10 (bnc#773251).
- patches.suse/md-raid10-tracepoints: md: add raid10 tracepoints
  (bnc#768084).
- patches.suse/md-wakeup-thread-upon-rdev_dec_pending: md:
  wakeup thread upon rdev_dec_pending() (bnc#771398).
* Tue Jul 31 2012 hare@suse.de
- patches.suse/dasd-fail-all-requests-after-timeout.patch:
  Kick tasklet instead of processing the request_queue directly.
* Mon Jul 30 2012 jjolly@suse.de
- patches.arch/s390-55-01-cpu-idle.patch: kernel: CPU idle vs
  CPU hotplug (bnc#772407,LTC#83468).
- patches.arch/s390-55-02-lgr-early-panic.patch: lgr: Make
  lgr_page static (bnc#772407,LTC#83520).
- patches.arch/s390-55-03-crst-table-downgrade.patch:
  kernel: incorrect task size after fork of a 31 bit process
  (bnc#772407,LTC#83674).
* Mon Jul 30 2012 ohering@suse.de
- patches.suse/msft-hv-0359-net-hyperv-Use-wait_event-on-outstanding-sends-durin.patch:
  net/hyperv: Use wait_event on outstanding sends during device removal.
- patches.suse/msft-hv-0360-Tools-hv-verify-origin-of-netlink-connector-message.patch:
  Tools: hv: verify origin of netlink connector message.
- patches.suse/msft-hv-0361-hyperv-Add-support-for-setting-MAC-from-within-guest.patch:
  hyperv: Add support for setting MAC from within guests.
- patches.suse/msft-hv-0362-Drivers-hv-Change-the-hex-constant-to-a-decimal-cons.patch:
  Drivers: hv: Change the hex constant to a decimal constant.
- patches.suse/msft-hv-0363-hyperv-Add-error-handling-to-rndis_filter_device_add.patch:
  hyperv: Add error handling to rndis_filter_device_add().
- patches.suse/msft-hv-0364-hyperv-Add-a-check-for-ring_size-value.patch:
  hyperv: Add a check for ring_size value.
- patches.suse/suse-hv-Cleanup-the-guest-ID-computation.patch:
  Drivers: hv: Cleanup the guest ID computation.
- patches.suse/suse-hv-rndis_filter-defines.patch: hv: add
  RNDIS_OID_GEN_RNDIS_CONFIG_PARAMETER.
* Mon Jul 30 2012 hare@suse.de
- patches.suse/dasd-fail-all-requests-on-dasd_times_out.patch:
  Remove incorrect patch.
* Mon Jul 30 2012 hare@suse.de
- patches.suse/dasd-fail-all-requests-after-timeout.patch:
  Abort all requests on the request_queue, too (bnc#768084).
- patches.suse/dasd-fail-all-requests-on-dasd_times_out.patch:
  dasd: Fail all requests on dasd_times_out() (bnc#768084).
* Mon Jul 30 2012 jdelvare@suse.de
- patches.fixes/natsemi-long-cable-fix: Update Patch-mainline tag
  and add detailed explanations.)
* Mon Jul 30 2012 mhocko@suse.cz
- patches.fixes/proc-stats-Use-arch_idle_time-for-idle-and-iowait-ti.patch:
  proc: stats: Use arch_idle_time for idle and iowait times if
  available (bnc#772893).
* Mon Jul 30 2012 jkosina@suse.cz
- patches.fixes/tcp-fix-MSG_TRUNC-dma-receive-offloading.patch:
  tcp: perform DMA to userspace only if there is a task waiting
  for it (bnc#773606).
* Fri Jul 27 2012 mmarek@suse.cz
- patches.fixes/rt2x00-RT3290-chip-support-v4.patch: Move to
  patches.drivers.
* Fri Jul 27 2012 mmarek@suse.cz
- patches.drivers/rt2x00-fix_rt3290_resuming.patch: rt2x00 :
  fix rt3290 resuming failed (bnc#771778).
* Fri Jul 27 2012 tiwai@suse.de
- patches.suse/SUSE-bootsplash: Refresh.
  Fix wrong vfree() (bnc#773406)
* Thu Jul 26 2012 hare@suse.de
- patches.suse/dasd-timeout-attribute.patch: DASD: Add 'timeout'
  attribute (bnc#771361).
* Wed Jul 25 2012 hare@suse.de
- patches.suse/dasd-fail-all-requests-after-timeout.patch:
  Fixup typo in debugging message.
* Wed Jul 25 2012 jdelvare@suse.de
- patches.kernel.org/patch-3.0.36-37: vhost: don't forget to
  schedule() (bnc#767983).
* Mon Jul 23 2012 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Update mainline tag.
* Mon Jul 23 2012 mhocko@suse.cz
- patches.kabi/powerpc-Fix-wrong-divisor-in-usecs_to_cputime-kabi.patch:
  powerpc, kabi: reintroduce __cputime_msec_factor (bnc#771242).
* Mon Jul 23 2012 hare@suse.de
- patches.suse/md-display-timeout-error.patch: Correctly
  register error code on failure.
* Mon Jul 23 2012 nfbrown@suse.de
- patches.suse/md-unlock_rdev_access: Don't take mddev lock when
  reading rdev attributes from sysfs (bnc#772420).
* Fri Jul 20 2012 jslaby@suse.de
- Linux 3.0.38.
- patches.kabi/kabi-protect-struct-hrtimer_cpu_base.patch: kABI:
  protect struct hrtimer_cpu_base.
- patches.xen/xen3-patch-2.6.18: Refresh.
- patches.drivers/intel_ips-blacklist-HP-ProBook-laptops: Delete.
- patches.fixes/ntp-avoid-printk-under-xtime_lock.patch: Delete.
- patches.fixes/ntp-fix-leap-second-hrtimer-deadlock.patch:
  Delete.
- patches.fixes/tcp-drop-syn-fin-messages.patch: Delete.
* Thu Jul 19 2012 jankit@suse.de
- patches.drivers/0031-bnx2fc-call-ctlr_link_up-only-when-the-interface-is-.patch:
- patches.drivers/0033-bnx2fc-Return-error-statistics-of-remote-peer.patch:
- patches.drivers/0034-bnx2fc-Bumped-version-to-1.0.8.patch:
  Fix Patch-mainline and Git-commit tags.
* Thu Jul 19 2012 jankit@suse.de
- patches.fixes/scsi_dh-code-cleanup-and-remove-references-to-scsi_dev_info:
- patches.fixes/scsi_dh_emc-adding-the-match-function-for-emc-device-handler:
- patches.fixes/scsi_dh_hp_sw-adding-the-match-function-for-hp_sw-device_handler:
- patches.fixes/scsi_dh_rdac-adding-the-match-function-for-rdac-device-handler:
  Fix Patch-mainline and Git-commit tags.
* Thu Jul 19 2012 mhocko@suse.cz
- patches.arch/powerpc-Fix-wrong-divisor-in-usecs_to_cputime.patch:
  powerpc: Fix wrong divisor in usecs_to_cputime (bnc#771242).
* Wed Jul 18 2012 ohering@suse.de
- patches.suse/led_classdev.sysfs-name.patch: Delete.
  All valid changes in this patch were merged into 2.6.32-rc3
  The remaining change to default-on LED trigger changed the name
  from default-on to default::on, which is wrong.
* Wed Jul 18 2012 tonyj@suse.de
  Fix Patch-mainline headers:
- patches.suse/audit-export-logging.patch: Refresh.
- patches.suse/perf-0277-x86-Fix-cmpxchg-usage-in-amd_put_event_constrai.patch:
  Refresh.
- patches.suse/perf-userspace-no-werror.patch: Refresh.
- patches.suse/perfmon2-remove_get_base_syscall_attr.patch:
  remove perfmon syscall_base attribute.
- patches.suse/perfmon2-remove_syscalls.patch: Refresh.
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/perfmon2_ioctl.patch: Refresh.
- patches.suse/perfmon2_noutrace.patch: Refresh.
* Tue Jul 17 2012 jbohac@suse.cz
  Fix Patch-mainline headers:
- patches.arch/x86_64-hpet-64bit-timer.patch: Refresh.
- patches.fixes/ipv6-fix-problem-with-expired-dst-cache.patch:
  Refresh.
- patches.fixes/net-allow-vlan-traffic-to-be-received-under-bond.patch:
  Refresh.
- patches.fixes/net-make-ipv6-bind-honour-freebind.patch: Refresh.
- patches.fixes/net-make-ipv6-pktinfo-honour-freebind.patch:
  Refresh.
- patches.fixes/ntp-avoid-printk-under-xtime_lock.patch: Refresh.
- patches.fixes/ntp-fix-leap-second-hrtimer-deadlock.patch:
  Refresh.
- patches.fixes/vlan-allow-nested-vlan_do_receive.patch: Refresh.
- patches.suse/ebt_vlan-dummy-debug-option.patch: Refresh.
- patches.suse/enable_nf_conntrack_accounting_by_default.patch:
  Refresh.
- patches.suse/ip6_tunnel-add-optional-fwmark-inherit.patch:
  Refresh.
- patches.suse/ipv6-dont-block-modules-that-depend-on-ipv6-when-blacklisted.patch:
  Refresh.
- patches.suse/l2tp_ppp-alias.patch: Refresh.
- patches.suse/netfilter-ip_conntrack_slp.patch: Refresh.
* Tue Jul 17 2012 jslaby@suse.de
- Linux 3.0.37.
- patches.arch/x86-reboot-blacklist-dell-optiplex-990.patch:
  Refresh.
- patches.drivers/0143-be2net-support-multiple-TX-queues.patch:
  Refresh.
- patches.drivers/rtnetlink-compute-and-store-minimum-ifinfo-dump-size:
  Refresh.
- patches.kabi/kabi-add-padding-to-some-important-structures:
  Refresh.
- patches.suse/SoN-0013-mm-Throttle-direct-reclaimers-if-PF_MEMALLOC-reserve.patch:
  Refresh.
- patches.xen/xen3-patch-2.6.27: Refresh.
- patches.drivers/0001-USB-option-Add-USB-ID-for-Novatel-Ovation-MC551.patch:
  Delete.
- patches.drivers/0001-USB-option-add-id-for-Cellient-MEN-200.patch:
  Delete.
- patches.drivers/drm-i915-Fix-eDP-blank-screen-after-S3-resume-on-HP:
  Delete.
- patches.fixes/net-sock-validate-data_len-before-allocating-skb.patch:
  Delete.
- patches.fixes/udf-Avoid-run-away-loop-when-partition-table-length-.patch:
  Delete.
- patches.fixes/udf-Fortify-loading-of-sparing-table.patch:
  Delete.
- patches.fixes/udf-Use-ret-instead-of-abusing-i-in-udf_load_logical.patch:
  Delete.
* Tue Jul 17 2012 ohering@suse.de
- Add patch-mainline tags:
  patches.arch/ppc-efika-mpc52xx-ac97.patch
  patches.arch/ppc-efika-psc-console-autodetection.patch
  patches.arch/ppc64-xmon-dmesg-printing.patch
  patches.drivers/ehea-modinfo.patch
  patches.fixes/scsi-ibmvscsi-module_alias.patch
  patches.fixes/scsi-ibmvscsi-show-config.patch
  patches.suse/8250-sysrq-ctrl_o.patch
  patches.suse/led_classdev.sysfs-name.patch
  patches.suse/nameif-track-rename.patch
  patches.suse/ppc-powerbook-usb-fn-key-default.patch
  patches.suse/radeon-monitor-jsxx-quirk.patch
* Tue Jul 17 2012 mgorman@suse.de
- patches.suse/mm-use-cpu_chill-in-spin_trylock_page.patch: mm:
  use cpu_chill() in spin_trylock_page() and cancel on immediately RT.
  (bnc#768470)
* Tue Jul 17 2012 tiwai@suse.de
- patches.drivers/intel_ips-blacklist-HP-ProBook-laptops: Refresh.
  update git-commit and patch-mainline tags
* Mon Jul 16 2012 brogers@suse.com
- patches.suse/acpiphp-match-to-Bochs-dmi-data.patch: Refresh.
  Fix Patch-mainline and From tags
* Mon Jul 16 2012 oneukum@suse.de
- patches.fixes/0001-usbhid-fix-error-handling-of-not-enough-bandwidth.patch:
  Refresh.
- patches.suse/elousb-fix-api-usage.patch: Refresh.
  Patch-Mainline tags
* Mon Jul 16 2012 hare@suse.de
- Fixup Git-commit and Patch-Mainline tags:
  * patches.drivers/fcoe-0025-libfc-cache-align-struct-fc_fc.patch
  * patches.drivers/fcoe-0026-libfc-cache-align-struct-fc_ex.patch
  * patches.drivers/fcoe-0027-libfc-cache-align-fc_exch_pool.patch
  * patches.drivers/fcoe-0028-fcoe-use-real-dev-in-case-of-h.patch
  * patches.drivers/qla4xxx-Fixed-session-destroy-issue-on-link-up-down.patch
  * patches.drivers/qla4xxx-cleanup-make-qla4xxx_build_ddb_list-short
  * patches.drivers/qla4xxx-clear-the-risc-interrupt-bit-during-fw-init
  * patches.drivers/qla4xxx-disable-generating-pause-frames-in-case-of-fw-hung
  * patches.drivers/qla4xxx-temperature-monitoring-for-isp82xx-core
  * patches.drivers/qla4xxx-updated-device-id-check-for-BFS.patch
  * patches.fixes/fcoe-add-DCB-notifiers-to-set-skb-priority.patch
  * patches.fixes/fcoe-fix-regression-on-offload-em-matching-function
  * patches.fixes/fcoe-setup-default-initial-ddp-value
  * patches.fixes/fcoe-use_vlan_id-parameter
* Mon Jul 16 2012 hare@suse.de
- Update Git-commit and Patch-Mainline tags:
  * patches.drivers/qla4xxx-Add-new-FLT-firmware-region.patch
  * patches.drivers/qla4xxx-Clear-DDB-map-index-on-the-basis-of-AEN.patch
  * patches.drivers/qla4xxx-Do-not-add-duplicate-CHAP-entry-in-FLASH.patch
  * patches.drivers/qla4xxx-Fix-bidirectional-CHAP.patch
  * patches.drivers/qla4xxx-Fix-exporting-boot-targets-to-sysfs.patch
  * patches.drivers/qla4xxx-Fix-getting-BIDI-CHAP-for-boot-targets.patch
  * patches.drivers/qla4xxx-Fix-huge-delay-for-ISP4022.patch
  * patches.drivers/qla4xxx-Fix-un-necessary-delay-on-invalid-DDB.patch
  * patches.drivers/qla4xxx-Fix-verify-boot-idx-correctly.patch
  * patches.drivers/qla4xxx-Fixed-active-session-re-open-issue.patch
  * patches.drivers/qla4xxx-Fixed-device-blocked-issue-on-link-up-down.patch
  * patches.drivers/qla4xxx-Fixed-target-discovery-failed-issue.patch
  * patches.drivers/qla4xxx-Free-Device-Database-DDB-reserved-by-FW.patch
  * patches.drivers/qla4xxx-do-not-print-warning-when-rom-lock-fails.patch
* Mon Jul 16 2012 tiwai@suse.de
- Update git-commit and patch-mainline tags:
  patches.drivers/drm-Add-poll-blacklist-for-Dell-Latitude-E5420,
  patches.drivers/drm-Skip-too-big-EDID-extensions,
  patches.drivers/drm-edid-Add-a-workaround-for-1366x768-HD-panel,
  patches.drivers/drm-i915-Clear-TV-sense-state-bits-on-GM45,
  patches.drivers/iommu-Export-intel_iommu_enabled,
  patches.drivers/lis3-add-support-for-hp-2011-bnb,
  patches.drivers/synaptics-hp-clickpad,
  patches.drivers/synaptics-hp-new-model.diff,
  patches.fixes/xhci-Don-t-free-endpoints-in-xhci_mem_cleanup,
  patches.fixes/xhci-Fix-invalid-loop-check-in-xhci_free_tt_info
* Mon Jul 16 2012 hare@suse.de
- Update Git-commit and Patch-Mainline tags:
  * patches.drivers/0001-iscsi_transport-add-support-for-net-settings.patch
  * patches.drivers/0002-qla4xxx-add-support-for-set_net_config.patch
  * patches.drivers/0003-qla4xxx-Added-new-struct-ipaddress_config.patch
  * patches.drivers/0004-iscsi-class-add-iface-representation.patch
  * patches.drivers/0005-qla4xxx-added-support-to-show-multiple-iface-in-sys.patch
  * patches.drivers/0006-iscsi-cls-sysfs-group-is_visible-callout-for-conn-a.patch
  * patches.drivers/0007-iscsi-class-sysfs-group-is_visible-callout-for-sess.patch
  * patches.drivers/0008-iscsi-class-remove-iface-param-mask.patch
  * patches.drivers/0009-iscsi-class-sysfs-group-is_visible-callout-for-iscs.patch
  * patches.drivers/0010-be2iscsi-remove-host-and-session-casts.patch
  * patches.drivers/0011-iscsi-class-expand-vlan-support.patch
  * patches.drivers/0012-libiscsi-don-t-bugon-when-if-user-sets-markers.patch
  * patches.drivers/0013-qla4xxx-Add-VLAN-support.patch
  * patches.drivers/0014-iscsi-class-add-bsg-support-to-iscsi-class.patch
  * patches.drivers/0015-qla4xxx-add-bsg-support.patch
  * patches.drivers/0016-scsi_transport_iscsi-Add-conn-login-kernel-to-user.patch
  * patches.drivers/0017-qla4xxx-support-iscsiadm-session-mgmt.patch
  * patches.drivers/0018-qla4xxx-Remove-reduandant-code-after-open-iscsi-int.patch
  * patches.drivers/0019-qla4xxx-Boot-from-SAN-support-for-open-iscsi.patch
  * patches.drivers/0020-scsi_transport_iscsi-Added-support-to-update-mtu.patch
  * patches.drivers/0021-qla4xxx-Added-support-to-update-mtu.patch
  * patches.drivers/0022-qla4xxx-Code-cleanup-for-read-update-flash-using-BS.patch
  * patches.drivers/0023-qla4xxx-Add-get-ACB-state-support-using-BSG.patch
  * patches.drivers/0024-qla4xxx-Add-read-update-NVRAM-support-for-40xx-adap.patch
  * patches.drivers/0025-qla4xxx-Added-vendor-specific-sysfs-attributes.patch
  * patches.drivers/0026-scsi_transport_iscsi-Added-support-to-update-initia.patch
  * patches.drivers/0027-qla4xxx-added-support-to-update-initiator-iscsi-por.patch
  * patches.drivers/0028-qla4xxx-Added-restore-factory-defaults-support-usin.patch
  * patches.drivers/0029-qla4xxx-Added-Get-ACB-support-using-BSG.patch
  * patches.drivers/0030-scsi-Added-support-for-adapter-and-firmware-reset.patch
  * patches.drivers/0031-qla4xxx-Added-support-for-adapter-and-firmware-rese.patch:
  * patches.drivers/0032-qla4xxx-export-iface-name.patch
  * patches.drivers/0033-qla4xxx-select-iscsi-boot-sysfs-attrs.patch
  * patches.drivers/be2iscsi-Fix-for-case-where-task-sc-was-cleanedup.patch
  * patches.drivers/be2iscsi-Fix-for-wrong-dmsg-setting-in-wrb.patch
  * patches.drivers/be2iscsi-Move-Driver-Version-to-4.1.282.0.patch
  * patches.drivers/be2iscsi-memset-wrb-for-ring-create.patch
  * patches.drivers/be2iscsi-passing-correct-offset-in-async-paths.patch
  * patches.drivers/bnx2i-Fixed-kernel-panic-caused-by-unprotected-task.patch
  * patches.drivers/bnx2x-DCBX-use-define-instead-of-magic.patch
  * patches.drivers/bnx2x-Remove-on-stack-napi-struct-variable.patch
  * patches.drivers/bnx2x-add-endline-at-end-of-message.patch
  * patches.drivers/bnx2x-add-fan-failure-event-handling.patch
  * patches.drivers/bnx2x-cache-in-compressed-fw-image.patch
  * patches.drivers/bnx2x-prevent-race-in-statistics-flow.patch
  * patches.drivers/bnx2x-propagate-DCBX-negotiation.patch
  * patches.drivers/bnx2x-remove-unused-define.patch
  * patches.drivers/bnx2x-remove-unused-variable.patch
  * patches.drivers/bnx2x-separate-FCoE-and-iSCSI-license-initializatio.patch
  * patches.drivers/bnx2x-simplify-definition-of-RX_SGE_MASK_LEN-and-us.patch
  * patches.drivers/bnx2x-update-driver-version-to-1.70.35-0.patch
  * patches.drivers/bnx2x-use-rx_queue-index-for-skb_record_rx_queue.patch
  * patches.drivers/isci-SATA-STP-I-O-is-only-returned-in-the-no.patch
  * patches.drivers/isci-The-port-state-should-be-set-to-stoppin.patch
  * patches.drivers/isci-atapi-support.patch
  * patches.drivers/isci-export-phy-events-via-lldd_control_ph.patch
  * patches.drivers/isci-fix-decode-of-DONE_CRC_ERR-TC-completio.patch
  * patches.drivers/isci-fix-sgpio-register-definitions.patch
  * patches.drivers/isci-initial-sgpio-write-support.patch
  * patches.drivers/libsas-Allow-expander-T-T-attachments.patch
  * patches.drivers/libsas-disable-scanning-lun-0-on-ata-devic.patch
  * patches.drivers/libsas-dynamic-queue-depth.patch
  * patches.drivers/libsas-export-sas_alloc_task.patch
  * patches.drivers/libsas-fix-sas_queuecommand-return-values.patch
  * patches.drivers/libsas-fix-try_test_sas_gpio_gp_bit-build.patch
  * patches.drivers/libsas-fix-warnings-when-checking-sata-stp-p.patch
  * patches.drivers/libsas-libata-fix-change_queue_-depth-type.patch
  * patches.drivers/libsas-reindent-sas_queuecommand.patch
  * patches.drivers/libsas-sas_queuecommand-doesnt-need-host_loc.patch
  * patches.drivers/libsas-sgpio-write-support.patch
  * patches.drivers/lpfc-8.3.5.48.1p-update
  * patches.drivers/mvsas-remove-mvs_slave_-alloc-configure.patch
  * patches.drivers/pm8001-fix-DEV_IS_GONE-infinite-retry.patch
  * patches.drivers/pm8001-missing-break-statements.patch
  * patches.drivers/pm8001-remove-pm8001_slave_-alloc-configure.patch
  * patches.drivers/qla2xxx-0015-Add-support-for-ISP82xx-to-capture-dump-mi.patch
  * patches.drivers/qla2xxx-0016-Implemeted-beacon-on-off-for-ISP82XX.patch
  * patches.drivers/qla2xxx-0017-Prevent-CPU-lockups-when-ql2xdontresethba.patch
  * patches.drivers/qla2xxx-0018-Enable-write-permission-to-some-debug-relat.patch
  * patches.drivers/qla2xxx-0019-check-for-marker-IOCB-during-response-queue.patch
  * patches.drivers/qla2xxx-0020-Fix-array-out-of-bound-warning.patch
  * patches.drivers/qla2xxx-0021-During-loopdown-perform-Diagnostic-loopback.patch
  * patches.drivers/qla2xxx-0022-Correction-to-sysfs-edc-interface.patch
  * patches.drivers/qla2xxx-0023-Provide-method-for-updating-I2C-attached-VP.patch
  * patches.drivers/qla2xxx-0024-Return-sysfs-error-codes-appropriate-to-con.patch
  * patches.drivers/qla2xxx-0025-Issue-mailbox-command-only-when-firmware-hu.patch
  * patches.drivers/qla2xxx-0026-Fix-active_mask-may-be-used-uninitialized.patch
* Mon Jul 16 2012 sjayaraman@suse.de
  Update Patch-mainline and Git-commit tags.
- patches.drivers/floppy-cleanup-disk-queue-if-add_disk-was-never-called.patch:
  Refresh.
- patches.drivers/floppy-fix-a-crash-during-rmmod.patch: Refresh.
* Fri Jul 13 2012 bpoirier@suse.de
- patches.fixes/macvtap-zerocopy-validate-vectors-before-building-sk.patch:
  Fix erroneous commit id.
* Fri Jul 13 2012 jslaby@suse.de
  Update tags in some patches.
- patches.rpmify/rpm-kernel-config: Refresh.
- patches.suse/file-capabilities-disable-by-default.diff: Refresh.
- patches.suse/rlim-0021-FS-proc-switch-limits-reading-to-fops.patch:
  Refresh.
- patches.suse/rlim-0022-FS-proc-make-limits-writable.patch:
  Refresh.
- patches.suse/squashfs-3.4.patch: Refresh.
* Fri Jul 13 2012 mhocko@suse.cz
- patches.fixes/memcg-fix-hierarchical-oom-locking.patch: Refresh.
- patches.fixes/nfs-slot-table-alloc: Refresh.
- patches.fixes/thp-avoid-atomic64_read-in-pmd_read_atomic-for-32-bit-PAE.patch:
  Refresh.
- patches.suse/shmem-do-not-export-shmem_inode_info-struct.patch:
  Refresh.
* Fri Jul 13 2012 bpoirier@suse.de
- patches.drivers/be2net-Fix-EEH-error-reset-before-a-flash-dump-compl.patch:
  be2net: Fix EEH error reset before a flash dump completes
  (bnc#755546).
* Thu Jul 12 2012 jeffm@suse.com
- patches.fixes/st-clean-up-device-file-creation-and-removal:
  Fix adding of 'tape' link from device directory (bnc#771102).
- patches.fixes/st-get-rid-of-scsi_tapes-array: Fix locking of
  minor idr during failure-case removal and add freeing of minor
  idr during device removal.
* Thu Jul 12 2012 hare@suse.de
- patches.suse/dasd-fail-all-requests-after-timeout.patch:
  Fixup handling of failfast requests (bnc#768084).
* Wed Jul 11 2012 duwe@suse.de
- patches.suse/zcrypt-feed-hwrandom-2: s390: allow zcrypt to
  /dev/random feeding to be resumed (bnc#718910)
* Wed Jul 11 2012 oneukum@suse.de
- patches.drivers/0001-add-firmware-update-for-Atheros-0cf3-311f.patch:
  add firmware update for Atheros 0cf3:311f (bnc#761775).
* Tue Jul 10 2012 jjolly@suse.de
- Update config files.
  - Unset CONFIG_WATCHDOG_NOWAYOUT to prevent reboot of openais on
    service stop. (bnc#756585)
* Tue Jul 10 2012 jjolly@suse.de
- patches.arch/s390-54-01-hypfs-missing-files.patch: hypfs:
  Missing files and directories (bnc#769407,LTC#82838).
* Mon Jul  9 2012 hare@suse.de
- patches.suse/dasd-fail-all-requests-after-timeout.patch: dasd:
  Fail all requests after timeout (bnc#768084).
* Sat Jul  7 2012 mmarek@suse.cz
- Update config files: Enable CONFIG_RT2800PCI_RT3290.
* Sat Jul  7 2012 mmarek@suse.cz
- patches.fixes/rt2x00-RT3290-chip-support-v4.patch: Fix Git-commit
  tag and adjust indentation to match upstream.
* Fri Jul  6 2012 brogers@suse.com
- patches.drivers/0001-ida-simplified-functions-for-id-allocation.patch:
  ida: simplified functions for id allocation (bnc#740291).
- patches.drivers/0002-ida-make-ida_simple_get-put-IRQ-safe.patch:
  ida: make ida_simple_get/put() IRQ safe (bnc#740291).
- patches.drivers/0003-virtio-blk-use-ida-to-allocate-disk-index.patch:
  virtio-blk: use ida to allocate disk index (bnc#740291).
* Fri Jul  6 2012 oneukum@suse.de
- patches.drivers/0001-USB-option-Add-USB-ID-for-Novatel-Ovation-MC551.patch:
  USB: option: Add USB ID for Novatel Ovation MC551 (bnc#770269).
- patches.drivers/0001-USB-option-add-id-for-Cellient-MEN-200.patch:
  USB: option: add id for Cellient MEN-200 (bnc#770269).
* Fri Jul  6 2012 tiwai@suse.de
- patches.suse/SUSE-bootsplash: Refresh.
  Fix the position of SUSE logo on text screen (bnc#770238)
* Fri Jul  6 2012 oneukum@suse.de
- patches.drivers/0001-enable-Atheros-0cf3-311e-for-firmware-upload.patch:
  enable Atheros 0cf3:311e for firmware upload (bnc#766733).
* Fri Jul  6 2012 hare@suse.de
- patches.fixes/scsi_dh_alua-Improve-error-handling.patch:
  scsi_dh_alua: Improve error handling (bnc#715635).
- patches.suse/scsi-remove-unhandled-error-code-message.patch:
  scsi: remove 'unhandled error code' message (bnc#715635).
* Thu Jul  5 2012 machen@suse.com
- patches.fixes/rt2x00-RT3290-chip-support-v4.patch
  Add to support Ralink ROMA wifi chip. (bnc#758703)
* Wed Jul  4 2012 mszeredi@suse.cz
- patches.fixes/epoll-clear-the-tfile_check_list-on-eloop.patch:
  epoll: clear the tfile_check_list on -ELOOP (bnc#769896).
* Wed Jul  4 2012 mhocko@suse.cz
- patches.fixes/sched-Make-sure-to-not-re-read-variables-after-valid.patch:
  sched: Make sure to not re-read variables after validation
  (bnc#769685).
* Tue Jul  3 2012 tonyj@suse.de
- patches.arch/uv-update-nmi-handler-for-uv2.patch: x86_64,
  UV: Update NMI handler for UV1000/2000 systems (bnc#746509,
  bnc#744655).
- patches.suse/kdb-v4.4-3.1-x86-1-fix-merge-error.patch: Fix
  merge error in original kdb x86 patch (bnc#746509).
- patches.arch/uv-optimize-uv-nmis: Delete.
* Tue Jul  3 2012 jack@suse.cz
- patches.fixes/udf-Avoid-run-away-loop-when-partition-table-length-.patch:
  udf: Avoid run away loop when partition table length is
  corrupted (bnc#769784).
- patches.fixes/udf-Fortify-loading-of-sparing-table.patch: udf:
  Fortify loading of sparing table (bnc#769784).
- patches.fixes/udf-Use-ret-instead-of-abusing-i-in-udf_load_logical.patch:
  udf: Use 'ret' instead of abusing 'i' in udf_load_logicalvol()
  (bnc#769784).
* Tue Jul  3 2012 tiwai@suse.de
- patches.drivers/intel_ips-blacklist-HP-ProBook-laptops:
  intel_ips: blacklist HP ProBook laptops (bnc#720946).
* Tue Jul  3 2012 tiwai@suse.de
- patches.drivers/drm-edid-Don-t-add-inferred-modes-with-higher-resolu:
  drm: edid: Don't add inferred modes with higher resolution
  (bnc#753172).
* Tue Jul  3 2012 mgorman@suse.de
- patches.fixes/init-mm-reschedule-when-initialising-large-numbers-of-sections.patch:
  init: mm: Reschedule when initialising large numbers of memory sections.
  (bnc#755620).
* Fri Jun 29 2012 trenn@suse.de
- patches.arch/x86_x2apic_use_phys_apic_mode_on_bios_request.patch:
  x86/apic: Use x2apic physical mode based on FADT setting
  (bnc#768052).
* Fri Jun 29 2012 mmarek@suse.cz
- Update reference module symbol versions.
* Thu Jun 28 2012 jjolly@suse.de
- patches.arch/s390-53-01-lgr-detection.patch: kernel: Add z/VM
  LGR detection (bnc#767281,LTC#RAS1203).
* Wed Jun 27 2012 brogers@suse.com
- patches.suse/acpiphp-match-to-Bochs-dmi-data.patch: acpiphp:
  add dmi info to acpiphp module (bnc#754391).
* Wed Jun 27 2012 jbohac@suse.cz
- patches.fixes/ntp-fix-leap-second-hrtimer-deadlock.patch: ntp:
  fix leap second hrtimer deadlock (bnc#768632).
* Wed Jun 27 2012 mhocko@suse.cz
- patches.fixes/nohz-Fix-update_ts_time_stat-idle-accounting.patch:
  nohz: Fix update_ts_time_stat idle accounting (bnc#767469, bnc#705551).
- patches.fixes/nohz-Make-idle-iowait-counter-update-conditional.patch:
  nohz: Make idle/iowait counter update conditional (bnc#767469, bnc#705551).
* Wed Jun 27 2012 mgorman@suse.de
- patches.fixes/mm-bug-introduce-BUILD_BUG_ON_INVALID-macro.patch:
  bug: introduce BUILD_BUG_ON_INVALID() macro
- patches.fixes/mm-bug-completely-remove-code-generated-by-disabled-VM_BUG_ON.patch:
  bug: completely remove code generated by disabled.
  (VM Performance).
* Wed Jun 27 2012 hare@suse.de
- patches.suse/md-unblock-SET_DISK_FAULTY.patch: md: unblock
  'SET_DISK_FAULTY' ioctl (bnc#768084).
* Tue Jun 26 2012 vojtech@suse.com
- Update post.sh to make the RT kernel default in the bootloader
  after installation.
- commit 28ca507
* Tue Jun 26 2012 trenn@suse.de
- patches.suse/ibm_x3850M2_blacklist_modesetting.patch: Update
  references (bnc#744314).
* Mon Jun 25 2012 mhocko@suse.cz
- patches.fixes/mm-cond_resced-in-putback_lru_pages.patch:
  mm: call cond_resched in putback_lru_pages (bnc#763968).
* Mon Jun 25 2012 jslaby@suse.de
- Linux 3.0.36.
- patches.kabi/kabi-protect-struct-usb_hcd.patch: Delete.
* Fri Jun 22 2012 jbeulich@novell.com
- Update x84-64 Xen config file (CONFIG_ACPI_PROCESSOR_AGGREGATOR=m).
* Fri Jun 22 2012 mgalbraith@suse.de
- ia64 is odd man out, CONFIG_SCHED_HRTICK is not set, fix
  build failure due to missing hrtick_enabled() in that case.
- patches.fixes/sched-Save-some-hrtick_start_fair-cycles.patch:
  Refresh.
* Fri Jun 22 2012 jbeulich@novell.com
- Update Xen patches to 3.0.35.
- patches.xen/frontswap-cleancache-invalidate,
  patches.xen/frontswap-config, patches.xen/frontswap-core,
  patches.xen/frontswap-header, patches.xen/frontswap-hooks:
  Update mainline tags.
- Refresh other Xen patches.
- patches.xen/xen3-thp-avoid-atomic64_read-in-pmd_read_atomic-for-32-bit-PAE.patch:
  thp: avoid atomic64_read in pmd_read_atomic for 32bit PAE
  (bnc#762991).
- Update Xen config files (CONFIG_XEN_SPINLOCK_ACQUIRE_NESTING=1).
* Fri Jun 22 2012 tiwai@suse.de
- patches.drivers/drm-Add-poll-blacklist-for-Dell-Latitude-E5420:
  drm: Add poll blacklist for Dell Latitude E5420 (bnc#756276).
* Thu Jun 21 2012 jkosina@suse.cz
- supported.conf: mark libceph and rbd as unsupported.
* Thu Jun 21 2012 jbohac@suse.cz
- patches.fixes/ntp-avoid-printk-under-xtime_lock.patch: ntp:
  avoid printk under xtime_lock (bnc#767684).
* Thu Jun 21 2012 dsterba@suse.cz
- disable patches.suse/btrfs-8052-fix-wrong-information-of-the-directory-in-the-.patch
  (bnc#757059)
- patches.suse/btrfs-0450-avoid-deadlocks-from-GFP_KERNEL-allocations-du.patch:
  Refresh.
- patches.suse/btrfs-handle-EIO: Refresh.
* Thu Jun 21 2012 tiwai@suse.de
- patches.drivers/drm-i915-Fix-eDP-blank-screen-after-S3-resume-on-HP:
  drm/i915: Fix eDP blank screen after S3 resume on HP desktops
  (bnc#752352).
* Thu Jun 21 2012 mgorman@suse.de
- patches.fixes/mm-hugetlb-decrement-mapcount-under-page_table_lock.patch:
  mm: hugetlb: Decrement mapcount under page table lock
  (Consistent mapcount decrementing under lock (bnc#762366)).
- patches.fixes/mm-hugetlb-flush_tlb_range-needs-page_table_lock-when-mmap_sem-is-not-held.patch:
  mm: hugetlb: flush_tlb_range() needs page_table_lock when mmap_sem is not held.
  (Consistent locking for TLB flush of hugetlb pages (bnc#762366)).
- patches.fixes/mm-hugetlb.c-undo-change-to-page-mapcount-in-fault-handler.patch:
  mm/hugetlb.c: undo change to page mapcount in fault handler
  (Handle potential leaks in hugetlbfs error paths (bnc#762366)).
* Thu Jun 21 2012 gzhao@suse.com
  FATE#312404
- Update config files.
- patches.ceph/0001-libceph-don-t-time-out-osd-requests-that-haven-t-bee.patch:
  libceph: don't time out osd requests that haven't been received.
- patches.ceph/0002-rbd-cancel-watch-request-when-releasing-the-device.patch:
  rbd: cancel watch request when releasing the device.
- patches.ceph/0003-rbd-set-blk_queue-request-sizes-to-object-size.patch:
  rbd: set blk_queue request sizes to object size.
- patches.ceph/0004-libceph-fix-msgpool.patch: libceph: fix
  msgpool.
- patches.ceph/0005-libceph-fix-leak-of-osd-structs-during-shutdown.patch:
  libceph: fix leak of osd structs during shutdown.
- patches.ceph/0006-libceph-initialize-ack_stamp-to-avoid-unnecessary-co.patch:
  libceph: initialize ack_stamp to avoid unnecessary connection
  reset.
- patches.ceph/0007-libceph-fix-parse-options-memory-leak.patch:
  libceph: fix parse options memory leak.
- patches.ceph/0008-libceph-fix-linger-request-requeuing.patch:
  libceph: fix linger request requeuing.
- patches.ceph/0009-libceph-fix-pg_temp-mapping-calculation.patch:
  libceph: fix pg_temp mapping calculation.
- patches.ceph/0010-libceph-fix-pg_temp-mapping-update.patch:
  libceph: fix pg_temp mapping update.
- patches.ceph/0011-libceph-create-messenger-with-client.patch.filterdiff:
  libceph: create messenger with client.
- patches.ceph/0012-libceph-always-preallocate-mon-connection.patch:
  libceph: always preallocate mon connection.
- patches.ceph/0013-libceph-don-t-complain-on-msgpool-alloc-failures.patch.filterdiff:
  libceph: don't complain on msgpool alloc failures.
- patches.ceph/0014-libceph-warn-on-msg-allocation-failures.patch:
  libceph: warn on msg allocation failures.
- patches.ceph/0015-ceph-fix-ceph_monc_init-memory-leak.patch:
  ceph: fix ceph_monc_init memory leak.
- patches.ceph/0016-ceph-use-kernel-DNS-resolver.patch: ceph:
  use kernel DNS resolver.
- patches.ceph/0017-libceph-force-resend-of-osd-requests-if-we-skip-an-o.patch:
  libceph: force resend of osd requests if we skip an osdmap.
- patches.ceph/0018-libceph-Allocate-larger-oid-buffer-in-request-msgs.patch:
  libceph: Allocate larger oid buffer in request msgs.
- patches.ceph/0019-rbd-return-an-error-when-an-invalid-header-is-read.patch:
  rbd: return an error when an invalid header is read.
- patches.ceph/0020-rbd-remove-buggy-rollback-functionality.patch:
  rbd: remove buggy rollback functionality.
- patches.ceph/0021-crush-fix-mapping-calculation-when-force-argument-do.patch:
  crush: fix mapping calculation when force argument doesn't
  exist.
- patches.ceph/0022-ceph-Use-kmemdup-rather-than-duplicating-its-impleme.patch:
  ceph: Use kmemdup rather than duplicating its implementation.
- patches.ceph/0023-crush-fix-force-for-non-root-TAKE.patch:
  crush: fix force for non-root TAKE.
- patches.ceph/0024-libceph-remove-useless-return-value-for-osd_client-_.patch:
  libceph: remove useless return value for osd_client
  __send_request().
- patches.ceph/0025-rbd-initialize-snap_rwsem-in-rbd_add.patch:
  rbd: initialize snap_rwsem in rbd_add().
- patches.ceph/0026-ceph-initialize-client-debugfs-outside-of-monc-mutex.patch:
  ceph: initialize client debugfs outside of monc->mutex.
- patches.ceph/0027-rbd-fix-a-memory-leak-in-rbd_get_client.patch:
  rbd: fix a memory leak in rbd_get_client().
- patches.ceph/0028-rbd-fix-safety-of-rbd_put_client.patch: rbd:
  fix safety of rbd_put_client().
- patches.ceph/0029-net-ceph-Only-clear-SOCK_NOSPACE-when-there-is-suffi.patch:
  net/ceph: Only clear SOCK_NOSPACE when there is sufficient
  space in the socket buffer.
- patches.ceph/0030-libceph-fix-overflow-check-in-crush_decode.patch:
  libceph: fix overflow check in crush_decode().
- patches.ceph/0031-ceph-use-a-shared-zero-page-rather-than-one-per-mess.patch:
  ceph: use a shared zero page rather than one per messenger.
- patches.ceph/0032-ceph-make-use-of-else-where-appropriate.patch:
  ceph: make use of "else" where appropriate.
- patches.ceph/0033-ceph-kill-addr_str_lock-spinlock-use-atomic-instead.patch:
  ceph: kill addr_str_lock spinlock; use atomic instead.
- patches.ceph/0034-ceph-eliminate-some-needless-casts.patch:
  ceph: eliminate some needless casts.
- patches.ceph/0035-ceph-eliminate-some-abusive-casts.patch:
  ceph: eliminate some abusive casts.
- patches.ceph/0036-rbd-a-few-small-cleanups.patch: rbd: a few
  small cleanups.
- patches.ceph/0037-rbd-make-ceph_parse_options-return-a-pointer.patch.filterdiff:
  rbd: make ceph_parse_options() return a pointer.
- patches.ceph/0038-rbd-do-not-duplicate-ceph_client-pointer-in-rbd_devi.patch:
  rbd: do not duplicate ceph_client pointer in rbd_device.
- patches.ceph/0039-rbd-use-a-single-value-of-snap_name-to-mean-no-snap.patch:
  rbd: use a single value of snap_name to mean no snap.
- patches.ceph/0040-rbd-encapsulate-new-rbd-id-selection.patch:
  rbd: encapsulate new rbd id selection.
- patches.ceph/0041-rbd-rework-calculation-of-new-rbd-id-s.patch:
  rbd: rework calculation of new rbd id's.
- patches.ceph/0042-rbd-protect-the-rbd_dev_list-with-a-spinlock.patch:
  rbd: protect the rbd_dev_list with a spinlock.
- patches.ceph/0043-rbd-tie-rbd_dev_list-changes-to-rbd_id-operations.patch:
  rbd: tie rbd_dev_list changes to rbd_id operations.
- patches.ceph/0044-rbd-restore-previous-rbd-id-sequence-behavior.patch:
  rbd: restore previous rbd id sequence behavior.
- patches.ceph/0045-rbd-release-client-list-lock-sooner.patch:
  rbd: release client list lock sooner.
- patches.ceph/0046-rbd-move-ctl_mutex-lock-inside-rbd_get_client.patch:
  rbd: move ctl_mutex lock inside rbd_get_client().
- patches.ceph/0047-rbd-move-ctl_mutex-lock-inside-rbd_client_create.patch:
  rbd: move ctl_mutex lock inside rbd_client_create().
- patches.ceph/0048-rbd-rename-node_lock.patch: rbd: rename
  "node_lock".
- patches.ceph/0049-remove-extra-semicolon.patch: ceph-backport:
  remove extra semicolon.
- patches.ceph/0050-rbd-a-few-simple-changes.patch: rbd: a few
  simple changes.
- patches.ceph/0051-rbd-have-rbd_get_client-return-a-rbd_client.patch:
  rbd: have rbd_get_client() return a rbd_client.
- patches.ceph/0052-rbd-reduce-memory-used-for-rbd_dev-fields.patch:
  rbd: reduce memory used for rbd_dev fields.
- patches.ceph/0053-rbd-simplify-error-handling-in-rbd_add.patch:
  rbd: simplify error handling in rbd_add().
- patches.ceph/0054-rbd-encapsulate-argument-parsing-for-rbd_add.patch:
  rbd: encapsulate argument parsing for rbd_add().
- patches.ceph/0055-rbd-don-t-use-sscanf-in-rbd_add_parse_args.patch:
  rbd: don't use sscanf() in rbd_add_parse_args().
- patches.ceph/0056-rbd-do-a-few-checks-at-build-time.patch:
  rbd: do a few checks at build time.
- patches.ceph/0057-rbd-have-rbd_parse_args-report-found-mon_addrs-size.patch:
  rbd: have rbd_parse_args() report found mon_addrs size.
- patches.ceph/0058-rbd-don-t-allocate-mon_addrs-buffer-in-rbd_add.patch:
  rbd: don't allocate mon_addrs buffer in rbd_add().
- patches.ceph/0059-rbd-fix-module-sysfs-setup-teardown-code.patch:
  rbd: fix module sysfs setup/teardown code.
- patches.ceph/0060-rbd-do-some-refactoring.patch: rbd: do
  some refactoring.
- patches.ceph/0061-rbd-small-changes.patch: rbd: small changes.
- patches.ceph/0062-rbd-don-t-drop-the-rbd_id-too-early.patch:
  rbd: don't drop the rbd_id too early.
- patches.ceph/0063-libceph-move-prepare_write_banner.patch:
  libceph: move prepare_write_banner().
- patches.ceph/0064-libceph-encapsulate-connection-kvec-operations.patch:
  libceph: encapsulate connection kvec operations.
- patches.ceph/0065-libceph-make-ceph_msgr_wq-private.patch:
  libceph: make ceph_msgr_wq private.
- patches.ceph/0066-libceph-encapsulate-some-messenger-cleanup-code.patch:
  libceph: encapsulate some messenger cleanup code.
- patches.ceph/0067-libceph-make-ceph_tcp_connect-return-int.patch:
  libceph: make ceph_tcp_connect() return int.
- patches.ceph/0068-libceph-a-few-small-changes.patch: libceph:
  a few small changes.
- patches.ceph/0069-ceph-ensure-Boolean-options-support-both-senses.patch.filterdiff:
  ceph: ensure Boolean options support both senses.
- patches.ceph/0070-libceph-use-do-in-CRC-related-Boolean-variables.patch:
  libceph: use "do" in CRC-related Boolean variables.
- patches.ceph/0071-libceph-separate-CRC-calculation-from-byte-swapping.patch:
  libceph: separate CRC calculation from byte swapping.
- patches.ceph/0072-libceph-do-crc-calculations-outside-loop.patch:
  libceph: do crc calculations outside loop.
- patches.ceph/0073-libceph-small-refactor-in-write_partial_kvec.patch:
  libceph: small refactor in write_partial_kvec().
- patches.ceph/0074-libceph-some-simple-changes.patch: libceph:
  some simple changes.
- patches.ceph/0075-libceph-fix-inverted-crc-option-logic.patch:
  libceph: fix inverted crc option logic.
- patches.ceph/0076-libceph-use-kernel_sendpage-for-sending-zeroes.patch:
  libceph: use kernel_sendpage() for sending zeroes.
- patches.ceph/0077-libceph-only-call-kernel_sendpage-via-helper.patch:
  libceph: only call kernel_sendpage() via helper.
- patches.ceph/0078-libceph-get-rid-of-zero_page_address.patch:
  libceph: get rid of zero_page_address.
- patches.ceph/0079-libceph-rename-page_shift-variable-to-something-sens.patch:
  libceph: rename "page_shift" variable to something sensible.
- patches.ceph/0080-libceph-isolate-kmap-call-in-write_partial_msg_pages.patch:
  libceph: isolate kmap() call in write_partial_msg_pages().
- patches.ceph/0081-rbd-move-snap_rwsem-to-the-device-rename-to-header_r.patch:
  rbd: move snap_rwsem to the device, rename to header_rwsem.
- patches.ceph/0082-rbd-don-t-hold-spinlock-during-messenger-flush.patch:
  rbd: don't hold spinlock during messenger flush.
- patches.ceph/0083-ceph-drop-support-for-preferred_osd-pgs.patch.filterdiff:
  ceph: drop support for preferred_osd pgs.
- patches.ceph/0084-crush-clean-up-types-const-ness.patch: crush:
  clean up types, const-ness.
- patches.ceph/0085-crush-adjust-local-retry-threshold.patch:
  crush: adjust local retry threshold.
- patches.ceph/0086-crush-be-more-tolerant-of-nonsensical-crush-maps.patch:
  crush: be more tolerant of nonsensical crush maps.
- patches.ceph/0087-crush-use-a-temporary-variable-to-simplify-crush_do_.patch:
  crush: use a temporary variable to simplify crush_do_rule.
- patches.ceph/0088-crush-remove-forcefeed-functionality.patch:
  crush: remove forcefeed functionality.
- patches.ceph/0089-crush-remove-parent-maps.patch: crush:
  remove parent maps.
- patches.ceph/0090-crush-fix-tree-node-weight-lookup.patch:
  crush: fix tree node weight lookup.
- patches.ceph/0091-crush-fix-memory-leak-when-destroying-tree-buckets.patch:
  crush: fix memory leak when destroying tree buckets.
- patches.ceph/0092-crush-warn-on-do_rule-failure.patch: crush:
  warn on do_rule failure.
- patches.ceph/0093-ceph-osd_client-fix-endianness-bug-in-osd_req_encode.patch:
  ceph: osd_client: fix endianness bug in osd_req_encode_op().
- patches.ceph/0094-ceph-fix-bounds-check-in-ceph_decode_need-and-ceph_e.patch:
  ceph: fix bounds check in ceph_decode_need and ceph_encode_need.
- patches.ceph/0095-rbd-use-gfp_flags-parameter-in-rbd_header_from_disk.patch:
  rbd: use gfp_flags parameter in rbd_header_from_disk().
- patches.ceph/0096-rbd-fix-integer-overflow-in-rbd_header_from_disk.patch:
  rbd: fix integer overflow in rbd_header_from_disk().
- patches.ceph/0097-rbd-protect-read-of-snapshot-sequence-number.patch:
  rbd: protect read of snapshot sequence number.
- patches.ceph/0098-rbd-store-snapshot-id-instead-of-index.patch:
  rbd: store snapshot id instead of index.
- patches.ceph/0099-rbd-remove-conditional-snapid-parameters.patch:
  rbd: remove conditional snapid parameters.
- patches.ceph/0100-rbd-fix-snapshot-size-type.patch: rbd:
  fix snapshot size type.
- patches.ceph/0101-rbd-rename-__rbd_update_snaps-to-__rbd_refresh_heade.patch:
  rbd: rename __rbd_update_snaps to __rbd_refresh_header.
- patches.ceph/0102-rbd-correct-sysfs-snap-attribute-documentation.patch:
  rbd: correct sysfs snap attribute documentation.
- patches.ceph/0103-ceph-messenger-use-read_partial-in-read_partial_mess.patch:
  ceph: messenger: use read_partial() in read_partial_message().
- patches.ceph/0104-ceph-messenger-update-to-in-read_partial-caller.patch:
  ceph: messenger: update "to" in read_partial() caller.
- patches.ceph/0105-ceph-messenger-change-read_partial-to-take-end-arg.patch:
  ceph: messenger: change read_partial() to take "end" arg.
- patches.ceph/0106-libceph-don-t-reset-kvec-in-prepare_write_banner.patch:
  libceph: don't reset kvec in prepare_write_banner().
- patches.ceph/0107-ceph-messenger-reset-connection-kvec-caller.patch:
  ceph: messenger: reset connection kvec caller.
- patches.ceph/0108-ceph-messenger-send-banner-in-process_connect.patch:
  ceph: messenger: send banner in process_connect().
- patches.ceph/0109-ceph-drop-msgr-argument-from-prepare_write_connect.patch:
  ceph: drop msgr argument from prepare_write_connect().
- patches.ceph/0110-ceph-don-t-set-WRITE_PENDING-too-early.patch:
  ceph: don't set WRITE_PENDING too early.
- patches.ceph/0111-ceph-messenger-check-prepare_write_connect-result.patch:
  ceph: messenger: check prepare_write_connect() result.
- patches.ceph/0112-ceph-messenger-rework-prepare_connect_authorizer.patch:
  ceph: messenger: rework prepare_connect_authorizer().
- patches.ceph/0113-ceph-messenger-check-return-from-get_authorizer.patch:
  ceph: messenger: check return from get_authorizer.
- patches.ceph/0114-ceph-define-ceph_auth_handshake-type.patch.filterdiff:
  ceph: define ceph_auth_handshake type.
- patches.ceph/0115-ceph-messenger-reduce-args-to-create_authorizer.patch.filterdiff:
  ceph: messenger: reduce args to create_authorizer.
- patches.ceph/0116-ceph-ensure-auth-ops-are-defined-before-use.patch.filterdiff:
  ceph: ensure auth ops are defined before use.
- patches.ceph/0117-ceph-have-get_authorizer-methods-return-pointers.patch.filterdiff:
  ceph: have get_authorizer methods return pointers.
- patches.ceph/0118-ceph-use-info-returned-by-get_authorizer.patch.filterdiff:
  ceph: use info returned by get_authorizer.
- patches.ceph/0119-ceph-return-pointer-from-prepare_connect_authorizer.patch:
  ceph: return pointer from prepare_connect_authorizer().
- patches.ceph/0120-ceph-rename-prepare_connect_authorizer.patch:
  ceph: rename prepare_connect_authorizer().
- patches.ceph/0121-ceph-add-auth-buf-in-prepare_write_connect.patch:
  ceph: add auth buf in prepare_write_connect().
- patches.ceph/0122-libceph-avoid-unregistering-osd-request-when-not-reg.patch:
  libceph: avoid unregistering osd request when not registered.
- patches.ceph/0123-libceph-fix-pg_temp-updates.patch: libceph:
  fix pg_temp updates.
- patches.ceph/0124-rename-__atomic_add_unless.patch:
  ceph-backport: rename __atomic_add_unless as atomic_add_unless.
- rpm/kernel-source.spec.in:
* Wed Jun 20 2012 tiwai@suse.de
- patches.drivers/drm-i915-Add-intel_backlight-for-edp: Not all
  systems expose a firmware or platform mechanism for changing
  the backlight intensity on i915, so add native driver support
  (bnc#752352).
- patches.drivers/drm-i915-do-not-setup-intel_backlight-twice:
  i915: do not setup intel_backlight twice (bnc#752352).
- patches.drivers/drm-i915-enable-vdd-when-switching-off-the-eDP-panel:
  drm/i915: enable vdd when switching off the eDP panel
  (bnc#752352).
* Wed Jun 20 2012 hare@suse.de
- patches.fixes/block-add-blk_queue_dead.patch:
  Add missing definition blk_queue_dead().
* Wed Jun 20 2012 hare@suse.de
- Backport patches from mainline to fix SCSI crash
  under heavy load (bnc#738284):
  * patches.fixes/block-add-blk_queue_dead.patch: block: add
    blk_queue_dead() (bnc#738284).
  * patches.fixes/block-add-missing-blk_queue_dead-checks.patch:
    block: add missing blk_queue_dead() checks (bnc#738284).
  * patches.fixes/block-fix-race-on-request.end_io-invocations.patch:
    block: Fix race on request.end_io invocations (bnc#738284).
  * patches.fixes/scsi-fc-class-fix-scanning-when-devs-are-offline.patch:
    fc class: fix scanning when devs are offline (bnc#738284).
  * patches.fixes/scsi-fix-device-removal-NULL-pointer-dereference.patch:
    scsi: Fix device removal NULL pointer dereference (bnc#738284).
  * patches.fixes/scsi-fix-the-new-host-byte-settings.patch: scsi:
    fix DID_TARGET_FAILURE and DID_NEXUS_FAILURE host byte settings
    (bnc#738284).
  * patches.fixes/scsi-stop-accepting-scsi-requests.patch:
    scsi: Stop accepting SCSI requests before removing a device
    (bnc#738284).
  * patches.fixes/scsi-Revert-put-stricter-guards-on-queue-dead-chec.patch:
    Delete preliminary patch.
* Tue Jun 19 2012 jkosina@suse.cz
- patches.arch/paravirt-stub-kabi-for-KVM_MMU.patch: Refresh.
  Drop omitted ifdef in get_call_destination(), which resulted
  in all the stubs still going through NULL pointer, as pv_mmu_ops
  were not used properly for patching. This harmed KMPs with
  statically inlined APIs.
* Mon Jun 18 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Provide obsoleted KMPs (bnc#753353),
  fix ath3k obsoletes.
* Mon Jun 18 2012 mgorman@suse.de
- patches.suse/lock_page_or_retry-speedup.patch:
  mm: filemap: Optimise file-backed page faulting by emulating an adaptive sleeping spinlock
  (bnc#762414)
* Sun Jun 17 2012 jslaby@suse.de
- Linux 3.0.35.
- patches.fixes/mm-hugetlbfs-fix-use-after-free-bug-in-quota-handling.patch:
  Refresh.
- patches.drivers/hwmon-fam15h_power-increase-output-resolution.patch:
  Delete.
- patches.fixes/mm-fix-vma_resv_map-NULL-pointer.patch: Delete.
- patches.fixes/mm-hugetlb-fix-resv_map-leak-in-error-path.patch:
  Delete.
* Thu Jun 14 2012 tiwai@suse.de
- patches.drivers/synaptics-hp-clickpad: Refresh.
  Add yet another product ID for HP cert machines (bnc#764339)
* Wed Jun 13 2012 rjw@suse.de
- patches.arch/x86-check-for-valid-irq_cfg-pointer-in-smp_irq_move_cleanup_interrupt.patch:
  x86: check for valid irq_cfg pointer in smp_irq_move_cleanup_interrupt (bnc#763754).
* Wed Jun 13 2012 jkosina@suse.cz
- patches.fixes/backing-dev-use-synchronize_rcu_expedited-instead-of.patch:
  backing-dev: use synchronize_rcu_expedited instead of
  synchronize_rcu (bnc#766027).
- patches.fixes/sysfs-count-subdirectories.patch: sysfs: count
  subdirectories (bnc#766027).
- patches.kabi/sysfs-count-subdirectories-kabi.patch: kABI fix
  for sysfs-count-subdirectories (bnc#766027).
* Wed Jun 13 2012 mgalbraith@suse.de
- Fix up UP box build booboo in 77e81365 backport, split domain flags handler patch
  into the two patches (part2 + handler) it should have already been, and refresh
  patches to kill much hated offsets.
- patches.fixes/sched-Only-queue-remote-wakeups-when-crossing-cache-boundaries-part2.patch:
  sched: Only queue remote wakeups when crossing cache boundaries part2 (bnc#754690).
- patches.fixes/sched-Clean-up-domain-traversal-in-select_idle_sibling.patch: Refresh.
- patches.fixes/sched-Dont-call-task_group-too-many-times-in-set_task_rq.patch: Refresh.
- patches.fixes/sched-Fix-the-sched-group-node-allocation-for-SD_OVERLAP-domains.patch: Refresh.
- patches.fixes/sched-Wrap-scheduler-p--cpus_allowed-access.patch: Refresh.
- patches.fixes/sched-domain-flags-proc-handler.patch: Refresh.
- patches.fixes/sched-fix-select_idle_sibling-induced-bouncing.patch: Refresh.
- patches.fixes/sched-set-skip_clock_update-when-yielding.patch: Refresh.
- patches.fixes/sched-throttle-nohz.patch: Refresh.
* Tue Jun 12 2012 jankit@suse.de
- patches.fixes/block-introduce-blk_set_stacking_limits-function:
  block: Introduce blk_set_stacking_limits function (bnc#763026).
* Tue Jun 12 2012 jbohac@suse.cz
- patches.fixes/net-sock-validate-data_len-before-allocating-skb.patch:
  net: sock: validate data_len before allocating skb in
  sock_alloc_send_pskb() (bnc#765320, CVE-2012-2136).
- patches.fixes/tcp-drop-syn-fin-messages.patch: tcp: drop
  SYN+FIN messages (bnc#765102, CVE-2012-2663).
* Tue Jun 12 2012 mgorman@suse.de
- patches.fixes/mm-hugetlb-fix-resv_map-leak-in-error-path.patch:
  hugetlb: fix resv_map leak in error path
- patches.fixes/mm-fix-vma_resv_map-NULL-pointer.patch:
  mm: fix vma_resv_map() NULL pointer
  (Fix reservation leaks in hugetlbfs (bnc#764150, CVE-2012-2390)).
* Tue Jun 12 2012 mgalbraith@suse.de
- patches.fixes/sched-really-revert-latency-defaults.patch:
  sched: really revert latency defaults to SP1 values (bnc#754690).
- patches.fixes/sched-optimize-latency-defaults.patch:
  sched: optimize latency defaults (bnc#754690).
- patches.fixes/sched-Save-some-hrtick_start_fair-cycles.patch:
  sched: Save some hrtick_start_fair cycles (bnc#754690).
- patches.fixes/sched-use-rt-nr_cpus_allowed-to-recover-select_task_rq-cycles.patch:
  sched: use rt.nr_cpus_allowed to recover select_task_rq() cycles (bnc#754690).
- patches.fixes/sched-set-skip_clock_update-when-yielding.patch:
  sched: Set skip_clock_update in yield_task_fair() (bnc#754690).
- patches.fixes/sched-Dont-call-task_group-too-many-times-in-set_task_rq.patch:
  sched: Don't call task_group() too many times in set_task_rq() (bnc#754690).
- patches.fixes/sched-throttle-nohz.patch:
  sched: ratelimit nohz (bnc#754690).
- patches.fixes/sched-Wrap-scheduler-p--cpus_allowed-access.patch:
  sched: Wrap scheduler p->cpus_allowed access (bnc#754690).
- patches.fixes/sched-Avoid-SMT-siblings-in-select_idle_sibling-if-possible.patch:
  sched: Avoid SMT siblings in select_idle_sibling() if possible (bnc#754690).
- patches.fixes/sched-Clean-up-domain-traversal-in-select_idle_sibling.patch:
  sched: Clean up domain traversal in select_idle_sibling() (bnc#754690).
- patches.fixes/sched-Remove-rcu_read_lock-unlock-from-select_idle_sibling.patch:
  sched: Remove rcu_read_lock/unlock() from select_idle_sibling() (bnc#754690).
- patches.fixes/sched-Fix-the-sched-group-node-allocation-for-SD_OVERLAP-domains.patch:
  sched: Fix the sched group node allocation for SD_OVERLAP domains (bnc#754690).
- patches.fixes/sched-domain-flags-proc-handler.patch:
  sched: add SD_SHARE_PKG_RESOURCES domain flags proc handler (bnc#754690).
- patches.fixes/sched-fix-select_idle_sibling-induced-bouncing.patch:
  sched: fix select_idle_sibling() induced bouncing (bnc#754690).
  monteverdi test results
  thench      1         2         4          8         16         32         64        128
  SP1       270       491       958       1749       2597       2810       6349       6610
  SP2       225       451       911       1573       2723       3501      11189      13951
  SP2x      299       603      1211       2418       4697       6847      11606      14557
  vs sp2  1.328     1.337     1.329      1.537      1.724      1.955      1.037      1.043
  vs sp1  1.107     1.228     1.264      1.382      1.808      2.436      1.828      2.202
  AIM7 Jobs/Min
  tasks       64     128     256      512     1024     2048     4096     8192    16384    32768    65536
  SP1      19257   39414   77918   145054   270743   390647   470198   516044   543859   556604   559158
  SP2      26401   51677   99001   177095   276042   377919   450976   501956   533571   548653   447072
  SP2x     26600   51884   99255   179763   292158   395376   476974   529870   560532   576948   585850
  vs sp1   1.381   1.316   1.273    1.239    1.079    1.012    1.014    1.026    1.030    1.036    1.047
  vs sp2   1.007   1.004   1.002    1.015    1.058    1.046    1.057    1.055    1.050    1.051    1.310
* Mon Jun 11 2012 mhocko@suse.cz
- patches.fixes/mm-avoid-swapping-out-with-swappiness-0.patch:
  mm: avoid swapping out with swappiness==0 (swappiness).
* Mon Jun 11 2012 dsterba@suse.cz
- patches.suse/btrfs-update-message-levels.patch: more module message prefixes.
* Mon Jun 11 2012 mhocko@suse.cz
- patches.fixes/thp-avoid-atomic64_read-in-pmd_read_atomic-for-32-bit-PAE.patch:
  thp: avoid atomic64_read in pmd_read_atomic for 32bit PAE
  (bnc#762991).
* Mon Jun 11 2012 mgorman@suse.de
- patches.arch/paravirt-split-paravirt-MMU-ops.patch:
  paravirt: Split paravirt MMU ops (bnc#556135, bnc#754690, FATE#306453).
- patches.arch/paravirt-only-export-pv_mmu_ops-if-PARAVIRT_MMU.patch:
  paravirt: Only export pv_mmu_ops symbol if PARAVIRT_MMU
- patches.arch/paravirt-stub-kabi-for-KVM_MMU.patch:
  parvirt: Stub support KABI for KVM_MMU
  (bnc#556135, bnc#754690, FATE#306453).
- patches.xen/xen3-patch-2.6.31:
  Refresh.
* Sat Jun  9 2012 jslaby@suse.de
- Linux 3.0.34.
- patches.kabi/kabi-reintroduce-skb_set_dev.patch: kABI:
  reintroduce skb_set_dev.
- patches.fixes/0001-mm-pmd_read_atomic-fix-32bit-PAE-pmd-walk-vs-pmd_pop.patch:
  Delete.
- patches.fixes/Add_support_for_Foxconn_Hon_Hai_AR5BBU22.diff:
  Delete.
- patches.fixes/broadcom_softsailing.diff: Delete.
- patches.fixes/cifs-fix-oops-while-traversing-open-file-list.patch:
  Delete.
- patches.fixes/scsi-fix-dm-multipath-starvation.patch: Delete.
- patches.fixes/xfrm-take-net-hdr-len-into-account-for-esp-payload-s.patch:
  Delete.
* Fri Jun  8 2012 mhocko@suse.cz
- patches.fixes/tmpfs-implement-NUMA-node-interleaving.patch:
  tmpfs: implement NUMA node interleaving (bnc#764209).
* Thu Jun  7 2012 jack@suse.cz
- patches.fixes/xfs-Don-t-allocate-new-buffers-on-every-call-to-_xfs.patch:
  xfs: Don't allocate new buffers on every call to _xfs_buf_find
  (bnc#763968).
- patches.fixes/xfs-fix-buffer-lookup-race-on-allocation-failure.patch:
  xfs: fix buffer lookup race on allocation failure (bnc#763968).
- commit 0e627da
* Thu Jun  7 2012 jslaby@suse.de
- Linux 3.0.33.
- patches.drivers/USB3-0094-xhci-Implement-HS-FS-LS-bandwidth-checking.patch:
  Refresh.
- patches.drivers/USB3-0352-xHCI-reset-on-resume-quirk-for-NEC-uPD720200.patch:
  Refresh.
- patches.drivers/USB3-0366-Revert-xHCI-reset-on-resume-quirk-for-NEC-uPD720200.patch:
  Refresh.
- patches.drivers/drm-i915-Flush-other-plane-register-writes:
  Refresh.
- patches.fixes/writeback-split-inode_wb_list_lock-into-bdi_writebac.patch:
  Refresh.
- patches.kabi/kabi-protect-struct-mmc_host.patch: kABI: protect
  struct mmc_host.
- patches.arch/s390-52-02-pfault-race.patch: Delete.
* Thu Jun  7 2012 dsterba@suse.cz
- patches.suse/0002-vfs-re-implement-writeback_inodes_sb-_nr-_if_idle-an.patch:
  vfs: re-implement writeback_inodes_sb(_nr)_if_idle() and rename
  them (FATE#306586).
- patches.suse/btrfs-8094-flush-all-the-dirty-pages-if-try_to_writeback_.patch:
  Btrfs: flush all the dirty pages if
  try_to_writeback_inodes_sb_nr() fails (FATE#306586).
- patches.suse/btrfs-8095-use-writeback_inodes_sb-_nr-_if_idle.patch:
  vfs: re-implement writeback_inodes_sb(_nr)_if_idle() and rename
  them (FATE#306586).
* Wed Jun  6 2012 bpoirier@suse.de
- patches.fixes/macvtap-zerocopy-validate-vectors-before-building-sk.patch:
  macvtap: zerocopy: validate vectors before building skb
  (bnc#758243 CVE-2012-2119).
* Wed Jun  6 2012 tiwai@suse.de
- patches.drivers/synaptics-hp-clickpad: Refresh.
  patches.drivers/synaptics-hp-new-model.diff: Refresh.
  Fix the detection of LED on the recent HP laptops (bnc#765524)
* Wed Jun  6 2012 tiwai@suse.de
- patches.drivers/drm-Skip-too-big-EDID-extensions: drm: Skip
  too big EDID extensions (bnc#764900).
* Tue Jun  5 2012 jbohac@suse.cz
- supported.conf: add xt_AUDIT (bnc#765253)
* Tue Jun  5 2012 mkubecek@suse.cz
- patches.fixes/bonding-start-slaves-with-link-down-for-ARP-monitor.patch:
  update upstream reference
* Tue Jun  5 2012 dsterba@suse.cz
- patches.suse/btrfs-8089-fix-locking-in-btrfs_destroy_delayed_refs.patch:
  Btrfs: fix locking in btrfs_destroy_delayed_refs (FATE#306586).
- patches.suse/btrfs-8090-wake-up-transaction-waiters-when-aborting-a-tr.patch:
  Btrfs: wake up transaction waiters when aborting a transaction
  (FATE#306586).
- patches.suse/btrfs-8091-abort-the-transaction-if-the-commit-fails.patch:
  Btrfs: abort the transaction if the commit fails (FATE#306586).
- patches.suse/btrfs-8092-fix-btrfs_destroy_marked_extents.patch:
  Btrfs: fix btrfs_destroy_marked_extents (FATE#306586).
- patches.suse/btrfs-8093-unlock-everything-properly-in-the-error-case-f.patch:
  Btrfs: unlock everything properly in the error case for nocow
  (FATE#306586).
- patches.suse/btrfs-8088-check-the-return-code-of-btrfs_save_ino_cache.patch:
  Delete.
* Tue Jun  5 2012 nfbrown@suse.de
- patches.fixes/nfs-acl-fix.1: Fix length of buffer copied in
  __nfs4_get_acl_uncached (bnc#762992).
- patches.fixes/nfs-acl-fix.2: Avoid beyond bounds copy while
  caching ACL (bnc#762992).
- patches.fixes/nfs-acl-fix.3: Avoid reading past buffer when
  calling GETACL (bnc#762992).
* Mon Jun  4 2012 ohering@suse.de
- patches.suse/msft-hv-0349-SCSI-storvsc-Properly-handle-errors-from-the-host.patch:
  [SCSI] storvsc: Properly handle errors from the host (bnc#747404).
- patches.suse/msft-hv-0350-HID-hid-hyperv-Do-not-use-hid_parse_report-directly.patch:
  HID: hid-hyperv: Do not use hid_parse_report() directly.
- patches.suse/msft-hv-0351-HID-hyperv-Set-the-hid-drvdata-correctly.patch:
  HID: hyperv: Set the hid drvdata correctly.
- patches.suse/msft-hv-0352-Drivers-hv-Get-rid-of-an-unnecessary-check-in-vmbus_.patch:
  Drivers: hv: Get rid of an unnecessary check in vmbus_prep_negotiate_resp().
- patches.suse/msft-hv-0353-Drivers-hv-util-Properly-handle-version-negotiations.patch:
  Drivers: hv: util: Properly handle version negotiations.
- patches.suse/msft-hv-0354-hv-fix-return-type-of-hv_post_message.patch:
  hv: fix return type of hv_post_message().
- patches.suse/msft-hv-0355-net-hyperv-Add-flow-control-based-on-hi-low-watermar.patch:
  net/hyperv: Add flow control based on hi/low watermark.
- patches.suse/msft-hv-0356-usb-net-rndis-break-out-linux-rndis.h-defines.patch:
  usb/net: rndis: break out <linux/rndis.h> defines.
  only net/hyperv part
- patches.suse/msft-hv-0357-usb-net-rndis-remove-ambigous-status-codes.patch:
  usb/net: rndis: remove ambigous status codes.
  only net/hyperv part
- patches.suse/msft-hv-0358-usb-net-rndis-merge-command-codes.patch:
  usb/net: rndis: merge command codes.
  only net/hyperv part
* Mon Jun  4 2012 ohering@suse.de
- patches.suse/suse-hv-pata_piix-ignore-disks.patch
  replace our version of this patch with upstream variant:
  ata_piix: defer disks to the Hyper-V drivers by default
  libata: add a host flag to ignore detected ATA devices.
* Fri Jun  1 2012 dsterba@suse.cz
- patches.suse/btrfs-8085-fix-return-code-in-drop_objectid_items.patch:
  Btrfs: fix return code in drop_objectid_items (FATE#306586).
- patches.suse/btrfs-8086-check-to-see-if-the-inode-is-in-the-log-before.patch:
  Btrfs: check to see if the inode is in the log before fsyncing
  (FATE#306586).
- patches.suse/btrfs-8087-pass-locked_page-into-extent_clear_unlock_dela.patch:
  Btrfs: pass locked_page into extent_clear_unlock_delalloc if
  theres an error (FATE#306586).
- patches.suse/btrfs-8088-check-the-return-code-of-btrfs_save_ino_cache.patch:
  Btrfs: check the return code of btrfs_save_ino_cache
  (FATE#306586).
* Fri Jun  1 2012 dsterba@suse.cz
- patches.suse/btrfs-8084-do-not-update-atime-for-RO-snapshots.patch:
  btrfs: do not update atime for RO snapshots (FATE#306586).
* Fri Jun  1 2012 mhocko@suse.cz
- patches.fixes/0001-mm-pmd_read_atomic-fix-32bit-PAE-pmd-walk-vs-pmd_pop.patch:
  mm: pmd_read_atomic: fix 32bit PAE pmd walk vs pmd_populate
  SMP race condition (bnc#762991 CVE-2012-2373).
* Fri Jun  1 2012 tiwai@suse.de
- patches.fixes/xhci-Don-t-free-endpoints-in-xhci_mem_cleanup:
  xhci: Don't free endpoints in xhci_mem_cleanup() (bnc#763307).
- patches.fixes/xhci-Fix-invalid-loop-check-in-xhci_free_tt_info:
  xhci: Fix invalid loop check in xhci_free_tt_info()
  (bnc#763307).
* Fri Jun  1 2012 tiwai@suse.de
- patches.drivers/drm-i915-lvds-disable-at-modeset-for-hp-elitebook:
  drm/i915: Add HP EliteBook to LVDS-temporary-disable list
  (bnc#763717).
* Thu May 31 2012 jkosina@suse.cz
- patches.drivers/floppy-convert-to-single-threaded-wq.patch:
- patches.drivers/floppy-remove-floppy-specific-o_excl-handling.patch:
  Update references.
* Thu May 31 2012 dsterba@suse.cz
  delete unused patches
- patches.suse/btrfs-0427-fix-uninit-variable-in-repair_eb_io_failure.patch:
  Delete.
- patches.suse/btrfs-0439-always-store-the-mirror-we-read-the-eb-from.patch:
  Delete.
- patches.suse/btrfs-0443-don-t-count-CRC-or-header-errors-twice-while-s.patch:
  Delete.
* Thu May 31 2012 dsterba@suse.cz
- kabi/severities: add btrfs exception for ulist.
- patches.kabi/kabi-fix-btrfs-ulist-realloc-bugfix.patch: Delete.
* Thu May 31 2012 mmarek@suse.cz
- patches.drivers/0012-rt2800-radio-3xxx-reprogram-only-lower-bits-of-RF_R3:
  rt2800: radio 3xxx: reprogram only lower bits of RF_R3
  (bnc#759805).
- patches.drivers/0013-rt2800-radio-3xxx-program-RF_R1-during-channel-switch:
  rt2800: radio 3xxx: program RF_R1 during channel switch
  (bnc#759805).
- patches.drivers/0014-rt2800-radio-3xxx-add-channel-switch-calibration-routines:
  Refresh.
- patches.drivers/0015-rt2800-radio-3xxxx-channel-switch-RX-TX-calibration-fixes:
  rt2800: radio 3xxxx: channel switch RX/TX calibration fixes
  (bnc#759805).
* Wed May 30 2012 mmarek@suse.cz
- rpm/config.sh, scripts/config.sh: Build the KOTD against SP2.
* Wed May 30 2012 jdelvare@suse.de
- patches.drivers/hwmon-fam15h_power-increase-output-resolution.patch:
  hwmon: (fam15h_power) Increase output resolution (bnc#759336).
* Wed May 30 2012 jdelvare@suse.de
- patches.drivers/hwmon-k10temp-add-support-for-amd-trinity-cpus.patch:
  hwmon: (k10temp) Add support for AMD Trinity CPUs (bnc#759336).
* Wed May 30 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Own the right -kdump initrd (bnc#764500)
* Wed May 30 2012 dsterba@suse.cz
- patches.kabi/kabi-fix-btrfs-ulist-realloc-bugfix.patch: kABI:
  fix update ulist_next signature change.
* Wed May 30 2012 mhocko@suse.cz
- patches.fixes/mm-consider-PageReclaim-for-sync-reclaim.patch:
  memcg: prevent from OOM with too many dirty pages.
* Tue May 29 2012 jjolly@suse.de
- patches.arch/s390-52-01-dasd_reprioritize_partition_message.patch:
  dasd: re-prioritize partition detection message
  (bnc#764091,LTC#81617).
- patches.arch/s390-52-02-pfault-race.patch: kernel: pfault task
  state race (bnc#764091,LTC#81724).
- patches.arch/s390-52-03-hugetlb-clear-pgtable.patch:
  kernel: clear page table for sw large page emulation
  (bnc#764091,LTC#81933).
* Tue May 29 2012 dsterba@suse.cz
- patches.suse/btrfs-8077-stop-defrag-the-files-automatically-when-doin-.patch:
  Refresh.
- patches.suse/btrfs-8080-destroy-the-items-of-the-delayed-inodes-in-err.patch:
  Refresh.
* Tue May 29 2012 dsterba@suse.cz
- patches.suse/btrfs-8075-convert-the-inode-bit-field-to-use-the-actual-.patch:
  Btrfs: convert the inode bit field to use the actual bit
  operations (FATE#306586).
- patches.suse/btrfs-8076-fix-deadlock-when-the-process-of-delayed-refs-.patch:
  Btrfs: fix deadlock when the process of delayed refs fails
  (FATE#306586).
- patches.suse/btrfs-8077-stop-defrag-the-files-automatically-when-doin-.patch:
  Btrfs: stop defrag the files automatically when doin readonly
  remount or umount (FATE#306586).
- patches.suse/btrfs-8078-avoid-memory-leak-of-extent-state-in-error-han.patch:
  Btrfs: avoid memory leak of extent state in error handling
  routine (FATE#306586).
- patches.suse/btrfs-8079-make-sure-that-we-ve-made-everything-in-pinned.patch:
  Btrfs: make sure that we've made everything in pinned tree clean
  (FATE#306586).
- patches.suse/btrfs-8080-destroy-the-items-of-the-delayed-inodes-in-err.patch:
  Btrfs: destroy the items of the delayed inodes in error handling
  routine (FATE#306586).
- patches.suse/btrfs-8081-ulist-realloc-bugfix.patch: Btrfs:
  ulist realloc bugfix (FATE#306586).
- patches.suse/btrfs-8082-bugfix-in-btrfs_find_parent_nodes.patch:
  Btrfs: bugfix in btrfs_find_parent_nodes (FATE#306586).
- patches.suse/btrfs-8083-bugfix-ignore-the-wrong-key-for-indirect-tree-.patch:
  Btrfs: bugfix: ignore the wrong key for indirect tree block
  backrefs (FATE#306586).
* Tue May 29 2012 oneukum@suse.de
- patches.drivers/0001-USB-fix-bug-of-device-descriptor-got-from-superspeed.patch:
  USB: fix bug of device descriptor got from superspeed device
  (bnc#761087).
* Tue May 29 2012 jack@suse.cz
- patches.fixes/fs-only-send-IPI-to-invalidate-LRU-BH-when-needed.patch:
  fs: only send IPI to invalidate LRU BH when needed (bnc#763628
  bnc#744692).
- patches.fixes/smp-add-func-to-IPI-cpus-based-on-parameter-func.patch:
  smp: add func to IPI cpus based on parameter func (bnc#763628
  bnc#744692).
- patches.fixes/smp-introduce-a-generic-on_each_cpu_mask-function.patch:
  smp: introduce a generic on_each_cpu_mask() function (bnc#763628
  bnc#744692).
- commit 1c9e23f
* Mon May 28 2012 dsterba@suse.cz
- patches.suse/btrfs-8066-avoid-buffer-overrun-in-btrfs_printk.patch:
  Btrfs: avoid buffer overrun in btrfs_printk (FATE#306586).
- patches.suse/btrfs-8066-fall-back-to-non-inline-if-we-don-t-have-enoug.patch:
  Btrfs: fall back to non-inline if we don't have enough space
  (FATE#306586).
- patches.suse/btrfs-8067-NUL-terminate-path-buffer-in-DEV_INFO-ioctl-re.patch:
  Btrfs: NUL-terminate path buffer in DEV_INFO ioctl result
  (FATE#306586).
- patches.suse/btrfs-8068-avoid-buffer-overrun-in-mount-option-handling.patch:
  Btrfs: avoid buffer overrun in mount option handling
  (FATE#306586).
- patches.suse/btrfs-8070-do-not-do-balance-in-readonly-mode.patch:
  Btrfs: do not do balance in readonly mode (FATE#306586).
- patches.suse/btrfs-8072-fix-the-same-inode-id-problem-when-doing-auto-.patch:
  Btrfs: fix the same inode id problem when doing auto defragment
  (FATE#306586).
- patches.suse/btrfs-8073-fix-wrong-error-returned-by-adding-a-device.patch:
  Btrfs: fix wrong error returned by adding a device
  (FATE#306586).
- patches.suse/btrfs-8074-use-fastpath-in-extent-state-ops-as-much-as-po.patch:
  Btrfs: use fastpath in extent state ops as much as possible
  (FATE#306586).
* Mon May 28 2012 bpoirier@suse.de
- patches.fixes/xfrm-take-net-hdr-len-into-account-for-esp-payload-s.patch:
  xfrm: take net hdr len into account for esp payload size
  calculation (bnc#759545).
* Thu May 24 2012 lduncan@suse.de
- patches.fixes/st-clean-up-dev-cleanup-in-st_probe: st: clean
  up dev cleanup in st_probe (bnc#760806).
- patches.fixes/st-clean-up-device-file-creation-and-removal:
  st: clean up device file creation and removal (bnc#760806).
- patches.fixes/st-get-rid-of-scsi_tapes-array: st: get rid of
  scsi_tapes array (bnc#760806).
- patches.fixes/st-raise-device-limit: st: raise device limit
  (bnc#760806).
- patches.fixes/st-use-static-class-attributes: st: Use static
  class attributes (bnc#760806).
* Thu May 24 2012 mgorman@suse.de
- patches.fixes/cpuset-mm-optimise-put_mems_allowed-usage.patch:
  mm: Optimize put_mems_allowed() usage (VM performance).
* Thu May 24 2012 sjayaraman@suse.de
- patches.fixes/cifs-fix-oops-while-traversing-open-file-list.patch:
  cifs: fix oops while traversing open file list (try #4)
  (bnc#756050).
* Tue May 22 2012 jslaby@suse.de
- Linux 3.0.32.
- patches.drivers/hpsa-update-to-hp-version.patch: Refresh.
- patches.fixes/large-hash-dcache_init-fix.patch: Refresh.
- patches.kabi/kabi-hide-proc_fs-inclusion.patch: kabi: hide
  proc_fs.h inclusion.
- patches.suse/perfmon2-remove_syscalls.patch: Refresh.
- patches.suse/perfmon2.patch: Refresh.
- patches.drivers/0001-cdc_ether-Ignore-bogus-union-descriptor-for-RNDIS-de.patch:
  Delete.
- patches.drivers/tg3-Avoid-panic-from-reserved-statblk-field-access.patch:
  Delete.
- patches.fixes/ext3-Fix-error-handling-on-inode-bitmap-corruption.patch:
  Delete.
- patches.fixes/procfs-namespace-pid_ns-fix-leakage-on-fork-failure:
  Delete.
* Tue May 22 2012 hare@suse.de
- patches.fixes/scsi-fix-dm-multipath-starvation.patch: scsi:
  Fix dm-multipath starvation when scsi host is busy (bnc#763485).
* Tue May 22 2012 hare@suse.de
- patches.fixes/scsi_dh_rdac-update-match-function.patch:
  Disable patch due to deadlocks.
* Tue May 22 2012 hare@suse.de
- patches.suse/dasd-continue-device-tasklet.patch: dasd: process
  all requests in the device tasklet (bnc#763267).
* Mon May 21 2012 ohering@suse.de
- patches.suse/msft-hv-0348-net-hyperv-Adding-cancellation-to-ensure-rndis-filte.patch:
  net/hyperv: Adding cancellation to ensure rndis filter is closed.
* Mon May 21 2012 ohering@suse.de
- update hv drivers to 3.4-rc1, requires new hv_kvp_daemon:
- drivers: hv: kvp: Add/cleanup connector defines.
- drivers: hv: kvp: Move the contents of hv_kvp.h to hyperv.h.
- net/hyperv: Convert camel cased variables in rndis_filter.c
  to lower cases.
- net/hyperv: Correct the assignment in netvsc_recv_callback().
- net/hyperv: Remove the unnecessary memset in
  rndis_filter_send().
- drivers: hv: Cleanup the kvp related state in hyperv.h.
- tools: hv: Use hyperv.h to get the KVP definitions.
- drivers: hv: kvp: Cleanup the kernel/user protocol.
- drivers: hv: Increase the number of VCPUs supported in the
  guest.
- net/hyperv: Fix data corruption in rndis_filter_receive().
- net/hyperv: Add support for vlan trunking from guests.
- Drivers: hv: Add new message types to enhance KVP.
- Drivers: hv: Support the newly introduced KVP messages in
  the driver.
- Tools: hv: Fully support the new KVP verbs in the user level
  daemon.
- Tools: hv: Support enumeration from all the pools.
- net/hyperv: Fix the code handling tx busy.
* Fri May 18 2012 jkosina@suse.cz
- patches.drivers/floppy-convert-to-single-threaded-wq.patch:
  floppy: convert to delayed work and single-thread wq
  (bnc#761245).
* Fri May 18 2012 mmarek@suse.cz
- patches.drivers/rt2x00-add-RT539b: rt2x00:Add RT539b chipset
  support (bnc#760237).
* Fri May 18 2012 mmarek@suse.cz
- kabi/severities: Ignore changes in drivers/net/wireless/rt2x00/*,
  these are just exports used among the rt2x00 modules.
* Fri May 18 2012 mmarek@suse.cz
- patches.drivers/0001-rt2x00-Avoid-unnecessary-uncached: rt2x00:
  Avoid unnecessary uncached (bnc#759805).
- patches.drivers/0002-rt2x00-Introduce-sta_add-remove-callbacks:
  rt2x00: Introduce sta_add/remove callbacks (bnc#759805).
- patches.drivers/0003-rt2x00-Add-WCID-to-crypto-struct: rt2x00:
  Add WCID to crypto struct (bnc#759805).
- patches.drivers/0004-rt2x00-Add-WCID-to-HT-TX-descriptor:
  rt2x00: Add WCID to HT TX descriptor (bnc#759805).
- patches.drivers/0005-rt2x00-Move-bssidx-calculation-into-its-own-function:
  rt2x00: Move bssidx calculation into its own function
  (bnc#759805).
- patches.drivers/0006-rt2x00-Make-use-of-sta_add-remove-callbacks-in-rt2800:
  rt2x00: Make use of sta_add/remove callbacks in rt2800
  (bnc#759805).
- patches.drivers/0007-rt2x00-Forbid-aggregation-for-STAs-not-programmed-into-the-hw:
  rt2x00: Forbid aggregation for STAs not programmed into the hw
  (bnc#759805).
- patches.drivers/0009-rt2x00-handle-spurious-pci-interrupts:
  rt2x00: handle spurious pci interrupts (bnc#759805).
- patches.drivers/0011-rt2800-disable-DMA-after-firmware-load:
  rt2800: disable DMA after firmware load.
- patches.drivers/0012-rt2800-radio-3xxx-add-channel-switch-calibration-routines:
  rt2800: radio 3xxx: add channel switch calibration routines
  (bnc#759805).
* Fri May 18 2012 hare@suse.de
- Fixup patches for series2git:
  * patches.drivers/ehea-fix-allmulticast-support
  * patches.drivers/ehea-fix-promiscuous-mode
  * patches.drivers/ehea-register-irq-after-port-setup
* Thu May 17 2012 jkosina@suse.cz
- rpm/kernel-binary.spec.in: Obsolete ath3k, as it's now in the
  tree.
* Thu May 17 2012 jkosina@suse.cz
- patches.drivers/floppy-remove-floppy-specific-o_excl-handling.patch:
  floppy: remove floppy-specific O_EXCL handling (bnc#757315).
* Wed May 16 2012 mmarek@suse.cz
- patches.kabi/netfilter-really-export-nf_conntrack_event_cb:
  kabi: Really preserve nf_{conntract,expect}_event_cb exports
  (bnc#758540).
* Wed May 16 2012 jbeulich@novell.com
- Update Xen patches to 3.0.31.
- patches.xen/1174-foreign-map.patch: fix VM_FOREIGN users after
  c/s 878:eba6fe6d8d53 (bnc#760974).
- patches.xen/1175-gntdev-multi-page.patch: gntdev: fix multi-page
  slot allocation (bnc#760974).
- patches.xen/xen-x86-bigmem: Refresh (bnc#756236).
* Wed May 16 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-026-Add-Creative-CA0132-HDA-codec-support:
  ALSA: hda - Add Creative CA0132 HDA codec support (bnc#762424).
- patches.drivers/alsa-sp2-hda-027-Fix-error-handling-in-patch_ca0132_c:
  ALSA: hda - Fix error handling in patch_ca0132.c (bnc#762424).
- patches.drivers/alsa-sp2-hda-028-Add-the-support-for-Creative-SoundCore3D:
  ALSA: hda - Add the support for Creative SoundCore3D
  (bnc#762424).
- Update config files.
* Tue May 15 2012 tiwai@suse.de
- patches.drivers/rts_pstor-Avoid-Bad-target-number-message-wh:
  staging:rts_pstor:Avoid "Bad target number" message when
  probing driver (bnc#762329).
- patches.drivers/rts_pstor-Complete-scanning_done-variable:
  staging:rts_pstor:Complete scanning_done variable (bnc#762329).
- patches.drivers/rts_pstor-Fix-SDIO-issue: staging:rts_pstor:Fix
  SDIO issue (bnc#762329).
- patches.drivers/rts_pstor-Fix-a-bug-that-a-MMCPlus-card-can:
  staging: rts_pstor: Fix a bug that a MMCPlus card can't be
  accessed (bnc#762329).
- patches.drivers/rts_pstor-Fix-a-miswriting: staging: rts_pstor:
  Fix a miswriting (bnc#762329).
- patches.drivers/rts_pstor-Fix-possible-panic-by-NULL-pointer:
  staging:rts_pstor:Fix possible panic by NULL pointer dereference
  (bnc#762329).
- patches.drivers/rts_pstor-fix-thread-synchronization-flow:
  staging:rts_pstor: fix thread synchronization flow (bnc#762329).
- patches.drivers/rts_pstor-freezer-don-t-unnecessarily-set-PF_NOFREEZE:
  freezer: don't unnecessarily set PF_NOFREEZE explicitly
  (bnc#762329).
- patches.drivers/rts_pstor-off-by-one-in-for-loop: Staging:
  rts_pstor: off by one in for loop (bnc#762329).
* Tue May 15 2012 ohering@suse.de
- patches.suse/cgroup-disable-memcg-when-low-lowmem.patch:
  fix typo: use if defined(CONFIG_*) rather than if CONFIG_*
* Tue May 15 2012 jbohac@suse.cz
- patches.fixes/bonding-dont-increase-rx_dropped-after-processing-LACPDUs.patch:
  bonding: don't increase rx_dropped after processing LACPDUs
  (bnc#759657).
* Tue May 15 2012 tiwai@suse.de
- patches.drivers/drm-i915-delay-drm_irq_install-at-resume:
  drm/i915: delay drm_irq_install() at resume (bnc#753698).
* Tue May 15 2012 hare@suse.de
- patches.fixes/edd-check-for-correct-device_path_info_length.patch:
  EDD: Check for correct EDD 3.0 length (bnc#762285).
* Tue May 15 2012 mhocko@suse.cz
- patches.suse/pagecache-limit-fix-shmem-deadlock.patch: fix the BUG_ON
  safety belt
* Tue May 15 2012 mhocko@suse.cz
- patches.suse/pagecache-limit-fix-shmem-deadlock.patch: Fixed the
  GFP_NOWAIT is zero and not suitable for tests bug (bnc#755537)
* Tue May 15 2012 mkubecek@suse.cz
- patches.kabi/netfilter-additional-kABI-fix-after-making-event-cal.patch:
  netfilter: additional kABI fix after making event callback
  registration per-netns (bnc#758540).
- kabi/severities:
  revert changes from commit a0a5ba2e2dfeb4ee2a25f3196ae5dd4f142366a6
* Mon May 14 2012 dsterba@suse.cz
  btrfs updates, 3.4 fixes
- patches.suse/btrfs-0427-fix-uninit-variable-in-repair_eb_io_failure.patch:
  Btrfs: fix uninit variable in repair_eb_io_failure
  (FATE#306586).
- patches.suse/btrfs-0439-always-store-the-mirror-we-read-the-eb-from.patch:
  Btrfs: always store the mirror we read the eb from
  (FATE#306586).
- patches.suse/btrfs-0443-don-t-count-CRC-or-header-errors-twice-while-s.patch:
  Btrfs: don't count CRC or header errors twice while scrubbing
  (FATE#306586).
- patches.suse/btrfs-0445-do-not-start-delalloc-inodes-during-sync.patch:
  Btrfs: do not start delalloc inodes during sync (FATE#306586).
- patches.suse/btrfs-0446-fix-repair-code-for-RAID10.patch:
  Btrfs: fix repair code for RAID10 (FATE#306586).
- patches.suse/btrfs-0447-Prevent-root_list-corruption.patch:
  Btrfs: Prevent root_list corruption (FATE#306586).
- patches.suse/btrfs-0448-fix-block_rsv-and-space_info-lock-ordering.patch:
  Btrfs: fix block_rsv and space_info lock ordering (FATE#306586).
- patches.suse/btrfs-0449-Fix-space-checking-during-fs-resize.patch:
  Btrfs: Fix space checking during fs resize (FATE#306586).
- patches.suse/btrfs-0450-avoid-deadlocks-from-GFP_KERNEL-allocations-du.patch:
  Btrfs: avoid deadlocks from GFP_KERNEL allocations during
  btrfs_real_readdir (FATE#306586).
- patches.suse/btrfs-0451-reduce-lock-contention-during-extent-insertion.patch:
  Btrfs: reduce lock contention during extent insertion
  (FATE#306586).
- patches.suse/btrfs-0452-Add-properly-locking-around-add_root_to_dirty_.patch:
  Btrfs: Add properly locking around add_root_to_dirty_list
  (FATE#306586).
- patches.suse/btrfs-0453-Fix-mismatching-struct-members-in-ioctl.h.patch:
  btrfs: Fix mismatching struct members in ioctl.h (FATE#306586).
- patches.suse/btrfs-allow-cross-subvolume-file-clone.patch:
  Refresh.
* Mon May 14 2012 hare@suse.de
- patches.fixes/scsi_dh_rdac-update-match-function.patch:
  scsi_dh_rdac: Update match function to check page C8
  (bnc#757077).
* Mon May 14 2012 hare@suse.de
- patches.fixes/scsi_dh_rdac-add-new-netapp-id.patch:
  scsi_dh_rdac: Add new NetApp IDs (bnc#757077).
* Mon May 14 2012 duwe@suse.de
- patches.drivers/ehea-fix-losing-of-NEQ-events: ehea: fix losing
  of NEQ events when one event occurred early (bnc#758731).
* Mon May 14 2012 jlee@suse.com
- patches.drivers/igb-reset-PHY-after-recovering-from-PHY-power-down.patch:
  igb: reset PHY after recovering from PHY power down. (bnc#745088)
* Fri May 11 2012 bpoirier@suse.de
- patches.drivers/igb-fix-rtnl-race-in-PM-resume-path.patch:
  igb: fix rtnl race in PM resume path (bnc#748859).
- patches.drivers/ixgbe-add-missing-rtnl_lock-in-PM-resume-path.patch:
  ixgbe: add missing rtnl_lock in PM resume path (bnc#748859).
* Fri May 11 2012 jdelvare@suse.de
- patches.fixes/watchdog-iTCO_wdt-preserve-SMI-on-new-hardware.patch:
  watchdog: iTCO_wdt.c - problems with newer hardware due to
  SMI clearing (bnc#757373).
* Fri May 11 2012 jdelvare@suse.de
- patches.fixes/watchdog-iTCO_wdt-preserve-SMI-on-new-hardware.patch:
  watchdog: iTCO_wdt.c - problems with newer hardware due to
  SMI clearing (bnc#757373, redhat#727875).
* Fri May 11 2012 sjayaraman@suse.de
- patches.fixes/cfq-iosched-Reduce-linked-group-count-upon-group-des.patch:
  cfq-iosched: Reduce linked group count upon group destruction
  (bnc#759541).
* Fri May 11 2012 oneukum@suse.de
- patches.drivers/0001-cdc_ether-Ignore-bogus-union-descriptor-for-RNDIS-de.patch:
  cdc_ether: Ignore bogus union descriptor for RNDIS devices
  (bnc#761772).
* Thu May 10 2012 oneukum@suse.de
- patches.fixes/0001-USB-fix-resource-leak-in-xhci-power-loss-path.patch:
  USB: fix resource leak in xhci power loss path (bnc#746938).
* Thu May 10 2012 mszeredi@suse.cz
- patches.fixes/sys_poll-fix-incorrect-type-for-timeout-parameter.patch:
  sys_poll: fix incorrect type for 'timeout' parameter
  (bnc#754428).
* Thu May 10 2012 jjolly@suse.de
- patches.arch/s390-51-01-sclp-sdias-async.patch: zfcpdump:
  Implement async sdias event processing (bnc#761387,LTC#81330).
* Wed May  9 2012 jslaby@suse.de
- Linux 3.0.31.
- patches.arch/001-efi_pstore_fixes.patch: Refresh.
- patches.arch/003-efi_pstore_fixes.patch: Refresh.
- patches.drivers/003-pstore_3_2_fixes.patch: Refresh.
- patches.drivers/006-pstore_3_2_fixes.patch: Refresh.
- patches.drivers/hwmon-coretemp-01-add-core-pkg-threshold-support-to-coretemp.patch:
  Refresh.
- patches.drivers/hwmon-coretemp-04-let-the-user-force-tjmax.patch:
  Refresh.
- patches.drivers/hwmon-coretemp-05-dont-use-threshold-registers-for-tempX_max.patch:
  Refresh.
- patches.kabi/kabi-protect-struct-usb_hcd.patch: kABI: protect
  struct usb_hcd.
- patches.arch/002-efi_pstore_fixes.patch: Delete.
- patches.arch/006-efi_pstore_fixes.patch: Delete.
- patches.drivers/libata-skip-old-error-history-when-counting-probe-tr.patch:
  Delete.
- patches.fixes/0001-cdc-wdm-fix-race-leading-leading-to-memory-corruptio.patch:
  Delete.
* Wed May  9 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-025-Always-resume-the-codec-immediately:
  ALSA: hda - Always resume the codec immediately (bnc#750426).
- patches.drivers/alsa-sp2-hda-025-Set-codec-to-D3-forcibly-even-if-not-used:
  Delete.
* Wed May  9 2012 tiwai@suse.de
- patches.drivers/drm-i915-add-Ivy-Bridge-GT2-Server-entries:
  drm/i915: add Ivy Bridge GT2 Server entries (bnc#759971).
* Wed May  9 2012 mkubecek@suse.cz
- patches.fixes/netfilter-nf_conntrack-make-event-callback-registrat.patch:
  netfilter: nf_conntrack: make event callback registration
  per-netns (bnc#758540).
- patches.fixes/netfilter-kABI-fix-after-making-event-callback-regis.patch:
  netfilter: kABI fix after making event callback registration
  per-netns (bnc#758540).
- kabi/severities:
  ignore netfilter symbols touched by making event callback
  registration per-netns which are not supposed to be used
  by any third-party module (bnc#758540)
* Tue May  8 2012 bpoirier@suse.de
- patches.drivers/ixgbe-fix-ring-assignment-issues-for-SR-IOV-and-drop.patch:
  ixgbe: fix ring assignment issues for SR-IOV and drop cases
  (bnc#761158).
* Tue May  8 2012 trenn@suse.de
- patches.drivers/edac_amd_drop_too_granulary_family_model_checks.patch:
  MCE, AMD: Drop too granulary family model checks (bnc#758833).
- patches.drivers/edac_amd_print_cpu_number.patch: EDAC, MCE,
  AMD: Print CPU number when reporting the error (bnc#758833).
- patches.drivers/edac_amd_print_valid_addr.patch: EDAC, MCE,
  AMD: Print valid addr when reporting an error (bnc#758833).
* Tue May  8 2012 jlee@suse.com
- patches.drivers/libata-skip-old-error-history-when-counting-probe-tr.patch:
  libata: skip old error history when counting probe trials.
* Mon May  7 2012 jkosina@suse.cz
- patches.suse/kdb-restore-kdb-stack-trace.patch: x86: kdb:
  restore kdb stack trace (bnc#760015).
* Fri May  4 2012 dsterba@suse.cz
- patches.suse/btrfs-revert-partial-truncate-improvements.patch:
  btrfs: partial revert of truncation improvements (FATE#306586
  bnc#748463 bnc#760279).
- patches.suse/btrfs-update-message-levels.patch: Refresh.
* Fri May  4 2012 bpoirier@suse.de
- patches.drivers/tg3-Avoid-panic-from-reserved-statblk-field-access.patch:
  tg3: Avoid panic from reserved statblk field access
  (bnc#760346).
* Fri May  4 2012 mgalbraith@suse.de
- patches.fixes/procfs-namespace-pid_ns-fix-leakage-on-fork-failure: Refresh.
  Whack proc_fs.h include to fix odd kABI gripe.  Oddly enough, the prototype isn't
  needed to build this kernel even with -Werror=implicit-function-declaration.  No
  gripe, nada, just works.  Upstream it is required.
  KABI: symbol __mmdrop(kernel/fork/built-in) changed crc from 0xbf464b89 to 0xa4b0b91f
  KABI: symbol __put_task_struct(kernel/fork/built-in) changed crc from 0xb64f68c2 to 0x13181232
  KABI: symbol free_task(kernel/fork/built-in) changed crc from 0xa4879a04 to 0x72b0d120
  KABI: symbol get_task_mm(kernel/fork/built-in) changed crc from 0xbfee2b4e to 0x8495fbe4
  KABI: symbol mmput(kernel/fork/built-in) changed crc from 0xef280caf to 0x0b59f5be
  KABI: aborting due to kabi changes.
* Fri May  4 2012 mgalbraith@suse.de
- patches.fixes/procfs-namespace-pid_ns-fix-leakage-on-fork-failure:
  procfs, namespace, pid_ns: fix leakage upon fork() failure (bnc#757783).
* Thu May  3 2012 duwe@suse.de
- patches.drivers/ehea-fix-allmulticast-support: ehea: fix
  allmulticast support,
- patches.drivers/ehea-fix-promiscuous-mode: ehea: fix promiscuous
  mode (both bnc#757289)
- patches.drivers/ehea-register-irq-after-port-setup: ehea:
  only register irq after setting up ports (bnc#758731).
* Thu May  3 2012 hare@suse.de
- patches.suse/dasd-detailed-io-errors.patch: Rediff.
* Wed May  2 2012 hare@suse.de
- patches.suse/dasd-blk-timeout.patch: Fixup typos in
  dasd_times_out().
* Wed May  2 2012 hare@suse.de
- patches.suse/dasd-blk-timeout.patch: Fix I/O stall
  when reserving dasds (bnc#757719).
- patches.suse/dasd-detailed-io-errors.patch: Rediff.
* Wed May  2 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not require distribution-release
  during build.
* Wed May  2 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Depend on distribution-release, so that
  the grub entry has correct title (bnc#757565).
* Wed May  2 2012 jack@suse.cz
- patches.suse/scsi-silence-ioctl-warnings.patch: scsi: Silence
  unnecessary warnings about ioctl to partition (bnc#758104).
* Mon Apr 30 2012 oneukum@suse.de
- patches.fixes/Add_support_for_Foxconn_Hon_Hai_AR5BBU22.diff:
  bluetooth: Add support for Foxconn/Hon Hai AR5BBU22 0489:E03C
  (bnc#759908).
* Fri Apr 27 2012 jslaby@suse.de
- Linux 3.0.30.
- patches.drivers/USB3-0022-USB-EHCI-remove-usages-of-hcd-state.patch:
  Refresh.
- patches.suse/btrfs-0192-add-a-log-of-past-tree-roots.patch:
  Refresh.
- patches.arch/mm-s390-use-__set_page_dirty_no_writeback-on-swap.patch:
  Delete.
- patches.drivers/0001-uwb-fix-error-handling.patch: Delete.
- patches.drivers/0001-uwb-fix-use-of-del_timer_sync-in-interrupt.patch:
  Delete.
- patches.drivers/0013-rt2x00-Properly-identify-rt2800usb-devices.patch:
  Delete.
- patches.drivers/0015-rt2800usb-Add-new-device-ID-for-Belkin.patch:
  Delete.
- patches.fixes/epoll-dont-limit-non-nested.patch: Delete.
* Fri Apr 27 2012 trenn@suse.de
- patches.arch/x86_amd_add_translation_cache_extension_tce_cpuflag.patch:
  x86/amd: Add missing feature flag for fam15h models 10h-1fh
  processors (bnc#759340).
- patches.arch/x86_amd_correct_cpuinfo_for_cpb_and_eff_freq_ro.patch:
  x86: Report cpb and eff_freq_ro flags correctly (bnc#759340).
- patches.arch/x86_amd_numa_node_info_fam_15.patch: x86, amd:
  Fix up numa_node information for AMD CPU family 15h model
  0-0fh northbridge functions (bnc#759340).
- patches.arch/x86_amd_remove_misleading_message.patch: x86/PCI:
  amd: Kill misleading message about enablement of IO access to
  PCI ECS] (bnc#759340).
* Fri Apr 27 2012 oneukum@suse.de
- patches.fixes/0001-cdc-wdm-fix-race-leading-leading-to-memory-corruptio.patch:
  cdc-wdm: fix race leading leading to memory corruption
  (bnc#759539).
* Thu Apr 26 2012 hare@suse.de
- patches.fixes/0001-usbhid-fix-error-handling-of-not-enough-bandwidth.patch:
  Fixup patch for series2git.
* Thu Apr 26 2012 bpoirier@suse.de
- patches.drivers/tlan-add-cast-needed-for-proper-64-bit-operation.patch:
  tlan: add cast needed for proper 64 bit operation (bnc#756840).
* Wed Apr 25 2012 jeffm@suse.com
- patches.fixes/dl2k-tighten-ioctl-permissions: dl2k: Tighten
  ioctl permissions (bnc#758813).
* Wed Apr 25 2012 hare@suse.de
- patches.suse/md-bm-20-bitmap-add-bitmap_resize-function-to-allow-bitmap.patch:
  Add missing EXPORT_SYMBOL.
* Wed Apr 25 2012 mkubecek@suse.cz
- patches.fixes/bonding-update-speed-duplex-for-NETDEV_CHANGE.patch:
  bonding:update speed/duplex for NETDEV_CHANGE (bnc#752634).
- patches.fixes/bonding-comparing-a-u8-with-1-is-always-false.patch:
  bonding: comparing a u8 with -1 is always false (bnc#752634).
- patches.fixes/bonding-start-slaves-with-link-down-for-ARP-monitor.patch:
  bonding: start slaves with link down for ARP monitor
  (bnc#752634).
* Wed Apr 25 2012 ptesarik@suse.cz
- patches.arch/x86-physnode_map-init.patch: x86: fix the
  initialization of physnode_map (bnc#748112).
* Wed Apr 25 2012 jbeulich@novell.com
- patches.xen/1157-blkfront-per-device-io-lock.patch: blkfront:
  make blkif_io_lock spinlock per-device.
- patches.xen/1171-blkback-streamline-main-loop.patch: blkback:
  streamline main processing loop (fate#309305).
- patches.xen/xen-blkback-discard: blkback: Implement discard
  requests handling (fate#309305).
- patches.xen/xen-blkback-discard-secure: blkback: Enhance
  discard support with secure erasing support (fate#309305).
- patches.xen/xen-blkfront-cdrom: Refresh.
- patches.xen/xen-blkfront-discard: blkfront: Handle discard
  requests (fate#309305).
- patches.xen/xen-blkfront-discard-secure: blkfront: Enhance
  discard support with secure erasing support (fate#309305).
- patches.xen/xen-blkif-discard: blkif: support discard
  (fate#309305).
- patches.xen/xen-blkif-discard-secure: blkif: Enhance discard
  support with secure erasing support (fate#309305).
- Refresh other Xen patches.
* Wed Apr 25 2012 jjolly@suse.de
- patches.arch/s390-50-01-af_iucv-netdev-event.patch:
  af_iucv: detect down state of HS transport interface
  (bnc#758279,LTC#80859).
- patches.arch/s390-50-02-af_iucv-shutdown.patch: af_iucv:
  allow shutdown for HS transport sockets (bnc#758279,LTC#80860).
* Tue Apr 24 2012 dsterba@suse.cz
- patches.suse/btrfs-0428-fix-eof-while-discarding-extents.patch:
  Btrfs: fix eof while discarding extents (FATE#306586).
- patches.suse/btrfs-0429-check-return-value-of-bio_alloc-properly.patch:
  Btrfs: check return value of bio_alloc() properly (FATE#306586).
- patches.suse/btrfs-0430-add-missing-free_fs_devices.patch:
  (FATE#306586 FATE#306586).
- patches.suse/btrfs-0431-retrurn-void-from-clear_state_bit.patch:
  Btrfs: retrurn void from clear_state_bit (FATE#306586).
- patches.suse/btrfs-0432-avoid-possible-use-after-free-in-clear_extent_.patch:
  Btrfs: avoid possible use-after-free in clear_extent_bit()
  (FATE#306586).
- patches.suse/btrfs-0433-Make-free_ipath-deal-gracefully-with-NULL-poin.patch:
  Btrfs: Make free_ipath() deal gracefully with NULL pointers
  (FATE#306586).
- patches.suse/btrfs-0434-don-t-call-free_extent_buffer-twice-in-iterate.patch:
  Btrfs: don't call free_extent_buffer twice in iterate_irefs
  (FATE#306586).
- patches.suse/btrfs-0435-add-missing-read-locks-in-backref.c.patch:
  Btrfs: add missing read locks in backref.c (FATE#306586).
- patches.suse/btrfs-0436-fix-max-chunk-size-check-in-chunk-allocator.patch:
  Btrfs: fix max chunk size check in chunk allocator
  (FATE#306586).
- patches.suse/btrfs-0440-double-unlock-bug-in-error-handling.patch:
  Btrfs: double unlock bug in error handling (FATE#306586).
- patches.suse/btrfs-0441-don-t-return-EINTR.patch: btrfs:
  don't return EINTR (FATE#306586).
- patches.suse/btrfs-0442-fix-btrfs_ioctl_dev_info-crash-on-missing-devi.patch:
  Btrfs: fix btrfs_ioctl_dev_info() crash on missing device
  (FATE#306586).
- patches.suse/btrfs-0444-fix-that-check_int_data-mount-option-was-ignor.patch:
  Btrfs: fix that check_int_data mount option was ignored
  (FATE#306586).
- patches.suse/btrfs-1016-add-skip_balance-mount-option.patch:
  Refresh.
- patches.suse/btrfs-handle-EIO: Refresh.
- patches.suse/btrfs-8066-avoid-possible-use-after-free-in-clear_extent_.patch:
  Delete.
- patches.suse/btrfs-8067-retrurn-void-from-clear_state_bit.patch:
  Delete.
* Tue Apr 24 2012 mgalbraith@suse.de
- patches.fixes/sched-rt-Fix-isolated-CPUs-leaving-root_task_group-indefinitely-throttled.patch:
  sched,rt: fix isolated CPUs leaving root_task_group indefinitely throttled (bnc#754085).
* Tue Apr 24 2012 mgalbraith@suse.de
- Fix SLE11-SP1->SLE11-SP2 interrupt latency regression.
  Revert 0209f649, and turn tick skew on globally, since 0209f649
  came about to mitigate lock contention that skew removal induces,
  both on xtime_lock and on RCU leaf node locks.
  NOTE: This change trades ~400%% latency regression fix for power
  consumption progression that skew removal bought (at high cost).
- patches.fixes/rcu-Revert-limit-rcu_node-leaf-level-fanout.patch:
  Revert mainline 0209f649 - rcu: limit rcu_node leaf-level fanout (bnc#718521).
- patches.fixes/clockevents-Reinstate-the-per-cpu-tick-skew.patch: Refresh.
* Tue Apr 24 2012 mgorman@suse.de
- patches.fixes/mm-hugetlbfs-fix-use-after-free-bug-in-quota-handling.patch:
  hugepages: fix use after free bug in "quota" handling
  (CVE-2012-2133 bnc#758532)
* Tue Apr 24 2012 nfbrown@suse.de
- patches.fixes/md-no-readonly.fix: md: fix possible corruption
  of array metadata on shutdown.
* Mon Apr 23 2012 jslaby@suse.de
- Linux 3.0.29.
- patches.arch/s390-add-FREE_PTE_NR: Refresh.
- patches.drivers/USB3-0147-xHCI-Check-host-USB2-LPM-capability.patch:
  Refresh.
- patches.drivers/USB3-0156-usb-xhci-replace-pci_-_consistent-with-dma_-_coherent.patch:
  Refresh.
- patches.drivers/USB3-0157-usb-xhci-refactor-xhci_pci_setup.patch:
  Refresh.
- patches.drivers/cciss-update-to-4.6.28.patch: Refresh.
- patches.drivers/0001-USB-sierra-add-support-for-Sierra-Wireless-MC7710.patch:
  Delete.
- patches.drivers/Bluetooth_Fixed_Atheros_AR3012_Maryann_PID_VID_supported.patch:
  Delete.
- patches.drivers/bug-732296_ath3k-Add-Atheros-AR3012-Maryann-PID-VID-supported.patch:
  Delete.
- patches.drivers/bug-732296_btusb-Add-Atheros-AR3012-Maryann-PID-VID-supported.patch:
  Delete.
- patches.fixes/md-bitmap-init-lock: Delete.
* Mon Apr 23 2012 tiwai@suse.de
- patches.drivers/drm-edid-Add-a-workaround-for-1366x768-HD-panel:
  drm/edid: Add a workaround for 1366x768 HD panel (bnc#753172).
- patches.drivers/drm-edid-Add-extra_modes: drm/edid: Add
  extra_modes (bnc#753172).
- patches.drivers/drm-edid-Add-packed-attribute-to-new-gtf2-and-cvt-structs:
  drm/edid: Add packed attribute to new gtf2 and cvt structs
  (bnc#753172).
- patches.drivers/drm-edid-Add-the-reduced-blanking-DMT-modes-to-the-D:
  drm/edid: Add the reduced blanking DMT modes to the DMT list
  (bnc#753172).
- patches.drivers/drm-edid-Allow-drm_mode_find_dmt-to-hunt-for-reduced:
  drm/edid: Allow drm_mode_find_dmt to hunt for reduced-blanking
  modes (bnc#753172).
- patches.drivers/drm-edid-Do-drm_dmt_modes_for_range-for-all-range-de:
  drm/edid: Do drm_dmt_modes_for_range() for all range descriptor
  types (bnc#753172).
- patches.drivers/drm-edid-Document-drm_mode_find_dmt: drm/edid:
  Document drm_mode_find_dmt (bnc#753172).
- patches.drivers/drm-edid-Fix-some-comment-typos-in-the-DMT-mode-list:
  drm/edid: Fix some comment typos in the DMT mode list
  (bnc#753172).
- patches.drivers/drm-edid-Generate-modes-from-extra_modes-for-range-d:
  drm/edid: Generate modes from extra_modes for range descriptors
  (bnc#753172).
- patches.drivers/drm-edid-Give-the-est3-mode-struct-a-real-name:
  drm/edid: Give the est3 mode struct a real name (bnc#753172).
- patches.drivers/drm-edid-Remove-a-misleading-comment: drm/edid:
  Remove a misleading comment (bnc#753172).
- patches.drivers/drm-edid-Rewrite-drm_mode_find_dmt-search-loop:
  drm/edid: Rewrite drm_mode_find_dmt search loop (bnc#753172).
- patches.drivers/drm-edid-Update-range-descriptor-struct-for-EDID-1.4:
  drm/edid: Update range descriptor struct for EDID 1.4
  (bnc#753172).
- patches.drivers/drm-edid-add-missing-NULL-checks: drm/edid:
  add missing NULL checks (bnc#753172).
- patches.drivers/drm-edid-s-drm_gtf_modes_for_range-drm_dmt_modes_for:
  drm/edid: s/drm_gtf_modes_for_range/drm_dmt_modes_for_range/
  (bnc#753172).
- patches.kabi/drm-edid-kabi-fix: Fix kABI for drm EDID
  improvement patches (bnc#753172).
* Mon Apr 23 2012 mgorman@suse.de
- patches.suse/SoN-0017-mm-Add-support-for-a-filesystem-to-control-swap-file.patch
- patches.suse/SoN-0018-mm-swap-Implement-generic-handlers-for-swap-related-.patch
  Refresh
- patches.arch/mm-s390-use-__set_page_dirty_no_writeback-on-swap.patch:
  mm: s390: Fix BUG by using __set_page_dirty_no_writeback on swap.
  (bnc#751550)
* Sun Apr 22 2012 jeffm@suse.com
- patches.fixes/mqueue-fix-a-vfsmount-longterm-reference-leak:
  mqueue: fix a vfsmount longterm reference leak (bnc#757783).
* Sun Apr 22 2012 jeffm@suse.com
- patches.fixes/cciss-add-irqf_shared-back-in-for-the-non-msix-interrupt-handler:
  cciss: Add IRQF_SHARED back in for the non-MSI(X) interrupt
  handler (bnc#757789).
* Sun Apr 22 2012 jeffm@suse.com
- patches.fixes/procfs-fix-a-vfsmount-longterm-reference-leak:
  procfs: fix a vfsmount longterm reference leak (bnc#757783).
* Fri Apr 20 2012 tiwai@suse.de
- patches.drivers/drm-i915-lvds-add-standard-modes.diff: Refresh.
  Fix the case where multiple modes are returned from EDID
  (bnc#753172)
* Thu Apr 19 2012 bpoirier@suse.de
- patches.drivers/tg3-Fix-5717-serdes-powerdown-problem.patch:
  tg3: Fix 5717 serdes powerdown problem (bnc#756940).
- patches.drivers/tg3-Fix-RSS-ring-refill-race-condition.patch:
  tg3: Fix RSS ring refill race condition (bnc#756940).
- patches.drivers/tg3-Fix-single-vector-MSI-X-code.patch: tg3:
  Fix single-vector MSI-X code (bnc#756940).
- patches.drivers/tg3-fix-ipv6-header-length-computation.patch:
  tg3: fix ipv6 header length computation (bnc#756940).
* Thu Apr 19 2012 mmarek@suse.cz
- patches.drivers/drm-i915-lvds-add-standard-modes.diff: drm/i915:
  Add more standard modes to LVDS output (bnc#753172).
* Thu Apr 19 2012 hare@suse.de
- patches.fixes/scsi_dh_alua-Optimize-stpg-command.patch:
  scsi_dh_alua: Optimize stpg command (bnc#744758).
- patches.fixes/scsi_dh_alua-Store-pref-bit-from-RTPG.patch:
  scsi_dh_alua: Store 'pref' bit from RTPG (bnc#755758).
- patches.fixes/scsi_dh_alua-set_params-interface.patch:
  scsi_dh_alua: set_params interface (bnc#755758).
* Thu Apr 19 2012 oneukum@suse.de
- patches.drivers/0001-uwb-fix-error-handling.patch: uwb: fix
  error handling (bnc#757950).
- patches.drivers/0001-uwb-fix-use-of-del_timer_sync-in-interrupt.patch:
  uwb: fix use of del_timer_sync() in interrupt (bnc#757950).
* Wed Apr 18 2012 jbohac@suse.cz
- patches.fixes/ipv6-fix-problem-with-expired-dst-cache.patch:
  Update patch header.
* Wed Apr 18 2012 oneukum@suse.de
- patches.fixes/0001-usbhid-fix-error-handling-of-not-enough-bandwidth.patch:
  usbhid: fix error handling of not enough bandwidth (bnc#704280).
* Wed Apr 18 2012 mgorman@suse.de
- patches.fixes/mm-test-PageSwapBacked-in-lumpy-reclaim.patch:
- patches.fixes/mm-vmscan-activate-executable-pages-after-first-usage.patch:
- patches.fixes/mm-vmscan-promote-shared-file-mapped-pages.patch:
- patches.fixes/mm-vmscan-trace-Add-file-info-to-trace_mm_vmscan_lru_isolate.patch:
- patches.fixes/mm-vmscan.c-consider-swap-space-when-deciding-whether-to-continue-reclaim.patch:
- patches.fixes/mm-vmscan-do-not-force-scan.patch
  Improve preservation of page-age information (bnc#754690)
* Tue Apr 17 2012 mhocko@suse.cz
- patches.suse/pagecache-limit-fix-shmem-deadlock.patch: pagecache
  limit: Fix the shmem deadlock (bnc#755537).
* Tue Apr 17 2012 oneukum@suse.de
- patches.drivers/0001-USB-sierra-add-support-for-Sierra-Wireless-MC7710.patch:
  USB: sierra: add support for Sierra Wireless MC7710
  (bnc#757517).
* Mon Apr 16 2012 rjw@suse.de
- patches.arch/x86-iommu-intel-Fix-identity-mapping-for-sandy-bridge.patch:
  x86/iommu/intel: Fix identity mapping for sandy bridge
  (bnc#743232).
* Mon Apr 16 2012 jslaby@suse.de
- Linux 3.0.28.
- patches.fixes/pci_use_acpi_resources_whitelist.patch: Refresh.
- patches.drivers/bug-708836_bluetooth-l2cap-security-race.patch:
  Delete.
- patches.drivers/drm-i915-Sanitize-BIOS-debugging-bits: Delete.
* Sat Apr 14 2012 jbohac@suse.cz
- patches.fixes/ipv6-check-dest-prefix-length-on-original-route.patch:
  ipv6: Check dest prefix length on original route not copied
  one in rt6_alloc_cow() (bnc#757202).
- patches.fixes/ipv6-dont-use-inetpeer-to-store-metrics-for-routes.patch:
  ipv6: don't use inetpeer to store metrics for routes
  (bnc#757202).
- patches.fixes/ipv6-fix-problem-with-expired-dst-cache.patch:
  ipv6: fix problem with expired dst cache (bnc#757205).
- patches.fixes/ipv6-unshare-inetpeers.patch: unshare inetpeers.
* Fri Apr 13 2012 bpoirier@suse.de
- patches.fixes/bridge-correct-IPv6-checksum-after-pull.patch:
  bridge: correct IPv6 checksum after pull (bnc#738644).
* Fri Apr 13 2012 mmarek@suse.cz
- patches.drivers/cxgb4_collect_flush_cq_on_close.patch: Update
  references (bnc#721857).
- patches.drivers/cxgb4_serialize_comp_handler_calls.patch:
  Update references (bnc#721857).
* Fri Apr 13 2012 dsterba@suse.cz
- patches.suse/btrfs-8061-handle-errors-from-read_tree_block.patch:
  fix broken condition (bnc#756821)
* Fri Apr 13 2012 jbeulich@novell.com
- patches.fixes/hv-storvsc-reset-wait.patch: Drivers: scsi:
  storvsc: Account for in-transit packets in the RESET path.
* Fri Apr 13 2012 jjolly@suse.de
- patches.arch/s390-49-01-qeth-fix-OSA4-blkt.patch: qeth:
  Improve OSA Express 4 blkt defaults (bnc#754969,LTC#80325).
- patches.arch/s390-49-02-zcrypt-fix_copro_cprb_check.patch:
  zcrypt: Fix parameter checking for ZSECSENDCPRB ioctl
  (bnc#754969,LTC#80378).
* Thu Apr 12 2012 nfbrown@suse.de
- patches.fixes/md-bitmap-init-lock: md/bitmap: prevent
  bitmap_daemon_work running while initialising bitmap.
* Thu Apr 12 2012 nfbrown@suse.de
- patches.fixes/md-bitmap-hot-add.fix: Delete. Equivalent
  patch came in with 3.0.27
* Wed Apr 11 2012 mgorman@suse.de
- patches.fixes/mm-mempolicy.c-fix-pgoff-in-mbind-vma-merge.patch:
- patches.fixes/mm-mempolicy.c-refix-mbind_range-vma-issue.patch:
  Fix vma merging issue during mbind affecting JVMs.
* Wed Apr 11 2012 mmarek@suse.cz
- Sync kabi files for s390x (symsets and symtypes were outdated).
* Wed Apr 11 2012 dsterba@suse.cz
  btrfs fixes
- patches.suse/btrfs-0408-add-get_restripe_target-helper.patch:
  Refresh.
- patches.suse/btrfs-0409-add-__get_block_group_index-helper.patch:
  Refresh.
- patches.suse/btrfs-8065-do-not-mount-when-we-have-a-sectorsize-unequal.patch:
  Btrfs: do not mount when we have a sectorsize unequal to
  PAGE_SIZE (FATE#306586).
- patches.suse/btrfs-8066-avoid-possible-use-after-free-in-clear_extent_.patch:
  Btrfs: avoid possible use-after-free in clear_extent_bit()
  (FATE#306586).
- patches.suse/btrfs-8067-retrurn-void-from-clear_state_bit.patch:
  Btrfs: retrurn void from clear_state_bit (FATE#306586).
- patches.suse/btrfs-handle-EIO: Refresh.
* Tue Apr 10 2012 nfbrown@suse.de
- patches.fixes/md-record-write-mostly-status: md: ensure changes
  to 'write-mostly' are reflected in metadata (bnc#755178).
* Fri Apr  6 2012 trenn@suse.de
- patches.drivers/apei_check_acc_width_allow_not_byte_alligned_bit_offset.patch:
  ACPI, APEI: Fix incorrect APEI register bit width check and
  usage (bnc#725592).
* Thu Apr  5 2012 bpoirier@suse.de
- patches.drivers/vmxnet3-cap-copy-length-at-size-of-skb-to-prevent-dr.patch:
  vmxnet3: cap copy length at size of skb to prevent dropped
  frames on tx (bnc#755812).
* Wed Apr  4 2012 dsterba@suse.cz
  btrfs updates
- patches.suse/btrfs-0400-Fix-typo-in-free-space-cache.c.patch:
  btrfs: Fix typo in free-space-cache.c (FATE#306586).
- patches.suse/btrfs-0401-remove-the-ideal-caching-code.patch:
  Btrfs: remove the ideal caching code (FATE#306586).
- patches.suse/btrfs-0402-remove-search_start-and-search_end-from-find_f.patch:
  Btrfs: remove search_start and search_end from find_free_extent
  and callers (FATE#306586).
- patches.suse/btrfs-0403-adjust-the-write_lock_level-as-we-unlock.patch:
  Btrfs: adjust the write_lock_level as we unlock (FATE#306586).
- patches.suse/btrfs-0409-add-__get_block_group_index-helper.patch:
  Refresh.
- patches.suse/btrfs-0415-actually-call-btrfs_init_lockdep.patch:
  Btrfs: actually call btrfs_init_lockdep (FATE#306586).
- patches.suse/btrfs-0417-fix-regression-in-scrub-path-resolving.patch:
  Btrfs: fix regression in scrub path resolving (FATE#306586).
- patches.suse/btrfs-0418-show-useful-info-in-space-reservation-tracepoi.patch:
  Btrfs: show useful info in space reservation tracepoint
  (FATE#306586).
- patches.suse/btrfs-0419-flush-out-and-clean-up-any-block-device-pages-.patch:
  Btrfs: flush out and clean up any block device pages during
  mount (FATE#306586).
- patches.suse/btrfs-0420-fix-deadlock-during-allocating-chunks.patch:
  Btrfs: fix deadlock during allocating chunks (FATE#306586).
- patches.suse/btrfs-0421-fix-race-between-direct-io-and-autodefrag.patch:
  Btrfs: fix race between direct io and autodefrag (FATE#306586).
- patches.suse/btrfs-0422-fix-the-mismatch-of-page-mapping.patch:
  Btrfs: fix the mismatch of page->mapping (FATE#306586).
- patches.suse/btrfs-0423-fix-recursive-defragment-with-autodefrag-optio.patch:
  Btrfs: fix recursive defragment with autodefrag option
  (FATE#306586).
- patches.suse/btrfs-0424-add-a-check-to-decide-if-we-should-defrag-the-.patch:
  Btrfs: add a check to decide if we should defrag the range
  (FATE#306586).
- patches.suse/btrfs-0425-do-not-bother-to-defrag-an-extent-if-it-is-a-b.patch:
  Btrfs: do not bother to defrag an extent if it is a big real
  extent (FATE#306586).
- patches.suse/btrfs-0426-update-to-the-right-index-of-defragment.patch:
  Btrfs: update to the right index of defragment (FATE#306586).
- patches.suse/btrfs-handle-EIO: Refresh.
* Wed Apr  4 2012 jbeulich@novell.com
- patches.xen/1166-smpboot-ordering.patch: smpboot: adjust
  ordering of operations.
- patches.xen/1167-x86_64-memset.patch: x86-64: provide a memset()
  that can deal with 4Gb or above at a time (bnc#738528).
- Update Xen patches to 3.0.27.
* Tue Apr  3 2012 dsterba@suse.cz
- patches.suse/btrfs-8064-Fix-use-after-free-in-__btrfs_end_transaction.patch:
  btrfs: Fix use-after-free in __btrfs_end_transaction
  (FATE#306586).
* Tue Apr  3 2012 dsterba@suse.cz
  btrfs updates: restriper fixes
- patches.suse/btrfs-0404-stop-silently-switching-single-chunks-to-raid0.patch:
  Btrfs: stop silently switching single chunks to raid0 on balance
  (FATE#306586).
- patches.suse/btrfs-0405-add-wrappers-for-working-with-alloc-profiles.patch:
  Btrfs: add wrappers for working with alloc profiles
  (FATE#306586).
- patches.suse/btrfs-0406-make-profile_is_valid-check-more-strict.patch:
  Btrfs: make profile_is_valid() check more strict (FATE#306586).
- patches.suse/btrfs-0407-move-alloc_profile_is_valid-to-volumes.c.patch:
  Btrfs: move alloc_profile_is_valid() to volumes.c (FATE#306586).
- patches.suse/btrfs-0408-add-get_restripe_target-helper.patch:
  Btrfs: add get_restripe_target() helper (FATE#306586).
- patches.suse/btrfs-0409-add-__get_block_group_index-helper.patch:
  Btrfs: add __get_block_group_index() helper (FATE#306586).
- patches.suse/btrfs-0410-improve-the-logic-in-btrfs_can_relocate.patch:
  Btrfs: improve the logic in btrfs_can_relocate() (FATE#306586).
- patches.suse/btrfs-0411-validate-target-profiles-only-if-we-are-going-.patch:
  Btrfs: validate target profiles only if we are going to use them
  (FATE#306586).
- patches.suse/btrfs-0412-allow-dup-for-data-chunks-in-mixed-mode.patch:
  Btrfs: allow dup for data chunks in mixed mode (FATE#306586).
- patches.suse/btrfs-0413-fix-memory-leak-in-resolver-code.patch:
  Btrfs: fix memory leak in resolver code (FATE#306586).
- patches.suse/btrfs-0414-fix-infinite-loop-in-btrfs_shrink_device.patch:
  Btrfs: fix infinite loop in btrfs_shrink_device() (FATE#306586).
- patches.suse/btrfs-8055-stop-silently-switching-single-chunks-to-raid0.patch:
  Delete.
* Tue Apr  3 2012 tiwai@suse.de
- patches.drivers/drm-i915-lvds-disable-at-modeset-for-hp-probook:
  drm/i915: Disable LVDS at mode change (bnc#752022).
* Mon Apr  2 2012 jslaby@suse.de
- Linux 3.0.27.
- patches.drivers/target-0030-target-Make-all-control-CDBs-scatter-gather.patch:
  Refresh.
- patches.kernel.org/revert-ASPM-Fix-pcie-devices-with-non-pcie-children.patch:
  Revert "ASPM: Fix pcie devices with non-pcie children".
- patches.kernel.org/revert-net-fix-a-potential-rcu_read_lock-imbalance-i.patch:
  Revert "net: fix a potential rcu_read_lock() imbalance in
  rt6_fill_node()".
- patches.drivers/0001-Bluetooth-btusb-fix-bInterval-for-high-super-speed-i.patch:
  Delete.
- patches.drivers/drm-i915-suspend-fbdev-device-around-suspend-hiberna:
  Delete.
- patches.fixes/jbd2-clear-BH_Delay-BH_Unwritten-in-journal_unmap_buffer.patch:
  Delete.
- patches.fixes/kvm-KVM-x86-extend-struct-x86_emulate_ops-with-get_cpuid.patch:
  Delete.
- patches.fixes/kvm-KVM-x86-fix-missing-checks-in-syscall-emulation.patch:
  Delete.
- patches.fixes/lockd-arg-parse.fix: Delete.
- patches.fixes/mm-sparsemem-bootmem-catch-greater-than-section-size-allocations.patch:
  Delete.
- patches.fixes/mm-thp-fix-pmd_bad-triggering-in-code-paths-holding-mmap_sem-read-mode.patch:
  Delete.
- patches.fixes/xfs-Fix-oops-on-IO-error-during-xlog_recover_process.patch:
  Delete.
* Mon Apr  2 2012 mmarek@suse.cz
- patches.drivers/rt2x00-Fix-rfkill_polling-register-function:
  rt2x00: rt2x00dev: move rfkill_polling register to proper place
  (bnc#748806).
* Mon Apr  2 2012 dsterba@suse.cz
- patches.suse/btrfs-8063-error-handling-locking-fixup.patch:
  btrfs: error handling locking fixup (FATE#306586).
* Fri Mar 30 2012 jdelvare@suse.de
- patches.fixes/ipmi-fix-deadlock-in-start_next_msg.patch:
  Refresh.
* Thu Mar 29 2012 tiwai@suse.de
- patches.drivers/drm-i915-suspend-fbdev-device-around-suspend-hiberna:
  drm/i915: suspend fbdev device around suspend/hibernate
  (bnc#732908).
* Thu Mar 29 2012 dsterba@suse.cz
- patches.suse/btrfs-8059-handle-errors-when-excluding-super-extents.patch:
  disable due to potential corruptions (bnc#751743)
* Thu Mar 29 2012 rjw@suse.de
- patches.fixes/pci-set-device-power-state-to-PCI_D0.patch: PCI:
  Set device power state to PCI_D0 for device without native PM
  support (bnc#752972).
* Wed Mar 28 2012 bpoirier@suse.de
- patches.fixes/dlm-Do-not-allocate-a-fd-for-peeloff.patch: dlm:
  Do not allocate a fd for peeloff (bnc#729247).
- patches.fixes/sctp-Export-sctp_do_peeloff.patch: sctp: Export
  sctp_do_peeloff (bnc#729247).
* Wed Mar 28 2012 hare@suse.de
- patches.suse/dasd-blk-timeout.patch: Only activate blk_timeout
  for failfast requests (bnc#753617).
* Tue Mar 27 2012 jack@suse.cz
- patches.fixes/xfs-Fix-oops-on-IO-error-during-xlog_recover_process.patch:
  xfs: Fix oops on IO error during xlog_recover_process_iunlinks()
  (bnc#716850).
* Tue Mar 27 2012 mhocko@suse.cz
- patches.fixes/watchdog-make-sure-the-watchdog-thread-gets-CPU-on-l.patch:
  watchdog: make sure the watchdog thread gets CPU on loaded
  system (bnc#738583).
* Tue Mar 27 2012 nfbrown@suse.de
- patches.suse/md-Do-not-block-when-displaying-info.patch: md:
  Do not block when displaying info. (bnc#753617)
  This patch is currently disabled.
  Also remove (by tagging) some related patches that aren't wanted
  any more.
* Mon Mar 26 2012 oneukum@suse.de
- patches.drivers/0001-Bluetooth-btusb-fix-bInterval-for-high-super-speed-i.patch:
  Bluetooth: btusb: fix bInterval for high/super speed isochronous
  endpoints (bnc#754052).
* Mon Mar 26 2012 jslaby@suse.de
- Linux 3.0.26.
* Sun Mar 25 2012 ohering@suse.de
- patches.suse/msft-hv-0286-Staging-hv-mousevsc-Remove-the-mouse-driver-from.patch:
- patches.suse/msft-hv-0296-HID-hv_mouse-Properly-add-the-hid-device.patch:
  add mainline tags from staging-next tree
* Sun Mar 25 2012 ohering@suse.de
- patches.suse/msft-hv-0327-net-hyperv-Use-netif_tx_disable-instead-of-netif_.patch:
  net/hyperv: Use netif_tx_disable() instead of netif_stop_queue()
  when necessary.
- patches.suse/msft-hv-0328-net-hyperv-rx_bytes-should-account-the-ether-header.patch:
  net/hyperv: rx_bytes should account the ether header size.
- patches.suse/msft-hv-0329-net-hyperv-fix-the-issue-that-large-packets-be-drop.patch:
  net/hyperv: fix the issue that large packets be dropped
  under bridge.
- patches.suse/msft-hv-0330-net-hyperv-Fix-the-page-buffer-when-an-RNDIS-messag.patch:
  net/hyperv: Fix the page buffer when an RNDIS message goes
  beyond page boundary.
* Fri Mar 23 2012 dsterba@suse.cz
- patches.suse/btrfs-8058-disallow-unequal-data-metadata-blocksize-for-m.patch:
  fix logic in condition.
* Fri Mar 23 2012 dsterba@suse.cz
- patches.suse/btrfs-8059-handle-errors-when-excluding-super-extents.patch:
  fix incorrect exclusion of superblock from blockgroups (bnc#751743)
* Fri Mar 23 2012 mhocko@suse.cz
- patches.fixes/proc-Consider-NO_HZ-when-printing-idle-and-iowait-ti.patch:
  proc: Consider NO_HZ when printing idle and iowait times
  (bnc#705551).
- patches.fixes/procfs-do-not-confuse-jiffies-with-cputime64_t.patch:
  procfs: do not confuse jiffies with cputime64_t (bnc#705551).
- patches.fixes/procfs-do-not-overflow-get_-idle-iowait-_time-for-no.patch:
  procfs: do not overflow get_{idle,iowait}_time for nohz
  (bnc#705551).
* Fri Mar 23 2012 mmarek@suse.cz
- patches.drivers/drm-i915-Sanitize-BIOS-debugging-bits:
  drm/i915: Sanitize BIOS debugging bits from PIPECONF
  (bnc#751916).
* Thu Mar 22 2012 hare@suse.de
- patches.suse/dasd-blk-timeout.patch: Update patch
  by suggestion of Stefan Weinhuber.
- patches.suse/dasd-detailed-io-errors.patch: Refresh.
* Thu Mar 22 2012 jjolly@suse.de
- patches.arch/s390-48-01-lcs-setoffline.patch: lcs: lcs offline
  failure (bnc#752484,LTC#79788).
- patches.arch/s390-48-02-qeth-wake.patch: qeth: add missing
  wake_up call (bnc#752484,LTC#79899).
* Thu Mar 22 2012 hare@suse.de
- patches.drivers/bfa-set-correct-scsi-returncode: bfa: Do not
  return DID_ABORT on failure (bnc#745400).
* Thu Mar 22 2012 jslaby@suse.de
- Linux 3.0.25.
- patches.drivers/0012-rt2x00-Reduce-window-of-a-queue-s-tx-lock.patch:
  Refresh.
- patches.kernel.org/revert-PCI-ignore-pre-1.1-ASPM-quirking-when-ASPM-is.patch:
  Revert "PCI: ignore pre-1.1 ASPM quirking when ASPM is
  disabled".
- patches.xen/xen3-auto-common.diff: Refresh.
- patches.rpmify/compat-Re-add-missing-asm-compat.h-include.patch:
  Delete.
* Thu Mar 22 2012 mgorman@suse.de
- patches.fixes/mm-thp-fix-pmd_bad-triggering-in-code-paths-holding-mmap_sem-read-mode.patch:
  mm: thp: fix pmd_bad() triggering in code paths holding mmap_sem read mode
  (CVE-2012-1179, bnc#752599)
* Thu Mar 22 2012 dsterba@suse.cz
- patches.suse/btrfs-8059-handle-errors-when-excluding-super-extents.patch:
  fix incorrect default value.
* Thu Mar 22 2012 dsterba@suse.cz
- patches.suse/btrfs-volumes-schedule_bio-should-return-void:
  fix aio/dio bio refcounting bnc#718918.
* Wed Mar 21 2012 mmarek@suse.cz
- Add patches.drivers/hp_accel-ignore-resume-error to series.conf
* Wed Mar 21 2012 hare@suse.de
- patches.suse/0005-md-raid10-add-failfast-handling-for-writes.patch:
  Fix kernel oops during drive failure (bnc#750995).
* Wed Mar 21 2012 jbeulich@novell.com
- patches.xen/1158-xenbus-remove-details.patch: xenbus: don't
  free other end details too early.
- patches.xen/1162-blkback-disconnect.patch: blkback: also call
  blkif_disconnect() when frontend switched to closed.
- patches.xen/1163-gnttab-deferred-end-access.patch: gnttab:
  add deferred freeing logic.
- patches.xen/1164-blkback-feature-barrier-non-fatal.patch:
  blkback: failure to write "feature-barrier" node is non-fatal.
- Refresh other Xen patches.
* Tue Mar 20 2012 tiwai@suse.de
- patches.drivers/drm-i915-Add-lvds_channel-module-option:
  drm/i915: Add lvds_channel module option (bnc#739837).
- patches.drivers/drm-i915-Check-VBIOS-value-for-determining-LVDS-dual:
  drm/i915: Check VBIOS value for determining LVDS dual channel
  mode, too (bnc#739837).
* Tue Mar 20 2012 dsterba@suse.cz
- patches.suse/btrfs-8053-fix-race-in-reada.patch: Refresh.
* Tue Mar 20 2012 dsterba@suse.cz
  btrfs sync with 3.3
- patches.suse/btrfs-0396-fix-locking-issues-in-find_parent_nodes.patch:
  btrfs: fix locking issues in find_parent_nodes() (FATE#306586).
- patches.suse/btrfs-0397-fix-casting-error-in-scrub-reada-code.patch:
  Btrfs: fix casting error in scrub reada code (FATE#306586).
- patches.suse/btrfs-8059-handle-errors-when-excluding-super-extents.patch:
  Fix uninitialized variable.
- patches.suse/btrfs-8056-fix-locking-issues-in-find_parent_nodes.patch:
  Delete.
- patches.suse/btrfs-8057-fix-casting-error-in-scrub-reada-code.patch:
  Delete.
* Tue Mar 20 2012 mgorman@suse.de
- patches.fixes/cpuset-mm-reduce-memory-barrier-related-damage-fix.patch:
  Fix uninitialised variable warning and obey the
  [get|put]_mems_allowed API.
* Tue Mar 20 2012 rgoldwyn@suse.de
- patches.fixes/Fix-SMI-induced-variation-in-quick_pit_calibrate:
  x86, tsc: Fix SMI induced variation in quick_pit_calibrate().
  (bnc#751322)
* Mon Mar 19 2012 mszeredi@suse.cz
- patches.fixes/epoll-dont-limit-non-nested.patch: Don't limit
  non-nested epoll paths (bnc#676204).
* Mon Mar 19 2012 bpoirier@suse.de
- patches.drivers/mlx4_en-Assigning-TX-irq-per-ring.patch:
  mlx4_en: Assigning TX irq per ring (bnc#624072).
* Mon Mar 19 2012 hare@suse.de
- patches.suse/dasd-blk-timeout.patch: Terminate inactive
  cqrs correctly (bnc#750995)
- patches.suse/dasd-detailed-io-errors.patch: dasd: detailed
  I/O errors (bnc#746717).
* Mon Mar 19 2012 ohering@suse.de
- patches.suse/msft-hv-0326-net-hyperv-fix-erroneous-NETDEV_TX_BUSY-use.patch:
  net/hyperv: fix erroneous NETDEV_TX_BUSY use.
* Mon Mar 19 2012 hare@suse.de
- patches.suse/dasd-Implement-failfast_retries.patch: Fixup typo.
- patches.suse/dasd-make-number-of-retries-configurable.patch:
  Fixup typo.
* Sat Mar 17 2012 dsterba@suse.cz
- patches.suse/btrfs-8059-handle-errors-when-excluding-super-extents.patch:
  Refresh.
- patches.suse/btrfs-8061-handle-errors-from-read_tree_block.patch:
  btrfs: handle errors from read_tree_block (FATE#306586
  bnc#748632).
- patches.suse/btrfs-8062-push-up-errors-in-btrfs-num-copies.patch:
  btrfs: push-up errors from btrfs_num_copies (FATE#306586
  bnc#748632).
* Fri Mar 16 2012 hare@suse.de
- patches.suse/msft-hv-0324-Staging-hv-storvsc-Move-the-storage-driver-out-of.patch:
  Fixup patch for series2git.
- patches.xen/xen3-patch-2.6.32: Fixup patch for series2git.
* Fri Mar 16 2012 ohering@suse.de
- patches.suse/md-re-add-to-failed: Update references
  (bnc#746717).
* Fri Mar 16 2012 ohering@suse.de
- patches.suse/sd_init.mark_majors_busy.patch: Update references
  (bnc#744658).
* Thu Mar 15 2012 jbohac@suse.cz
- patches.fixes/bridge-always-send-NETDEV_CHANGEADDR-up-on-br-MAC-change.patch:
  Bridge: Always send NETDEV_CHANGEADDR up on br MAC change
  (bnc#752408).
* Wed Mar 14 2012 tiwai@suse.de
- patches.drivers/agp-fix-scratch-page-cleanup: agp: fix scratch
  page cleanup (bnc#738679).
* Wed Mar 14 2012 tiwai@suse.de
- patches.drivers/hp_accel-ignore-resume-error: hp_accel: Ignore
  the error from lis3lv02d_poweron() at resume (bnc#751903).
* Wed Mar 14 2012 trenn@suse.de
- patches.drivers/pstore_fix_ia64_compile_warning.patch: efivars:
  add missing parameter to efi_pstore_read().
* Wed Mar 14 2012 nfbrown@suse.de
- patches.suse/md-raid10-handle-merge_bvec_fn-in-member-devices.patch:
  md/raid10: handle merge_bvec_fn in member devices.
- patches.suse/md-raid10-support-resizing-some-RAID10-arrays.patch:
  md/raid10 - support resizing some RAID10 arrays.
* Wed Mar 14 2012 dsterba@suse.cz
- patches.suse/btrfs-handle-EIO: add a few error cleanups.
- patches.suse/btrfs-update-message-levels.patch: Refreshed.
* Tue Mar 13 2012 jack@suse.cz
- patches.suse/xfs-dmapi-send-rw-events.patch: XFS read/write
  calls do not generate DMAPI events (bnc#751885).
* Tue Mar 13 2012 jslaby@suse.de
- Linux 3.0.24.
- Update config files.
- patches.arch/s390-vmcp-module.patch: Refresh.
- patches.kabi/hide-compat-h-inclusion.patch: kabi: hide compat.h
  inclusion.
- patches.kabi/kabi-protect-struct-ath_hw.patch: kABI: protect
  struct ath_hw.
- patches.drivers/USB3-0295-net-usb-Misc.-fixes-for-the-LG-VL600-LTE-USB-modem.patch:
  Refresh.
- patches.drivers/drm-i915-Cache-GT-fifo-count-for-SandyBridge:
  Refresh.
- patches.drivers/drm-i915-Flush-other-plane-register-writes:
  Refresh.
- patches.drivers/drm-i915-Set-two-chicken-bits-implicated-in-missed-I:
  Refresh.
- patches.drivers/drm-i915-Prevent-a-machine-hang-by-checking-crtc-act:
  Delete.
- patches.drivers/drm-i915-gen7-Disable-the-RHWO-optimization-as-it-ca:
  Delete.
- patches.drivers/drm-i915-gen7-Implement-an-L3-caching-workaround:
  Delete.
- patches.drivers/drm-i915-gen7-implement-rczunit-workaround:
  Delete.
- patches.drivers/drm-i915-gen7-work-around-a-system-hang-on-IVB:
  Delete.
- patches.fixes/cifs-fix-dentry-refcount-leak-when-opening-a-fifo-on-lookup:
  Delete.
- patches.fixes/mm-memcg-correct-unregistring-of-events-attached-to-the-same-eventfd:
  Delete.
- patches.fixes/regset-prevent-null-pointer-reference-on-readonly-regsets:
  Delete.
- patches.fixes/regset-return-efault-not-eio-on-host-side-memory-fault:
  Delete.
- patches.rpmify/compat-Re-add-missing-asm-compat.h-include.patch:
  compat: Re-add missing asm/compat.h include to fix compile
  breakage on s390.
* Mon Mar 12 2012 jslaby@suse.de
- Linux 3.0.23.
- patches.drivers/USB3-0154-usb-xhci-group-MSI-interrupt-registration-into-its-own-funct.patch:
  Refresh.
- patches.drivers/USB3-0155-usb-xhci-hide-MSI-code-behind-PCI-bars.patch:
  Refresh.
- patches.kabi/kabi-protect-struct-file.patch: kABI: protect
  struct file.
- patches.kabi/kabi-protect-struct-us_data.patch: kABI: protect
  struct us_data.
- patches.kabi/kabi-protect-thread-struct.patch: kABI: protect
  thread_struct.
- patches.kabi/revert-i387-math_state_restore-isn-t-called-from-asm.patch:
  Revert "i387: math_state_restore() isn't called from asm".
- patches.kabi/revert-ipv4-Fix-wrong-order-of-ip_rt_get_source-and-.patch:
  Revert "ipv4: Fix wrong order of ip_rt_get_source() and update
  iph->daddr.".
- patches.kabi/revert-ipv4-Save-nexthop-address-of-LSRR-SSRR-option.patch:
  Revert "ipv4: Save nexthop address of LSRR/SSRR option to
  IPCB.".
- patches.kabi/revert-net-fix-NULL-dereferences-in-check_peer_redir.patch:
  Refresh.
- patches.kernel.org/0001-Revert-i387-re-introduce-FPU-state-preloading-at-con.patch:
  Revert "i387: re-introduce FPU state preloading at context
  switch time".
- patches.kernel.org/0002-Revert-i387-move-TS_USEDFPU-flag-from-thread_info-to.patch:
  Revert "i387: move TS_USEDFPU flag from thread_info to
  task_struct".
- patches.kernel.org/0003-Revert-i387-move-AMD-K7-K8-fpu-fxsave-fxrstor-workar.patch:
  Revert "i387: move AMD K7/K8 fpu fxsave/fxrstor workaround
  from save to restore".
- patches.kernel.org/0004-Revert-i387-do-not-preload-FPU-state-at-task-switch-.patch:
  Revert "i387: do not preload FPU state at task switch time".
- patches.kernel.org/0005-Revert-i387-don-t-ever-touch-TS_USEDFPU-directly-use.patch:
  Revert "i387: don't ever touch TS_USEDFPU directly, use helper
  functions".
- patches.kernel.org/0006-Revert-i387-move-TS_USEDFPU-clearing-out-of-__save_i.patch:
  Revert "i387: move TS_USEDFPU clearing out of __save_init_fpu
  and into callers".
- patches.kernel.org/0007-Revert-i387-fix-x86-64-preemption-unsafe-user-stack-.patch:
  Revert "i387: fix x86-64 preemption-unsafe user stack
  save/restore".
- patches.kernel.org/0008-Revert-i387-fix-sense-of-sanity-check.patch:
  Revert "i387: fix sense of sanity check".
- patches.kernel.org/0009-Revert-i387-make-irq_fpu_usable-tests-more-robust.patch:
  Revert "i387: make irq_fpu_usable() tests more robust".
- patches.kernel.org/0010-Revert-i387-math_state_restore-isn-t-called-from-asm.patch:
  Revert "i387: math_state_restore() isn't called from asm".
- patches.xen/xen3-fixup-arch-x86: Refresh.
- patches.drivers/0001-USB-Don-t-fail-USB3-probe-on-missing-legacy-PCI-IRQ.patch:
  Delete.
- patches.drivers/0001-USB-Fix-handoff-when-BIOS-disables-host-PCI-device.patch:
  Delete.
- patches.drivers/0001-USB-Set-hub-depth-after-USB3-hub-reset.patch:
  Delete.
- patches.drivers/0001-xhci-Fix-encoding-for-HS-bulk-control-NAK-rate.patch:
  Delete.
- patches.drivers/0001-xhci-Fix-oops-caused-by-more-USB2-ports-than-USB3-po.patch:
  Delete.
- patches.fixes/0001-USB-xhci-fix-port-switching-on-PantherPoint.patch:
  Delete.
- patches.fixes/bug-735909_hard_wired_primary_bus.patch: Delete.
- patches.fixes/epoll-limit-paths.patch: Delete.
- patches.kabi/epoll-kabi-fix.patch: Delete.
* Mon Mar 12 2012 ohering@suse.de
- disable patches.suse/msft-hv-0261-NLS-improve-UTF8-UTF16-string-conversion-routine.patch
  breaks KABI and is not strictly required
* Mon Mar 12 2012 nfbrown@suse.de
- patches.fixes/nfs-noac-mount.fix: nfs: Do not allow multiple
  mounts on same mountpoint when using -o noac (bnc#745422).
* Mon Mar 12 2012 nfbrown@suse.de
- patches.suse/md-raid10-disable-recovery: raid10: Disable
  recovery when recovery cannot proceed (bnc#751171).
* Sun Mar 11 2012 ohering@suse.de
- update hyperv drivers to 3.3-rc7 and move them out of staging:
  hv_timesource -> merged into core kernel
  hv_vmbus      -> drivers/hv/hv_vmbus
  hv_utils      -> drivers/hv/hv_utils
  hv_storvsc    -> drivers/scsi/hv_storvsc
  hv_netvsc     -> drivers/net/hyperv/hv_netvsc
  hv_mousevsc   -> drivers/hid/hid-hyperv
  add compat modalias for hv_mousevsc
  update supported.conf
  rename all 333 patches, use msft-hv- and suse-hv- as prefix
* Fri Mar  9 2012 ohering@suse.de
- patches.suse/sd_init.mark_majors_busy.patch: mark busy sd
  majors as allocated (bug#744658).
* Fri Mar  9 2012 hare@suse.de
- patches.suse/dasd-blk-timeout.patch: Update patch after review
  from Stefan Weinhuber @ IBM.
* Fri Mar  9 2012 jjolly@suse.de
- Update reference module symbol versions.
- patches.arch/s390-kmsg-dev-printk.patch: callhome:  fix broken
  proc interface and activate compid (bnc#748862,LTC#79115).
* Thu Mar  8 2012 dsterba@suse.cz
- patches.suse/btrfs-8059-handle-errors-when-excluding-super-extents.patch:
  btrfs: handle errors when excluding super extents (FATE#306586
  bnc#751015).
* Thu Mar  8 2012 jeffm@suse.com
- patches.fixes/xfs-dmapi-remove-cached-vfsmount: xfs/dmapi:
  Remove cached vfsmount (bnc#749417).
* Thu Mar  8 2012 nfbrown@suse.de
- patches.fixes/md-bitmap-hot-add.fix: md/bitmap: ensure to load
  bitmap when creating via sysfs.
* Thu Mar  8 2012 lduncan@suse.de
- patches.fixes/st-expand-ability-to-write-immediate-filemarks.patch:
  expand tape driver ability to write immediate filemarks (bnc#688996).
* Thu Mar  8 2012 nfbrown@suse.de
- patches.fixes/md-no-readonly: md: don't set md arrays to
  readonly on shutdown (bnc#740180, bnc#713148, bnc#734900).
* Wed Mar  7 2012 jeffm@suse.com
- patches.fixes/regset-prevent-null-pointer-reference-on-readonly-regsets:
  regset: Prevent null pointer reference on readonly regsets
  (bnc#750079 CVE-2012-1097).
- patches.fixes/regset-return-efault-not-eio-on-host-side-memory-fault:
  regset: Return -EFAULT, not -EIO, on host-side memory fault
  (bnc#750079 CVE-2012-1097).
* Wed Mar  7 2012 jeffm@suse.com
- patches.fixes/mm-memcg-correct-unregistring-of-events-attached-to-the-same-eventfd:
  mm: memcg: Correct unregistring of events attached to the same
  eventfd (CVE-2012-1146 bnc#750959).
* Wed Mar  7 2012 jeffm@suse.com
- patches.suse/btrfs-handle-EIO: Fix missing goto in btrfs_ioctl_clone.
* Wed Mar  7 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-025-Set-codec-to-D3-forcibly-even-if-not-used:
  ALSA: hda - Set codec to D3 forcibly even if not used
  (bnc#750426).
* Wed Mar  7 2012 hare@suse.de
- patches.suse/dasd-blk-timeout.patch: Fixup compilation error.
* Wed Mar  7 2012 hare@suse.de
- patches.suse/dasd-blk-timeout.patch: dasd: Implement block
  timeout handling (bnc#746717).
* Wed Mar  7 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-023-Add-Realtek-ALC269VC-codec-support:
  ALSA: hda - Add Realtek ALC269VC codec support (bnc#748827).
- patches.drivers/alsa-sp2-hda-024-Apply-the-coef-setup-only-to-ALC269:
  ALSA: hda/realtek - Apply the coef-setup only to ALC269VB
  (bnc#748827).
* Wed Mar  7 2012 nfbrown@suse.de
- patches.suse/md-allow-force-fail: md: allow last device to be
  forcibly removed from RAID1/RAID10 (bnc#746717).
- patches.suse/md-re-add-to-failed: md: allow re-add to failed
  arrays (bnc#764717).
* Tue Mar  6 2012 jack@suse.cz
- enable patches.suse/ext3-increase-reservation-window.patch. I forgot
  to enable it when committing the patch.
* Tue Mar  6 2012 jeffm@suse.com
- patches.suse/btrfs-handle-EIO: Fixed mishandled -EAGAIN error case
  from btrfs_split_item (bnc#750459).
* Tue Mar  6 2012 tiwai@suse.de
- patches.drivers/drm-i915-Force-explicit-bpp-selection-for-intel_dp_l:
  drm/i915: Force explicit bpp selection for
  intel_dp_link_required (bnc#749980).
- patches.drivers/drm-i915-dp-Dither-down-to-6bpc-if-it-makes-the-mode:
  drm/i915/dp: Dither down to 6bpc if it makes the mode fit
  (bnc#749980).
- patches.drivers/drm-i915-dp-Read-more-DPCD-registers-on-connection-p:
  drm/i915/dp: Read more DPCD registers on connection probe
  (bnc#749980).
- patches.drivers/drm-i915-fixup-interlaced-bits-clearing-in-PIPECONF-:
  drm/i915: fixup interlaced bits clearing in PIPECONF on
  PCH_SPLIT (bnc#749980).
- patches.drivers/drm-i915-read-full-receiver-capability-field-during-:
  drm/i915: read full receiver capability field during DP hot plug
  (bnc#749980).
- patches.drivers/drm-intel-Fix-initialization-if-startup-happens-in-i:
  drm/intel: Fix initialization if startup happens in interlaced
  mode [v2] (bnc#749980).
* Tue Mar  6 2012 dsterba@suse.cz
- patches.suse/btrfs-8058-disallow-unequal-data-metadata-blocksize-for-m.patch:
  btrfs: disallow unequal data/metadata blocksize for mixed
  block groups (FATE#306586).
* Tue Mar  6 2012 jdelvare@suse.de
- supported.conf: Add acpi_ipmi as supported (bnc#716971).
* Tue Mar  6 2012 mgorman@suse.de
- patches.fixes/mm-cpusets-avoid-looping-when-storing-to-mems_allowed-if-one.patch:
  cpusets: avoid looping when storing to mems_allowed if one.
- patches.fixes/mm-cpusets-stall-when-updating-mems_allowed-for-mempolicy-or.patch:
  cpusets: avoid stall when updating mems_allowed for mempolicy.
- patches.fixes/cpuset-mm-reduce-memory-barrier-related-damage.patch:
- patches.fixes/cpuset-mm-reduce-memory-barrier-related-damage-kabi.patch
  cpuset: mm: Reduce large amounts of memory barrier related slowdown.
- patches.fixes/mm-make-swapin-readahead-skip-over-holes.patch
  mm: make swapin readahead skip over holes.
* Tue Mar  6 2012 jeffm@suse.com
- patches.fixes/cifs-fix-dentry-refcount-leak-when-opening-a-fifo-on-lookup:
  cifs: fix dentry refcount leak when opening a FIFO on lookup
  (CVE-2012-1090 bnc#749569).
* Tue Mar  6 2012 dsterba@suse.cz
- patches.suse/btrfs-btrfs_destroy_ordered_extents-should-return-void:
  Refresh.
- patches.suse/btrfs-btrfs_destroy_ordered_operations-should-return-void:
  Refresh.
- patches.suse/btrfs-superblock-sanity-checks.patch: Btrfs:
  enhance superblock sanity checks (FATE#306586 bnc#749651).
- patches.suse/btrfs-update-message-levels.patch: Btrfs: update
  message levels (FATE#306586).
* Mon Mar  5 2012 mszeredi@suse.cz
- patches.fixes/epoll-limit-paths.patch: epoll: limit paths
  (bnc#676204 CVE-2011-1083).
- patches.kabi/epoll-kabi-fix.patch: epoll: hide kabi change in
  struct file (bnc#676204 CVE-2011-1083).
* Mon Mar  5 2012 tiwai@suse.de
- drm/i915 IVY/SNB fix patches from upstream 3.3-rc5 & rc6:
  patches.drivers/drm-i915-Prevent-a-machine-hang-by-checking-crtc-act,
  patches.drivers/drm-i915-do-not-enable-RC6p-on-Sandy-Bridge,
  patches.drivers/drm-i915-fix-operator-precedence-when-enabling-RC6p,
  patches.drivers/drm-i915-gen7-Disable-the-RHWO-optimization-as-it-ca,
  patches.drivers/drm-i915-gen7-Implement-an-L3-caching-workaround,
  patches.drivers/drm-i915-gen7-implement-rczunit-workaround,
  patches.drivers/drm-i915-gen7-work-around-a-system-hang-on-IVB
* Mon Mar  5 2012 hare@suse.de
- patches.xen/pci-reserve: Update for series2git.
* Mon Mar  5 2012 oneukum@suse.de
- patches.drivers/0001-xhci-Fix-encoding-for-HS-bulk-control-NAK-rate.patch:
  xhci: Fix encoding for HS bulk/control NAK rate (bnc#750402).
* Mon Mar  5 2012 dsterba@suse.cz
  btrfs 3.3-rc6 updates
- patches.suse/btrfs-8051-avoid-setting-d_op-twice.patch: Btrfs:
  avoid setting ->d_op twice (FATE#306586 bnc#731387).
- patches.suse/btrfs-8052-fix-wrong-information-of-the-directory-in-the-.patch:
  btrfs: fix wrong information of the directory in the snapshot
  (FATE#306586).
- patches.suse/btrfs-8053-fix-race-in-reada.patch: btrfs: fix
  race in reada (FATE#306586).
- patches.suse/btrfs-8054-don-t-add-both-copies-of-DUP-to-reada-extent-t.patch:
  btrfs: don't add both copies of DUP to reada extent tree
  (FATE#306586).
- patches.suse/btrfs-8055-stop-silently-switching-single-chunks-to-raid0.patch:
  Btrfs: stop silently switching single chunks to raid0 on balance
  (FATE#306586).
- patches.suse/btrfs-8056-fix-locking-issues-in-find_parent_nodes.patch:
  btrfs: fix locking issues in find_parent_nodes() (FATE#306586).
- patches.suse/btrfs-8057-fix-casting-error-in-scrub-reada-code.patch:
  Btrfs: fix casting error in scrub reada code (FATE#306586).
- patches.suse/btrfs-handle-EIO: Refresh.
* Sat Mar  3 2012 jjolly@suse.de
- patches.arch/s390-47-01-ctcmpc-idal.patch: ctcmpc: use correct
  idal word list for ctcmpc (bnc#750173,LTC#79264).
* Sat Mar  3 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-020-Export-snd_pcm_lib_default_mmap-helper:
  ALSA: pcm - Export snd_pcm_lib_default_mmap() helper
  (bnc#748384,bnc#738597).
- patches.drivers/alsa-sp2-hda-021-Add-snoop-option: ALSA: hda -
  Add snoop option (bnc#748384,bnc#738597).
- patches.drivers/alsa-sp2-hda-022-Add-support-for-new-AMD-products:
  ALSA: HDA: Add support for new AMD products
  (bnc#748384,bnc#738597).
* Sat Mar  3 2012 oneukum@suse.de
- patches.drivers/0001-USB-Fix-handoff-when-BIOS-disables-host-PCI-device.patch:
  USB: Fix handoff when BIOS disables host PCI device
  (bnc#747878).
* Fri Mar  2 2012 tiwai@suse.de
- patches.drivers/drm-i915-Clear-TV-sense-state-bits-on-GM45:
  drm/i915: Clear the TV sense state bits on cantiga to make TV
  detection reliable (bnc#750041).
* Fri Mar  2 2012 rjw@suse.de
- patches.drivers/pci-introduce-option-to-disable-ARI.patch: PCI /
  PCIe: Introduce command line option to disable ARI (bnc#742845).
- patches.xen/pci-reserve: Refresh.
* Thu Mar  1 2012 mgorman@suse.de
- patches.suse/SoN-0004a-mm-allow-PF_MEMALLOC-from-softirq-context.patch:
  mm: allow PF_MEMALLOC from softirq context.
- patches.suse/SoN-0013d-mm-kswapd-awake-while-throttling.patch:
  patches.suse/SoN-0013e-mm-ensure-GFP_NOFS-does-not-block-forever.patch:
- Refresh patches.suse/SoN-0014-mm-Account-for-the-number-of-times-direct-reclaimers.patch
  Ensure processes do not remain throttled under memory pressure.
  (Swap over NFS (fate#304949, bnc#747944).
* Thu Mar  1 2012 hare@suse.de
- patches.fixes/md-raid10-error-handling-fix: Correctly handle
  read failure from last working device in RAID10 (bnc#746717).
* Thu Mar  1 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-019-Fix-audio-playback-support-on-HP-Zephyr:
  ALSA: hda - Fix audio playback support on HP Zephyr system
  (bnc#749787).
* Wed Feb 29 2012 jbohac@suse.cz
- patches.arch/x86-lower-uv-rtc-clocksource-rating.patch: x86/UV:
  Lower UV rtc clocksource rating (bnc#748456).
* Wed Feb 29 2012 jbeulich@novell.com
- Update Xen patches to 3.0.22.
- patches.xen/1148-xenbus-dev-write-watch-checks.patch:
  xenbus_dev: add missing error checks to watch handling.
- patches.xen/1149-strlcpy.patch: drivers/xen/: use strlcpy()
  instead of strncpy().
- patches.xen/1153-xenoprof-escape-compat.patch: xenoprof:
  backward compatibility for changed XENOPROF_ESCAPE_CODE.
- patches.xen/1154-blkfront-fail-packet-requests.patch: blkfront:
  properly fail packet requests (bnc#745929).
- Refresh other Xen patches (bnc#732070, bnc#742871).
* Wed Feb 29 2012 oneukum@suse.de
- patches.drivers/0001-USB-Don-t-fail-USB3-probe-on-missing-legacy-PCI-IRQ.patch:
  USB: Don't fail USB3 probe on missing legacy PCI IRQ
  (bnc#749543).
* Tue Feb 28 2012 mgorman@suse.de
- patches.fixes/mm-sparsemem-bootmem-catch-greater-than-section-size-allocations.patch:
  Allow sparsemem usemap allocations for very large NUMA nodes (bnc#749049).
* Tue Feb 28 2012 oneukum@suse.de
- patches.drivers/0001-USB-Adding-define-in-hub_configure-and-hcd.c-file.patch:
  USB: Adding #define in hub_configure() and hcd.c file
  (bnc#714604).
- patches.drivers/0001-USB-remove-BKL-comments.patch: USB:
  remove BKL comments (bnc#714604).
- patches.drivers/0001-xHCI-Adding-define-values-used-for-hub-descriptor.patch:
  xHCI: Adding #define values used for hub descriptor
  (bnc#714604).
- patches.drivers/0001-xHCI-Kick-khubd-when-USB3-resume-really-completes.patch:
  xHCI: Kick khubd when USB3 resume really completes (bnc#714604).
- patches.drivers/0001-xhci-Fix-oops-caused-by-more-USB2-ports-than-USB3-po.patch:
  xhci: Fix oops caused by more USB2 ports than USB3 ports
  (bnc#714604).
- patches.drivers/0002-USB-xhci-Enable-remote-wakeup-for-USB3-devices.patch:
  USB/xhci: Enable remote wakeup for USB3 devices (bnc#714604).
- patches.drivers/0003-USB-Suspend-functions-before-putting-dev-into-U3.patch:
  USB: Suspend functions before putting dev into U3 (bnc#714604).
- patches.drivers/0004-USB-xHCI-Enable-USB-3.0-hub-remote-wakeup.patch:
  USB/xHCI: Enable USB 3.0 hub remote wakeup (bnc#714604).
- patches.drivers/0005-USB-Refactor-hub-remote-wake-handling.patch:
  USB: Refactor hub remote wake handling (bnc#714604).
- patches.drivers/0006-USB-xHCI-Support-device-initiated-USB-3.0-resume.patch:
  USB/xHCI: Support device-initiated USB 3.0 resume (bnc#714604).
- patches.drivers/0007-USB-Set-wakeup-bits-for-all-children-hubs.patch:
  USB: Set wakeup bits for all children hubs (bnc#714604).
- patches.drivers/0008-USB-Turn-on-auto-suspend-for-USB-3.0-hubs.patch:
  USB: Turn on auto-suspend for USB 3.0 hubs (bnc#714604).
* Tue Feb 28 2012 jjolly@suse.de
- patches.drivers/cxgb4_collect_flush_cq_on_close.patch:
  RDMA/cxgb4: Make sure flush CQ entries are collected on
  connection close (bnc#721587).
- patches.drivers/cxgb4_serialize_comp_handler_calls.patch:
  RDMA/cxgb4: Serialize calls to CQ's comp_handler (bnc#721587).
* Mon Feb 27 2012 dsterba@suse.cz
  btrfs sync with upstream up to 3.3-rc5
- patches.suse/btrfs-0373-Sector-Size-check-during-Mount.patch:
  btrfs: Sector Size check during Mount (FATE#306586).
- patches.suse/btrfs-0374-avoid-positive-number-with-ERR_PTR.patch:
  Btrfs: avoid positive number with ERR_PTR (FATE#306586).
- patches.suse/btrfs-0375-return-the-internal-error-unchanged-if-btrfs_g.patch:
  Btrfs: return the internal error unchanged if
  btrfs_get_extent_fiemap() call failed for SEEK_DATA/SEEK_HOLE
  inquiry (FATE#306586).
- patches.suse/btrfs-0376-fix-trim-0-bytes-after-a-device-delete.patch:
  Btrfs: fix trim 0 bytes after a device delete (FATE#306586).
- patches.suse/btrfs-0377-don-t-check-DUP-chunks-twice.patch:
  btrfs: don't check DUP chunks twice (FATE#306586).
- patches.suse/btrfs-0378-fix-memory-leak-in-load_free_space_cache.patch:
  Btrfs: fix memory leak in load_free_space_cache() (FATE#306586).
- patches.suse/btrfs-0379-delalloc-for-page-dirtied-out-of-band-in-fixup.patch:
  btrfs: delalloc for page dirtied out-of-band in fixup worker
  (FATE#306586).
- patches.suse/btrfs-0380-fix-structs-where-bitfields-and-spinlock-atomi.patch:
  btrfs: fix structs where bitfields and spinlock/atomic share
  8B word (FATE#306586).
- patches.suse/btrfs-0381-silence-warning-in-raid-array-setup.patch:
  btrfs: silence warning in raid array setup (FATE#306586).
- patches.suse/btrfs-0382-honor-umask-when-creating-subvol-root.patch:
  btrfs: honor umask when creating subvol root (FATE#306586).
- patches.suse/btrfs-0383-fix-return-value-check-of-extent_io_ops.patch:
  Btrfs: fix return value check of extent_io_ops (FATE#306586).
- patches.suse/btrfs-0384-fix-deadlock-on-page-lock-when-doing-auto-defr.patch:
  Btrfs: fix deadlock on page lock when doing auto-defragment
  (FATE#306586).
- patches.suse/btrfs-0385-check-return-value-of-lookup_extent_mapping-co.patch:
  Btrfs: check return value of lookup_extent_mapping() correctly
  (FATE#306586).
- patches.suse/btrfs-0386-skip-states-when-they-does-not-contain-bits-to.patch:
  Btrfs: skip states when they does not contain bits to clear
  (FATE#306586).
- patches.suse/btrfs-0387-kick-out-redundant-stuff-in-convert_extent_bit.patch:
  Btrfs: kick out redundant stuff in convert_extent_bit
  (FATE#306586).
- patches.suse/btrfs-0388-fix-a-bug-on-overcommit-stuff.patch:
  Btrfs: fix a bug on overcommit stuff (FATE#306586).
- patches.suse/btrfs-0389-be-less-strict-on-finding-next-node-in-clear_e.patch:
  Btrfs: be less strict on finding next node in clear_extent_bit
  (FATE#306586).
- patches.suse/btrfs-0390-improve-error-handling-for-btrfs_insert_dir_it.patch:
  Btrfs: improve error handling for btrfs_insert_dir_item callers
  (FATE#306586).
- patches.suse/btrfs-0391-make-sure-we-update-latest_bdev.patch:
  Btrfs: make sure we update latest_bdev (FATE#306586).
- patches.suse/btrfs-0392-add-extra-sanity-checks-on-the-path-names-in-b.patch:
  Btrfs: add extra sanity checks on the path names in
  btrfs_mksubvol (FATE#306586).
- patches.suse/btrfs-0393-clear-the-extent-uptodate-bits-during-parent-t.patch:
  Btrfs: clear the extent uptodate bits during parent transid
  failures (FATE#306586).
- patches.suse/btrfs-0394-increase-the-global-block-reserve-estimates.patch:
  Btrfs: increase the global block reserve estimates
  (FATE#306586).
- patches.suse/btrfs-0395-fix-compiler-warnings-on-32-bit-systems.patch:
  Btrfs: fix compiler warnings on 32 bit systems (FATE#306586).
- patches.suse/btrfs-handle-EIO: Refresh.
- patches.suse/btrfs-volumes-btrfs_close_extra_devices-should-return-void:
  Refresh.
- patches.suse/btrfs-8013-sector-size-check-during-mount.patch:
  Delete.
- patches.suse/btrfs-8044-avoid-positive-number-with-ERR_PTR.patch:
  Delete.
- patches.suse/btrfs-8045-return-the-internal-error-unchanged-if-btrfs_g.patch:
  Delete.
- patches.suse/btrfs-8046-fix-trim-0-bytes-after-a-device-delete.patch:
  Delete.
- patches.suse/btrfs-8047-don-t-check-DUP-chunks-twice.patch:
  Delete.
- patches.suse/btrfs-8048-fix-memory-leak-in-load_free_space_cache.patch:
  Delete.
- patches.suse/btrfs-8049-fix-new-subvol-perms.patch: Delete.
- patches.suse/btrfs-8051-fix-return-value-check-of-extent_io_ops.patch:
  Delete.
- patches.suse/btrfs-8052-fix-deadlock-on-page-lock-when-doing-auto-defr.patch:
  Delete.
- patches.suse/btrfs-8053-check-return-value-of-lookup_extent_mapping-co.patch:
  Delete.
- patches.suse/btrfs-8054-skip-states-when-they-does-not-contain-bits-to.patch:
  Delete.
- patches.suse/btrfs-8055-kick-out-redundant-stuff-in-convert_extent_bit.patch:
  Delete.
- patches.suse/btrfs-8056-fix-a-bug-on-overcommit-stuff.patch:
  Delete.
- patches.suse/btrfs-8057-be-less-strict-on-finding-next-node-in-clear_e.patch:
  Delete.
- patches.suse/btrfs-delalloc-for-page-dirtied-out-of-band-in-fixup-worker:
  Delete.
- patches.suse/btrfs-fix-structs-spinlock-bitfield.patch: Delete.
- patches.suse/btrfs-silence-warning-in-raid-array-setup.patch:
  Delete.
* Mon Feb 27 2012 oneukum@suse.de
- patches.drivers/0001-USB-Set-hub-depth-after-USB3-hub-reset.patch:
  USB: Set hub depth after USB3 hub reset (bnc#749115).
* Mon Feb 27 2012 tiwai@suse.de
- Removed redundant patches for a fix over an obsoleted fix
  (bnc#744315): no code change at all by this commit
- patches.drivers/drm-i915-fix-intel-sdvo-lvds-connected-status.diff:
  Delete.
- patches.drivers/drm-i915-sdvo-Fix-up-EDID-matching-logic.patch:
  Delete.
- patches.drivers/drm-i915-sdvo-Include-LVDS-panels-for-the-IS_DIGITAL:
  Refresh.
* Mon Feb 27 2012 tiwai@suse.de
- patches.drivers/drm-i915-dont-write-DSPSURF-for-old-chips:
  drm/i915: Don't write DSPSURF for old chips (bnc#747071).
* Mon Feb 27 2012 jjolly@suse.de
- patches.arch/s390-46-01-qeth-recovery-async-delivery.patch:
  Fix recovery in case of concurrent asynchronous deliveries
  (bnc#748629,LTC#78309).
- patches.arch/s390-46-02-3215-wakeup.patch: kernel: 3215 console
  deadlock (bnc#748629,LTC#78612).
- patches.arch/s390-46-03-qeth_sync_modload.patch: qeth:
  synchronize discipline module loading (bnc#748629,LTC#78788).
- patches.arch/s390-46-04-memplug_zone_interleave.patch: memory
  hotplug: prevent memory zone interleave (bnc#748629,LTC#79113).
- patches.arch/s390-46-05-dasd-fix_fixpoint_devide_exception.patch:
  dasd: fix fixpoint divide exception in define_extent
  (bnc#748629,LTC#79125).
* Fri Feb 24 2012 jeffm@suse.com
- patches.fixes/make-taskstats-require-root-access: Make TASKSTATS
  require root access (CVE-2011-2494 bnc#703156).
* Fri Feb 24 2012 jeffm@suse.com
- patches.suse/btrfs-handle-EIO: Clean up unused code, fix use of
  error-indicated pointer in transaction teardown (bnc#748854).
* Thu Feb 23 2012 bpoirier@suse.de
- patches.drivers/qlge-Removing-needless-print-s-which-are-not.patch:
  qlge: Removing needless print's which are not (bnc#718863).
* Thu Feb 23 2012 eich@suse.de
- patches.suse/drm-edid-workaround-shift.patch: Delete.
  This only addressed a small subset of EDID issues we have been
  seeing. Besides that the fix was broken.
* Thu Feb 23 2012 eich@suse.de
- patches.suse/drm-radeon-limit-bpp-for-low-vram.patch: Refresh.
  Fixing commit 7b4df11b1 - had forgotten to run commit --amend
  before pushing. oops.
* Thu Feb 23 2012 eich@suse.de
- patches.drivers/drm-intel-do-not-delete-dpll-multiplier-during-dac-init.patch:
  Don't delete DPLL Multiplier during DAC init (bnc #728840).
* Thu Feb 23 2012 eich@suse.de
- patches.suse/drm-radeon-limit-bpp-for-low-vram.patch: Set
  depth on low mem Radeon cards to 16 instead of 8 (bnc #746883).
* Thu Feb 23 2012 rjw@suse.de
- patches.arch/x86-pci-Increase-the-number-of-iommus-supported-to-be-MAX_IO_APICS.patch:
  Refresh.
* Wed Feb 22 2012 jslaby@suse.de
- Linux 3.0.22.
- patches.suse/SoN-0002-mm-sl-au-b-Add-knowledge-of-PFMEMALLOC-reserve-pages.patch:
  Refresh.
* Wed Feb 22 2012 jslaby@suse.de
- Linux 3.0.21.
- patches.drivers/drm-i915-simplify-pipe-checking: Refresh.
- patches.drivers/target-0034-target-Follow-up-core-updates-from-AGrover-and-HCH.patch:
  Refresh.
- patches.fixes/proc-enable-writing-to-proc-pid-mem-revert.patch:
  Refresh.
- patches.drivers/alsa-sp2-hda-017-Fix-duplicated-output-to-more-than-one-codec:
  Delete.
- patches.drivers/drm-i915-DisplayPort-hot-remove-notification-to-audio-driver:
  Delete.
- patches.drivers/drm-i915-HDMI-hot-remove-notification-to-audio-driver:
  Delete.
- patches.drivers/drm-i915-check-ACTHD-of-all-rings: Delete.
- patches.drivers/drm-i915-handle-3rd-pipe: Delete.
- patches.fixes/mm-compaction-check-for-overlapping-nodes.patch:
  Delete.
- patches.fixes/mm-compaction-check-pfn_valid-entering-MAX_ORDER_NR_PAGES-block.patch:
  Delete.
- patches.fixes/readahead-fix-pipeline-break-caused-by-block-plug.patch:
  Delete.
- patches.kabi/revert-net-fix-NULL-dereferences-in-check_peer_redir.patch:
  Revert "net: fix NULL dereferences in check_peer_redir()".
* Wed Feb 22 2012 jslaby@suse.de
- Linux 3.0.20. (This release changes no code.)
- patches.kernel.org/revert-PCI-Rework-ASPM-disable-code.patch:
  Revert "PCI: Rework ASPM disable code".
* Wed Feb 22 2012 jslaby@suse.de
- Linux 3.0.19.
- patches.drivers/USB3-0144-xHCI-set-link-state.patch: Refresh.
- patches.suse/SoN-0006-net-Introduce-sk_allocation-to-allow-addition-of-GFP.patch:
  Refresh.
- patches.suse/remove-syslog-WARN_ON.patch: Refresh.
- patches.arch/x86-UV-uv_gpa_to_soc_phys_ram-shift.patch: Delete.
- patches.drivers/0001-xhci-Fix-USB-3.0-device-restart-on-resume.patch:
  Delete.
- patches.drivers/alsa-sp2-hda-016-Fix-silent-outputs-from-docking-station:
  Delete.
- patches.drivers/drm-i915-sdvo-always-set-positive-sync-polarity:
  Delete.
- patches.fixes/bonding-fix-enslaving-in-alb-mode-when-link-down.patch:
  Delete.
- patches.fixes/serial-jsm-save-state: Delete.
- patches.fixes/tty-fix-UV-serial-console-regression.patch:
  Delete.
- patches.fixes/xfs-Fix-missing-xfs_iunlock-on-error-recovery-path-i.patch:
  Delete.
* Wed Feb 22 2012 jslaby@suse.de
- Linux 3.0.18.
- patches.fixes/proc-enable-writing-to-proc-pid-mem-revert.patch:
  Refresh.
- patches.xen/xen3-fixup-xen: Refresh.
- patches.xen/xen3-patch-2.6.24: Refresh.
- patches.xen/xen3-patch-2.6.28: Refresh.
- patches.xen/xen3-patch-2.6.39:
- patches.arch/acpi_srat-pxm-rev-ia64.patch: Delete.
- patches.arch/acpi_srat-pxm-rev-store.patch: Delete.
- patches.arch/acpi_srat-pxm-rev-x86-64.patch: Delete.
- patches.arch/x86-UV2-Fix-BAU-destination-timeout-initialization.patch:
  Delete.
- patches.arch/x86-UV2-harp-boot-message.patch: Delete.
- patches.drivers/pci_acpi_crs_fix_32bit_addresses_exceeding_4g.patch:
  Delete.
- patches.fixes/block-add-and-use-scsi_blk_cmd_ioctl.patch:
  Delete.
- patches.fixes/block-fail-SCSI-passthrough-ioctls-on-partition-devi.patch:
  Delete.
- patches.fixes/dm-do-not-forward-ioctls-from-logical-volumes-to-the.patch:
  Delete.
- patches.fixes/fix-shrink_dcache_parent-livelock.patch: Delete.
- patches.fixes/mm-Fix-NULL-ptr-dereference-in-__count_immobile_page.patch:
  Delete.
* Wed Feb 22 2012 jslaby@suse.de
- Linux 3.0.17.
- patches.drivers/USB3-0034-USB-use-usb_endpoint_maxp-instead-of-le16_to_cpu.patch:
  Refresh.
- patches.fixes/reiserfs-xattr-crash-fix: Refresh.
- patches.drivers/USB3-0334-USB-option-add-id-for-3G-dongle-Model-VT1000-of-Viettel.patch:
  Delete.
- patches.drivers/USB3-0345-OHCI-final-fix-for-NVIDIA-problems-I-hope.patch:
  Delete.
- patches.drivers/USB3-0377-asix-new-device-id.patch: Delete.
- patches.drivers/mpt2sas-added-missing-mpt2sas_base_detach-call-from-scsih_remove-context:
  Delete.
- patches.drivers/usb-fix-number-of-mapped-sg-dma-entries.patch:
  Delete.
- patches.fixes/CPU-hotplug-Freezer-Fix-race-between-CPU-hotplug-and-freezer.patch:
  Delete.
- patches.fixes/ext3-Don-t-warn-from-writepage-when-readonly-inode-i.patch:
  Delete.
- patches.fixes/igmp-Avoid-zero-delay: Delete.
- patches.fixes/reiserfs-Fix-quota-mount-option-parsing.patch:
  Delete.
- patches.fixes/xfs-fix-acl-count-validation-in-xfs_acl_from_disk:
  Delete.
* Wed Feb 22 2012 jslaby@suse.de
- Linux 3.0.16.
- patches.kabi/reintroduce-removed-blk_init_allocated_queue_node.patch:
  Reintroduce removed blk_init_allocated_queue_node.
- patches.arch/s390-41-03-zfcp-return-early-from-slave_destroy-if-slave_alloc-returned-early.patch:
  Delete.
- patches.drivers/drm-i915-prevent-division-by-zero-when-asking-for-ch:
  Delete.
- patches.fixes/hpwdt_fix_BIOS_calls_under_NX.patch: Delete.
- patches.fixes/ipv4-reintroduce-route-cache-garbage-collector.patch:
  Delete.
- patches.fixes/oom-fix-oom_badness-overflow.patch: Delete.
- patches.fixes/per_cpu_ptr_to_phys-non-page-aligned.patch:
  Delete.
* Wed Feb 22 2012 jslaby@suse.de
- Linux 3.0.15.
* Wed Feb 22 2012 jslaby@suse.de
- Linux 3.0.14.
- patches.arch/x86-pci-Increase-the-number-of-iommus-supported-to-be-MAX_IO_APICS.patch:
  Refresh.
- patches.fixes/md-raid5-degraded-reshape-fix: Refresh.
- patches.fixes/hfs-fix-hfs_find_init-sb-ext_tree-null-ptr-oops.patch:
  Delete.
- patches.fixes/ibft-fix-finding-ibft-acpi-table-on-uefi.patch:
  Delete.
- patches.fixes/jbd-validate-sb-s_first-in-journal_get_superblo.patch:
  Delete.
- patches.fixes/log2.h-Fix-rounddown_pow_of_two-1.patch: Delete.
- patches.fixes/percpu_fix_chunk_range_calculation.patch: Delete.
- patches.kernel.org/alarmtimers-fix-time-comparison.patch:
  Delete.
- patches.kernel.org/alsa-hda-realtek-fix-oops-in-alc_mux_select.patch:
  Delete.
- patches.kernel.org/alsa-sis7019-give-slow-codecs-more-time-to-reset.patch:
  Delete.
- patches.kernel.org/arm-at91-fix-clock-conid-for-atmel_tcb.1-on-9260-9g20.patch:
  Delete.
- patches.kernel.org/arm-davinci-da850-evm-change-audio-edma-event-queue-to-eventq_0.patch:
  Delete.
- patches.kernel.org/arm-davinci-dm646x-evm-wrong-register-used-in-setup_vpif_input_channel_mode.patch:
  Delete.
- patches.kernel.org/arm-mx23-recognise-stmp378x-as-mx23.patch:
  Delete.
- patches.kernel.org/asoc-provide-a-more-complete-dma-driver-stub.patch:
  Delete.
- patches.kernel.org/fix-apparmor-dereferencing-potentially-freed-dentry-sanitize-__d_path-api.patch:
  Delete.
- patches.kernel.org/fs-proc-meminfo.c-fix-compilation-error.patch:
  Delete.
- patches.kernel.org/mm-ensure-that-pfn_valid-is-called-once-per-pageblock-when-reserving-pageblocks.patch:
  Delete.
- patches.kernel.org/mm-vmalloc-check-for-page-allocation-failure-before-vmlist-insertion.patch:
  Delete.
- patches.kernel.org/ptp-fix-clock_getres-implementation.patch:
  Delete.
- patches.kernel.org/thp-add-compound-tail-page-_mapcount-when-mapped.patch:
  Delete.
- patches.kernel.org/thp-set-compound-tail-page-_count-to-zero.patch:
  Delete.
* Wed Feb 22 2012 jack@suse.cz
- patches.fixes/jbd2-clear-BH_Delay-BH_Unwritten-in-journal_unmap_buffer.patch:
  jbd2: clear BH_Delay & BH_Unwritten in journal_unmap_buffer
  (bnc#745832 CVE-2011-4086).
* Wed Feb 22 2012 hare@suse.de
- patches.fixes/ibft-fix-finding-ibft-acpi-table-on-uefi.patch:
  ibft: Fix finding IBFT ACPI table on UEFI (bnc#746579).
* Wed Feb 22 2012 hare@suse.de
- patches.fixes/scsi-scan-dont-fail-scans-when-host-is-in-recovery.patch:
  scsi scan: don't fail scans when host is in recovery
  (bnc#747867).
* Tue Feb 21 2012 dsterba@suse.cz
  btrfs update, fixes
- patches.suse/btrfs-8051-fix-return-value-check-of-extent_io_ops.patch:
  Btrfs: fix return value check of extent_io_ops (FATE#306586).
- patches.suse/btrfs-8052-fix-deadlock-on-page-lock-when-doing-auto-defr.patch:
  Btrfs: fix deadlock on page lock when doing auto-defragment
  (FATE#306586).
- patches.suse/btrfs-8053-check-return-value-of-lookup_extent_mapping-co.patch:
  Btrfs: check return value of lookup_extent_mapping() correctly
  (FATE#306586).
- patches.suse/btrfs-8054-skip-states-when-they-does-not-contain-bits-to.patch:
  Btrfs: skip states when they does not contain bits to clear
  (FATE#306586).
- patches.suse/btrfs-8055-kick-out-redundant-stuff-in-convert_extent_bit.patch:
  Btrfs: kick out redundant stuff in convert_extent_bit
  (FATE#306586).
- patches.suse/btrfs-8056-fix-a-bug-on-overcommit-stuff.patch:
  Btrfs: fix a bug on overcommit stuff (FATE#306586).
- patches.suse/btrfs-8057-be-less-strict-on-finding-next-node-in-clear_e.patch:
  Btrfs: be less strict on finding next node in clear_extent_bit
  (FATE#306586).
- patches.suse/btrfs-clear_extent_bit-api-change: Refresh.
- patches.suse/btrfs-drop-gfp_t-from-lock_extent: Refresh.
- patches.suse/btrfs-handle-EIO: Refresh.
* Mon Feb 20 2012 trenn@suse.de
- patches.arch/x86_thermal_throttle_avoid_fake_mces.patch: x86,
  mce, therm_throt: Don't report power limit and package level
  thermal throttle events in mcelog (bnc#745876).
* Mon Feb 20 2012 acho@suse.com
  bluetooth:
- patches.drivers/bug-732296_ath3k-Add-Atheros-AR3012-Maryann-PID-VID-supported.patch:
  Bluetooth: Add Atheros AR3012 Maryann PID/VID supported in ath3k
  (bnc#732296).
* Sun Feb 19 2012 nfbrown@suse.de
- patches.suse/0003-md-raid1-add-failfast-handling-for-writes.patch:
  Refresh to not crash when handling write error on FailFast devices.
  bnc#747159
* Thu Feb 16 2012 dsterba@suse.cz
  btrfs: enable block allocator fixes again
- patches.suse/btrfs-btrfs_reserve_extent-check-sinfo: Refresh.
- patches.suse/btrfs-handle-EIO: Refresh.
* Wed Feb 15 2012 dsterba@suse.cz
  btrfs updates, misc fixes
- patches.suse/btrfs-0372-don-t-reserve-data-with-extents-locked-in-btrf.patch:
  Btrfs: don't reserve data with extents locked in btrfs_fallocate
  (FATE#306586).
- patches.suse/btrfs-8044-avoid-positive-number-with-ERR_PTR.patch:
  Btrfs: avoid positive number with ERR_PTR (FATE#306586).
- patches.suse/btrfs-8045-return-the-internal-error-unchanged-if-btrfs_g.patch:
  Btrfs: return the internal error unchanged if
  btrfs_get_extent_fiemap() call failed for SEEK_DATA/SEEK_HOLE
  inquiry (FATE#306586).
- patches.suse/btrfs-8046-fix-trim-0-bytes-after-a-device-delete.patch:
  Btrfs: fix trim 0 bytes after a device delete (FATE#306586).
- patches.suse/btrfs-8047-don-t-check-DUP-chunks-twice.patch:
  btrfs: don't check DUP chunks twice (FATE#306586).
- patches.suse/btrfs-8048-fix-memory-leak-in-load_free_space_cache.patch:
  Btrfs: fix memory leak in load_free_space_cache() (FATE#306586).
- patches.suse/btrfs-8049-fix-new-subvol-perms.patch: btrfs:
  fix permissions of new subvolume (FATE#306586 bnc#746373).
- patches.suse/btrfs-8050-set-ioprio-of-scrub-readahead-to-idle.patch:
  Btrfs: set ioprio of scrub readahead to idle (FATE#306586).
- patches.suse/btrfs-fix-new-subvol-perms.patch: Delete.
* Wed Feb 15 2012 tiwai@suse.de
- Disable broken patches.suse/drm-edid-workaround-shift.patch
  (bnc#746526)
* Wed Feb 15 2012 tiwai@suse.de
- patches.suse/drm-radeon-remove-ES1000-support: Remove the
  support for ES1000 from drm/radeon (bnc#746526).
* Tue Feb 14 2012 dsterba@suse.cz
  delete stale btrfs patches
- patches.suse/btrfs-0010-go-readonly-on-insert-error-in-btrfs_add_root_.patch:
  Delete.
- patches.suse/btrfs-0014-Document-BUG-in-find_lock_delalloc_range.patch:
  Delete.
- patches.suse/btrfs-0015-Go-readonly-on-missing-ref-in-btrfs_get_parent.patch:
  Delete.
- patches.suse/btrfs-0900-add-allocator-tracepoints.patch: Delete.
- patches.suse/btrfs-0901-protect-orphan-block-rsv-with-spin_lock.patch:
  Delete.
- patches.suse/btrfs-8027-fix-dirtied-pages-accounting-on-sub-page-write.patch:
  Delete.
- patches.suse/btrfs-8053-rewrite-btrfs_trim_block_group.patch:
  Delete.
- patches.suse/btrfs-8054-update-global-block_rsv-when-creating-a-new-bl.patch:
  Delete.
- patches.suse/btrfs-8055-fix-possible-deadlock-when-opening-a-seed-devi.patch:
  Delete.
- patches.suse/btrfs-_btrfs_mod_ref-s-process_func-should-return-void:
  Delete.
- patches.suse/btrfs-_btrfs_mod_ref-should-return-void: Delete.
- patches.suse/btrfs-add_excluded_extent-should-return-void:
  Delete.
- patches.suse/btrfs-async_thread-btrfs_queue_worker-should-return-void:
  Delete.
- patches.suse/btrfs-btrfs_free_extent-void-return-prep: Delete.
- patches.suse/btrfs-btrfs_inc_extent_ref-void-return-prep:
  Delete.
- patches.suse/btrfs-btrfs_pin_extent-error-push-up: Delete.
- patches.suse/btrfs-btrfs_start_transaction-non-looped-error-push-up:
  Delete.
- patches.suse/btrfs-clean_tree_block-should-return-void: Delete.
- patches.suse/btrfs-clear_extent_bit-can-drop_gfp_t: Delete.
- patches.suse/btrfs-clear_extent_bit-error-push-up: Delete.
- patches.suse/btrfs-clear_extent_bit-should-return-void-with-_gfp_wait-set:
  Delete.
- patches.suse/btrfs-clear_extent_bits-can-drop-gfp_t: Delete.
- patches.suse/btrfs-clear_extent_dirty-can-drop-gfp_t: Delete.
- patches.suse/btrfs-clear_extent_uptodate-can-drop_gfp_t: Delete.
- patches.suse/btrfs-convert_extent_bit-should-return-void-with-_gfp_wait-set:
  Delete.
- patches.suse/btrfs-delayed-ref-mempool-functions-should-return-void:
  Delete.
- patches.suse/btrfs-drop-gfp_t-from-set_extent_bit: Delete.
- patches.suse/btrfs-extent_io-set_range_writeback-should-return-void:
  Delete.
- patches.suse/btrfs-file-btrfs_run_defrag_inodes-should-return-void:
  Delete.
- patches.suse/btrfs-lock-extent-can-drop-gfp_t-argument: Delete.
- patches.suse/btrfs-pin_down_extent-should-return-void: Delete.
- patches.suse/btrfs-set_extent_bit-error-push-up: Delete.
- patches.suse/btrfs-set_extent_bit-should-return-void: Delete.
- patches.suse/btrfs-set_extent_bits-can-drop-gfp_t-argument:
  Delete.
- patches.suse/btrfs-set_extent_buffer_uptodate-should-return-void:
  Delete.
- patches.suse/btrfs-set_extent_delalloc-can-drop-gfp_t-argument:
  Delete.
- patches.suse/btrfs-set_extent_dirty-can-drop-gfp_t-argument:
  Delete.
- patches.suse/btrfs-set_extent_new-can-drop-gfp_t-argument:
  Delete.
- patches.suse/btrfs-set_extent_uptodate-can-drop-gfp_t-argument:
  Delete.
- patches.suse/btrfs-split-set_extent_bit-exclusive-mode-out:
  Delete.
- patches.suse/btrfs-try_lock_extent-can-drop-gfp_t: Delete.
- patches.suse/btrfs-unlock_extent-can-eliminate-gfp_t: Delete.
- patches.suse/btrfs-unlock_extent-can-eliminate-gfp_t-addon:
  Delete.
- patches.suse/btrfs-unlock_extent-can-return-void: Delete.
- patches.suse/btrfs-unlock_extent_cached-can-return-void: Delete.
- patches.suse/btrfs-use-mempools-for-delayed-refs: Delete.
- patches.suse/btrfs-use-mempools-for-extent_state-structures:
  Delete.
* Mon Feb 13 2012 rjw@suse.de
- patches.arch/x86-fix-unknown_nmi_error.patch: Refresh.
* Mon Feb 13 2012 jack@suse.cz
- patches.fixes/jbd-validate-sb-s_first-in-journal_get_superblo.patch:
  jbd/jbd2: validate sb->s_first in journal_get_superblock()
  (bnc#730118).
* Mon Feb 13 2012 jack@suse.cz
- patches.fixes/writeback-fix-sb-locking.diff: Delete unused patch.
* Mon Feb 13 2012 mmarek@suse.cz
- patches.drivers/0006-benet-Add-missing-comma-between-constant-string-arr.patch
  patches.drivers/0018-benet-fix-build-error-on-32bit-arch.patch
  patches.drivers/0025-benet-remove-bogus-unlikely-on-vlan-check.patch:
  Enable missing patches in be2net series.
- patches.drivers/benet-32bit-fix: Delete.
* Mon Feb 13 2012 dsterba@suse.cz
- use guard instead of comment for my patches
* Mon Feb 13 2012 mmarek@suse.cz
- Add patches.suse/kdb-x86-unlock-nmi-lock-after-kdb-ipi.patch
  to series.conf.
* Fri Feb 10 2012 dsterba@suse.cz
- patches.suse/btrfs-fix-new-subvol-perms.patch: btrfs: fix
  permissions of new subvolume (FATE#306586 bnc#746373).
* Fri Feb 10 2012 sjayaraman@suse.de
- patches.fixes/readahead-fix-pipeline-break-caused-by-block-plug.patch:
  readahead: fix pipeline break caused by block plug (bnc#746454).
* Fri Feb 10 2012 oneukum@suse.de
- patches.drivers/0001-xhci-Fix-USB-3.0-device-restart-on-resume.patch:
  xhci: Fix USB 3.0 device restart on resume (bnc#745867).
- patches.drivers/0001-xhci-Remove-scary-warnings-about-transfer-issues.patch:
  xhci: Remove scary warnings about transfer issues (bnc#745867).
- patches.drivers/0001-xhci-Remove-warnings-about-MSI-and-MSI-X-capabilitie.patch:
  xhci: Remove warnings about MSI and MSI-X capabilities
  (bnc#745867).
* Fri Feb 10 2012 tiwai@suse.de
- patches.suse/tmpfs-fix-kmap_atomic-leak: tmpfs: Fix kmap_atomic
  leak in shmem_read_mapping_page*() (bnc#744392).
* Fri Feb 10 2012 tiwai@suse.de
- Add a few missing drm/i915 fixes from upstream 3.2 kernel
  (bnc#744392):
  patches.drivers/drm-i915-Fix-wrong-initializer-for-locked-variable,
  patches.drivers/drm-i915-fix-transcoder-PLL-select-masking,
  patches.drivers/drm-i915-remove-transcoder-PLL-mashing-from-mode_set
* Fri Feb 10 2012 sjayaraman@suse.de
- patches.fixes/mm-backing-dev-fix-wakeup-timer-races-with-bdi_unregister.patch:
  backing-dev: fix wakeup timer races with bdi_unregister()
  (bnc#741824).
* Thu Feb  9 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-018-Fix-mute-LED-VREF-value-for-new-HP-laptops:
  ALSA: hda - Fix mute-LED VREF value for new HP laptops
  (bnc#745741).
* Wed Feb  8 2012 mgorman@suse.de
- patches.fixes/mm-page-allocator-drain-local-per-cpu-lists.patch:
  Drain local per-cpu lists for any allocation failure (bnc744392)
* Tue Feb  7 2012 eich@suse.de
- patches.drivers/drm-i915-sdvo-Fix-up-EDID-matching-logic.patch:
  drm/i915/sdvo: Fix up EDID matching logic (bnc #744315).
* Tue Feb  7 2012 tiwai@suse.de
- patches.drivers/drm-i915-set-AUD_CONFIG_N_index-for-DP: Refresh.
  Updated the patch from the upstream (bnc#722560)
* Tue Feb  7 2012 jkosina@suse.cz
- patches.suse/kdb-x86-unlock-nmi-lock-after-kdb-ipi.patch: x86:
  Unlock nmi lock after kdb_ipi call (bnc#745424).
* Tue Feb  7 2012 nfbrown@suse.de
- patches.fixes/lockd-arg-parse.fix: lockd: fix arg parsing for
  grace_period and timeout (bnc#733761).
* Sat Feb  4 2012 nfbrown@suse.de
- patches.fixes/nfs-bitmap-fix-fix: NFSv4: Fix an Oops in the
  NFSv4 getacl code (bnc#730117).
* Sat Feb  4 2012 jjolly@suse.de
- patches.arch/s390-45-04-kmsg-tag-jhash-v2.patch: kernel:
  incorrect kernel message tags (bnc#744795,LTC#78356).
* Fri Feb  3 2012 jjolly@suse.de
- patches.arch/s390-45-01-af_iucv-remove-iucv-path.patch: af_iucv:
  remove IUCV-pathes completely (bnc#744795,LTC#78292).
- patches.arch/s390-45-02-af_iucv-net-device.patch:
  af_iucv: performance improvements for new HS transport
  (bnc#744795,LTC#78346).
- patches.arch/s390-45-03-af_iucv-getsockopt-msgsize.patch:
  af_iucv: offer new getsockopt SO_MSGSIZE (bnc#744795,LTC#78348).
* Fri Feb  3 2012 jeffm@suse.com
- patches.suse/btrfs-handle-EIO: Fix typo.
* Fri Feb  3 2012 jeffm@suse.com
- patches.suse/btrfs-handle-EIO: Fix incorrect transaction abort in
  __btrfs_prealloc_file_range, add new error handling cases.
* Fri Feb  3 2012 jbohac@suse.cz
- Update config files: disable CONFIG_PTP_1588_CLOCK (bnc#744206)
- kabi/severities: work around the resulting kabi change
* Fri Feb  3 2012 oneukum@suse.de
- patches.fixes/0001-USB-xhci-fix-port-switching-on-PantherPoint.patch:
  USB:xhci: fix port switching on PantherPoint (bnc#744963).
* Fri Feb  3 2012 jkosina@suse.cz
- patches.arch/x86-pci-Increase-the-number-of-iommus-supported-to-be-MAX_IO_APICS.patch:
  Work around ia64 build problem.
- patches.suse/kdb-nmis-are-not-catastrophic: Fix build on non-UV enabled configs.
* Fri Feb  3 2012 hare@suse.de
- patches.suse/block-add-WARN_ON-in-blk_complete_requests.patch:
  block: Add WARN_ON in blk_complete_request() (bnc#738284).
* Fri Feb  3 2012 ptesarik@suse.cz
- rpm/kernel-binary.spec.in: Create build-id symlink for the
  vmlinux image.
* Fri Feb  3 2012 rjw@suse.de
- patches.arch/x86-pci-Increase-the-number-of-iommus-supported-to-be-MAX_IO_APICS.patch:
  x86, pci: Increase the number of iommus supported to be
  MAX_IO_APICS (bnc#744400).
* Fri Feb  3 2012 jeffm@suse.com
- patches.arch/uv-optimize-uv-nmis: UV: Optimize UV NMIs
  (bnc#744655).
- patches.arch/uv-use-nmi-backend: UV: Use NMI Backend
  (bnc#744655).
- patches.arch/uv-use-show_regs-in-nmi-handling: UV: Use show_regs
  in NMI handling (bnc#744655).
- patches.suse/kdb-fix-conflict-in-function-prototypes-between-kdb-h-and-lkdb-h:
  KDB: Fix conflict in function prototypes between kdb.h and
  lkdb.h (bnc#744655).
- patches.suse/kdb-nmis-are-not-catastrophic: KDB: NMIs are not
  catastrophic (bnc#744655).
* Fri Feb  3 2012 mgalbraith@suse.de
- patches.fixes/sched-disable-FAIR_SLEEPERS-for-S390.patch:
  sched: disable FAIR_SLEEPERS for S390 (bnc#724577).
* Thu Feb  2 2012 rjw@suse.de
- patches.arch/x86-UV-Enable-64-bit-ACPI-MFCG-support-for-SGI-UV2-platform.patch:
  x66, UV: Enable 64-bit ACPI MFCG support for SGI UV2 platform
  (bnc#744404).
* Thu Feb  2 2012 trenn@suse.de
- patches.suse/ibm_x3850M2_blacklist_modesetting.patch: Blacklist
  IBM 3850 M2 / x3950 M2 to not use radeon modesetting by default
  (bnc#743579).
* Thu Feb  2 2012 jbohac@suse.cz
- patches.fixes/ipv4-reintroduce-route-cache-garbage-collector.patch:
  fix build on some architectures (forgotten #include)
* Thu Feb  2 2012 jbohac@suse.cz
- patches.fixes/ipv4-reintroduce-route-cache-garbage-collector.patch:
  ipv4: reintroduce route cache garbage collector (bnc#724014).
* Thu Feb  2 2012 dsterba@suse.cz
- patches.suse/btrfs-delalloc-for-page-dirtied-out-of-band-in-fixup-worker:
  Refresh.
* Thu Feb  2 2012 jbohac@suse.cz
- patches.arch/x86-reduce-clock-calibration-time-during-slave-cpu-startup.patch:
  x86: Reduce clock calibration time during slave cpu startup
  (bnc#727650).
* Thu Feb  2 2012 dsterba@suse.cz
- patches.suse/btrfs-fix-structs-spinlock-bitfield.patch: btrfs:
  fix structs where bitfields and spinlock/atomic share 8B word
  (FATE#306586 bnc#734522).
* Thu Feb  2 2012 hare@suse.de
- patches.drivers/qla4xxx-do-not-print-warning-when-rom-lock-fails.patch:
  qla4xxx: Do not print warning when rom lock fails (bnc#744652).
* Thu Feb  2 2012 dsterba@suse.cz
- btrfs: back out
  patches.suse/btrfs-0363-make-sure-a-bitmap-has-enough-bytes.patch
  patches.suse/btrfs-0366-use-cluster-window_start-when-allocating-from-.patch
  patches.suse/btrfs-0368-fix-enospc-error-caused-by-wrong-checks-of-the.patch
  patches.suse/btrfs-0370-advance-window_start-if-we-re-using-a-bitmap.patch
- patches.suse/btrfs-btrfs_reserve_extent-check-sinfo: Refresh.
- patches.suse/btrfs-handle-EIO: Refresh.
* Thu Feb  2 2012 rjw@suse.de
- patches.arch/x86-UV2-Ack-BAU-interrupt-earlier.patch: x86/UV2:
  Ack BAU interrupt earlier (bnc#743212).
- patches.arch/x86-UV2-Add-accounting-for-BAU-strong-nacks.patch:
  x86/UV2: Add accounting for BAU strong nacks (bnc#743212).
- patches.arch/x86-UV2-Fix-BAU-destination-timeout-initialization.patch:
  x86/UV2: Fix BAU destination timeout initialization
  (bnc#743212).
- patches.arch/x86-UV2-Remove-stale-no-resources-test-for-UV2-BAU.patch:
  x86/UV2: Remove stale no-resources test for UV2 BAU
  (bnc#743212).
- patches.arch/x86-UV2-Work-around-BAU-bug.patch: x86/UV2:
  Work around BAU bug (bnc#743212).
- patches.arch/x86-UV2-use-native-UV2-broadcast-mode.patch: x86,
  UV2: use native UV2 broadcast mode (bnc#743212).
- patches.arch/x86-uv-fix-uninitialized-spinlocks-in-tlb_uv_c.patch:
  x86/uv: Fix uninitialized spinlocks (bnc#743212).
* Thu Feb  2 2012 rjw@suse.de
- patches.arch/x86-UV-Allow-for-non-consecutive-sockets.patch:
  x86, UV: Allow for non-consecutive sockets (bnc#743212).
- patches.arch/x86-UV-Correct-failed-topology-memory-leak.patch:
  x86, UV: Correct failed topology memory leak (bnc#743212).
- patches.arch/x86-UV-Correct-reset_with_ipi.patch: x86, UV:
  Correct reset_with_ipi() (bnc#743212).
- patches.arch/x86-UV-Fix-smp_processor_id-use-in-a-preemptable-region.patch:
  x86, UV: Fix smp_processor_id() use in a preemptable region
  (bnc#743212).
- patches.arch/x86-UV-Remove-cpumask_t-from-the-stack.patch:
  x86, UV: Remove cpumask_t from the stack (bnc#743212).
- patches.arch/x86-UV-Rename-hubmask-to-pnmask.patch: x86, UV:
  Rename hubmask to pnmask (bnc#743212).
* Thu Feb  2 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-017-Fix-duplicated-output-to-more-than-one-codec:
  ALSA: HDA: Fix duplicated output to more than one codec.
* Thu Feb  2 2012 hare@suse.de
- patches.drivers/qla4xxx-Fix-verify-boot-idx-correctly.patch:
  qla4xxx: Fix verify boot idx correctly (bnc#742570).
* Wed Feb  1 2012 mgorman@suse.de
- patches.fixes/mm-compaction-check-for-overlapping-nodes.patch:
  mm: compaction: Check for overlapping nodes during isolation (bnc737581)
* Wed Feb  1 2012 tiwai@suse.de
- Add missing two patches from 3.2 for fixing drm/i915 issues:
  patches.drivers/drm-bpp-and-depth-changes-require-full-mode-sets,
  patches.drivers/drm-try-to-restore-previous-CRTC-config-if-mode-set
* Wed Feb  1 2012 hare@suse.de
- patches.drivers/mpt2sas-Fix-for-Panic-when-inactive-volume-is-tried-deleting.patch:
  mpt2sas: Fix for Panic when inactive volume is tried deleting
  (bnc#736743).
* Wed Feb  1 2012 jbohac@suse.cz
- Update config files: disable CONFIG_RTC_HCTOSYS (bnc#743735)
* Wed Feb  1 2012 hare@suse.de
- patches.drivers/qla4xxx-Fix-huge-delay-for-ISP4022.patch:
  qla4xxx: Fix huge delay for ISP4022 (bnc#744253).
* Wed Feb  1 2012 brogers@suse.com
- patches.fixes/kvm-KVM-x86-Prevent-starting-PIT-timers-in-the-absence-o.patch:
  KVM: x86: Prevent starting PIT timers in the absence of irqchip
  support (bnc#738210 CVE-2011-4622).
- patches.fixes/kvm-KVM-x86-extend-struct-x86_emulate_ops-with-get_cpuid.patch:
  KVM: x86: extend "struct x86_emulate_ops" with "get_cpuid"
  (bnc#740969 CVE-2012-0045).
- patches.fixes/kvm-KVM-x86-fix-missing-checks-in-syscall-emulation.patch:
  KVM: x86: fix missing checks in syscall emulation (bnc#740969
  CVE-2012-0045).
* Tue Jan 31 2012 dsterba@suse.cz
- patches.suse/btrfs-handle-EIO: Refresh; quickfix to print abort warning only
  once (bnc#743978)
* Tue Jan 31 2012 hare@suse.de
- patches.drivers/qla4xxx-Fix-un-necessary-delay-on-invalid-DDB.patch:
  qla4xxx: Fix un-necessary delay on invalid DDB (bnc#744253).
* Tue Jan 31 2012 dsterba@suse.cz
  btrfs: sync with upstream, add a few fixes
- patches.suse/btrfs-0300-run-chunk-allocations-while-we-do-delayed-refs.patch:
  Btrfs: run chunk allocations while we do delayed refs
  (FATE#306586).
- patches.suse/btrfs-0301-lower-the-bar-for-chunk-allocation.patch:
  Btrfs: lower the bar for chunk allocation (FATE#306586).
- patches.suse/btrfs-0302-use-bigger-metadata-chunks-on-bigger-filesyste.patch:
  Btrfs: use bigger metadata chunks on bigger filesystems
  (FATE#306586).
- patches.suse/btrfs-0303-test-free-space-only-for-unclustered-allocatio.patch:
  Btrfs: test free space only for unclustered allocation
  (FATE#306586).
- patches.suse/btrfs-0304-don-t-set-up-allocation-result-twice.patch:
  Btrfs: don't set up allocation result twice (FATE#306586).
- patches.suse/btrfs-0305-revamp-clustered-allocation-logic.patch:
  Btrfs: revamp clustered allocation logic (FATE#306586).
- patches.suse/btrfs-0328-add-pinned-extents-to-on-disk-free-space-cache.patch:
  Btrfs: add pinned extents to on-disk free space cache correctly
  (FATE#306586).
- patches.suse/btrfs-0329-avoid-possible-NULL-deref-in-io_ctl_drop_pages.patch:
  Btrfs: avoid possible NULL deref in io_ctl_drop_pages()
  (FATE#306586).
- patches.suse/btrfs-0330-check-the-return-value-of-io_ctl_init.patch:
  Btrfs: check the return value of io_ctl_init() (FATE#306586).
- patches.suse/btrfs-0331-remove-BUG_ON-s-in-btrfs_ioctl_setflags.patch:
  Btrfs: remove BUG_ON()s in btrfs_ioctl_setflags() (FATE#306586).
- patches.suse/btrfs-0332-reserve-metadata-space-in-btrfs_ioctl_setflags.patch:
  Btrfs: reserve metadata space in btrfs_ioctl_setflags()
  (FATE#306586).
- patches.suse/btrfs-0333-don-t-pass-a-trans-handle-unnecessarily-in-vol.patch:
  Btrfs: don't pass a trans handle unnecessarily in volumes.c
  (FATE#306586).
- patches.suse/btrfs-0334-don-t-pre-allocate-btrfs-bio.patch:
  Btrfs: don't pre-allocate btrfs bio (FATE#306586).
- patches.suse/btrfs-0335-simplfy-calculation-of-stripe-length-for-disca.patch:
  Btrfs: simplfy calculation of stripe length for discard
  operation (FATE#306586).
- patches.suse/btrfs-0336-rewrite-btrfs_trim_block_group.patch:
  Btrfs: rewrite btrfs_trim_block_group() (FATE#306586).
- patches.suse/btrfs-0337-update-global-block_rsv-when-creating-a-new-bl.patch:
  Btrfs: update global block_rsv when creating a new block group
  (FATE#306586).
- patches.suse/btrfs-0338-fix-possible-deadlock-when-opening-a-seed-devi.patch:
  Btrfs: fix possible deadlock when opening a seed device
  (FATE#306586).
- patches.suse/btrfs-0339-generic-data-structure-to-build-unique-lists.patch:
  Btrfs: generic data structure to build unique lists
  (FATE#306586).
- patches.suse/btrfs-0340-added-helper-btrfs_next_item.patch:
  Btrfs: added helper btrfs_next_item() (FATE#306586).
- patches.suse/btrfs-0341-mark-delayed-refs-as-for-cow.patch:
  Btrfs: mark delayed refs as for cow (FATE#306586).
- patches.suse/btrfs-0342-always-save-ref_root-in-delayed-refs.patch:
  Btrfs: always save ref_root in delayed refs (FATE#306586).
- patches.suse/btrfs-0343-add-nested-locking-mode-for-paths.patch:
  Btrfs: add nested locking mode for paths (FATE#306586).
- patches.suse/btrfs-0344-add-sequence-numbers-to-delayed-refs.patch:
  Btrfs: add sequence numbers to delayed refs (FATE#306586).
- patches.suse/btrfs-0345-put-back-delayed-refs-that-are-too-new.patch:
  Btrfs: put back delayed refs that are too new (FATE#306586).
- patches.suse/btrfs-0346-add-waitqueue-instead-of-doing-busy-waiting-fo.patch:
  Btrfs: add waitqueue instead of doing busy waiting for more
  delayed refs (FATE#306586).
- patches.suse/btrfs-0347-added-btrfs_find_all_roots.patch:
  Btrfs: added btrfs_find_all_roots() (FATE#306586).
- patches.suse/btrfs-0348-new-backref-walking-code.patch: Btrfs:
  new backref walking code (FATE#306586).
- patches.suse/btrfs-0349-make-sure-we-re-not-using-obsolete-code-in-btr.patch:
  Btrfs: make sure we're not using obsolete code in
  btrfs_get_extent (FATE#306586).
- patches.suse/btrfs-0350-do-not-use-btrfs_end_transaction_throttle-ever.patch:
  Btrfs: do not use btrfs_end_transaction_throttle everywhere
  (FATE#306586).
- patches.suse/btrfs-0351-fix-btrfsck-error-400-when-truncating-a-compre.patch:
  Btrfs: fix btrfsck error 400 when truncating a compressed
  (FATE#306586).
- patches.suse/btrfs-0352-release-space-on-error-in-page_mkwrite.patch:
  Btrfs: release space on error in page_mkwrite (FATE#306586).
- patches.suse/btrfs-0353-don-t-call-btrfs_throttle-in-file-write.patch:
  Btrfs: don't call btrfs_throttle in file write (FATE#306586).
- patches.suse/btrfs-0354-add-allocator-tracepoints.patch: Btrfs:
  add allocator tracepoints (FATE#306586).
- patches.suse/btrfs-0355-protect-orphan-block-rsv-with-spin_lock.patch:
  Btrfs: protect orphan block rsv with spin_lock (FATE#306586).
- patches.suse/btrfs-0356-space-leak-tracepoints.patch: Btrfs:
  space leak tracepoints (FATE#306586).
- patches.suse/btrfs-0357-add-a-delalloc-mutex-to-inodes-for-delalloc-re.patch:
  Btrfs: add a delalloc mutex to inodes for delalloc reservations
  (FATE#306586).
- patches.suse/btrfs-0358-use-larger-system-chunks.patch: Btrfs:
  use larger system chunks (FATE#306586).
- patches.suse/btrfs-0359-preparation-to-fixing-mount-umount-race.patch:
  btrfs: preparation to fixing mount/umount race (FATE#306586).
- patches.suse/btrfs-0360-get-kill_sb-of-its-own.patch: btrfs:
  get ->kill_sb() of its own (FATE#306586).
- patches.suse/btrfs-0361-fix-mount-umount-race.patch: btrfs:
  fix mount/umount race (FATE#306586).
- patches.suse/btrfs-0362-fix-a-deadlock-in-btrfs_scan_one_device.patch:
  btrfs: fix a deadlock in btrfs_scan_one_device() (FATE#306586).
- patches.suse/btrfs-0363-make-sure-a-bitmap-has-enough-bytes.patch:
  Btrfs: make sure a bitmap has enough bytes (FATE#306586).
- patches.suse/btrfs-0364-Fix-busyloops-in-transaction-waiting-code.patch:
  btrfs: Fix busyloops in transaction waiting code (FATE#306586).
- patches.suse/btrfs-0365-Check-for-NULL-page-in-extent_range_uptodate.patch:
  Btrfs: Check for NULL page in extent_range_uptodate
  (FATE#306586).
- patches.suse/btrfs-0366-use-cluster-window_start-when-allocating-from-.patch:
  Btrfs: use cluster->window_start when allocating from a cluster
  bitmap (FATE#306586).
- patches.suse/btrfs-0367-do-not-defrag-a-file-partially.patch:
  Btrfs: do not defrag a file partially (FATE#306586).
- patches.suse/btrfs-0368-fix-enospc-error-caused-by-wrong-checks-of-the.patch:
  Btrfs: fix enospc error caused by wrong checks of the chunk
  (FATE#306586).
- patches.suse/btrfs-0369-mask-out-gfp-flags-in-releasepage.patch:
  btrfs: mask out gfp flags in releasepage (FATE#306586).
- patches.suse/btrfs-0370-advance-window_start-if-we-re-using-a-bitmap.patch:
  Btrfs: advance window_start if we're using a bitmap
  (FATE#306586).
- patches.suse/btrfs-0371-fix-reservations-in-btrfs_page_mkwrite.patch:
  Btrfs: fix reservations in btrfs_page_mkwrite (FATE#306586).
- patches.suse/btrfs-1005-add-basic-infrastructure-for-selective-balanci.patch:
  Refresh.
- patches.suse/btrfs-1015-recover-balance-on-mount.patch: Refresh.
- patches.suse/btrfs-1017-allow-for-pausing-restriper.patch:
  Refresh.
- patches.suse/btrfs-8043-improve-truncation-of-btrfs.patch:
  Refresh.
- patches.suse/btrfs-add-btrfs_panic: Refresh.
- patches.suse/btrfs-btrfs_reserve_extent-check-sinfo: Refresh.
- patches.suse/btrfs-handle-EIO: Refresh.
- patches.suse/btrfs-tree-log-wait_for_writer-should-return-void:
  Refresh.
- patches.suse/btrfs-0902-do-not-use-btrfs_end_transaction_throttle-ever.patch:
  Delete.
- patches.suse/btrfs-0903-don-t-call-btrfs_throttle-in-file-write.patch:
  Delete.
- patches.suse/btrfs-8001-rewrite-btrfs_trim_block_group.patch:
  Delete.
- patches.suse/btrfs-8025-update-global-block_rsv-when-creating-a-new-bl.patch:
  Delete.
- patches.suse/btrfs-8026-fix-possible-deadlock-when-opening-a-seed-devi.patch:
  Delete.
- patches.suse/btrfs-8030-generic-data-structure-to-build-unique-lists.patch:
  Delete.
- patches.suse/btrfs-8031-added-helper-btrfs_next_item.patch:
  Delete.
- patches.suse/btrfs-8032-mark-delayed-refs-as-for-cow.patch:
  Delete.
- patches.suse/btrfs-8033-always-save-ref_root-in-delayed-refs.patch:
  Delete.
- patches.suse/btrfs-8034-add-nested-locking-mode-for-paths.patch:
  Delete.
- patches.suse/btrfs-8035-add-sequence-numbers-to-delayed-refs.patch:
  Delete.
- patches.suse/btrfs-8036-put-back-delayed-refs-that-are-too-new.patch:
  Delete.
- patches.suse/btrfs-8037-add-waitqueue-instead-of-doing-busy-waiting-fo.patch:
  Delete.
- patches.suse/btrfs-8038-added-btrfs_find_all_roots.patch:
  Delete.
- patches.suse/btrfs-8039-new-backref-walking-code.patch: Delete.
- patches.suse/btrfs-8040-make-sure-we-re-not-using-obsolete-code-in-btr.patch:
  Delete.
- patches.suse/btrfs-8041-fix-btrfsck-error-400-when-truncating-a-compre.patch:
  Delete.
- patches.suse/btrfs-8044-release-space-on-error-in-page_mkwrite.patch:
  Delete.
- patches.suse/btrfs-8045-add-pinned-extents-to-on-disk-free-space-cache.patch:
  Delete.
- patches.suse/btrfs-8046-avoid-possible-NULL-deref-in-io_ctl_drop_pages.patch:
  Delete.
- patches.suse/btrfs-8047-check-the-return-value-of-io_ctl_init.patch:
  Delete.
- patches.suse/btrfs-8048-remove-BUG_ON-s-in-btrfs_ioctl_setflags.patch:
  Delete.
- patches.suse/btrfs-8049-reserve-metadata-space-in-btrfs_ioctl_setflags.patch:
  Delete.
- patches.suse/btrfs-8050-don-t-pass-a-trans-handle-unnecessarily-in-vol.patch:
  Delete.
- patches.suse/btrfs-8051-don-t-pre-allocate-btrfs-bio.patch:
  Delete.
- patches.suse/btrfs-8052-simplfy-calculation-of-stripe-length-for-disca.patch:
  Delete.
- patches.suse/btrfs-8056-run-chunk-allocations-while-we-do-delayed-refs.patch:
  Delete.
- patches.suse/btrfs-8057-lower-the-bar-for-chunk-allocation.patch:
  Delete.
- patches.suse/btrfs-8058-use-bigger-metadata-chunks-on-bigger-filesyste.patch:
  Delete.
- patches.suse/btrfs-8059-test-free-space-only-for-unclustered-allocatio.patch:
  Delete.
- patches.suse/btrfs-8060-don-t-set-up-allocation-result-twice.patch:
  Delete.
- patches.suse/btrfs-8061-revamp-clustered-allocation-logic.patch:
  Delete.
- patches.suse/btrfs-8062-add-allocator-tracepoints.patch: Delete.
- patches.suse/btrfs-8063-protect-orphan-block-rsv-with-spin_lock.patch:
  Delete.
- patches.suse/btrfs-8064-space-leak-tracepoints.patch: Delete.
- patches.suse/btrfs-8065-add-a-delalloc-mutex-to-inodes-for-delalloc-re.patch:
  Delete.
- patches.suse/btrfs-8066-use-larger-system-chunks.patch: Delete.
- patches.suse/btrfs-8067-mask-out-gfp-flags-in-releasepage.patch:
  Delete.
- patches.suse/btrfs-Fix-busyloops-in-transaction-waiting-code.patch:
  Delete.
* Tue Jan 31 2012 mmarek@suse.cz
- patches.suse/supported-flag
  patches.suse/supported-flag-enterprise: s/Novell/SUSE/ (bnc#741478).
* Mon Jan 30 2012 jack@suse.cz
- patches.fixes/large-hash-dcache_init-fix.patch: Fix oops when
  initializing large hash on > 16TB machine (bnc#742210).
* Mon Jan 30 2012 hare@suse.de
- patches.drivers/qla4xxx-bug-fixes-for-mixed-mode-support.patch:
  Revert ql4xdisablesysfsboot=0 (bnc#742570).
* Mon Jan 30 2012 tiwai@suse.de
- More stability fix patches for IvyBridge / SandyBridge graphics
  backported from 3.3-rc2 kernel:
  patches.drivers/drm-i915-Hold-gt_lock-across-forcewake-register-read,
  patches.drivers/drm-i915-Hold-gt_lock-during-reset,
  patches.drivers/drm-i915-Move-reset-forcewake-processing-to-gen6,
  patches.drivers/drm-i915-Re-enable-gen7-RC6-and-GPU-turbo-after-resume,
  patches.drivers/drm-i915-VBT-Parser-cleanup-for-eDP-block,
  patches.drivers/drm-i915-allow-userspace-forcewake-references,
  patches.drivers/drm-i915-convert-force_wake_get-to-func-pointer,
  patches.drivers/drm-i915-handle-3rd-pipe,
  patches.drivers/drm-i915-mask-transcoder-select-bits-before-setting,
  patches.drivers/drm-i915-paper-over-missed-irq-issues,
  patches.drivers/drm-i915-protect-force_wake_-get-put-with-the-gt_lock,
  patches.drivers/drm-i915-rip-out-the-HWSTAM-missed-irq-workaround,
  patches.drivers/drm-i915-sdvo-always-set-positive-sync-polarity,
  patches.drivers/drm-i915-simplify-pipe-checking
- patches.drivers/drm-i915-Work-around-gen7-BLT-ring-synchronization-i:
  Delete.  Obsoleted by the new fix.
* Mon Jan 30 2012 trenn@suse.de
  Add dev_warn() if the workaround gets active:
- patches.fixes/bug-735909_hard_wired_primary_bus.patch: Refresh.
* Mon Jan 30 2012 trenn@suse.de
- patches.fixes/bug-735909_hard_wired_primary_bus.patch:
  workaround hard-wired bus number (bnc#735909).
* Mon Jan 30 2012 sjayaraman@suse.de
- patches.drivers/floppy-cleanup-disk-queue-if-add_disk-was-never-called.patch:
  floppy: Cleanup disk->queue before caling put_disk() if
  add_disk() was never called (bnc#739381).
- patches.drivers/floppy-fix-a-crash-during-rmmod.patch: floppy:
  Fix a crash during rmmmod (bnc#739381).
* Mon Jan 30 2012 nfbrown@suse.de
- patches.fixes/nfs-bitmap-size.fix: NFSv4: include bitmap in
  nfsv4 get acl data (bnc#730117, CVE-2011-4131).
* Mon Jan 30 2012 nfbrown@suse.de
- patches.fixes/nfs-reval-dot.fix: nfs - handle d_revalidate of
  'dot' correctly (bnc#731809).
* Mon Jan 30 2012 nfbrown@suse.de
- patches.fixes/md-raid5-degraded-reshape-fix: md/raid5:
  ensure correct assessment of drives during degraded reshape
  (bcn#741289).
* Fri Jan 27 2012 jeffm@suse.com
- patches.suse/btrfs-delalloc-for-page-dirtied-out-of-band-in-fixup-worker:
  btrfs: delalloc for page dirtied out-of-band in fixup worker
  (bnc#720753).
* Fri Jan 27 2012 jack@suse.cz
- patches.fixes/block-fail-SCSI-passthrough-ioctls-on-partition-devi.patch:
  Silence warnings about some ioctls on partition.
* Fri Jan 27 2012 jslaby@suse.de
- patches.suse/revert-U6715-16550A-serial-driver-support.patch:
  Revert "U6715 16550A serial driver support" (bnc#739111).
* Fri Jan 27 2012 oneukum@suse.de
- patches.suse/elousb-fix-api-usage.patch: Fixed bug in USB core
  API usage, code cleanup (bnc#733863).
* Thu Jan 26 2012 mgorman@suse.de
- patches.suse/SoN-0009c-netvm-Propagate-page-pfmemalloc-to-skb.patch:
  Avoid NULL pointer dereference when propagating pfmemalloc to skb (bnc#743518)
* Thu Jan 26 2012 rw@suse.de
- patches.arch/x86-UV-uv_gpa_to_soc_phys_ram-shift.patch:
  x86 / UV: Fix uv_gpa_to_soc_phys_ram shift.  (bnc#740898)
- patches.arch/x86-UV2-harp-boot-message.patch:
  x86 / UV2: Fix blade count in boot messages.  (bnc#741117)
* Thu Jan 26 2012 jslaby@suse.de
- patches.fixes/tty-fix-UV-serial-console-regression.patch: TTY:
  fix UV serial console regression (bnc#718518).
- patches.suse/0001-Revert-serial-core-remove-uart_update_termios.patch:
  Delete.
- patches.suse/0002-Revert-serial-core-do-not-set-DTR-RTS-twice-on-st.patch:
  Delete.
- patches.suse/0003-Revert-serial-core-move-termios-handling-to-uart_.patch:
  Delete.
- patches.suse/0004-Revert-serial-fix-termios-settings-in-open.patch:
  Delete.
- patches.suse/0005-Revert-serial-Use-block_til_ready-helper.patch:
  Delete.
* Thu Jan 26 2012 jlee@suse.com
- patches.drivers/r8169-fix-Config2-MSIEnable-bit-setting.patch:
  r8169: fix Config2 MSIEnable bit setting. (bnc#741814)
* Thu Jan 26 2012 jack@suse.cz
- patches.fixes/xfs-Fix-missing-xfs_iunlock-on-error-recovery-path-i.patch:
  xfs: Fix missing xfs_iunlock() on error recovery path in
  xfs_readlink() (bnc#726600).
* Thu Jan 26 2012 jack@suse.cz
- patches.fixes/block-fail-SCSI-passthrough-ioctls-on-partition-devi.patch:
  Fixup return value from EINVAL to ENOTTY.
* Wed Jan 25 2012 duwe@suse.de
- patches.fixes/ipr-eeh-recovery-for-64-bit-adapters: ipr:
  fix eeh recovery for 64-bit adapters (bnc#742353).
* Wed Jan 25 2012 jjolly@suse.de
- patches.suse/0001-iw_cxgb4-workaround-powerpc64-rping-hang-as-a-driver.patch:
  iw_cxgb4: workaround powerpc64 rping hang as a driver specific
  change (bnc#721857).
* Wed Jan 25 2012 jack@suse.cz
- patches.fixes/block-add-and-use-scsi_blk_cmd_ioctl.patch: block:
  add and use scsi_blk_cmd_ioctl (bnc#738400 CVE-2011-4127).
- patches.fixes/block-fail-SCSI-passthrough-ioctls-on-partition-devi.patch:
  block: fail SCSI passthrough ioctls on partition devices
  (bnc#738400 CVE-2011-4127).
- patches.fixes/dm-do-not-forward-ioctls-from-logical-volumes-to-the.patch:
  dm: do not forward ioctls from logical volumes to the underlying
  device (bnc#738400 CVE-2011-4127).
* Wed Jan 25 2012 jack@suse.cz
- enable patches.suse/btrfs-Fix-busyloop-in-transaction-kthread.patch in
  series.conf
* Wed Jan 25 2012 jack@suse.cz
- patches.suse/btrfs-Fix-busyloop-in-transaction-kthread.patch:
  btrfs: Fix busyloop in transaction_kthread() (bnc#730103).
* Wed Jan 25 2012 jack@suse.cz
- patches.suse/btrfs-Fix-busyloops-in-transaction-waiting-code.patch:
  btrfs: Fix busyloops in transaction waiting code (bnc#730103).
* Tue Jan 24 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-016-Fix-silent-outputs-from-docking-station:
  ALSA: hda - Fix silent outputs from docking-station jacks of
  Dell laptops (bnc#740347).
* Tue Jan 24 2012 rgoldwyn@suse.de
- patches.fixes/ocfs2-serialize-unaligned-aio.patch: ocfs2:
  serialize unaligned aio  (bnc#671479).
* Mon Jan 23 2012 oneukum@suse.de
- patches.drivers/bug-708836_bluetooth-l2cap-security-race.patch:
  Bluetooth: Fix l2cap conn failures for ssp devices (bnc#708836).
* Mon Jan 23 2012 hare@suse.de
- patches.fixes/scsi-return-BLKPREP_KILL-in-prep_fn.patch: sd,sr:
  Return BLKPREP_KILL in prep_fn() (bnc#739381).
* Sun Jan 22 2012 jlee@suse.com
- patches.drivers/ixgbe-only-enable-WoL-for-magic-packet-by-default.patch:
  ixgbe: only enable WoL for magic packet by default. (bnc#741863)
* Fri Jan 20 2012 mmarek@suse.cz
- patches.fixes/xfs-fix-acl-count-validation-in-xfs_acl_from_disk:
  xfs: fix acl count validation in xfs_acl_from_disk()
  (bnc#740703, CVE-2012-0038).
* Fri Jan 20 2012 mhocko@suse.cz
- patches.fixes/proc-enable-writing-to-proc-pid-mem-revert.patch:
  proc: enable writing to /proc/pid/mem (bnc#742279
  CVE-2012-0056).
* Fri Jan 20 2012 mmarek@suse.cz
- patches.suse/supported-flag-sysfs: Delete, this has been merged
  into patches.suse/supported-flag.
* Fri Jan 20 2012 mmarek@suse.cz
- patches.fixes/igmp-Avoid-zero-delay: igmp: Avoid zero delay
  when receiving odd mixture of IGMP queries (CVE-2012-0207,
  bnc#740448).
* Fri Jan 20 2012 mmarek@suse.cz
- patches.kabi/ata_scsi_unlock_native_capacity-stub: kabi:
  Provide stub for ata_scsi_unlock_native_capacity().
* Fri Jan 20 2012 hare@suse.de
- patches.drivers/revert-libata-implement-on-demand-hpa-unlocking:
  Fixup patch for series2git.
* Fri Jan 20 2012 jbohac@suse.cz
- patches.fixes/bonding-dont-allow-mode-change-via-sysfs-with-slaves-present.patch:
  bonding: Don't allow mode change via sysfs with slaves present
  (bnc#737833).
- patches.fixes/bonding-fix-enslaving-in-alb-mode-when-link-down.patch:
  bonding: fix enslaving in alb mode when link down (bnc#737833).
* Thu Jan 19 2012 jeffm@suse.com
- patches.drivers/revert-libata-implement-on-demand-hpa-unlocking:
  revert: libata: implement on-demand HPA unlocking (bnc#713675).
* Thu Jan 19 2012 jeffm@suse.com
- patches.suse/btrfs-handle-EIO: Add missing unlock during failure in
  cow_file_range().
* Thu Jan 19 2012 hare@suse.de
- patches.suse/dasd-Clarify-comment.patch: dasd: Clarify comment
  (bnc#735543).
- patches.suse/dasd-Implement-failfast_retries.patch: dasd:
  Implement failfast_retries (bnc#735543).
- patches.suse/dasd-make-number-of-retries-configurable.patch:
  dasd: make number of retries configurable (bnc#735543).
* Thu Jan 19 2012 dsterba@suse.cz
- patches.suse/btrfs-8067-mask-out-gfp-flags-in-releasepage.patch:
  btrfs: mask out gfp flasg in releasepage (FATE#306586
  bnc#742181).
- patches.suse/btrfs-debug-setpagedirty-tracing.patch: Refresh.
* Tue Jan 17 2012 mgalbraith@suse.de
- Ward off potential SP1->SP2 HPC jitter regression
- patches.fixes/clockevents-Reinstate-the-per-cpu-tick-skew.patch:
  clockevents: Reinstate the per cpu tick skew.
* Tue Jan 17 2012 dsterba@suse.cz
- patches.suse/btrfs-1021-restriper-updates-v2.patch: Btrfs:
  restriper updates (FATE#306586).
* Mon Jan 16 2012 jeffm@suse.com
- patches.suse/btrfs-btrfs_reserve_extent-check-sinfo: btrfs:
  avoid NULL deref in btrfs_reserve_extent with DEBUG_ENOSPC.
- patches.suse/btrfs-btrfs_set_item_key_safe-should-bug-and-return-void:
  btrfs: btrfs_set_item_key_safe should BUG on error and return
  void.
- patches.suse/btrfs-btrfs_tree_unlock-should-return-void: btrfs:
  btrfs_tree_{,un}lock should return void.
- patches.suse/btrfs-clean_tree_block-should-panic-on-error-and-return-void:
  btrfs: clean_tree_block should panic on observed memory
  corruption and return void.
- patches.suse/btrfs-copy_for_split-should-return-void: Refresh.
- patches.suse/btrfs-disk-io-__setup_root-should-return-void:
  Refresh.
- patches.suse/btrfs-drop-gfp_t-from-lock_extent: btrfs: drop
  gfp_t from lock_extent.
- patches.suse/btrfs-handle-EIO: btrfs: Handle EIO
* Mon Jan 16 2012 mmarek@suse.cz
- patches.kabi/struct-bootsplash_data: Fix typo.
* Mon Jan 16 2012 mmarek@suse.cz
- patches.kabi/struct-bootsplash_data: bootsplash: Hide kabi
  change in struct bootsplash_data.
* Mon Jan 16 2012 dsterba@suse.cz
- patches.suse/btrfs-add-extent_state-alloc-free-tracing: Refresh.
* Mon Jan 16 2012 dsterba@suse.cz
- patches.suse/btrfs-8062-add-allocator-tracepoints.patch: Btrfs:
  add allocator tracepoints (FATE#306586).
- patches.suse/btrfs-8063-protect-orphan-block-rsv-with-spin_lock.patch:
  Btrfs: protect orphan block rsv with spin_lock (FATE#306586).
- patches.suse/btrfs-8064-space-leak-tracepoints.patch: Btrfs:
  space leak tracepoints (FATE#306586).
- patches.suse/btrfs-8065-add-a-delalloc-mutex-to-inodes-for-delalloc-re.patch:
  Btrfs: add a delalloc mutex to inodes for delalloc reservations
  (FATE#306586).
- patches.suse/btrfs-8066-use-larger-system-chunks.patch: Btrfs:
  use larger system chunks (FATE#306586).
* Mon Jan 16 2012 dsterba@suse.cz
- patches.suse/btrfs-8042-make-btrfs_truncate_inode_items-more-readable.patch:
  Refresh.
- patches.suse/btrfs-8059-test-free-space-only-for-unclustered-allocatio.patch:
  Btrfs: test free space only for unclustered allocation
  (FATE#306586).
- patches.suse/btrfs-8060-don-t-set-up-allocation-result-twice.patch:
  Btrfs: don't set up allocation result twice (FATE#306586).
- patches.suse/btrfs-8061-revamp-clustered-allocation-logic.patch:
  Btrfs: revamp clustered allocation logic (FATE#306586).
- patches.suse/btrfs-add-extent_state-alloc-free-tracing: Refresh.
- patches.suse/btrfs-unlock_extent-can-eliminate-gfp_t: Refresh.
* Mon Jan 16 2012 trenn@suse.de
- patches.fixes/pci_blacklist_usecrs.patch: Blacklist IBM 3850
  M2, x3950 M2 to use pci=nocrs (bnc#735909).
* Fri Jan 13 2012 tiwai@suse.de
- patches.suse/SUSE-bootsplash: Refresh;
  add a proper support for Xen fb (bnc#739020);
  fix the bootsplash-verbose switch race (bnc#734213)
* Fri Jan 13 2012 mmarek@suse.cz
- kabi/severities: One more fix for the pstore kabi change.
* Fri Jan 13 2012 ptesarik@suse.cz
- patches.suse/kdump-x86-remap-allocator: Add missing include.
* Fri Jan 13 2012 mmarek@suse.cz
- kabi/severities: Ignore pstore_write.
* Fri Jan 13 2012 mgorman@suse.de
- patches.fixes/mm-compaction-check-pfn_valid-entering-MAX_ORDER_NR_PAGES-block.patch:
  Check pfn_valid when entering a new MAX_ORDER_NR_PAGES block during isolation for migration.
* Fri Jan 13 2012 ptesarik@suse.cz
- patches.suse/kdump-x86-remap-allocator: Save remap allocator
  symbols to VMCOREINFO (bnc#738742).
* Fri Jan 13 2012 dsterba@suse.cz
- patches.suse/btrfs-0901-protect-orphan-block-rsv-with-spin_lock.patch:
  Btrfs: protect orphan block rsv with spin_lock (FATE#306586).
- patches.suse/btrfs-0902-do-not-use-btrfs_end_transaction_throttle-ever.patch:
  Btrfs: do not use btrfs_end_transaction_throttle everywhere
  (FATE#306586).
- patches.suse/btrfs-0903-don-t-call-btrfs_throttle-in-file-write.patch:
  Btrfs: don't call btrfs_throttle in file write (FATE#306586).
- patches.suse/btrfs-8043-improve-truncation-of-btrfs.patch:
  Refresh.
- patches.suse/btrfs-8056-run-chunk-allocations-while-we-do-delayed-refs.patch:
  Btrfs: run chunk allocations while we do delayed refs
  (FATE#306586).
- patches.suse/btrfs-8057-lower-the-bar-for-chunk-allocation.patch:
  Btrfs: lower the bar for chunk allocation (FATE#306586).
- patches.suse/btrfs-8058-use-bigger-metadata-chunks-on-bigger-filesyste.patch:
  Btrfs: use bigger metadata chunks on bigger filesystems
  (FATE#306586).
* Fri Jan 13 2012 trenn@suse.de
- kabi/severities:
  allow pstore/uefivars kabi change and re-enable:
  patches.drivers/006-pstore_3_2_fixes.patch
* Fri Jan 13 2012 jkosina@suse.cz
- patches.fixes/log2.h-Fix-rounddown_pow_of_two-1.patch:
  linux/log2.h: Fix rounddown_pow_of_two(1) (bnc#739356).
* Fri Jan 13 2012 dsterba@suse.cz
- patches.suse/btrfs-8024-workaround-for-cleaner-deadlock.patch:
  enhance the workaround
* Fri Jan 13 2012 trenn@suse.de
  Cleanup only: remove attempt to fix c-states init on physical
  cpu hotplug. Patches are not mainline and Intel agrees with it.
- patches.arch/acpi_processor_delay_cpuidle_init_on_hotplug.patch:
  Delete.
- patches.arch/acpi_processor_split_add.patch: Delete.
- patches.arch/intel_idle_register_per_cpu.patch: Delete.
* Fri Jan 13 2012 tiwai@suse.de
- patches.suse/SUSE-bootsplash: Refresh.  Suppress bootsplash with
  xenfb (bnc#739020)
* Fri Jan 13 2012 jankit@suse.de
- patches.drivers/mpt-fusion-check-sili-bit-read_6-for-data-underrun-errata:
  mptfusion : Added check for SILI bit in READ_6 CDB for DATA
  UNDERRUN ERRATA (bnc #712456).
* Fri Jan 13 2012 tiwai@suse.de
- patches.suse/SUSE-bootsplash: Update the patch from master to
  fix a copule of bugs.
* Fri Jan 13 2012 dsterba@suse.cz
- patches.suse/btrfs-btrfs_truncate_item-should-return-void:
  Refresh.
* Fri Jan 13 2012 ptesarik@suse.cz
- patches.suse/kdump-save-PG_compound: Save PG_compound or
  PG_head value in VMCOREINFO (bnc#741191).
* Fri Jan 13 2012 hare@suse.de
- patches.fixes/fcoe-fix-regression-on-offload-em-matching-function:
  fcoe: fix regression on offload em matching function for
  initiator/target (bnc#739856).
- patches.fixes/scsi_dh_alua-rtpg-flood-during-state-transitioning.patch:
  Update patch after suggestions from upstream discussion.
* Fri Jan 13 2012 lduncan@suse.de
- patches.drivers/qla4xxx-add-error-logging-for-firmware-abort:
  qla4xxx: Added error logging for firmware abort (bnc#738421).
- patches.drivers/qla4xxx-check-for-fw-alive-before-calling-chip_reset:
  qla4xxx: check for FW alive before calling chip_reset
  (bnc#738421).
- patches.drivers/qla4xxx-cleanup-make-qla4xxx_build_ddb_list-short:
  qla4xxx: cleanup, make qla4xxx_build_ddb_list short
  (bnc#738421).
- patches.drivers/qla4xxx-clear-the-risc-interrupt-bit-during-fw-init:
  qla4xxx: Clear the RISC interrupt bit during FW init
  (bnc#738421).
- patches.drivers/qla4xxx-disable-generating-pause-frames-in-case-of-fw-hung:
  qla4xxx: Disable generating pause frames in case of FW hung
  (bnc#738421).
- patches.drivers/qla4xxx-don-t-recover-adapter-if-device-state-is-failed:
  qla4xxx: Don't recover adapter if device state is FAILED
  (bnc#738421).
- patches.drivers/qla4xxx-fix-call-trace-on-rmmod-with-ql4xdontresethba-1:
  qla4xxx: fix call trace on rmmod with ql4xdontresethba=1
  (bnc#738421).
- patches.drivers/qla4xxx-fix-cpu-lockups-when-ql4xdontresethba-set:
  qla4xxx: Fix CPU lockups when ql4xdontresethba set (bnc#738421).
- patches.drivers/qla4xxx-fix-qla4xxx_dump_buffer-to-dump-buffer-correctly:
  qla4xxx: Fix qla4xxx_dump_buffer to dump buffer correctly
  (bnc#738421).
- patches.drivers/qla4xxx-fix-the-idc-locking-mechanism: qla4xxx:
  Fix the IDC locking mechanism (bnc#738421).
- patches.drivers/qla4xxx-perform-context-resets-in-case-of-context-failures:
  qla4xxx: Perform context resets in case of context failures
  (bnc#738421).
- patches.drivers/qla4xxx-temperature-monitoring-for-isp82xx-core:
  qla4xxx: Temperature monitoring for ISP82XX core (bnc#738421).
- patches.drivers/qla4xxx-wait-for-disable_acb-before-doing-set_acb:
  qla4xxx: Wait for disable_acb before doing set_acb (bnc#738421).
* Fri Jan 13 2012 dsterba@suse.cz
  btrfs fixes
- patches.suse/btrfs-0005-Don-t-BUG_ON-errors-in-__finish_chunk_alloc.patch:
  Refresh.
- patches.suse/btrfs-1001-introduce-masks-for-chunk-type-and-profile.patch:
  Refresh.
- patches.suse/btrfs-1004-add-basic-restriper-infrastructure.patch:
  Refresh.
- patches.suse/btrfs-1015-recover-balance-on-mount.patch: Refresh.
- patches.suse/btrfs-1017-allow-for-pausing-restriper.patch:
  Refresh.
- patches.suse/btrfs-1018-allow-for-cancelling-restriper.patch:
  Refresh.
- patches.suse/btrfs-1019-allow-for-resuming-restriper-after-it-was-paus.patch:
  Refresh.
- patches.suse/btrfs-8001-rewrite-btrfs_trim_block_group.patch:
  Refresh.
- patches.suse/btrfs-8025-update-global-block_rsv-when-creating-a-new-bl.patch:
  Refresh.
- patches.suse/btrfs-8026-fix-possible-deadlock-when-opening-a-seed-devi.patch:
  Refresh.
- patches.suse/btrfs-8027-fix-dirtied-pages-accounting-on-sub-page-write.patch:
  btrfs: fix dirtied pages accounting on sub-page writes
  (FATE#306586).
- patches.suse/btrfs-8030-generic-data-structure-to-build-unique-lists.patch:
  Btrfs: generic data structure to build unique lists
  (FATE#306586).
- patches.suse/btrfs-8031-added-helper-btrfs_next_item.patch:
  Btrfs: added helper btrfs_next_item() (FATE#306586).
- patches.suse/btrfs-8032-mark-delayed-refs-as-for-cow.patch:
  Btrfs: mark delayed refs as for cow (FATE#306586).
- patches.suse/btrfs-8033-always-save-ref_root-in-delayed-refs.patch:
  Btrfs: always save ref_root in delayed refs (FATE#306586).
- patches.suse/btrfs-8034-add-nested-locking-mode-for-paths.patch:
  Btrfs: add nested locking mode for paths (FATE#306586).
- patches.suse/btrfs-8035-add-sequence-numbers-to-delayed-refs.patch:
  Btrfs: add sequence numbers to delayed refs (FATE#306586).
- patches.suse/btrfs-8036-put-back-delayed-refs-that-are-too-new.patch:
  Btrfs: put back delayed refs that are too new (FATE#306586).
- patches.suse/btrfs-8037-add-waitqueue-instead-of-doing-busy-waiting-fo.patch:
  Btrfs: add waitqueue instead of doing busy waiting for more
  delayed refs (FATE#306586).
- patches.suse/btrfs-8038-added-btrfs_find_all_roots.patch:
  Btrfs: added btrfs_find_all_roots() (FATE#306586).
- patches.suse/btrfs-8039-new-backref-walking-code.patch: Btrfs:
  new backref walking code (FATE#306586).
- patches.suse/btrfs-8040-make-sure-we-re-not-using-obsolete-code-in-btr.patch:
  Btrfs: make sure we're not using obsolete code in
  btrfs_get_extent (FATE#306586).
- patches.suse/btrfs-8041-fix-btrfsck-error-400-when-truncating-a-compre.patch:
  Btrfs: fix btrfsck error 400 when truncating a compressed file
  extent (FATE#306586).
- patches.suse/btrfs-8042-make-btrfs_truncate_inode_items-more-readable.patch:
  Btrfs: make btrfs_truncate_inode_items() more readable
  (FATE#306586).
- patches.suse/btrfs-8043-improve-truncation-of-btrfs.patch:
  Btrfs: improve truncation of btrfs (FATE#306586).
- patches.suse/btrfs-8044-release-space-on-error-in-page_mkwrite.patch:
  Btrfs: release space on error in page_mkwrite (FATE#306586).
- patches.suse/btrfs-8045-add-pinned-extents-to-on-disk-free-space-cache.patch:
  Btrfs: add pinned extents to on-disk free space cache correctly
  (FATE#306586).
- patches.suse/btrfs-8046-avoid-possible-NULL-deref-in-io_ctl_drop_pages.patch:
  Btrfs: avoid possible NULL deref in io_ctl_drop_pages()
  (FATE#306586).
- patches.suse/btrfs-8047-check-the-return-value-of-io_ctl_init.patch:
  Btrfs: check the return value of io_ctl_init() (FATE#306586).
- patches.suse/btrfs-8048-remove-BUG_ON-s-in-btrfs_ioctl_setflags.patch:
  Btrfs: remove BUG_ON()s in btrfs_ioctl_setflags() (FATE#306586).
- patches.suse/btrfs-8049-reserve-metadata-space-in-btrfs_ioctl_setflags.patch:
  Btrfs: reserve metadata space in btrfs_ioctl_setflags()
  (FATE#306586).
- patches.suse/btrfs-8050-don-t-pass-a-trans-handle-unnecessarily-in-vol.patch:
  Btrfs: don't pass a trans handle unnecessarily in volumes.c
  (FATE#306586).
- patches.suse/btrfs-8051-don-t-pre-allocate-btrfs-bio.patch:
  Btrfs: don't pre-allocate btrfs bio (FATE#306586).
- patches.suse/btrfs-8052-simplfy-calculation-of-stripe-length-for-disca.patch:
  Btrfs: simplfy calculation of stripe length for discard
  operation (FATE#306586).
- patches.suse/btrfs-8053-rewrite-btrfs_trim_block_group.patch:
  Btrfs: rewrite btrfs_trim_block_group() (FATE#306586).
- patches.suse/btrfs-8054-update-global-block_rsv-when-creating-a-new-bl.patch:
  Btrfs: update global block_rsv when creating a new block group
  (FATE#306586).
- patches.suse/btrfs-8055-fix-possible-deadlock-when-opening-a-seed-devi.patch:
  Btrfs: fix possible deadlock when opening a seed device
  (FATE#306586).
- patches.suse/btrfs-_btrfs_mod_ref-s-process_func-should-return-void:
  Refresh.
- patches.suse/btrfs-_btrfs_mod_ref-should-return-void: Refresh.
- patches.suse/btrfs-add_delayed_data_ref-should-return-void:
  Refresh.
- patches.suse/btrfs-add_delayed_ref_head-should-return-void:
  Refresh.
- patches.suse/btrfs-add_delayed_tree_ref-should-return-void:
  Refresh.
- patches.suse/btrfs-btrfs_drop_snapshot-should-return-int:
  Refresh.
- patches.suse/btrfs-btrfs_free_extent-void-return-prep: Refresh.
- patches.suse/btrfs-btrfs_inc_extent_ref-void-return-prep:
  Refresh.
- patches.suse/btrfs-btrfs_pin_extent-error-push-up: Refresh.
- patches.suse/btrfs-btrfs_truncate_item-should-return-void:
  Refresh.
- patches.suse/btrfs-del_ptr-should-return-void: Refresh.
- patches.suse/btrfs-delayed-ref-mempool-functions-should-return-void:
  Refresh.
- patches.suse/btrfs-lock-extent-can-drop-gfp_t-argument: Refresh.
- patches.suse/btrfs-unlock_extent-can-eliminate-gfp_t: Refresh.
- patches.suse/btrfs-use-mempools-for-delayed-refs: Refresh.
* Thu Jan 12 2012 trenn@suse.de
- Disable patches.drivers/006-pstore_3_2_fixes.patch due to kabi
  breakage
* Thu Jan 12 2012 trenn@suse.de
- patches.drivers/004-pstore_3_2_fixes.patch: Refresh.
- patches.drivers/005-pstore_3_2_fixes.patch: pstore: gracefully
  handle NULL pstore_info functions (bnc#718551).
- patches.drivers/006-pstore_3_2_fixes.patch: pstore: pass reason
  to backend write callback (bnc#718551).
* Thu Jan 12 2012 jlee@suse.com
- patches.fixes/SCSI-libcxgbi-do-not-print-a-message-when-memory-all.patch:
  [SCSI] libcxgbi: do not print a message when memory allocation
  fails. (bnc#725594)
* Thu Jan 12 2012 duwe@suse.de
- patches.fixes/powerpc-migration-vphn-fix: fix hang during live
  partition migration (bnc#740866).
* Thu Jan 12 2012 trenn@suse.de
- patches.drivers/hpwdt_avoid_double_nmi_msg.patch: watchdog:
  hpwdt: prevent multiple "NMI occurred" messages (bnc#740997).
* Thu Jan 12 2012 dsterba@suse.cz
  btrfs: update restriper
- patches.suse/btrfs-1000-get-rid-of-_alloc_profile-fields.patch:
  Refresh.
- patches.suse/btrfs-1001-introduce-masks-for-chunk-type-and-profile.patch:
  Refresh.
- patches.suse/btrfs-1002-add-btrfs_AVAIL_ALLOC_BIT_SINGLE-bit.patch:
  Refresh.
- patches.suse/btrfs-1003-make-avail_-_alloc_bits-fields-dynamic.patch:
  Refresh.
- patches.suse/btrfs-1004-add-basic-restriper-infrastructure.patch:
  Refresh.
- patches.suse/btrfs-1005-add-basic-infrastructure-for-selective-balanci.patch:
  Btrfs: add basic infrastructure for selective balancing
  (FATE#306586).
- patches.suse/btrfs-1006-profiles-filter.patch: Btrfs: profiles
  filter (FATE#306586).
- patches.suse/btrfs-1007-usage-filter.patch: Btrfs: usage filter
  (FATE#306586).
- patches.suse/btrfs-1008-devid-filter.patch: Btrfs: devid filter
  (FATE#306586).
- patches.suse/btrfs-1009-devid-subset-filter.patch: Btrfs:
  devid subset filter (FATE#306586).
- patches.suse/btrfs-1010-virtual-address-space-subset-filter.patch:
  Btrfs: virtual address space subset filter (FATE#306586).
- patches.suse/btrfs-1011-do-not-reduce-profile-in-do_chunk_alloc.patch:
  Btrfs: do not reduce profile in do_chunk_alloc() (FATE#306586).
- patches.suse/btrfs-1012-implement-online-profile-changing.patch:
  Btrfs: implement online profile changing (FATE#306586).
- patches.suse/btrfs-1013-soft-profile-changing-mode-aka-soft-convert.patch:
  Btrfs: soft profile changing mode (aka soft convert)
  (FATE#306586).
- patches.suse/btrfs-1014-save-balance-parameters-to-disk.patch:
  Btrfs: save balance parameters to disk (FATE#306586).
- patches.suse/btrfs-1015-recover-balance-on-mount.patch: Btrfs:
  recover balance on mount (FATE#306586).
- patches.suse/btrfs-1016-add-skip_balance-mount-option.patch:
  Btrfs: add skip_balance mount option (FATE#306586).
- patches.suse/btrfs-1017-allow-for-pausing-restriper.patch:
  Btrfs: allow for pausing restriper (FATE#306586).
- patches.suse/btrfs-1018-allow-for-cancelling-restriper.patch:
  Btrfs: allow for cancelling restriper (FATE#306586).
- patches.suse/btrfs-1019-allow-for-resuming-restriper-after-it-was-paus.patch:
  Btrfs: allow for resuming restriper after it was paused
  (FATE#306586).
- patches.suse/btrfs-1020-add-balance-progress-reporting.patch:
  Btrfs: add balance progress reporting (FATE#306586).
- patches.suse/btrfs-1005-implement-online-profile-changing.patch:
  Delete.
- patches.suse/btrfs-1006-add-basic-infrastructure-for-selective-balanci.patch:
  Delete.
- patches.suse/btrfs-1007-soft-profile-changing-mode-aka-soft-convert.patch:
  Delete.
- patches.suse/btrfs-1008-profiles-filter.patch: Delete.
- patches.suse/btrfs-1009-usage-filter.patch: Delete.
- patches.suse/btrfs-1010-devid-filter.patch: Delete.
- patches.suse/btrfs-1011-devid-subset-filter.patch: Delete.
- patches.suse/btrfs-1012-virtual-address-space-subset-filter.patch:
  Delete.
- patches.suse/btrfs-1013-save-restripe-parameters-to-disk.patch:
  Delete.
- patches.suse/btrfs-1014-recover-restripe-on-mount.patch: Delete.
- patches.suse/btrfs-1015-allow-for-cancelling-restriper.patch:
  Delete.
- patches.suse/btrfs-1016-allow-for-pausing-restriper.patch:
  Delete.
- patches.suse/btrfs-1017-allow-for-resuming-restriper-after-it-was-paus.patch:
  Delete.
- patches.suse/btrfs-1018-add-skip_restripe-mount-option.patch:
  Delete.
- patches.suse/btrfs-1019-get-rid-of-btrfs_balance-function.patch:
  Delete.
- patches.suse/btrfs-1020-add-restripe-progress-reporting.patch:
  Delete.
* Thu Jan 12 2012 jbeulich@novell.com
- patches.xen/1140-xs-payload-limit.patch: xenbus: Reject replies with
  payload > XENSTORE_PAYLOAD_MAX.
- patches.xen/1142-xenbus-reset-watches-check.patch: xenbus: check
  availibility of XS_RESET_WATCHES command.
- Refresh Xen patches (bnc#733822, bnc#738528).
- Update Xen config files.
* Thu Jan 12 2012 mgalbraith@suse.de
- patches.fixes/sched-Only-queue-remote-wakeups-when-crossing-cache-boundaries.patch:
  sched: Only queue remote wakeups when crossing cache boundaries (bnc#722993).
* Wed Jan 11 2012 rjw@suse.de
- patches.suse/pci-pciehp-Automatically-load-on-VMware.patch:
  pciehp: Automatically load on VMware (bnc#736669).
* Wed Jan 11 2012 dsterba@suse.cz
  btrfs update up to 3.2
- patches.suse/btrfs-0286-fix-worker-lock-misuse-in-find_worker.patch:
  Btrfs: fix worker lock misuse in find_worker (FATE#306586).
- patches.suse/btrfs-0287-call-d_instantiate-after-all-ops-are-setup.patch:
  Btrfs: call d_instantiate after all ops are setup (FATE#306586).
* Wed Jan 11 2012 dsterba@suse.cz
- patches.suse/btrfs-debug-setpagedirty-tracing.patch:
  setpagedirty tracing v4.
* Wed Jan 11 2012 jjolly@suse.de
- patches.arch/s390-44-01-pgste-update.patch: kernel: no
  storage key operations for invalid page table entries
  (bnc#740780,LTC#77697).
* Wed Jan 11 2012 jbeulich@novell.com
- patches.suse/stack-unwind: Fix more 2.6.29 merge problems plus a
  glue code problem (bnc#736018).
* Wed Jan 11 2012 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-015-Fix-the-lost-power-setup-of-seconary-pins-a:
  ALSA: hda - Fix the lost power-setup of seconary pins after
  PM resume (bnc#740347).
* Wed Jan 11 2012 mszeredi@suse.cz
- patches.fixes/fix-shrink_dcache_parent-livelock.patch: fix
  shrink_dcache_parent() livelock (bnc#735277).
* Tue Jan 10 2012 gregkh@suse.de
- supported.conf: (bnc#737969) add ums-realtek to base and supported, as
  well as ums-eneub6250, both of which we supported as part of the
  usb-storage driver in SLE11 SP1 (the driver split since then.)  Also
  mark uas.ko as unsupported as it is not good quality yet, and wasn't
  even listed in the file.
* Tue Jan 10 2012 trenn@suse.de
- patches.drivers/cciss_fix_const.patch: Fix compiler warning,
  no functional change (bnc#740281).
- patches.drivers/cciss_simple_mode.patch: cciss: Adds simple
  mode functionality (bnc#737574).
* Tue Jan 10 2012 tiwai@suse.de
- patches.drivers/drm-i915-Add-support-for-resetting-the-SO-write-poin:
  patches.drivers/drm-i915-Clean-up-multi-threaded-forcewake-patch:
  patches.drivers/drm-i915-Do-the-fallback-non-IRQ-wait-in-ring-thrott:
  patches.drivers/drm-i915-Force-sync-command-ordering-Gen6:
  patches.drivers/drm-i915-Make-the-fallback-IRQ-wait-not-sleep:
  patches.drivers/drm-i915-Set-two-chicken-bits-implicated-in-missed-I:
  patches.drivers/drm-i915-Update-GEN6_RP_CONTROL-definitions:
  patches.drivers/drm-i915-Work-around-gen7-BLT-ring-synchronization-i:
  patches.drivers/drm-i915-check-ACTHD-of-all-rings:
  patches.drivers/drm-i915-don-t-bail-out-of-intel_wait_ring_buffer-to:
  patches.drivers/drm-i915-don-t-disable-a-PCH-DPLL-that-s-in-use:
  patches.drivers/drm-i915-kicking-rings-stuck-on-semaphores-considere:
  patches.drivers/drm-i915-only-set-the-intel_crtc-DPMS-mode-to-on-if-:
  patches.drivers/drm-i915-relative_constants_mode-race-fix:
  Backport 3.3-fix patches for SNB/IVB GPUs (bnc#735417)
- patches.drivers/drm-i915-set-AUD_CONFIG_N_index-for-DP: Refresh.
* Tue Jan 10 2012 jeffm@suse.com
- patches.fixes/xfs-dmapi-fix-crash-due-to-null-pointer-dereference:
  xfs/dmapi: Fix crash due to NULL pointer dereference
  (bnc#735765).
* Tue Jan 10 2012 tiwai@suse.de
- patches.drivers/drm-i915-DisplayPort-hot-remove-notification-to-audio-driver:
  patches.drivers/drm-i915-HDMI-hot-remove-notification-to-audio-driver:
  patches.drivers/drm-i915-dont-trigger-hotplug-events-on-uncached-ELD:
  patches.drivers/drm-i915-fix-ELD-writing-for-SandyBridge:
  patches.drivers/drm-i915-rename-audio-ELD-registers: Refresh.
  just update tags.
* Tue Jan 10 2012 tiwai@suse.de
- patches.drivers/drm-i915-set-AUD_CONFIG_N_index-for-DP:
  drm/i915: set AUD_CONFIG N_value_index for DisplayPort
  (bnc#722560,bnc#711201).
* Tue Jan 10 2012 trenn@suse.de
- patches.drivers/cciss_fix_const.patch: Fix pointer type mismatch
  which leads to corruptions in kdump case (bnc#740281).
* Tue Jan 10 2012 gregkh@suse.de
- Final 3.1 -> 3.2 usb 3 patch set:
- patches.drivers/USB3-0377-asix-new-device-id.patch: asix:
  new device id.
- patches.drivers/usb-fix-number-of-mapped-sg-dma-entries.patch:
  Refresh.
* Mon Jan  9 2012 mhocko@suse.cz
- patches.fixes/mm-Fix-NULL-ptr-dereference-in-__count_immobile_page.patch:
  mm: Fix NULL ptr dereference in __count_immobile_pages
  (bnc#738117).
* Mon Jan  9 2012 jack@suse.cz
- patches.fixes/jbd-Issue-cache-flush-after-checkpointing.patch:
  jbd: Issue cache flush after checkpointing (bnc#731770).
* Mon Jan  9 2012 mmarek@suse.cz
- patches.drivers/sfc-dummy-option: sfc: Provide dummy module
  parameters for compatibility with SLE11-SP1 (bnc#720460).
* Mon Jan  9 2012 hare@suse.de
- patches.drivers/lpfc-8.3.5.48.2p-update: Update Emulex LPFC
  driver to 8.3.5.48.2p (bnc#736896).
* Mon Jan  9 2012 tiwai@suse.de
- patches.drivers/drm-i915-Disable-RC6-on-Sandybridge-by-default:
  drm/i915: Disable RC6 on Sandybridge by default (bnc#735417).
- patches.drivers/drm-i915-Disable-semaphores-by-default-on-SNB:
  drm/i915: Disable semaphores by default on SNB (bnc#735417).
* Mon Jan  9 2012 hare@suse.de
- patches.drivers/ixgbe-resolve-errors-with-many-to-one-mappings.patch:
  ixgbe: Resolve errors with many to one up2tc mappings
  (bnc#714789).
* Mon Jan  9 2012 jbeulich@novell.com
- patches.xen/1134-blktap-locking.patch: blktap: fix locking (again)
  (bnc#724734).
- patches.xen/1135-blktap-map-once.patch: blktap: ensure mmap() is
  called only once per region.
- patches.xen/1137-netback-wait-for-hotplug.patch: netback: wait for
  hotplug scripts to complete before signalling connected to frontend.
- patches.xen/1138-netfront-delay-gARP.patch: netfront: delay gARP
  until backend switches to Connected.
- Update Xen patches to 3.0.14.
- patches.xen/xen-x86-msr-on-pcpu: Rename and extend to ...
- patches.xen/xen-x86-pcpu: ... this (x86: pCPU handling).
* Thu Jan  5 2012 jbohac@suse.cz
- patches.fixes/net-make-ipv6-bind-honour-freebind.patch: net:
  make ipv6 bind honour freebind (bnc#736182).
- patches.fixes/net-make-ipv6-pktinfo-honour-freebind.patch:
  net: make ipv6 PKTINFO honour freebind (bnc#736182).
- patches.fixes/net-relax-pktinfo-non-local-ipv6-udp-xmit-check.patch:
  relax PKTINFO non local ipv6 udp xmit check (bnc#736182).
* Wed Jan  4 2012 mgorman@suse.de
- patches.fixes/mm-stop_machine-reorganize-stop_cpus-implementation.patch
- patches.fixes/mm-stop_machine-implement-stop_machine_from_inactive_cpu.patch
- patches.fixes/mm-x86,-mtrr-use-stop_machine-APIs-for-doing-MTRR-rendezvous.patch
- patches.fixes/mm-x86-Serialize-SMP-bootup-CMOS-accesses-on-rtc_lock.patch
- patches.fixes/mm-VFS--mount-lock-scalability-for-internal-mounts.patch
- patches.fixes/fs-sysfs-do-dcache-related-updates-to-sysfs-under-sysfs_mutex.patch
- patches.fixes/mm-page-allocator-do-not-drain-per-cpu-lists-via-IPI-from-page-allocator-context.patch
  Guard against sending IPI to offline CPUs (bnc#729122 bnc#738567)
* Mon Jan  2 2012 mhocko@suse.cz
- patches.fixes/oom-thaw-threads-if-oom-killed-thread-is-frozen-befo.patch:
  Update references (bnc#718831).
* Sat Dec 31 2011 bpoirier@suse.de
- patches.fixes/x25-Handle-undersized-fragmented-skbs.patch: x25:
  Handle undersized/fragmented skbs (CVE-2010-3873 bnc#651219).
- patches.fixes/x25-Validate-incoming-call-user-data-lengths.patch:
  x25: Validate incoming call user data lengths (CVE-2010-3873
  bnc#651219).
* Fri Dec 30 2011 bpoirier@suse.de
- patches.fixes/net-check-return-value-for-dst_alloc.patch: net:
  check return value for dst_alloc (bnc#737624).
- patches.fixes/net-Add-a-flow_cache_flush_deferred-function.patch:
  net: Add a flow_cache_flush_deferred function (bnc#737624).
* Fri Dec 23 2011 jack@suse.cz
- patches.fixes/reiserfs-writeback-buffer-lock.patch: reiserfs:
  Lock buffers unconditionally in reiserfs_write_full_page()
  (bnc#716023).
- patches.fixes/writeback-include-all-inodes-in-background.patch:
  writeback: Include all dirty inodes in background writeback
  (bnc#716023).
* Thu Dec 22 2011 jack@suse.cz
- patches.fixes/ext3-Fix-error-handling-on-inode-bitmap-corruption.patch:
  ext3: Fix error handling on inode bitmap corruption
  (bnc#733270).
* Thu Dec 22 2011 jack@suse.cz
- patches.fixes/ext3-Don-t-warn-from-writepage-when-readonly-inode-i.patch:
  ext3: Don't warn from writepage when readonly inode is spotted
  after error (bnc#731945).
* Thu Dec 22 2011 dsterba@suse.cz
- patches.suse/btrfs-debug-setpagedirty-tracing.patch: Refresh.
* Wed Dec 21 2011 jack@suse.cz
- patches.fixes/reiserfs-Fix-quota-mount-option-parsing.patch:
  reiserfs: Fix quota mount option parsing (bnc#728626).
* Wed Dec 21 2011 tiwai@suse.de
- patches.fixes/ACPI-Battery-Add-the-check-before-refresh-sysfs-in-t:
  ACPI / Battery: Add the check before refresh sysfs in the
  battery_notify() (bnc#738056).
- patches.fixes/ACPI-Battery-Add-the-hibernation-process-in-the-batt:
  ACPI / Battery: Add the hibernation process in the
  battery_notify() (bnc#738056).
- patches.fixes/ACPI-Battery-Resolve-the-race-condition-in-the-sysfs:
  ACPI / Battery: Resolve the race condition in the
  sysfs_remove_battery() (bnc#738056).
- patches.fixes/ACPI-Battery-avoid-acpi_battery_add-use-after-free:
  ACPI / Battery: avoid acpi_battery_add() use-after-free
  (bnc#738056).
- patches.fixes/ACPI-Battery-propagate-sysfs-error-in-acpi_battery_a:
  ACPI / Battery: propagate sysfs error in acpi_battery_add()
  (bnc#738056).
- patches.fixes/Battery-sysfs_remove_battery-possible-circular-locki:
  Battery: sysfs_remove_battery(): possible circular locking
  (bnc#738056).
* Wed Dec 21 2011 tiwai@suse.de
- patches.kabi/drm-i915-ILK-VT-d-workaround-kABI-fix: Fix kABI
  for patches.drivers/drm-i915-ILK-VT-d-workaround.
* Wed Dec 21 2011 tiwai@suse.de
- Fixed series.conf to apply the missing
  patches.drivers/drm-i915-close-PM-interrupt-masking-races-in-the-rps.patch
* Wed Dec 21 2011 tiwai@suse.de
- patches.drivers/drm-i915-ILK-VT-d-workaround: drm/i915: ILK +
  VT-d workaround; missing patch from the previous commit.
* Wed Dec 21 2011 tiwai@suse.de
- patches.drivers/Revert-and-fix-drm-i915-dp-remove-DPMS-mode-tracking,
  patches.drivers/drm-i915-Add-an-interface-to-dynamically-change-the-,
  patches.drivers/drm-i915-All-PCH-refclks-are-120MHz, drm/i915,
  patches.drivers/drm-i915-Allow-SSC-parameter-to-override-VBT-value,
  patches.drivers/drm-i915-Cache-GT-fifo-count-for-SandyBridge,
  patches.drivers/drm-i915-Check-eDP-power-when-doing-aux-channel-comm,
  patches.drivers/drm-i915-Check-for-eDP-inside-edp-panel-on-off-funcs,
  patches.drivers/drm-i915-Combine-pinning-with-setting-to-the-display,
  patches.drivers/drm-i915-Correct-eDP-panel-power-sequencing-delay-co,
  patches.drivers/drm-i915-Create-helper-functions-to-determine-eDP-po,
  patches.drivers/drm-i915-Defend-against-userspace-creating-a-gem-obj,
  patches.drivers/drm-i915-Delay-DP-i2c-initialization-until-panel-pow,
  patches.drivers/drm-i915-Disable-FBC-across-page-flipping,
  patches.drivers/drm-i915-Disable-eDP-VDD-in-a-delayed-work-proc-inst,
  patches.drivers/drm-i915-Document-a-few-more-BDB_GENERAL_FEATURES-bi,
  patches.drivers/drm-i915-Dumb-down-the-semaphore-logic,
  patches.drivers/drm-i915-Enable-SDVO-hotplug-interrupts-for-HDMI-and,
  patches.drivers/drm-i915-Enable-digital-port-hotplug-on-PCH-systems,
  patches.drivers/drm-i915-Enable-dither-whenever-display-bpc-frame-bu,
  patches.drivers/drm-i915-Enable-eDP-panel-power-during-I2C-initializ,
  patches.drivers/drm-i915-Ensure-eDP-powered-up-during-DP_SET_POWER-o,
  patches.drivers/drm-i915-Ensure-panel-is-on-during-DPMS-off,
  patches.drivers/drm-i915-FBC-off-for-ironlake-and-older-otherwise-on,
  patches.drivers/drm-i915-Fix-PCH-SSC-reference-clock-settings,
  patches.drivers/drm-i915-Fix-memory-leak-in-i915_gem_busy_ioctl,
  patches.drivers/drm-i915-Fix-multifunction-SDVO-detection,
  patches.drivers/drm-i915-Flush-other-plane-register-writes,
  patches.drivers/drm-i915-Hook-up-Ivybridge-eDP, drm/i915,
  patches.drivers/drm-i915-In-intel_dp_init-replace-read-of-DPCD-with-,
  patches.drivers/drm-i915-Initialize-PCH-refclks-at-modeset-init-time,
  patches.drivers/drm-i915-Initiate-DP-link-training-only-on-the-lanes,
  patches.drivers/drm-i915-Introduce-i915_gem_object_finish_gpu,
  patches.drivers/drm-i915-Introduce-i915_gem_object_finish_gtt,
  patches.drivers/drm-i915-Let-panel-power-sequencing-hardware-do-its-,
  patches.drivers/drm-i915-Make-DP-prepare-commit-consistent-with-DP-d,
  patches.drivers/drm-i915-Mark-the-cursor-and-the-overlay-as-being-pa,
  patches.drivers/drm-i915-Move-common-PCH_PP_CONTROL-setup-to-ironlak,
  patches.drivers/drm-i915-Move-eDP-panel-fixed-mode-from-dev_priv-to-,
  patches.drivers/drm-i915-No-need-to-wait-for-eDP-power-off-delay-if-,
  patches.drivers/drm-i915-Only-export-the-generic-intel_disable_fbc-i,
  patches.drivers/drm-i915-Only-use-VBT-panel-mode-on-eDP-if-no-EDID-i,
  patches.drivers/drm-i915-PLL-macro-cleanup-and-pipe-assertion-check,
  patches.drivers/drm-i915-Perform-intel_enable_fbc-from-a-delayed-tas,
  patches.drivers/drm-i915-Remove-early-exit-on-i915_gpu_idle,
  patches.drivers/drm-i915-Remove-i2c_speed-nonsense-from-child-device,
  patches.drivers/drm-i915-Remove-implied-length-of-2-from-GFX_OP_PIPE,
  patches.drivers/drm-i915-Remove-link_status-field-from-intel_dp-stru,
  patches.drivers/drm-i915-Remove-redundant-bit-shifting-from-intel_gm,
  patches.drivers/drm-i915-Remove-vestigial-pitch-from-post-gen2-FBC-c,
  patches.drivers/drm-i915-Rename-PIPE_CONTROL-bit-defines-to-be-less-,
  patches.drivers/drm-i915-Rename-i915_dp_detect_common-to-intel_dp_ge,
  patches.drivers/drm-i915-Rename-intel_sdvo_hdmi_sink_detect,
  patches.drivers/drm-i915-Replace-direct-calls-to-vfunc.disable_fbc-w,
  patches.drivers/drm-i915-Restrict-ILK-specific-eDP-power-hack-to-ILK,
  patches.drivers/drm-i915-Select-correct-pipe-during-TV-detect,
  patches.drivers/drm-i915-Set-crtc-DPMS-mode-to-ON-in-intel_crtc_mode,
  patches.drivers/drm-i915-Set-persistent-mode-for-ILK-SNB-framebuffer,
  patches.drivers/drm-i915-Share-the-common-work-of-disabling-active-F,
  patches.drivers/drm-i915-Shut-down-PCH-interrupts-during-irq_uninsta,
  patches.drivers/drm-i915-Skip-GPU-wait-for-scanout-pin-while-wedged,
  patches.drivers/drm-i915-TVDAC_STATE_CHG-does-not-indicate-successfu,
  patches.drivers/drm-i915-Treat-PCH-eDP-like-DP-in-most-places,
  patches.drivers/drm-i915-Treat-pre-gen4-backlight-duty-cycle-value-c,
  patches.drivers/drm-i915-Try-harder-during-dp-pattern-1-link-trainin,
  patches.drivers/drm-i915-Turn-force-VDD-back-off-when-panel-running-,
  patches.drivers/drm-i915-Unlock-PCH_PP_CONTROL-always, drm/i915,
  patches.drivers/drm-i915-Use-CK505-as-non-SSC-source-where-available,
  patches.drivers/drm-i915-Use-DPCD-value-for-max-DP-lanes,
  patches.drivers/drm-i915-Use-PIPE_CONTROL-for-flushing-on-gen6,
  patches.drivers/drm-i915-Use-dp_detect_common-in-hotplug-helper-func,
  patches.drivers/drm-i915-Use-mode_config.mutex-in-ironlake_panel_vdd,
  patches.drivers/drm-i915-Use-of-a-CPU-fence-is-mandatory-to-update-F,
  patches.drivers/drm-i915-Use-the-LLC-mode-on-gen6-for-everything-but,
  patches.drivers/drm-i915-Use-the-uncached-domain-for-the-display-pla,
  patches.drivers/drm-i915-add-DP-test-request-handling, drm/i915,
  patches.drivers/drm-i915-add-PLL-sharing-support-to-handle-3-pipes,
  patches.drivers/drm-i915-allow-cache-sharing-policy-control,
  patches.drivers/drm-i915-apply-phase-pointer-override-on-SNB-too,
  patches.drivers/drm-i915-bios-Avoid-temporary-allocation-whilst-sear,
  patches.drivers/drm-i915-check-for-supported-depth-at-fb-init-time,
  patches.drivers/drm-i915-close-PM-interrupt-masking-races-in-the-irq,
  patches.drivers/drm-i915-close-PM-interrupt-masking-races-in-the-rps.patch,
  patches.drivers/drm-i915-disable-temporal-dithering-on-the-internal-,
  patches.drivers/drm-i915-don-t-set-SDVO-color-range-on-ILK,
  patches.drivers/drm-i915-don-t-set-transcoder-bpc-on-CougarPoint,
  patches.drivers/drm-i915-don-t-set-unpin_work-if-vblank_get-fails,
  patches.drivers/drm-i915-don-t-use-uninitialized-EDID-bpc-values-whe,
  patches.drivers/drm-i915-dp-Don-t-turn-CPT-DP-ports-on-too-early,
  patches.drivers/drm-i915-dp-Explicitly-disable-symbol-scrambling-whi,
  patches.drivers/drm-i915-dp-Explicitly-request-8-10-channel-coding,
  patches.drivers/drm-i915-dp-Fix-eDP-on-PCH-DP-on-CPT-PPT,
  patches.drivers/drm-i915-dp-Fix-the-math-in-intel_dp_link_required,
  patches.drivers/drm-i915-dp-Introduce-is_cpu_edp, drm/i915/dp,
  patches.drivers/drm-i915-dp-Remove-eDP-special-cases-from-bandwidth-,
  patches.drivers/drm-i915-dp-Retry-DPCD-fetch-on-G4X-too,
  patches.drivers/drm-i915-dp-wait-for-previous-AUX-channel-activity-t,
  patches.drivers/drm-i915-edp_panel_on-does-not-need-to-return-a-bool,
  patches.drivers/drm-i915-enable-cacheable-objects-on-Ivybridge,
  patches.drivers/drm-i915-enable-semaphores-on-per-device,
  patches.drivers/drm-i915-export-a-CPT-mode-set-verification-function,
  patches.drivers/drm-i915-fix-ILK-infoframe-support, drm/i915,
  patches.drivers/drm-i915-fix-PCH-PLL-assertion-check-for-3-pipes,
  patches.drivers/drm-i915-fix-debug-output-for-3-pipe-configs,
  patches.drivers/drm-i915-fix-swizzling-on-gen6, drm/i915,
  patches.drivers/drm-i915-flush-plane-control-changes-on-ILK-as-well,
  patches.drivers/drm-i915-gtt-Split-out-i915_gem_gtt_rebind_object,
  patches.drivers/drm-i915-hdmi-HDMI-source-product-description-infofr,
  patches.drivers/drm-i915-hdmi-send-AVI-info-frames-on-ILK-as-well,
  patches.drivers/drm-i915-hdmi-split-infoframe-setting-from-infoframe,
  patches.drivers/drm-i915-i915_gem_object_finish_gtt-must-always-rele,
  patches.drivers/drm-i915-only-match-on-PCI_BASE_CLASS_DISPLAY,
  patches.drivers/drm-i915-prevent-division-by-zero-when-asking-for-ch,
  patches.drivers/drm-i915-properly-cancel-rps_work-on-module-unload-v,
  patches.drivers/drm-i915-sdvo-Include-LVDS-panels-for-the-IS_DIGITAL,
  patches.drivers/drm-i915-set-GFX_MODE-to-pre-Ivybridge-default-value,
  patches.drivers/drm-i915-set-bpc-for-DP-transcoder, drm/i915,
  patches.drivers/drm-i915-set-watermarks-for-third-pipe-on-IVB,
  patches.drivers/drm-i915-show-interrupt-info-on-IVB, drm/i915,
  patches.drivers/drm-i915-simplify-swapin-out-swizzle-checking-a-bit,
  patches.drivers/drm-i915-split-out-Ironlake-pipe-bpp-picking-code,
  patches.drivers/drm-i915-split-out-PCH-refclk-update-code,
  patches.drivers/drm-i915-split-out-plane-update-code, drm/i915,
  patches.drivers/drm-i915-split-refclk-code-out-of-ironlake_crtc_mode,
  patches.drivers/drm-i915-support-3-pipes-on-IVB, drm/i915,
  patches.drivers/drm-i915-use-correct-SPD-type-value, drm/i915,
  patches.drivers/drm-i915-use-pipe-bpp-in-DP-link, drm/i915,
  patches.drivers/drm-i915-use-pipe-bpp-in-DP-link-bandwidth-calculati,
  patches.drivers/drm-i915-use-pipe-bpp-when-setting-HDMI-bpc,
  patches.drivers/drm-i915-use-transcoder-select-bits-on-VGA-and-HDMI-,
  patches.drivers/drv-i915-Pull-display_clock_mode-out-of-VBT-table:
  update drm/i915 to 3.2-rc6 equivalent (bnc#7297470,bnc#729466,
  bnc#735417)
* Wed Dec 21 2011 jjolly@suse.de
- patches.fixes/dasd-fix-erp-expiration.patch: Delete.
  Duplicate of s390-43-03-dasd-fix-erp-expiration.patch
* Wed Dec 21 2011 jjolly@suse.de
- patches.arch/s390-43-01-qeth_hd_recover.patch: qeth: improve
  recovery during resource shortage (bnc#737328,LTC#77239).
- patches.arch/s390-43-02-console-panic.patch: kernel: console
  interrupts vs. panic (bnc#737328,LTC#77272).
- patches.arch/s390-43-03-dasd-fix-erp-expiration.patch:
  dasd: fix expiration handling for recovery requests
  (bnc#737328,bnc#735543,LTC#77273).
* Tue Dec 20 2011 dsterba@suse.cz
- patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch:
  Refresh.
- patches.suse/btrfs-lock-extent-can-drop-gfp_t-argument: Refresh.
- patches.suse/btrfs-unlock_extent-can-eliminate-gfp_t-addon:
  Refresh.
* Mon Dec 19 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-119-Fix-invalid-mute-led-state-on-resume-of-IDT,
  patches.drivers/alsa-sp1-hda-120-Make-sure-mute-led-reflects-master-mute-state,
  patches.drivers/alsa-sp1-hda-121-Add-support-of-4-internal-speakers-on-cNB,
  patches.drivers/alsa-sp2-hda-002-Make-CONFIG_SND_HDA_POWER_SAVE-depending,
  patches.drivers/alsa-sp2-hda-003-Add-post_suspend-patch-ops,
  patches.drivers/alsa-sp2-hda-004-Allow-codec-specific-set_power_state-ops,
  patches.drivers/alsa-sp2-hda-008-sigmatel-Automatically-retrieve-digital-I-O,
  patches.drivers/alsa-sp2-hda-010-Avoid-touching-mute-VREF-pin-for-IDT-codecs,
  patches.drivers/alsa-sp2-hda-011-Fix-S3-S4-problem-on-machines-with-VREF-pin,
  patches.drivers/alsa-sp2-hda-012-Fix-GPIO-LED-setup-for-IDT-92HD75-codecs,
  patches.drivers/alsa-sp2-hda-013-Fix-remaining-VREF-mute-LED-NID-check-in-po,
  patches.drivers/drm-i915-By-default-enable-RC6-on-IVB-and-SNB,
  patches.drivers/drm-i915-add-multi-threaded-forcewake,
  patches.drivers/drm-i915-pass-ELD-to-HDMI-DP-audio-driver,
  patches.drivers/drm-i915-set-the-right-SDVO-transcoder-for-CPT,
  patches.drivers/drm-support-routines-for-HDMI-DP-ELD,
  patches.drivers/hp_accel-Add-a-new-PNP-id:
  Refreshed GIT and mainline tags
* Mon Dec 19 2011 dsterba@suse.cz
  btrfs sync with upstream
- patches.suse/btrfs-0270-fix-wrong-i_size-when-truncating-a-file-to-a-l.patch:
  Btrfs: fix wrong i_size when truncating a file to a larger size
  (FATE#306586).
- patches.suse/btrfs-0271-fix-wrong-disk-space-information-of-the-files.patch:
  Btrfs: fix wrong disk space information of the files
  (FATE#306586).
- patches.suse/btrfs-0272-fix-inaccurate-available-space-on-raid0-profil.patch:
  Btrfs: fix inaccurate available space on raid0 profile
  (FATE#306586).
- patches.suse/btrfs-0273-keep-orphans-for-subvolume-deletion.patch:
  btrfs: keep orphans for subvolume deletion (FATE#306586).
- patches.suse/btrfs-0274-fix-ctime-update-of-on-disk-inode.patch:
  Btrfs: fix ctime update of on-disk inode (FATE#306586).
- patches.suse/btrfs-0275-add-a-cond_resched-into-the-worker-loop.patch:
  Btrfs: add a cond_resched() into the worker loop (FATE#306586).
- patches.suse/btrfs-0276-Establish-i_ops-before-calling-d_instantiate.patch:
  BTRFS: Establish i_ops before calling d_instantiate
  (FATE#306586).
- patches.suse/btrfs-0277-deal-with-NULL-srv_rsv-in-the-delalloc-inode-r.patch:
  Btrfs: deal with NULL srv_rsv in the delalloc inode reservation
  code (FATE#306586).
- patches.suse/btrfs-0278-fix-num_workers_starting-bug-and-other-bugs-in.patch:
  Btrfs: fix num_workers_starting bug and other bugs in async
  thread (FATE#306586).
- patches.suse/btrfs-0279-deal-with-enospc-from-dirtying-inodes-properly.patch:
  Btrfs: deal with enospc from dirtying inodes properly
  (FATE#306586).
- patches.suse/btrfs-0280-fix-how-we-do-delalloc-reservations-and-how-we.patch:
  Btrfs: fix how we do delalloc reservations and how we free
  reservations on error (FATE#306586).
- patches.suse/btrfs-0281-fix-leaked-space-in-truncate.patch:
  Btrfs: fix leaked space in truncate (FATE#306586).
- patches.suse/btrfs-0282-don-t-panic-if-orphan-item-already-exists.patch:
  Btrfs: don't panic if orphan item already exists (FATE#306586).
- patches.suse/btrfs-0283-only-set-cache_generation-if-we-setup-the-bloc.patch:
  Btrfs: only set cache_generation if we setup the block group
  (FATE#306586).
- patches.suse/btrfs-0284-unplug-every-once-and-a-while.patch:
  Btrfs: unplug every once and a while (FATE#306586).
- patches.suse/btrfs-8018-use-irqsave-spinlocks-everywhere.patch:
  Refresh.
- patches.suse/btrfs-0901-fix-num_workers_starting-bug-and-other-bugs-in.patch:
  Delete.
- patches.suse/btrfs-0902-deal-with-enospc-from-dirtying-inodes-properly.patch:
  Delete.
- patches.suse/btrfs-0903-fix-how-we-do-delalloc-reservations-and-how-we.patch:
  Delete.
- patches.suse/btrfs-0904-fix-leaked-space-in-truncate.patch:
  Delete.
- patches.suse/btrfs-0905-only-set-cache_generation-if-we-setup-the-bloc.patch:
  Delete.
- patches.suse/btrfs-0906-don-t-panic-if-orphan-item-already-exists.patch:
  Delete.
- patches.suse/btrfs-8027-fix-ctime-update-of-on-disk-inode.patch:
  Delete.
- patches.suse/btrfs-8028-fix-wrong-disk-space-information-of-the-files.patch:
  Delete.
- patches.suse/btrfs-8029-fix-wrong-i_size-when-truncating-a-file-to-a-l.patch:
  Delete.
- patches.suse/btrfs-8030-fix-inaccurate-available-space-on-raid0-profil.patch:
  Delete.
* Mon Dec 19 2011 jeffm@suse.com
- patches.drivers/libata-unlock-hpa-by-default: libata: unlock
  HPA by default (bnc#299267 bnc#713675).
* Mon Dec 19 2011 hare@suse.de
- patches.drivers/cciss-stable-controller-enumeration.patch:
  Set 'cciss_allow_hpsa=0' per default (bnc#713707).
* Sun Dec 18 2011 rjw@suse.de
- patches.fixes/pci-hotplug-do-not-register-pcie-ports-for-acpiphp.patch:
  Refresh.
* Fri Dec 16 2011 ptesarik@suse.cz
- patches.fixes/per_cpu_ptr_to_phys-non-page-aligned.patch:
  percpu: fix per_cpu_ptr_to_phys() handling of non-page-aligned
  addresses (bnc#733543).
* Fri Dec 16 2011 jbeulich@novell.com
- Update Xen patches to 3.0.13.
* Fri Dec 16 2011 tiwai@suse.de
- patches.fixes/mac80211-be-more-careful-in-suspend-resume:
  mac80211: be more careful in suspend/resume (bnc#728329).
* Thu Dec 15 2011 tonyj@suse.de
- patches.fixes/perf-fail-softly-on-eopnotsupp.patch: perf fail
  softly on EOPNOTSUPP (bnc#736079).
* Thu Dec 15 2011 mmarek@suse.de
- Import RC2 kabi kabi files.
* Thu Dec 15 2011 dsterba@suse.cz
  btrfs fixes
- patches.suse/btrfs-0006-fix-error-check-of-btrfs_lookup_dentry.patch:
  Refresh.
- patches.suse/btrfs-0903-fix-how-we-do-delalloc-reservations-and-how-we.patch:
  Refresh.
- patches.suse/btrfs-0905-only-set-cache_generation-if-we-setup-the-bloc.patch:
  Btrfs: only set cache_generation if we setup the block group
  (FATE#306586).
- patches.suse/btrfs-0906-don-t-panic-if-orphan-item-already-exists.patch:
  Btrfs: don't panic if orphan item already exists (FATE#306586).
- patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch:
  Refresh.
- patches.suse/btrfs-8024-workaround-for-cleaner-deadlock.patch:
  btrfs: workaround for cleaner deadlock (FATE#306586).
- patches.suse/btrfs-8025-update-global-block_rsv-when-creating-a-new-bl.patch:
  Btrfs: update global block_rsv when creating a new block group
  (FATE#306586).
- patches.suse/btrfs-8026-fix-possible-deadlock-when-opening-a-seed-devi.patch:
  Btrfs: fix possible deadlock when opening a seed device
  (FATE#306586).
- patches.suse/btrfs-8027-fix-ctime-update-of-on-disk-inode.patch:
  Btrfs: fix ctime update of on-disk inode (FATE#306586).
- patches.suse/btrfs-8028-fix-wrong-disk-space-information-of-the-files.patch:
  Btrfs: fix wrong disk space information of the files
  (FATE#306586).
- patches.suse/btrfs-8029-fix-wrong-i_size-when-truncating-a-file-to-a-l.patch:
  Btrfs: fix wrong i_size when truncating a file to a larger size
  (FATE#306586).
- patches.suse/btrfs-8030-fix-inaccurate-available-space-on-raid0-profil.patch:
  Btrfs: fix inaccurate available space on raid0 profile
  (FATE#306586).
- patches.suse/btrfs-debug-setpagedirty-tracing.patch:
  setpagedirty tracing v2. [disabled]
* Wed Dec 14 2011 jdelvare@suse.de
- patches.fixes/ipmi-fix-deadlock-in-start_next_msg.patch: ipmi:
  Fix deadlock in start_next_msg() (bnc#730749).
* Wed Dec 14 2011 dsterba@suse.cz
- fix typo in series.conf (no cat involved)
* Wed Dec 14 2011 dsterba@suse.cz
- disable fs-fix-how-we-clear-DCACHE_NEED_LOOKUP.patch for now
* Wed Dec 14 2011 mgorman@suse.de
- patches.suse/mm-compaction-introduce-sync-light-migration-hugetlbfs-fix.patch
  Update signature of hugetlbfs migration callback
* Wed Dec 14 2011 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-014-fix-GPIO-to-control-mute-LED:
  ALSA: hda - GPIO to control mute LED may be enabled on HP
  systems with no such HW (bnc#732535).
* Wed Dec 14 2011 hare@suse.de
- patches.fixes/dasd-fix-erp-expiration.patch: I/O stalls when
  writing to a reserved DASD (bnc#735543).
* Tue Dec 13 2011 nfbrown@suse.de
- patches.suse/0003a-md-improve-raid10-failure: md/raid10:
  Improve decision on whether to fail a device with a read error
  (bnc#735543).
- patches.suse/0004-md-raid10-add-failfast-handling-for-reads.patch:
  Refresh.
- patches.suse/0005-md-raid10-add-failfast-handling-for-writes.patch:
  Refresh.
* Tue Dec 13 2011 bpoirier@suse.de
- patches.fixes/batman-adv-Only-write-requested-number-of-byte-to-us.patch:
  batman-adv: Only write requested number of byte to user buffer
  (bnc#736149 CVE-2011-4604).
- patches.fixes/batman-adv-bat_socket_read-missing-checks.patch:
  batman-adv: bat_socket_read missing checks (bnc#736149
  CVE-2011-4604).
* Tue Dec 13 2011 tiwai@suse.de
- patches.drivers/drm-i915-By-default-enable-RC6-on-IVB-and-SNB:
  drm/i915: By default, enable RC6 on IVB and SNB when reasonable
  (bnc#735417).
- patches.drivers/iommu-Export-intel_iommu_enabled: iommu: Export
  intel_iommu_enabled to signal when iommu is in use (bnc#735417).
* Tue Dec 13 2011 dsterba@suse.cz
- patches.suse/btrfs-0269-fix-btrfs_end_bio-to-deal-with-write-errors-to.patch:
  Btrfs: fix btrfs_end_bio to deal with write errors to a single
  mirror (FATE#306586).
- patches.suse/btrfs-0903-fix-how-we-do-delalloc-reservations-and-how-we.patch:
  Btrfs: fix how we do delalloc reservations and how we free
  reservations on error (FATE#306586).
- patches.suse/btrfs-0904-fix-leaked-space-in-truncate.patch:
  Btrfs: fix leaked space in truncate (FATE#306586).
- patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch:
  Refresh.
- patches.suse/btrfs-unlock_extent-can-eliminate-gfp_t-addon:
  Refresh.
* Tue Dec 13 2011 mmarek@suse.cz
- patches.drivers/0001-iwlagn-separate-firmware-version-warning.patch:
  Delete.
- patches.drivers/0002-iwlagn-bump-firmware-API-for-some-devices.patch:
  Delete, the 3.0 driver does not work with the new firmware.
* Tue Dec 13 2011 jjolly@suse.de
- patches.arch/s390-42-01-ap-process-requests-after-reset.patch:
  ap: Setup timer for sending messages after reset
  (bnc#735369,LTC#76969).
- patches.arch/s390-42-02-cio_disallow_driver_io_for_known_to_be_broken_paths.patch:
  cio: disallow driver io for known to be broken paths
  (bnc#735369,LTC#77108).
- patches.arch/s390-42-03-irq-accounting.patch: kernel: fix
  interrupt accounting (bnc#735369,LTC#77186).
* Tue Dec 13 2011 nfbrown@suse.de
- patches.suse/0004-md-raid10-add-failfast-handling-for-reads.patch:
  Fix bug which caused an oops (bnc#736257)
- patches.suse/0005-md-raid10-add-failfast-handling-for-writes.patch:
  Refresh to align with previous patch.
* Mon Dec 12 2011 rjw@suse.de
- patches.fixes/pci-hotplug-do-not-register-pcie-ports-for-acpiphp.patch:
  PCI / Hotplug: Do not register slots for PCIe ports with native
  HP (bnc#714552, bnc#732471).
- patches.fixes/acpiphp-ignore-root-bridges-using-PCIe-native-hotplug:
  Delete.
* Mon Dec 12 2011 hare@suse.de
-  patches.fixes/net-fix-crash-due-to-wrong-dev-in-calling.patch:
  Reshuffle patch to apply.
* Mon Dec 12 2011 hare@suse.de
- patches.fixes/net-fix-crash-due-to-wrong-dev-in-calling.patch:
  net: fixes a crash due to wrong dev in calling
  __netif_receive_skb (bnc#732582).
* Mon Dec 12 2011 mhocko@suse.cz
- patches.fixes/net-ipv4-relax-AF_INET-check-in-bind.patch: net:
  ipv4: relax AF_INET check in bind() (bnc#735216).
* Mon Dec 12 2011 oneukum@suse.de
- patches.drivers/Bluetooth_Fixed_Atheros_AR3012_Maryann_PID_VID_supported.patch:
  Bluetooth: Fixed Atheros AR3012 Maryann PID/VID supported
  (bnc#732296).
* Sat Dec 10 2011 gregkh@suse.de
- patches.drivers/usb-fix-number-of-mapped-sg-dma-entries.patch:
  usb: fix number of mapped SG DMA entries.
* Fri Dec  9 2011 gregkh@suse.de
- start of 3.0.14 patches, needed now as there are ABI changes.
- patches.kernel.org/alarmtimers-fix-time-comparison.patch:
  alarmtimers: Fix time comparison.
- patches.kernel.org/alsa-hda-realtek-fix-oops-in-alc_mux_select.patch:
  ALSA: hda/realtek - Fix Oops in alc_mux_select().
- patches.kernel.org/alsa-sis7019-give-slow-codecs-more-time-to-reset.patch:
  ALSA: sis7019 - give slow codecs more time to reset.
- patches.kernel.org/arm-at91-fix-clock-conid-for-atmel_tcb.1-on-9260-9g20.patch:
  ARM: at91: fix clock conid for atmel_tcb.1 on 9260/9g20.
- patches.kernel.org/arm-davinci-da850-evm-change-audio-edma-event-queue-to-eventq_0.patch:
  ARM: davinci: da850 evm: change audio edma event queue to
  EVENTQ_0.
- patches.kernel.org/arm-davinci-dm646x-evm-wrong-register-used-in-setup_vpif_input_channel_mode.patch:
  ARM: davinci: dm646x evm: wrong register used in
  setup_vpif_input_channel_mode.
- patches.kernel.org/arm-mx23-recognise-stmp378x-as-mx23.patch:
  arm: mx23: recognise stmp378x as mx23.
- patches.kernel.org/asoc-provide-a-more-complete-dma-driver-stub.patch:
  ASoC: Provide a more complete DMA driver stub.
- patches.kernel.org/fix-apparmor-dereferencing-potentially-freed-dentry-sanitize-__d_path-api.patch:
  fix apparmor dereferencing potentially freed dentry, sanitize
  __d_path() API.
- patches.kernel.org/fs-proc-meminfo.c-fix-compilation-error.patch:
  fs/proc/meminfo.c: fix compilation error.
- patches.kernel.org/mm-ensure-that-pfn_valid-is-called-once-per-pageblock-when-reserving-pageblocks.patch:
  mm: Ensure that pfn_valid() is called once per pageblock when
  reserving pageblocks.
- patches.kernel.org/mm-vmalloc-check-for-page-allocation-failure-before-vmlist-insertion.patch:
  mm: vmalloc: check for page allocation failure before vmlist
  insertion.
- patches.kernel.org/ptp-fix-clock_getres-implementation.patch:
  ptp: Fix clock_getres() implementation.
- patches.kernel.org/thp-add-compound-tail-page-_mapcount-when-mapped.patch:
  thp: add compound tail page _mapcount when mapped.
- patches.kernel.org/thp-set-compound-tail-page-_count-to-zero.patch:
  thp: set compound tail page _count to zero.
- patches.fixes/mm-Ensure-that-pfn_valid-is-called-once-per-pagebloc.patch:
  Delete.
- patches.fixes/mm-vmalloc-check-for-allocation-failure-before-insertion.patch:
  Delete.
* Fri Dec  9 2011 gregkh@suse.de
- patches.kernel.org/patch-3.0.12-13: Linux 3.0.13.
- patches.kernel.org/add-missing-.set-function-for-nt_s390_last_break-regset.patch:
  Delete.
- patches.kernel.org/alsa-lx6464es-fix-device-communication-via-command-bus.patch:
  Delete.
- patches.kernel.org/arm-7161-1-errata-no-automatic-store-buffer-drain.patch:
  Delete.
- patches.kernel.org/arm-mx28-fix-bit-operation-in-clock-setting.patch:
  Delete.
- patches.kernel.org/arm-omap-smartreflex-fix-irq-handling-bug.patch:
  Delete.
- patches.kernel.org/arm-omap2-select-arm_amba-if-omap3_emu-is-defined.patch:
  Delete.
- patches.kernel.org/arm-pxa-fix-inconsistent-config_usb_pxa27x.patch:
  Delete.
- patches.kernel.org/asoc-ensure-wm8731-register-cache-is-synced-when-resuming-from-disabled.patch:
  Delete.
- patches.kernel.org/asoc-fsl_ssi-properly-initialize-the-sysfs-attribute-object.patch:
  Delete.
- patches.kernel.org/asoc-wm8753-skip-noop-reconfiguration-of-dai-mode.patch:
  Delete.
- patches.kernel.org/cfg80211-amend-regulatory-null-dereference-fix.patch:
  Delete.
- patches.kernel.org/cfg80211-fix-race-on-init-and-driver-registration.patch:
  Delete.
- patches.kernel.org/cfg80211-fix-regulatory-null-dereference.patch:
  Delete.
- patches.kernel.org/cgroup_freezer-fix-freezing-groups-with-stopped-tasks.patch:
  Delete.
- patches.kernel.org/clockevents-set-noop-handler-in-clockevents_exchange_device.patch:
  Delete.
- patches.kernel.org/clocksource-fix-bug-with-max_deferment-margin-calculation.patch:
  Delete.
- patches.kernel.org/crypto-mv_cesa-fix-hashing-of-chunks-1920-bytes.patch:
  Delete.
- patches.kernel.org/drm-i915-fix-cb-tuning-check-for-ilk.patch:
  Delete.
- patches.kernel.org/drm-i915-ivybridge-still-has-fences.patch:
  Delete.
- patches.kernel.org/drm-i915-turn-on-a-required-3d-clock-gating-bit-on-sandybridge.patch:
  Delete.
- patches.kernel.org/drm-i915-turn-on-another-required-clock-gating-bit-on-gen6.patch:
  Delete.
- patches.kernel.org/drm-integer-overflow-in-drm_mode_dirtyfb_ioctl.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-add-some-loop-timeouts-in-pageflip-code.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-add-some-new-pci-ids.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx-for-real.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx.patch:
  Delete.
- patches.kernel.org/drm-ttm-request-zeroed-system-memory-pages-for-new-tt-buffer-objects.patch:
  Delete.
- patches.kernel.org/ecryptfs-extend-array-bounds-for-all-filename-chars.patch:
  Delete.
- patches.kernel.org/ecryptfs-flush-file-in-vma-close.patch:
  Delete.
- patches.kernel.org/ehci-fix-a-regression-in-the-iso-scheduler.patch:
  Delete.
- patches.kernel.org/firmware-sigma-fix-endianess-issues.patch:
  Delete.
- patches.kernel.org/firmware-sigma-prevent-out-of-bounds-memory-access.patch:
  Delete.
- patches.kernel.org/firmware-sigma-skip-header-during-crc-generation.patch:
  Delete.
- patches.kernel.org/genirq-fix-race-condition-when-stopping-the-irq-thread.patch:
  Delete.
- patches.kernel.org/genirq-fix-regression-in-irqfixup-irqpoll.patch:
  Delete.
- patches.kernel.org/hid-correct-general-touch-pid.patch: Delete.
- patches.kernel.org/hrtimer-fix-extra-wakeups-from-__remove_hrtimer.patch:
  Delete.
- patches.kernel.org/hugetlb-release-pages-in-the-error-path-of-hugetlb_cow.patch:
  Delete.
- patches.kernel.org/hwmon-coretemp-fix-oops-on-driver-load.patch:
  Delete.
- patches.kernel.org/i2c-algo-bit-generate-correct-i2c-address-sequence-for-10-bit-target.patch:
  Delete.
- patches.kernel.org/jump_label-jump_label_inc-may-return-before-the-code-is-patched.patch:
  Delete.
- patches.kernel.org/mac80211-don-t-stop-a-single-aggregation-session-twice.patch:
  Delete.
- patches.kernel.org/mac80211-fix-race-between-the-agg-sm-and-the-tx-data-path.patch:
  Delete.
- patches.kernel.org/nfs-prevent-3.0-from-crashing-if-it-receives-a-partial-layout.patch:
  Delete.
- patches.kernel.org/nl80211-fix-mac-address-validation.patch:
  Delete.
- patches.kernel.org/oprofile-fix-crash-when-unloading-module-hr-timer-mode.patch:
  Delete.
- patches.kernel.org/oprofile-x86-fix-crash-when-unloading-module-nmi-timer-mode.patch:
  Delete.
- patches.kernel.org/p54spi-add-missing-spin_lock_init.patch:
  Delete.
- patches.kernel.org/p54spi-fix-workqueue-deadlock.patch: Delete.
- patches.kernel.org/pci-hotplug-shpchp-don-t-blindly-claim-non-amd-0x7450-device-ids.patch:
  Delete.
- patches.kernel.org/perf-fix-parsing-of-__print_flags-in-tp_printk.patch:
  Delete.
- patches.kernel.org/perf-x86-fix-pebs-instruction-unwind.patch:
  Delete.
- patches.kernel.org/revert-mfd-fix-twl4030-dependencies-for-audio-codec.patch:
  Delete.
- patches.kernel.org/rt2x00-fix-efuse-eeprom-reading-on-ppc32.patch:
  Delete.
- patches.kernel.org/rtc-disable-the-alarm-in-the-hardware.patch:
  Delete.
- patches.kernel.org/sched-x86-avoid-unnecessary-overflow-in-sched_clock.patch:
  Delete.
- patches.kernel.org/scsi-silencing-killing-requests-for-dead-queue.patch:
  Delete.
- patches.kernel.org/staging-comedi-fix-mmap_count.patch: Delete.
- patches.kernel.org/staging-comedi-fix-oops-for-usb-daq-devices.patch:
  Delete.
- patches.kernel.org/staging-comedi-fix-signal-handling-in-read-and-write.patch:
  Delete.
- patches.kernel.org/staging-usbip-bugfix-for-deadlock.patch:
  Delete.
- patches.kernel.org/sunrpc-ensure-we-return-eagain-in-xs_nospace-if-congestion-is-cleared.patch:
  Delete.
- patches.kernel.org/tick-broadcast-stop-active-broadcast-device-when-replacing-it.patch:
  Delete.
- patches.kernel.org/timekeeping-add-arch_offset-hook-to-ktime_get-functions.patch:
  Delete.
- patches.kernel.org/trace_events_filter-use-rcu_assign_pointer-when-setting-ftrace_event_call-filter.patch:
  Delete.
- patches.kernel.org/tracing-fix-event_subsystem-ref-counting.patch:
  Delete.
- patches.kernel.org/usb-ehci-fix-hub-tt-scheduling-issue-with-iso-transfer.patch:
  Delete.
- patches.kernel.org/usb-ftdi_sio-add-pid-for-propox-ispcable-iii.patch:
  Delete.
- patches.kernel.org/usb-option-add-huawei-e353-controlling-interfaces.patch:
  Delete.
- patches.kernel.org/usb-option-add-simcom-sim5218.patch: Delete.
- patches.kernel.org/usb-usb-storage-unusual_devs-entry-for-kingston-dt-101-g2.patch:
  Delete.
- patches.kernel.org/usb-whci-hcd-fix-endian-conversion-in-qset_clear.patch:
  Delete.
- patches.kernel.org/viafb-correct-sync-polarity-for-olpc-dcon.patch:
  Delete.
- patches.kernel.org/x86-fix-acer-aspire-1-reboot-hang.patch:
  Delete.
- patches.kernel.org/x86-mpparse-account-for-bus-types-other-than-isa-and-pci.patch:
  Delete.
- patches.kernel.org/x86-paravirt-pte-updates-in-k-un-map_atomic-need-to-be-synchronous-regardless-of-lazy_mmu-mode.patch:
  Delete.
- patches.kernel.org/xfs-fix-attr2-vs-large-data-fork-assert.patch:
  Delete.
- patches.kernel.org/xfs-force-buffer-writeback-before-blocking-on-the-ilock-in-inode-reclaim.patch:
  Delete.
- patches.kernel.org/xfs-validate-acl-count.patch: Delete.
- patches.kernel.org/xhci-fix-bug-in-xhci_clear_command_ring.patch:
  Delete.
* Fri Dec  9 2011 tiwai@suse.de
- patches.xen/xen3-3.1-fix-i915-tsc_khz: Temporary build fix
  for Xen kernel (bnc#728329); now retrieved from master branch
  xen patch, and renamed from patches.drivers/drm-i915-fix-xen-build
* Fri Dec  9 2011 hare@suse.de
- patches.drivers/qla4xxx-rc2-update.patch: qla4xxx update to
  5.02.00.00.11.2-k2 (bnc#735800).
- patches.suse/mm-page-allocator-Do-not-call-direct-reclaim-for-THP-allocations-while-compaction-is-deferred.patch:
  Fixup patch for series2git.
- patches.suse/mm-thp-limit-writes-in-direct-reclaim.patch:
  Fixup patch for series2git.
* Fri Dec  9 2011 hare@suse.de
- patches.drivers/bnx2i-Fixed-kernel-panic-caused-by-unprotected-task.patch:
  bnx2i: Fixed kernel panic caused by unprotected deref
  (bnc#734771).
* Fri Dec  9 2011 tiwai@suse.de
- patches.drivers/drm-i915-fix-xen-build: Temporary build fix
  for Xen kernel (bnc#728329).
* Fri Dec  9 2011 ohering@suse.de
- patches.suse/mm-thp-limit-writes-in-direct-reclaim.patch:
  Refresh.
* Fri Dec  9 2011 ohering@suse.de
- Update hv_storvsc to current to-become-mainline state
- patches.suse/staging-hv-storvsc-cleanup_error_handling_in_the_probe_function.patch:
  Staging: hv: storvsc: Cleanup error handling in the probe
  function.
- patches.suse/staging-hv-storvsc-fix_checkpatch_warnings.patch:
  Staging: hv: storvsc: Fix checkpatch warnings.
- patches.suse/staging-hv-storvsc-fix_error_handling_storvsc_host_reset.patch:
  Staging: hv: storvsc: Fix error handling storvsc_host_reset().
- patches.suse/staging-hv-storvsc-fixup_the_error_when_processing_set_window_command.patch:
  Staging: hv: storvsc: Fixup the error when processing SET_WINDOW
  command.
- patches.suse/staging-hv-storvsc-get_rid_of_an_unnecessary_forward_declaration.patch:
  Staging: hv: storvsc: Get rid of an unnecessary forward
  declaration.
- patches.suse/staging-hv-storvsc-implement_per_device_memory_pools.patch:
  Staging: hv: storvsc: Implement per device memory pools.
- patches.suse/staging-hv-storvsc-remove-last-usage-of-DPRINT_WARN.patch:
  Staging: hv: storvsc: remove last usage of DPRINT_WARN.
- patches.suse/staging-hv-storvsc-support_hot_add_of_scsi_disks.patch:
  Staging: hv: storvsc: Support hot add of scsi disks.
- patches.suse/staging-hv-storvsc-support_hotremoving_of_scsi_devices.patch:
  Staging: hv: storvsc: Support hot-removing of scsi devices.
- patches.suse/staging-hv-storvsc-upgrade_the_vmstor_protocol_version.patch:
  Staging: hv: storvsc: Upgrade the vmstor protocol version.
- patches.suse/staging-hv-storvsc-use_mempools_to_allocate_struct_storvsc_cmd_request.patch:
  Staging: hv: storvsc: Use mempools to allocate struct
  storvsc_cmd_request.
- patches.suse/staging-hv-storvsc-use_the_accessor_function_shost_priv.patch:
  Staging: hv: storvsc: Use the accessor function shost_priv().
- patches.suse/staging-hv-storvsc-use_the_macro_kbuild_modname.patch:
  Staging: hv: storvsc: use the macro KBUILD_MODNAME.
- patches.suse/staging-hv-storvsc-use_the_unlocked_version_queuecommand.patch:
  Staging: hv: storvsc: Use the unlocked version queuecommand.
* Fri Dec  9 2011 tiwai@suse.de
- patches.drivers/drm-i915-DisplayPort-hot-remove-notification-to-audio-driver:
  drm/i915: DisplayPort hot remove notification to audio driver
  (bnc#722560).
- patches.drivers/drm-i915-HDMI-hot-remove-notification-to-audio-driver:
  drm/i915: HDMI hot remove notification to audio driver
  (bnc#722560).
- patches.drivers/drm-i915-dont-trigger-hotplug-events-on-uncached-ELD:
  drm/i915: dont trigger hotplug events on unchanged ELD
  (bnc#722560).
- patches.drivers/drm-i915-fix-ELD-writing-for-SandyBridge:
  Refresh.
- patches.drivers/drm-i915-rename-audio-ELD-registers: drm/i915:
  rename audio ELD registers (bnc#722560).
* Fri Dec  9 2011 tiwai@suse.de
- patches.drivers/cpufreq-expose-a-cpufreq_quick_get_max-routine:
  cpufreq: expose a cpufreq_quick_get_max routine (bnc#728329).
- patches.drivers/drm-i915-load-a-ring-frequency-scaling-table-v3:
  drm/i915: load a ring frequency scaling table v3 (bnc#728329).
- patches.xen/xen-cpufreq-report: Refresh.
* Fri Dec  9 2011 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-007-Fix-DAC-assignment-for-secondary-headphone-:
  ALSA: HDA: Fix DAC assignment for secondary headphone on
  Sigmatel/IDT (bnc#732535).
- patches.drivers/alsa-sp2-hda-008-sigmatel-Automatically-retrieve-digital-I-O:
  ALSA: hda/sigmatel - Automatically retrieve digital I/O widgets
  (bnc#732535).
- patches.drivers/alsa-sp2-hda-009-pwr_nids-cleanup-for-IDT-codecs:
  ALSA: hda - pwr_nids cleanup for IDT codecs (bnc#732535).
- patches.drivers/alsa-sp2-hda-010-Avoid-touching-mute-VREF-pin-for-IDT-codecs:
  ALSA: hda - Avoid touching mute-VREF pin for IDT codecs
  (bnc#732535).
- patches.drivers/alsa-sp2-hda-011-Fix-S3-S4-problem-on-machines-with-VREF-pin:
  ALSA: hda - Fix S3/S4 problem on machines with VREF-pin mute-LED
  (bnc#732535).
- patches.drivers/alsa-sp2-hda-012-Fix-GPIO-LED-setup-for-IDT-92HD75-codecs:
  ALSA: hda - Fix GPIO LED setup for IDT 92HD75 codecs
  (bnc#732535).
- patches.drivers/alsa-sp2-hda-013-Fix-remaining-VREF-mute-LED-NID-check-in-po:
  ALSA: hda - Fix remaining VREF mute-LED NID check in post-3.1
  changes (bnc#732535).
* Fri Dec  9 2011 jlee@suse.com
- patches.drivers/0001-be2net-don-t-create-multiple-TXQs-in-BE2.patch:
  be2net: don't create multiple TXQs in BE2. (bnc#733435)
* Fri Dec  9 2011 jbeulich@novell.com
- Update Xen patches to c/s 1131.
* Fri Dec  9 2011 nfbrown@suse.de
- patches.fixes/md-refine-interpretation-of-hold_active-UNTIL_IOCTL.patch:
  md: refine interpretation of "hold_active == UNTIL_IOCTL".
- patches.fixes/md-take-a-reference-to-mddev-during-sysfs-access.patch:
  md: take a reference to mddev during sysfs access.
  Patches from mainline that solve some issues with races in sysfs access.
* Fri Dec  9 2011 dsterba@suse.cz
- patches.suse/btrfs-8019-let-fiemap-flag-compressed-extents.patch:
  btrfs: let fiemap flag compressed extents (FATE#306586).
- patches.suse/btrfs-8020-simplify-move_pages-and-copy_pages.patch:
  btrfs: simplify move_pages and copy_pages (FATE#306586).
- patches.suse/btrfs-8021-Prefix-mount-messages-with-btrfs-for-clarity.patch:
  Prefix mount messages with btrfs: for clarity (FATE#306586).
- patches.suse/btrfs-8022-forced-readonly-when-free_log_tree-fails.patch:
  Btrfs: forced readonly when free_log_tree fails (FATE#306586).
- patches.suse/btrfs-8023-forced-readonly-when-orphan_del-fails.patch:
  Btrfs: forced readonly when orphan_del fails (FATE#306586).
- patches.suse/fs-FIEMAP-add-flag-for-compressed-extent.patch:
  fs: FIEMAP: add flag for compressed extent (FATE#306586).
* Fri Dec  9 2011 trenn@suse.de
  Patch is mainline, correct patch header:
- patches.fixes/percpu_fix_chunk_range_calculation.patch: Refresh.
* Fri Dec  9 2011 dsterba@suse.cz
  btrfs sync upstream accepted patches
- patches.suse/btrfs-0265-try-to-allocate-from-cluster-even-at-LOOP_NO_E.patch:
  Btrfs: try to allocate from cluster even at LOOP_NO_EMPTY_SIZE
  (FATE#306586).
- patches.suse/btrfs-0266-try-cluster-but-don-t-advance-in-search-list.patch:
  Btrfs: try cluster but don't advance in search list
  (FATE#306586).
- patches.suse/btrfs-0267-check-if-the-to-be-added-device-is-writable.patch:
  Btrfs: check if the to-be-added device is writable
  (FATE#306586).
- patches.suse/btrfs-0268-drop-spin-lock-when-memory-alloc-fails.patch:
  Btrfs: drop spin lock when memory alloc fails (FATE#306586).
- patches.suse/btrfs-0900-add-allocator-tracepoints.patch:
  Refresh.
- patches.suse/btrfs-8008-drop-spin-lock-when-memory-alloc-fails.patch:
  Delete.
- patches.suse/btrfs-8010-check-if-the-to-be-added-device-is-writable.patch:
  Delete.
* Thu Dec  8 2011 jbohac@suse.cz
- patches.fixes/bonding-eliminate-bond_close-race-conditions-prepare.patch:
  bonding: properly stop queuing work when requested.
- patches.fixes/bonding-eliminate-bond_close-race-conditions.patch:
  bonding: eliminate bond_close race conditions (bnc#602969,
  bnc#735277).
- patches.fixes/bonding-minimize-race-window-on-miimon-rearming.patch:
  Delete.
* Thu Dec  8 2011 ptesarik@suse.cz
- patches.arch/ia64-resvd-overlap: ia64: Merge overlapping
  reserved regions (bnc#73149).
* Thu Dec  8 2011 hare@suse.de
- patches.drivers/megaraid-sas-continue-booting-on-FAULT.patch:
  megaraid_sas: Continue booting immediately if FW in FAULT at
  driver load time (bnc#731009).
* Thu Dec  8 2011 duwe@suse.de
- patches.fixes/disable-hifn_795x-64-bit-compile: crypto: Make
  hifn_795x build depend on !ARCH_DMA_ADDR_T_64BIT (bnc#733248).
* Thu Dec  8 2011 dsterba@suse.cz
- patches.suse/btrfs-8018-use-irqsave-spinlocks-everywhere.patch:
  Refresh.
- patches.suse/btrfs-async_thread-btrfs_stop_workers-should-return-void:
  Refresh.
* Thu Dec  8 2011 dsterba@suse.cz
- patches.suse/btrfs-8017-reduce-btrfs_path-size.patch: Refresh.
- patches.suse/btrfs-8018-use-irqsave-spinlocks-everywhere.patch:
  btrfs: use irqsave spinlocks everywhere (FATE#306586
  bnc#734522).
* Thu Dec  8 2011 dsterba@suse.cz
- patches.suse/btrfs-add-extent_state-alloc-free-tracing: Refresh.
* Thu Dec  8 2011 dsterba@suse.cz
- patches.suse/0002-btrfs-Introduce-btrfs_get_maps_dev.patch:
  Refresh.
- patches.suse/btrfs-0900-add-allocator-tracepoints.patch: Btrfs:
  add allocator tracepoints (FATE#306586).
- patches.suse/btrfs-0901-fix-num_workers_starting-bug-and-other-bugs-in.patch:
  Btrfs: fix num_workers_starting bug and other bugs in async
  thread (FATE#306586).
- patches.suse/btrfs-0902-deal-with-enospc-from-dirtying-inodes-properly.patch:
  Btrfs: deal with enospc from dirtying inodes properly
  (FATE#306586).
- patches.suse/btrfs-8016-skip-compression-of-very-small-extents.patch:
  btrfs: skip compression of very small extents (FATE#306586).
- patches.suse/btrfs-8017-reduce-btrfs_path-size.patch: btrfs:
  reduce btrfs_path size (FATE#306586).
- patches.suse/btrfs-async_thread-btrfs_stop_workers-should-return-void:
  Refresh.
- patches.suse/btrfs-set_extent_bit-should-return-void: Refresh.
* Wed Dec  7 2011 jeffm@suse.com
- patches.suse/dmapi-xfs_free_eof_haslock-flag-is-not-always-checked:
  DMAPI: XFS_FREE_EOF_HASLOCK flag is not always checked
  (bnc#733390).
* Wed Dec  7 2011 gregkh@suse.de
- Forgot my signed-off-by: on some patches:
- patches.drivers/USB3-0287-usb-fix-implicit-usage-of-gfp.h-in-host-xhci-hub.c.patch:
  Refresh.
- patches.drivers/USB3-0293-usbnet-fix-oops-in-usbnet_start_xmit.patch:
  Refresh.
- patches.drivers/USB3-0294-Fix-incorrect-usage-of-NET_IP_ALIGN.patch:
  Refresh.
- patches.drivers/USB3-0295-net-usb-Misc.-fixes-for-the-LG-VL600-LTE-USB-modem.patch:
  Refresh.
- patches.drivers/USB3-0336-net-next-asix-PHY_MODE_RTL8211CL-should-be-0xC.patch:
  Refresh.
- patches.drivers/USB3-0337-net-next-asix-poll-in-asix_get_phyid-in-case-phy-not-ready.patch:
  Refresh.
- patches.drivers/USB3-0338-net-next-asix-reduce-AX88772-init-time-by-about-2-seconds.patch:
  Refresh.
- patches.drivers/USB3-0339-net-next-asix-V2-more-fixes-for-ax88178-phy-init-sequence.patch:
  Refresh.
- patches.drivers/USB3-0340-net-next-asix-V2-Update-VERSION.patch:
  Refresh.
- patches.drivers/USB3-0352-xHCI-reset-on-resume-quirk-for-NEC-uPD720200.patch:
  Refresh.
- patches.drivers/USB3-0366-Revert-xHCI-reset-on-resume-quirk-for-NEC-uPD720200.patch:
  Refresh.
* Wed Dec  7 2011 gregkh@suse.de
- More USB updates as 3.2 starts to settle down.
- patches.drivers/USB3-0281-NET-asix-fix-ethtool-e-for-AX88178-USB-dongle.patch:
  Refresh.
- patches.drivers/USB3-0287-usb-fix-implicit-usage-of-gfp.h-in-host-xhci-hub.c.patch:
  usb: fix implicit usage of gfp.h in host/xhci-hub.c.
- patches.drivers/USB3-0293-usbnet-fix-oops-in-usbnet_start_xmit.patch:
  usbnet: fix oops in usbnet_start_xmit.
- patches.drivers/USB3-0294-Fix-incorrect-usage-of-NET_IP_ALIGN.patch:
  Fix incorrect usage of NET_IP_ALIGN.
- patches.drivers/USB3-0295-net-usb-Misc.-fixes-for-the-LG-VL600-LTE-USB-modem.patch:
  net/usb: Misc. fixes for the LG-VL600 LTE USB modem.
- patches.drivers/USB3-0334-USB-option-add-id-for-3G-dongle-Model-VT1000-of-Viettel.patch:
  USB: option: add id for 3G dongle Model VT1000 of Viettel.
- patches.drivers/USB3-0336-net-next-asix-PHY_MODE_RTL8211CL-should-be-0xC.patch:
  net-next:asix:PHY_MODE_RTL8211CL should be 0xC.
- patches.drivers/USB3-0337-net-next-asix-poll-in-asix_get_phyid-in-case-phy-not-ready.patch:
  net-next:asix:poll in asix_get_phyid in case phy not ready.
- patches.drivers/USB3-0338-net-next-asix-reduce-AX88772-init-time-by-about-2-seconds.patch:
  net-next:asix: reduce AX88772 init time by about 2 seconds.
- patches.drivers/USB3-0339-net-next-asix-V2-more-fixes-for-ax88178-phy-init-sequence.patch:
  net-next:asix: V2 more fixes for ax88178 phy init sequence.
- patches.drivers/USB3-0340-net-next-asix-V2-Update-VERSION.patch:
  net-next:asix: V2 Update VERSION.
- patches.drivers/USB3-0345-OHCI-final-fix-for-NVIDIA-problems-I-hope.patch:
  OHCI: final fix for NVIDIA problems (I hope).
- patches.drivers/USB3-0352-xHCI-reset-on-resume-quirk-for-NEC-uPD720200.patch:
  xHCI: reset-on-resume quirk for NEC uPD720200.
- patches.drivers/USB3-0366-Revert-xHCI-reset-on-resume-quirk-for-NEC-uPD720200.patch:
  Revert "xHCI: reset-on-resume quirk for NEC uPD720200".
* Wed Dec  7 2011 gregkh@suse.de
- patches.kernel.org/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx.patch:
  Refresh.
* Wed Dec  7 2011 gregkh@suse.de
- Update to 3.0.13-rc1 patch level + one revert
- Update config files.
- patches.kernel.org/add-missing-.set-function-for-nt_s390_last_break-regset.patch:
  add missing .set function for NT_S390_LAST_BREAK regset.
- patches.kernel.org/alsa-lx6464es-fix-device-communication-via-command-bus.patch:
  ALSA: lx6464es - fix device communication via command bus.
- patches.kernel.org/arm-7161-1-errata-no-automatic-store-buffer-drain.patch:
  ARM: 7161/1: errata: no automatic store buffer drain.
- patches.kernel.org/arm-mx28-fix-bit-operation-in-clock-setting.patch:
  arm: mx28: fix bit operation in clock setting.
- patches.kernel.org/arm-omap-smartreflex-fix-irq-handling-bug.patch:
  ARM: OMAP: smartreflex: fix IRQ handling bug.
- patches.kernel.org/arm-omap2-select-arm_amba-if-omap3_emu-is-defined.patch:
  ARM: OMAP2: select ARM_AMBA if OMAP3_EMU is defined.
- patches.kernel.org/arm-pxa-fix-inconsistent-config_usb_pxa27x.patch:
  ARM: pxa: fix inconsistent CONFIG_USB_PXA27X.
- patches.kernel.org/asoc-ensure-wm8731-register-cache-is-synced-when-resuming-from-disabled.patch:
  ASoC: Ensure WM8731 register cache is synced when resuming
  from disabled.
- patches.kernel.org/asoc-fsl_ssi-properly-initialize-the-sysfs-attribute-object.patch:
  ASoC: fsl_ssi: properly initialize the sysfs attribute object.
- patches.kernel.org/asoc-wm8753-skip-noop-reconfiguration-of-dai-mode.patch:
  ASoC: wm8753: Skip noop reconfiguration of DAI mode.
- patches.kernel.org/cfg80211-amend-regulatory-null-dereference-fix.patch:
  cfg80211: amend regulatory NULL dereference fix.
- patches.kernel.org/cfg80211-fix-race-on-init-and-driver-registration.patch:
  cfg80211: fix race on init and driver registration.
- patches.kernel.org/cfg80211-fix-regulatory-null-dereference.patch:
  cfg80211: fix regulatory NULL dereference.
- patches.kernel.org/cgroup_freezer-fix-freezing-groups-with-stopped-tasks.patch:
  cgroup_freezer: fix freezing groups with stopped tasks.
- patches.kernel.org/clockevents-set-noop-handler-in-clockevents_exchange_device.patch:
  clockevents: Set noop handler in clockevents_exchange_device().
- patches.kernel.org/clocksource-fix-bug-with-max_deferment-margin-calculation.patch:
  clocksource: Fix bug with max_deferment margin calculation.
- patches.kernel.org/crypto-mv_cesa-fix-hashing-of-chunks-1920-bytes.patch:
  crypto: mv_cesa - fix hashing of chunks > 1920 bytes.
- patches.kernel.org/drm-i915-fix-cb-tuning-check-for-ilk.patch:
  drm/i915: fix CB tuning check for ILK+.
- patches.kernel.org/drm-i915-ivybridge-still-has-fences.patch:
  drm/i915: Ivybridge still has fences!.
- patches.kernel.org/drm-i915-turn-on-a-required-3d-clock-gating-bit-on-sandybridge.patch:
  drm/i915: Turn on a required 3D clock gating bit on Sandybridge.
- patches.kernel.org/drm-i915-turn-on-another-required-clock-gating-bit-on-gen6.patch:
  drm/i915: Turn on another required clock gating bit on gen6.
- patches.kernel.org/drm-integer-overflow-in-drm_mode_dirtyfb_ioctl.patch:
  drm: integer overflow in drm_mode_dirtyfb_ioctl().
- patches.kernel.org/drm-radeon-kms-add-some-loop-timeouts-in-pageflip-code.patch:
  drm/radeon/kms: add some loop timeouts in pageflip code.
- patches.kernel.org/drm-radeon-kms-add-some-new-pci-ids.patch:
  drm/radeon/kms: add some new pci ids.
- patches.kernel.org/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx-for-real.patch:
  drm/radeon/kms: fix up gpio i2c mask bits for r4xx for real.
- patches.kernel.org/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx.patch:
  drm/radeon/kms: fix up gpio i2c mask bits for r4xx.
- patches.kernel.org/drm-ttm-request-zeroed-system-memory-pages-for-new-tt-buffer-objects.patch:
  drm/ttm: request zeroed system memory pages for new TT buffer
  objects.
- patches.kernel.org/ecryptfs-extend-array-bounds-for-all-filename-chars.patch:
  eCryptfs: Extend array bounds for all filename chars.
- patches.kernel.org/ecryptfs-flush-file-in-vma-close.patch:
  eCryptfs: Flush file in vma close.
- patches.kernel.org/ehci-fix-a-regression-in-the-iso-scheduler.patch:
  EHCI : Fix a regression in the ISO scheduler.
- patches.kernel.org/firmware-sigma-fix-endianess-issues.patch:
  firmware: Sigma: Fix endianess issues.
- patches.kernel.org/firmware-sigma-prevent-out-of-bounds-memory-access.patch:
  firmware: Sigma: Prevent out of bounds memory access.
- patches.kernel.org/firmware-sigma-skip-header-during-crc-generation.patch:
  firmware: Sigma: Skip header during CRC generation.
- patches.kernel.org/genirq-fix-race-condition-when-stopping-the-irq-thread.patch:
  genirq: Fix race condition when stopping the irq thread.
- patches.kernel.org/genirq-fix-regression-in-irqfixup-irqpoll.patch:
  genirq: fix regression in irqfixup, irqpoll.
- patches.kernel.org/hid-correct-general-touch-pid.patch: HID:
  Correct General touch PID.
- patches.kernel.org/hrtimer-fix-extra-wakeups-from-__remove_hrtimer.patch:
  hrtimer: Fix extra wakeups from __remove_hrtimer().
- patches.kernel.org/hugetlb-release-pages-in-the-error-path-of-hugetlb_cow.patch:
  hugetlb: release pages in the error path of hugetlb_cow().
- patches.kernel.org/hwmon-coretemp-fix-oops-on-driver-load.patch:
  hwmon: (coretemp) Fix oops on driver load.
- patches.kernel.org/i2c-algo-bit-generate-correct-i2c-address-sequence-for-10-bit-target.patch:
  i2c-algo-bit: Generate correct i2c address sequence for
  10-bit target.
- patches.kernel.org/jump_label-jump_label_inc-may-return-before-the-code-is-patched.patch:
  jump_label: jump_label_inc may return before the code is
  patched.
- patches.kernel.org/mac80211-don-t-stop-a-single-aggregation-session-twice.patch:
  mac80211: don't stop a single aggregation session twice.
- patches.kernel.org/mac80211-fix-race-between-the-agg-sm-and-the-tx-data-path.patch:
  mac80211: fix race between the AGG SM and the Tx data path.
- patches.kernel.org/nfs-prevent-3.0-from-crashing-if-it-receives-a-partial-layout.patch:
  NFS: Prevent 3.0 from crashing if it receives a partial layout.
- patches.kernel.org/nl80211-fix-mac-address-validation.patch:
  nl80211: fix MAC address validation.
- patches.kernel.org/oprofile-fix-crash-when-unloading-module-hr-timer-mode.patch:
  oprofile: Fix crash when unloading module (hr timer mode).
- patches.kernel.org/oprofile-x86-fix-crash-when-unloading-module-nmi-timer-mode.patch:
  oprofile, x86: Fix crash when unloading module (nmi timer mode).
- patches.kernel.org/p54spi-add-missing-spin_lock_init.patch:
  p54spi: Add missing spin_lock_init.
- patches.kernel.org/p54spi-fix-workqueue-deadlock.patch: p54spi:
  Fix workqueue deadlock.
- patches.kernel.org/pci-hotplug-shpchp-don-t-blindly-claim-non-amd-0x7450-device-ids.patch:
  PCI hotplug: shpchp: don't blindly claim non-AMD 0x7450
  device IDs.
- patches.kernel.org/perf-fix-parsing-of-__print_flags-in-tp_printk.patch:
  perf: Fix parsing of __print_flags() in TP_printk().
- patches.kernel.org/perf-x86-fix-pebs-instruction-unwind.patch:
  perf/x86: Fix PEBS instruction unwind.
- patches.kernel.org/revert-hwmon-coretemp-fix-oops-on-driver-load.patch:
  Revert "hwmon: (coretemp) Fix oops on driver load".
- patches.kernel.org/revert-mfd-fix-twl4030-dependencies-for-audio-codec.patch:
  revert "mfd: Fix twl4030 dependencies for audio codec".
- patches.kernel.org/rt2x00-fix-efuse-eeprom-reading-on-ppc32.patch:
  rt2x00: Fix efuse EEPROM reading on PPC32.
- patches.kernel.org/rtc-disable-the-alarm-in-the-hardware.patch:
  rtc: Disable the alarm in the hardware.
- patches.kernel.org/sched-x86-avoid-unnecessary-overflow-in-sched_clock.patch:
  sched, x86: Avoid unnecessary overflow in sched_clock.
- patches.kernel.org/scsi-silencing-killing-requests-for-dead-queue.patch:
  SCSI: Silencing 'killing requests for dead queue'.
- patches.kernel.org/staging-comedi-fix-mmap_count.patch: Staging:
  comedi: fix mmap_count.
- patches.kernel.org/staging-comedi-fix-oops-for-usb-daq-devices.patch:
  staging: comedi: fix oops for USB DAQ devices.
- patches.kernel.org/staging-comedi-fix-signal-handling-in-read-and-write.patch:
  Staging: comedi: fix signal handling in read and write.
- patches.kernel.org/staging-usbip-bugfix-for-deadlock.patch:
  staging: usbip: bugfix for deadlock.
- patches.kernel.org/sunrpc-ensure-we-return-eagain-in-xs_nospace-if-congestion-is-cleared.patch:
  SUNRPC: Ensure we return EAGAIN in xs_nospace if congestion
  is cleared.
- patches.kernel.org/tick-broadcast-stop-active-broadcast-device-when-replacing-it.patch:
  tick-broadcast: Stop active broadcast device when replacing it.
- patches.kernel.org/timekeeping-add-arch_offset-hook-to-ktime_get-functions.patch:
  timekeeping: add arch_offset hook to ktime_get functions.
- patches.kernel.org/trace_events_filter-use-rcu_assign_pointer-when-setting-ftrace_event_call-filter.patch:
  trace_events_filter: Use rcu_assign_pointer() when setting
  ftrace_event_call->filter.
- patches.kernel.org/tracing-fix-event_subsystem-ref-counting.patch:
  tracing: fix event_subsystem ref counting.
- patches.kernel.org/usb-ehci-fix-hub-tt-scheduling-issue-with-iso-transfer.patch:
  USB: EHCI: fix HUB TT scheduling issue with iso transfer.
- patches.kernel.org/usb-ftdi_sio-add-pid-for-propox-ispcable-iii.patch:
  usb: ftdi_sio: add PID for Propox ISPcable III.
- patches.kernel.org/usb-option-add-huawei-e353-controlling-interfaces.patch:
  usb: option: add Huawei E353 controlling interfaces.
- patches.kernel.org/usb-option-add-simcom-sim5218.patch: usb:
  option: add SIMCom SIM5218.
- patches.kernel.org/usb-usb-storage-unusual_devs-entry-for-kingston-dt-101-g2.patch:
  USB: usb-storage: unusual_devs entry for Kingston DT 101 G2.
- patches.kernel.org/usb-whci-hcd-fix-endian-conversion-in-qset_clear.patch:
  USB: whci-hcd: fix endian conversion in qset_clear().
- patches.kernel.org/viafb-correct-sync-polarity-for-olpc-dcon.patch:
  viafb: correct sync polarity for OLPC DCON.
- patches.kernel.org/x86-fix-acer-aspire-1-reboot-hang.patch:
  x86: Fix "Acer Aspire 1" reboot hang.
- patches.kernel.org/x86-mpparse-account-for-bus-types-other-than-isa-and-pci.patch:
  x86/mpparse: Account for bus types other than ISA and PCI.
- patches.kernel.org/x86-paravirt-pte-updates-in-k-un-map_atomic-need-to-be-synchronous-regardless-of-lazy_mmu-mode.patch:
  x86/paravirt: PTE updates in k(un)map_atomic need to be
  synchronous, regardless of lazy_mmu mode.
- patches.kernel.org/xfs-fix-attr2-vs-large-data-fork-assert.patch:
  xfs: fix attr2 vs large data fork assert.
- patches.kernel.org/xfs-force-buffer-writeback-before-blocking-on-the-ilock-in-inode-reclaim.patch:
  xfs: force buffer writeback before blocking on the ilock in
  inode reclaim.
- patches.kernel.org/xfs-validate-acl-count.patch: xfs: validate
  acl count.
- patches.kernel.org/xhci-fix-bug-in-xhci_clear_command_ring.patch:
  xHCI: fix bug in xhci_clear_command_ring().
- patches.fixes/cgroup_freezer_freeze_stopped_tasks_correctly.patch:
  Delete.
- patches.fixes/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx.patch:
  Delete.
- patches.fixes/pnfs-fix: Delete.
- patches.fixes/scsi-silencing-killing-requests-for-dead-queue:
  Delete.
- patches.fixes/x86-sched-avoid-overflow-in-cyc_2_ns.patch:
  Delete.
* Wed Dec  7 2011 gregkh@suse.de
- patches.kernel.org/b43-refuse-to-load-unsupported-firmware.patch:
  Delete.
* Wed Dec  7 2011 jeffm@suse.com
- supported.conf: Update supported status of read-only, spectator
  mode GFS2. (FATE#307584)
* Wed Dec  7 2011 dsterba@suse.cz
- patches.suse/btrfs-8015-make-lzo-the-default-compression-scheme.patch:
  Btrfs: make lzo the default compression scheme (FATE#306586).
* Wed Dec  7 2011 dsterba@suse.cz
- patches.suse/btrfs-1004-add-basic-restriper-infrastructure.patch:
  Refresh.
- patches.suse/btrfs-1015-allow-for-cancelling-restriper.patch:
  Refresh.
- patches.suse/btrfs-1019-get-rid-of-btrfs_balance-function.patch:
  Refresh.
- patches.suse/btrfs-1020-add-restripe-progress-reporting.patch:
  Refresh.
- patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch:
  btrfs: add new ioctl to determine size of compressed file
  (FATE#306586).
- patches.suse/btrfs-unlock_extent-can-eliminate-gfp_t-addon:
  fixup -- btrfs: unlock_extent can drop gfp_t argument.
* Wed Dec  7 2011 oneukum@suse.de
- patches.drivers/bug-732296_btusb-Add-Atheros-AR3012-Maryann-PID-VID-supported.patch:
  Bluetooth: Add Atheros AR3012 Maryann PID/VID supported.
  (bnc#732296)
* Wed Dec  7 2011 ohering@suse.de
- patches.suse/staging-hv-storvsc-fix-a-bug-in-create_bounce_buffer.patch:
  Staging: hv: storvsc: Fix a bug in create_bounce_buffer()
  (bnc#724616).
* Wed Dec  7 2011 trenn@suse.de
- patches.arch/intel_iommu_fix_wrong_firmware_warning.patch:
  intel iommu: Only check for iommu ioat BIOS bug if iommu is
  detected (bnc#733702).
* Wed Dec  7 2011 oneukum@suse.de
- patches.fixes/0001-pciehp-By-default-handle-resume.patch:
  pciehp: By default handle resume (bnc#734526).
* Tue Dec  6 2011 jslaby@suse.de
- patches.suse/0001-Revert-serial-core-remove-uart_update_termios.patch:
  Revert "serial: core, remove uart_update_termios" (bnc#718518).
- patches.suse/0002-Revert-serial-core-do-not-set-DTR-RTS-twice-on-st.patch:
  Revert "serial: core, do not set DTR/RTS twice on startup"
  (bnc#718518).
- patches.suse/0003-Revert-serial-core-move-termios-handling-to-uart_.patch:
  Revert "serial: core, move termios handling to uart_startup"
  (bnc#718518).
- patches.suse/0004-Revert-serial-fix-termios-settings-in-open.patch:
  Revert "serial: fix termios settings in open" (bnc#718518).
- patches.suse/0005-Revert-serial-Use-block_til_ready-helper.patch:
  Revert "serial: Use block_til_ready helper" (bnc#718518).
* Tue Dec  6 2011 hare@suse.de
- patches.fixes/dm-use-done-bytes-for-io-completion.patch: dm:
  Use done_bytes for io completion (bnc#711378).
* Tue Dec  6 2011 ohering@suse.de
- patches.suse/staging-hv-storvsc_cleanup_storvsc_device_alloc.patch:
  Staging: hv: storvsc: Cleanup storvsc_device_alloc()
  (bnc#724616).
- patches.suse/staging-hv-storvsc_disable_clustering.patch:
  Staging: hv: storvsc: Disable clustering (bnc#724616).
- patches.suse/staging-hv-storvsc_fix_a_bug_in_copy_from_bounce_buffer.patch:
  Staging: hv: storvsc: Fix a bug in copy_from_bounce_buffer()
  (bnc#724616).
- patches.suse/staging-hv-storvsc_fix_a_bug_in_storvsc_command_completion.patch:
  Staging: hv: storvsc: Fix a bug in storvsc_command_completion()
  (bnc#724616).
* Mon Dec  5 2011 brogers@suse.com
- patches.fixes/kvm-KVM-IOMMU-Disable-device-assignment-without-interrup.patch:
  KVM: IOMMU: Disable device assignment without interrupt
  remapping (bnc#724906).
* Mon Dec  5 2011 dsterba@suse.cz
- patches.suse/btrfs-8013-sector-size-check-during-mount.patch:
  Sector Size check during Mount (FATE#306586 bnc#724620).
* Fri Dec  2 2011 nfbrown@suse.de
- patches.suse/01a-md-failfast-metadata: Use FAILFAST on metadata
  writes where appropriate (FATE#311379).
* Fri Dec  2 2011 jbohac@suse.cz
- patches.fixes/x86-sched-avoid-overflow-in-cyc_2_ns.patch: sched,
  x86: Avoid unnecessary overflow in sched_clock (bnc#725709).
* Fri Dec  2 2011 eich@suse.de
- patches.suse/drm-edid-workaround-shift.patch: drm/edid: Fix
  EDID block that is shifted by up to 3 bytes (bnc#712899 et.al.).
  This workaround will be removed once the underlying issue has
  been understood and fixed.
* Fri Dec  2 2011 eich@suse.de
- patches.drivers/drm_radeon_fix_panic_on_unload.patch:
  drm/radeon: Don't destroy i2c bus rec in
  radeon_ext_tmds_enc_destroy() (bnc#731739).
* Fri Dec  2 2011 hare@suse.de
- patches.fixes/scsi-don-t-use-execute_in_process_context.patch:
  Remove patch which was rejected upstream (bnc#733236).
* Fri Dec  2 2011 hare@suse.de
- patches.suse/dasd-failfast-expires: Fixup patch to actually
  display the sysfs attribute.
* Fri Dec  2 2011 jankit@suse.de
- supported.conf: mark ide-cd_mod as supported (bnc#732132).
* Thu Dec  1 2011 dsterba@suse.cz
- enable 'restriper' patchset
* Thu Dec  1 2011 dsterba@suse.cz
- patches.suse/btrfs-submit_bio_hook-error-push-up: Refresh.
* Thu Dec  1 2011 dsterba@suse.cz
- patches.suse/btrfs-0254-scrub-handle-ENOMEM-from-init_ipath.patch:
  btrfs scrub: handle -ENOMEM from init_ipath() (FATE#306586).
- patches.suse/btrfs-0256-fix-deadlock-on-metadata-reservation-when-evic.patch:
  Btrfs: fix deadlock on metadata reservation when evicting a
  inode (FATE#306586).
- patches.suse/btrfs-0257-Don-t-error-on-resizing-FS-to-same-size.patch:
  Btrfs: Don't error on resizing FS to same size (FATE#306586).
- patches.suse/btrfs-0258-fix-oops-when-calling-statfs-on-readonly-devic.patch:
  Btrfs: fix oops when calling statfs on readonly device
  (FATE#306586).
- patches.suse/btrfs-0259-initialize-new-bitmaps-list.patch:
  Btrfs: initialize new bitmaps' list (FATE#306586).
- patches.suse/btrfs-0260-reset-cluster-s-max_size-when-creating-bitmap.patch:
  Btrfs: reset cluster's max_size when creating bitmap
  (FATE#306586).
- patches.suse/btrfs-0261-start-search-for-new-cluster-at-the-beginning.patch:
  Btrfs: start search for new cluster at the beginning
  (FATE#306586).
- patches.suse/btrfs-0262-skip-block-groups-without-enough-space-for-a-c.patch:
  Btrfs: skip block groups without enough space for a cluster
  (FATE#306586).
- patches.suse/btrfs-0263-skip-allocation-attempt-from-empty-cluster.patch:
  Btrfs: skip allocation attempt from empty cluster (FATE#306586).
- patches.suse/btrfs-0264-fix-meta-data-raid-repair-merge-problem.patch:
  Btrfs: fix meta data raid-repair merge problem (FATE#306586).
- patches.suse/btrfs-8003-scrub-handle-ENOMEM-from-init_ipath.patch:
  Delete.
- patches.suse/btrfs-8005-fix-deadlock-on-metadata-reservation-when-evic.patch:
  Delete.
- patches.suse/btrfs-8006-Don-t-error-on-resizing-FS-to-same-size.patch:
  Delete.
- patches.suse/btrfs-8009-fix-oops-when-calling-statfs-on-readonly-devic.patch:
  Delete.
- patches.suse/btrfs-8011-initialize-new-bitmaps-list.patch:
  Delete.
* Thu Dec  1 2011 dsterba@suse.cz
- patches.suse/btrfs-8008-drop-spin-lock-when-memory-alloc-fails.patch:
  Btrfs: drop spin lock when memory alloc fails (FATE#306586).
- patches.suse/btrfs-8009-fix-oops-when-calling-statfs-on-readonly-devic.patch:
  Btrfs: fix oops when calling statfs on readonly device
  (FATE#306586).
- patches.suse/btrfs-8010-check-if-the-to-be-added-device-is-writable.patch:
  Btrfs: check if the to-be-added device is writable
  (FATE#306586).
- patches.suse/btrfs-8011-initialize-new-bitmaps-list.patch:
  Btrfs: initialize new bitmaps' list (FATE#306586).
- patches.suse/btrfs-catch-locking-failures-in-set-clear-extent_bit:
  Refresh.
- patches.suse/btrfs-use-mempools-for-extent_state-structures:
  Refresh.
- patches.suse/btrfs-8001-btrfs_calc_avail_data_space-cope-with-no-read-.patch:
  Delete.
- patches.suse/btrfs-8002-Fix-the-write-error-into-tiny-space.patch:
  Delete.
* Thu Dec  1 2011 mhocko@suse.cz
- patches.fixes/cgroup_freezer_freeze_stopped_tasks_correctly.patch:
  Updated reference to the upstream commmit. Patch got accepted in the
  meantime
* Thu Dec  1 2011 mhocko@suse.cz
- patches.fixes/mm-Ensure-that-pfn_valid-is-called-once-per-pagebloc.patch:
  mm: Ensure that pfn_valid is called once per pageblock when
  reserving pageblocks (bnc#731261, bnc#730731).
* Thu Dec  1 2011 tiwai@suse.de
- patches.drivers/drm-i915-Move-i915_read-write-out-of-line:
  i915: Move i915_read/write out of line (bnc#729518).
- patches.drivers/drm-i915-add-multi-threaded-forcewake: drm/i915:
  add multi-threaded forcewake support (bnc#729518).
* Thu Dec  1 2011 jbeulich@novell.com
- patches.xen/xen-pcpu-hotplug: Fix a number of problems.
- Refresh other Xen patches.
* Wed Nov 30 2011 jankit@suse.de
- patches.drivers/mpt2sas-added-missing-mpt2sas_base_detach-call-from-scsih_remove-context:
  mpt2sas: Added missing mpt2sas_base_detach call from
  scsih_remove context (bnc#728086).
* Wed Nov 30 2011 nfbrown@suse.de
- patches.fixes/pnfs-fix: NFSv4.1: File layout only supports
  whole file layouts (FATE#310250).
* Tue Nov 29 2011 trenn@suse.de
- patches.drivers/001-pstore_3_2_fixes.patch: pstore: defer
  inserting OOPS entries into pstore (bnc#718551).
- patches.drivers/002-pstore_3_2_fixes.patch: pstore: change
  mutex locking to spin_locks (bnc#718551).
- patches.drivers/003-pstore_3_2_fixes.patch: pstore: make pstore
  write function return normal success/fail value (bnc#718551).
- patches.drivers/004-pstore_3_2_fixes.patch: pstore: pass
  allocated memory region back to caller (bnc#718551).
* Tue Nov 29 2011 jlee@suse.de
- patches.drivers/tg3-Fix-TSO-CAP-for-5704-devs-w-ASF-enabled.patch:
  tg3: Fix TSO CAP for 5704 devs w / ASF enabled.
- patches.drivers/tg3-Scale-back-code-that-modifies-MRRS.patch:
  tg3: Scale back code that modifies MRRS.
* Tue Nov 29 2011 jslaby@suse.de
- Linux 3.0.12
* Tue Nov 29 2011 nfbrown@suse.de
- patches.suse/dasd-failfast-expires: Add failfast_expires
  configuration to dasd (Fate#311379).
* Mon Nov 28 2011 dsterba@suse.cz
  btrfs: experimental 'restriper' patchset, not applied by default
- patches.suse/btrfs-1000-get-rid-of-_alloc_profile-fields.patch:
  Btrfs: get rid of *_alloc_profile fields (FATE#306586).
- patches.suse/btrfs-1001-introduce-masks-for-chunk-type-and-profile.patch:
  Btrfs: introduce masks for chunk type and profile (FATE#306586).
- patches.suse/btrfs-1002-add-btrfs_AVAIL_ALLOC_BIT_SINGLE-bit.patch:
  Btrfs: add BTRFS_AVAIL_ALLOC_BIT_SINGLE bit (FATE#306586).
- patches.suse/btrfs-1003-make-avail_-_alloc_bits-fields-dynamic.patch:
  Btrfs: make avail_*_alloc_bits fields dynamic (FATE#306586).
- patches.suse/btrfs-1004-add-basic-restriper-infrastructure.patch:
  Btrfs: add basic restriper infrastructure (FATE#306586).
- patches.suse/btrfs-1005-implement-online-profile-changing.patch:
  Btrfs: implement online profile changing (FATE#306586).
- patches.suse/btrfs-1006-add-basic-infrastructure-for-selective-balanci.patch:
  Btrfs: add basic infrastructure for selective balancing
  (FATE#306586).
- patches.suse/btrfs-1007-soft-profile-changing-mode-aka-soft-convert.patch:
  Btrfs: soft profile changing mode (aka soft convert)
  (FATE#306586).
- patches.suse/btrfs-1008-profiles-filter.patch: Btrfs: profiles
  filter (FATE#306586).
- patches.suse/btrfs-1009-usage-filter.patch: Btrfs: usage filter
  (FATE#306586).
- patches.suse/btrfs-1010-devid-filter.patch: Btrfs: devid filter
  (FATE#306586).
- patches.suse/btrfs-1011-devid-subset-filter.patch: Btrfs:
  devid subset filter (FATE#306586).
- patches.suse/btrfs-1012-virtual-address-space-subset-filter.patch:
  Btrfs: virtual address space subset filter (FATE#306586).
- patches.suse/btrfs-1013-save-restripe-parameters-to-disk.patch:
  Btrfs: save restripe parameters to disk (FATE#306586).
- patches.suse/btrfs-1014-recover-restripe-on-mount.patch: Btrfs:
  recover restripe on mount (FATE#306586).
- patches.suse/btrfs-1015-allow-for-cancelling-restriper.patch:
  Btrfs: allow for cancelling restriper (FATE#306586).
- patches.suse/btrfs-1016-allow-for-pausing-restriper.patch:
  Btrfs: allow for pausing restriper (FATE#306586).
- patches.suse/btrfs-1017-allow-for-resuming-restriper-after-it-was-paus.patch:
  Btrfs: allow for resuming restriper after it was paused
  (FATE#306586).
- patches.suse/btrfs-1018-add-skip_restripe-mount-option.patch:
  Btrfs: add skip_restripe mount option (FATE#306586).
- patches.suse/btrfs-1019-get-rid-of-btrfs_balance-function.patch:
  Btrfs: get rid of btrfs_balance() function (FATE#306586).
- patches.suse/btrfs-1020-add-restripe-progress-reporting.patch:
  Btrfs: add restripe progress reporting (FATE#306586).
* Mon Nov 28 2011 jslaby@suse.de
- Linux 3.0.11
- patches.arch/s390-message-catalog.diff: Refresh.
- patches.drivers/USB3-0001-xhci-Remove-some-unnecessary-casts-and-tidy-some-endian-swap.patch:
  Refresh.
- patches.drivers/drm-i915-always-set-FDI-composite-sync-bit:
  Delete.
- patches.drivers/drm-i915-fix-IVB-cursor-support: Delete.
- patches.fixes/scsi-set-queuedata-to-NULL.patch: Delete.
* Fri Nov 25 2011 mmarek@suse.cz
- patches.drivers/0003-ixgbe-consolidate-MRQC-and-MTQC-handling.patch:
  ixgbe: consolidate MRQC and MTQC handling (bnc#714789).
- patches.drivers/0004-ixgbe-dcbnl-reduce-duplicated-code-and-indentation.patch:
  ixgbe: dcbnl reduce duplicated code and indentation
  (bnc#714789).
- patches.drivers/0005-ixgbe-configure-minimal-packet-buffers-to-support-TC.patch:
  ixgbe: configure minimal packet buffers to support TC
  (bnc#714789).
- patches.drivers/0006-ixgbe-consolidate-packet-buffer-allocation.patch:
  ixgbe: consolidate packet buffer allocation (bnc#714789).
- patches.drivers/0007-ixgbe-add-basic-support-for-setting-and-getting-nfc-.patch:
  ixgbe: add basic support for setting and getting nfc controls
  (bnc#714789).
- patches.drivers/0008-ixgbe-DCB-use-existing-TX-and-RX-queues.patch:
  ixgbe: DCB use existing TX and RX queues (bnc#714789).
- patches.drivers/0009-ixgbe-add-support-for-displaying-ntuple-filters-via-.patch:
  ixgbe: add support for displaying ntuple filters via the nfc
  interface (bnc#714789).
- patches.drivers/0010-ixgbe-fix-flags-relating-to-perfect-filters-to-suppo.patch:
  ixgbe: fix flags relating to perfect filters to support
  coexistence (bnc#714789).
- patches.drivers/0011-ixgbe-remove-ntuple-filtering.patch:
  ixgbe: remove ntuple filtering (bnc#714789).
- patches.drivers/0012-ixgbe-update-perfect-filter-framework-to-support-ret.patch:
  ixgbe: update perfect filter framework to support retaining
  filters (bnc#714789).
- patches.drivers/0013-ixgbe-add-support-for-nfc-addition-and-removal-of-fi.patch:
  ixgbe: add support for nfc addition and removal of filters
  (bnc#714789).
- patches.drivers/0014-ixgbe-remove-redundant-configuration-of-tx_sample_ra.patch:
  ixgbe: remove redundant configuration of tx_sample_rate
  (bnc#714789).
- patches.drivers/0015-ixgbe-PFC-not-cleared-on-X540-devices.patch:
  ixgbe: PFC not cleared on X540 devices (bnc#714789).
- patches.drivers/0016-ixgbe-DCB-and-perfect-filters-can-coexist.patch:
  ixgbe: DCB and perfect filters can coexist (bnc#714789).
- patches.drivers/0017-ixgbe-consolidate-setup-for-multiple-traffic-classes.patch:
  ixgbe: consolidate, setup for multiple traffic classes
  (bnc#714789).
- patches.drivers/0018-v2-ixgbe-Update-packet-buffer-reservation-to-correct.patch:
  v2 ixgbe: Update packet buffer reservation to correct fdir
  headroom size (bnc#714789).
- patches.drivers/0019-ixgbe-update-P-FC-thresholds-to-account-for-X540-and.patch:
  ixgbe: update {P}FC thresholds to account for X540 and loopback
  (bnc#714789).
- patches.drivers/0020-ixgbe-Make-certain-to-initialize-the-fdir_perfect_lo.patch:
  ixgbe: Make certain to initialize the fdir_perfect_lock in
  all cases (bnc#714789).
- patches.drivers/0021-ixgbe-complete-FCoE-initialization-from-setapp-routi.patch:
  ixgbe: complete FCoE initialization from setapp() routine
  (bnc#714789).
- patches.drivers/0022-ixgbe-DCB-do-not-call-set_state-from-IEEE-mode.patch:
  ixgbe: DCB, do not call set_state() from IEEE mode (bnc#714789).
- patches.drivers/0023-ixgbe-add-structure-for-containing-RX-TX-rings-to-q_.patch:
  ixgbe: add structure for containing RX/TX rings to q_vector
  (bnc#714789).
- patches.drivers/0024-ixgbe-Move-interrupt-related-values-out-of-ring-and-.patch:
  ixgbe: Move interrupt related values out of ring and into
  q_vector (bnc#714789).
- patches.drivers/0025-ixgbe-DCB-X540-devices-support-max-traffic-class-of-.patch:
  ixgbe: DCB X540 devices support max traffic class of 4
  (bnc#714789).
- patches.drivers/0026-ixgbe-Move-all-values-that-deal-with-count-next_to_u.patch:
  ixgbe: Move all values that deal with count, next_to_use,
  next_to_clean to u16 (bnc#714789).
- patches.drivers/0027-ixgbe-Update-method-used-for-determining-descriptor-.patch:
  ixgbe: Update method used for determining descriptor count
  for an skb (bnc#714789).
- patches.drivers/0028-ixgbe-Add-one-function-that-handles-most-of-context-.patch:
  ixgbe: Add one function that handles most of context descriptor
  setup (bnc#714789).
- patches.drivers/0029-ixgbe-Refactor-transmit-map-and-cleanup-routines.patch:
  ixgbe: Refactor transmit map and cleanup routines (bnc#714789).
- patches.drivers/0030-ixgbe-Cleanup-FCOE-and-VLAN-handling-in-xmit_frame_r.patch:
  ixgbe: Cleanup FCOE and VLAN handling in xmit_frame_ring
  (bnc#714789).
- patches.drivers/0031-ixgbe-Always-tag-VLAN-tagged-packets.patch:
  ixgbe: Always tag VLAN tagged packets (bnc#714789).
- patches.drivers/0032-ixgbe-fixup-hard-dependencies-on-supporting-8-traffi.patch:
  ixgbe: fixup hard dependencies on supporting 8 traffic classes
  (bnc#714789).
* Fri Nov 25 2011 jlee@suse.de
- patches.drivers/0001-qlge-fix-size-of-external-list-for-TX-address-descri.patch:
  qlge: fix size of external list for TX address descriptors. (bnc#727638)
* Fri Nov 25 2011 nfbrown@suse.de
- patches.suse/0001-md-failfast-add-failfast-flag-for-md-to-be-used-by-s.patch:
  md/failfast:  add failfast flag for md to be used by some
  personalities (Fate#311379).
- patches.suse/0002-md-raid1-add-failfast-handling-for-reads.patch:
  md/raid1 add failfast handling for reads (Fate#311379).
- patches.suse/0003-md-raid1-add-failfast-handling-for-writes.patch:
  md/raid1 - add failfast handling for writes (Fate#311379).
- patches.suse/0004-md-raid10-add-failfast-handling-for-reads.patch:
  md/raid10 add failfast handling for reads (Fate#311379).
- patches.suse/0005-md-raid10-add-failfast-handling-for-writes.patch:
  md/raid10 - add failfast handling for writes (Fate#311379).
* Fri Nov 25 2011 nfbrown@suse.de
- patches.suse/0001-md-failfast-add-failfast-flag-for-md-to-be-used-by-s.patch:
  md/failfast:  add failfast flag for md to be used by some
  personalities (Fate#311379).
- patches.suse/0002-md-raid1-add-failfast-handling-for-reads.patch:
  md/raid1 add failfast handling for reads (Fate#311379).
- patches.suse/0003-md-raid1-add-failfast-handling-for-writes.patch:
  md/raid1 - add failfast handling for writes (Fate#311379).
- patches.suse/0004-md-raid10-add-failfast-handling-for-reads.patch:
  md/raid10 add failfast handling for reads (Fate#311379).
- patches.suse/0005-md-raid10-add-failfast-handling-for-writes.patch:
  md/raid10 - add failfast handling for writes (Fate#311379).
* Fri Nov 25 2011 nfbrown@suse.de
- patches.suse/0001-md-failfast-add-failfast-flag-for-md-to-be-used-by-s.patch:
  md/failfast:  add failfast flag for md to be used by some
  personalities (Fate#311379).
- patches.suse/0002-md-raid1-add-failfast-handling-for-reads.patch:
  md/raid1 add failfast handling for reads (Fate#311379).
- patches.suse/0003-md-raid1-add-failfast-handling-for-writes.patch:
  md/raid1 - add failfast handling for writes (Fate#311379).
- patches.suse/0004-md-raid10-add-failfast-handling-for-reads.patch:
  md/raid10 add failfast handling for reads (Fate#311379).
- patches.suse/0005-md-raid10-add-failfast-handling-for-writes.patch:
  md/raid10 - add failfast handling for writes (Fate#311379).
* Fri Nov 25 2011 jeffm@suse.com
- Btrfs error handling update:
  - Quilt-refresh patchset
  - Added simplification for ->submit_bio_hook
  - Added missing btree locking panic for convert_extent_bit.
  - Fixed typos in Subject headers
* Thu Nov 24 2011 mmarek@suse.cz
- Update config files: Disable CEPH_FS and BLK_DEV_RBD, they will
  be shipped separately(fate#312934, bnc#731701).
* Thu Nov 24 2011 jjolly@suse.de
- patches.arch/s390-41-01-qeth-avoid-siga-r-cost.patch:
  qeth: reduce SIGA-r to avoid CPU cost implications
  (bnc#732371,LTC#76691).
- patches.arch/s390-41-02-z10-topology.patch: kernel: fix z10
  CPU topology (bnc#732371,LTC#76623).
- patches.arch/s390-41-03-zfcp-return-early-from-slave_destroy-if-slave_alloc-returned-early.patch:
  zfcp: return early from slave_destroy if slave_alloc returned
  early (bnc#732371,LTC#76754).
- patches.arch/s390-41-04-qeth-shutdown-no-recovery.patch: qeth:
  forbid recovery during shutdown (bnc#732371,LTC#76845).
* Thu Nov 24 2011 hare@suse.de
- patches.fixes/dcb-add-stub-routines-for-not-CONFIG_DCB.patch:
  dcb: Add stub routines for !CONFIG_DCB (bnc#714789).
* Thu Nov 24 2011 mhocko@suse.cz
- patches.suse/shmem-do-not-export-shmem_inode_info-struct.patch:
  Refresh.
* Thu Nov 24 2011 mhocko@suse.cz
- patches.suse/mm-a-few-small-updates-for-radix-swap.patch: mm:
  a few small updates for radix-swap (bnc#731999 fate#313009).
- patches.suse/mm-let-swap-use-exceptional-entries.patch: mm:
  let swap use exceptional entries (bnc#731999 FATE#313009).
- patches.suse/tmpfs-convert-mem_cgroup-shmem-to-radix-swap.patch:
  tmpfs: convert mem_cgroup shmem to radix-swap (bnc#731999
  fate#313009).
- patches.suse/tmpfs-convert-shmem_getpage_gfp-to-radix-swap.patch:
  tmpfs: convert shmem_getpage_gfp to radix-swap (bnc#731999
  fate#313009).
- patches.suse/tmpfs-convert-shmem_truncate_range-to-radix-swap.patch:
  tmpfs: convert shmem_truncate_range to radix-swap (bnc#731999
  fate#313009).
- patches.suse/tmpfs-convert-shmem_unuse_inode-to-radix-swap.patch:
  tmpfs: convert shmem_unuse_inode to radix-swap (bnc#731999
  fate#313009).
- patches.suse/tmpfs-convert-shmem_writepage-and-enable-swap.patch:
  tmpfs: convert shmem_writepage and enable swap (bnc#731999
  fate#313009).
- patches.suse/tmpfs-copy-truncate_inode_pages_range.patch:
  tmpfs: copy truncate_inode_pages_range (bnc#731999 fate#313009).
- patches.suse/tmpfs-demolish-old-swap-vector-support.patch:
  tmpfs: demolish old swap vector support (bnc#731999
  fate#313009).
- patches.suse/tmpfs-miscellaneous-trivial-cleanups.patch: tmpfs:
  miscellaneous trivial cleanups (bnc#731999 fate#313009).
- patches.suse/tmpfs-use-kmemdup-for-short-symlinks.patch: tmpfs:
  use kmemdup for short symlinks (bnc#731999 fate#313009).
- commit 62fa82a
* Thu Nov 24 2011 mmarek@suse.cz
- Build kdb modules as modules, not built-in.
* Thu Nov 24 2011 mgalbraith@suse.de
- patches.fixes/perf-events-Fix-slow-and-broken-cgroup-context-switch-code:
  perf events: Fix slow and broken cgroup context switch code.
* Thu Nov 24 2011 mhocko@suse.cz
- patches.suse/radix_tree-exceptional-entries-and-indices.patch:
  radix_tree: exceptional entries and indices (bnc#731999
  FATE#313009).
- patches.suse/shmem-do-not-export-shmem_inode_info-struct.patch:
  Do not export shmem internal data structures (bnc#731999
  FATE#313009).
* Thu Nov 24 2011 mhocko@suse.cz
- patches.suse/mm-cleanup-descriptions-of-filler-arg.patch: mm:
  cleanup descriptions of filler arg (bnc#731999).
- patches.suse/mm-consistent-truncate-and-invalidate-loops.patch:
  mm: consistent truncate and invalidate loops (bnc#731999).
- patches.suse/mm-pincer-in-truncate_inode_pages_range.patch:
  mm: pincer in truncate_inode_pages_range (bnc#731999).
- patches.suse/mm-tidy-vmtruncate_range-and-related-functions.patch:
  mm: tidy vmtruncate_range and related functions (bnc#731999).
- patches.suse/mm-truncate-functions-are-in-truncate.c.patch:
  mm: truncate functions are in truncate.c (bnc#731999).
- patches.suse/tmpfs-clone-shmem_file_splice_read.patch: tmpfs:
  clone shmem_file_splice_read() (bnc#731999).
- patches.suse/tmpfs-no-need-to-use-i_lock.patch: tmpfs: no need
  to use i_lock (bnc#731999).
- patches.suse/tmpfs-pass-gfp-to-shmem_getpage_gfp.patch: tmpfs:
  pass gfp to shmem_getpage_gfp (bnc#731999).
- patches.suse/tmpfs-refine-shmem_file_splice_read.patch: tmpfs:
  refine shmem_file_splice_read (bnc#731999).
- patches.suse/tmpfs-remove_shmem_readpage.patch: tmpfs:
  remove_shmem_readpage (bnc#731999).
- patches.suse/tmpfs-simplify-filepage-swappage.patch: tmpfs:
  simplify filepage/swappage (bnc#731999).
- patches.suse/tmpfs-simplify-prealloc_page.patch: tmpfs:
  simplify prealloc_page (bnc#731999).
- patches.suse/tmpfs-simplify-unuse-and-writepage.patch: tmpfs:
  simplify unuse and writepage (bnc#731999).
- patches.xen/cleancache-update: Refresh.
* Thu Nov 24 2011 hare@suse.de
- patches.fixes/dcb-Use-ifindex-instead-of-ifname.patch: dcb:
  Use ifindex instead of ifname (bnc#714789).
- patches.fixes/dcb-add-DCBX-mode-to-event-notifier-attributes.patch:
  dcb: add DCBX mode to event notifier attributes (bnc#714789).
- patches.suse/SoN-0009b-netvm-Propagate-page-pfmemalloc-to-skb.patch:
  Fixup typo.
* Thu Nov 24 2011 jdelvare@suse.de
- patches.fixes/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx.patch:
  Add missing git-commit.
* Thu Nov 24 2011 trenn@suse.de
- patches.fixes/percpu_fix_chunk_range_calculation.patch: percpu:
  fix chunk range calculation (bnc#668872).
* Thu Nov 24 2011 hare@suse.de
- patches.fixes/fcoe-add-DCB-notifiers-to-set-skb-priority.patch:
  fcoe: add DCB notifiers to set skb priority (bnc#714789).
* Thu Nov 24 2011 hare@suse.de
- Update bnx2x driver to version 1.70.35-0 (bnc#732335):
  * patches.drivers/bnx2x-DCBX-use-define-instead-of-magic.patch:
    bnx2x: DCBX: use #define instead of magic.
  * patches.drivers/bnx2x-Remove-on-stack-napi-struct-variable.patch:
    bnx2x: Remove on-stack napi struct variable.
  * patches.drivers/bnx2x-add-endline-at-end-of-message.patch:
    bnx2x: add endline at end of message.
  * patches.drivers/bnx2x-add-fan-failure-event-handling.patch:
    bnx2x: add fan failure event handling.
  * patches.drivers/bnx2x-cache-in-compressed-fw-image.patch:
    bnx2x: cache-in compressed fw image.
  * patches.drivers/bnx2x-prevent-race-in-statistics-flow.patch:
    bnx2x: prevent race in statistics flow.
  * patches.drivers/bnx2x-propagate-DCBX-negotiation.patch: bnx2x:
    propagate DCBX negotiation.
  * patches.drivers/bnx2x-remove-unused-define.patch: bnx2x:
    remove unused #define.
  * patches.drivers/bnx2x-remove-unused-variable.patch: bnx2x:
    remove unused variable.
  * patches.drivers/bnx2x-separate-FCoE-and-iSCSI-license-initializatio.patch:
    bnx2x: separate FCoE and iSCSI license initialization.
  * patches.drivers/bnx2x-simplify-definition-of-RX_SGE_MASK_LEN-and-us.patch:
    bnx2x: simplify definition of RX_SGE_MASK_LEN and use it.
  * patches.drivers/bnx2x-update-driver-version-to-1.70.35-0.patch:
    bnx2x: update driver version to 1.70.35-0.
  * patches.drivers/bnx2x-use-rx_queue-index-for-skb_record_rx_queue.patch:
    bnx2x: use rx_queue index for skb_record_rx_queue().
* Thu Nov 24 2011 jeffm@suse.com
- Latest btrfs error handling update.
  - extent_state allocs now use mempools
  - eliminates a bunch of error push-ups since
    they now return void
* Wed Nov 23 2011 dsterba@suse.cz
  btrfs hotfixes
- patches.suse/btrfs-8001-btrfs_calc_avail_data_space-cope-with-no-read-.patch:
  btrfs: btrfs_calc_avail_data_space cope with no read/write
  devices V2 (FATE#306586).
- patches.suse/btrfs-8001-rewrite-btrfs_trim_block_group.patch:
  Btrfs: rewrite btrfs_trim_block_group() (FATE#306586).
- patches.suse/btrfs-8002-Fix-the-write-error-into-tiny-space.patch:
  Btrfs: Fix the write error into tiny space (FATE#306586).
- patches.suse/btrfs-8003-scrub-handle-ENOMEM-from-init_ipath.patch:
  btrfs scrub: handle -ENOMEM from init_ipath() (FATE#306586).
- patches.suse/btrfs-8005-fix-deadlock-on-metadata-reservation-when-evic.patch:
  Btrfs: fix deadlock on metadata reservation when evicting a
  inode (FATE#306586).
- patches.suse/btrfs-8006-Don-t-error-on-resizing-FS-to-same-size.patch:
  Btrfs: Don't error on resizing FS to same size (FATE#306586).
- patches.suse/btrfs-8007-lock-and-disable-irq-during-space-alloc.patch:
  btrfs: lock and disable irq during space alloc (FATE#306586
  bnc#730103).
- patches.suse/btrfs-8001-kill-space_info-pointer-from-inode-structure.patch:
  Delete.
* Wed Nov 23 2011 mmarek@suse.cz
- supported.conf: mbp_nvidia_bl got renamed to apple_bl.
* Wed Nov 23 2011 mmarek@suse.cz
- supported.conf: Remove radio-gemtek-pci
  (duplicate of radio-maxiradio).
* Wed Nov 23 2011 mmarek@suse.cz
- supported.conf: Add back mt9m001 and mt9v022. The chances of
  someone using these with SLE are pretty slim, but we used to
  have them in SP1.
* Wed Nov 23 2011 mmarek@suse.cz
- supported.conf: Add gspca drivers that replaced usbvideo ones.
* Wed Nov 23 2011 hare@suse.de
- patches.drivers/bfa-set-correct-scsi-returncode: Fixup typo.
* Wed Nov 23 2011 hare@suse.de
- patches.drivers/cciss-stable-controller-enumeration.patch:
  cciss: Stable controller enumeration (bnc#713707).
* Wed Nov 23 2011 hare@suse.de
- patches.drivers/bfa-set-correct-scsi-returncode: bfa: set
  correct command return code (bnc#721874).
* Wed Nov 23 2011 jbeulich@novell.com
- Update Xen patches to c/s 1127.
- patches.xen/xen3-pnp_fix_misleading_error_msg.patch: PNP ACPI:
  Fix a buggy debug messagge (bnc#720750).
- Update EC2 config files.
* Wed Nov 23 2011 hare@suse.de
- supported.conf: mark iscsi_target_mod as supported (bnc#730440).
* Wed Nov 23 2011 hare@suse.de
- patches.suse/mkinitrd-scsi_host_template-proc_name.patch:
  Remove WARN_ON(), as it breaks PLDP drivers (bnc#732082).
* Wed Nov 23 2011 hare@suse.de
- patches.drivers/be2iscsi-Move-Driver-Version-to-4.1.282.0.patch:
  be2iscsi: Move Driver Version to 4.1.282.0 (bnc#732178).
- patches.drivers/be2iscsi-memset-wrb-for-ring-create.patch:
  be2iscsi: memset wrb for ring create (bnc#732178).
- patches.drivers/be2iscsi-passing-correct-offset-in-async-paths.patch:
  be2iscsi: passing correct offset in async paths (bnc#732178).
* Wed Nov 23 2011 lduncan@suse.de
- patches.drivers/bnx2fc-bumped-version-to-1-0-9: bnx2fc: Bumped
  version to 1.0.9 (bnc#726703).
- patches.drivers/bnx2fc-handle-abts-timeout-during-ulp-timeout:
  bnx2fc: Handle ABTS timeout during ulp timeout (bnc#726703).
- patches.drivers/bnx2fc-handle-srr-ls_acc-drop-scenario: bnx2fc:
  Handle SRR LS_ACC drop scenario (bnc#726703).
* Wed Nov 23 2011 mgalbraith@suse.de
- The abreviated version of facc4307 (perf-oprofile-fix) breaks perf.
  Fix the problem by bringing perf core up to the 27eb4a1e merge point
  instead, and add b58f6b0d, the follow-up fix for the series.
  Discovered while adding a8d757ef076f0f95f13a918808824058de25b3eb
  perf events: Fix slow and broken cgroup context switch code.
- patches.fixes/perf-oprofile-fix: Delete.
- patches.fixes/perf-Change-and-simplify-ctx-is_active-semantics:
  perf: Change and simplify ctx::is_active semantics (bnc#723171).
- patches.fixes/perf-Change-close-semantics-for-group-events:
  perf: Change close() semantics for group events.
- patches.fixes/perf-Clean-up-ctx-reference-counting:
  perf: Clean up 'ctx' reference counting (bnc#723171).
- patches.fixes/perf-Collect-the-schedule-in-rules-in-one-function:
  perf: Collect the schedule-in rules in one function (bnc#723171).
- patches.fixes/perf-De-schedule-a-task-context-when-removing-the-last-event:
  perf: De-schedule a task context when removing the last event (bnc#723171).
- patches.fixes/perf-Optimize-ctx_sched_out:
  perf: Optimize ctx_sched_out() (bnc#723171).
- patches.fixes/perf-Optimize-event-scheduling-locking:
  perf: Optimize event scheduling locking (bnc#723171).
- patches.fixes/perf-Remove-task_ctx_sched_in:
  perf: Remove task_ctx_sched_in() (bnc#723171).
- patches.fixes/perf-Simplify-and-fix-__perf_install_in_context:
  perf: Simplify and fix __perf_install_in_context() (bnc#723171).
- patches.fixes/perf-core-Fix-initial-task_ctx-slash-event-installation:
  perf, core: Fix initial task_ctx/event installation (bnc#723171).
* Tue Nov 22 2011 rjw@suse.de
- patches.fixes/pci-pciehp-fix-pcied_cleanup.patch: PCI / Hotplug:
  Fix the ordering of operations in pcied_cleanup() (bnc#729789).
* Tue Nov 22 2011 rjw@suse.de
- patches.arch/x86-UV-make-uv_mmrs.h-be-identical-with-upstream.patch:
  x86 / UV: Make uv_mmrs.h be identical with the upstream version
  (bnc#722795).
* Tue Nov 22 2011 jslaby@suse.de
- Linux 3.0.10
- patches.kernel.org/alsa-hda-don-t-add-elements-of-other-codecs-to-vmaster-slave.patch:
  Delete.
- patches.kernel.org/alsa-usb-audio-check-the-db-range-validity-in-the-later-read-too.patch:
  Delete.
- patches.kernel.org/alsa-usb-audio-fix-the-missing-volume-quirks-at-delayed-init.patch:
  Delete.
- patches.kernel.org/asoc-don-t-use-wm8994-control_data-in-wm8994_readable_register.patch:
  Delete.
- patches.kernel.org/backing-dev-ensure-wakeup_timer-is-deleted.patch:
  Delete.
- patches.kernel.org/block-always-check-length-of-all-iov-entries-in.patch:
  Delete.
- patches.kernel.org/drm-i915-enable-ring-freq-scaling-rc6-and-graphics-turbo-on-ivy-bridge-v3.patch:
  Delete.
- patches.kernel.org/drm-i915-fix-object-refcount-leak-on-mmappable-size-limit-error-path.patch:
  Delete.
- patches.kernel.org/drm-nouveau-initialize-chan-fence.lock-before-use.patch:
  Delete.
- patches.kernel.org/drm-radeon-add-some-missing-firemv-pci-ids.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-make-an-aux-failure-debug-only.patch:
  Delete.
- patches.kernel.org/hfs-add-sanity-check-for-file-name-length.patch:
  Delete.
- patches.kernel.org/keys-fix-a-null-pointer-deref-in-the-user-defined-key-type.patch:
  Delete.
- patches.kernel.org/md-raid5-abort-any-pending-parity-operations-when-array-fails.patch:
  Delete.
- patches.kernel.org/mfd-fix-twl4030-dependencies-for-audio-codec.patch:
  Delete.
- patches.kernel.org/powerpc-copy-down-exception-vectors-after-feature-fixups.patch:
  Delete.
- patches.kernel.org/powerpc-ps3-fix-lost-smp-ipis.patch: Delete.
- patches.kernel.org/revert-leds-save-the-delay-values-after-a-successful-call-to-blink_set.patch:
  Delete.
- patches.kernel.org/sfi-table-irq-0xff-means-no-interrupt.patch:
  Delete.
- patches.kernel.org/sh-fix-cached-uncaced-address-calculation-in-29bit-mode.patch:
  Delete.
- patches.kernel.org/virtio-pci-fix-use-after-free.patch: Delete.
- patches.kernel.org/x86-mrst-use-a-temporary-variable-for-sfi-irq.patch:
  Delete.
- patches.kernel.org/xen-gntalloc-integer-overflow-in-gntalloc_ioctl_alloc.patch:
  Delete.
- patches.kernel.org/xen-gntalloc-signedness-bug-in-add_grefs.patch:
  Delete.
- patches.kernel.org/xen-pvhvm-enable-pvhvm-vcpu-placement-when-using-more-than-32-cpus.patch:
  Delete.
* Tue Nov 22 2011 mhocko@suse.cz
- patches.suse/pagecache-limit-warn-on-usage.patch: Refresh.
  Do not report on the proc file read.
* Tue Nov 22 2011 jdelvare@suse.de
- patches.fixes/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx.patch:
  drm/radeon/kms: fix up gpio i2c mask bits for r4xx (bnc#691052).
* Tue Nov 22 2011 dsterba@suse.cz
  post 3.2-rc2 updates and critical fixes
- patches.suse/btrfs-0243-fix-barrier-flushes.patch: Btrfs:
  fix barrier flushes (FATE#306586).
- patches.suse/btrfs-0244-Fix-up-32-64-bit-compatibility-for-new-ioctls.patch:
  btrfs: Fix up 32/64-bit compatibility for new ioctls
  (FATE#306586).
- patches.suse/btrfs-0245-mirror_num-should-be-int-not-u64.patch:
  btrfs: mirror_num should be int, not u64 (FATE#306586).
- patches.suse/btrfs-0246-fix-to-search-one-more-bitmap-for-cluster-setu.patch:
  Btrfs: fix to search one more bitmap for cluster setup
  (FATE#306586).
- patches.suse/btrfs-0247-avoid-unnecessary-bitmap-search-for-cluster-se.patch:
  Btrfs: avoid unnecessary bitmap search for cluster setup
  (FATE#306586).
- patches.suse/btrfs-0248-fix-stat-blocks-accounting.patch:
  btrfs: fix stat blocks accounting (FATE#306586).
- patches.suse/btrfs-0249-prefix-resize-related-printks-with-btrfs.patch:
  Btrfs: prefix resize related printks with btrfs: (FATE#306586).
- patches.suse/btrfs-0250-wait-on-caching-if-we-re-loading-the-free-spac.patch:
  Btrfs: wait on caching if we're loading the free space cache
  (FATE#306586).
- patches.suse/btrfs-0251-clear-pages-dirty-for-io-and-set-them-extent-m.patch:
  Btrfs: clear pages dirty for io and set them extent mapped
  (FATE#306586).
- patches.suse/btrfs-0252-sectorsize-align-offsets-in-fiemap.patch:
  Btrfs: sectorsize align offsets in fiemap (FATE#306586).
- patches.suse/btrfs-0253-remove-free-space-cache.c-WARN-during-log-repl.patch:
  Btrfs: remove free-space-cache.c WARN during log replay
  (FATE#306586).
- patches.suse/btrfs-lock_extent-error-push-up: Refresh.
- patches.suse/btrfs-fix-up-32-64-bit-compatibility-for-new-ioctls:
  Delete.
* Tue Nov 22 2011 mhocko@suse.cz
- patches.fixes/cgroup_freezer_freeze_stopped_tasks_correctly.patch:
  cgroup_freezer: fix freezing groups with stopped tasks
  (bnc#713933).
* Tue Nov 22 2011 mmarek@suse.cz
- patches.fixes/0001-genksyms-Minor-parser-cleanup.patch:
  genksyms: Minor parser cleanup.
- patches.fixes/0002-genksyms-Do-not-expand-internal-types.patch:
  genksyms: Do not expand internal types.
- patches.fixes/0003-genksyms-Regenerate-lexer-and-parser.patch:
  genksyms: Regenerate lexer and parser.
* Tue Nov 22 2011 sjayaraman@suse.de
- patches.fixes/xfs-Fix-wrong-return-value-of-xfs_file_aio_write.patch:
  xfs: Fix wrong return value of xfs_file_aio_write (bnc#719079).
* Mon Nov 21 2011 hare@suse.de
- patches.drivers/qla4xxx-bug-fixes-for-mixed-mode-support.patch:
  qla4xxx: bug fixes for mixed mode support (bnc#731029).
* Mon Nov 21 2011 mhocko@suse.cz
- patches.fixes/aggressive-zone-reclaim.patch: Delete. No feedback
  from the requester (bnc#476525)
* Mon Nov 21 2011 hare@suse.de
- Fixup patches for series2git:
  * patches.suse/btrfs-_btrfs_mod_ref-s-process_func-should-return-void
  * patches.suse/btrfs-btrfs_inc_extent_ref-void-return-prep
  * patches.suse/btrfs-clean_tree_block-should-return-void
  * patches.suse/btrfs-disk-io-__setup_root-should-return-void
  * patches.suse/btrfs-extent-tree-btrfs_prepare_extent_commit-should-return-void
  * patches.suse/btrfs-extent-tree-btrfs_set_block_group_rw-should-return-void
  * patches.suse/btrfs-lock_extent-error-push-up
  * patches.suse/btrfs-unlock_extent-error-push-up
* Sun Nov 20 2011 mgalbraith@suse.de
- CFS Hard Limits bugfix (for FATE#311682)
- patches.fixes/sched-Fix-buglet-in-return_cfs_rq_runtime: sched:
  Fix buglet in return_cfs_rq_runtime().
* Fri Nov 18 2011 gregkh@suse.de
- patches.arch/ccwgroup-fix-uevent-vs-dev-attrs-race.patch:
  ccwgroup: fix uevent vs dev attrs race (bnc#717797).
* Fri Nov 18 2011 gregkh@suse.de
- Linux 3.0.10 patches queued up
- patches.kernel.org/alsa-hda-don-t-add-elements-of-other-codecs-to-vmaster-slave.patch:
  ALSA: hda - Don't add elements of other codecs to vmaster slave.
- patches.kernel.org/alsa-usb-audio-check-the-db-range-validity-in-the-later-read-too.patch:
  ALSA: usb-audio - Check the dB-range validity in the later
  read, too.
- patches.kernel.org/alsa-usb-audio-fix-the-missing-volume-quirks-at-delayed-init.patch:
  ALSA: usb-audio - Fix the missing volume quirks at delayed init.
- patches.kernel.org/asoc-don-t-use-wm8994-control_data-in-wm8994_readable_register.patch:
  ASoC: Don't use wm8994->control_data in
  wm8994_readable_register().
- patches.kernel.org/b43-refuse-to-load-unsupported-firmware.patch:
  b43: refuse to load unsupported firmware.
- patches.kernel.org/backing-dev-ensure-wakeup_timer-is-deleted.patch:
  backing-dev: ensure wakeup_timer is deleted.
- patches.kernel.org/block-always-check-length-of-all-iov-entries-in.patch:
  block: Always check length of all iov entries in
  blk_rq_map_user_iov().
- patches.kernel.org/drm-i915-enable-ring-freq-scaling-rc6-and-graphics-turbo-on-ivy-bridge-v3.patch:
  drm/i915: enable ring freq scaling, RC6 and graphics turbo on
  Ivy Bridge v3.
- patches.kernel.org/drm-i915-fix-object-refcount-leak-on-mmappable-size-limit-error-path.patch:
  drm/i915: Fix object refcount leak on mmappable size limit
  error path.
- patches.kernel.org/drm-nouveau-initialize-chan-fence.lock-before-use.patch:
  drm/nouveau: initialize chan->fence.lock before use.
- patches.kernel.org/drm-radeon-add-some-missing-firemv-pci-ids.patch:
  drm/radeon: add some missing FireMV pci ids.
- patches.kernel.org/drm-radeon-kms-make-an-aux-failure-debug-only.patch:
  drm/radeon/kms: make an aux failure debug only.
- patches.kernel.org/hfs-add-sanity-check-for-file-name-length.patch:
  hfs: add sanity check for file name length.
- patches.kernel.org/keys-fix-a-null-pointer-deref-in-the-user-defined-key-type.patch:
  KEYS: Fix a NULL pointer deref in the user-defined key type.
- patches.kernel.org/md-raid5-abort-any-pending-parity-operations-when-array-fails.patch:
  md/raid5: abort any pending parity operations when array fails.
- patches.kernel.org/mfd-fix-twl4030-dependencies-for-audio-codec.patch:
  mfd: Fix twl4030 dependencies for audio codec.
- patches.kernel.org/powerpc-copy-down-exception-vectors-after-feature-fixups.patch:
  powerpc: Copy down exception vectors after feature fixups.
- patches.kernel.org/powerpc-ps3-fix-lost-smp-ipis.patch:
  powerpc/ps3: Fix lost SMP IPIs.
- patches.kernel.org/revert-leds-save-the-delay-values-after-a-successful-call-to-blink_set.patch:
  Revert "leds: save the delay values after a successful call
  to blink_set()".
- patches.kernel.org/sfi-table-irq-0xff-means-no-interrupt.patch:
  sfi: table irq 0xFF means 'no interrupt'.
- patches.kernel.org/sh-fix-cached-uncaced-address-calculation-in-29bit-mode.patch:
  sh: Fix cached/uncaced address calculation in 29bit mode.
- patches.kernel.org/virtio-pci-fix-use-after-free.patch:
  virtio-pci: fix use after free.
- patches.kernel.org/x86-mrst-use-a-temporary-variable-for-sfi-irq.patch:
  x86, mrst: use a temporary variable for SFI irq.
- patches.kernel.org/xen-gntalloc-integer-overflow-in-gntalloc_ioctl_alloc.patch:
  xen-gntalloc: integer overflow in gntalloc_ioctl_alloc().
- patches.kernel.org/xen-gntalloc-signedness-bug-in-add_grefs.patch:
  xen-gntalloc: signedness bug in add_grefs().
- patches.kernel.org/xen-pvhvm-enable-pvhvm-vcpu-placement-when-using-more-than-32-cpus.patch:
  xen:pvhvm: enable PVHVM VCPU placement when using more than
  32 CPUs.
- patches.drivers/drm_add_radeon_rv380_3151_rv280_4C6E_support:
  Delete.
* Fri Nov 18 2011 mmarek@suse.cz
- rpm/symsets.pl: Fix --list-exported-symbols for 3.0 (bnc#727793).
* Fri Nov 18 2011 mmarek@suse.cz
- patches.kabi/kabi-add-padding-to-some-important-structures:
  kabi: Add placeholders to a couple of important structures
  (fate#312013).
- patches.suse/perfmon2.patch: Refresh.
* Thu Nov 17 2011 rjw@suse.de
- patches.arch/x86-uv2-drop-UV2_HUB_KABI_HACKS.patch: x86 /
  UV2: Drop the unnecessary definition of UV2_HUB_KABI_HACKS
  (bnc#722795).
* Wed Nov 16 2011 tiwai@suse.de
- patches.fixes/x86-kexec-temporary-hack-v2: x86: kexec:
  Temporary hack to allow crashkernel=512M on server hardware (v2)
  (bnc#726850).
- patches.fixes/x86-kexec-temporary-hack-for-large-crashkernels-on-servers.patch:
  Delete.
* Wed Nov 16 2011 hare@suse.de
- patches.fixes/dm-mpath-do-not-call-request_module:
  dm-multipath: Do not call request_module for existing
  hw_handlers (bnc#721738).
* Wed Nov 16 2011 trenn@suse.de
- patches.drivers/pci_acpi_crs_fix_32bit_addresses_exceeding_4g.patch:
  x86/PCI: Ignore CPU non-addressable _CRS reserved memory
  resources (bnc#727453).
- patches.drivers/pnp_fix_misleading_error_msg.patch: PNP ACPI:
  Fix a buggy debug messagge (bnc#720750).
- patches.drivers/pnp_gsi_irq_override.patch: PNP ACPI: Use real
  gsi (bnc#720750).
* Wed Nov 16 2011 dsterba@suse.cz
- patches.suse/btrfs-add-btrfs_panic: Refresh.
* Wed Nov 16 2011 dsterba@suse.cz
- patches.suse/btrfs-0214-Moved-repair-code-from-inode.c-to-extent_io.c.patch:
  Refresh.
- patches.suse/btrfs-0241-rename-the-option-to-nospace_cache.patch:
  btrfs: rename the option to nospace_cache (FATE#306586).
- patches.suse/btrfs-0242-fix-tree-corruption-after-multi-thread-snapsho.patch:
  Btrfs: fix tree corruption after multi-thread snapshots and
  inode_cache flush (FATE#306586).
- patches.suse/btrfs-fixup_low_keys-should-return-void: Refresh.
- patches.suse/btrfs-setup_items_for_insert-should-return-void:
  Refresh.
- patches.suse/btrfs-0214-Moved-repair-code-from-inode.c-to-extent_io.c.patch-fix:
  Delete.
* Wed Nov 16 2011 rjw@suse.de
- patches.arch/x86-reboot-blacklist-dell-optiplex-990.patch:
  x86 / reboot: Blacklist Dell OptiPlex 990 known to require
  PCI reboot  (bnc#727324).
* Tue Nov 15 2011 trenn@suse.de
- patches.arch/x2apic_opt_out.patch: x86, x2apic: Enable the
  bios request for x2apic optout (bnc#718401).
* Tue Nov 15 2011 jbeulich@novell.com
- Update Xen patches to c/s 1125 and 3.0.9.
- Update frontswap patches to v10.
* Tue Nov 15 2011 jeffm@suse.com
- patches.suse/btrfs-fix-up-32-64-bit-compatibility-for-new-ioctls:
  btrfs: Fix up 32/64-bit compatibility for new ioctls.
* Tue Nov 15 2011 jeffm@suse.com
- patches.suse/btrfs-0214-Moved-repair-code-from-inode.c-to-extent_io.c.patch-fix:
  btrfs: Fix btree_io_failed_hook prototype.
* Mon Nov 14 2011 eich@suse.de
- patches.drivers/drm_add_radeon_rv380_3151_rv280_4C6E_support:
  Add two missing PCI IDs for Radeon Chips (bnc#730265).
* Mon Nov 14 2011 duwe@suse.de
- patches.fixes/ipv6-check-dst_alloc-retval: ipv6: check return
  value for dst_alloc (bnc#726309).
* Mon Nov 14 2011 mmarek@suse.cz
- supported.conf: Add mtd_blkdevs and mtdblock again, for
  compatibility with SP1.
* Sat Nov 12 2011 jeffm@suse.com
- Updated btrfs error handling patchset.
  - patches.suse/btrfs-use-mempools-for-delayed-refs: btrfs:
    Use mempools for delayed refs.
  - patches.suse/btrfs-panic-on-bad-rbtree-operations: btrfs:
    Panic on bad rbtree operations.
  - patches.suse/btrfs-simplify-btrfs_insert_root: btrfs: Simplify
    btrfs_insert_root.
  - patches.suse/btrfs-clear_extent_bit-api-change: btrfs: Remove
    set bits return from clear_extent_bit.
  - patches.suse/btrfs-convert_extent_bit-error-push-up: btrfs:
    convert_extent_bit error push-up.
  - patches.suse/btrfs-btrfs_update_root-error-push-up: btrfs:
    btrfs_update_root error push-up.
  - patches.suse/btrfs-_add_reloc_root-error-push-up: btrfs:
    __add_reloc_root error push-up.
  - patches.suse/btrfs-setup_items_for_insert-should-return-void:
    btrfs: setup_items_for_insert should return void.
  - patches.suse/btrfs-delayed-ref-mempool-functions-should-return-void:
    btrfs: Delayed ref mempool functions should return void.
  - patches.suse/btrfs-btrfs_inc_extent_ref-void-return-prep:
    btrfs: btrfs_inc_extent_ref void return prep.
  - patches.suse/btrfs-btrfs_free_extent-void-return-prep: btrfs:
    btrfs_free_extent void return prep.
  - patches.suse/btrfs-_btrfs_mod_ref-s-process_func-should-return-void:
    btrfs: __btrfs_mod_ref's process_func should return void.
  - patches.suse/btrfs-_btrfs_mod_ref-should-return-void: btrfs:
    __btrfs_mod_ref should return void.
  - patches.suse/btrfs-clean_tree_block-should-return-void: btrfs:
    clean_tree_block should return void.
  - patches.suse/btrfs-btrfs_truncate_item-should-return-void:
    btrfs: btrfs_truncate_item should return void.
  - patches.suse/btrfs-btrfs_extend_item-should-return-void: btrfs:
    btrfs_extend_item should return void.
  - patches.suse/btrfs-end_compressed_writeback-should-return-void:
    btrfs: end_compressed_writeback should return void.
  - patches.suse/btrfs-copy_for_split-should-return-void: btrfs:
    copy_for_split should return void.
  - patches.suse/btrfs-extent-tree-update_inline_extent_backref-should-return-void:
    btrfs: update_inline_extent_backref should return void.
  - patches.suse/btrfs-fix-kfree-of-member-instead-of-structure:
    btrfs: Fix kfree of member instead of structure.
* Fri Nov 11 2011 gregkh@suse.de
- patches.kernel.org/patch-3.0.8-9: Linux 3.0.9.
- patches.kernel.org/acpi-atomicio-convert-width-in-bits-to-bytes-in-__acpi_ioremap_fast.patch:
  Delete.
- patches.kernel.org/alsa-hda-add-new-revision-for-alc662.patch:
  Delete.
- patches.kernel.org/alsa-hda-add-support-for-92hd65-92hd66-family-of-codecs.patch:
  Delete.
- patches.kernel.org/alsa-hda-disable-power-widget-control-for-idt-92hd83-93.patch:
  Delete.
- patches.kernel.org/alsa-hda-fix-adc-input-amp-handling-for-cx20549-codec.patch:
  Delete.
- patches.kernel.org/alsa-hda-realtek-skip-invalid-digital-out-pins.patch:
  Delete.
- patches.kernel.org/alsa-hda-remove-bad-code-for-idt-92hd83-family-patch.patch:
  Delete.
- patches.kernel.org/alsa-ua101-fix-crash-when-unplugging.patch:
  Delete.
- patches.kernel.org/apic-i386-bigsmp-fix-false-warnings-regarding-logical-apic-id-mismatches.patch:
  Delete.
- patches.kernel.org/arm-mach-ux500-unlock-i-d-l2x0-caches-before-init.patch:
  Delete.
- patches.kernel.org/asix-simplify-condition-in-rx_fixup.patch:
  Delete.
- patches.kernel.org/asix-use-only-11-bits-of-header-for-data-size.patch:
  Delete.
- patches.kernel.org/asoc-ak4535-fixup-cache-register-table.patch:
  Delete.
- patches.kernel.org/asoc-ak4642-fixup-cache-register-table.patch:
  Delete.
- patches.kernel.org/asoc-ensure-the-wm8962-oscillator-and-plls-start-up-disabled.patch:
  Delete.
- patches.kernel.org/asoc-ensure-wm8962-pll-registers-are-reset.patch:
  Delete.
- patches.kernel.org/asoc-fix-a-bug-in-wm8962-dsp_a-and-dsp_b-settings.patch:
  Delete.
- patches.kernel.org/asoc-leave-input-audio-data-bit-length-settings-untouched-in-wm8711_set_dai_fmt.patch:
  Delete.
- patches.kernel.org/asoc-remove-direct-register-cache-accesses-from-wm8962.patch:
  Delete.
- patches.kernel.org/asoc-wm8711-fix-wrong-mask-for-setting-input-audio-data-bit-length-select.patch:
  Delete.
- patches.kernel.org/asoc-wm8741-fix-setting-interface-format-for-dsp-modes.patch:
  Delete.
- patches.kernel.org/asoc-wm8904-set-invert-bit-for-capture-switch.patch:
  Delete.
- patches.kernel.org/asoc-wm8940-properly-set-codec-dapm.bias_level.patch:
  Delete.
- patches.kernel.org/asoc-wm8994-use-snd_soc_dapm_aif_out-for-aif3-capture.patch:
  Delete.
- patches.kernel.org/ata_piix-make-dvd-drive-recognisable-on-systems-with-intel-sandybridge-chipsets-v2.patch:
  Delete.
- patches.kernel.org/ath9k-disable-unnecessary-phy-error-reporting.patch:
  Delete.
- patches.kernel.org/ath9k_htc-add-avm-fritz-wlan-11n-v2-support.patch:
  Delete.
- patches.kernel.org/ath9k_hw-fix-descriptor-status-of-txopexceeded.patch:
  Delete.
- patches.kernel.org/ath9k_hw-fix-magnitude-phase-coeff-correction.patch:
  Delete.
- patches.kernel.org/ath9k_hw-fix-number-of-gpio-pins-for-ar9287-9300.patch:
  Delete.
- patches.kernel.org/ath9k_hw-fix-regression-of-register-offset-for-ar9003-chips.patch:
  Delete.
- patches.kernel.org/ath9k_hw-update-ar9485-initvals-to-fix-system-hang-issue.patch:
  Delete.
- patches.kernel.org/binfmt_elf-fix-pie-execution-with-randomization-disabled.patch:
  Delete.
- patches.kernel.org/block-make-gendisk-hold-a-reference-to-its-queue.patch:
  Delete.
- patches.kernel.org/bluetooth-add-atheros-ar3012-one-pid-vid-supported.patch:
  Delete.
- patches.kernel.org/bluetooth-add-macbookair4-1-support.patch:
  Delete.
- patches.kernel.org/bluetooth-add-support-for-2011-mac-mini.patch:
  Delete.
- patches.kernel.org/bluetooth-add-toshiba-laptops-ar30xx-device-id.patch:
  Delete.
- patches.kernel.org/bonding-use-local-function-pointer-of-bond-recv_probe-in-bond_handle_frame.patch:
  Delete.
- patches.kernel.org/bridge-fix-hang-on-removal-of-bridge-via-netlink.patch:
  Delete.
- patches.kernel.org/bridge-leave-carrier-on-for-empty-bridge.patch:
  Delete.
- patches.kernel.org/btusb-add-device-entry-for-broadcom-softsailing.patch:
  Delete.
- patches.kernel.org/caif-fix-bug-with-network-namespaces.patch:
  Delete.
- patches.kernel.org/can-bcm-fix-incomplete-tx_setup-fix.patch:
  Delete.
- patches.kernel.org/can-bcm-fix-tx_setup-off-by-one-errors.patch:
  Delete.
- patches.kernel.org/carminefb-fix-module-parameters-permissions.patch:
  Delete.
- patches.kernel.org/cciss-add-small-delay-when-using-pci-power-management-to-reset-for-kump.patch:
  Delete.
- patches.kernel.org/ccwgroup-move-attributes-to-attribute-group.patch:
  Delete.
- patches.kernel.org/cifs-fix-dfs-handling-in-cifs_get_file_info.patch:
  Delete.
- patches.kernel.org/cifs-fix-incorrect-max-rfc1002-write-size-value.patch:
  Delete.
- patches.kernel.org/cris-fix-a-build-error-in-drivers-tty-serial-crisv10.c.patch:
  Delete.
- patches.kernel.org/crypto-cryptd-use-subsys_initcall-to-prevent-races-with-aesni.patch:
  Delete.
- patches.kernel.org/dib0700-protect-the-dib0700-buffer-access.patch:
  Delete.
- patches.kernel.org/dibcom-protect-the-i2c-bufer-access.patch:
  Delete.
- patches.kernel.org/dp83640-free-packet-queues-on-remove.patch:
  Delete.
- patches.kernel.org/dp83640-use-proper-function-to-free-transmit-time-stamping.patch:
  Delete.
- patches.kernel.org/drivers-net-rionet.c-fix-ethernet-address-macros-for-le-platforms.patch:
  Delete.
- patches.kernel.org/drivers-power-ds2780_battery.c-add-a-nolock-function-to-w1-interface.patch:
  Delete.
- patches.kernel.org/drivers-power-ds2780_battery.c-create-central-point-for-calling-w1-interface.patch:
  Delete.
- patches.kernel.org/drivers-power-ds2780_battery.c-fix-deadlock-upon-insertion-and-removal.patch:
  Delete.
- patches.kernel.org/drm-i915-panel-always-record-the-backlight-level-again-but-cleverly.patch:
  Delete.
- patches.kernel.org/drm-i915-wrap-dp-edid-fetch-functions-to-enable-edp-panel.patch:
  Delete.
- patches.kernel.org/drm-radeon-avoid-bouncing-connector-status-btw-disconnected-unknown.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-add-msi-module-parameter.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-add-msi-quirk-for-dell-rs690.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-add-msi-quirk-for-hp-rs690.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-bail-early-in-dvi_detect-for-digital-only-connectors.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-fix-i2c-mask-definitions.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-handle-force-case-in-connector-detect-more-gracefully.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-properly-set-panel-mode-for-edp.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-set-hpd-polarity-in-hpd_init.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-split-msi-check-into-a-separate-function.patch:
  Delete.
- patches.kernel.org/drm-radeon-set-hpd-polarity-at-init-time-so-hotplug-detect-works.patch:
  Delete.
- patches.kernel.org/ehci-introduce-a-common-ehci_setup.patch:
  Delete.
- patches.kernel.org/ehci-workaround-for-moschip-controller-bug.patch:
  Delete.
- patches.kernel.org/enic-bug-fix-fix-hardware-transmit-queue-indexing-in-enic_poll_controller.patch:
  Delete.
- patches.kernel.org/epoll-fix-spurious-lockdep-warnings.patch:
  Delete.
- patches.kernel.org/ext2-ext3-ext4-don-t-inherit-append_fl-or-immutable_fl-for-new-inodes.patch:
  Delete.
- patches.kernel.org/ext4-call-ext4_handle_dirty_metadata-with-correct-inode-in-ext4_dx_add_entry.patch:
  Delete.
- patches.kernel.org/ext4-ext4_mkdir-should-dirty-dir_block-with-newly-created-directory-inode.patch:
  Delete.
- patches.kernel.org/ext4-ext4_rename-should-dirty-dir_bh-with-the-correct-directory.patch:
  Delete.
- patches.kernel.org/ext4-fix-race-in-xattr-block-allocation-path.patch:
  Delete.
- patches.kernel.org/ext4-remove-i_mutex-lock-in-ext4_evict_inode-to-fix-lockdep-complaining.patch:
  Delete.
- patches.kernel.org/fb-avoid-possible-deadlock-caused-by-fb_set_suspend.patch:
  Delete.
- patches.kernel.org/fb-sh-mobile-fix-deadlock-risk-between-lock_fb_info-and-console_lock.patch:
  Delete.
- patches.kernel.org/fix-block-queue-and-elevator-memory-leak-in-scsi_alloc_sdev.patch:
  Delete.
- patches.kernel.org/genirq-add-irqf_resume_early-and-resume-such-irqs-earlier.patch:
  Delete.
- patches.kernel.org/hid-acrux-fix-enabling-force-feedback-support.patch:
  Delete.
- patches.kernel.org/hid-add-device-ids-for-macbook-pro-8-keyboards.patch:
  Delete.
- patches.kernel.org/hid-add-macbookair4-2-to-hid_have_special_driver.patch:
  Delete.
- patches.kernel.org/hid-add-support-for-huijia-usb-gamepad-connector.patch:
  Delete.
- patches.kernel.org/hid-add-support-for-macbookair4-2-keyboard.patch:
  Delete.
- patches.kernel.org/hid-add-support-for-new-revision-of-apple-aluminum-keyboard.patch:
  Delete.
- patches.kernel.org/hid-add-support-macbookair-4-1-keyboard.patch:
  Delete.
- patches.kernel.org/hid-apple-modern-macbook-airs-use-the-standard-apple-function-key-translations.patch:
  Delete.
- patches.kernel.org/hid-consolidate-macbookair-4-1-mappings.patch:
  Delete.
- patches.kernel.org/hid-hid-apple-add-device-id-of-another-wireless-aluminium.patch:
  Delete.
- patches.kernel.org/hid-hid-multitouch-add-lg-display-multitouch-device.patch:
  Delete.
- patches.kernel.org/hppfs-missing-include.patch: Delete.
- patches.kernel.org/hpsa-add-small-delay-when-using-pci-power-management-to-reset-for-kump.patch:
  Delete.
- patches.kernel.org/hwmon-coretemp-fix-for-non-smp-builds.patch:
  Delete.
- patches.kernel.org/hwmon-w83627ehf-fix-broken-driver-init.patch:
  Delete.
- patches.kernel.org/hwmon-w83627ehf-properly-report-peci-and-amd-si-sensor-types.patch:
  Delete.
- patches.kernel.org/hwspinlock-core-use-a-mutex-to-protect-the-radix-tree.patch:
  Delete.
- patches.kernel.org/io-mapping-ensure-io_mapping_map_atomic-_is_-atomic.patch:
  Delete.
- patches.kernel.org/iommu-amd-fix-wrong-shift-direction.patch:
  Delete.
- patches.kernel.org/ipheth-iphone-4-verizon-cdma-usb-product-id-add.patch:
  Delete.
- patches.kernel.org/ipr-always-initiate-hard-reset-in-kdump-kernel.patch:
  Delete.
- patches.kernel.org/ipv4-fix-ipsec-forward-performance-regression.patch:
  Delete.
- patches.kernel.org/ipv6-nullify-ipv6_ac_list-and-ipv6_fl_list-when-creating-new-socket.patch:
  Delete.
- patches.kernel.org/isci-fix-missed-unlock-in-apc_agent_timeout.patch:
  Delete.
- patches.kernel.org/isci-fix-support-for-large-smp-requests.patch:
  Delete.
- patches.kernel.org/iwlagn-do-not-use-interruptible-waits.patch:
  Delete.
- patches.kernel.org/jsm-remove-buggy-write-queue.patch: Delete.
- patches.kernel.org/kbuild-fix-help-text-not-displayed-in-choice-option.patch:
  Delete.
- patches.kernel.org/kmod-prevent-kmod_loop_msg-overflow-in-__request_module.patch:
  Delete.
- patches.kernel.org/kobj_uevent-ignore-if-some-listeners-cannot-handle-message.patch:
  Delete.
- patches.kernel.org/kvm-s390-check-cpu_id-prior-to-using-it.patch:
  Delete.
- patches.kernel.org/l2tp-fix-a-potential-skb-leak-in-l2tp_xmit_skb.patch:
  Delete.
- patches.kernel.org/leds-save-the-delay-values-after-a-successful-call-to-blink_set.patch:
  Delete.
- patches.kernel.org/leds-turn-the-blink_timer-off-before-starting-to-blink.patch:
  Delete.
- patches.kernel.org/libsas-set-sas_address-and-device-type-of-rphy.patch:
  Delete.
- patches.kernel.org/mac80211-config-hw-when-going-back-on-channel.patch:
  Delete.
- patches.kernel.org/mac80211-disable-powersave-for-broken-aps.patch:
  Delete.
- patches.kernel.org/mac80211-fix-offchannel-tx-cookie-matching.patch:
  Delete.
- patches.kernel.org/mac80211-fix-remain_off_channel-regression.patch:
  Delete.
- patches.kernel.org/macvlan-macvtap-fix-unicast-between-macvtap-interfaces-in-bridge-mode.patch:
  Delete.
- patches.kernel.org/maintaners-update-qualcomm-atheros-addresses.patch:
  Delete.
- patches.kernel.org/make-packet_statistics-getsockopt-report-consistently-between-ring-and-non-ring.patch:
  Delete.
- patches.kernel.org/make-scsi_free_queue-kill-pending-scsi-commands.patch:
  Delete.
- patches.kernel.org/md-raid5-fix-bug-that-could-result-in-reads-from-a-failed-device.patch:
  Delete.
- patches.kernel.org/megaraid_sas-fix-instance-access-in-megasas_reset_timer.patch:
  Delete.
- patches.kernel.org/memory-leak-with-rcu_table_free.patch:
  Delete.
- patches.kernel.org/mm-avoid-null-pointer-access-in-vm_struct-via-proc-vmallocinfo.patch:
  Delete.
- patches.kernel.org/mm-thp-tail-page-refcounting-fix.patch:
  Delete.
- patches.kernel.org/mmc-core-ext_csd.raw_-used-in-comparison-but-never-set.patch:
  Delete.
- patches.kernel.org/mmc-core-fix-hangs-related-to-insert-remove-of-cards.patch:
  Delete.
- patches.kernel.org/mpt2sas-fix-for-system-hang-when-discovery-in-progress.patch:
  Delete.
- patches.kernel.org/mtd-mtdchar-add-missing-initializer-on-raw-write.patch:
  Delete.
- patches.kernel.org/mtd-nand_base-always-initialise-oob_poi-before-writing-oob-data.patch:
  Delete.
- patches.kernel.org/mtd-provide-an-alias-for-the-redboot-module-name.patch:
  Delete.
- patches.kernel.org/mtd-pxa3xx_nand-fix-blank-page-ecc-mismatch.patch:
  Delete.
- patches.kernel.org/mtd-pxa3xx_nand-fix-nand-detection-issue.patch:
  Delete.
- patches.kernel.org/net-align-af-specific-flowi-structs-to-long.patch:
  Delete.
- patches.kernel.org/net-handle-different-key-sizes-between-address-families-in-flow-cache.patch:
  Delete.
- patches.kernel.org/net-hold-sock-reference-while-processing-tx-timestamps.patch:
  Delete.
- patches.kernel.org/net-unlock-sock-before-calling-sk_free.patch:
  Delete.
- patches.kernel.org/net-xen-netback-correctly-restart-tx-after-a-vm-restore-migrate.patch:
  Delete.
- patches.kernel.org/netconsole-enable-netconsole-can-make-net_device-refcnt-incorrent.patch:
  Delete.
- patches.kernel.org/netlink-validate-nla_msecs-length.patch:
  Delete.
- patches.kernel.org/nfs-don-t-redirty-inode-when-ncommit-0-in.patch:
  Delete.
- patches.kernel.org/nfs-don-t-try-to-migrate-pages-with-active-requests.patch:
  Delete.
- patches.kernel.org/nfs-sunrpc-don-t-use-a-credential-with-extra-groups.patch:
  Delete.
- patches.kernel.org/nfsd4-fix-open-downgrade-again.patch: Delete.
- patches.kernel.org/nfsd4-fix-seqid_mutating_error.patch: Delete.
- patches.kernel.org/nfsd4-ignore-want-bits-in-open-downgrade.patch:
  Delete.
- patches.kernel.org/nfsd4-permit-read-opens-of-executable-only-files.patch:
  Delete.
- patches.kernel.org/nfsd4-remove-check-for-a-32-bit-cookie-in-nfsd4_readdir.patch:
  Delete.
- patches.kernel.org/nfsd4-stop-using-nfserr_resource-for-transitory-errors.patch:
  Delete.
- patches.kernel.org/pci-quirk-mmc-always-check-for-lower-base-frequency-quirk-for-ricoh-1180-e823.patch:
  Delete.
- patches.kernel.org/perf-probe-fix-to-show-correct-error-string.patch:
  Delete.
- patches.kernel.org/plat-mxc-iomux-v3.h-implicitly-enable-pull-up-down-when-that-s-desired.patch:
  Delete.
- patches.kernel.org/platform-fix-error-path-in-samsung-laptop-init.patch:
  Delete.
- patches.kernel.org/platform-samsung_laptop-add-dmi-information-for-samsung.patch:
  Delete.
- patches.kernel.org/platform-samsung_laptop-add-support-for-x520-machines.patch:
  Delete.
- patches.kernel.org/platform-samsung_laptop-fix-samsung-brightness-min-max.patch:
  Delete.
- patches.kernel.org/platform-samsung_laptop-samsung-backlight-for-r528-r728.patch:
  Delete.
- patches.kernel.org/pm-runtime-automatically-retry-failed-autosuspends.patch:
  Delete.
- patches.kernel.org/pm-suspend-off-by-one-in-pm_suspend.patch:
  Delete.
- patches.kernel.org/powerpc-eeh-fix-proc-ppc64-eeh-creation.patch:
  Delete.
- patches.kernel.org/powerpc-fix-deadlock-in-icswx-code.patch:
  Delete.
- patches.kernel.org/powerpc-fix-oops-when-echoing-bad-values-to-sys-devices-system-memory-probe.patch:
  Delete.
- patches.kernel.org/powerpc-get_hugepte-don-t-put_page-the-wrong-page.patch:
  Delete.
- patches.kernel.org/powerpc-gup_huge_pmd-return-0-if-pte-changes.patch:
  Delete.
- patches.kernel.org/powerpc-gup_hugepte-avoid-freeing-the-head-page-too-many-times.patch:
  Delete.
- patches.kernel.org/powerpc-gup_hugepte-support-thp-based-tail-recounting.patch:
  Delete.
- patches.kernel.org/powerpc-numa-remove-double-of_node_put-in-hot_add_node_scn_to_nid.patch:
  Delete.
- patches.kernel.org/powerpc-pseries-avoid-spurious-error-during-hotplug-cpu-add.patch:
  Delete.
- patches.kernel.org/powerpc-remove-superfluous-pagetail-checks-on-the-pte-gup_fast.patch:
  Delete.
- patches.kernel.org/proc-self-numa_maps-restore-huge-tag-for-hugetlb-vmas.patch:
  Delete.
- patches.kernel.org/ptrace-don-t-clear-group_stop_sigmask-on-double-stop.patch:
  Delete.
- patches.kernel.org/qe-fhci-fixed-the-control-bug.patch: Delete.
- patches.kernel.org/readlinkat-ensure-we-return-enoent-for-the-empty-pathname-for-normal-lookups.patch:
  Delete.
- patches.kernel.org/revert-nfs-ensure-that-writeback_single_inode-calls-write_inode-when-syncing.patch:
  Delete.
- patches.kernel.org/rtl8150-rtl8150_disconnect-...-does-not-need-tasklet_disable.patch:
  Delete.
- patches.kernel.org/rtnetlink-add-missing-manual-netlink-notification-in.patch:
  Delete.
- patches.kernel.org/s390-gup_huge_pmd-return-0-if-pte-changes.patch:
  Delete.
- patches.kernel.org/s390-gup_huge_pmd-support-thp-tail-recounting.patch:
  Delete.
- patches.kernel.org/scsi_dh-check-queuedata-pointer-before-proceeding-further.patch:
  Delete.
- patches.kernel.org/serial-core-power-up-uart-port-early-before-we-do-set_termios-when-resuming.patch:
  Delete.
- patches.kernel.org/serial-pxa-work-around-for-errata-20.patch:
  Delete.
- patches.kernel.org/st-fix-race-in-st_scsi_execute_end.patch:
  Delete.
- patches.kernel.org/staging-hv-add-support-for-2-tb-lun-in-storage-driver.patch:
  Delete.
- patches.kernel.org/staging-quatech_usb2-potential-lost-wakeup-scenario-in-tiocmiwait.patch:
  Delete.
- patches.kernel.org/staging-serqt_usb2-remove-ssu100-from-supported-devices.patch:
  Delete.
- patches.kernel.org/target-fix-report-target-port-groups-handling-with-small-allocation-length.patch:
  Delete.
- patches.kernel.org/tcm_loop-add-explict-read-buffer-memset-for-scf_scsi_control_sg_io_cdb.patch:
  Delete.
- patches.kernel.org/tcp-properly-handle-md5sig_pool-references.patch:
  Delete.
- patches.kernel.org/tcp-properly-update-lost_cnt_hint-during-shifting.patch:
  Delete.
- patches.kernel.org/tg3-negate-use_phylib-flag-check.patch:
  Delete.
- patches.kernel.org/thp-share-get_huge_page_tail.patch: Delete.
- patches.kernel.org/time-change-jiffies_to_clock_t-argument-type-to-unsigned-long.patch:
  Delete.
- patches.kernel.org/tracing-fix-returning-of-duplicate-data-after-eof-in-trace_pipe_raw.patch:
  Delete.
- patches.kernel.org/tty-drop-driver-reference-in-tty_open-fail-path.patch:
  Delete.
- patches.kernel.org/tty-make-tty_add_file-non-failing.patch:
  Delete.
- patches.kernel.org/tty-pty-release-tty-in-all-ptmx_open-fail-paths.patch:
  Delete.
- patches.kernel.org/tuner_xc2028-allow-selection-of-the-frequency-adjustment-code-for-xc3028.patch:
  Delete.
- patches.kernel.org/um-fix-ubd-cow-size.patch: Delete.
- patches.kernel.org/update-email-address-for-stable-patch-submission.patch:
  Delete.
- patches.kernel.org/usb-add-quirk-for-logitech-c300-web-cam.patch:
  Delete.
- patches.kernel.org/usb-add-reset_resume-for-webcams-shown-to-be-quirky.patch:
  Delete.
- patches.kernel.org/usb-avoid-null-pointer-deref-in-usb_hcd_alloc_bandwidth.patch:
  Delete.
- patches.kernel.org/usb-cdc-acm-owen-si-30-support.patch: Delete.
- patches.kernel.org/usb-core-devio.c-check-for-printer-class-specific-request.patch:
  Delete.
- patches.kernel.org/usb-ehci-fix-test-mode-sequence.patch:
  Delete.
- patches.kernel.org/usb-fix-ehci-alignment-error.patch: Delete.
- patches.kernel.org/usb-fix-runtime-wakeup-on-ohci.patch: Delete.
- patches.kernel.org/usb-for-usb_autopm_get_interface_async-einprogress-is-not-an-error.patch:
  Delete.
- patches.kernel.org/usb-ftdi_sio-add-pid-for-sony-ericsson-urban.patch:
  Delete.
- patches.kernel.org/usb-ftdi_sio-support-ti-luminary-micro-stellaris-bd-icdi.patch:
  Delete.
- patches.kernel.org/usb-g_printer-fix-bug-in-unregistration.patch:
  Delete.
- patches.kernel.org/usb-isp1760-added-missing-call-to-usb_hcd_check_unlink_urb-during-unlink.patch:
  Delete.
- patches.kernel.org/usb-option-add-various-zte-device-network-interfaces-to.patch:
  Delete.
- patches.kernel.org/usb-option-add-zte-product-0x0037-to-sendsetup-blacklist.patch:
  Delete.
- patches.kernel.org/usb-option-convert-huawei-k3765-k4505-k4605-reservered.patch:
  Delete.
- patches.kernel.org/usb-option-convert-interface-blacklisting-to-bitfields.patch:
  Delete.
- patches.kernel.org/usb-pid_ns-ensure-pid-is-not-freed-during.patch:
  Delete.
- patches.kernel.org/usb-pl2303-add-id-for-smart-device.patch:
  Delete.
- patches.kernel.org/usb-qcserial-add-device-id-for-hp-un2430-mobile-broadband-module.patch:
  Delete.
- patches.kernel.org/usb-qcserial-add-support-for-sierra-wireless-mc8355-gobi-3000.patch:
  Delete.
- patches.kernel.org/usb-serial-add-device-id-for-sierra-wireless-mc8305.patch:
  Delete.
- patches.kernel.org/usb-serial-add-pid-0xf7c0-to-ftdi-sio-driver-for-a-zeitcontrol-device.patch:
  Delete.
- patches.kernel.org/usb-storage-use-normalized-sense-when-emulating-autosense.patch:
  Delete.
- patches.kernel.org/usb-update-last_busy-time-after-autosuspend-fails.patch:
  Delete.
- patches.kernel.org/usb-xhci-prevent-infinite-loop-when-processing-mse-event.patch:
  Delete.
- patches.kernel.org/usb_storage-don-t-freeze-in-usb-stor-scan.patch:
  Delete.
- patches.kernel.org/usbmon-vs.-tcpdump-fix-dropped-packet-count.patch:
  Delete.
- patches.kernel.org/usbnet-cdc_ncm-don-t-use-stack-variables-for-dma.patch:
  Delete.
- patches.kernel.org/user-per-registers-vs.-ptrace-single-stepping.patch:
  Delete.
- patches.kernel.org/uvcvideo-set-alternate-setting-0-on-resume-if-the-bus-has-been-reset.patch:
  Delete.
- patches.kernel.org/vfs-add-device-tag-to-proc-self-mountstats.patch:
  Delete.
- patches.kernel.org/vfs-automount-should-ignore-lookup_follow.patch:
  Delete.
- patches.kernel.org/vfs-fix-automount-for-negative-autofs-dentries.patch:
  Delete.
- patches.kernel.org/vfs-fix-statfs-automounter-semantics-regression.patch:
  Delete.
- patches.kernel.org/vfs-fix-the-remaining-automounter-semantics-regressions.patch:
  Delete.
- patches.kernel.org/vfs-pathname-lookup-add-lookup_automount-flag.patch:
  Delete.
- patches.kernel.org/vfs-show-o_cloexe-bit-properly-in-proc-pid-fdinfo-fd-files.patch:
  Delete.
- patches.kernel.org/vfs-we-need-to-set-lookup_jumped-on-mountpoint-crossing.patch:
  Delete.
- patches.kernel.org/viafb-improve-pitch-handling.patch: Delete.
- patches.kernel.org/viafb-use-display-information-in-info-not-in-var-for.patch:
  Delete.
- patches.kernel.org/wl12xx-fix-forced-passive-scans.patch:
  Delete.
- patches.kernel.org/wmi-properly-cleanup-devices-to-avoid-crashes.patch:
  Delete.
- patches.kernel.org/x86-fix-compilation-bug-in-kprobes-twobyte_is_boostable.patch:
  Delete.
- patches.kernel.org/x86-uv2-workaround-for-uv2-hub-bug-system-global-address-format.patch:
  Delete.
- patches.kernel.org/xen-blkback-report-vbd_wsect-wr_sect-properly.patch:
  Delete.
- patches.kernel.org/xen-pcifront-update-warning-comment-to-use-e820_host.patch:
  Delete.
- patches.kernel.org/xen-swiotlb-fix-wrong-panic.patch: Delete.
- patches.kernel.org/xhci-amd-isoc-link-trb-chain-bit-quirk.patch:
  Delete.
- patches.kernel.org/xhci-clear-plc-for-usb2-root-hub-ports.patch:
  Delete.
- patches.kernel.org/xhci-if-no-endpoints-changed-don-t-issue-bw-command.patch:
  Delete.
- patches.kernel.org/xhci-mem.c-check-for-ring-first_seg-null.patch:
  Delete.
- patches.kernel.org/xhci-test-and-clear-rwc-bit.patch: Delete.
* Fri Nov 11 2011 jjolly@suse.de
- patches.arch/s390-40-01-ap-process-requestq.patch: ap:
  Setup timer for processing messages in request queue
  (bnc#729840,LTC#76476).
* Fri Nov 11 2011 jjolly@suse.de
- patches.arch/s390-vmlinux-note-header.patch: incorrect note
  program header.
* Fri Nov 11 2011 dsterba@suse.cz
  patches up to 3.2-rc2
- patches.suse/btrfs-0240-handle-bio_add_page-failure-gracefully-in-scru.patch:
  Btrfs: handle bio_add_page failure gracefully in scrub
  (FATE#306586).
* Fri Nov 11 2011 dsterba@suse.cz
- patches.suse/btrfs-0214-Moved-repair-code-from-inode.c-to-extent_io.c.patch:
  Refresh.
- patches.suse/btrfs-0224-fix-double-free-tree_root-in-btrfs_mount.patch:
  Refresh.
- patches.suse/btrfs-0225-fix-oops-on-NULL-trans-handle-in-btrfs_truncat.patch:
  Btrfs: fix oops on NULL trans handle in btrfs_truncate
  (FATE#306586).
- patches.suse/btrfs-0226-fix-our-reservations-for-updating-an-inode-whe.patch:
  Btrfs: fix our reservations for updating an inode when
  completing io (FATE#306586).
- patches.suse/btrfs-0227-fix-memory-leak-in-btrfs_parse_early_options.patch:
  Btrfs: fix memory leak in btrfs_parse_early_options()
  (FATE#306586).
- patches.suse/btrfs-0228-fix-subvol_name-leak-on-error-in-btrfs_mount.patch:
  Btrfs: fix subvol_name leak on error in btrfs_mount()
  (FATE#306586).
- patches.suse/btrfs-0229-avoid-null-dereference-and-leaks-when-bailing-.patch:
  Btrfs: avoid null dereference and leaks when bailing from
  open_ctree() (FATE#306586).
- patches.suse/btrfs-0230-close-devices-on-all-error-paths-in-open_ctree.patch:
  Btrfs: close devices on all error paths in open_ctree()
  (FATE#306586).
- patches.suse/btrfs-0231-rework-error-handling-in-btrfs_mount.patch:
  Btrfs: rework error handling in btrfs_mount() (FATE#306586).
- patches.suse/btrfs-0232-tweak-the-delayed-inode-reservations-again.patch:
  Btrfs: tweak the delayed inode reservations again (FATE#306586).
- patches.suse/btrfs-0233-fix-nocow-when-deleting-the-item.patch:
  Btrfs: fix nocow when deleting the item (FATE#306586).
- patches.suse/btrfs-0234-fix-no-reserved-space-for-writing-out-inode-ca.patch:
  Btrfs: fix no reserved space for writing out inode cache
  (FATE#306586).
- patches.suse/btrfs-0235-fix-unreleased-path-in-btrfs_orphan_cleanup.patch:
  Btrfs: fix unreleased path in btrfs_orphan_cleanup()
  (FATE#306586).
- patches.suse/btrfs-0236-Abstract-similar-code-for-btrfs_block_rsv_add-.patch:
  Btrfs: Abstract similar code for btrfs_block_rsv_add{, _noflush}
  (FATE#306586).
- patches.suse/btrfs-0237-fix-orphan-backref-nodes.patch: Btrfs:
  fix orphan backref nodes (FATE#306586).
- patches.suse/btrfs-0238-only-map-pages-if-we-know-we-need-them-when-re.patch:
  Btrfs: only map pages if we know we need them when reading
  the space cache (FATE#306586).
- patches.suse/btrfs-0239-fix-deadlock-caused-by-the-race-between-reloca.patch:
  Btrfs: fix deadlock caused by the race between relocation
  (FATE#306586).
- patches.suse/btrfs-push-up-unlock_extent-errors-to-callers:
  Refresh.
* Fri Nov 11 2011 dsterba@suse.cz
- patches.suse/btrfs-8019-Free-inode-mutex-on-lseek-error.patch:
  Delete.
* Fri Nov 11 2011 tiwai@suse.de
- patches.drivers/i915-Fix-opregion-notifications: i915: Fix
  opregion notifications (bnc#647567).
- patches.suse/acpi-video-switch-option: Delete.  Replaced with
  the upstream fix.
* Thu Nov 10 2011 mhocko@suse.cz
- patches.fixes/Documentation-update-cgroups-notes.patch:
  Documentation: update cgroups notes (bnc#724133).
* Thu Nov 10 2011 hare@suse.de
- patches.fixes/dm-mpath-reset-map_pointer-on-requeue: dm-mpath:
  Reset map pointer when requeing.
* Thu Nov 10 2011 hare@suse.de
- patches.fixes/scsi-set-queuedata-to-NULL.patch: SCSI: set
  queuedata to NULL before calling scsi_free_queue() (bnc#729548).
* Thu Nov 10 2011 tiwai@suse.de
- patches.drivers/drm-i915-fix-ELD-writing-for-SandyBridge:
  drm/i915: fix ELD writing for SandyBridge (bnc#722560).
* Thu Nov 10 2011 tiwai@suse.de
- patches.drivers/lis3lv02d-avoid-divide-by-zero-due-to-unchecked:
  lis3lv02d: avoid divide by zero due to unchecked (bnc#728035).
- patches.drivers/lis3lv02d-Avoid-zero-division: Delete.  Replaced
  with the upstream fix.
* Thu Nov 10 2011 mhocko@suse.cz
- patches.suse/pagecache-limit-warn-on-usage.patch: Warn on
  pagecache limit usage (FATE309111).
* Wed Nov  9 2011 gregkh@suse.de
- Final 3.0.9 patchset
- patches.drivers/USB3-0144-xHCI-set-link-state.patch: Refresh.
- patches.drivers/target-0008-target-More-core-cleanups-from-AGrover-round-2.patch:
  Refresh.
- patches.kernel.org/acpi-atomicio-convert-width-in-bits-to-bytes-in-__acpi_ioremap_fast.patch:
  ACPI atomicio: Convert width in bits to bytes in
  __acpi_ioremap_fast().
- patches.kernel.org/alsa-hda-add-support-for-92hd65-92hd66-family-of-codecs.patch:
  ALSA: hda - Add support for 92HD65 / 92HD66 family of codecs.
- patches.kernel.org/alsa-hda-disable-power-widget-control-for-idt-92hd83-93.patch:
  ALSA: hda - Disable power-widget control for IDT 92HD83/93
  as default.
- patches.kernel.org/alsa-hda-realtek-skip-invalid-digital-out-pins.patch:
  ALSA: hda/realtek - Skip invalid digital out pins.
- patches.kernel.org/alsa-ua101-fix-crash-when-unplugging.patch:
  ALSA: ua101: fix crash when unplugging.
- patches.kernel.org/asix-simplify-condition-in-rx_fixup.patch:
  ASIX: Simplify condition in rx_fixup().
- patches.kernel.org/asix-use-only-11-bits-of-header-for-data-size.patch:
  ASIX: Use only 11 bits of header for data size.
- patches.kernel.org/asoc-ensure-the-wm8962-oscillator-and-plls-start-up-disabled.patch:
  ASoC: Ensure the WM8962 oscillator and PLLs start up disabled.
- patches.kernel.org/asoc-ensure-wm8962-pll-registers-are-reset.patch:
  ASoC: Ensure WM8962 PLL registers are reset.
- patches.kernel.org/asoc-leave-input-audio-data-bit-length-settings-untouched-in-wm8711_set_dai_fmt.patch:
  ASoC: Leave input audio data bit length settings untouched
  in wm8711_set_dai_fmt.
- patches.kernel.org/asoc-wm8711-fix-wrong-mask-for-setting-input-audio-data-bit-length-select.patch:
  ASoC: wm8711: Fix wrong mask for setting input audio data bit
  length select.
- patches.kernel.org/asoc-wm8904-set-invert-bit-for-capture-switch.patch:
  ASoC: WM8904: Set `invert' bit for Capture Switch.
- patches.kernel.org/ath9k_hw-fix-regression-of-register-offset-for-ar9003-chips.patch:
  ath9k_hw: Fix regression of register offset for AR9003 chips.
- patches.kernel.org/ath9k_hw-update-ar9485-initvals-to-fix-system-hang-issue.patch:
  ath9k_hw: Update AR9485 initvals to fix system hang issue.
- patches.kernel.org/block-make-gendisk-hold-a-reference-to-its-queue.patch:
  block: make gendisk hold a reference to its queue.
- patches.kernel.org/bluetooth-add-atheros-ar3012-one-pid-vid-supported.patch:
  Bluetooth: Add Atheros AR3012 one PID/VID supported.
- patches.kernel.org/bluetooth-add-macbookair4-1-support.patch:
  Bluetooth: Add MacBookAir4,1 support.
- patches.kernel.org/bluetooth-add-support-for-2011-mac-mini.patch:
  Bluetooth: add support for 2011 mac mini.
- patches.kernel.org/bluetooth-add-toshiba-laptops-ar30xx-device-id.patch:
  Bluetooth: Add Toshiba laptops AR30XX device ID.
- patches.kernel.org/bridge-leave-carrier-on-for-empty-bridge.patch:
  bridge: leave carrier on for empty bridge.
- patches.kernel.org/btusb-add-device-entry-for-broadcom-softsailing.patch:
  btusb: add device entry for Broadcom SoftSailing.
- patches.kernel.org/can-bcm-fix-incomplete-tx_setup-fix.patch:
  can bcm: fix incomplete tx_setup fix.
- patches.kernel.org/cciss-add-small-delay-when-using-pci-power-management-to-reset-for-kump.patch:
  cciss: add small delay when using PCI Power Management to
  reset for kump.
- patches.kernel.org/crypto-cryptd-use-subsys_initcall-to-prevent-races-with-aesni.patch:
  crypto: cryptd - Use subsys_initcall to prevent races with
  aesni.
- patches.kernel.org/dp83640-use-proper-function-to-free-transmit-time-stamping.patch:
  dp83640: use proper function to free transmit time stamping
  packets.
- patches.kernel.org/drm-i915-wrap-dp-edid-fetch-functions-to-enable-edp-panel.patch:
  Refresh.
- patches.kernel.org/drm-radeon-avoid-bouncing-connector-status-btw-disconnected-unknown.patch:
  drm/radeon: avoid bouncing connector status btw disconnected
  & unknown.
- patches.kernel.org/drm-radeon-kms-add-msi-module-parameter.patch:
  drm/radeon/kms: add MSI module parameter.
- patches.kernel.org/drm-radeon-kms-add-msi-quirk-for-dell-rs690.patch:
  drm/radeon/kms: Add MSI quirk for Dell RS690.
- patches.kernel.org/drm-radeon-kms-add-msi-quirk-for-hp-rs690.patch:
  drm/radeon/kms: Add MSI quirk for HP RS690.
- patches.kernel.org/drm-radeon-kms-properly-set-panel-mode-for-edp.patch:
  drm/radeon/kms: properly set panel mode for eDP.
- patches.kernel.org/drm-radeon-kms-set-hpd-polarity-in-hpd_init.patch:
  drm/radeon/kms: set HPD polarity in hpd_init().
- patches.kernel.org/drm-radeon-kms-split-msi-check-into-a-separate-function.patch:
  drm/radeon/kms: split MSI check into a separate function.
- patches.kernel.org/drm-radeon-set-hpd-polarity-at-init-time-so-hotplug-detect-works.patch:
  drm/radeon: set hpd polarity at init time so hotplug detect
  works.
- patches.kernel.org/ext4-remove-i_mutex-lock-in-ext4_evict_inode-to-fix-lockdep-complaining.patch:
  ext4: remove i_mutex lock in ext4_evict_inode to fix lockdep
  complaining.
- patches.kernel.org/fix-block-queue-and-elevator-memory-leak-in-scsi_alloc_sdev.patch:
  Fix block queue and elevator memory leak in scsi_alloc_sdev.
- patches.kernel.org/hid-add-device-ids-for-macbook-pro-8-keyboards.patch:
  HID: Add device IDs for Macbook Pro 8 keyboards.
- patches.kernel.org/hid-add-macbookair4-2-to-hid_have_special_driver.patch:
  HID: add MacBookAir4,2 to hid_have_special_driver.
- patches.kernel.org/hid-add-support-for-huijia-usb-gamepad-connector.patch:
  HID: add support for HuiJia USB Gamepad connector.
- patches.kernel.org/hid-add-support-for-macbookair4-2-keyboard.patch:
  HID: add support for MacBookAir4,2 keyboard.
- patches.kernel.org/hid-add-support-for-new-revision-of-apple-aluminum-keyboard.patch:
  HID: add support for new revision of Apple aluminum keyboard.
- patches.kernel.org/hid-add-support-macbookair-4-1-keyboard.patch:
  HID: Add support MacbookAir 4,1 keyboard.
- patches.kernel.org/hid-apple-modern-macbook-airs-use-the-standard-apple-function-key-translations.patch:
  hid/apple: modern macbook airs use the standard apple function
  key translations.
- patches.kernel.org/hid-consolidate-macbookair-4-1-mappings.patch:
  HID: consolidate MacbookAir 4,1 mappings.
- patches.kernel.org/hid-hid-apple-add-device-id-of-another-wireless-aluminium.patch:
  HID: hid-apple: add device ID of another wireless aluminium.
- patches.kernel.org/hid-hid-multitouch-add-lg-display-multitouch-device.patch:
  HID: hid-multitouch: Add LG Display Multitouch device.
- patches.kernel.org/hpsa-add-small-delay-when-using-pci-power-management-to-reset-for-kump.patch:
  hpsa: add small delay when using PCI Power Management to reset
  for kump.
- patches.kernel.org/hwmon-coretemp-fix-for-non-smp-builds.patch:
  hwmon: (coretemp) Fix for non-SMP builds.
- patches.kernel.org/hwmon-w83627ehf-fix-broken-driver-init.patch:
  hwmon: (w83627ehf) Fix broken driver init.
- patches.kernel.org/hwmon-w83627ehf-properly-report-peci-and-amd-si-sensor-types.patch:
  hwmon: (w83627ehf) Properly report PECI and AMD-SI sensor types.
- patches.kernel.org/ipheth-iphone-4-verizon-cdma-usb-product-id-add.patch:
  ipheth: iPhone 4 Verizon CDMA USB Product ID add.
- patches.kernel.org/kbuild-fix-help-text-not-displayed-in-choice-option.patch:
  kbuild: Fix help text not displayed in choice option.
- patches.kernel.org/mac80211-config-hw-when-going-back-on-channel.patch:
  mac80211: config hw when going back on-channel.
- patches.kernel.org/mac80211-disable-powersave-for-broken-aps.patch:
  mac80211: disable powersave for broken APs.
- patches.kernel.org/mac80211-fix-remain_off_channel-regression.patch:
  mac80211: fix remain_off_channel regression.
- patches.kernel.org/make-scsi_free_queue-kill-pending-scsi-commands.patch:
  Make scsi_free_queue() kill pending SCSI commands.
- patches.kernel.org/mpt2sas-fix-for-system-hang-when-discovery-in-progress.patch:
  mpt2sas: Fix for system hang when discovery in progress.
- patches.kernel.org/mtd-mtdchar-add-missing-initializer-on-raw-write.patch:
  mtd: mtdchar: add missing initializer on raw write.
- patches.kernel.org/mtd-nand_base-always-initialise-oob_poi-before-writing-oob-data.patch:
  mtd: nand_base: always initialise oob_poi before writing
  OOB data.
- patches.kernel.org/mtd-provide-an-alias-for-the-redboot-module-name.patch:
  mtd: provide an alias for the redboot module name.
- patches.kernel.org/mtd-pxa3xx_nand-fix-blank-page-ecc-mismatch.patch:
  mtd: pxa3xx_nand: Fix blank page ECC mismatch.
- patches.kernel.org/mtd-pxa3xx_nand-fix-nand-detection-issue.patch:
  mtd: pxa3xx_nand: fix nand detection issue.
- patches.kernel.org/net-align-af-specific-flowi-structs-to-long.patch:
  net: Align AF-specific flowi structs to long.
- patches.kernel.org/net-handle-different-key-sizes-between-address-families-in-flow-cache.patch:
  net: Handle different key sizes between address families in
  flow cache.
- patches.kernel.org/net-unlock-sock-before-calling-sk_free.patch:
  net: Unlock sock before calling sk_free().
- patches.kernel.org/netlink-validate-nla_msecs-length.patch:
  netlink: validate NLA_MSECS length.
- patches.kernel.org/nfs-don-t-redirty-inode-when-ncommit-0-in.patch:
  Refresh.
- patches.kernel.org/nfs-sunrpc-don-t-use-a-credential-with-extra-groups.patch:
  NFS/sunrpc: don't use a credential with extra groups.
- patches.kernel.org/platform-samsung_laptop-add-dmi-information-for-samsung.patch:
  Refresh.
- patches.kernel.org/platform-samsung_laptop-fix-samsung-brightness-min-max.patch:
  Refresh.
- patches.kernel.org/pm-runtime-automatically-retry-failed-autosuspends.patch:
  PM / Runtime: Automatically retry failed autosuspends.
- patches.kernel.org/pm-suspend-off-by-one-in-pm_suspend.patch:
  PM / Suspend: Off by one in pm_suspend().
- patches.kernel.org/powerpc-eeh-fix-proc-ppc64-eeh-creation.patch:
  powerpc/eeh: Fix /proc/ppc64/eeh creation.
- patches.kernel.org/powerpc-fix-deadlock-in-icswx-code.patch:
  powerpc: Fix deadlock in icswx code.
- patches.kernel.org/powerpc-fix-oops-when-echoing-bad-values-to-sys-devices-system-memory-probe.patch:
  powerpc: Fix oops when echoing bad values to
  /sys/devices/system/memory/probe.
- patches.kernel.org/powerpc-get_hugepte-don-t-put_page-the-wrong-page.patch:
  powerpc: get_hugepte() don't put_page() the wrong page.
- patches.kernel.org/powerpc-gup_huge_pmd-return-0-if-pte-changes.patch:
  powerpc: gup_huge_pmd() return 0 if pte changes.
- patches.kernel.org/powerpc-gup_hugepte-avoid-freeing-the-head-page-too-many-times.patch:
  powerpc: gup_hugepte() avoid freeing the head page too many
  times.
- patches.kernel.org/powerpc-gup_hugepte-support-thp-based-tail-recounting.patch:
  powerpc: gup_hugepte() support THP based tail recounting.
- patches.kernel.org/powerpc-numa-remove-double-of_node_put-in-hot_add_node_scn_to_nid.patch:
  powerpc/numa: Remove double of_node_put in
  hot_add_node_scn_to_nid.
- patches.kernel.org/powerpc-pseries-avoid-spurious-error-during-hotplug-cpu-add.patch:
  powerpc/pseries: Avoid spurious error during hotplug CPU add.
- patches.kernel.org/powerpc-remove-superfluous-pagetail-checks-on-the-pte-gup_fast.patch:
  powerpc: remove superfluous PageTail checks on the pte gup_fast.
- patches.kernel.org/revert-nfs-ensure-that-writeback_single_inode-calls-write_inode-when-syncing.patch:
  Refresh.
- patches.kernel.org/rtl8150-rtl8150_disconnect-...-does-not-need-tasklet_disable.patch:
  rtl8150: rtl8150_disconnect(...) does not need
  tasklet_disable(...).
- patches.kernel.org/s390-gup_huge_pmd-return-0-if-pte-changes.patch:
  s390: gup_huge_pmd() return 0 if pte changes.
- patches.kernel.org/s390-gup_huge_pmd-support-thp-tail-recounting.patch:
  s390: gup_huge_pmd() support THP tail recounting.
- patches.kernel.org/scsi_dh-check-queuedata-pointer-before-proceeding-further.patch:
  scsi_dh: check queuedata pointer before proceeding further.
- patches.kernel.org/st-fix-race-in-st_scsi_execute_end.patch:
  st: fix race in st_scsi_execute_end.
- patches.kernel.org/tcm_loop-add-explict-read-buffer-memset-for-scf_scsi_control_sg_io_cdb.patch:
  tcm_loop: Add explict read buffer memset for
  SCF_SCSI_CONTROL_SG_IO_CDB.
- patches.kernel.org/thp-share-get_huge_page_tail.patch: thp:
  share get_huge_page_tail().
- patches.kernel.org/usb-avoid-null-pointer-deref-in-usb_hcd_alloc_bandwidth.patch:
  USB: Avoid NULL pointer deref in usb_hcd_alloc_bandwidth.
- patches.kernel.org/usb-ehci-fix-test-mode-sequence.patch: USB:
  EHCI: Fix test mode sequence.
- patches.kernel.org/usb-ftdi_sio-support-ti-luminary-micro-stellaris-bd-icdi.patch:
  Refresh.
- patches.kernel.org/usb-isp1760-added-missing-call-to-usb_hcd_check_unlink_urb-during-unlink.patch:
  usb/isp1760: Added missing call to usb_hcd_check_unlink_urb()
  during unlink.
- patches.kernel.org/usb-option-add-various-zte-device-network-interfaces-to.patch:
  Refresh.
- patches.kernel.org/usb-option-convert-huawei-k3765-k4505-k4605-reservered.patch:
  Refresh.
- patches.kernel.org/usb-pid_ns-ensure-pid-is-not-freed-during.patch:
  Refresh.
- patches.kernel.org/usb-serial-add-device-id-for-sierra-wireless-mc8305.patch:
  USB: Serial: Add device ID for Sierra Wireless MC8305.
- patches.kernel.org/usb-serial-add-pid-0xf7c0-to-ftdi-sio-driver-for-a-zeitcontrol-device.patch:
  USB: Serial: Add PID(0xF7C0) to FTDI SIO driver for a
  zeitcontrol-device.
- patches.kernel.org/usb-update-last_busy-time-after-autosuspend-fails.patch:
  USB: Update last_busy time after autosuspend fails.
- patches.kernel.org/usb-xhci-prevent-infinite-loop-when-processing-mse-event.patch:
  USB: xHCI: prevent infinite loop when processing MSE event.
- patches.kernel.org/usb_storage-don-t-freeze-in-usb-stor-scan.patch:
  usb_storage: Don't freeze in usb-stor-scan.
- patches.kernel.org/usbnet-cdc_ncm-don-t-use-stack-variables-for-dma.patch:
  usbnet/cdc_ncm: Don't use stack variables for DMA.
- patches.kernel.org/vfs-fix-statfs-automounter-semantics-regression.patch:
  VFS: fix statfs() automounter semantics regression.
- patches.kernel.org/vfs-we-need-to-set-lookup_jumped-on-mountpoint-crossing.patch:
  VFS: we need to set LOOKUP_JUMPED on mountpoint crossing.
- patches.kernel.org/xen-blkback-report-vbd_wsect-wr_sect-properly.patch:
  xen/blkback: Report VBD_WSECT (wr_sect) properly.
- patches.kernel.org/xen-pcifront-update-warning-comment-to-use-e820_host.patch:
  Refresh.
- patches.kernel.org/xhci-clear-plc-for-usb2-root-hub-ports.patch:
  xHCI: Clear PLC for USB2 root hub ports.
- patches.kernel.org/xhci-if-no-endpoints-changed-don-t-issue-bw-command.patch:
  xhci: If no endpoints changed, don't issue BW command.
- patches.kernel.org/xhci-test-and-clear-rwc-bit.patch: xHCI:
  test and clear RWC bit.
- patches.arch/ppc-fix-oops-on-wrong-memory-probe: Delete.
- patches.drivers/0001-btusb-add-device-entry-for-Broadcom-SoftSailing.patch:
  Delete.
- patches.drivers/USB3-0087-xhci-If-no-endpoints-changed-don-t-issue-BW-command.patch:
  Delete.
- patches.drivers/USB3-0132-ASIX-Simplify-condition-in-rx_fixup.patch:
  Delete.
- patches.drivers/USB3-0133-ASIX-Use-only-11-bits-of-header-for-data-size.patch:
  Delete.
- patches.drivers/USB3-0145-xHCI-test-and-clear-RWC-bit.patch:
  Delete.
- patches.drivers/USB3-0146-rtl8150-rtl8150_disconnect-.-does-not-need-tasklet_disable.patch:
  Delete.
- patches.drivers/USB3-0146-xHCI-Clear-PLC-for-USB2-root-hub-ports.patch:
  Delete.
- patches.drivers/USB3-0155-USB-EHCI-Fix-test-mode-sequence.patch:
  Delete.
- patches.drivers/USB3-0156-usb-isp1760-Added-missing-call-to-usb_hcd_check_unlink_urb-d.patch:
  Delete.
- patches.drivers/USB3-0169-USB-Serial-Add-device-ID-for-Sierra-Wireless-MC8305.patch:
  Delete.
- patches.drivers/USB3-0170-USB-Serial-Add-PID-0xF7C0-to-FTDI-SIO-driver-for-a-zeitcontr.patch:
  Delete.
- patches.drivers/USB3-0187-usbnet-cdc_ncm-Don-t-use-stack-variables-for-DMA.patch:
  Delete.
- patches.drivers/USB3-0188-USB-Avoid-NULL-pointer-deref-in-usb_hcd_alloc_bandwidth.patch:
  Delete.
- patches.drivers/USB3-0197-ipheth-iPhone-4-Verizon-CDMA-USB-Product-ID-add.patch:
  Delete.
- patches.drivers/USB3-0199-USB-xHCI-prevent-infinite-loop-when-processing-MSE-event.patch:
  Delete.
- patches.fixes/rpc-cred-test: Delete.
- patches.fixes/scsi-fix-block-queue-and-elevator-mem-leak:
  Delete.
- patches.fixes/scsi-make-scsi-free-kill-pending-scmds.patch:
  Delete.
- patches.fixes/scsi_dh-check-queuedata-pointer.patch: Delete.
- patches.fixes/st-fix-race-in-st_scsi_execute_end.patch: Delete.
- patches.kernel.org/proc-fix-races-against-execve-of-proc-pid-fd.patch:
  Delete.
* Wed Nov  9 2011 mfasheh@suse.com
- patches.suse/btrfs-0001-Don-t-BUG_ON-errors-from-btrfs_create_subvol_r.patch:
  Refresh.
- patches.suse/btrfs-0005-Don-t-BUG_ON-errors-in-__finish_chunk_alloc.patch:
  Refresh.
- patches.suse/btrfs-0010-go-readonly-on-insert-error-in-btrfs_add_root_.patch:
  Refresh.
* Wed Nov  9 2011 jbohac@suse.cz
- patches.fixes/vlan-allow-nested-vlan_do_receive.patch: vlan:
  allow nested vlan_do_receive() (bnc#728597).
* Wed Nov  9 2011 jbohac@suse.cz
- patches.fixes/vlan-allow-nested-vlan_do_receive.patch:
  (bnc#728597).
* Wed Nov  9 2011 jbohac@suse.cz
- supported.conf:
  * added xt_CONNSECMARK, removed by mistake in a2a68b74
* Wed Nov  9 2011 jbohac@suse.cz
- patches.suse/ebt_vlan-dummy-debug-option.patch: ebt_vlan:
  add a dummy debug option (bnc#720451).
* Tue Nov  8 2011 jjolly@suse.de
- patches.drivers/mlx4_en-0001-fix-endianness-with-blue-frame-support.patch:
  mlx4_en: fix endianness with blue frame support (bnc#727611).
* Tue Nov  8 2011 tonyj@suse.de
- Fix compile error when CONFIG_DEBUG_RODATA=n (bnc#725836)
  patches.suse/x86-mark_rodata_rw.patch: Refresh.
  patches.suse/perf-0278-x86-Fix-redefinition-of-mark_rodata_ro-compile-error.patch: Delete.
* Tue Nov  8 2011 hare@suse.de
- patches.fixes/scsi-silencing-killing-requests-for-dead-queue:
  scsi: silencing 'killing requests for dead queue'.
* Tue Nov  8 2011 dsterba@suse.cz
  updates up to 3.2-rc1
- patches.suse/btrfs-0110-move-stuff-around-in-btrfs_inode-to-get-better.patch:
  Btrfs: move stuff around in btrfs_inode to get better packing
  (FATE#306586).
- patches.suse/btrfs-0111-kill-reserved_bytes-in-inode.patch:
  Btrfs: kill reserved_bytes in inode (FATE#306586).
- patches.suse/btrfs-0112-use-d_obtain_alias-when-mounting-subvol-subvol.patch:
  Btrfs: use d_obtain_alias when mounting subvol/subvolid
  (FATE#306586).
- patches.suse/btrfs-0113-fix-how-we-mount-subvol-whatever.patch:
  Btrfs: fix how we mount subvol=<whatever> (FATE#306586).
- patches.suse/btrfs-0114-use-bytes_may_use-for-all-ENOSPC-reservations.patch:
  Btrfs: use bytes_may_use for all ENOSPC reservations
  (FATE#306586).
- patches.suse/btrfs-0115-skip-looking-for-delalloc-if-we-don-t-have-fil.patch:
  Btrfs: skip looking for delalloc if we don't have
  - >fill_delalloc (FATE#306586).
- patches.suse/btrfs-0116-calculate-checksum-space-correctly.patch:
  Btrfs: calculate checksum space correctly (FATE#306586).
- patches.suse/btrfs-0117-kill-the-orphan-space-calculation-for-snapshot.patch:
  Btrfs: kill the orphan space calculation for snapshots
  (FATE#306586).
- patches.suse/btrfs-0118-kill-the-durable-block-rsv-stuff.patch:
  Btrfs: kill the durable block rsv stuff (FATE#306586).
- patches.suse/btrfs-0119-fix-how-we-reserve-space-for-deleting-inodes.patch:
  Btrfs: fix how we reserve space for deleting inodes
  (FATE#306586).
- patches.suse/btrfs-0120-ratelimit-the-generation-printk-for-the-free-s.patch:
  Btrfs: ratelimit the generation printk for the free space cache
  (FATE#306586).
- patches.suse/btrfs-0121-kill-unused-parts-of-block_rsv.patch:
  Btrfs: kill unused parts of block_rsv (FATE#306586).
- patches.suse/btrfs-0122-don-t-try-to-commit-in-btrfs_block_rsv_check.patch:
  Btrfs: don't try to commit in btrfs_block_rsv_check
  (FATE#306586).
- patches.suse/btrfs-0123-optimize-how-we-account-for-space-in-truncate.patch:
  Btrfs: optimize how we account for space in truncate
  (FATE#306586).
- patches.suse/btrfs-0124-kill-btrfs_truncate_reserve_metadata.patch:
  Btrfs: kill btrfs_truncate_reserve_metadata (FATE#306586).
- patches.suse/btrfs-0125-only-reserve-space-in-fallocate-if-we-have-to-.patch:
  Btrfs: only reserve space in fallocate if we have to do a
  preallocate (FATE#306586).
- patches.suse/btrfs-0126-reduce-the-amount-of-space-needed-for-truncate.patch:
  Btrfs: reduce the amount of space needed for truncates
  (FATE#306586).
- patches.suse/btrfs-0127-allow-callers-to-specify-if-flushing-can-occur.patch:
  Btrfs: allow callers to specify if flushing can occur for
  btrfs_block_rsv_check (FATE#306586).
- patches.suse/btrfs-0128-fix-call-to-btrfs_search_slot-in-free-space-ca.patch:
  Btrfs: fix call to btrfs_search_slot in free space cache
  (FATE#306586).
- patches.suse/btrfs-0129-fix-space-leak-when-we-fail-to-make-an-allocat.patch:
  Btrfs: fix space leak when we fail to make an allocation
  (FATE#306586).
- patches.suse/btrfs-0130-don-t-increase-the-block_rsv-s-size-when-emerg.patch:
  Btrfs: don't increase the block_rsv's size when emergency
  allocating space (FATE#306586).
- patches.suse/btrfs-0131-set-truncate-block-rsv-s-size.patch:
  Btrfs: set truncate block rsv's size (FATE#306586).
- patches.suse/btrfs-0132-put-the-block-group-cache-after-we-commit-the-.patch:
  Btrfs: put the block group cache after we commit the super
  (FATE#306586).
- patches.suse/btrfs-0133-handle-enospc-accounting-for-free-space-inodes.patch:
  Btrfs: handle enospc accounting for free space inodes
  (FATE#306586).
- patches.suse/btrfs-0134-use-the-transactions-block_rsv-for-the-csum-ro.patch:
  Btrfs: use the transactions block_rsv for the csum root
  (FATE#306586).
- patches.suse/btrfs-0135-don-t-get-the-block_rsv-in-btrfs_free_tree_blo.patch:
  Btrfs: don't get the block_rsv in btrfs_free_tree_block
  (FATE#306586).
- patches.suse/btrfs-0136-stop-passing-a-trans-handle-all-around-the-res.patch:
  Btrfs: stop passing a trans handle all around the reservation
  code (FATE#306586).
- patches.suse/btrfs-0137-make-sure-to-unset-trans-block_rsv-before-runn.patch:
  Btrfs: make sure to unset trans->block_rsv before running
  delayed refs (FATE#306586).
- patches.suse/btrfs-0138-delay-iput-when-deleting-a-block-group.patch:
  Btrfs: delay iput when deleting a block group (FATE#306586).
- patches.suse/btrfs-0139-use-the-inode-s-mapping-mask-for-allocating-pa.patch:
  Btrfs: use the inode's mapping mask for allocating pages
  (FATE#306586).
- patches.suse/btrfs-0140-fix-orphan-cleanup-regression.patch:
  Btrfs: fix orphan cleanup regression (FATE#306586).
- patches.suse/btrfs-0141-check-unused-against-how-much-space-we-actuall.patch:
  Btrfs: check unused against how much space we actually want
  (FATE#306586).
- patches.suse/btrfs-0142-introduce-convert_extent_bit.patch:
  Btrfs: introduce convert_extent_bit (FATE#306586).
- patches.suse/btrfs-0143-stop-using-write_one_page.patch: Btrfs:
  stop using write_one_page (FATE#306586).
- patches.suse/btrfs-0144-use-the-global-reserve-as-a-backup-for-deletin.patch:
  Btrfs: use the global reserve as a backup for deleting inodes
  (FATE#306586).
- patches.suse/btrfs-0145-break-out-of-orphan-cleanup-if-we-can-t-make-p.patch:
  Btrfs: break out of orphan cleanup if we can't make progress
  (FATE#306586).
- patches.suse/btrfs-0146-allow-us-to-overcommit-our-enospc-reservations.patch:
  Btrfs: allow us to overcommit our enospc reservations
  (FATE#306586).
- patches.suse/btrfs-0147-only-inherit-btrfs-specific-flags-when-creatin.patch:
  Btrfs: only inherit btrfs specific flags when creating files
  (FATE#306586).
- patches.suse/btrfs-0148-introduce-mount-option-no_space_cache.patch:
  Btrfs: introduce mount option no_space_cache (FATE#306586).
- patches.suse/btrfs-0149-don-t-skip-writing-out-a-empty-block-groups-ca.patch:
  Btrfs: don't skip writing out a empty block groups cache
  (FATE#306586).
- patches.suse/btrfs-0150-add-a-io_ctl-struct-and-helpers-for-dealing-wi.patch:
  Btrfs: add a io_ctl struct and helpers for dealing with the
  space cache (FATE#306586).
- patches.suse/btrfs-0151-check-the-return-value-of-filemap_write_and_wa.patch:
  Btrfs: check the return value of filemap_write_and_wait in
  the space cache (FATE#306586).
- patches.suse/btrfs-0152-take-overflow-into-account-in-reserving-space.patch:
  Btrfs: take overflow into account in reserving space
  (FATE#306586).
- patches.suse/btrfs-0153-inline-checksums-into-the-disk-free-space-cach.patch:
  Btrfs: inline checksums into the disk free space cache
  (FATE#306586).
- patches.suse/btrfs-0154-wait-for-ordered-extents-if-we-didn-t-reclaim-.patch:
  Btrfs: wait for ordered extents if we didn't reclaim enough
  (FATE#306586).
- patches.suse/btrfs-0155-fix-the-amount-of-space-reserved-for-unlink.patch:
  Btrfs: fix the amount of space reserved for unlink
  (FATE#306586).
- patches.suse/btrfs-0156-fix-regression-in-re-setting-a-large-xattr.patch:
  Btrfs: fix regression in re-setting a large xattr (FATE#306586).
- patches.suse/btrfs-0157-don-t-check-bytes_pinned-to-determine-if-we-sh.patch:
  Btrfs: don't check bytes_pinned to determine if we should
  commit the transaction (FATE#306586).
- patches.suse/btrfs-0158-wait-for-ordered-extents-if-we-re-in-trouble-w.patch:
  Btrfs: wait for ordered extents if we're in trouble when
  shrinking delalloc (FATE#306586).
- patches.suse/btrfs-0159-allow-shrink_delalloc-flush-the-needed-reclaim.patch:
  Btrfs: allow shrink_delalloc flush the needed reclaimed pages
  (FATE#306586).
- patches.suse/btrfs-0160-release-trans-metadata-bytes-before-flushing-d.patch:
  Btrfs: release trans metadata bytes before flushing delayed refs
  (FATE#306586).
- patches.suse/btrfs-0161-reserve-some-space-for-an-orphan-item-when-unl.patch:
  Btrfs: reserve some space for an orphan item when unlinking
  (FATE#306586).
- patches.suse/btrfs-0162-seperate-out-btrfs_block_rsv_check-out-into-2-.patch:
  Btrfs: seperate out btrfs_block_rsv_check out into 2 different
  functions (FATE#306586).
- patches.suse/btrfs-0163-if-we-have-a-lot-of-pinned-space-commit-the-tr.patch:
  Btrfs: if we have a lot of pinned space, commit the transaction
  (FATE#306586).
- patches.suse/btrfs-0164-don-t-flush-the-cache-inode-before-writing-it.patch:
  Btrfs: don't flush the cache inode before writing it
  (FATE#306586).
- patches.suse/btrfs-0165-check-file-extent-backref-offset-underflow.patch:
  btrfs: check file extent backref offset underflow (FATE#306586).
- patches.suse/btrfs-0166-fix-memory-leak-in-btrfs_defrag_file.patch:
  btrfs: fix memory leak in btrfs_defrag_file (FATE#306586).
- patches.suse/btrfs-0167-fix-defragmentation-regression.patch:
  Btrfs: fix defragmentation regression (FATE#306586).
- patches.suse/btrfs-0168-use-i_size_read-in-btrfs_defrag_file.patch:
  Btrfs: use i_size_read() in btrfs_defrag_file() (FATE#306586).
- patches.suse/btrfs-0169-fix-wrong-max_to_defrag-in-btrfs_defrag_file.patch:
  Btrfs: fix wrong max_to_defrag in btrfs_defrag_file()
  (FATE#306586).
- patches.suse/btrfs-0170-trivial-fix-a-potential-memory-leak-in-btrfs_p.patch:
  btrfs: trivial fix, a potential memory leak in
  btrfs_parse_early_options() (FATE#306586).
- patches.suse/btrfs-0171-honor-extent-thresh-during-defragmentation.patch:
  Btrfs: honor extent thresh during defragmentation (FATE#306586).
- patches.suse/btrfs-0172-return-EINVAL-if-start-total_bytes-in-fitrim-i.patch:
  btrfs: return EINVAL if start > total_bytes in fitrim ioctl
  (FATE#306586).
- patches.suse/btrfs-0173-fix-array-bound-checking.patch: Btrfs:
  fix array bound checking (FATE#306586).
- patches.suse/btrfs-0174-remove-BUG_ON-in-compress_file_range.patch:
  Btrfs: remove BUG_ON() in compress_file_range() (FATE#306586).
- patches.suse/btrfs-0175-fix-direct-io-vs-nodatacow.patch:
  Btrfs: fix direct-io vs nodatacow (FATE#306586).
- patches.suse/btrfs-0176-do-not-set-EXTENT_DIRTY-along-with-EXTENT_DELA.patch:
  Btrfs: do not set EXTENT_DIRTY along with EXTENT_DELALLOC
  (FATE#306586).
- patches.suse/btrfs-0177-pass-the-correct-root-to-lookup_free_space_ino.patch:
  Btrfs: pass the correct root to lookup_free_space_inode()
  (FATE#306586).
- patches.suse/btrfs-0178-fix-return-value-of-btrfs_get_acl.patch:
  Btrfs: fix return value of btrfs_get_acl() (FATE#306586).
- patches.suse/btrfs-0179-fix-race-between-multi-task-space-allocation-a.patch:
  Btrfs: fix race between multi-task space allocation and caching
  space (FATE#306586).
- patches.suse/btrfs-0180-fix-oops-on-failure-path.patch: btrfs:
  fix oops on failure path (FATE#306586).
- patches.suse/btrfs-0181-fix-a-bug-when-opening-seed-devices.patch:
  Btrfs: fix a bug when opening seed devices (FATE#306586).
- patches.suse/btrfs-0182-close-all-bdevs-on-mount-failure.patch:
  Btrfs: close all bdevs on mount failure (FATE#306586).
- patches.suse/btrfs-0183-do-not-allow-mounting-non-subvolumes-via-subvo.patch:
  btrfs: do not allow mounting non-subvolumes via subvol option
  (FATE#306586).
- patches.suse/btrfs-0184-ratelimit-WARN_ON-in-use_block_rsv.patch:
  btrfs: ratelimit WARN_ON in use_block_rsv (FATE#306586).
- patches.suse/btrfs-0185-don-t-wait-as-long-for-more-batches-during-SSD.patch:
  Btrfs: don't wait as long for more batches during SSD log commit
  (FATE#306586).
- patches.suse/btrfs-0186-make-sure-btrfs_remove_free_space-doesn-t-leak.patch:
  Btrfs: make sure btrfs_remove_free_space doesn't leak EAGAIN
  (FATE#306586).
- patches.suse/btrfs-0187-fix-extent-pinning-bugs-in-the-tree-log.patch:
  Btrfs: fix extent pinning bugs in the tree log (FATE#306586).
- patches.suse/btrfs-0188-make-sure-to-flush-queued-bios-if-write_cache_.patch:
  Btrfs: make sure to flush queued bios if write_cache_pages waits
  (FATE#306586).
- patches.suse/btrfs-0189-release-metadata-from-global-reserve-if-we-hav.patch:
  Btrfs: release metadata from global reserve if we have to
  fallback for unlink (FATE#306586).
- patches.suse/btrfs-0190-use-the-global-reserve-when-truncating-the-fre.patch:
  Btrfs: use the global reserve when truncating the free space
  cache inode (FATE#306586).
- patches.suse/btrfs-0191-separate-superblock-items-out-of-fs_info.patch:
  btrfs: separate superblock items out of fs_info (FATE#306586).
- patches.suse/btrfs-0192-add-a-log-of-past-tree-roots.patch:
  Btrfs: add a log of past tree roots (FATE#306586).
- patches.suse/btrfs-0193-make-a-delayed_block_rsv-for-the-delayed-item-.patch:
  Btrfs: make a delayed_block_rsv for the delayed item insertion
  (FATE#306586).
- patches.suse/btrfs-0194-be-smarter-about-committing-the-transaction-in.patch:
  Btrfs: be smarter about committing the transaction in
  reserve_metadata_bytes (FATE#306586).
- patches.suse/btrfs-0195-ClearPageError-during-writepage-and-clean_tree.patch:
  Btrfs: ClearPageError during writepage and clean_tree_block
  (FATE#306586).
- patches.suse/btrfs-0196-fix-delayed-insertion-reservation.patch:
  Btrfs: fix delayed insertion reservation (FATE#306586).
- patches.suse/btrfs-0197-add-an-extra-wait-mode-to-read_extent_buffer_p.patch:
  btrfs: add an extra wait mode to read_extent_buffer_pages
  (FATE#306586).
- patches.suse/btrfs-0198-add-READAHEAD-extent-buffer-flag.patch:
  btrfs: add READAHEAD extent buffer flag (FATE#306586).
- patches.suse/btrfs-0199-state-information-for-readahead.patch:
  btrfs: state information for readahead (FATE#306586).
- patches.suse/btrfs-0200-initial-readahead-code-and-prototypes.patch:
  btrfs: initial readahead code and prototypes (FATE#306586).
- patches.suse/btrfs-0201-hooks-for-readahead.patch: btrfs:
  hooks for readahead (FATE#306586).
- patches.suse/btrfs-0202-use-readahead-API-for-scrub.patch:
  btrfs: use readahead API for scrub (FATE#306586).
- patches.suse/btrfs-0203-added-helper-functions-to-iterate-backrefs.patch:
  btrfs: added helper functions to iterate backrefs (FATE#306586).
- patches.suse/btrfs-0204-scrub-added-unverified_errors.patch:
  btrfs scrub: added unverified_errors (FATE#306586).
- patches.suse/btrfs-0205-scrub-print-paths-of-corrupted-files.patch:
  btrfs scrub: print paths of corrupted files (FATE#306586).
- patches.suse/btrfs-0206-scrub-bugfix-mirror_num-off-by-one.patch:
  btrfs scrub: bugfix: mirror_num off by one (FATE#306586).
- patches.suse/btrfs-0207-add-mirror_num-to-extent_read_full_page.patch:
  btrfs: add mirror_num to extent_read_full_page (FATE#306586).
- patches.suse/btrfs-0208-scrub-use-int-for-mirror_num-not-u64.patch:
  btrfs scrub: use int for mirror_num, not u64 (FATE#306586).
- patches.suse/btrfs-0209-scrub-add-fixup-code-for-errors-on-nodatasum-f.patch:
  btrfs scrub: add fixup code for errors on nodatasum files
  (FATE#306586).
- patches.suse/btrfs-0210-new-ioctls-to-do-logical-inode-and-inode-path-.patch:
  btrfs: new ioctls to do logical->inode and inode->path resolving
  (FATE#306586).
- patches.suse/btrfs-0211-btrfs_multi_bio-replaced-with-btrfs_bio.patch:
  btrfs: btrfs_multi_bio replaced with btrfs_bio (FATE#306586).
- patches.suse/btrfs-0212-Do-not-use-bio-bi_bdev-after-submission.patch:
  btrfs: Do not use bio->bi_bdev after submission (FATE#306586).
- patches.suse/btrfs-0213-Put-mirror_num-in-bi_bdev.patch: btrfs:
  Put mirror_num in bi_bdev (FATE#306586).
- patches.suse/btrfs-0214-Moved-repair-code-from-inode.c-to-extent_io.c.patch:
  btrfs: Moved repair code from inode.c to extent_io.c
  (FATE#306586).
- patches.suse/btrfs-0215-integrating-raid-repair-and-scrub-fixup-nodata.patch:
  btrfs: integrating raid-repair and scrub-fixup-nodatasum
  (FATE#306586).
- patches.suse/btrfs-0216-fix-the-new-inspection-ioctls-for-32-bit-compa.patch:
  Btrfs: fix the new inspection ioctls for 32 bit compat
  (FATE#306586).
- patches.suse/btrfs-0217-fix-extent_buffer-leak-in-the-metadata-IO-erro.patch:
  Btrfs: fix extent_buffer leak in the metadata IO error handling
  (FATE#306586).
- patches.suse/btrfs-0218-stop-the-readahead-threads-on-failed-mount.patch:
  Btrfs: stop the readahead threads on failed mount (FATE#306586).
- patches.suse/btrfs-0219-stop-leaking-btrfs_bios-on-readahead.patch:
  Btrfs: stop leaking btrfs_bios on readahead (FATE#306586).
- patches.suse/btrfs-0221-fix-a-potential-btrfs_bio-leak-on-scrub-fixups.patch:
  Btrfs: fix a potential btrfs_bio leak on scrub fixups
  (FATE#306586).
- patches.suse/btrfs-0222-fix-race-during-transaction-joins.patch:
  Btrfs: fix race during transaction joins (FATE#306586).
- patches.suse/btrfs-0223-check-for-a-null-fs-root-when-writing-to-the-b.patch:
  Btrfs: check for a null fs root when writing to the backup
  root log (FATE#306586).
- patches.suse/btrfs-0224-fix-double-free-tree_root-in-btrfs_mount.patch:
  btrfs: fix double-free 'tree_root' in 'btrfs_mount()'.
- patches.suse/btrfs-add-btrfs_panic: Refresh.
- patches.suse/btrfs-extent_io-return-void: Refresh.
- patches.suse/btrfs-extent_tree-void-functions: Refresh.
- patches.suse/btrfs-push-up-btrfs_pin_extent-failures: Refresh.
- patches.suse/btrfs-push-up-clear_extent_bit-errors-to-callers:
  Refresh.
- patches.suse/btrfs-push-up-set_extent_bit-errors-to-callers:
  Refresh.
- patches.suse/btrfs-push-up-submit_bio_hook-failures: Refresh.
- patches.suse/btrfs-0901-move-stuff-around-in-btrfs_inode-to-get-better.patch:
  Delete.
- patches.suse/btrfs-0902-kill-reserved_bytes-in-inode.patch:
  Delete.
- patches.suse/btrfs-0903-use-d_obtain_alias-when-mounting-subvol-subvol.patch:
  Delete.
- patches.suse/btrfs-0904-fix-how-we-mount-subvol-whatever.patch:
  Delete.
- patches.suse/btrfs-0905-use-bytes_may_use-for-all-ENOSPC-reservations.patch:
  Delete.
- patches.suse/btrfs-0906-skip-looking-for-delalloc-if-we-don-t-have-fil.patch:
  Delete.
- patches.suse/btrfs-0907-calculate-checksum-space-correctly.patch:
  Delete.
- patches.suse/btrfs-0908-kill-the-orphan-space-calculation-for-snapshot.patch:
  Delete.
- patches.suse/btrfs-0909-kill-the-durable-block-rsv-stuff.patch:
  Delete.
- patches.suse/btrfs-0910-fix-how-we-reserve-space-for-deleting-inodes.patch:
  Delete.
- patches.suse/btrfs-0911-ratelimit-the-generation-printk-for-the-free-s.patch:
  Delete.
- patches.suse/btrfs-0912-kill-unused-parts-of-block_rsv.patch:
  Delete.
- patches.suse/btrfs-0913-don-t-try-to-commit-in-btrfs_block_rsv_check.patch:
  Delete.
- patches.suse/btrfs-0914-optimize-how-we-account-for-space-in-truncate.patch:
  Delete.
- patches.suse/btrfs-0915-kill-btrfs_truncate_reserve_metadata.patch:
  Delete.
- patches.suse/btrfs-0916-only-reserve-space-in-fallocate-if-we-have-to-.patch:
  Delete.
- patches.suse/btrfs-0918-reduce-the-amount-of-space-needed-for-truncate.patch:
  Delete.
- patches.suse/btrfs-0919-allow-callers-to-specify-if-flushing-can-occur.patch:
  Delete.
- patches.suse/btrfs-0920-fix-call-to-btrfs_search_slot-in-free-space-ca.patch:
  Delete.
- patches.suse/btrfs-0921-fix-space-leak-when-we-fail-to-make-an-allocat.patch:
  Delete.
- patches.suse/btrfs-0922-don-t-increase-the-block_rsv-s-size-when-emerg.patch:
  Delete.
- patches.suse/btrfs-0923-set-truncate-block-rsv-s-size.patch:
  Delete.
- patches.suse/btrfs-0924-put-the-block-group-cache-after-we-commit-the-.patch:
  Delete.
- patches.suse/btrfs-0925-handle-enospc-accounting-for-free-space-inodes.patch:
  Delete.
- patches.suse/btrfs-0926-use-the-transactions-block_rsv-for-the-csum-ro.patch:
  Delete.
- patches.suse/btrfs-0927-don-t-get-the-block_rsv-in-btrfs_free_tree_blo.patch:
  Delete.
- patches.suse/btrfs-0928-stop-passing-a-trans-handle-all-around-the-res.patch:
  Delete.
- patches.suse/btrfs-0929-make-sure-to-unset-trans-block_rsv-before-runn.patch:
  Delete.
- patches.suse/btrfs-0930-delay-iput-when-deleting-a-block-group.patch:
  Delete.
- patches.suse/btrfs-0931-use-the-inode-s-mapping-mask-for-allocating-pa.patch:
  Delete.
- patches.suse/btrfs-0932-fix-orphan-cleanup-regression.patch:
  Delete.
- patches.suse/btrfs-0932-use-the-inode-s-mapping-mask-for-allocating-pa.patch:
  Delete.
- patches.suse/btrfs-0933-check-unused-against-how-much-space-we-actuall.patch:
  Delete.
- patches.suse/btrfs-0934-introduce-convert_extent_bit.patch:
  Delete.
- patches.suse/btrfs-0935-stop-using-write_one_page.patch: Delete.
- patches.suse/btrfs-0936-use-the-global-reserve-as-a-backup-for-deletin.patch:
  Delete.
- patches.suse/btrfs-0937-break-out-of-orphan-cleanup-if-we-can-t-make-p.patch:
  Delete.
- patches.suse/btrfs-0938-allow-us-to-overcommit-our-enospc-reservations.patch:
  Delete.
- patches.suse/btrfs-0939-only-inherit-btrfs-specific-flags-when-creatin.patch:
  Delete.
- patches.suse/btrfs-0940-introduce-mount-option-no_space_cache.patch:
  Delete.
- patches.suse/btrfs-0941-don-t-skip-writing-out-a-empty-block-groups-ca.patch:
  Delete.
- patches.suse/btrfs-0942-add-a-io_ctl-struct-and-helpers-for-dealing-wi.patch:
  Delete.
- patches.suse/btrfs-0943-check-the-return-value-of-filemap_write_and_wa.patch:
  Delete.
- patches.suse/btrfs-0944-take-overflow-into-account-in-reserving-space.patch:
  Delete.
- patches.suse/btrfs-0945-inline-checksums-into-the-disk-free-space-cach.patch:
  Delete.
- patches.suse/btrfs-0946-wait-for-ordered-extents-if-we-didn-t-reclaim-.patch:
  Delete.
- patches.suse/btrfs-0947-fix-the-amount-of-space-reserved-for-unlink.patch:
  Delete.
- patches.suse/btrfs-8003-check-file-extent-backref-offset-underflow.patch:
  Delete.
- patches.suse/btrfs-8004-fix-memory-leak-in-btrfs_defrag_file.patch:
  Delete.
- patches.suse/btrfs-8005-fix-defragmentation-regression.patch:
  Delete.
- patches.suse/btrfs-8006-use-i_size_read-in-btrfs_defrag_file.patch:
  Delete.
- patches.suse/btrfs-8007-fix-wrong-max_to_defrag-in-btrfs_defrag_file.patch:
  Delete.
- patches.suse/btrfs-8008-honor-extent-thresh-during-defragmentation.patch:
  Delete.
- patches.suse/btrfs-8009-return-EINVAL-if-start-total_bytes-in-fitrim-i.patch:
  Delete.
- patches.suse/btrfs-8010-fix-array-bound-checking.patch: Delete.
- patches.suse/btrfs-8011-remove-BUG_ON-in-compress_file_range.patch:
  Delete.
- patches.suse/btrfs-8012-fix-direct-io-vs-nodatacow.patch:
  Delete.
- patches.suse/btrfs-8013-fix-race-between-multi-task-space-allocation-a.patch:
  Delete.
- patches.suse/btrfs-8014-trivial-fix-a-potential-memory-leak-in-btrfs_p.patch:
  Delete.
- patches.suse/btrfs-8017-ratelimit-WARN_ON-in-use_block_rsv.patch:
  Delete.
- patches.suse/btrfs-8018-ratelimit-WARN_ON-before-iput-in-orphan-cleanu.patch:
  Delete.
- patches.suse/btrfs-8020-do-not-set-EXTENT_DIRTY-along-with-EXTENT_DELA.patch:
  Delete.
- patches.suse/btrfs-8021-pass-the-correct-root-to-lookup_free_space_ino.patch:
  Delete.
- patches.suse/btrfs-8023-fix-return-value-of-btrfs_get_acl.patch:
  Delete.
- patches.suse/btrfs-8024-fix-oops-on-failure-path.patch: Delete.
- patches.suse/btrfs-do-not-allow-mounting-non-subvolumes-via-subvol.patch:
  Delete.
* Tue Nov  8 2011 jbeulich@novell.com
- patches.xen/xen3-x86_do_not_set_nvs_ram_busy.patch: x86:
  allow NVS can be accessed by driver (bnc#725592).
- Refresh other Xen patches.
* Tue Nov  8 2011 hare@suse.de
- patches.fixes/scsi-fix-block-queue-and-elevator-mem-leak:
  Set queuedata to NULL before calling scsi_free_queue().
* Mon Nov  7 2011 jdelvare@suse.de
- patches.fixes/hpwdt_fix_BIOS_calls_under_NX.patch:
  watchdog/hpwdt: Allow BIOS calls when NX is enabled
  (bnc#720674).
* Mon Nov  7 2011 jdelvare@suse.de
- patches.fixes/hpwdt_fix_BIOS_calls_under_NX.patch:
  watchdog/hpwdt: Allow BIOS calls when NX is enabled
  (bnc#720674
  ).
* Mon Nov  7 2011 jlee@suse.com
- patches.drivers/0001-tg3-fix-tigon3_dma_hwbug_workaround.patch:
  tg3: fix tigon3_dma_hwbug_workaround().
- patches.drivers/0002-tg3-Fix-4k-tx-bd-segmentation-code.patch:
  tg3: Fix 4k tx bd segmentation code.
- patches.drivers/0003-tg3-Obtain-PCI-function-number-from-device.patch:
  tg3: Obtain PCI function number from device.
- patches.drivers/0004-tg3-Fix-4k-skb-error-recovery-path.patch:
  tg3: Fix 4k skb error recovery path.
- patches.drivers/0005-tg3-Fix-irq-alloc-error-cleanup-path.patch:
  tg3: Fix irq alloc error cleanup path.
* Mon Nov  7 2011 jack@suse.cz
- patches.suse/ext3-increase-reservation-window.patch: ext3:
  Increase maximum reservation window (bnc#716023).
* Mon Nov  7 2011 jack@suse.cz
- patches.fixes/st-fix-race-in-st_scsi_execute_end.patch: [SCSI]
  st: fix race in st_scsi_execute_end (bnc#720536).
* Mon Nov  7 2011 jack@suse.cz
- Disable CONFIG_DEBUG_PAGEALLOC for ia64
* Sun Nov  6 2011 jkosina@suse.cz
- Update config files.
- patches.suse/kdb-modules-fix-lm.patch: KDB: fix build in
  kdbm_fl().
- patches.suse/kdb-modules-fix-xfs.patch: KDB: fix build in
  XFS code.
* Sat Nov  5 2011 jlee@suse.de
- patches.drivers/0001-bnx2-remove-unnecessary-read-of-PCI_CAP_ID_EXP.patch:
  bnx2: remove unnecessary read of PCI_CAP_ID_EXP.
- patches.drivers/0001-bnx2x-Remove-local-defines-for-pM-and-mac-address.patch:
  bnx2x: Remove local defines for %%pM and mac address.
- patches.drivers/0001-drivers-net-Remove-casts-of-void.patch:
  drivers/net: Remove casts of void *.
- patches.drivers/0001-net-add-external-loopback-test-in-ethtool-self-test.patch:
  net: add external loopback test in ethtool self test.
- patches.drivers/0001-vlan-introduce-__vlan_find_dev_deep.patch:
  vlan: introduce __vlan_find_dev_deep().
- patches.drivers/0002-bnx2x-Coalesce-pr_cont-uses-and-fix-DP-typos.patch:
  bnx2x: Coalesce pr_cont uses and fix DP typos.
- patches.drivers/0002-cnic-Add-timeout-for-ramrod-replies.patch:
  cnic: Add timeout for ramrod replies.
- patches.drivers/0002-qlcnic-Add-capability-to-take-FW-dump-deterministica.patch:
  qlcnic: Add capability to take FW dump deterministically.
- patches.drivers/0003-bnx2x-Use-pr_fmt-and-message-logging-cleanups.patch:
  bnx2x: Use pr_fmt and message logging cleanups.
- patches.drivers/0003-cnic-bnx2fc-Increase-maximum-FCoE-sessions.patch:
  cnic, bnx2fc: Increase maximum FCoE sessions.
- patches.drivers/0003-qlcnic-Remove-holding-api-lock-while-taking-the-dump.patch:
  qlcnic: Remove holding api lock while taking the dump.
- patches.drivers/0004-bnx2-don-t-request-firmware-when-there-s-no-userspac.patch:
  bnx2: don't request firmware when there's no userspace.
- patches.drivers/0004-bnx2x-downgrade-Max-BW-error-message-to-debug.patch:
  bnx2x: downgrade Max BW error message to debug.
- patches.drivers/0004-qlcnic-Add-code-to-tune-FW-dump.patch:
  qlcnic: Add code to tune FW dump.
- patches.drivers/0005-bnx2x-resurrect-RX-hashing.patch: bnx2x:
  resurrect RX hashing.
- patches.drivers/0005-qlcnic-fix-initial-number-of-msix-entries-in-adapter.patch:
  qlcnic: fix initial number of msix entries in adapter.
- patches.drivers/0006-bnx2x-fix-WOL-by-enablement-PME-in-config-space.patch:
  bnx2x: fix WOL by enablement PME in config space.
- patches.drivers/0006-qlcnic-fix-default-operating-state-of-interface.patch:
  qlcnic: fix default operating state of interface.
- patches.drivers/0007-bnx2x-fix-cl_id-allocation-for-non-eth-clients-for.patch:
  bnx2x: fix cl_id allocation for non-eth clients for NPAR mode.
- patches.drivers/0007-qlcnic-Add-support-to-enable-disable-FW-dump-capabil.patch:
  qlcnic: Add support to enable/disable FW dump capability.
- patches.drivers/0008-bnx2x-fix-skb-truesize-underestimation.patch:
  bnx2x: fix skb truesize underestimation.
- patches.drivers/0008-qlcnic-multi-protocol-internal-loopback-support-adde.patch:
  qlcnic: multi protocol internal loopback support added.
- patches.drivers/0009-bnx2x-Fix-LED-blink-rate-for-578xx.patch:
  bnx2x: Fix LED blink rate for 578xx.
- patches.drivers/0009-qlcnic-add-external-loopback-support.patch:
  qlcnic: add external loopback support.
- patches.drivers/0010-bnx2x-Add-link-retry-to-578xx-KR.patch:
  bnx2x: Add link retry to 578xx-KR.
- patches.drivers/0010-qlcnic-fix-chip-reset-logic.patch: qlcnic:
  fix chip reset logic.
- patches.drivers/0011-bnx2x-Fix-RX-TX-problem-caused-by-the-MAC-layer.patch:
  bnx2x: Fix RX/TX problem caused by the MAC layer.
- patches.drivers/0011-qlcnic-updated-supported-cards-information.patch:
  qlcnic: updated supported cards information.
- patches.drivers/0012-bnx2x-Fix-54618se-LED-behavior.patch:
  bnx2x: Fix 54618se LED behavior.
- patches.drivers/0012-qlcnic-enable-mac-learning-in-promiscous-mode.patch:
  qlcnic: enable mac-learning in promiscous mode.
- patches.drivers/0013-bnx2x-Enable-changing-speed-when-port-type-is-PORT_D.patch:
  bnx2x: Enable changing speed when port type is PORT_DA.
- patches.drivers/0013-qlcnic-fix-race-in-skb-len-access.patch:
  qlcnic: fix race in skb->len access.
- patches.drivers/0014-bnx2x-use-FW-7.0.29.0.patch: bnx2x:
  use FW 7.0.29.0.
- patches.drivers/0014-qlcnic-define-error-code-for-loopback-test.patch:
  qlcnic: define error code for loopback test.
- patches.drivers/0015-bnx2x-update-driver-version-to-1.70.30-0.patch:
  bnx2x: update driver version to 1.70.30-0.
- patches.drivers/0015-qlcnic-change-capture-mask-for-FW-dump.patch:
  qlcnic: change capture mask for FW dump.
- patches.drivers/0016-net-vlan-qlcnic-make-vlan_find_dev-private.patch:
  net: vlan, qlcnic: make vlan_find_dev private.
- patches.drivers/0017-qlcnic-Fix-enviroment-variable-for-udev-event-genera.patch:
  qlcnic: Fix enviroment variable for udev event generation
  during FW dump.
- patches.drivers/0018-qlcnic-FW-dump-related-changes.patch:
  qlcnic: FW dump related changes.
- patches.drivers/0019-qlcnic-Fix-delay-in-reset-path.patch:
  qlcnic: Fix delay in reset path.
- patches.drivers/0020-qlcnic-Move-get-template-from-probe-to-start-fw.patch:
  qlcnic: Move get template from probe to start fw.
- patches.drivers/0021-qlcnic-Added-debug-info.patch: qlcnic:
  Added debug info.
- patches.drivers/0022-net-remove-use-of-ndo_set_multicast_list-in-drivers.patch:
  net: remove use of ndo_set_multicast_list in drivers.
- patches.drivers/0023-qlcnic-detect-fan-failure.patch: qlcnic:
  detect fan failure.
- patches.drivers/0024-qlcnic-Change-debug-messages-in-loopback-path.patch:
  qlcnic: Change debug messages in loopback path.
- patches.drivers/0025-qlcnic-Add-FLT-entry-for-CO-cards-FW-image-region.patch:
  qlcnic: Add FLT entry for CO cards FW image region.
- patches.drivers/0026-qlcnic-fix-cdrp-race-condition.patch:
  qlcnic: fix cdrp race condition.
- patches.drivers/0027-qlcnic-add-beacon-test-support.patch:
  qlcnic: add beacon test support.
- patches.drivers/0028-qlcnic-Added-error-logging-for-firmware-abort.patch:
  qlcnic: Added error logging for firmware abort.
- patches.drivers/0029-qlcnic-Change-CDRP-function.patch: qlcnic:
  Change CDRP function.
* Sat Nov  5 2011 rjw@suse.de
- patches.fixes/Documentation-fix-typo-in-freezer-subsystem_txt.patch:
  Documentation: Fix typo in freezer-subsystem.txt (bnc#724544).
* Fri Nov  4 2011 gregkh@suse.de
- supported.conf: add usb-common to supported list.
* Fri Nov  4 2011 ptesarik@suse.cz
- patches.suse/hid-drff-alias.patch: provide a hid-drff module
  alias for hid-dr.
* Fri Nov  4 2011 gregkh@suse.de
- Update config files.
* Fri Nov  4 2011 gregkh@suse.de
- Final USB 3 work to bring us from 3.1 -> 3.2-rc1
- patches.drivers/USB3-0262-xHCI-USB-Make-xHCI-driver-have-a-BOS-descriptor.patch:
  xHCI/USB: Make xHCI driver have a BOS descriptor.
- patches.drivers/USB3-0266-USB-ftdi_sio.c-Basic-icount-infrastructure-for-ftdi_sio.patch:
  USB: ftdi_sio.c: Basic icount infrastructure for ftdi_sio.
- patches.drivers/USB3-0267-USB-ftdi_sio.c-Fill-the-RX-field-of-the-ftdi-async_icount-st.patch:
  USB: ftdi_sio.c: Fill the RX field of the ftdi async_icount
  structure.
- patches.drivers/USB3-0268-USB-ftdi_sio.c-Fill-TX-field-of-the-ftdi-async_icount-struct.patch:
  USB: ftdi_sio.c:Fill TX field of the ftdi async_icount
  structure.
- patches.drivers/USB3-0269-USB-ftdi_sio.c-Fill-LSR-fields-of-the-ftdi-async_icount-stru.patch:
  USB: ftdi_sio.c: Fill LSR fields of the ftdi async_icount
  structure.
- patches.drivers/USB3-0270-USB-ftdi_sio.c-Fill-MSR-fields-of-the-ftdi-async_icount-stru.patch:
  USB: ftdi_sio.c:Fill MSR fields of the ftdi async_icount
  structure.
- patches.drivers/USB3-0271-USB-ftdi_sio.c-Use-ftdi-async_icount-structure-for-TIOCMIWAI.patch:
  USB: ftdi_sio.c: Use ftdi async_icount structure for TIOCMIWAIT,
  as in other drivers.
- patches.drivers/USB3-0281-NET-asix-fix-ethtool-e-for-AX88178-USB-dongle.patch:
  NET: asix: fix ethtool -e for AX88178 USB dongle.
* Fri Nov  4 2011 ptesarik@suse.cz
- supported.conf: reflect the upstream rename of hid-drff to hid-dr
  in commit 152fd6347e63d176d1f03c8d142e534a5227ef3f.
* Fri Nov  4 2011 gregkh@suse.de
- More USB 3 work from 3.1 -> 3.2
- patches.drivers/USB3-0106-USB-Add-endpoint-usage-definitions-to-ch9.h.patch:
  USB: Add endpoint usage definitions to ch9.h.
- patches.drivers/USB3-0115-usb-Provide-usb_speed_string-function.patch:
  usb: Provide usb_speed_string() function.
- patches.drivers/USB3-0120-usb-ehci-remove-wmb-in-qh_update.patch:
  usb: ehci: remove wmb in qh_update.
- patches.drivers/USB3-0121-usb-ehci-only-prepare-zero-packet-for-out-transfer-if-requir.patch:
  usb: ehci: only prepare zero packet for out transfer if
  required.
- patches.drivers/USB3-0122-usb-ehci-fix-comment-for-EHCI_SHRINK_JIFFIES.patch:
  usb: ehci: fix comment for EHCI_SHRINK_JIFFIES.
- patches.drivers/USB3-0123-usb-ehci-remove-the-1st-wmb-in-qh_append_tds.patch:
  usb: ehci: remove the 1st wmb in qh_append_tds.
- patches.drivers/USB3-0124-USB-irq-Remove-IRQF_DISABLED.patch:
  USB: irq: Remove IRQF_DISABLED.
- patches.drivers/USB3-0126-USB-Realtek-cr-Fix-driver-freeze-issue.patch:
  USB: Realtek cr: Fix driver freeze issue.
- patches.drivers/USB3-0127-usb-xhci-ignore-xhci-version-while-checking-for-the-link-qui.patch:
  usb/xhci: ignore xhci version while checking for the link quirk.
- patches.drivers/USB3-0128-usbcore-refine-warm-reset-logic.patch:
  usbcore: refine warm reset logic.
- patches.drivers/USB3-0129-xhci-Fix-mult-base-in-endpoint-bandwidth-info.patch:
  xhci: Fix mult base in endpoint bandwidth info.
- patches.drivers/USB3-0130-xhci-USB-3.0-BW-checking.patch:
  xhci: USB 3.0 BW checking.
- patches.drivers/USB3-0131-USB-When-hot-reset-for-USB3-fails-try-warm-reset.patch:
  USB: When hot reset for USB3 fails, try warm reset.
- patches.drivers/USB3-0133-xhci-mem.c-xhci_segment_free-No-need-for-checking-seg-argume.patch:
  xhci-mem.c: xhci_segment_free: No need for checking seg
  argument.
- patches.drivers/USB3-0135-USB-export-video.h-to-the-includes-available-for-userspace.patch:
  USB: export video.h to the includes available for userspace.
- patches.drivers/USB3-0142-usbcore-get-BOS-descriptor-set.patch:
  usbcore: get BOS descriptor set.
- patches.drivers/USB3-0143-usbcore-check-device-s-LPM-capability.patch:
  usbcore: check device's LPM capability.
- patches.drivers/USB3-0144-xHCI-set-link-state.patch: xHCI:
  set link state.
- patches.drivers/USB3-0145-xHCI-test-and-clear-RWC-bit.patch:
  xHCI: test and clear RWC bit.
- patches.drivers/USB3-0146-xHCI-Clear-PLC-for-USB2-root-hub-ports.patch:
  xHCI: Clear PLC for USB2 root hub ports.
- patches.drivers/USB3-0147-xHCI-Check-host-USB2-LPM-capability.patch:
  xHCI: Check host USB2 LPM capability.
- patches.drivers/USB3-0148-xHCI-test-USB2-software-LPM.patch:
  xHCI: test USB2 software LPM.
- patches.drivers/USB3-0149-xHCI-set-USB2-hardware-LPM.patch:
  xHCI: set USB2 hardware LPM.
- patches.drivers/USB3-0150-usbcore-add-sysfs-support-to-xHCI-usb2-hardware-LPM.patch:
  usbcore: add sysfs support to xHCI usb2 hardware LPM.
- patches.drivers/USB3-0152-xHCI-fix-debug-message.patch: xHCI:
  fix debug message.
- patches.drivers/USB3-0153-usb-host-introduce-USB_ARCH_HAS_XHCI.patch:
  usb/host: introduce USB_ARCH_HAS_XHCI.
- patches.drivers/USB3-0154-usb-xhci-group-MSI-interrupt-registration-into-its-own-funct.patch:
  usb/xhci: group MSI interrupt registration into its own
  function.
- patches.drivers/USB3-0155-usb-xhci-hide-MSI-code-behind-PCI-bars.patch:
  usb/xhci: hide MSI code behind PCI bars.
- patches.drivers/USB3-0156-usb-xhci-replace-pci_-_consistent-with-dma_-_coherent.patch:
  usb/xhci: replace pci_*_consistent() with dma_*_coherent().
- patches.drivers/USB3-0157-usb-xhci-refactor-xhci_pci_setup.patch:
  usb/xhci: refactor xhci_pci_setup().
- patches.drivers/USB3-0158-usb-xhci-move-xhci_gen_setup-away-from-pci.patch:
  usb/xhci: move xhci_gen_setup() away from -pci.
- patches.drivers/USB3-0159-usb-xhci-remove-CONFIG_PCI-in-xhci.c-s-probe-function.patch:
  usb/xhci: remove CONFIG_PCI in xhci.c's probe function.
- patches.drivers/USB3-0160-USB-Update-USB-default-wakeup-settings.patch:
  USB: Update USB default wakeup settings.
- patches.drivers/USB3-0161-USB-UHCI-improve-comments-and-logic-for-root-hub-suspend.patch:
  USB: UHCI: improve comments and logic for root-hub suspend.
- patches.drivers/USB3-0166-usbnet-add-timestamping-support.patch:
  usbnet: add timestamping support.
- patches.drivers/USB3-0168-USB-message-cleanup-min_t-cast-in-usb_sg_init.patch:
  USB: message: cleanup min_t() cast in usb_sg_init().
- patches.drivers/USB3-0169-user-namespace-usb-make-usb-urbs-user-namespace-aware-v2.patch:
  user namespace: usb: make usb urbs user namespace aware (v2).
- patches.drivers/USB3-0190-NET-fix-phy-init-for-AX88772-USB-ethernet.patch:
  NET: fix phy init for AX88772 USB ethernet.
- patches.drivers/USB3-0191-NET-fix-phy-init-for-Asix-AX88178-USB-GigE.patch:
  NET: fix phy init for Asix AX88178 USB (GigE).
- patches.drivers/USB3-0192-NET-white-space-coding-style-cleanup-of-asix-driver.patch:
  NET: white space/coding style cleanup of asix driver.
- patches.suse/0001-USB-resurrect-the-vstusb-driver.patch:
  Refresh.
* Fri Nov  4 2011 mmarek@suse.cz
- patches.drivers/0001-drivers-net-Remove-unnecessary-semicolons.patch:
  drivers/net: Remove unnecessary semicolons (bnc#720960).
- patches.drivers/0002-netxen-convert-to-64-bit-statistics.patch:
  netxen: convert to 64 bit statistics (bnc#720960).
- patches.drivers/0003-drivers-net-netxen-Remove-casts-of-void.patch:
  drivers/net/netxen: Remove casts of void * (bnc#720960).
- patches.drivers/0004-netxen-add-fw-version-compatibility-check.patch:
  netxen: add fw version compatibility check (bnc#720960).
- patches.drivers/0005-net-remove-use-of-ndo_set_multicast_list-in-drivers.patch:
  net: remove use of ndo_set_multicast_list in drivers
  (bnc#720960).
- patches.drivers/0006-netxen-add-vlan-LRO-support.patch: netxen:
  add vlan LRO support (bnc#720960).
- patches.drivers/0007-netxen-Fix-vhdr_len-in-case-of-non-vlan-packets.patch:
  netxen: Fix vhdr_len in case of non vlan packets (bnc#720960).
- patches.drivers/0008-netxen-Add-pcie-workaround.patch: netxen:
  Add pcie workaround (bnc#720960).
* Fri Nov  4 2011 trenn@suse.de
  Re-add:
- patches.arch/x86-apic-force-bigsmp-apic-on-IBM-EXA3-4.patch:
  Refresh.
* Fri Nov  4 2011 mmarek@suse.cz
- patches.drivers/0001-Separate-handling-of-irq-type-flags-variable-from-th.patch:
  Separate handling of irq type flags variable from the irq_flags
  request_irq variable (bnc#689230, fate#311451).
- patches.drivers/0002-net-Remove-unneeded-version.h-includes-from-drivers-.patch:
  net: Remove unneeded version.h includes from drivers/net/bna
  (bnc#689230, fate#311451).
- patches.drivers/0003-drivers-net-Remove-casts-of-void.patch:
  drivers/net: Remove casts of void * (bnc#689230, fate#311451).
- patches.drivers/bna-Multiple-Definition-and-Interface-Setup-Fix.patch:
  bna: Multiple Definition and Interface Setup Fix (bnc#689230,
  fate#311451).
* Fri Nov  4 2011 jjolly@suse.de
- patches.drivers/rds-add-pf-sol-sysctl.diff: RDS: Re-add pf/sol
  access via sysctl (bnc#708204).
* Fri Nov  4 2011 mhocko@suse.cz
- patches.fixes/oom-fix-oom_badness-overflow.patch: oom:
  fix integer overflow of points in oom_badness (bnc#727493,
  bnc#725208, CVE-2011-4097).
* Fri Nov  4 2011 jjolly@suse.de
- patches.drivers/mlx4_0080_profile_parm.patch: mlx4-core:
  enable changing default max HCA resource limits (bnc#726710).
* Fri Nov  4 2011 mmarek@suse.cz
- patches.drivers/0001-iwlagn-separate-firmware-version-warning.patch:
  Update references (bnc#727250).
- patches.drivers/0002-iwlagn-bump-firmware-API-for-some-devices.patch:
  Update references (bnc#727250).
* Fri Nov  4 2011 hare@suse.de
- patches.drivers/qla4xxx-Support-mixed-mode.patch: Fixup patch.
* Fri Nov  4 2011 hare@suse.de
- patches.drivers/qla4xxx-Support-mixed-mode.patch: qla4xxx:
  Support mixed mode (bnc#727415).
* Fri Nov  4 2011 jankit@suse.de
- patches.fixes/scsi_dh-code-cleanup-and-remove-references-to-scsi_dev_info:
  scsi_dh: code cleanup and remove the references to scsi_dev_info
  (bnc#726504).
- patches.fixes/scsi_dh_emc-adding-the-match-function-for-emc-device-handler:
  scsi_dh_emc: Adding the match function for emc device handler
  (bnc#726504).
- patches.fixes/scsi_dh_hp_sw-adding-the-match-function-for-hp_sw-device_handler:
  scsi_dh_hp_sw: Adding the match function for hp_sw device
  handler (bnc#726504).
- patches.fixes/scsi_dh_rdac-adding-the-match-function-for-rdac-device-handler:
  scsi_dh_rdac: Adding the match function for rdac device handler
  (bnc#726504).
* Fri Nov  4 2011 hare@suse.de
- patches.fixes/fcoe-setup-default-initial-ddp-value: fcoe:
  setup default initial value for DDP threshold (bnc#728195).
* Fri Nov  4 2011 rw@suse.de
- patches.arch/ia64-sn-genirq:
  ia64: genirq fixup for SGI/SN.  (bnc#718160)
- patches.suse/kdb-v4.4-3.1-common-1:
  Refresh.  (Don't kill 'console_initcall()'!)
* Fri Nov  4 2011 hare@suse.de
- patches.fixes/scsi-dh-rdac-get-sdev-reference-in-queue_mode_select:
  scsi_dh_rdac: Get sdev reference in queue_mode_select()
  (bnc#721738).
* Fri Nov  4 2011 hare@suse.de
- patches.fixes/scsi-fix-block-queue-and-elevator-mem-leak:
  Fix block queue and elevator memory leak in scsi_alloc_sdev
  (bnc#727814).
- patches.fixes/scsi-make-scsi-free-kill-pending-scmds.patch:
  Make scsi_free_queue() kill pending SCSI commands (bnc#727814).
- patches.fixes/scsi_dh-check-queuedata-pointer.patch: scsi_dh:
  check queuedata pointer before proceeding further (bnc#721738).
- patches.fixes/scsi_dh-do-not-access-invalid-sdev: Delete.
* Fri Nov  4 2011 hare@suse.de
- patches.drivers/hpsa-add-new-controller-names: hpsa: add Gen8
  controller names (bnc#703426).
* Fri Nov  4 2011 rjw@suse.de
- patches.fixes/CPU-hotplug-Freezer-Fix-race-between-CPU-hotplug-and-freezer.patch:
  PM / Sleep: Fix race between CPU hotplug and freezer
  (bnc#719280).
* Fri Nov  4 2011 gregkh@suse.de
- patches.drivers/USB3-0001-net-usb-Add-IPv6-support-to-the-LG-VL600-LTE-USB-modem-drive.patch:
  Refresh.
- patches.drivers/USB3-0009-USB-ipw-convert-to-usb-wwan-framework.patch:
  Refresh.
- patches.drivers/USB3-0020-usb-add-usb_endpoint_maxp-macro.patch:
  Refresh.
- patches.drivers/USB3-0022-USB-EHCI-remove-usages-of-hcd-state.patch:
  Refresh.
- patches.drivers/USB3-0023-usb-ch9-add-function-defines-from-ch9-USB-3.0-spec.patch:
  Refresh.
- patches.drivers/USB3-0032-USB-usbtest-use-URB_ZERO_PACKET-for-BULK-OUT-transfers.patch:
  Refresh.
- patches.drivers/USB3-0034-USB-use-usb_endpoint_maxp-instead-of-le16_to_cpu.patch:
  Refresh.
- patches.drivers/USB3-0040-USB-pl2303-remove-unreachable-code.patch:
  Refresh.
- patches.drivers/USB3-0087-xhci-If-no-endpoints-changed-don-t-issue-BW-command.patch:
  Refresh.
- patches.drivers/USB3-0088-xhci-Rename-virt_dev-port-to-fake_port.patch:
  Refresh.
- patches.drivers/USB3-0089-xhci-Refactor-endpoint-limit-checking.patch:
  Refresh.
- patches.drivers/USB3-0090-xhci-Store-the-real-root-port-number.patch:
  Refresh.
- patches.drivers/USB3-0091-xhci-Store-information-about-roothubs-and-TTs.patch:
  Refresh.
- patches.drivers/USB3-0092-xhci-Store-endpoint-bandwidth-information.patch:
  Refresh.
- patches.drivers/USB3-0093-xhci-Track-interval-bandwidth-tables-per-port-TT.patch:
  Refresh.
- patches.drivers/USB3-0094-xhci-Implement-HS-FS-LS-bandwidth-checking.patch:
  Refresh.
- patches.drivers/USB3-0095-xhci-Add-software-BW-checking-quirk-to-Intel-PPT-xHCI.patch:
  Refresh.
- patches.drivers/USB3-0096-xhci-Don-t-print-short-isoc-packets.patch:
  Refresh.
- patches.drivers/USB3-0097-xHCI-refine-td-allocation.patch:
  Refresh.
- patches.drivers/USB3-0098-xhci-Redundant-check-in-xhci_check_args-for-xhci-devs.patch:
  Refresh.
* Fri Nov  4 2011 gregkh@suse.de
- USB 3.0 work from 3.1 -> 3.2
- patches.drivers/USB3-0001-net-usb-Add-IPv6-support-to-the-LG-VL600-LTE-USB-modem-drive.patch:
  net/usb: Add IPv6 support to the LG-VL600 LTE USB modem driver.
- patches.drivers/USB3-0009-USB-ipw-convert-to-usb-wwan-framework.patch:
  USB: ipw: convert to usb-wwan framework.
- patches.drivers/USB3-0020-usb-add-usb_endpoint_maxp-macro.patch:
  usb: add usb_endpoint_maxp() macro.
- patches.drivers/USB3-0022-USB-EHCI-remove-usages-of-hcd-state.patch:
  USB: EHCI: remove usages of hcd->state.
- patches.drivers/USB3-0023-usb-ch9-add-function-defines-from-ch9-USB-3.0-spec.patch:
  usb: ch9: add function defines from ch9, USB 3.0 spec.
- patches.drivers/USB3-0032-USB-usbtest-use-URB_ZERO_PACKET-for-BULK-OUT-transfers.patch:
  USB: usbtest: use URB_ZERO_PACKET for BULK-OUT transfers.
- patches.drivers/USB3-0034-USB-use-usb_endpoint_maxp-instead-of-le16_to_cpu.patch:
  USB: use usb_endpoint_maxp() instead of le16_to_cpu().
- patches.drivers/USB3-0040-USB-pl2303-remove-unreachable-code.patch:
  USB: pl2303: remove unreachable code.
- patches.drivers/USB3-0087-xhci-If-no-endpoints-changed-don-t-issue-BW-command.patch:
  xhci: If no endpoints changed, don't issue BW command.
- patches.drivers/USB3-0088-xhci-Rename-virt_dev-port-to-fake_port.patch:
  xhci: Rename virt_dev->port to fake_port.
- patches.drivers/USB3-0089-xhci-Refactor-endpoint-limit-checking.patch:
  xhci: Refactor endpoint limit checking.
- patches.drivers/USB3-0090-xhci-Store-the-real-root-port-number.patch:
  xhci: Store the "real" root port number.
- patches.drivers/USB3-0091-xhci-Store-information-about-roothubs-and-TTs.patch:
  xhci: Store information about roothubs and TTs.
- patches.drivers/USB3-0092-xhci-Store-endpoint-bandwidth-information.patch:
  xhci: Store endpoint bandwidth information.
- patches.drivers/USB3-0093-xhci-Track-interval-bandwidth-tables-per-port-TT.patch:
  xhci: Track interval bandwidth tables per port/TT.
- patches.drivers/USB3-0094-xhci-Implement-HS-FS-LS-bandwidth-checking.patch:
  xhci: Implement HS/FS/LS bandwidth checking.
- patches.drivers/USB3-0095-xhci-Add-software-BW-checking-quirk-to-Intel-PPT-xHCI.patch:
  xhci: Add software BW checking quirk to Intel PPT xHCI.
- patches.drivers/USB3-0096-xhci-Don-t-print-short-isoc-packets.patch:
  xhci: Don't print short isoc packets.
- patches.drivers/USB3-0097-xHCI-refine-td-allocation.patch:
  xHCI: refine td allocation.
- patches.drivers/USB3-0098-xhci-Redundant-check-in-xhci_check_args-for-xhci-devs.patch:
  xhci: Redundant check in xhci_check_args for xhci->devs.
* Thu Nov  3 2011 gregkh@suse.de
- patches.drivers/USB3-0146-rtl8150-rtl8150_disconnect-.-does-not-need-tasklet_disable.patch:
  Refresh.
- patches.drivers/USB3-0187-usbnet-cdc_ncm-Don-t-use-stack-variables-for-DMA.patch:
  Refresh.
- patches.drivers/USB3-0188-USB-Avoid-NULL-pointer-deref-in-usb_hcd_alloc_bandwidth.patch:
  Refresh.
- patches.drivers/USB3-0197-ipheth-iPhone-4-Verizon-CDMA-USB-Product-ID-add.patch:
  Refresh.
* Thu Nov  3 2011 gregkh@suse.de
- USB patches to get to 3.1 level (most will end up in next 3.0-stable release)
- patches.drivers/USB3-0146-rtl8150-rtl8150_disconnect-.-does-not-need-tasklet_disable.patch:
  rtl8150: rtl8150_disconnect(...) does not need
  tasklet_disable(...).
- patches.drivers/USB3-0155-USB-EHCI-Fix-test-mode-sequence.patch:
  USB: EHCI: Fix test mode sequence.
- patches.drivers/USB3-0156-usb-isp1760-Added-missing-call-to-usb_hcd_check_unlink_urb-d.patch:
  usb/isp1760: Added missing call to usb_hcd_check_unlink_urb()
  during unlink.
- patches.drivers/USB3-0157-usb-serial-ftdi_sio.c-For-the-FT232H-FTDI_SIO_SET_BAUDRATE_R.patch:
  usb: serial: ftdi_sio.c: For the FT232H
  FTDI_SIO_SET_BAUDRATE_REQUEST, index needs to be shifted too.
- patches.drivers/USB3-0169-USB-Serial-Add-device-ID-for-Sierra-Wireless-MC8305.patch:
  USB: Serial: Add device ID for Sierra Wireless MC8305.
- patches.drivers/USB3-0170-USB-Serial-Add-PID-0xF7C0-to-FTDI-SIO-driver-for-a-zeitcontr.patch:
  USB: Serial: Add PID(0xF7C0) to FTDI SIO driver for a
  zeitcontrol-device.
- patches.drivers/USB3-0187-usbnet-cdc_ncm-Don-t-use-stack-variables-for-DMA.patch:
  usbnet/cdc_ncm: Don't use stack variables for DMA.
- patches.drivers/USB3-0188-USB-Avoid-NULL-pointer-deref-in-usb_hcd_alloc_bandwidth.patch:
  USB: Avoid NULL pointer deref in usb_hcd_alloc_bandwidth.
- patches.drivers/USB3-0197-ipheth-iPhone-4-Verizon-CDMA-USB-Product-ID-add.patch:
  ipheth: iPhone 4 Verizon CDMA USB Product ID add.
- patches.drivers/USB3-0199-USB-xHCI-prevent-infinite-loop-when-processing-MSE-event.patch:
  USB: xHCI: prevent infinite loop when processing MSE event.
* Thu Nov  3 2011 gregkh@suse.de
- patches.kernel.org/series: Delete.
* Thu Nov  3 2011 gregkh@suse.de
- patches.kernel.org/ath9k_hw-fix-descriptor-status-of-txopexceeded.patch:
  Refresh.
* Thu Nov  3 2011 gregkh@suse.de
- Add 3.0.9 pre-release patches
- Update config files.
- patches.drivers/target-0006-target-Core-cleanups-from-AGrover-round-1.patch:
  Refresh.
- patches.drivers/target-0008-target-More-core-cleanups-from-AGrover-round-2.patch:
  Refresh.
- patches.drivers/target-0011-target-Updates-from-AGrover-and-HCH-round-3.patch:
  Refresh.
- patches.drivers/target-0030-target-Make-all-control-CDBs-scatter-gather.patch:
  Refresh.
- patches.kernel.org/alsa-hda-add-new-revision-for-alc662.patch:
  ALSA: HDA: Add new revision for ALC662.
- patches.kernel.org/alsa-hda-fix-adc-input-amp-handling-for-cx20549-codec.patch:
  ALSA: hda - Fix ADC input-amp handling for Cx20549 codec.
- patches.kernel.org/alsa-hda-remove-bad-code-for-idt-92hd83-family-patch.patch:
  ALSA: hda - Remove bad code for IDT 92HD83 family patch.
- patches.kernel.org/apic-i386-bigsmp-fix-false-warnings-regarding-logical-apic-id-mismatches.patch:
  apic, i386/bigsmp: Fix false warnings regarding logical APIC
  ID mismatches.
- patches.kernel.org/arm-mach-ux500-unlock-i-d-l2x0-caches-before-init.patch:
  ARM: mach-ux500: unlock I&D l2x0 caches before init.
- patches.kernel.org/asoc-ak4535-fixup-cache-register-table.patch:
  ASoC: ak4535: fixup cache register table.
- patches.kernel.org/asoc-ak4642-fixup-cache-register-table.patch:
  ASoC: ak4642: fixup cache register table.
- patches.kernel.org/asoc-fix-a-bug-in-wm8962-dsp_a-and-dsp_b-settings.patch:
  ASoC: Fix a bug in WM8962 DSP_A and DSP_B settings.
- patches.kernel.org/asoc-remove-direct-register-cache-accesses-from-wm8962.patch:
  ASoC: Remove direct register cache accesses from WM8962 driver.
- patches.kernel.org/asoc-wm8741-fix-setting-interface-format-for-dsp-modes.patch:
  ASoC: wm8741: Fix setting interface format for DSP modes.
- patches.kernel.org/asoc-wm8940-properly-set-codec-dapm.bias_level.patch:
  ASoC: wm8940: Properly set codec->dapm.bias_level.
- patches.kernel.org/asoc-wm8994-use-snd_soc_dapm_aif_out-for-aif3-capture.patch:
  ASoC: wm8994: Use SND_SOC_DAPM_AIF_OUT for AIF3 Capture.
- patches.kernel.org/ata_piix-make-dvd-drive-recognisable-on-systems-with-intel-sandybridge-chipsets-v2.patch:
  ata_piix: make DVD Drive recognisable on systems with Intel
  Sandybridge chipsets(v2).
- patches.kernel.org/ath9k-disable-unnecessary-phy-error-reporting.patch:
  ath9k: disable unnecessary PHY error reporting.
- patches.kernel.org/ath9k_htc-add-avm-fritz-wlan-11n-v2-support.patch:
  ath9k_htc: add AVM FRITZ!WLAN 11N v2 support.
- patches.kernel.org/ath9k_hw-fix-descriptor-status-of-txopexceeded.patch:
  ath9k_hw: Fix descriptor status of TxOpExceeded.
- patches.kernel.org/ath9k_hw-fix-magnitude-phase-coeff-correction.patch:
  ath9k_hw: Fix magnitude/phase coeff correction.
- patches.kernel.org/ath9k_hw-fix-number-of-gpio-pins-for-ar9287-9300.patch:
  ath9k_hw: Fix number of GPIO pins for AR9287/9300.
- patches.kernel.org/binfmt_elf-fix-pie-execution-with-randomization-disabled.patch:
  binfmt_elf: fix PIE execution with randomization disabled.
- patches.kernel.org/bonding-use-local-function-pointer-of-bond-recv_probe-in-bond_handle_frame.patch:
  bonding: use local function pointer of bond->recv_probe in
  bond_handle_frame.
- patches.kernel.org/bridge-fix-hang-on-removal-of-bridge-via-netlink.patch:
  bridge: fix hang on removal of bridge via netlink.
- patches.kernel.org/caif-fix-bug-with-network-namespaces.patch:
  caif: Fix BUG() with network namespaces.
- patches.kernel.org/can-bcm-fix-tx_setup-off-by-one-errors.patch:
  can bcm: fix tx_setup off-by-one errors.
- patches.kernel.org/carminefb-fix-module-parameters-permissions.patch:
  carminefb: Fix module parameters permissions.
- patches.kernel.org/ccwgroup-move-attributes-to-attribute-group.patch:
  ccwgroup: move attributes to attribute group.
- patches.kernel.org/cifs-fix-dfs-handling-in-cifs_get_file_info.patch:
  CIFS: Fix DFS handling in cifs_get_file_info.
- patches.kernel.org/cifs-fix-incorrect-max-rfc1002-write-size-value.patch:
  CIFS: Fix incorrect max RFC1002 write size value.
- patches.kernel.org/cris-fix-a-build-error-in-drivers-tty-serial-crisv10.c.patch:
  cris: fix a build error in drivers/tty/serial/crisv10.c.
- patches.kernel.org/dib0700-protect-the-dib0700-buffer-access.patch:
  dib0700: protect the dib0700 buffer access.
- patches.kernel.org/dibcom-protect-the-i2c-bufer-access.patch:
  DiBcom: protect the I2C bufer access.
- patches.kernel.org/dp83640-free-packet-queues-on-remove.patch:
  dp83640: free packet queues on remove.
- patches.kernel.org/drivers-net-rionet.c-fix-ethernet-address-macros-for-le-platforms.patch:
  drivers/net/rionet.c: fix ethernet address macros for LE
  platforms.
- patches.kernel.org/drivers-power-ds2780_battery.c-add-a-nolock-function-to-w1-interface.patch:
  drivers/power/ds2780_battery.c: add a nolock function to
  w1 interface.
- patches.kernel.org/drivers-power-ds2780_battery.c-create-central-point-for-calling-w1-interface.patch:
  drivers/power/ds2780_battery.c: create central point for
  calling w1 interface.
- patches.kernel.org/drivers-power-ds2780_battery.c-fix-deadlock-upon-insertion-and-removal.patch:
  drivers/power/ds2780_battery.c: fix deadlock upon insertion
  and removal.
- patches.kernel.org/drm-i915-panel-always-record-the-backlight-level-again-but-cleverly.patch:
  drm/i915/panel: Always record the backlight level again
  (but cleverly).
- patches.kernel.org/drm-i915-wrap-dp-edid-fetch-functions-to-enable-edp-panel.patch:
  drm/i915: Wrap DP EDID fetch functions to enable eDP panel
  power.
- patches.kernel.org/drm-radeon-kms-bail-early-in-dvi_detect-for-digital-only-connectors.patch:
  drm/radeon/kms: bail early in dvi_detect for digital only
  connectors.
- patches.kernel.org/drm-radeon-kms-fix-i2c-mask-definitions.patch:
  drm/radeon/kms: Fix I2C mask definitions.
- patches.kernel.org/drm-radeon-kms-handle-force-case-in-connector-detect-more-gracefully.patch:
  drm/radeon/kms: handle !force case in connector detect more
  gracefully.
- patches.kernel.org/ehci-introduce-a-common-ehci_setup.patch:
  EHCI : introduce a common ehci_setup.
- patches.kernel.org/ehci-workaround-for-moschip-controller-bug.patch:
  EHCI: workaround for MosChip controller bug.
- patches.kernel.org/enic-bug-fix-fix-hardware-transmit-queue-indexing-in-enic_poll_controller.patch:
  enic: Bug Fix: Fix hardware transmit queue indexing in
  enic_poll_controller.
- patches.kernel.org/epoll-fix-spurious-lockdep-warnings.patch:
  epoll: fix spurious lockdep warnings.
- patches.kernel.org/ext2-ext3-ext4-don-t-inherit-append_fl-or-immutable_fl-for-new-inodes.patch:
  ext2,ext3,ext4: don't inherit APPEND_FL or IMMUTABLE_FL for
  new inodes.
- patches.kernel.org/ext4-call-ext4_handle_dirty_metadata-with-correct-inode-in-ext4_dx_add_entry.patch:
  ext4: call ext4_handle_dirty_metadata with correct inode in
  ext4_dx_add_entry.
- patches.kernel.org/ext4-ext4_mkdir-should-dirty-dir_block-with-newly-created-directory-inode.patch:
  ext4: ext4_mkdir should dirty dir_block with newly created
  directory inode.
- patches.kernel.org/ext4-ext4_rename-should-dirty-dir_bh-with-the-correct-directory.patch:
  ext4: ext4_rename should dirty dir_bh with the correct
  directory.
- patches.kernel.org/ext4-fix-race-in-xattr-block-allocation-path.patch:
  ext4: fix race in xattr block allocation path.
- patches.kernel.org/fb-avoid-possible-deadlock-caused-by-fb_set_suspend.patch:
  fb: avoid possible deadlock caused by fb_set_suspend.
- patches.kernel.org/fb-sh-mobile-fix-deadlock-risk-between-lock_fb_info-and-console_lock.patch:
  fb: sh-mobile: Fix deadlock risk between lock_fb_info()
  and console_lock().
- patches.kernel.org/genirq-add-irqf_resume_early-and-resume-such-irqs-earlier.patch:
  genirq: Add IRQF_RESUME_EARLY and resume such IRQs earlier.
- patches.kernel.org/hid-acrux-fix-enabling-force-feedback-support.patch:
  HID: ACRUX - fix enabling force feedback support.
- patches.kernel.org/hppfs-missing-include.patch: hppfs:
  missing include.
- patches.kernel.org/hwspinlock-core-use-a-mutex-to-protect-the-radix-tree.patch:
  hwspinlock/core: use a mutex to protect the radix tree.
- patches.kernel.org/io-mapping-ensure-io_mapping_map_atomic-_is_-atomic.patch:
  io-mapping: ensure io_mapping_map_atomic _is_ atomic.
- patches.kernel.org/iommu-amd-fix-wrong-shift-direction.patch:
  iommu/amd: Fix wrong shift direction.
- patches.kernel.org/ipr-always-initiate-hard-reset-in-kdump-kernel.patch:
  ipr: Always initiate hard reset in kdump kernel.
- patches.kernel.org/ipv4-fix-ipsec-forward-performance-regression.patch:
  ipv4: fix ipsec forward performance regression.
- patches.kernel.org/ipv6-nullify-ipv6_ac_list-and-ipv6_fl_list-when-creating-new-socket.patch:
  ipv6: nullify ipv6_ac_list and ipv6_fl_list when creating
  new socket.
- patches.kernel.org/isci-fix-missed-unlock-in-apc_agent_timeout.patch:
  isci: fix missed unlock in apc_agent_timeout().
- patches.kernel.org/isci-fix-support-for-large-smp-requests.patch:
  isci: fix support for large smp requests.
- patches.kernel.org/iwlagn-do-not-use-interruptible-waits.patch:
  iwlagn: do not use interruptible waits.
- patches.kernel.org/jsm-remove-buggy-write-queue.patch: jsm:
  remove buggy write queue.
- patches.kernel.org/kmod-prevent-kmod_loop_msg-overflow-in-__request_module.patch:
  kmod: prevent kmod_loop_msg overflow in __request_module().
- patches.kernel.org/kobj_uevent-ignore-if-some-listeners-cannot-handle-message.patch:
  kobj_uevent: Ignore if some listeners cannot handle message.
- patches.kernel.org/kvm-s390-check-cpu_id-prior-to-using-it.patch:
  KVM: s390: check cpu_id prior to using it.
- patches.kernel.org/l2tp-fix-a-potential-skb-leak-in-l2tp_xmit_skb.patch:
  l2tp: fix a potential skb leak in l2tp_xmit_skb().
- patches.kernel.org/leds-save-the-delay-values-after-a-successful-call-to-blink_set.patch:
  leds: save the delay values after a successful call to
  blink_set().
- patches.kernel.org/leds-turn-the-blink_timer-off-before-starting-to-blink.patch:
  leds: turn the blink_timer off before starting to blink.
- patches.kernel.org/libsas-set-sas_address-and-device-type-of-rphy.patch:
  libsas: set sas_address and device type of rphy.
- patches.kernel.org/mac80211-fix-offchannel-tx-cookie-matching.patch:
  mac80211: fix offchannel TX cookie matching.
- patches.kernel.org/macvlan-macvtap-fix-unicast-between-macvtap-interfaces-in-bridge-mode.patch:
  macvlan/macvtap: Fix unicast between macvtap interfaces in
  bridge mode.
- patches.kernel.org/maintaners-update-qualcomm-atheros-addresses.patch:
  MAINTANERS: update Qualcomm Atheros addresses.
- patches.kernel.org/make-packet_statistics-getsockopt-report-consistently-between-ring-and-non-ring.patch:
  make PACKET_STATISTICS getsockopt report consistently between
  ring and non-ring.
- patches.kernel.org/md-raid5-fix-bug-that-could-result-in-reads-from-a-failed-device.patch:
  md/raid5: fix bug that could result in reads from a failed
  device.
- patches.kernel.org/megaraid_sas-fix-instance-access-in-megasas_reset_timer.patch:
  megaraid_sas: Fix instance access in megasas_reset_timer.
- patches.kernel.org/memory-leak-with-rcu_table_free.patch:
  memory leak with RCU_TABLE_FREE.
- patches.kernel.org/mm-avoid-null-pointer-access-in-vm_struct-via-proc-vmallocinfo.patch:
  mm: avoid null pointer access in vm_struct via
  /proc/vmallocinfo.
- patches.kernel.org/mm-thp-tail-page-refcounting-fix.patch:
  mm: thp: tail page refcounting fix.
- patches.kernel.org/mmc-core-ext_csd.raw_-used-in-comparison-but-never-set.patch:
  mmc: core: ext_csd.raw_* used in comparison but never set.
- patches.kernel.org/mmc-core-fix-hangs-related-to-insert-remove-of-cards.patch:
  mmc: core: Fix hangs related to insert/remove of cards.
- patches.kernel.org/net-hold-sock-reference-while-processing-tx-timestamps.patch:
  net: hold sock reference while processing tx timestamps.
- patches.kernel.org/net-xen-netback-correctly-restart-tx-after-a-vm-restore-migrate.patch:
  net: xen-netback: correctly restart Tx after a VM
  restore/migrate.
- patches.kernel.org/netconsole-enable-netconsole-can-make-net_device-refcnt-incorrent.patch:
  netconsole: enable netconsole can make net_device refcnt
  incorrent.
- patches.kernel.org/nfs-don-t-redirty-inode-when-ncommit-0-in.patch:
  nfs: don't redirty inode when ncommit == 0 in
  nfs_commit_unstable_pages.
- patches.kernel.org/nfs-don-t-try-to-migrate-pages-with-active-requests.patch:
  nfs: don't try to migrate pages with active requests.
- patches.kernel.org/nfsd4-fix-open-downgrade-again.patch: nfsd4:
  fix open downgrade, again.
- patches.kernel.org/nfsd4-fix-seqid_mutating_error.patch: nfsd4:
  fix seqid_mutating_error.
- patches.kernel.org/nfsd4-ignore-want-bits-in-open-downgrade.patch:
  nfsd4: ignore WANT bits in open downgrade.
- patches.kernel.org/nfsd4-permit-read-opens-of-executable-only-files.patch:
  nfsd4: permit read opens of executable-only files.
- patches.kernel.org/nfsd4-remove-check-for-a-32-bit-cookie-in-nfsd4_readdir.patch:
  nfsd4: Remove check for a 32-bit cookie in nfsd4_readdir().
- patches.kernel.org/nfsd4-stop-using-nfserr_resource-for-transitory-errors.patch:
  nfsd4: stop using nfserr_resource for transitory errors.
- patches.kernel.org/pci-quirk-mmc-always-check-for-lower-base-frequency-quirk-for-ricoh-1180-e823.patch:
  PCI quirk: mmc: Always check for lower base frequency quirk
  for Ricoh 1180:e823.
- patches.kernel.org/perf-probe-fix-to-show-correct-error-string.patch:
  perf probe: Fix to show correct error string.
- patches.kernel.org/plat-mxc-iomux-v3.h-implicitly-enable-pull-up-down-when-that-s-desired.patch:
  plat-mxc: iomux-v3.h: implicitly enable pull-up/down when
  that's desired.
- patches.kernel.org/platform-fix-error-path-in-samsung-laptop-init.patch:
  Platform: Fix error path in samsung-laptop init.
- patches.kernel.org/platform-samsung_laptop-add-dmi-information-for-samsung.patch:
  platform: samsung_laptop: add dmi information for Samsung
  R700 laptops.
- patches.kernel.org/platform-samsung_laptop-add-support-for-x520-machines.patch:
  Platform: samsung_laptop: add support for X520 machines.
- patches.kernel.org/platform-samsung_laptop-fix-samsung-brightness-min-max.patch:
  platform: samsung_laptop: fix samsung brightness min/max
  calculations.
- patches.kernel.org/platform-samsung_laptop-samsung-backlight-for-r528-r728.patch:
  Platform: samsung_laptop: samsung backlight for R528/R728.
- patches.kernel.org/proc-fix-races-against-execve-of-proc-pid-fd.patch:
  proc: fix races against execve() of /proc/PID/fd**.
- patches.kernel.org/proc-self-numa_maps-restore-huge-tag-for-hugetlb-vmas.patch:
  /proc/self/numa_maps: restore "huge" tag for hugetlb vmas.
- patches.kernel.org/ptrace-don-t-clear-group_stop_sigmask-on-double-stop.patch:
  ptrace: don't clear GROUP_STOP_SIGMASK on double-stop.
- patches.kernel.org/qe-fhci-fixed-the-control-bug.patch: QE/FHCI:
  fixed the CONTROL bug.
- patches.kernel.org/readlinkat-ensure-we-return-enoent-for-the-empty-pathname-for-normal-lookups.patch:
  readlinkat: ensure we return ENOENT for the empty pathname
  for normal lookups.
- patches.kernel.org/revert-nfs-ensure-that-writeback_single_inode-calls-write_inode-when-syncing.patch:
  Revert "NFS: Ensure that writeback_single_inode() calls
  write_inode() when syncing".
- patches.kernel.org/rtnetlink-add-missing-manual-netlink-notification-in.patch:
  rtnetlink: Add missing manual netlink notification in
  dev_change_net_namespaces.
- patches.kernel.org/serial-core-power-up-uart-port-early-before-we-do-set_termios-when-resuming.patch:
  serial-core: power up uart port early before we do set_termios
  when resuming.
- patches.kernel.org/serial-pxa-work-around-for-errata-20.patch:
  serial: pxa: work around for errata #20.
- patches.kernel.org/series:
- patches.kernel.org/staging-hv-add-support-for-2-tb-lun-in-storage-driver.patch:
  Staging: hv: Add support for >2 TB LUN in storage driver.
- patches.kernel.org/staging-quatech_usb2-potential-lost-wakeup-scenario-in-tiocmiwait.patch:
  staging: quatech_usb2: Potential lost wakeup scenario in
  TIOCMIWAIT.
- patches.kernel.org/staging-serqt_usb2-remove-ssu100-from-supported-devices.patch:
  staging: serqt_usb2: remove ssu100 from supported devices.
- patches.kernel.org/target-fix-report-target-port-groups-handling-with-small-allocation-length.patch:
  target: Fix REPORT TARGET PORT GROUPS handling with small
  allocation length.
- patches.kernel.org/tcp-properly-handle-md5sig_pool-references.patch:
  tcp: properly handle md5sig_pool references.
- patches.kernel.org/tcp-properly-update-lost_cnt_hint-during-shifting.patch:
  tcp: properly update lost_cnt_hint during shifting.
- patches.kernel.org/tg3-negate-use_phylib-flag-check.patch:
  tg3: negate USE_PHYLIB flag check.
- patches.kernel.org/time-change-jiffies_to_clock_t-argument-type-to-unsigned-long.patch:
  time: Change jiffies_to_clock_t() argument type to unsigned
  long.
- patches.kernel.org/tracing-fix-returning-of-duplicate-data-after-eof-in-trace_pipe_raw.patch:
  tracing: Fix returning of duplicate data after EOF in
  trace_pipe_raw.
- patches.kernel.org/tty-drop-driver-reference-in-tty_open-fail-path.patch:
  TTY: drop driver reference in tty_open fail path.
- patches.kernel.org/tty-make-tty_add_file-non-failing.patch:
  TTY: make tty_add_file non-failing.
- patches.kernel.org/tty-pty-release-tty-in-all-ptmx_open-fail-paths.patch:
  TTY: pty, release tty in all ptmx_open fail paths.
- patches.kernel.org/tuner_xc2028-allow-selection-of-the-frequency-adjustment-code-for-xc3028.patch:
  tuner_xc2028: Allow selection of the frequency adjustment code
  for XC3028.
- patches.kernel.org/um-fix-ubd-cow-size.patch: um: fix ubd
  cow size.
- patches.kernel.org/update-email-address-for-stable-patch-submission.patch:
  Update email address for stable patch submission.
- patches.kernel.org/usb-add-quirk-for-logitech-c300-web-cam.patch:
  USB: add quirk for Logitech C300 web cam.
- patches.kernel.org/usb-add-reset_resume-for-webcams-shown-to-be-quirky.patch:
  USB: add RESET_RESUME for webcams shown to be quirky.
- patches.kernel.org/usb-cdc-acm-owen-si-30-support.patch: usb:
  cdc-acm: Owen SI-30 support.
- patches.kernel.org/usb-core-devio.c-check-for-printer-class-specific-request.patch:
  usb/core/devio.c: Check for printer class specific request.
- patches.kernel.org/usb-fix-ehci-alignment-error.patch: USB:
  fix ehci alignment error.
- patches.kernel.org/usb-fix-runtime-wakeup-on-ohci.patch: USB:
  Fix runtime wakeup on OHCI.
- patches.kernel.org/usb-for-usb_autopm_get_interface_async-einprogress-is-not-an-error.patch:
  USB: for usb_autopm_get_interface_async -EINPROGRESS is not
  an error.
- patches.kernel.org/usb-ftdi_sio-add-pid-for-sony-ericsson-urban.patch:
  USB: ftdi_sio: add PID for Sony Ericsson Urban.
- patches.kernel.org/usb-ftdi_sio-support-ti-luminary-micro-stellaris-bd-icdi.patch:
  USB: ftdi_sio: Support TI/Luminary Micro Stellaris BD-ICDI
  Board.
- patches.kernel.org/usb-g_printer-fix-bug-in-unregistration.patch:
  USB: g_printer: fix bug in unregistration.
- patches.kernel.org/usb-option-add-various-zte-device-network-interfaces-to.patch:
  USB: option: add various ZTE device network interfaces to
  the blacklist.
- patches.kernel.org/usb-option-add-zte-product-0x0037-to-sendsetup-blacklist.patch:
  USB: option: add ZTE product 0x0037 to sendsetup blacklist.
- patches.kernel.org/usb-option-convert-huawei-k3765-k4505-k4605-reservered.patch:
  USB: option: convert Huawei K3765, K4505, K4605 reservered
  interface to blacklist.
- patches.kernel.org/usb-option-convert-interface-blacklisting-to-bitfields.patch:
  USB: option: convert interface blacklisting to bitfields.
- patches.kernel.org/usb-pid_ns-ensure-pid-is-not-freed-during.patch:
  USB: pid_ns: ensure pid is not freed during
  kill_pid_info_as_uid.
- patches.kernel.org/usb-pl2303-add-id-for-smart-device.patch:
  USB: pl2303: add id for SMART device.
- patches.kernel.org/usb-qcserial-add-device-id-for-hp-un2430-mobile-broadband-module.patch:
  USB: qcserial: add device ID for "HP un2430 Mobile Broadband
  Module".
- patches.kernel.org/usb-qcserial-add-support-for-sierra-wireless-mc8355-gobi-3000.patch:
  USB: qcserial: Add support for Sierra Wireless MC8355/Gobi 3000.
- patches.kernel.org/usb-storage-use-normalized-sense-when-emulating-autosense.patch:
  USB: storage: Use normalized sense when emulating autosense.
- patches.kernel.org/usbmon-vs.-tcpdump-fix-dropped-packet-count.patch:
  usbmon vs. tcpdump: fix dropped packet count.
- patches.kernel.org/user-per-registers-vs.-ptrace-single-stepping.patch:
  user per registers vs. ptrace single stepping.
- patches.kernel.org/uvcvideo-set-alternate-setting-0-on-resume-if-the-bus-has-been-reset.patch:
  uvcvideo: Set alternate setting 0 on resume if the bus has
  been reset.
- patches.kernel.org/vfs-add-device-tag-to-proc-self-mountstats.patch:
  vfs: add "device" tag to /proc/self/mountstats.
- patches.kernel.org/vfs-automount-should-ignore-lookup_follow.patch:
  vfs: automount should ignore LOOKUP_FOLLOW.
- patches.kernel.org/vfs-fix-automount-for-negative-autofs-dentries.patch:
  Refresh.
- patches.kernel.org/vfs-fix-the-remaining-automounter-semantics-regressions.patch:
  VFS: Fix the remaining automounter semantics regressions.
- patches.kernel.org/vfs-pathname-lookup-add-lookup_automount-flag.patch:
  vfs pathname lookup: Add LOOKUP_AUTOMOUNT flag.
- patches.kernel.org/vfs-show-o_cloexe-bit-properly-in-proc-pid-fdinfo-fd-files.patch:
  vfs: show O_CLOEXE bit properly in /proc/<pid>/fdinfo/<fd>
  files.
- patches.kernel.org/viafb-improve-pitch-handling.patch: viafb:
  improve pitch handling.
- patches.kernel.org/viafb-use-display-information-in-info-not-in-var-for.patch:
  viafb: use display information in info not in var for panning.
- patches.kernel.org/wl12xx-fix-forced-passive-scans.patch:
  wl12xx: fix forced passive scans.
- patches.kernel.org/wmi-properly-cleanup-devices-to-avoid-crashes.patch:
  WMI: properly cleanup devices to avoid crashes.
- patches.kernel.org/x86-fix-compilation-bug-in-kprobes-twobyte_is_boostable.patch:
  x86: Fix compilation bug in kprobes' twobyte_is_boostable.
- patches.kernel.org/x86-uv2-workaround-for-uv2-hub-bug-system-global-address-format.patch:
  x86: uv2: Workaround for UV2 Hub bug (system global address
  format).
- patches.kernel.org/xen-pcifront-update-warning-comment-to-use-e820_host.patch:
  xen-pcifront: Update warning comment to use 'e820_host' option.
- patches.kernel.org/xen-swiotlb-fix-wrong-panic.patch:
  xen-swiotlb: Fix wrong panic.
- patches.kernel.org/xhci-amd-isoc-link-trb-chain-bit-quirk.patch:
  xHCI: AMD isoc link TRB chain bit quirk.
- patches.kernel.org/xhci-mem.c-check-for-ring-first_seg-null.patch:
  xhci-mem.c: Check for ring->first_seg != NULL.
- patches.suse/SoN-0006-net-Introduce-sk_allocation-to-allow-addition-of-GFP.patch:
  Refresh.
- patches.suse/SoN-0019-mm-Methods-for-teaching-filesystems-about-PG_swapcac.patch:
  Refresh.
- patches.suse/SoN-0020-nfs-teach-the-NFS-client-how-to-treat-PG_swapcache-p.patch:
  Refresh.
- patches.suse/staging-hv-staging-next-20110829-0327-Staging-hv-storvsc-Add-the-contents-of-hyperv_sto.patch:
  Refresh.
- patches.xen/xen-x86-no-lapic: Refresh.
- patches.arch/s390-37-01-rcu-table-free-leak.diff: Delete.
- patches.arch/x86_uv2_GRU_TLB_fix.patch: Delete.
- patches.drivers/drm-i915-panel-Alwyas-record-the-backlight-level-again:
  Delete.
- patches.drivers/isci-fix-missed-unlock-in-apc_agent_timeout.patch:
  Delete.
- patches.drivers/isci-fix-support-for-large-smp-requests.patch:
  Delete.
- patches.drivers/libsas-set-sas_address-and-device-type-of-rp.patch:
  Delete.
- patches.drivers/xhci-amd-isoc-link-trb-chain-bit-quirk.patch:
  Delete.
- patches.fixes/ata-piix-atapi-fix.patch: Delete.
- patches.fixes/ccwgroup-fix-availability-of-attributes.patch:
  Delete.
- patches.fixes/drm-radeon-kms-fix-i2c-masks.patch: Delete.
- patches.fixes/hp_gobi3000id_1bfac90d1b8e63a4d44158c3445d8fda3fb6d5eb.diff:
  Delete.
- patches.fixes/jsm-remove-buggy-write-queue.patch: Delete.
- patches.fixes/vfs-automount-should-ignore-lookup_follow.patch:
  Delete.
- patches.fixes/vfs-fix-the-remaining-automounter-semantics-regressi.patch:
  Delete.
- patches.fixes/vfs-pathname-lookup-add-lookup_automount-flag.patch:
  Delete.
- patches.suse/staging-hv-staging-next-20111001-0129-Staging-hv-Add-support-for-2-TB-LUN-in-storage-dr.patch:
  Delete.
* Thu Nov  3 2011 jjolly@suse.de
- patches.arch/s390-39-01-qeth-remove-warning.txt: qeth: remove
  kernel warning qeth_core_main.c:884 (bnc#728043,LTC#76146).
* Thu Nov  3 2011 jjolly@suse.de
- rpm/kernel-binary.spec.in: Removed kerntypes references
  (bnc#726400,LTC#76221)
- patches.suse/s390-Kerntypes.diff: Delete.
* Thu Nov  3 2011 mszeredi@suse.cz
- patches.fixes/hfs-fix-hfs_find_init-sb-ext_tree-null-ptr-oops.patch:
  hfs: fix hfs_find_init() sb->ext_tree NULL ptr oops
  (CVE-2011-2203 bnc#699709).
* Thu Nov  3 2011 jdelvare@suse.de
- patches.fixes/drm-radeon-kms-fix-i2c-masks.patch: Add git commit
  ID.
* Thu Nov  3 2011 mhocko@suse.cz
- patches.fixes/oom-thaw-threads-if-oom-killed-thread-is-frozen-befo.patch:
  oom: thaw threads if oom killed thread is frozen before
  deferring (bnc#723999).
* Thu Nov  3 2011 jankit@suse.de
- patches.fixes/scsi_dh_alua-add-one-more-check-condition-for-alua-handler:
  scsi_dh_alua: Add one more check-condition for alua handler
  (bnc#727367).
- patches.fixes/scsi_dh_alua-fix-time-interval-for-alua-rtpg-commands:
  scsi_dh_alua: Fix the time inteval for alua rtpg commands
  (bnc#727367).
* Thu Nov  3 2011 tiwai@suse.de
- patches.drivers/drm-i915-set-the-right-SDVO-transcoder-for-CPT:
  drm/i915: set the right SDVO transcoder for CPT (bnc#715031).
* Thu Nov  3 2011 tiwai@suse.de
- patches.drivers/lis3lv02d-Avoid-zero-division: lis3lv02d:
  Avoid zero-division (bnc#728035).
* Thu Nov  3 2011 duwe@suse.de
- patches.drivers/ipr-add-bluehawk-IDs: ipr: add bluehawk PCI IDs
  (bnc#726214).
- patches.fixes/perf-oprofile-fix: perf: Optimize event scheduling
  locking (bnc#723171).
* Thu Nov  3 2011 jjolly@suse.de
- patches.drivers/ipoib-sp1-compatible-options.patch: Add
  SP1-compatible module options to ipoib driver (bnc#720456).
- patches.drivers/srp-sp1-compatible-options.patch: Add
  SP1-compatible module options to srp driver (bnc#720456).
* Thu Nov  3 2011 nfbrown@suse.de
- patches.fixes/rpc-cred-test: NFS/sunrpc: don't use a credential
  with extra groups (bnc#725878).
* Wed Nov  2 2011 trenn@suse.de
- patches.suse/acpi_osi_sle11_not_winp_key.patch: Provide
  possibility for vendors to workaround WIN-P key issue
  (kernel@suse.de list, subject: About acpi osi string for
  SUSE issue).
* Wed Nov  2 2011 mgalbraith@suse.de
- Fix typo
- patches.fixes/sched-Fix-idle_cpu: Refresh.
* Tue Nov  1 2011 tiwai@suse.de
- patches.drivers/drm-i915-panel-Alwyas-record-the-backlight-level-again:
  Refresh.  Update tags.
* Tue Nov  1 2011 mgalbraith@suse.de
- patches.fixes/sched-Fix-idle_cpu:
  sched: Fix idle_cpu() (bnc#726023).
- patches.fixes/sched-Request-for-idle-balance-during-nohz-idle-load-balance:
  sched: Request for idle balance during nohz idle load balance (bnc#726023).
- patches.fixes/sched-Use-resched-IPI-to-kick-off-the-nohz-idle-balance:
  sched: Use resched IPI to kick off the nohz idle balance (bnc#726023).
- patches.suse/kdb-v4.4-3.1-common-1: Refresh.
* Tue Nov  1 2011 mmarek@suse.cz
- patches.drivers/igb-Fix-for-Alt-MAC-Address-feature-on-82580-and-la.patch:
  igb: Fix for Alt MAC Address feature on 82580 and later devices.
* Mon Oct 31 2011 trenn@suse.de
  This one is mainline:
- patches.arch/acpi_ec_delay_param.patch: Delete.
* Mon Oct 31 2011 hare@suse.de
- patches.suse/fcoe-reduce-max_sectors: fcoe: Reduce max_sectors
  to 1024 (bnc#695898).
* Mon Oct 31 2011 hare@suse.de
- patches.fixes/scsi-edd-Treat-XPRS-host-bus-type-the-same-as.patch:
  edd: Treat "XPRS" host bus type the same as "PCI" (bnc#726699).
- patches.fixes/scsi-libfc-avoid-exchanges-collision-during-lport.patch:
  libfc: avoid exchanges collision during lport reset
  (bnc#726699).
- patches.fixes/scsi-libfc-fix-checking-FC_TYPE_BLS.patch: libfc:
  fix checking FC_TYPE_BLS (bnc#726699).
- patches.fixes/scsi-libfc-improve-flogi-retries-to-avoid-lport-s.patch:
  libfc: improve flogi retries to avoid lport stuck (bnc#726699).
- patches.drivers/fcoe-0029-libfc-fix_deadlock_bug_in_fc_e.patch:
  Delete obsolete patch.
* Sun Oct 30 2011 mmarek@suse.cz
- patches.drivers/0001-iwlagn-separate-firmware-version-warning.patch:
  iwlagn: separate firmware version warning.
- patches.drivers/0002-iwlagn-bump-firmware-API-for-some-devices.patch:
  iwlagn: bump firmware API for some devices.
* Fri Oct 28 2011 tonyj@suse.de
- patches.fixes/perf-sched-fix-script-command-documentation.patch:
  perf sched: Fix script command documentation (bnc#726156).
* Fri Oct 28 2011 tonyj@suse.de
- patches.fixes/acpi-introduce-acpi_rsdp-parameter-for-kdump.patch:
  ACPI: introduce "acpi_rsdp=" parameter for kdump (bnc#717263).
* Fri Oct 28 2011 mfasheh@suse.com
- patches.suse/0001-vfs-allow-proc-pid-maps-to-return-a-custom-device.patch:
  vfs: allow /proc/pid/maps to return a custom device
  (bnc#672923).
- patches.suse/0002-btrfs-Introduce-btrfs_get_maps_dev.patch:
  btrfs: Introduce btrfs_get_maps_dev() (bnc#672923).
* Fri Oct 28 2011 jdelvare@suse.de
- patches.fixes/ata-piix-atapi-fix.patch: Add upstream commit id.
* Fri Oct 28 2011 oneukum@suse.de
- patches.fixes/broadcom_softsailing.diff: Fix Broadcom device
  IDs (bnc#719296).
* Fri Oct 28 2011 oneukum@suse.de
- patches.fixes/bug-722429_0001-add-device-entry-for-Broadcom-Valentine-combo-card.patch:
  add device entry for Broadcom Valentine combo card. From SP1. (bnc#726176).
* Fri Oct 28 2011 oneukum@suse.de
- patches.fixes/hp_gobi3000id_1bfac90d1b8e63a4d44158c3445d8fda3fb6d5eb.diff:
  new device ID to make HP's rebranded Gobi3000 work (bnc#726999)
* Thu Oct 27 2011 jbohac@suse.cz
- patches.fixes/ip_vs-fix-netns-shutdown-startup-deadlock.patch:
  IPVS netns shutdown/startup dead-lock (bnc#725350).
* Thu Oct 27 2011 ohering@suse.de
- patches.suse/staging-hv-mousevsc-module-name.patch:
  hv_mouse: use KBUILD_MODNAME as drivername.
* Thu Oct 27 2011 jbohac@suse.cz
- patches.suse/ip6_tunnel-add-optional-fwmark-inherit.patch:
  ip6_tunnel: add optional fwmark inherit (bnc#725346).
* Thu Oct 27 2011 tiwai@suse.de
- patches.drivers/0001-rt2x00-Enable-PA_PE-bits-in-TX_PIN_CFG-according-to-.patch:
  rt2x00: Enable PA_PE bits in TX_PIN_CFG according to active band
  (bnc#720741).
- patches.drivers/0002-rt2x00-Don-t-disable-G0-PA_PE-bit-in-case-of-BT-coex.patch:
  rt2x00: Don't disable G0 PA_PE bit in case of BT coexistence
  (bnc#720741).
- patches.drivers/0003-rt2x00-Add-support-for-RT3572-RT3592-RT3592-Bluetoot.patch:
  rt2x00: Add support for RT3572/RT3592/RT3592+Bluetooth combo
  card.
- patches.drivers/0004-rt2x00-Interface-sequence-lock-doesn-t-have-to-disab.patch:
  rt2x00: Interface sequence lock doesn't have to disable
  interrupts.
- patches.drivers/0005-rt2x00-Enabled-rt35xx-device-support-by-default.patch:
  rt2x00: Enabled rt35xx device support by default (bnc#720741).
- patches.drivers/0006-drivers-net-Remove-unnecessary-semicolons.patch:
  drivers/net: Remove unnecessary semicolons (bnc#720741).
- patches.drivers/0007-net-remove-interrupt.h-inclusion-from-netdevice.h.patch:
  net: remove interrupt.h inclusion from netdevice.h (bnc#720741).
- patches.drivers/0008-rt2x00-fix-possible-memory-corruption-in-case-of-inv.patch:
  rt2x00: fix possible memory corruption in case of invalid
  rxdesc.size (bnc#720741).
- patches.drivers/0009-rt2x00-reset-usb-devices-at-probe.patch:
  rt2x00: reset usb devices at probe (bnc#720741).
- patches.drivers/0010-rt2x00-Fix-unspeficied-typo.patch: rt2x00:
  Fix unspeficied typo (bnc#720741).
- patches.drivers/0011-rt2x00-Don-t-use-queue-entry-as-parameter-when-creat.patch:
  rt2x00: Don't use queue entry as parameter when creating TX
  descriptor (bnc#720741).
- patches.drivers/0012-rt2x00-Reduce-window-of-a-queue-s-tx-lock.patch:
  rt2x00: Reduce window of a queue's tx lock (bnc#720741).
- patches.drivers/0013-rt2x00-Properly-identify-rt2800usb-devices.patch:
  rt2x00: Properly identify rt2800usb devices (bnc#720741).
- patches.drivers/0014-rt2x00-Implement-tx_frames_pending-mac80211-callback.patch:
  rt2x00: Implement tx_frames_pending mac80211 callback function.
- patches.drivers/0015-rt2800usb-Add-new-device-ID-for-Belkin.patch:
  rt2800usb: Add new device ID for Belkin.
- patches.drivers/0016-rt2x00-Fix-compilation-without-CONFIG_RT2X00_LIB_CRY.patch:
  rt2x00: Fix compilation without CONFIG_RT2X00_LIB_CRYPTO.
- patches.drivers/0017-rt2x00-Fix-PCI-interrupt-processing-race-on-SMP-syst.patch:
  rt2x00: Fix PCI interrupt processing race on SMP systems.
- patches.drivers/0018-rt2x00-Add-new-chipset-support.patch:
  rt2x00: Add new chipset support.
* Wed Oct 26 2011 eich@suse.de
- patches.drivers/drm-i915-fix-intel-sdvo-lvds-connected-status.diff:
  Fix detection of connected LVDS sdvo devices (bnc#707270,
  bnc #710575).
* Wed Oct 26 2011 mmarek@suse.cz
- patches.fixes/acpiphp-ignore-root-bridges-using-PCIe-native-hotplug:
  PCI / ACPI: Make acpiphp ignore root bridges using PCIe native
  hotplug (bnc#714552).
* Wed Oct 26 2011 jjolly@suse.de
- supported.conf: Added rds_rdma and rds_tcp from /net/rds
  (bnc#708204)
* Tue Oct 25 2011 ohering@suse.de
- patches.xen/xencons-tty_mutex.patch:
  tty deadlock in kernel-xen, xenconsole (bnc#726333).
* Tue Oct 25 2011 jslaby@suse.de
- Linux 3.0.8.
- patches.arch/x86-fix-S4-regression: Delete.
- patches.kernel.org/arm-7113-1-mm-align-bank-start-to-max_order_nr_pages.patch:
  Delete.
- patches.kernel.org/arm-7117-1-perf-fix-hw_cache_-events-on-cortex-a9.patch:
  Delete.
- patches.kernel.org/avoid-using-variable-length-arrays-in-kernel-sys.c.patch:
  Delete.
- patches.kernel.org/cifs-fix-err_ptr-dereference-in-cifs_get_root.patch:
  Delete.
- patches.kernel.org/cputimer-cure-lock-inversion.patch: Delete.
- patches.kernel.org/drm-radeon-kms-atom-fix-handling-of-fb-scratch-indices.patch:
  Delete.
- patches.kernel.org/drm-ttm-ensure-ttm-for-new-node-is-bound-before-calling-move_notify.patch:
  Delete.
- patches.kernel.org/drm-ttm-unbind-ttm-before-destroying-node-in-accel-move-cleanup.patch:
  Delete.
- patches.kernel.org/firewire-sbp2-fix-panic-after-rmmod-with-slow-targets.patch:
  Delete.
- patches.kernel.org/fuse-fix-memory-leak.patch: Delete.
- patches.kernel.org/hfsplus-ensure-bio-requests-are-not-smaller-than-the-hardware-sectors.patch:
  Delete.
- patches.kernel.org/hid-magicmouse-ignore-ivalid-report-id-while-switching-modes-v2.patch:
  Delete.
- patches.kernel.org/hid-usbhid-add-support-for-sigma-micro-chip.patch:
  Delete.
- patches.kernel.org/hwmon-w83627ehf-properly-report-thermal-diode-sensors.patch:
  Delete.
- patches.kernel.org/mm-fix-race-between-mremap-and-removing-migration-entry.patch:
  Delete.
- patches.kernel.org/platform-fix-samsung-laptop-dmi-identification-for-n150-n210-220-n230.patch:
  Delete.
- patches.kernel.org/uvcvideo-fix-crash-when-linking-entities.patch:
  Delete.
- patches.kernel.org/x25-prevent-skb-overreads-when-checking-call-user-data.patch:
  Delete.
- patches.kernel.org/xfs-do-not-update-xa_last_pushed_lsn-for-locked-items.patch:
  Delete.
- patches.kernel.org/xfs-force-the-log-if-we-encounter-pinned-buffers-in-.iop_pushbuf.patch:
  Delete.
- patches.kernel.org/xfs-revert-to-using-a-kthread-for-ail-pushing.patch:
  Delete.
- patches.kernel.org/xfs-start-periodic-workers-later.patch:
  Delete.
- patches.kernel.org/xfs-use-a-cursor-for-bulk-ail-insertion.patch:
  Delete.
* Tue Oct 25 2011 mszeredi@suse.cz
- fix LOOKUP_PARENT -> LOOKUP_CONTINUE
    patches.fixes/vfs-automount-should-ignore-lookup_follow.patch
    patches.fixes/vfs-pathname-lookup-add-lookup_automount-flag.patch
    patches.kernel.org/vfs-fix-automount-for-negative-autofs-dentries.patch
* Tue Oct 25 2011 mszeredi@suse.cz
- patches.fixes/vfs-automount-should-ignore-lookup_follow.patch:
  Refresh.
- patches.fixes/vfs-pathname-lookup-add-lookup_automount-flag.patch:
  Refresh.
- Reenable patches.kernel.org/vfs-fix-automount-for-negative-autofs-dentries.patch
* Mon Oct 24 2011 ohering@suse.de
- patches.suse/SoN-0009b-netvm-Propagate-page-pfmemalloc-to-skb.patch:
  Add hack to avoid crash in propagate_pfmemalloc_skb (bnc#726075)
* Mon Oct 24 2011 mgalbraith@suse.de
- Update config files.
- patches.fixes/sched-reinstate-FAIR_SLEEPERS-feature:
  sched: reinstate FAIR_SLEEPERS feature (bnc#724577).
- Fix regression caused by FAIR_SLEEPERS_ON_BY_DEFAULT being
  mistakenly applied to GENTLE_FAIR_SLEEPERS.  Because s390
  did not have FAIR_SLEEPERS_ON_BY_DEFAULT set, it ended up
  with full sleeper credit, where it had none at all.
  Per agreement with IBM, SP2 will have sleeper fairness
  enabled like everyone else.  FAIR_SLEEPERS_ON_BY_DEFAULT
  config option is now superfluous, so remove it.  Restore
  the FAIR_SLEEPERS scheduler feature for SP2 (status-quo),
  and plan on that being removed in SLE12, with SCHED_BATCH
  being used as intended for loads which do not react well
  to wakeup preemption.
* Mon Oct 24 2011 mmarek@suse.cz
- patches.drivers/benet-32bit-fix: benet: fix build error on
  32bit arch.
* Mon Oct 24 2011 ohering@suse.de
- patches.suse/staging-hv-pata_piix-ignore-disks.patch:
  Update comments in code and reduce patch size
* Mon Oct 24 2011 mmarek@suse.cz
- patches.drivers/be2net-update-version-2.101.346u-to-2.102.147s.patch:
  Obsolete, delete.
* Mon Oct 24 2011 mmarek@suse.cz
- patches.drivers/0000-be2net-fix-netdev_stats_update.patch:
  be2net: fix netdev_stats_update (bnc#722092).
- patches.drivers/0001-be2net-get-rid-of-multi_rxq-module-param.patch:
  be2net: get rid of multi_rxq module param (bnc#722092).
- patches.drivers/0002-be2net-fix-initialization-of-vlan_prio_bmap.patch:
  be2net: fix initialization of vlan_prio_bmap (bnc#722092).
- patches.drivers/0003-be2net-fix-certain-cmd-failure-logging.patch:
  be2net: fix certain cmd failure logging (bnc#722092).
- patches.drivers/0004-be2net-create-destroy-rx-queues-on-interface-open-c.patch:
  be2net: create/destroy rx-queues on interface open/close
  (bnc#722092).
- patches.drivers/0005-be2net-clear-intr-bit-in-be_probe.patch:
  be2net: clear intr bit in be_probe() (bnc#722092).
- patches.drivers/0006-benet-Add-missing-comma-between-constant-string-arr.patch:
  benet: Add missing comma between constant string array
  (bnc#722092).
- patches.drivers/0007-be2net-account-for-skb-allocation-failures.patch:
  be2net: account for skb allocation failures (bnc#722092).
- patches.drivers/0008-be2net-move-to-new-vlan-model.patch:
  be2net: move to new vlan model (bnc#722092).
- patches.drivers/0009-be2net-cleanup-and-refactor-stats-code.patch:
  be2net: cleanup and refactor stats code (bnc#722092).
- patches.drivers/0010-be2net-use-stats-sync-to-read-write-64-bit-stats.patch:
  be2net: use stats-sync to read/write 64-bit stats (bnc#722092).
- patches.drivers/0011-be2net-remove-wrong-and-unnecessary-calls-to-netif_.patch:
  be2net: remove wrong and unnecessary calls to
  netif_carrier_off() (bnc#722092).
- patches.drivers/0012-be2net-no-need-to-query-link-status.patch:
  be2net: no need to query link status (bnc#722092).
- patches.drivers/0013-be2net-non-member-vlan-pkts-not-received-in-promisc.patch:
  be2net: non-member vlan pkts not received in promiscous mode
  (bnc#722092).
- patches.drivers/0014-be2net-use-RX_FILTER-cmd-to-program-multicast-addre.patch:
  be2net: use RX_FILTER cmd to program multicast addresses
  (bnc#722092).
- patches.drivers/0015-be2net-add-support-for-flashing-Teranetics-PHY-firmw.patch:
  be2net: add support for flashing Teranetics PHY firmware
  (bnc#722092).
- patches.drivers/0016-be2net-drop-pkts-that-do-not-belong-to-the-port.patch:
  be2net: drop pkts that do not belong to the port (bnc#722092).
- patches.drivers/0017-be2net-fix-cmd-rx-filter-not-notifying-MCC.patch:
  be2net: fix cmd-rx-filter not notifying MCC (bnc#722092).
- patches.drivers/0018-benet-fix-build-error-on-32bit-arch.patch:
  benet: fix build error on 32bit arch (bnc#722092).
- patches.drivers/0019-be2net-Storing-the-vid-got-by-the-grp5-event-inst.patch:
  be2net: Storing the 'vid' got by the grp5 event instead of
  storing the vlan_tag (bnc#722092).
- patches.drivers/0020-be2net-Fix-race-in-posting-rx-buffers.patch:
  be2net: Fix race in posting rx buffers (bnc#722092).
- patches.drivers/0021-be2net-get-rid-of-memory-mapped-pci-cfg-space-addre.patch:
  be2net: get rid of memory mapped pci-cfg space address
  (bnc#722092).
- patches.drivers/0022-be2net-fix-erx-rx_drops_no_frags-wrap-around.patch:
  be2net: fix erx->rx_drops_no_frags wrap around (bnc#722092).
- patches.drivers/0023-be2net-increase-FW-update-completion-timeout.patch:
  be2net: increase FW update completion timeout (bnc#722092).
- patches.drivers/0024-be2net-remove-unused-variable.patch:
  be2net: remove unused variable (bnc#722092).
- patches.drivers/0025-benet-remove-bogus-unlikely-on-vlan-check.patch:
  benet: remove bogus "unlikely" on vlan check (bnc#722092).
- patches.drivers/0026-be2net-fix-multicast-filter-programming.patch:
  be2net: fix multicast filter programming (bnc#722092).
- patches.drivers/0027-be2net-Show-newly-flashed-FW-ver-in-ethtool.patch:
  be2net: Show newly flashed FW ver in ethtool (bnc#722092).
- patches.drivers/0028-be2net-Add-60-second-delay-to-allow-FAT-dump-comple.patch:
  be2net: Add 60 second delay to allow FAT dump completion on
  recovery from EEH (bnc#722092).
- patches.drivers/0029-be2net-Change-the-data-type-of-the-on-die-temperat.patch:
  be2net: Change the data type of the 'on die temperature' stat
  (bnc#722092).
- patches.drivers/0030-be2net-Fixed-Endianness-issues-in-the-response-read.patch:
  be2net: Fixed Endianness issues in the response read log length
  field while retrieving FAT data (bnc#722092).
- patches.drivers/0031-be2net-Modified-PCI-MaxReadReq-size-to-4096-bytes.patch:
  be2net: Modified PCI MaxReadReq size to 4096 bytes (bnc#722092).
- patches.drivers/0032-be2net-Making-die-temperature-ioctl-call-async.patch:
  be2net: Making die temperature ioctl call async (bnc#722092).
- patches.drivers/0033-be2net-Changed-version-to-4.1.227.patch:
  be2net: Changed version to 4.1.227 (bnc#722092).
* Mon Oct 24 2011 hare@suse.de
- patches.fixes/scsi-dh-rdac-allow-for-empty-scsi_dh_data-pointer:
  scsi_dh_rdac: Allow for empty scsi_dh_data pointer (bnc#721738).
* Mon Oct 24 2011 nfbrown@suse.de
- patches.fixes/nfs-check-rpcclient-validity.patch: Check validity
  of cl_rpcclient in nfs_server_list_show (bnc#717884).
* Fri Oct 21 2011 hare@suse.de
- patches.drivers/hpsa-remove-closed-source-hpvsa-hooks.patch:
  hpsa: remove closed source hpvsa hooks (bnc#703426,FATE#311201).
- patches.drivers/hpsa-sanitize-version-number.patch: hpsa:
  sanitize version number (bnc#703426,FATE#311201).
* Fri Oct 21 2011 hare@suse.de
- patches.fixes/scsi-check-for-invalid-sdev-in-scsi_prep_fn:
  Check for invalid sdev in scsi_prep_fn() (bnc#722569).
* Fri Oct 21 2011 hare@suse.de
- patches.suse/dm-mpath-accept-failed-paths: Fix crash on
  multipath destroy (bnc#721738).
* Fri Oct 21 2011 trenn@suse.de
- patches.arch/x86_do_not_set_nvs_ram_busy.patch: x86: allow
  NVS can be accessed by driver (bnc#725592).
* Fri Oct 21 2011 gregkh@suse.de
- patches.drivers/xhci-amd-isoc-link-trb-chain-bit-quirk.patch:
  xHCI: AMD isoc link TRB chain bit quirk (bnc#721045).
* Thu Oct 20 2011 gregkh@suse.de
- patches.arch/qeth-l3-add-large_send-and-checksumming-sysfs-attributes-again.patch:
  qeth: l3 add large_send and checksumming sysfs attributes again
  (bnc#718149).
* Thu Oct 20 2011 gregkh@suse.de
- 3.0.8 patches:
- patches.kernel.org/arm-7113-1-mm-align-bank-start-to-max_order_nr_pages.patch:
  ARM: 7113/1: mm: Align bank start to MAX_ORDER_NR_PAGES.
- patches.kernel.org/arm-7117-1-perf-fix-hw_cache_-events-on-cortex-a9.patch:
  ARM: 7117/1: perf: fix HW_CACHE_* events on Cortex-A9.
- patches.kernel.org/avoid-using-variable-length-arrays-in-kernel-sys.c.patch:
  Avoid using variable-length arrays in kernel/sys.c.
- patches.kernel.org/cifs-fix-err_ptr-dereference-in-cifs_get_root.patch:
  CIFS: Fix ERR_PTR dereference in cifs_get_root.
- patches.kernel.org/cputimer-cure-lock-inversion.patch: cputimer:
  Cure lock inversion.
- patches.kernel.org/drm-radeon-kms-atom-fix-handling-of-fb-scratch-indices.patch:
  drm/radeon/kms/atom: fix handling of FB scratch indices.
- patches.kernel.org/drm-ttm-ensure-ttm-for-new-node-is-bound-before-calling-move_notify.patch:
  drm/ttm: ensure ttm for new node is bound before calling
  move_notify().
- patches.kernel.org/drm-ttm-unbind-ttm-before-destroying-node-in-accel-move-cleanup.patch:
  drm/ttm: unbind ttm before destroying node in accel move
  cleanup.
- patches.kernel.org/firewire-sbp2-fix-panic-after-rmmod-with-slow-targets.patch:
  firewire: sbp2: fix panic after rmmod with slow targets.
- patches.kernel.org/fuse-fix-memory-leak.patch: fuse: fix
  memory leak.
- patches.kernel.org/hfsplus-ensure-bio-requests-are-not-smaller-than-the-hardware-sectors.patch:
  hfsplus: ensure bio requests are not smaller than the hardware
  sectors.
- patches.kernel.org/hid-magicmouse-ignore-ivalid-report-id-while-switching-modes-v2.patch:
  HID: magicmouse: ignore 'ivalid report id' while switching
  modes, v2.
- patches.kernel.org/hid-usbhid-add-support-for-sigma-micro-chip.patch:
  HID: usbhid: Add support for SiGma Micro chip.
- patches.kernel.org/hwmon-w83627ehf-properly-report-thermal-diode-sensors.patch:
  hwmon: (w83627ehf) Properly report thermal diode sensors.
- patches.kernel.org/mm-fix-race-between-mremap-and-removing-migration-entry.patch:
  mm: fix race between mremap and removing migration entry.
- patches.kernel.org/platform-fix-samsung-laptop-dmi-identification-for-n150-n210-220-n230.patch:
  Platform: fix samsung-laptop DMI identification for
  N150/N210/220/N230.
- patches.kernel.org/uvcvideo-fix-crash-when-linking-entities.patch:
  uvcvideo: Fix crash when linking entities.
- patches.kernel.org/vfs-fix-automount-for-negative-autofs-dentries.patch:
  VFS: Fix automount for negative autofs dentries.
- patches.kernel.org/x25-prevent-skb-overreads-when-checking-call-user-data.patch:
  x25: Prevent skb overreads when checking call user data.
- patches.kernel.org/xfs-do-not-update-xa_last_pushed_lsn-for-locked-items.patch:
  xfs: do not update xa_last_pushed_lsn for locked items.
- patches.kernel.org/xfs-force-the-log-if-we-encounter-pinned-buffers-in-.iop_pushbuf.patch:
  xfs: force the log if we encounter pinned buffers in
  .iop_pushbuf.
- patches.kernel.org/xfs-revert-to-using-a-kthread-for-ail-pushing.patch:
  xfs: revert to using a kthread for AIL pushing.
- patches.kernel.org/xfs-start-periodic-workers-later.patch:
  xfs: start periodic workers later.
- patches.kernel.org/xfs-use-a-cursor-for-bulk-ail-insertion.patch:
  xfs: use a cursor for bulk AIL insertion.
- patches.suse/xfs-dmapi-obtain-vfsmount-for-use-in-xfs_dm_rdwr:
  Refresh.
- patches.suse/xfs-restore-dmapi-infrastructure: Refresh.
- patches.suse/mm-thp-fix-race-between-migration-mremap.patch:
  Delete.
* Thu Oct 20 2011 mmarek@suse.cz
- patches.drivers/tg3-fix-VLAN-tagging-regression: tg3: fix VLAN
  tagging regression (bnc#724865).
* Thu Oct 20 2011 mmarek@suse.cz
- patches.drivers/via-velocity-revive-txcsum_offload:
  via-velocity: revive txcsum_offload option for backwards
  compatibility (bnc#720459).
* Thu Oct 20 2011 jbohac@suse.cz
- patches.fixes/net-allow-vlan-traffic-to-be-received-under-bond.patch:
  net: allow vlan traffic to be received under bond (bnc#725344).
* Thu Oct 20 2011 trenn@suse.de
  Update to latest x86-tip version:
- patches.arch/x2apic_opt_out.patch: Refresh.
* Thu Oct 20 2011 mmarek@suse.cz
- patches.drivers/r8169-dummy-option: r8169: add dummy
  rx_copybreak option for backwards compatibility (bnc#720459).
- patches.drivers/via-velocity-dummy-option: via-velocity: add
  dummy int_works option for backwards compatibility (bnc#720459).
* Thu Oct 20 2011 jjolly@suse.de
- patches.arch/s390-38-01-qdio-partial_eqbs.patch: qdio: EQBS
  retry after CCQ 96 (bnc#725424,LTC#76117).
* Thu Oct 20 2011 hare@suse.de
- patches.fixes/dm-table-set-flush-capability: Rediff patch
  to apply.
* Thu Oct 20 2011 hare@suse.de
- patches.fixes/dm-table-set-flush-capability: dm table: set
  flush capability based on underlying devices (bnc#725077).
* Wed Oct 19 2011 dsterba@suse.cz
- patches.suse/btrfs-push-up-clear_extent_bit-errors-to-callers:
  Refresh.
* Wed Oct 19 2011 dsterba@suse.cz
- patches.suse/btrfs-0940-introduce-mount-option-no_space_cache.patch:
  Btrfs: introduce mount option no_space_cache (FATE#306586).
- patches.suse/btrfs-0941-don-t-skip-writing-out-a-empty-block-groups-ca.patch:
  Btrfs: don't skip writing out a empty block groups cache
  (FATE#306586).
- patches.suse/btrfs-0942-add-a-io_ctl-struct-and-helpers-for-dealing-wi.patch:
  Btrfs: add a io_ctl struct and helpers for dealing with the
  space cache (FATE#306586).
- patches.suse/btrfs-0943-check-the-return-value-of-filemap_write_and_wa.patch:
  Btrfs: check the return value of filemap_write_and_wait in
  the space cache (FATE#306586).
- patches.suse/btrfs-0944-take-overflow-into-account-in-reserving-space.patch:
  Btrfs: take overflow into account in reserving space
  (FATE#306586).
- patches.suse/btrfs-0945-inline-checksums-into-the-disk-free-space-cach.patch:
  Btrfs: inline checksums into the disk free space cache
  (FATE#306586).
- patches.suse/btrfs-0946-wait-for-ordered-extents-if-we-didn-t-reclaim-.patch:
  Btrfs: wait for ordered extents if we didn't reclaim enough
  (FATE#306586).
- patches.suse/btrfs-0947-fix-the-amount-of-space-reserved-for-unlink.patch:
  Btrfs: fix the amount of space reserved for unlink
  (FATE#306586).
- patches.suse/btrfs-8024-fix-oops-on-failure-path.patch: btrfs:
  fix oops on failure path (FATE#306586).
- patches.suse/btrfs-add-btrfs_panic: Refresh.
- patches.suse/btrfs-push-up-clear_extent_bit-errors-to-callers:
  Refresh.
- patches.suse/btrfs-push-up-lock_extent-errors-to-callers:
  Refresh.
- patches.suse/btrfs-push-up-unlock_extent-errors-to-callers:
  Refresh.
- patches.suse/btrfs-0940-don-t-skip-writing-out-a-empty-block-groups-ca.patch:
  Delete.
- patches.suse/btrfs-0941-check-the-return-value-of-filemap_write_and_wa.patch:
  Delete.
- patches.suse/btrfs-0942-take-overflow-into-account-in-reserving-space.patch:
  Delete.
* Wed Oct 19 2011 jjolly@suse.de
- patches.fixes/linux-3.0.0-fix-strim.txt: lib/string: Fix strim
  regression on all-whitespace strings (bnc#717248).
* Wed Oct 19 2011 hare@suse.de
- patches.fixes/scsi_dh-do-not-access-invalid-sdev: scsi_dh:
  Do not access invalid sdev (bnc#721738).
* Wed Oct 19 2011 jankit@suse.de
- patches.fixes/libfc-check-fc_block_scsi_eh-return-success: libfc
  - fc_block_scsi_eh returns SUCCESS instead of zero (bnc#722414).
* Wed Oct 19 2011 hare@suse.de
- patches.fixes/dm-mpath-reattach-dh: Remove obsolete patch
  (bnc#719911).
* Wed Oct 19 2011 hare@suse.de
- patches.drivers/lpfc-8.3.5.48.1p-update: Update lpfc to
  8.3.5.48.1p (bnc#714274).
* Wed Oct 19 2011 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-005-Add-support-for-vref-out-based-mute-LED-con:
  ALSA: hda - Add support for vref-out based mute LED control
  on IDT codecs (bnc#724800).
- patches.drivers/alsa-sp2-hda-006-Add-CONFIG_SND_HDA_POWER_SAVE-to-stac_vrefout:
  ALSA: hda - Add CONFIG_SND_HDA_POWER_SAVE to stac_vrefout_set()
  (bnc#724800).
* Tue Oct 18 2011 dsterba@suse.cz
- patches.suse/btrfs-0937-break-out-of-orphan-cleanup-if-we-can-t-make-p.patch:
  Refresh.
* Tue Oct 18 2011 jbeulich@novell.com
- patches.drivers/acpi_apei_disable_suse.patch: Fix two typos.
* Tue Oct 18 2011 jbeulich@novell.com
- Update Xen patches to c/s 1123.
- patches.xen/xen3-hwmon-coretemp-01-add-core-pkg-threshold-support-to-coretemp.patch:
  hwmon: (coretemp) Add core/pkg threshold support to Coretemp
  (bnc#698797, FATE#311941).
- patches.xen/xen3-hwmon-coretemp-02-initialize-tmin.patch: hwmon:
  (coretemp) Initialize tmin (bnc#698797, FATE#311941).
- patches.xen/xen3-hwmon-coretemp-03-drop-duplicate-function-get_pkg_tjmax.patch:
  hwmon: (coretemp) Drop duplicate function get_pkg_tjmax
  (bnc#698797, FATE#311941).
- patches.xen/xen3-hwmon-coretemp-04-let-the-user-force-tjmax.patch:
  hwmon: (coretemp) Let the user force TjMax (bnc#698797,
  FATE#311941).
- patches.xen/xen3-hwmon-coretemp-05-dont-use-threshold-registers-for-tempX_max.patch:
  hwmon: (coretemp) Don't use threshold registers for tempX_max
  (bnc#698797, FATE#311941).
- patches.xen/xen3-hwmon-coretemp-09-fixup-platform-device-id-change.patch:
  hwmon: (coretemp) Fixup platform device ID change (bnc#698797,
  FATE#311941).
* Tue Oct 18 2011 dsterba@suse.cz
- patches.suse/btrfs-0106-fix-recursive-auto-defrag.patch: Btrfs:
  fix recursive auto-defrag (FATE#306586).
- patches.suse/btrfs-0107-make-sure-not-to-defrag-extents-past-i_size.patch:
  Btrfs: make sure not to defrag extents past i_size
  (FATE#306586).
- patches.suse/btrfs-0937-break-out-of-orphan-cleanup-if-we-can-t-make-p.patch:
  Refresh.
- patches.suse/btrfs-8007-fix-wrong-max_to_defrag-in-btrfs_defrag_file.patch:
  Refresh.
- patches.suse/btrfs-8022-fix-recursive-auto-defrag.patch: Delete.
* Tue Oct 18 2011 mgalbraith@suse.de
- patches.fixes/sched-cgroups-Disallow-attaching-kthreadd:
  sched, cgroups: disallow attaching kthreadd (bnc#721840).
* Tue Oct 18 2011 oneukum@suse.de
- Update config files.
  Disable USB_OTG_BLACKLIST_HUB as it kills USB in practice
* Mon Oct 17 2011 jack@suse.cz
- patches.suse/linux-2.6.29-jbd-longer-commit-interval.patch:
  jbd: longer commit interval (was in SLE11-SP1).
* Mon Oct 17 2011 jslaby@suse.de
- Linux 3.0.7.
- patches.fixes/pci_use_acpi_resources_whitelist.patch: Refresh.
- patches.drivers/lis3-Fix-regression-of-HP-DriveGuard-with-8bit-chip:
  Delete.
- patches.drivers/qla2xxx-0014-Fix-crash-in-qla2x00_abort_all_cmds-on-un.patch:
  Delete.
* Mon Oct 17 2011 gregkh@suse.de
- move pci mps patches to patches.fixes as they are not going to be in the upstream 3.0-stable tree.
- patches.fixes/pci-disable_MPS_configuration_by_default.patch:
  PCI: Disable MPS configuration by default (bnc#720075).
- patches.fixes/pci-don-t-crash-when-reading-mpss-from-root-complex.patch:
  pci: Don't crash when reading mpss from root complex.
- patches.fixes/pci-export-pcie_bus_configure_settings-symbol.patch:
  PCI: export pcie_bus_configure_settings symbol.
- patches.fixes/pci-fix_pointer_dereference_before_call_to_pcie_bus_configure_settings.patch:
  Fix pointer dereference before call to
  pcie_bus_configure_settings (bnc#720075).
- patches.fixes/pci-remove-mrrs-modification-from-mps-setting-code.patch:
  PCI: Remove MRRS modification from MPS setting code.
- patches.fixes/pci-set-pci-e-max-payload-size-on-fabric.patch:
  PCI: Set PCI-E Max Payload Size on fabric.
- patches.kernel.org/pci-disable_MPS_configuration_by_default.patch:
  Delete.
- patches.kernel.org/pci-don-t-crash-when-reading-mpss-from-root-complex.patch:
  Delete.
- patches.kernel.org/pci-export-pcie_bus_configure_settings-symbol.patch:
  Delete.
- patches.kernel.org/pci-fix_pointer_dereference_before_call_to_pcie_bus_configure_settings.patch:
  Delete.
- patches.kernel.org/pci-remove-mrrs-modification-from-mps-setting-code.patch:
  Delete.
- patches.kernel.org/pci-set-pci-e-max-payload-size-on-fabric.patch:
  Delete.
* Fri Oct 14 2011 jjolly@suse.de
- patches.arch/s390-37-01-rcu-table-free-leak.diff: kernel:
  memory leak with RCU_TABLE_FREE (bnc#724227,LTC#75848).
- patches.arch/s390-37-02-dasd-wait_for_clear.patch: dasd:
  wait for terminated request (bnc#724227,LTC#75904).
- patches.arch/s390-37-03-dasd-fix_uid_readout.patch: dasd:
  fix UID readout for z/VM (bnc#724227,LTC#75905).
* Fri Oct 14 2011 tiwai@suse.de
- patches.drivers/drm-i915-always-set-FDI-composite-sync-bit:
  drm/i915: always set FDI composite sync bit (bnc#720661).
* Fri Oct 14 2011 duwe@suse.de
- patches.fixes/ipr-flag-dump-timeout: ipr: introduce timeout flag
  (bnc#721042).
* Fri Oct 14 2011 jankit@suse.de
  Fix s390x build. These are required by the bnx2fc driver update.
- patches.fixes/net-bnx2x-fix-build-error: bnx2x: Fix build error
  (bnc#722414).
- patches.fixes/net-dev-define-NETDEV_FCOE_WWNN-only-when-LIBFCOE-enabled:
  net: Define NETDEV_FCOE_WWNN, NETDEV_FCOE_WWPN only when
  CONFIG_LIBFCOE is enabled (bnc#722414).
* Fri Oct 14 2011 jkosina@suse.cz
- Update config files: Disable CRYPTO_MANAGER_DISABLE_TESTS and
  enable FIPS (bnc#723884).
* Fri Oct 14 2011 jankit@suse.de
  Update bnx2fc to 1.0.8:
- patches.drivers/0001-bnx2fc-Reset-the-max-receive-frame-size.patch:
  bnx2fc: Reset the max receive frame size (bnc#722414).
- patches.drivers/0002-bnx2fc-Bug-fixes-in-percpu_thread_create-destroy.patch:
  bnx2fc: Bug fixes in percpu_thread_create/destroy (bnc#722414).
- patches.drivers/0003-bnx2fc-Enable-bsg_request-support-for-bnx2fc.patch:
  bnx2fc: Enable bsg_request support for bnx2fc (bnc#722414).
- patches.drivers/0004-bnx2fc-Remove-erroneous-kref_get-on-IO-request.patch:
  bnx2fc: Remove erroneous kref_get on IO request (bnc#722414).
- patches.drivers/0005-bnx2fc-Do-not-attempt-destroying-NPIV-port-twice.patch:
  bnx2fc: Do not attempt destroying NPIV port twice (bnc#722414).
- patches.drivers/0006-bnx2fc-Change-function-names-of-bnx2fc_netdev_setup-.patch:
  bnx2fc: Change function names of
  bnx2fc_netdev_setup/bnx2fc_netdev_cleanup (bnc#722414).
- patches.drivers/0007-bnx2fc-Reorganize-cleanup-code-between-interface_cle.patch:
  bnx2fc: Reorganize cleanup code between interface_cleanup and
  if_destory (bnc#722414).
- patches.drivers/0008-bnx2fc-Handle-NETDEV_UNREGISTER-for-vlan-devices.patch:
  bnx2fc: Handle NETDEV_UNREGISTER for vlan devices (bnc#722414).
- patches.drivers/0009-bnx2fc-Clear-DESTROY_CMPL-flag-after-firmware-destro.patch:
  bnx2fc: Clear DESTROY_CMPL flag after firmware destroy
  (bnc#722414).
- patches.drivers/0010-bnx2fc-Do-not-reuse-the-fcoe-connection-id-immediate.patch:
  bnx2fc: Do not reuse the fcoe connection id immediately
  (bnc#722414).
- patches.drivers/0011-bnx2fc-IO-errors-when-receiving-unsolicited-LOGO.patch:
  bnx2fc: IO errors when receiving unsolicited LOGO (bnc#722414).
- patches.drivers/0012-bnx2fc-Fix-NULL-pointer-deref-during-arm_cq.patch:
  bnx2fc: Fix NULL pointer deref during arm_cq (bnc#722414).
- patches.drivers/0013-bnx2fc-code-cleanup-in-bnx2fc_offload_session.patch:
  bnx2fc: code cleanup in bnx2fc_offload_session (bnc#722414).
- patches.drivers/0014-bnx2fc-Drop-incoming-ABTS.patch: bnx2fc:
  Drop incoming ABTS (bnc#722414).
- patches.drivers/0015-fcoe-Move-common-functions-to-fcoe_transport-library.patch:
  fcoe: Move common functions to fcoe_transport library.
- patches.drivers/0016-bnx2fc-Obtain-WWNN-WWPN-from-the-shared-memory.patch:
  bnx2fc: Obtain WWNN/WWPN from the shared memory (bnc#722414).
- patches.drivers/0017-bnx2fc-Prevent-creating-of-NPIV-port-with-duplicate-.patch:
  bnx2fc: Prevent creating of NPIV port with duplicate WWN
  (bnc#722414).
- patches.drivers/0018-bnx2fc-Bump-version-to-1.0.5.patch:
  bnx2fc: Bump version to 1.0.5 (bnc#722414).
- patches.drivers/0019-bnx2fc-Need-not-schedule-destroy_work-from-__bnx2fc_.patch:
  bnx2fc: Need not schedule destroy_work from __bnx2fc_destroy
  (bnc#722414).
- patches.drivers/0020-bnx2fc-Reset-max-receive-frame-size-during-link-up.patch:
  bnx2fc: Reset max receive frame size during link up
  (bnc#722414).
- patches.drivers/0021-bnx2fc-Send-solicitation-only-after-vlan-discovery-i.patch:
  bnx2fc: Send solicitation only after vlan discovery is complete
  (bnc#722414).
- patches.drivers/0022-bnx2fc-No-abort-issued-for-REC-when-it-times-out.patch:
  bnx2fc: No abort issued for REC when it times out (bnc#722414).
- patches.drivers/0023-bnx2fc-Validate-vlan-id-in-NETDEV_UNREGISTER-handler.patch:
  bnx2fc: Validate vlan id in NETDEV_UNREGISTER handler
  (bnc#722414).
- patches.drivers/0024-bnx2fc-Avoid-calling-bnx2fc_if_destroy-with-unnecess.patch:
  bnx2fc: Avoid calling bnx2fc_if_destroy with unnecessary locks
  (bnc#722414).
- patches.drivers/0025-bnx2fc-Fix-panic-caused-because-of-incorrect-errror-.patch:
  bnx2fc: Fix panic caused because of incorrect errror handling
  in create() (bnc#722414).
- patches.drivers/0026-bnx2fc-Fix-FW-assert-during-RSCN-stress-tests.patch:
  bnx2fc: Fix FW assert during RSCN stress tests (bnc#722414).
- patches.drivers/0027-bnx2fc-Bumped-version-to-1.0.6.patch:
  bnx2fc: Bumped version to 1.0.6 (bnc#722414).
- patches.drivers/0028-bnx2fc-Replace-scsi_dma_map-with-dma_map_sg.patch:
  bnx2fc: Replace scsi_dma_map() with dma_map_sg() (bnc#722414).
- patches.drivers/0029-bnx2fc-Handle-bnx2fc_map_sg-failure.patch:
  bnx2fc: Handle bnx2fc_map_sg failure (bnc#722414).
- patches.drivers/0030-bnx2fc-Bumped-version-to-1.0.7.patch:
  bnx2fc: Bumped version to 1.0.7 (bnc#722414).
- patches.drivers/0031-bnx2fc-call-ctlr_link_up-only-when-the-interface-is-.patch:
  bnx2fc: call ctlr_link_up only when the interface is enabled.
- patches.drivers/0032-fcoe-libfcoe-Move-common-code-for-fcoe_get_lesb-to-f.patch:
  fcoe/libfcoe: Move common code for fcoe_get_lesb to
  fcoe_transport.
- patches.drivers/0033-bnx2fc-Return-error-statistics-of-remote-peer.patch:
  bnx2fc: Return error statistics of remote peer (bnc#722414).
- patches.drivers/0034-bnx2fc-Bumped-version-to-1.0.8.patch:
  bnx2fc: Bumped version to 1.0.8 (bnc#722414).
- patches.drivers/0035-bnx2fc-Unable-to-send-lun-tgt-reset-on-SLES-11-kerne.patch:
  bnx2fc: Unable to send lun/tgt reset on SLES 11 kernels
  (bnc#722414).
- patches.drivers/0036-bnx2fc-Add-driver-documentation.patch:
  bnx2fc: Add driver documentation (bnc#722414).
* Fri Oct 14 2011 mmarek@suse.cz
- rpm/*.spec.in, rpm/mkspec: Generate specfiles according to Factory
  requirements.
- commit ab4a1af
* Fri Oct 14 2011 tiwai@suse.de
- patches.drivers/drm-i915-apply-timing-generator-bug-workaround-on-CP:
  drm/i915: apply timing generator bug workaround on CPT and PPT
  (bnc#722560).
- patches.drivers/drm-i915-fix-IVB-cursor-support: drm/i915:
  fix IVB cursor support (bnc#720353).
- patches.drivers/drm-i915-panel-Alwyas-record-the-backlight-level-again:
  drm/i915/panel: Alwyas record the backlight level again (but
  cleverly) (v2) (bnc#720996).
- patches.drivers/drm-i915-pass-ELD-to-HDMI-DP-audio-driver:
  drm/i915: pass ELD to HDMI/DP audio driver (bnc#722560).
- patches.drivers/drm-support-routines-for-HDMI-DP-ELD: drm:
  support routines for HDMI/DP ELD (bnc#722560).
* Fri Oct 14 2011 jdelvare@suse.de
- patches.fixes/ata-piix-atapi-fix.patch: IDE mode ATAPI fix
  for Intel chipsets (bnc#719693).
* Wed Oct 12 2011 agraf@suse.de
- patches.fixes/virtio-console-early-console.patch: virtio:
  console: wait for first console port for early console output
  (bnc#723597).
* Wed Oct 12 2011 eich@suse.de
- patches.suse/SUSE-bootsplash:
  Fix crash when splash is off (ie. (struct fb_info *)->splash_data == NULL)
  but someone tries to manipulate the splash image thru the /proc interface.
  All other functions in render.c seem to be save - ie. upper level code
  already protects them from being called if the splash_data member is NULL
  (bnc #718666).
* Tue Oct 11 2011 rjw@suse.de
- patches.arch/x86-UV2-Update-UV2-hub-part-number.patch: x86 /
  UV: Update UV2 hub part number (bnc#722793).
* Tue Oct 11 2011 rjw@suse.de
- patches.arch/x86_uv2_GRU_TLB_fix.patch: x86 / UV: Fix GRU API
  for UV2 after incompatible hardware change (bnc#722795).
* Tue Oct 11 2011 rjw@suse.de
- patches.fixes/PM-Runtime-Return-special-error-code-if-runtime-PM-is-disabled.patch:
  PM / Runtime: Return special error code if runtime PM is
  disabled.
* Tue Oct 11 2011 hare@suse.de
- patches.drivers/fcoe-0029-libfc-fix_deadlock_bug_in_fc_e.patch:
  libfc: fix deadlock bug in fc_exch_abort_locked (bnc#722414).
* Mon Oct 10 2011 jdelvare@suse.de
- patches.drivers/hwmon-coretemp-01-add-core-pkg-threshold-support-to-coretemp.patch:
  hwmon: (coretemp) Add core/pkg threshold support to Coretemp
  (bnc#698797, FATE#311941).
- patches.drivers/hwmon-coretemp-02-initialize-tmin.patch: hwmon:
  (coretemp) Initialize tmin (bnc#698797, FATE#311941).
- patches.drivers/hwmon-coretemp-03-drop-duplicate-function-get_pkg_tjmax.patch:
  hwmon: (coretemp) Drop duplicate function get_pkg_tjmax
  (bnc#698797, FATE#311941).
- patches.drivers/hwmon-coretemp-04-let-the-user-force-tjmax.patch:
  hwmon: (coretemp) Let the user force TjMax (bnc#698797,
  FATE#311941).
- patches.drivers/hwmon-coretemp-05-dont-use-threshold-registers-for-tempX_max.patch:
  hwmon: (coretemp) Don't use threshold registers for tempX_max
  (bnc#698797, FATE#311941).
- patches.drivers/hwmon-coretemp-06-dont-use-kernel-assigned-cpu-number-as-platform-device-id.patch:
  hwmon: (coretemp) don't use kernel assigned CPU number as
  platform device ID (bnc#698797, FATE#311941).
- patches.drivers/hwmon-coretemp-07-constify-static-data.patch:
  hwmon: (coretemp) constify static data (bnc#698797,
  FATE#311941).
- patches.drivers/hwmon-coretemp-08-remove-struct-platform_data-parameter-from-create_core_data.patch:
  hwmon: (coretemp) remove struct platform_data * parameter from
  create_core_data() (bnc#698797, FATE#311941).
- patches.drivers/hwmon-coretemp-09-fixup-platform-device-id-change.patch:
  hwmon: (coretemp) Fixup platform device ID change (bnc#698797,
  FATE#311941).
- patches.drivers/hwmon-coretemp-10-avoid-leaving-around-dangling-pointer.patch:
  hwmon: (coretemp) Avoid leaving around dangling pointer
  (bnc#698797, FATE#311941).
* Mon Oct 10 2011 jdelvare@suse.de
- patches.fixes/drm-radeon-kms-fix-i2c-masks.patch:
  drm/radeon/kms: Fix I2C mask definitions (bnc#712023).
* Mon Oct 10 2011 rw@suse.de
- Update config files.
  Disable CPUMASK_OFFSTACK for ia64.  (bnc#721410)
* Mon Oct 10 2011 hare@suse.de
- patches.drivers/qla4xxx-Add-new-FLT-firmware-region.patch:
  qla4xxx: Add new FLT firmware region (bnc#723008).
- patches.drivers/qla4xxx-Clear-DDB-map-index-on-the-basis-of-AEN.patch:
  qla4xxx: Clear DDB map index on the basis of AEN (bnc#723008).
- patches.drivers/qla4xxx-Do-not-add-duplicate-CHAP-entry-in-FLASH.patch:
  qla4xxx: Do not add duplicate CHAP entry in FLASH (bnc#723008).
- patches.drivers/qla4xxx-Fix-bidirectional-CHAP.patch: qla4xxx:
  Fix bidirectional CHAP (bnc#723008).
- patches.drivers/qla4xxx-Fix-exporting-boot-targets-to-sysfs.patch:
  qla4xxx: Fix exporting boot targets to sysfs (bnc#723008).
- patches.drivers/qla4xxx-Fix-getting-BIDI-CHAP-for-boot-targets.patch:
  qla4xxx: Fix getting BIDI CHAP for boot targets (bnc#723008).
- patches.drivers/qla4xxx-Fixed-active-session-re-open-issue.patch:
  qla4xxx: Fixed active session re-open issue (bnc#723008).
- patches.drivers/qla4xxx-Fixed-device-blocked-issue-on-link-up-down.patch:
  qla4xxx: Fixed device blocked issue on link up-down
  (bnc#723008).
- patches.drivers/qla4xxx-Fixed-session-destroy-issue-on-link-up-down.patch:
  qla4xxx: Fixed session destroy issue on link up-down
  (bnc#723008).
- patches.drivers/qla4xxx-Fixed-target-discovery-failed-issue.patch:
  qla4xxx: Fixed target discovery failed issue (bnc#723008).
- patches.drivers/qla4xxx-Free-Device-Database-DDB-reserved-by-FW.patch:
  qla4xxx: Free Device Database (DDB) reserved by FW (bnc#723008).
- patches.drivers/qla4xxx-Update-driver-version-to-5.02.00-k8.patch:
  qla4xxx: Update driver version to 5.02.00-k8 (bnc#723008).
- patches.drivers/qla4xxx-Update-license.patch: qla4xxx: Update
  license (bnc#723008).
- patches.drivers/qla4xxx-updated-device-id-check-for-BFS.patch:
  qla4xxx: updated device id check for BFS (bnc#723008).
* Mon Oct 10 2011 ptesarik@suse.cz
- Update config files. Disable CONFIG_STRICT_DEVMEM for s390(x)
  (bnc#719645, LTC75336).
* Mon Oct 10 2011 ohering@suse.de
- patches.suse/staging-hv-storvsc-ignore-SET_WINDOW.patch:
  prepare for upstream submission
* Mon Oct 10 2011 ohering@suse.de
- patches.suse/staging-hv-netvsc-rndis_filter_receive-dereferencing-issue.patch:
  Staging: hv: netvsc: Fix a dereferencing issue.
- patches.suse/staging-hv-util-fix-a-bug-in-kvp-implementation.patch:
  Staging: hv: util: Fix a bug in kvp implementation.
- patches.suse/staging-hv-util-invoke-cn_netlink_send-in-a-work-context.patch:
  Staging: hv: util: Invoke cn_netlink_send() in a work context.
* Fri Oct  7 2011 gregkh@suse.de
- patches.fixes/jsm-remove-buggy-write-queue.patch: jsm: remove
  buggy write queue (bnc#719592).
- patches.fixes/serial-jsm-save-state: Refresh.
* Fri Oct  7 2011 gregkh@suse.de
- add back this patch as it's really needed for our tree:
- patches.fixes/vfs-automount-should-ignore-lookup_follow.patch:
  vfs: automount should ignore LOOKUP_FOLLOW.
* Fri Oct  7 2011 gregkh@suse.de
- remove 2 3.0.5 potential patches that were NAKed:
- patches.kernel.org/sfi-table-irq-0xff-means-no-interrupt.patch:
  Delete.
- patches.kernel.org/vfs-automount-should-ignore-lookup_follow.patch:
  Delete.
* Fri Oct  7 2011 dsterba@suse.cz
- patches.suse/btrfs-silence-warning-in-raid-array-setup.patch:
  Fix compilation warning/error.
* Fri Oct  7 2011 dsterba@suse.cz
- patches.suse/btrfs-silence-warning-in-raid-array-setup.patch:
  btrfs: silence warning in raid array setup (bnc#709974).
* Fri Oct  7 2011 dsterba@suse.cz
- patches.suse/btrfs-0105-force-a-page-fault-if-we-have-a-shorty-copy-on.patch:
  Btrfs: force a page fault if we have a shorty copy on a page
  boundary (FATE#306586).
- patches.suse/btrfs-0940-don-t-skip-writing-out-a-empty-block-groups-ca.patch:
  Btrfs: don't skip writing out a empty block groups cache
  (FATE#306586).
- patches.suse/btrfs-0941-check-the-return-value-of-filemap_write_and_wa.patch:
  Btrfs: check the return value of filemap_write_and_wait in
  the space cache (FATE#306586).
- patches.suse/btrfs-0942-take-overflow-into-account-in-reserving-space.patch:
  Btrfs: take overflow into account in reserving space
  (FATE#306586).
- patches.suse/btrfs-8019-Free-inode-mutex-on-lseek-error.patch:
  BTRFS: Free inode mutex on lseek error (FATE#306586).
- patches.suse/btrfs-8020-do-not-set-EXTENT_DIRTY-along-with-EXTENT_DELA.patch:
  Btrfs: do not set EXTENT_DIRTY along with EXTENT_DELALLOC
  (FATE#306586).
- patches.suse/btrfs-8021-pass-the-correct-root-to-lookup_free_space_ino.patch:
  Btrfs: pass the correct root to lookup_free_space_inode()
  (FATE#306586).
- patches.suse/btrfs-8022-fix-recursive-auto-defrag.patch: Btrfs:
  fix recursive auto-defrag (FATE#306586).
- patches.suse/btrfs-8023-fix-return-value-of-btrfs_get_acl.patch:
  Btrfs: fix return value of btrfs_get_acl() (FATE#306586).
* Fri Oct  7 2011 ohering@suse.de
- patches.suse/staging-hv-storvsc-ignore-SET_WINDOW.patch:
  staging: hv: storvsc: ignore some scsi commands from smartd (bnc#722646).
* Fri Oct  7 2011 trenn@suse.de
  Re-enabled latest version:
- patches.arch/x2apic_opt_out.patch: Refresh.
  Added mainline commit:
- patches.kernel.org/pci-disable_MPS_configuration_by_default.patch:
  PCI: Disable MPS configuration by default (bnc#720075).
  And move this one down because above patch depends on it:
- patches.kernel.org/pci-fix_pointer_dereference_before_call_to_pcie_bus_configure_settings.patch:
  Fix pointer dereference before call to
  pcie_bus_configure_settings (bnc#720075).
- patches.arch/x86-Fix-pointer-dereference-before-call-to-pcie_bus_configure_settings.patch:
  Delete.
* Fri Oct  7 2011 hare@suse.de
- patches.fixes/iscsi-class-fix-link-local-mispelling.patch:
  iscsi class: fix link local mispelling (bnc#722260).
- patches.fixes/iscsi-class-fix-vlan-configuration.patch: iscsi
  class: fix vlan configuration (bnc#722260).
- patches.fixes/qla4xxx-fix-data-alignment-and-use-nl-helpers.patch:
  qla4xxx: fix data alignment and use nl helpers (bnc#722260).
* Fri Oct  7 2011 hare@suse.de
- Rediff patches to apply:
  * patches.drivers/mvsas-remove-mvs_slave_-alloc-configure.patch
  * patches.drivers/pm8001-remove-pm8001_slave_-alloc-configure.patch
  * patches.suse/mkinitrd-scsi_host_template-proc_name.patch
* Fri Oct  7 2011 hare@suse.de
- SAS & isci driver update (bnc#721246):
- patches.drivers/isci-SATA-STP-I-O-is-only-returned-in-the-no.patch:
  isci: SATA/STP I/O is only returned in the normal path to libsas
  (bnc#721246).
- patches.drivers/isci-The-port-state-should-be-set-to-stoppin.patch:
  isci: The port state should be set to stopping on the last phy
  (bnc#721246).
- patches.drivers/isci-atapi-support.patch: isci: atapi support
  (bnc#721246).
- patches.drivers/isci-export-phy-events-via-lldd_control_ph.patch:
  isci: export phy events via ->lldd_control_phy() (bnc#721246).
- patches.drivers/isci-fix-decode-of-DONE_CRC_ERR-TC-completio.patch:
  isci: fix decode of DONE_CRC_ERR TC completion status
  (bnc#721246).
- patches.drivers/isci-fix-missed-unlock-in-apc_agent_timeout.patch:
  isci: fix missed unlock in apc_agent_timeout() (bnc#721246).
- patches.drivers/isci-fix-sgpio-register-definitions.patch:
  isci: fix sgpio register definitions (bnc#721246).
- patches.drivers/isci-fix-support-for-large-smp-requests.patch:
  isci: fix support for large smp requests (bnc#721246).
- patches.drivers/isci-initial-sgpio-write-support.patch: isci:
  initial sgpio write support (bnc#721246).
- patches.drivers/libsas-Allow-expander-T-T-attachments.patch:
  libsas: Allow expander T-T attachments (bnc#721246).
- patches.drivers/libsas-disable-scanning-lun-0-on-ata-devic.patch:
  libsas: disable scanning lun > 0 on ata devices (bnc#721246).
- patches.drivers/libsas-dynamic-queue-depth.patch: libsas:
  dynamic queue depth (bnc#721246).
- patches.drivers/libsas-export-sas_alloc_task.patch: libsas:
  export sas_alloc_task() (bnc#721246).
- patches.drivers/libsas-fix-sas_queuecommand-return-values.patch:
  libsas: fix sas_queuecommand return values (bnc#721246).
- patches.drivers/libsas-fix-try_test_sas_gpio_gp_bit-build.patch:
  libsas: fix try_test_sas_gpio_gp_bit() build error (bnc#721246).
- patches.drivers/libsas-fix-warnings-when-checking-sata-stp-p.patch:
  libsas: fix warnings when checking sata/stp protocol
  (bnc#721246).
- patches.drivers/libsas-libata-fix-change_queue_-depth-type.patch:
  libsas,libata: fix ->change_queue_{depth|type} for sata devices
  (bnc#721246).
- patches.drivers/libsas-reindent-sas_queuecommand.patch: libsas:
  reindent sas_queuecommand (bnc#721246).
- patches.drivers/libsas-sas_queuecommand-doesnt-need-host_loc.patch:
  libsas: sas_queuecommand doesnt need host_lock (bnc#721246).
- patches.drivers/libsas-set-sas_address-and-device-type-of-rp.patch:
  libsas: set sas_address and device type of rphy (bnc#721246).
- patches.drivers/libsas-sgpio-write-support.patch: libsas:
  sgpio write support (bnc#721246).
- patches.drivers/mvsas-remove-mvs_slave_-alloc-configure.patch:
  mvsas: remove mvs_slave_{alloc|configure} (bnc#721246).
- patches.drivers/pm8001-fix-DEV_IS_GONE-infinite-retry.patch:
  pm8001: fix DEV_IS_GONE infinite retry (bnc#721246).
- patches.drivers/pm8001-missing-break-statements.patch: pm8001:
  missing break statements (bnc#721246).
- patches.drivers/pm8001-remove-pm8001_slave_-alloc-configure.patch:
  pm8001: remove pm8001_slave_{alloc|configure} (bnc#721246).
* Fri Oct  7 2011 hare@suse.de
- Update config files.
- Fixup patches for series2git:
  * patches.drivers/bna-formatting-and-code-cleanup
  * patches.drivers/bna-initialization-and-locking-fix
  * patches.drivers/bna-minor-irq-index-and-definition-change
  * patches.drivers/bna-naming-change-and-minor-macro-fix
* Fri Oct  7 2011 mgalbraith@suse.de
- patches.fixes/sched-reinstate-sched_compat_yield.patch:
  sched: reinstate sched_compat_yield (bnc#722449).
* Fri Oct  7 2011 hare@suse.de
- patches.drivers/mvsas-0001-Add-support-for-Non-specific-NCQ-error.patch:
  mvsas: Add support for Non specific NCQ error interrupt
  (bnc#722635).
- patches.drivers/mvsas-0002-add-support-for-94xx-phy-tuning-and-mu.patch:
  mvsas: add support for 94xx phy tuning and multiple revisions
  (bnc#722635).
- patches.drivers/mvsas-0003-Add-driver-version-and-interrupt-coale.patch:
  mvsas: Add driver version and interrupt coalescing to device
  attributes in sysfs (bnc#722635).
- patches.drivers/mvsas-0004-fix-94xx-hotplug-issue.patch: mvsas:
  fix 94xx hotplug issue (bnc#722635).
- patches.drivers/mvsas-0005-Remove-unused-macros-variables-and-fu.patch:
  mvsas: Remove unused macros, variables and functions
  (bnc#722635).
- patches.drivers/mvsas-0006-Add-new-macros-and-functions.patch:
  mvsas: Add new macros and functions (bnc#722635).
- patches.drivers/mvsas-0007-misc-improvements.patch: mvsas:
  misc improvements (bnc#722635).
- patches.drivers/mvsas-0008-update-comments.patch: mvsas:
  update comments (bnc#722635).
- patches.drivers/mvsas-0009-Add-support-for-interrupt-tasklet.patch:
  mvsas: Add support for interrupt tasklet (bnc#722635).
* Fri Oct  7 2011 hare@suse.de
- Reshuffle patches to apply.
- Remove obsolete patches:
  * patches.drivers/3w-9xxx-fix-iommu_iova-leak.patch
  * patches.drivers/aacraid-reset-should-disable-MSI-interrupt.patch
  * patches.drivers/cxgb3i-convert-cdev-l2opt-to-use-rcu-to-pre.patch
* Fri Oct  7 2011 hare@suse.de
- patches.drivers/3w-9xxx-fix-iommu_iova-leak.patch: 3w-9xxx:
  fix iommu_iova leak (bnc#722640).
- patches.drivers/aacraid-reset-should-disable-MSI-interrupt.patch:
  aacraid: reset should disable MSI interrupt (bnc#722640).
- patches.drivers/aha152x-add-missing-ISA-PNP-IDs.patch: aha152x:
  add missing ISA PNP IDs (bnc#722640).
- patches.drivers/cxgb3i-convert-cdev-l2opt-to-use-rcu-to-pre.patch:
  cxgb3i: convert cdev->l2opt to use rcu to prevent NULL
  dereference (bnc#722640).
- patches.drivers/cxgb3i-fixed-programing-of-the-dma-page-size.patch:
  cxgb3i: fixed programing of the dma page sizes (bnc#722640).
- patches.drivers/fnic-fix-incorrect-use-of-SLAB_CACHE_DMA-fla.patch:
  fnic: fix incorrect use of SLAB_CACHE_DMA flag (bnc#722640).
* Fri Oct  7 2011 hare@suse.de
- patches.drivers/bnx2i-Added-the-use-of-kthreads-to-handle-SC.patch:
  bnx2i: Added the use of kthreads to handle SCSI cmd completion
  (bnc#722433).
- patches.drivers/bnx2i-Fixed-kernel-panic-due-to-illegal-usag.patch:
  bnx2i: Fixed kernel panic due to illegal usage of
  sc->request->cpu (bnc#722433).
- patches.drivers/bnx2i-Fixed-the-endian-on-TTT-for-NOP-out-tr.patch:
  bnx2i: Fixed the endian on TTT for NOP out transmission
  (bnc#722433).
- patches.drivers/bnx2i-Modified-to-skip-CNIC-registration-if.patch:
  bnx2i: Modified to skip CNIC registration if iSCSI is not
  supported (bnc#722433).
- patches.drivers/bnx2i-Updated-copyright-and-bump-version.patch:
  bnx2i: Updated copyright and bump version (bnc#722433).
- patches.fixes/iscsi_ibft-be2iscsi-iscsi_boot-fix-boot-kobj-data.patch:
  Add upstream commit ID.
* Fri Oct  7 2011 hare@suse.de
- Update bnx2fc patches with upstream commit ids:
  * patches.drivers/bnx2fc-Do-not-arm-CQ-when-there-are-no-CQEs.patch
  * patches.drivers/bnx2fc-Enable-REC-CONF-support-for-the-session.patch
  * patches.drivers/bnx2fc-Enable-support-for-sequence-level-error-reco.patch
  * patches.drivers/bnx2fc-HSI-changes-for-tape.patch
  * patches.drivers/bnx2fc-Handle-REC_TOV-error-code-from-firmware.patch
  * patches.drivers/bnx2fc-Introduce-interface-structure-for-each-vlan.patch
  * patches.drivers/bnx2fc-REC-SRR-link-service-request-and-response-ha.patch
  * patches.drivers/bnx2fc-Replace-printks-with-KERN_ALERT-to-KERN_ERR.patch
  * patches.drivers/bnx2fc-Support-sequence-cleanup-task.patch
  * patches.drivers/bnx2fc-Tx-BDs-cache-in-write-tasks.patch
  * patches.drivers/bnx2fc-hold-tgt-lock-when-calling-cmd_release.patch
- Add missing patch:
  * patches.drivers/bnx2fc-host-stats-show-the-link-speed-unkno.patch:
    bnx2fc: host stats show the link speed 'unknown' on NIC
    partitioned interfaces (bnc#698053, FATE#311462).
- Add missing upstream commit ids:
  * patches.fixes/scsi_lib-pause-between-error-retries.patch
  * patches.fixes/scsi_transport_spi-export-host-width-and-HBA-id
* Fri Oct  7 2011 jkosina@suse.cz
- patches.drivers/parport-release-io-region-properly.patch:
  parport_pc: release IO region properly if unsupported ITE887x
  card is found (bnc#721464).
* Thu Oct  6 2011 rjw@suse.de
- patches.arch/x86-kdump-ioapic_reset-remote-IRR-in-clear_IO_APIC.patch:
  x86, kdump, ioapic: reset remote IRR in clear_IO_APIC
  (bnc#701686).
* Thu Oct  6 2011 jbohac@suse.cz
- patches.suse/ipv6-dont-block-modules-that-depend-on-ipv6-when-blacklisted.patch:
  Cleanup, allow NET_NS to be disabled.
* Thu Oct  6 2011 duwe@suse.de
- patches.fixes/ibmveth-bounce-oops2: ibmveth: Fix oops on
  request_irq failure (bnc#719943).
- patches.fixes/ipr-dump-state-fix: ipr: Stop reading adapter
  dump prematurely (bnc#721042).
- patches.fixes/ipr-fpga-flash: ipr: Add support to flash FPGA
  and flash back DRAM images (bnc#722437).
- patches.fixes/serial-jsm-save-state: jsm: Fixed EEH recovery
  error (bnc#721239).
* Thu Oct  6 2011 jbeulich@novell.com
- Update Xen patches to c/s 1116.
* Thu Oct  6 2011 hare@suse.de
- Update config files.
- patches.fixes/block-add-bsg-helper-library.patch: block:
  add bsg helper library (bnc#722260).
* Thu Oct  6 2011 trenn@suse.de
  APEI cleanup: delete left over patches,
  did some #ifdef cleanup (found and taken over from Jan Beulich):
- patches.drivers/acpi_apei_disable_suse.patch: Refresh.
- patches.drivers/acpi_apei_whitelist_hest_dell.patch: Refresh.
- patches.drivers/acpi_apei_add_apei_bit_support_in_generic_OSC_call_3_4.patch:
  Delete.
- patches.drivers/acpi_apei_add_whea_osc_support_4_4.patch:
  Delete.
- patches.drivers/acpi_apei_ghes_prevent_ghes_to_be_built_as_module_1_4.patch:
  Delete.
- patches.drivers/acpi_apei_ghes_support_disable_ghes_at_boot_time_2_4.patch:
  Delete.
- patches.drivers/apei_pstore_mainline_000.patch: Delete.
* Thu Oct  6 2011 hare@suse.de
- patches.drivers/0001-iscsi_transport-add-support-for-net-settings.patch:
  iscsi_transport: add support for net settings (bnc#722265).
- patches.drivers/0002-qla4xxx-add-support-for-set_net_config.patch:
  qla4xxx: add support for set_net_config (bnc#722260).
- patches.drivers/0003-qla4xxx-Added-new-struct-ipaddress_config.patch:
  qla4xxx: Added new "struct ipaddress_config" (bnc#722260).
- patches.drivers/0004-iscsi-class-add-iface-representation.patch:
  iscsi class: add iface representation (bnc#722265).
- patches.drivers/0005-qla4xxx-added-support-to-show-multiple-iface-in-sys.patch:
  qla4xxx: added support to show multiple iface in sysfs
  (bnc#722260).
- patches.drivers/0006-iscsi-cls-sysfs-group-is_visible-callout-for-conn-a.patch:
  iscsi cls: sysfs group is_visible callout for conn attrs
  (bnc#722265).
- patches.drivers/0007-iscsi-class-sysfs-group-is_visible-callout-for-sess.patch:
  iscsi class: sysfs group is_visible callout for session attrs
  (bnc#722265).
- patches.drivers/0008-iscsi-class-remove-iface-param-mask.patch:
  iscsi class: remove iface param mask (bnc#722265).
- patches.drivers/0009-iscsi-class-sysfs-group-is_visible-callout-for-iscs.patch:
  iscsi class: sysfs group is_visible callout for iscsi host attrs
  (bnc#722265).
- patches.drivers/0010-be2iscsi-remove-host-and-session-casts.patch:
  be2iscsi: remove host and session casts (bnc#722260).
- patches.drivers/0011-iscsi-class-expand-vlan-support.patch:
  iscsi class: expand vlan support (bnc#722265).
- patches.drivers/0012-libiscsi-don-t-bugon-when-if-user-sets-markers.patch:
  libiscsi: don't bugon when if user sets markers (bnc#722265).
- patches.drivers/0013-qla4xxx-Add-VLAN-support.patch: qla4xxx:
  Add VLAN support (bnc#722260).
- patches.drivers/0014-iscsi-class-add-bsg-support-to-iscsi-class.patch:
  iscsi class: add bsg support to iscsi class (bnc#722265).
- patches.drivers/0015-qla4xxx-add-bsg-support.patch: qla4xxx:
  add bsg support (bnc#722260).
- patches.drivers/0016-scsi_transport_iscsi-Add-conn-login-kernel-to-user.patch:
  scsi_transport_iscsi: Add conn login, kernel to user, event
  to support offload session login (bnc#722265).
- patches.drivers/0017-qla4xxx-support-iscsiadm-session-mgmt.patch:
  qla4xxx: support iscsiadm session mgmt (bnc#722260).
- patches.drivers/0018-qla4xxx-Remove-reduandant-code-after-open-iscsi-int.patch:
  qla4xxx: Remove reduandant code after open-iscsi integration
  (bnc#722260).
- patches.drivers/0019-qla4xxx-Boot-from-SAN-support-for-open-iscsi.patch:
  qla4xxx: Boot from SAN support for open-iscsi (bnc#722260).
- patches.drivers/0020-scsi_transport_iscsi-Added-support-to-update-mtu.patch:
  scsi_transport_iscsi: Added support to update mtu (bnc#722265).
- patches.drivers/0021-qla4xxx-Added-support-to-update-mtu.patch:
  qla4xxx: Added support to update mtu (bnc#722260).
- patches.drivers/0022-qla4xxx-Code-cleanup-for-read-update-flash-using-BS.patch:
  qla4xxx: Code cleanup for read/update flash using BSG
  (bnc#722260).
- patches.drivers/0023-qla4xxx-Add-get-ACB-state-support-using-BSG.patch:
  qla4xxx: Add get ACB state support using BSG (bnc#722260).
- patches.drivers/0024-qla4xxx-Add-read-update-NVRAM-support-for-40xx-adap.patch:
  qla4xxx: Add read/update NVRAM support for 40xx adapters using
  BSG (bnc#722260).
- patches.drivers/0025-qla4xxx-Added-vendor-specific-sysfs-attributes.patch:
  qla4xxx: Added vendor specific sysfs attributes (bnc#722260).
- patches.drivers/0026-scsi_transport_iscsi-Added-support-to-update-initia.patch:
  scsi_transport_iscsi: Added support to update initiator iscsi
  port (bnc#722265).
- patches.drivers/0027-qla4xxx-added-support-to-update-initiator-iscsi-por.patch:
  qla4xxx: added support to update initiator iscsi port
  (bnc#722260).
- patches.drivers/0028-qla4xxx-Added-restore-factory-defaults-support-usin.patch:
  qla4xxx: Added restore factory defaults support using BSG
  (bnc#722260).
- patches.drivers/0029-qla4xxx-Added-Get-ACB-support-using-BSG.patch:
  qla4xxx: Added Get ACB support using BSG (bnc#722260).
- patches.drivers/0030-scsi-Added-support-for-adapter-and-firmware-reset.patch:
  scsi: Added support for adapter and firmware reset (bnc#722265).
- patches.drivers/0031-qla4xxx-Added-support-for-adapter-and-firmware-rese.patch:
  qla4xxx: Added support for adapter and firmware reset
  (bnc#722260).
- patches.drivers/0032-qla4xxx-export-iface-name.patch: qla4xxx:
  export iface name (bnc#722260).
- patches.drivers/0033-qla4xxx-select-iscsi-boot-sysfs-attrs.patch:
  qla4xxx: select iscsi boot sysfs attrs (bnc#722260).
* Thu Oct  6 2011 hare@suse.de
- Update qla2xxx for Beta6 (bnc#718279)
- patches.drivers/qla2xxx-0001-fix-comment-typo-hammmer.patch:
  scsi: qla_isr.c: fix comment typo 'hammmer' (bnc#718279).
- patches.drivers/qla2xxx-0002-Basic-infrastructure-for-dynamic-logging.patch:
  qla2xxx: Basic infrastructure for dynamic logging (bnc#718279).
- patches.drivers/qla2xxx-0003-Code-changes-to-support-new-dynamic-logging.patch:
  qla2xxx: Code changes to support new dynamic logging
  infrastructure (bnc#718279).
- patches.drivers/qla2xxx-0004-Cleanup-of-previous-infrastructure.patch:
  qla2xxx: Cleanup of previous infrastructure (bnc#718279).
- patches.drivers/qla2xxx-0005-T10-DIF-Handle-uninitalized-sectors.patch:
  qla2xxx: T10 DIF - Handle uninitalized sectors (bnc#718279).
- patches.drivers/qla2xxx-0006-T10-DIF-Fix-incorrect-error-reporting.patch:
  qla2xxx: T10 DIF - Fix incorrect error reporting (bnc#718279).
- patches.drivers/qla2xxx-0007-Fix-qla24xx-revision-check-while-enabling-i.patch:
  qla2xxx: Fix qla24xx revision check while enabling interrupts
  (bnc#718279).
- patches.drivers/qla2xxx-0008-Acquire-hardware-lock-while-manipulating-ds.patch:
  qla2xxx: Acquire hardware lock while manipulating dsd list
  (bnc#718279).
- patches.drivers/qla2xxx-0009-Double-check-for-command-completion-if-abor.patch:
  qla2xxx: Double check for command completion if abort mailbox
  command fails (bnc#718279).
- patches.drivers/qla2xxx-0010-Save-and-restore-irq-in-the-response-queue.patch:
  qla2xxx: Save and restore irq in the response queue interrupt
  handler (bnc#718279).
- patches.drivers/qla2xxx-0011-Set-the-task-attributes-after-memsetting-fc.patch:
  qla2xxx: Set the task attributes after memsetting fcp cmnd
  (bnc#718279).
- patches.drivers/qla2xxx-0012-Update-version-number-to-8.03.07.07-k.patch:
  qla2xxx: Update version number to 8.03.07.07-k (bnc#718279).
- patches.drivers/qla2xxx-0013-fix-printk-format-warning.patch:
  scsi: fix qla2xxx printk format warning (bnc#718279).
- patches.drivers/qla2xxx-0014-Fix-crash-in-qla2x00_abort_all_cmds-on-un.patch:
  qla2xxx: Fix crash in qla2x00_abort_all_cmds() on unload
  (bnc#718279).
- patches.drivers/qla2xxx-0015-Add-support-for-ISP82xx-to-capture-dump-mi.patch:
  qla2xxx: Add support for ISP82xx to capture dump (minidump)
  on failure (bnc#718279).
- patches.drivers/qla2xxx-0016-Implemeted-beacon-on-off-for-ISP82XX.patch:
  qla2xxx: Implemeted beacon on/off for ISP82XX (bnc#718279).
- patches.drivers/qla2xxx-0017-Prevent-CPU-lockups-when-ql2xdontresethba.patch:
  qla2xxx: Prevent CPU lockups when "ql2xdontresethba" module
  param is set (bnc#718279).
- patches.drivers/qla2xxx-0018-Enable-write-permission-to-some-debug-relat.patch:
  qla2xxx: Enable write permission to some debug related module
  parameters to be changed dynamically (bnc#718279).
- patches.drivers/qla2xxx-0019-check-for-marker-IOCB-during-response-queue.patch:
  qla2xxx: check for marker IOCB during response queue processing
  (bnc#718279).
- patches.drivers/qla2xxx-0020-Fix-array-out-of-bound-warning.patch:
  qla2xxx: Fix array out of bound warning (bnc#718279).
- patches.drivers/qla2xxx-0021-During-loopdown-perform-Diagnostic-loopback.patch:
  qla2xxx: During loopdown perform Diagnostic loopback
  (bnc#718279).
- patches.drivers/qla2xxx-0022-Correction-to-sysfs-edc-interface.patch:
  qla2xxx: Correction to sysfs edc interface (bnc#718279).
- patches.drivers/qla2xxx-0023-Provide-method-for-updating-I2C-attached-VP.patch:
  qla2xxx: Provide method for updating I2C attached VPD
  (bnc#718279).
- patches.drivers/qla2xxx-0024-Return-sysfs-error-codes-appropriate-to-con.patch:
  qla2xxx: Return sysfs error codes appropriate to conditions
  (bnc#718279).
- patches.drivers/qla2xxx-0025-Issue-mailbox-command-only-when-firmware-hu.patch:
  qla2xxx: Issue mailbox command only when firmware hung bit is
  reset for ISP82xx (bnc#718279).
- patches.drivers/qla2xxx-0026-Fix-active_mask-may-be-used-uninitialized.patch:
  qla2xxx: Fix "active_mask" may be used uninitialized warning
  (bnc#718279).
- patches.fixes/qla2xxx-skip-msix-correction.diff: Delete.
* Thu Oct  6 2011 hare@suse.de
- patches.drivers/be2iscsi-Fix-for-case-where-task-sc-was-cleanedup.patch:
  be2iscsi: Fix for case where task->sc was cleanedup earlier
  (bnc#713490).
- patches.drivers/be2iscsi-Fix-for-wrong-dmsg-setting-in-wrb.patch:
  be2iscsi: Fix for wrong dmsg setting in wrb (bnc#713490).
* Thu Oct  6 2011 tiwai@suse.de
- patches.drivers/lis3-Fix-regression-of-HP-DriveGuard-with-8bit-chip:
  Refresh.
* Thu Oct  6 2011 rjw@suse.de
- patches.suse/add_efi_memmap-update-e820_saved.patch: Refresh.
* Thu Oct  6 2011 rjw@suse.de
- patches.suse/add_efi_memmap-update-e820_saved.patch: x86 efi:
  Fill all reserved memmap entries if add_efi_memmap specified
  (bnc#603738).
* Thu Oct  6 2011 rjw@suse.de
- patches.arch/x86_64-numa-Cacheline-aliasing-makes-for_each_populated_zone-extremely-expensive-V2.patch:
  Refresh.
* Wed Oct  5 2011 jjolly@suse.de
- Update config files. s390x/vanilla still build vmcp as in-kernel.
* Wed Oct  5 2011 garloff@suse.de
- patches.arch/acpi_srat-pxm-rev-store.patch: Store SRAT table
  revision (bnc#503038).
- patches.arch/acpi_srat-pxm-rev-ia64.patch: Use SRAT table rev
  to use 8bit or 16/32bit PXM fields (ia64) (bnc#503038).
- patches.arch/acpi_srat-pxm-rev-x86-64.patch: Use SRAT table
  rev to use 8bit or 32bit PXM fields (x86/x86-64) (bnc#503038).
* Wed Oct  5 2011 jslaby@suse.de
- patches.suse/revert-pcmcia-remove-irq_list-parameter-from-pd6729.patch:
  Revert "pcmcia: remove irq_list parameter from pd6729"
  (bnc#720458).
* Wed Oct  5 2011 mmarek@suse.cz
- patches.drivers/ixgbe-add-WOL-support-for-X540: ixgbe: add
  WOL support for X540 (bnc#721206).
* Wed Oct  5 2011 ohering@suse.de
- Update config files to enable fixed hv_mouse driver
- patches.suse/staging-hv-bind-hv_blkkvsc-to-hv_storvsc.patch:
  Refresh.
- patches.suse/staging-hv-netvsc-module-name.patch: Refresh.
- patches.suse/staging-hv-staging-next-20111001-0051-Staging-hv-util-Deal-with-driver-register-failure.patch:
  Staging: hv: util: Deal with driver register failures.
- patches.suse/staging-hv-staging-next-20111001-0052-Staging-hv-vmbus-Fix-a-bug-in-error-handling-in-v.patch:
  Staging: hv: vmbus: Fix a bug in error handling in
  vmbus_bus_init().
- patches.suse/staging-hv-staging-next-20111001-0053-Staging-hv-vmbus-Check-for-events-before-messages.patch:
  Staging: hv: vmbus: Check for events before messages.
- patches.suse/staging-hv-staging-next-20111001-0054-Staging-hv-vmbus-Cleanup-the-code-in-process_chn_.patch:
  Staging: hv: vmbus: Cleanup the code in process_chn_event().
- patches.suse/staging-hv-staging-next-20111001-0055-staging-hv-remove-unnecessary-includes-in-netvsc.patch:
  staging: hv: remove unnecessary includes in netvsc.
- patches.suse/staging-hv-staging-next-20111001-0056-staging-hv-add-newline-to-log-messages-in-netvsc.patch:
  staging: hv: add newline to log messages in netvsc.
- patches.suse/staging-hv-staging-next-20111001-0057-staging-hv-convert-dev_-loglevel-to-netdev_-logle.patch:
  staging: hv: convert dev_<loglevel> to netdev_<loglevel>
  in netvsc.
- patches.suse/staging-hv-staging-next-20111001-0058-staging-hv-fix-a-kernel-warning-in-netvsc_linkstat.patch:
  staging: hv: fix a kernel warning in
  netvsc_linkstatus_callback().
- patches.suse/staging-hv-staging-next-20111001-0059-staging-hv-re-order-the-code-in-netvsc_probe.patch:
  staging: hv: re-order the code in netvsc_probe().
- patches.suse/staging-hv-staging-next-20111001-0060-staging-hv-fix-counting-of-outstanding-sends-in-f.patch:
  staging: hv: fix counting of #outstanding-sends in failed sends.
- patches.suse/staging-hv-staging-next-20111001-0061-staging-hv-fix-counting-of-available-buffer-slots.patch:
  staging: hv: fix counting of available buffer slots when
  send fails.
- patches.suse/staging-hv-staging-next-20111001-0062-staging-hv-fix-the-return-status-of-netvsc_start_x.patch:
  staging: hv: fix the return status of netvsc_start_xmit().
- patches.suse/staging-hv-staging-next-20111001-0063-staging-hv-fix-the-page-buffer-when-rndis-data-go.patch:
  staging: hv: fix the page buffer when rndis data go across
  page boundary.
- patches.suse/staging-hv-staging-next-20111001-0064-staging-hv-fix-some-typos-in-netvsc.c.patch:
  staging: hv: fix some typos in netvsc.c.
- patches.suse/staging-hv-staging-next-20111001-0065-Staging-hv-Update-TODO-file.patch:
  Staging: hv: Update TODO file.
- patches.suse/staging-hv-staging-next-20111001-0066-Staging-hv-vmbus-Show-the-modalias-in-sys-bus-vm.patch:
  Staging: hv: vmbus: Show the modalias in
  /sys/bus/vmbus/devices/*/.
- patches.suse/staging-hv-staging-next-20111001-0129-Staging-hv-Add-support-for-2-TB-LUN-in-storage-dr.patch:
  Staging: hv: Add support for >2 TB LUN in storage driver.
- patches.suse/staging-hv-staging-next-20111001-0243-Staging-hv-vmbus-Rename-vmbus_child_device_create.patch:
  Staging: hv: vmbus: Rename vmbus_child_device_create.
- patches.suse/staging-hv-staging-next-20111001-0244-Staging-hv-vmbus-Rename-vmbus_child_device_regist.patch:
  Staging: hv: vmbus: Rename vmbus_child_device_register.
- patches.suse/staging-hv-staging-next-20111001-0245-Staging-hv-vmbus-Rename-vmbus_child_device_unregi.patch:
  Staging: hv: vmbus: Rename vmbus_child_device_unregister.
- patches.suse/staging-hv-staging-next-20111001-0246-Staging-hv-vmbus-Cleanup-dated-comments-in-channe.patch:
  Staging: hv: vmbus: Cleanup dated comments in channel_mgmt.c.
- patches.suse/staging-hv-staging-next-20111001-0293-Staging-hv-vmbus-Introduce-a-utility-function-to.patch:
  Staging: hv: vmbus: Introduce a utility function to match
  hv_vmbus_device_id.
- patches.suse/staging-hv-staging-next-20111001-0294-Staging-hv-vmbus-Change-the-signature-of-struct-h.patch:
  Staging: hv: vmbus: Change the signature of struct hv_driver
  probe function.
- patches.suse/staging-hv-staging-next-20111001-0295-Staging-hv-storvsc-Use-the-driver_data-to-identif.patch:
  Staging: hv: storvsc: Use the driver_data to identify ide.
- patches.suse/staging-hv-staging-next-20111001-0296-Staging-hv-vmbus-Introduce-functions-for-setting.patch:
  Staging: hv: vmbus: Introduce functions for setting and getting
  driver data.
- patches.suse/staging-hv-staging-next-20111001-0297-Staging-hv-vmbus-Cleanup-vmbus_remove.patch:
  Staging: hv: vmbus: Cleanup vmbus_remove().
- patches.suse/staging-hv-staging-next-20111001-0298-Staging-hv-storvsc-Get-rid-of-storvsc_dev_add-b.patch:
  Staging: hv: storvsc: Get rid of storvsc_dev_add() by inlining
  the code.
- patches.suse/staging-hv-staging-next-20111001-0299-Staging-hv-storvsc-Get-rid-of-alloc_stor_device.patch:
  Staging: hv: storvsc: Get rid of alloc_stor_device() by inlining
  the code.
- patches.suse/staging-hv-staging-next-20111001-0300-Staging-hv-storvsc-Get-rid-of-some-unnecessary-st.patch:
  Staging: hv: storvsc: Get rid of some unnecessary state and
  definitions.
- patches.suse/staging-hv-staging-next-20111001-0301-Staging-hv-storvsc-Eliminate-the-usage-of-ext-fie.patch:
  Staging: hv: storvsc: Eliminate the usage of ext field in
  struct hv_device.
- patches.suse/staging-hv-staging-next-20111001-0302-Staging-hv-netvsc-Get-rid-of-the-usage-of-the-ext.patch:
  Staging: hv: netvsc: Get rid of the usage of the ext field in
  struct hv_device.
- patches.suse/staging-hv-staging-next-20111001-0303-Staging-hv-mousevsc-Get-rid-of-the-usage-of-the-e.patch:
  Staging: hv: mousevsc: Get rid of the usage of the ext field
  in struct hv_device.
- patches.suse/staging-hv-staging-next-20111001-0304-Staging-hv-vmbus-Get-rid-of-the-ext-field-in-stru.patch:
  Staging: hv: vmbus: Get rid of the ext field in struct
  hv_device.
- patches.suse/staging-hv-staging-next-20111001-0305-Staging-hv-vmbus-Do-not-allocate-struct-hv_device.patch:
  Staging: hv: vmbus: Do not allocate struct hv_device_info on
  the stack.
- patches.suse/staging-hv-staging-next-20111001-0306-Staging-hv-vmbus-Get-rid-of-the-module-dependency.patch:
  Staging: hv: vmbus: Get rid of the module dependency.
- patches.suse/staging-hv-staging-next-20111001-0307-Staging-hv-netvsc-Rename-netDevice-as-net_device.patch:
  Staging: hv: netvsc: Rename netDevice as net_device.
- patches.suse/staging-hv-staging-next-20111001-0308-Staging-hv-netvsc-Rename-rndisDevice-to-rndis_dev.patch:
  Staging: hv: netvsc: Rename rndisDevice to rndis_device.
- patches.suse/staging-hv-staging-next-20111001-0309-Staging-hv-netvsc-Rename-deviceInfo-as-device_inf.patch:
  Staging: hv: netvsc: Rename deviceInfo as device_info.
- patches.suse/staging-hv-staging-next-20111001-0310-Staging-hv-netvsc-Cleanup-the-name-and-type-of-li.patch:
  Staging: hv: netvsc: Cleanup the name and type of link_stat
  variable.
- patches.suse/staging-hv-staging-next-20111001-0421-Staging-hv-util-Perform-some-service-specific-ini.patch:
  Staging: hv: util: Perform some service specific init/deinit
  in probe/remove.
- patches.suse/staging-hv-staging-next-20111001-0422-Staging-hv-util-Properly-handle-util-services-in.patch:
  Staging: hv: util: Properly handle util services in the
  util driver.
- patches.suse/staging-hv-staging-next-20111001-0423-Staging-hv-vmbus-Get-rid-of-hv_cb_utils-and-oth.patch:
  Staging: hv: vmbus: Get rid of hv_cb_utils[] and other
  unneeded code.
- patches.suse/staging-hv-staging-next-20111001-0476-Staging-hv-Update-the-TODO-file.patch:
  Staging: hv: Update the TODO file.
- patches.suse/staging-hv-staging-next-20111001-0479-staging-hv-remove-the-carrier-status-check-from-ne.patch:
  staging: hv: remove the carrier status check from netvsc_open().
- patches.suse/staging-hv-staging-next-20111001-0579-Staging-hv-mousevsc-Fixup-struct-hv_input_dev_inf.patch:
  Staging: hv: mousevsc: Fixup struct hv_input_dev_info.
- patches.suse/staging-hv-staging-next-20111001-0580-Staging-hv-mousevsc-Get-rid-of-the-struct-input_d.patch:
  Staging: hv: mousevsc: Get rid of the struct
  input_device_context.
- patches.suse/staging-hv-staging-next-20111001-0581-Staging-hv-mousevsc-Fixup-some-bogus-WARN_ON-ca.patch:
  Staging: hv: mousevsc: Fixup some bogus WARN_ON() calls.
- patches.suse/staging-hv-staging-next-20111001-0582-Staging-hv-mousevsc-Change-the-allocation-flags-t.patch:
  Staging: hv: mousevsc: Change the allocation flags to reflect
  interrupt context.
- patches.suse/staging-hv-staging-next-20111001-0583-Staging-hv-mousevsc-Handle-the-case-where-we-may.patch:
  Staging: hv: mousevsc: Handle the case where we may get bogus
  report desc size.
- patches.suse/staging-hv-staging-next-20111001-0584-Staging-hv-mousevsc-Correctly-initialize-the-head.patch:
  Staging: hv: mousevsc: Correctly initialize the header size.
- patches.suse/staging-hv-staging-next-20111001-0585-Staging-hv-mousevsc-Use-completion-primitive-to-s.patch:
  Staging: hv: mousevsc: Use completion primitive to synchronize.
- patches.suse/staging-hv-staging-next-20111001-0586-Staging-hv-mousevsc-Cleanup-and-properly-implemen.patch:
  Staging: hv: mousevsc: Cleanup and properly implement
  reportdesc_callback().
- patches.suse/staging-hv-staging-next-20111001-0587-Staging-hv-mousevsc-Get-rid-of-unnecessary-DPRINT.patch:
  Staging: hv: mousevsc: Get rid of unnecessary DPRINT calls.
- patches.suse/staging-hv-staging-next-20111001-0588-Staging-hv-mousevsc-Cleanup-error-handling.patch:
  Staging: hv: mousevsc: Cleanup error handling.
- patches.suse/staging-hv-staging-next-20111001-0589-Staging-hv-mousevsc-Get-rid-of-unnecessary-pr_-c.patch:
  Staging: hv: mousevsc: Get rid of unnecessary pr_* calls.
- patches.suse/staging-hv-staging-next-20111001-0590-Staging-hv-mousevsc-Free-allocated-memory-in-free.patch:
  Staging: hv: mousevsc: Free allocated memory in
  free_input_device().
- patches.suse/staging-hv-staging-next-20111001-0591-Staging-hv-mousevsc-Get-rid-of-the-unused-state.patch:
  Staging: hv: mousevsc: Get rid of the unused state:
  num_outstanding_req.
- patches.suse/staging-hv-staging-next-20111001-0592-Staging-hv-mousevsc-Cleanup-alloc_input_device.patch:
  Staging: hv: mousevsc: Cleanup alloc_input_device().
- patches.suse/staging-hv-staging-next-20111001-0593-Staging-hv-mousevsc-Get-rid-of-mousevsc_on_send_c.patch:
  Staging: hv: mousevsc: Get rid of mousevsc_on_send_completion().
- patches.suse/staging-hv-staging-next-20111001-0594-Staging-hv-mousevsc-Cleanup-mousevsc_connect_to_v.patch:
  Staging: hv: mousevsc: Cleanup mousevsc_connect_to_vsp().
- patches.suse/staging-hv-staging-next-20111001-0595-Staging-hv-mousevsc-Get-rid-of-mousevsc_on_device.patch:
  Staging: hv: mousevsc: Get rid of mousevsc_on_device_remove()
  by inlining code.
- patches.suse/staging-hv-staging-next-20111001-0596-Staging-hv-mousevsc-Now-cleanup-mousevsc_remove.patch:
  Staging: hv: mousevsc: Now cleanup mousevsc_remove().
- patches.suse/staging-hv-staging-next-20111001-0597-Staging-hv-mousevsc-Get-rid-of-ref_count-state-in.patch:
  Staging: hv: mousevsc: Get rid of ref_count state in struct
  mousevsc_dev.
- patches.suse/staging-hv-staging-next-20111001-0598-Staging-hv-mousevsc-Cleanup-camel-cased-enums.patch:
  Staging: hv: mousevsc: Cleanup camel cased enums.
- patches.suse/staging-hv-staging-next-20111001-0599-Staging-hv-mousevsc-Get-rid-of-mousevsc_on_receiv.patch:
  Staging: hv: mousevsc: Get rid of
  mousevsc_on_receive_input_report() by inlining.
- patches.suse/staging-hv-staging-next-20111001-0600-Staging-hv-mousevsc-Cleanup-mousevsc_on_device_ad.patch:
  Staging: hv: mousevsc: Cleanup mousevsc_on_device_add().
- patches.suse/staging-hv-staging-next-20111001-0601-Staging-hv-mousevsc-Enable-autoloading-of-the-mou.patch:
  Staging: hv: mousevsc: Enable autoloading of the mouse driver.
- patches.suse/staging-hv-staging-next-20111001-0602-Staging-hv-mousevsc-Get-rid-of-unnecessary-commen.patch:
  Staging: hv: mousevsc: Get rid of unnecessary comments.
- patches.suse/staging-hv-storvsc-module-name.patch: Refresh.
- patches.suse/staging-hv-storvsc-scsi-proc_name.patch: Refresh.
- patches.xen/xen3-patch-2.6.32: Refresh.
- patches.suse/staging-hv-vmbus-modalias-show.patch: Delete.
* Wed Oct  5 2011 jjolly@suse.de
- Update config files to build VMCP as a module.
- patches.arch/s390-vmcp-module.patch: Revert vmcp in-kernel
  only change (bnc#721007).
* Wed Oct  5 2011 jeffm@suse.com
- patches.drivers/bna-add-callback-to-fix-rxq-stop: bna: Add
  Callback to Fix RXQ Stop (FATE#311451 bnc#689230).
- patches.drivers/bna-add-hw-semaphore-unlock-logic: bna: Add
  HW Semaphore Unlock Logic (FATE#311451 bnc#689230).
- patches.drivers/bna-add-new-hw-defs: bna: Add New HW Defs
  (FATE#311451 bnc#689230).
- patches.drivers/bna-async-mode-tx-rx-init-fix: bna: Async Mode
  Tx Rx Init Fix (FATE#311451 bnc#689230).
- patches.drivers/bna-brocade-1860-hw-enablement: bna: Brocade
  1860 HW Enablement (FATE#311451 bnc#689230).
- patches.drivers/bna-brocade-1860-ioc-pll-reg-defs-and-asic-mode-changes:
  bna: Brocade 1860 IOC PLL, Reg Defs and ASIC Mode Changes
  (FATE#311451 bnc#689230).
- patches.drivers/bna-capability-map-and-mfg-block-changes-for-new-hw:
  bna: Capability Map and MFG Block Changes for New HW
  (FATE#311451 bnc#689230).
- patches.drivers/bna-checkpatch-cleanup: bna: CheckPatch Cleanup
  (FATE#311451 bnc#689230).
- patches.drivers/bna-consolidated-hw-registers-for-supported-hws:
  bna: Consolidated HW Registers for Supported HWs (FATE#311451
  bnc#689230).
- patches.drivers/bna-driver-version-changed-to-3-0-2-0: bna:
  Driver Version changed to 3.0.2.0 (FATE#311451 bnc#689230).
- patches.drivers/bna-driver-version-changed-to-3-0-2-1: bna:
  Driver Version changed to 3.0.2.1 (FATE#311451 bnc#689230).
- patches.drivers/bna-driver-version-changed-to-3-0-2-2: bna:
  Driver Version changed to 3.0.2.2 (FATE#311451 bnc#689230).
- patches.drivers/bna-eliminate-small-race-condition-window-in-rx-path:
  bna: Eliminate Small Race Condition Window in RX Path
  (FATE#311451 bnc#689230).
- patches.drivers/bna-enet-and-tx-rx-redesign-enablement: bna:
  ENET and Tx Rx Redesign Enablement (FATE#311451 bnc#689230).
- patches.drivers/bna-ethtool-enhancements-and-fix: bna: Ethtool
  Enhancements and Fix (FATE#311451 bnc#689230).
- patches.drivers/bna-formatting-and-code-cleanup: bna: Formatting
  and Code Cleanup (FATE#311451 bnc#689230).
- patches.drivers/bna-header-file-consolidation: bna: Header
  File Consolidation (FATE#311451 bnc#689230).
- patches.drivers/bna-hw-error-counter-fix: bna: HW Error Counter
  Fix (FATE#311451 bnc#689230).
- patches.drivers/bna-hw-interface-init-update: bna: HW Interface
  Init Update (FATE#311451 bnc#689230).
- patches.drivers/bna-implement-fw-download-for-new-hw: bna:
  Implement FW Download for New HW (FATE#311451 bnc#689230).
- patches.drivers/bna-initialization-and-locking-fix: bna:
  Initialization and Locking Fix (FATE#311451 bnc#689230).
- patches.drivers/bna-interrupt-polling-and-napi-init-changes:
  bna: Interrupt Polling and NAPI Init Changes (FATE#311451
  bnc#689230).
- patches.drivers/bna-introduce-enet-as-new-driver-and-fw-interface:
  bna: Introduce ENET as New Driver and FW Interface (FATE#311451
  bnc#689230).
- patches.drivers/bna-ioc-event-name-change: bna: IOC Event Name
  Change (FATE#311451 bnc#689230).
- patches.drivers/bna-ioc-event-notification-enhancement: bna:
  IOC Event Notification Enhancement (FATE#311451 bnc#689230).
- patches.drivers/bna-make-function-tables-cont: bna: make
  function tables cont (FATE#311451 bnc#689230).
- patches.drivers/bna-mbox-irq-flag-check-after-locking: bna:
  MBOX IRQ Flag Check after Locking (FATE#311451 bnc#689230).
- patches.drivers/bna-mboxq-flush-when-ioc-disabled: bna: Mboxq
  Flush When IOC Disabled (FATE#311451 bnc#689230).
- patches.drivers/bna-minor-irq-index-and-definition-change: bna:
  Minor IRQ Index and Definition Change (FATE#311451 bnc#689230).
- patches.drivers/bna-msgq-implementation: bna: MSGQ
  Implementation (FATE#311451 bnc#689230).
- patches.drivers/bna-naming-change-and-minor-macro-fix: bna:
  Naming Change and Minor Macro Fix (FATE#311451 bnc#689230).
- patches.drivers/bna-off-by-one-in-bfa_msgq_rspq_pi_update:
  bna: off by one in bfa_msgq_rspq_pi_update() (FATE#311451
  bnc#689230).
- patches.drivers/bna-pci-probe-conf-lock-fix: bna: PCI Probe
  Conf Lock Fix (FATE#311451 bnc#689230).
- patches.drivers/bna-pci-probe-fix: bna: PCI Probe Fix
  (FATE#311451 bnc#689230).
- patches.drivers/bna-pll-init-fix-and-add-stats-attributes: bna:
  PLL Init Fix and Add Stats Attributes (FATE#311451 bnc#689230).
- patches.drivers/bna-print-driver-version: bna: Print Driver
  Version (FATE#311451 bnc#689230).
- patches.drivers/bna-remove-get_regs-ethtool-support: bna:
  Remove get_regs Ethtool Support (FATE#311451 bnc#689230).
- patches.drivers/bna-remove-obsolete-file-bfi_ctreg-h: bna:
  Remove Obsolete File bfi_ctreg.h (FATE#311451 bnc#689230).
- patches.drivers/bna-remove-obsolete-files: bna: Remove Obsolete
  Files (FATE#311451 bnc#689230).
- patches.drivers/bna-remove-unnecessary-cna-check: bna: Remove
  Unnecessary CNA Check (FATE#311451 bnc#689230).
- patches.drivers/bna-remove-unused-code: bna: Remove Unused Code
  (FATE#311451 bnc#689230).
- patches.drivers/bna-semaphore-lock-fix: bna: Semaphore Lock Fix
  (FATE#311451 bnc#689230).
- patches.drivers/bna-set-ring-param-fix: bna: Set Ring Param Fix
  (FATE#311451 bnc#689230).
- patches.drivers/bna-skb-pci-unmap-fix: bna: SKB PCI UNMAP Fix
  (FATE#311451 bnc#689230).
- patches.drivers/bna-state-machine-fault-handling-cleanup: bna:
  State Machine Fault Handling Cleanup (FATE#311451 bnc#689230).
- patches.drivers/bna-tx-and-rx-redesign: bna: Tx and Rx Redesign
  (FATE#311451 bnc#689230).
- patches.drivers/bna-tx-path-and-rx-path-changes: bna: TX Path
  and RX Path Changes (FATE#311451 bnc#689230).
- patches.drivers/bna-tx-queue-depth-fix: bna: TX Queue Depth Fix
  (FATE#311451 bnc#689230).
- patches.drivers/bna-unlock-on-error-path-in-bnad_pci_probe:
  bna: unlock on error path in bnad_pci_probe() (FATE#311451
  bnc#689230).
* Wed Oct  5 2011 oneukum@suse.de
- patches.suse/0001-bttv-add-dummy-module-parameter.patch: bttv:
  add dummy module parameter (bnc#720457).
* Wed Oct  5 2011 oneukum@suse.de
- patches.suse/0001-saa7134-add-dummy-compatibility-parameter.patch:
  saa7134: add dummy compatibility parameter (bnc#720457).
* Wed Oct  5 2011 oneukum@suse.de
- patches.suse/0001-ir-kbd-i2c-add-back-dummy-module-parameter.patch:
  ir-kbd-i2c: add back dummy module parameter (bnc#720457).
* Wed Oct  5 2011 jbeulich@novell.com
- patches.suse/supported-flag: Also look for Module.supported in the
  source tree.
- patches.suse/supported-flag-enterprise: Refresh.
* Wed Oct  5 2011 oneukum@suse.de
- patches.suse/0001-USB-usbvision-more-compatibility-parameters.patch:
  USB: usbvision: more compatibility parameters (bnc#720457).
* Wed Oct  5 2011 oneukum@suse.de
- patches.suse/0001-USB-usbvision-add-compatibility-module-parameters.patch:
  USB: usbvision: add compatibility module parameters
  (bnc#720457).
* Wed Oct  5 2011 jkosina@suse.cz
- Update config files: disable KDB on ec2 and xen flavours
* Wed Oct  5 2011 oneukum@suse.de
- patches.suse/0001-USB-pwc-add-dummy-module-parameter.patch:
  USB: pwc: add dummy module parameter (bnc#720457).
* Wed Oct  5 2011 jkosina@suse.cz
- Update config files: enable KDB on i586
- patches.suse/kdb-v4.4-3.1-x86-1: fix i586 build
* Tue Oct  4 2011 jslaby@suse.de
- patches.fixes/mm-vmscan-drop-nr_force_scan-from-get_scan_count.patch:
  Refresh.
- patches.fixes/mm-vmscan-fix-force-scanning-small-targets-without-swap.patch:
  Refresh.
  Update upstream info.
* Tue Oct  4 2011 jslaby@suse.de
- Linux 3.0.6.
- patches.drivers/0320-cnic-Fix-interrupt-logic.patch: Delete.
- patches.drivers/0321-cnic-Fix-race-conditions-with-firmware.patch:
  Delete.
- patches.drivers/0322-cnic-Randomize-initial-TCP-port-for-iSCSI-connection.patch:
  Delete.
- patches.drivers/0323-cnic-Improve-NETDEV_UP-event-handling.patch:
  Delete.
- patches.drivers/0324-cnic-bnx2-Check-iSCSI-support-early-in-bnx2_init_one.patch:
  Delete.
- patches.drivers/bnx2fc-Fix-kernel-panic-when-deleting-NPIV-ports.patch:
  Delete.
- patches.drivers/bnx2fc-scsi_dma_unmap-not-invoked-on-IO-completio.patch:
  Delete.
- patches.fixes/mm-memcg-fix-vmscan-count-in-small-memcgs.patch:
  Delete.
- patches.kernel.org/8250-fix-race-condition-in-serial8250_backup_timeout.patch:
  Delete.
- patches.kernel.org/8250_pci-add-support-for-rosewill-rc-305-4x-serial-port.patch:
  Delete.
- patches.kernel.org/9p-close-acl-leaks.patch: Delete.
- patches.kernel.org/acpica-acpi_max_sleep-should-be-2-sec-not-20.patch:
  Delete.
- patches.kernel.org/acpica-do-not-repair-_tss-return-package-if-_pss-is-present.patch:
  Delete.
- patches.kernel.org/ahci-raid-mode-sata-patch-for-intel-panther-point-deviceids.patch:
  Delete.
- patches.kernel.org/alarmtimers-avoid-possible-denial-of-service-with-high-freq-periodic-timers.patch:
  Delete.
- patches.kernel.org/alarmtimers-avoid-possible-null-pointer-traversal.patch:
  Delete.
- patches.kernel.org/alarmtimers-memset-itimerspec-passed-into-alarm_timer_get.patch:
  Delete.
- patches.kernel.org/alsa-fm801-fix-double-free-in-case-of-error-in-tuner-detection.patch:
  Delete.
- patches.kernel.org/alsa-fm801-gracefully-handle-failure-of-tuner-auto-detect.patch:
  Delete.
- patches.kernel.org/alsa-hda-cirrus-fix-surround-speaker-volume-control-name.patch:
  Delete.
- patches.kernel.org/alsa-hda-realtek-fix-auto-mute-with-hp-lo-configuration.patch:
  Delete.
- patches.kernel.org/alsa-pcm-fix-race-condition-in-wait_for_avail.patch:
  Delete.
- patches.kernel.org/alsa-usb-audio-clear-chip-probing-on-error-exit.patch:
  Delete.
- patches.kernel.org/arch-powerpc-sysdev-fsl_rio.c-correct-iecsr-register-clear.patch:
  Delete.
- patches.kernel.org/arm-7014-1-cache-l2x0-fix-l2-cache-size-calculation.patch:
  Delete.
- patches.kernel.org/arm-7081-1-mach-integrator-fix-the-clocksource.patch:
  Delete.
- patches.kernel.org/arm-davinci-da850-evm-read-mac-address-from-spi-flash.patch:
  Delete.
- patches.kernel.org/arm-davinci-fix-cache-flush-build-error.patch:
  Delete.
- patches.kernel.org/arm-dove-fix-second-spi-initialization-call.patch:
  Delete.
- patches.kernel.org/arp-fix-rcu-lockdep-splat-in-arp_process.patch:
  Delete.
- patches.kernel.org/asix-add-ax88772b-usb-id.patch: Delete.
- patches.kernel.org/asoc-ad193x-fix-dac-word-len-setting.patch:
  Delete.
- patches.kernel.org/asoc-ad193x-fix-registers-definition.patch:
  Delete.
- patches.kernel.org/asoc-blackfin-bf5xx-ad193x-fix-codec-device-name.patch:
  Delete.
- patches.kernel.org/asoc-fix-reporting-of-partial-jack-updates.patch:
  Delete.
- patches.kernel.org/asoc-mpc5200-replace-of_device-with-platform_device.patch:
  Delete.
- patches.kernel.org/asoc-soc-jack-fix-checking-return-value-of-request_any_context_irq.patch:
  Delete.
- patches.kernel.org/ath9k-fix-ps-wrappers-in-ath9k_set_coverage_class.patch:
  Delete.
- patches.kernel.org/ath9k_hw-fix-calibration-on-5-ghz.patch:
  Delete.
- patches.kernel.org/ath9k_hw-fix-sta-ar9485-bringup-issue-due-to-incorrect-mac-address.patch:
  Delete.
- patches.kernel.org/atm-br2684-fix-oops-due-to-skb-dev-being-null.patch:
  Delete.
- patches.kernel.org/avoid-dereferencing-a-request_queue-after-last-close.patch:
  Delete.
- patches.kernel.org/b43-fix-beacon-problem-in-ad-hoc-mode.patch:
  Delete.
- patches.kernel.org/blk-cgroup-be-able-to-remove-the-record-of-unplugged-device.patch:
  Delete.
- patches.kernel.org/bluetooth-fix-timeout-on-scanning-for-the-second-time.patch:
  Delete.
- patches.kernel.org/break-out-numa_maps-gather_pte_stats-checks.patch:
  Delete.
- patches.kernel.org/bridge-fix-a-possible-net_device-leak.patch:
  Delete.
- patches.kernel.org/bridge-fix-a-possible-use-after-free.patch:
  Delete.
- patches.kernel.org/bridge-pseudo-header-required-for-the-checksum-of-icmpv6.patch:
  Delete.
- patches.kernel.org/btrfs-fix-d_off-in-the-first-dirent.patch:
  Delete.
- patches.kernel.org/carl9170-fix-mismatch-in-carl9170_op_set_key-mutex.patch:
  Delete.
- patches.kernel.org/cdc_ncm-fix-endianness-problem.patch: Delete.
- patches.kernel.org/cifs-fix-possible-memory-corruption-in-cifsfindnext.patch:
  Delete.
- patches.kernel.org/drivers-cpufreq-pcc-cpufreq.c-avoid-null-pointer-dereference.patch:
  Delete.
- patches.kernel.org/drivers-leds-ledtrig-timer.c-fix-broken-sysfs-delay-handling.patch:
  Delete.
- patches.kernel.org/drm-nouveau-properly-handle-allocation-failure-in-nouveau_sgdma_populate.patch:
  Delete.
- patches.kernel.org/drm-radeon-don-t-read-from-cp-ring-write-pointer-registers.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-add-s-r-quirk-for-compaq-presario-v5245eu.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-evergreen-ni-reset-spi-block-on-cp-resume.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-fix-ddia-enable-on-some-rs690-systems.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-fix-typo-in-r100_blit_copy.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-make-gpu-cpu-page-size-handling-consistent-in-blit-code-v2.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-make-sure-pci-max-read-request-size-is-valid-on-evergreen-v2.patch:
  Delete.
- patches.kernel.org/drm-radeon-kms-set-a-default-max_pixel_clock.patch:
  Delete.
- patches.kernel.org/e1000-fix-driver-to-be-used-on-pa-risc-c8000-workstations.patch:
  Delete.
- patches.kernel.org/ehci-add-pci-quirk-for-ordissimo-and-rm-slate-100-too.patch:
  Delete.
- patches.kernel.org/ehci-refactor-pci-quirk-to-use-standard-dmi_check_system-method.patch:
  Delete.
- patches.kernel.org/fcoe-unable-to-select-the-exchangeid-from-offload-pool-for-storage-targets.patch:
  Delete.
- patches.kernel.org/fib-fix-bug_on-in-fib_nl_newrule-when-add-new-fib-rule.patch:
  Delete.
- patches.kernel.org/firewire-ohci-add-no-msi-quirk-for-o2micro-controller.patch:
  Delete.
- patches.kernel.org/fix-the-conflict-between-rwpidforward-and-rw-mount-options.patch:
  Delete.
- patches.kernel.org/fix-the-size-of-receive-buffer-packing-onto-virtio-ring.patch:
  Delete.
- patches.kernel.org/floppy-use-del_timer_sync-in-init-cleanup.patch:
  Delete.
- patches.kernel.org/fs-9p-add-fid-before-dentry-instantiation.patch:
  Delete.
- patches.kernel.org/fs-9p-add-os-dependent-open-flags-in-9p-protocol.patch:
  Delete.
- patches.kernel.org/fs-9p-always-ask-new-inode-in-create.patch:
  Delete.
- patches.kernel.org/fs-9p-always-ask-new-inode-in-lookup-for-cache-mode.patch:
  Delete.
- patches.kernel.org/fs-9p-don-t-update-file-type-when-updating-file-attributes.patch:
  Delete.
- patches.kernel.org/fs-9p-fid-is-not-valid-after-a-failed-clunk.patch:
  Delete.
- patches.kernel.org/fs-9p-fix-invalid-mount-options-args.patch:
  Delete.
- patches.kernel.org/fs-9p-use-protocol-defined-value-for-lock-getlock-type-field.patch:
  Delete.
- patches.kernel.org/fs-9p-when-doing-inode-lookup-compare-qid-details-and-inode.patch:
  Delete.
- patches.kernel.org/genirq-make-irq_shutdown-symmetric-vs.-irq_startup-again.patch:
  Delete.
- patches.kernel.org/hpsa-fix-physical-device-lun-and-target-numbering-problem.patch:
  Delete.
- patches.kernel.org/hpsa-fix-problem-that-obdr-devices-are-not-detected.patch:
  Delete.
- patches.kernel.org/hwmon-max16065-fix-current-calculation.patch:
  Delete.
- patches.kernel.org/ibmveth-checksum-offload-is-always-disabled.patch:
  Delete.
- patches.kernel.org/ibmveth-fix-dma-unmap-error.patch: Delete.
- patches.kernel.org/ibmveth-fix-issue-with-dma-mapping-failure.patch:
  Delete.
- patches.kernel.org/ibmveth-fix-leak-when-recycling-skb-and-hypervisor-returns.patch:
  Delete.
- patches.kernel.org/igb-fix-wol-on-second-port-of-i350-device.patch:
  Delete.
- patches.kernel.org/iommu-amd-don-t-take-domain-lock-recursivly.patch:
  Delete.
- patches.kernel.org/iommu-amd-make-sure-iommu-need_sync-contains-correct-value.patch:
  Delete.
- patches.kernel.org/ipc-mqueue.c-fix-mq_open-return-value.patch:
  Delete.
- patches.kernel.org/ipc-mqueue.c-refactor-failure-handling.patch:
  Delete.
- patches.kernel.org/ipv4-some-rt_iif-rt_route_iif-conversions.patch:
  Delete.
- patches.kernel.org/ipv6-fix-ipv6_getsockopt-for-ipv6_2292pktoptions.patch:
  Delete.
- patches.kernel.org/irda-fix-smsc-ircc2-section-mismatch-warning.patch:
  Delete.
- patches.kernel.org/isci-change-sas-phy-timeouts-from-54us-to-59us.patch:
  Delete.
- patches.kernel.org/isci-fix-32-bit-operation-when-config_highmem64g-n.patch:
  Delete.
- patches.kernel.org/isci-fix-event-get-pointer-increment.patch:
  Delete.
- patches.kernel.org/isci-fix-sata-response-handling.patch:
  Delete.
- patches.kernel.org/isci-leave-requests-alone-if-already-terminating.patch:
  Delete.
- patches.kernel.org/iscsi_tcp-fix-locking-around-iscsi-sk-user-data.patch:
  Delete.
- patches.kernel.org/iwlagn-fix-command-queue-timeout.patch:
  Delete.
- patches.kernel.org/iwlagn-workaround-bug-crashing-some-aps.patch:
  Delete.
- patches.kernel.org/iwlegacy-fix-bug_on-info-control.rates.idx-0.patch:
  Delete.
- patches.kernel.org/ixgbe-fix-possible-null-buffer-error.patch:
  Delete.
- patches.kernel.org/kernel-printk-do-not-turn-off-bootconsole-in-printk_late_init-if-keep_bootcon.patch:
  Delete.
- patches.kernel.org/libfc-enhancement-to-rport-state-machine-applicable-only-for-vn2vn-mode.patch:
  Delete.
- patches.kernel.org/libiscsi_tcp-fix-lld-data-allocation.patch:
  Delete.
- patches.kernel.org/lpfc-8.3.25-adapter-interface-fixes-and-changes.patch:
  Delete.
- patches.kernel.org/lpfc-8.3.25-fabric-and-target-discovery-fixes.patch:
  Delete.
- patches.kernel.org/lpfc-8.3.25-miscellaneous-bug-fixes-and-code-cleanup.patch:
  Delete.
- patches.kernel.org/lpfc-8.3.25-pci-and-sr-iov-fixes.patch:
  Delete.
- patches.kernel.org/lpfc-8.3.25-t10-dif-fixes.patch: Delete.
- patches.kernel.org/mac80211-fix-missing-sta_lock-in-__sta_info_destroy.patch:
  Delete.
- patches.kernel.org/make-proc-pid-numa_maps-gather_stats-take-variable-page.patch:
  Delete.
- patches.kernel.org/mcast-fix-source-address-selection-for-multicast-listener-report.patch:
  Delete.
- patches.kernel.org/md-fix-handling-for-devices-from-2tb-to-4tb-in-0.90.patch:
  Delete.
- patches.kernel.org/md-linear-avoid-corrupting-structure-while-waiting-for.patch:
  Delete.
- patches.kernel.org/mfd-fix-initialisation-of-tps65910-interrupts.patch:
  Delete.
- patches.kernel.org/mfd-fix-value-of-wm8994_configure_gpio.patch:
  Delete.
- patches.kernel.org/mfd-make-omap-usb-host-tll-mode-work-again.patch:
  Delete.
- patches.kernel.org/mm-page-allocator-initialise-zlc-for-first-zone-eligible-for-zone_reclaim.patch:
  Delete.
- patches.kernel.org/mm-page-allocator-reconsider-zones-for-allocation-after-direct-reclaim.patch:
  Delete.
- patches.kernel.org/mm-sync-vmalloc-address-space-page-tables-in-alloc_vm_area.patch:
  Delete.
- patches.kernel.org/mmc-core-prevent-aggressive-clock-gating-racing-with-ios.patch:
  Delete.
- patches.kernel.org/mmc-core-use-non-reentrant-workqueue-for-clock-gating.patch:
  Delete.
- patches.kernel.org/mmc-rename-mmc_host_clk_-ungate-gate-to-mmc_host_clk_-hold-release.patch:
  Delete.
- patches.kernel.org/mmc-sdhci-s3c-fix-mmc-card-i-o-problem.patch:
  Delete.
- patches.kernel.org/mpt2sas-added-did_no_connect-return-when-driver-remove-and-avoid-shutdown-call.patch:
  Delete.
- patches.kernel.org/mpt2sas-adding-support-for-customer-specific-branding.patch:
  Delete.
- patches.kernel.org/mxc-iomux-v3-correct-no_pad_ctrl-definition.patch:
  Delete.
- patches.kernel.org/net-9p-fix-client-code-to-fail-more-gracefully-on-protocol-error.patch:
  Delete.
- patches.kernel.org/net-9p-fix-kernel-crash-with-msize-512k.patch:
  Delete.
- patches.kernel.org/net-9p-fix-the-msize-calculation.patch:
  Delete.
- patches.kernel.org/net_sched-prio-use-qdisc_dequeue_peeked.patch:
  Delete.
- patches.kernel.org/netfilter-tcp-and-raw-fix-for-ip_route_me_harder.patch:
  Delete.
- patches.kernel.org/nuvoton-cir-simplify-raw-ir-sample-handling.patch:
  Delete.
- patches.kernel.org/omap-serial-allow-ixon-and-ixoff-to-be-disabled.patch:
  Delete.
- patches.kernel.org/pata_via-disable-atapi-dma-on-averatec-3200.patch:
  Delete.
- patches.kernel.org/perf-symbols-fix-ppc64-segv-in-dso__load_sym-with-debuginfo-files.patch:
  Delete.
- patches.kernel.org/perf-x86-add-model-45-sandybridge-support.patch:
  Delete.
- patches.kernel.org/qdio-clear-shared-dsci-before-scheduling-the-queue-handler.patch:
  Delete.
- patches.kernel.org/qla2xxx-correct-inadvertent-loop-state-transitions-during-port-update-handling.patch:
  Delete.
- patches.kernel.org/rapidio-fix-use-of-non-compatible-registers.patch:
  Delete.
- patches.kernel.org/regulator-tps65910-add-missing-breaks-in-switch-case.patch:
  Delete.
- patches.kernel.org/restore-pinning-the-victim-dentry-in-vfs_rmdir-vfs_rename_dir.patch:
  Delete.
- patches.kernel.org/revert-sfc-use-write-combining-to-reduce-tx-latency-and-follow-ups.patch:
  Delete.
- patches.kernel.org/rt2800pci-fix-compiler-error-on-powerpc.patch:
  Delete.
- patches.kernel.org/rt2x00-do-not-drop-usb-dev-reference-counter-on-suspend.patch:
  Delete.
- patches.kernel.org/rt2x00-fix-crash-in-rt2800usb_get_txwi.patch:
  Delete.
- patches.kernel.org/rt2x00-fix-crash-in-rt2800usb_write_tx_desc.patch:
  Delete.
- patches.kernel.org/rtc-fix-rtc-pie-frequency-limit.patch:
  Delete.
- patches.kernel.org/rtl2800usb-fix-incorrect-storage-of-mac-address-on.patch:
  Delete.
- patches.kernel.org/rtlwifi-fix-problem-when-switching-connections.patch:
  Delete.
- patches.kernel.org/rtlwifi-rtl8192su-fix-problem-connecting-to-ht-enabled-ap.patch:
  Delete.
- patches.kernel.org/savagedb-fix-typo-causing-regression-in-savage4-series.patch:
  Delete.
- patches.kernel.org/sched-fix-a-memory-leak-in-__sdt_free.patch:
  Delete.
- patches.kernel.org/sched-move-blk_schedule_flush_plug-out-of-__schedule.patch:
  Delete.
- patches.kernel.org/sched-separate-the-scheduler-entry-for-preemption.patch:
  Delete.
- patches.kernel.org/scm-capture-the-full-credentials-of-the-scm-sender.patch:
  Delete.
- patches.kernel.org/sendmmsg-sendmsg-fix-unsafe-user-pointer-access.patch:
  Delete.
- patches.kernel.org/serial-8250_pnp-add-intermec-cv60-touchscreen-device.patch:
  Delete.
- patches.kernel.org/sparc-allow-handling-signals-when-stack-is-corrupted.patch:
  Delete.
- patches.kernel.org/sparc-fix-array-bounds-error-setting-up-pcic-nmi-trap.patch:
  Delete.
- patches.kernel.org/sparc32-sun4d-change-ipi-irq-level-to-prevent-collision.patch:
  Delete.
- patches.kernel.org/sparc32-unbreak-arch_write_unlock.patch:
  Delete.
- patches.kernel.org/sparc64-only-panther-cheetah-chips-have-popc.patch:
  Delete.
- patches.kernel.org/sparc64-remove-unnecessary-macros-from-spinlock_64.h.patch:
  Delete.
- patches.kernel.org/sparc64-set-have_c_recordmcount.patch:
  Delete.
- patches.kernel.org/tcp-fix-validation-of-d-sack.patch: Delete.
- patches.kernel.org/tcp-initialize-variable-ecn_ok-in-syncookies-path.patch:
  Delete.
- patches.kernel.org/teach-proc-pid-numa_maps-about-transparent-hugepages.patch:
  Delete.
- patches.kernel.org/tg3-add-5719-and-5720-to-eee_cap-list.patch:
  Delete.
- patches.kernel.org/tg3-fix-int-selftest-for-recent-devices.patch:
  Delete.
- patches.kernel.org/tg3-fix-io-failures-after-chip-reset.patch:
  Delete.
- patches.kernel.org/tpm-call-tpm_transmit-with-correct-size.patch:
  Delete.
- patches.kernel.org/tpm-zero-buffer-after-copying-to-userspace.patch:
  Delete.
- patches.kernel.org/tty-add-spi-prefix-for-spi-modalias.patch:
  Delete.
- patches.kernel.org/tty-pty-fix-pty-counting.patch: Delete.
- patches.kernel.org/usb-ehci-do-not-rely-on-port_suspend-to-stop-usb-resuming-in-ehci_bus_resume.patch:
  Delete.
- patches.kernel.org/usb-ftdi_sio-add-calao-reference-board-support.patch:
  Delete.
- patches.kernel.org/usb-host-pci-quirks.c-correct-annotation-of.patch:
  Delete.
- patches.kernel.org/usb-musb-cppi-fix-build-errors-due-to-dbg-and-missing.patch:
  Delete.
- patches.kernel.org/usb-option-add-yuga-device-id-to-driver.patch:
  Delete.
- patches.kernel.org/usb-option-driver-add-pid-of-huawei-vodafone-k3806.patch:
  Delete.
- patches.kernel.org/usb-option-driver-add-pid-of-huawei-vodafone-k4605.patch:
  Delete.
- patches.kernel.org/usb-option-driver-k3765-k4505-avoid-cdc_data-interface.patch:
  Delete.
- patches.kernel.org/usb-pl2303-correctly-handle-baudrates-above-115200.patch:
  Delete.
- patches.kernel.org/usb-s5p-ehci-fix-a-null-pointer-deference.patch:
  Delete.
- patches.kernel.org/usb-xhci-set-change-bit-when-warm-reset-change-is-set.patch:
  Delete.
- patches.kernel.org/virtio-can-transfer-virtqueue_num-of-pages.patch:
  Delete.
- patches.kernel.org/vlan-reset-headers-on-accel-emulation-path.patch:
  Delete.
- patches.kernel.org/vp7045-fix-buffer-setup.patch: Delete.
- patches.kernel.org/wireless-reset-beacon_found-while-updating-regulatory.patch:
  Delete.
- patches.kernel.org/workqueue-lock-cwq-access-in-drain_workqueue.patch:
  Delete.
- patches.kernel.org/writeback-introduce-.tagged_writepages-for-the-wb_sync_none-sync-stage.patch:
  Delete.
- patches.kernel.org/writeback-update-dirtied_when-for-synced-inode-to-prevent-livelock.patch:
  Delete.
- patches.kernel.org/x86-iommu-mark-dmar-irq-as-non-threaded.patch:
  Delete.
- patches.kernel.org/x86-perf-check-that-current-mm-is-alive-before-getting-user-callchain.patch:
  Delete.
- patches.kernel.org/xen-e820-if-there-is-no-dom0_mem-don-t-tweak-extra_pages.patch:
  Delete.
- patches.kernel.org/xen-smp-warn-user-why-they-keel-over-nosmp-or-noapic-and-what-to-use-instead.patch:
  Delete.
- patches.kernel.org/xen-use-maximum-reservation-to-limit-amount-of-usable-ram.patch:
  Delete.
- patches.kernel.org/xen-x86_32-do-not-enable-iterrupts-when-returning-from.patch:
  Delete.
- patches.kernel.org/xfrm-perform-a-replay-check-after-return-from-async-codepaths.patch:
  Delete.
- patches.kernel.org/xhci-fix-failed-enqueue-in-the-middle-of-isoch-td.patch:
  Delete.
- patches.kernel.org/xhci-fix-memory-leak-during-failed-enqueue.patch:
  Delete.
- patches.kernel.org/xhci-fix-port-u3-status-check-condition.patch:
  Delete.
- patches.kernel.org/xhci-handle-zero-length-isochronous-packets.patch:
  Delete.
- patches.kernel.org/xhci-remove-tds-from-td-lists-when-urbs-are-canceled.patch:
  Delete.
- patches.kernel.org/xhci-report-usb2-port-in-resuming-as-suspend.patch:
  Delete.
- patches.kernel.org/xz-fix-incorrect-xz_buf_error.patch: Delete.
- patches.kernel.org/zorro-defer-device_register-until-all-devices-have-been-identified.patch:
  Delete.
* Tue Oct  4 2011 jbohac@suse.cz
- supported.conf: enable rtc_cmos, inadvertently disabled by commit
  a2a68b74 (the intention was to disable rtc-lib). Fixes bnc#721517.
* Tue Oct  4 2011 hare@suse.de
- patches.drivers/pci-skip-IOV-BARs: Typo: #if should be #ifdef.
* Tue Oct  4 2011 hare@suse.de
- Enable iSCSI target module.
* Tue Oct  4 2011 hare@suse.de
- patches.drivers/target-0001-tcm_fc-Fixing-reference-counting-problem-whi.patch:
  tcm_fc: Fixing reference counting problem which was causing
  ft_sess to be deleted (bnc#718950).
- patches.drivers/target-0002-target-Check-LUN-numbers-in-transport_get_lun_for_.patch:
  target: Check LUN numbers in transport_get_lun_for_[cmd,tmr]
  (bnc#718950).
- patches.drivers/target-0003-target-use-MAINTENANCE_IN-and-MAINTENANCE_OUT-defin.patch:
  target: use MAINTENANCE_IN and MAINTENANCE_OUT definitions in
  scsi.h (bnc#718950).
- patches.drivers/target-0004-target-Remove-unnecessary-cdb-transport_get_lun_fo.patch:
  target: Remove unnecessary *cdb transport_get_lun_for_cmd
  parameter (bnc#718950).
- patches.drivers/target-0005-target-Remove-unused-su_group-usage-in-fabric-regis.patch:
  target: Remove unused su_group usage in fabric
  register/dergister (bnc#718950).
- patches.drivers/target-0006-target-Core-cleanups-from-AGrover-round-1.patch:
  target: Core cleanups from AGrover (round 1) (bnc#718950).
- patches.drivers/target-0007-target-Fix-double-test-of-inquiry_prod.patch:
  target: Fix double test of inquiry_prod (bnc#718950).
- patches.drivers/target-0008-target-More-core-cleanups-from-AGrover-round-2.patch:
  target: More core cleanups from AGrover (round 2) (bnc#718950).
- patches.drivers/target-0009-target-Fix-WRITE_SAME_16-t_task_lba-assignment-bug.patch:
  target: Fix WRITE_SAME_16 t_task_lba assignment bug
  (bnc#718950).
- patches.drivers/target-0010-target-Fix-WRITE_SAME_-16-32-number-of-blocks-0-ca.patch:
  target: Fix WRITE_SAME_[16,32] number of blocks=0 case
  (bnc#718950).
- patches.drivers/target-0011-target-Updates-from-AGrover-and-HCH-round-3.patch:
  target: Updates from AGrover and HCH (round 3) (bnc#718950).
- patches.drivers/target-0012-target-remove-the-always-noop-new_cmd_failure-met.patch:
  target: remove the always-noop ->new_cmd_failure method
  (bnc#718950).
- patches.drivers/target-0013-target-remove-the-unused-SCF_-flags.patch:
  target: remove the unused SCF_* flags (bnc#718950).
- patches.drivers/target-0014-target-merge-release_cmd-methods.patch:
  target: merge release_cmd methods (bnc#718950).
- patches.drivers/target-0015-target-Add-transport_handle_cdb_direct-optimization.patch:
  target: Add transport_handle_cdb_direct optimization
  (bnc#718950).
- patches.drivers/target-0016-target-Add-SCF_EMULATE_QUEUE_FULL-transport_hand.patch:
  target: Add SCF_EMULATE_QUEUE_FULL ->
  transport_handle_queue_full (bnc#718950).
- patches.drivers/target-0017-target-Make-transport_lookup_cmd_lun-locking-IRQ.patch:
  target: Make transport_lookup_cmd_lun() locking IRQ-safe
  (bnc#718950).
- patches.drivers/target-0018-target-Make-se_dev_check_online-locking-IRQ-safe.patch:
  target: Make se_dev_check_online() locking IRQ-safe
  (bnc#718950).
- patches.drivers/target-0019-target-Make-se_tmr_lock-IRQ-safe.patch:
  target: Make se_tmr_lock IRQ-safe (bnc#718950).
- patches.drivers/target-0020-target-iblock-Use-request_queue-nr_request-for-se_.patch:
  target/iblock: Use request_queue->nr_request for se_device
  defaults (bnc#718950).
- patches.drivers/target-0021-target-iblock-Remove-unused-iblock_dev-members.patch:
  target/iblock: Remove unused iblock_dev members (bnc#718950).
- patches.drivers/target-0022-loopback-off-by-one-in-tcm_loop_make_naa_tpg.patch:
  loopback: off by one in tcm_loop_make_naa_tpg() (bnc#718950).
- patches.drivers/target-0023-loopback-Remove-duplicate-scsi-scsi_tcq.h-include.patch:
  loopback: Remove duplicate scsi/scsi_tcq.h include (bnc#718950).
- patches.drivers/target-0024-loopback-Fix-memory-leak-in-tcm_loop_make_scsi_hba.patch:
  loopback: Fix memory leak in tcm_loop_make_scsi_hba()
  (bnc#718950).
- patches.drivers/target-0025-tcm_fc-Makefile-cleanups.patch:
  tcm_fc: Makefile cleanups (bnc#718950).
- patches.drivers/target-0026-tcm_fc-Convert-to-wake_up_process-and-schedule_time.patch:
  tcm_fc: Convert to wake_up_process and
  schedule_timeout_interruptible (bnc#718950).
- patches.drivers/target-0027-target-Allow-for-built-in-target-modules.patch:
  target: Allow for built-in target modules (bnc#718950).
- patches.drivers/target-0028-target-Fix-reporting-of-supported-VPD-pages.patch:
  target: Fix reporting of supported VPD pages (bnc#718950).
- patches.drivers/target-0029-target-Implement-Block-Device-Characteristics-VPD-p.patch:
  target: Implement Block Device Characteristics VPD page
  (bnc#718950).
- patches.drivers/target-0030-target-Make-all-control-CDBs-scatter-gather.patch:
  target: Make all control CDBs scatter-gather (bnc#718950).
- patches.drivers/target-0031-target-Enforce-1-page-max-for-control-cdb-buffer-si.patch:
  target: Enforce 1 page max for control cdb buffer sizes
  (bnc#718950).
- patches.drivers/target-0032-target-Pass-2nd-param-of-transport_split_cdb-by-val.patch:
  target: Pass 2nd param of transport_split_cdb by value
  (bnc#718950).
- patches.drivers/target-0033-target-Eliminate-usage-of-struct-se_mem.patch:
  target: Eliminate usage of struct se_mem (bnc#718950).
- patches.drivers/target-0034-target-Follow-up-core-updates-from-AGrover-and-HCH.patch:
  target: Follow up core updates from AGrover and HCH (round 4)
  (bnc#718950).
- patches.drivers/target-0035-target-map_task_SG-conversion-to-map_control_SG.patch:
  target: ->map_task_SG conversion to ->map_control_SG and
  - >map_data_SG (bnc#718950).
- patches.drivers/target-0036-target-Update-QUEUE-ALGORITHM-MODIFIER-control-page.patch:
  target: Update QUEUE ALGORITHM MODIFIER control page default
  (bnc#718950).
- patches.drivers/target-0037-target-fix-typo-Assoication-Association.patch:
  target: fix typo Assoication -> Association (bnc#718950).
- patches.drivers/target-0038-target-remove-custom-hex2bin-implementation.patch:
  target: remove custom hex2bin() implementation (bnc#718950).
- patches.drivers/target-0039-target-Bump-version-to-v4.1.0-rc1-ml.patch:
  target: Bump version to v4.1.0-rc1-ml (bnc#718950).
- patches.drivers/target-0040-iscsi-target-Add-iSCSI-fabric-support-for-target-v4.patch:
  iscsi-target: Add iSCSI fabric support for target v4.1
  (bnc#718950).
- patches.drivers/target-0041-target-Convert-to-DIV_ROUND_UP_SECTOR_T-usage-for-s.patch:
  target: Convert to DIV_ROUND_UP_SECTOR_T usage for sectors /
  dev_max_sectors (bnc#718950).
- patches.drivers/target-0042-iscsi-target-Fix-NULL-dereference-on-allocation-fai.patch:
  iscsi-target: Fix NULL dereference on allocation failure
  (bnc#718950).
- patches.drivers/target-0043-iscsi-target-strlen-doesn-t-count-the-terminator.patch:
  iscsi-target: strlen() doesn't count the terminator
  (bnc#718950).
- patches.drivers/target-0044-iscsi-target-Fix-uninitialized-usage-of-cmd-pad_by.patch:
  iscsi-target: Fix uninitialized usage of cmd->pad_bytes
  (bnc#718950).
- patches.drivers/target-0045-iscsi-target-Fix-snprintf-usage-with-MAX_PORTAL_LEN.patch:
  iscsi-target: Fix snprintf usage with MAX_PORTAL_LEN
  (bnc#718950).
- patches.drivers/target-0046-iscsi-target-Fix-CONFIG_SMP-n-and-CONFIG_MODULES-n.patch:
  iscsi-target: Fix CONFIG_SMP=n and CONFIG_MODULES=n build
  failure (bnc#718950).
- patches.drivers/target-0047-target-Fix-WRITE_SAME_16-lba-assignment-breakage.patch:
  target: Fix WRITE_SAME_16 lba assignment breakage (bnc#718950).
- patches.drivers/target-0048-target-iscsi_target-depends-on-NET.patch:
  target: iscsi_target depends on NET (bnc#718950).
- patches.drivers/target-0049-target-Fix-bug-for-transport_generic_wait_for_tasks.patch:
  target: Fix bug for transport_generic_wait_for_tasks with
  direct operation (bnc#718950).
- patches.drivers/target-0050-tcm_fc-Handle-DDP-SW-fc_frame_payload_get-failures.patch:
  tcm_fc: Handle DDP/SW fc_frame_payload_get failures in
  ft_recv_write_data (bnc#718950).
- patches.drivers/target-0051-target-Change-TCM_NON_EXISTENT_LUN-response-to-ASC.patch:
  target: Change TCM_NON_EXISTENT_LUN response to ASC=LOGICAL
  UNIT NOT SUPPORTED (bnc#718950).
- patches.drivers/target-0052-target-Make-standard-INQUIRY-return-not-connected.patch:
  target: Make standard INQUIRY return 'not connected' for
  tpg_virt_lun0 (bnc#718950).
- patches.drivers/target-0053-target-Use-ERR_CAST-inlined-function.patch:
  target: Use ERR_CAST inlined function (bnc#718950).
- patches.drivers/target-0054-iscsi-target-Fix-leak-on-failure-in-iscsi_copy_para.patch:
  iscsi-target: Fix leak on failure in iscsi_copy_param_list()
  (bnc#718950).
- patches.drivers/target-0055-target-Convert-target_core_rd.c-to-use-use-BUG_ON.patch:
  target: Convert target_core_rd.c to use use BUG_ON (bnc#718950).
- patches.drivers/target-0056-iscsi-target-remove-duplicate-return.patch:
  iscsi-target: remove duplicate return (bnc#718950).
- patches.drivers/target-0057-iscsi-target-forever-loop-bug-in-iscsit_attach_ooo_.patch:
  iscsi-target: forever loop bug in iscsit_attach_ooo_cmdsn()
  (bnc#718950).
- patches.drivers/target-0058-target-Fix-write-payload-exception-handling-with.patch:
  target: Fix write payload exception handling with ->new_cmd_map
  (bnc#718950).
- patches.drivers/target-0059-target-Add-WRITE_SAME-10-parsing-and-refactor-pas.patch:
  target: Add WRITE_SAME (10) parsing and refactor passthrough
  checks (bnc#718950).
- patches.drivers/target-0060-target-Fix-WRITE_SAME-usage-with-transport_get_size.patch:
  target: Fix WRITE_SAME usage with transport_get_size
  (bnc#718950).
- patches.drivers/target-0061-target-Remove-duplicate-task-completions-in-transpo.patch:
  target: Remove duplicate task completions in
  transport_emulate_control_cdb (bnc#718950).
- patches.drivers/target-0062-target-Fix-SYNCHRONIZE_CACHE-zero-LBA-range-break.patch:
  target: Fix SYNCHRONIZE_CACHE zero LBA + range breakage
  (bnc#718950).
- patches.drivers/target-0063-target-Add-missing-DATA_SG_IO-transport_cmd_get_val.patch:
  target: Add missing DATA_SG_IO transport_cmd_get_valid_sectors
  check (bnc#718950).
- patches.drivers/target-0064-target-Fix-task-count-1-handling-breakage-and-use.patch:
  target: Fix task count > 1 handling breakage and use max_sector
  page alignment (bnc#718950).
- patches.drivers/target-0065-target-Fix-task-SGL-chaining-breakage-with-transpor.patch:
  target: Fix task SGL chaining breakage with
  transport_allocate_data_tasks (bnc#718950).
- patches.drivers/target-0066-iscsi-target-Implement-iSCSI-target-IPv6-address-pr.patch:
  iscsi-target: Implement iSCSI target IPv6 address printing
  (bnc#718950).
- patches.drivers/target-0067-iscsi-target-Fix-iscsit_allocate_se_cmd_for_tmr-fai.patch:
  iscsi-target: Fix iscsit_allocate_se_cmd_for_tmr failure path
  bugs (bnc#718950).
- patches.drivers/target-0068-target-Print-subpage-too-for-unhandled-MODE-SENSE-p.patch:
  target: Print subpage too for unhandled MODE SENSE pages
  (bnc#718950).
- patches.drivers/target-0069-tcm_fc-init-exit-functions-should-not-be-protected.patch:
  tcm_fc: init/exit functions should not be protected by "#ifdef
  MODULE" (bnc#718950).
- patches.drivers/target-0070-target-Make-locking-in-transport_deregister_session.patch:
  target: Make locking in transport_deregister_session() IRQ safe
  (bnc#718950).
- patches.drivers/target-0071-target-Convert-acl_node_lock-to-be-IRQ-disabling.patch:
  target: Convert acl_node_lock to be IRQ-disabling (bnc#718950).
- patches.drivers/target-0072-target-Fix-race-between-multiple-invocations-of-tar.patch:
  target: Fix race between multiple invocations of
  target_qf_do_work() (bnc#718950).
- patches.drivers/target-0073-tcm_fc-Invalidation-of-DDP-context-for-FCoE-target.patch:
  tcm_fc: Invalidation of DDP context for FCoE target in error
  conditions (bnc#718950).
- patches.drivers/target-0074-tcm_fc-Work-queue-based-approach-instead-of-managin.patch:
  tcm_fc: Work queue based approach instead of managing own
  thread and event based mechanism (bnc#718950).
- patches.drivers/target-0075-target-Skip-non-hex-characters-for-VPD-0x83-NAA-IEE.patch:
  target: Skip non hex characters for VPD=0x83 NAA IEEE Registered
  Extended (bnc#718950).
- patches.drivers/target-0076-iscsi-target-Disable-markers-remove-dangerous-loc.patch:
  iscsi-target: Disable markers + remove dangerous local scope
  array usage (bnc#718950).
- patches.drivers/target-0077-iscsi-target-Fix-sendpage-breakage-with-proper-padd.patch:
  iscsi-target: Fix sendpage breakage with proper
  padding+DataDigest iovec offsets (bnc#718950).
- patches.fixes/iscsi-Add-Serial-Number-Arithmetic-LT-and-GT-into-i.patch:
  iscsi: Add Serial Number Arithmetic LT and GT into iscsi_proto.h
  (bnc#718950).
- patches.fixes/iscsi-Resolve-iscsi_proto.h-naming-conflicts-with-d.patch:
  iscsi: Resolve iscsi_proto.h naming conflicts with
  drivers/target/iscsi (bnc#718950).
- patches.fixes/iscsi-Use-struct-scsi_lun-in-iscsi-structs-instead.patch:
  iscsi: Use struct scsi_lun in iscsi structs instead of u8
  (bnc#718950).
- patches.fixes/kernel.h-Add-DIV_ROUND_UP_ULL-and-DIV_ROUND_UP_SECT.patch:
  kernel.h: Add DIV_ROUND_UP_ULL and DIV_ROUND_UP_SECTOR_T macro
  usage (bnc#718950).
* Tue Oct  4 2011 hare@suse.de
- Re-enable SR-IOV for powerpc (bnc#711566).
- patches.drivers/pci-skip-IOV-BARs: pci: skip IOV BARs in
  __pci_enable_device_flags (bnc#711566).
* Mon Oct  3 2011 mmarek@suse.cz
- config.conf: Build KMPs for the -trace flavor as well
  (fate#312759, bnc#712404, bnc#712405, bnc#721337).
* Fri Sep 30 2011 trenn@suse.de
- patches.drivers/acpi_apei_whitelist_hest_dell.patch: Enable
  HEST parsing on Dell platforms by default (bnc#714106).
* Thu Sep 29 2011 dsterba@suse.cz
- patches.suse/btrfs-0904-fix-how-we-mount-subvol-whatever.patch:
  Refresh.
- patches.suse/btrfs-0933-check-unused-against-how-much-space-we-actuall.patch:
  Btrfs: check unused against how much space we actually want
  (FATE#306586).
- patches.suse/btrfs-0934-introduce-convert_extent_bit.patch:
  Btrfs: introduce convert_extent_bit (FATE#306586).
- patches.suse/btrfs-0935-stop-using-write_one_page.patch: Btrfs:
  stop using write_one_page (FATE#306586).
- patches.suse/btrfs-0936-use-the-global-reserve-as-a-backup-for-deletin.patch:
  Btrfs: use the global reserve as a backup for deleting inodes
  (FATE#306586).
- patches.suse/btrfs-0937-break-out-of-orphan-cleanup-if-we-can-t-make-p.patch:
  Btrfs: break out of orphan cleanup if we can't make progress
  (FATE#306586).
- patches.suse/btrfs-0938-allow-us-to-overcommit-our-enospc-reservations.patch:
  Btrfs: allow us to overcommit our enospc reservations
  (FATE#306586).
- patches.suse/btrfs-0939-only-inherit-btrfs-specific-flags-when-creatin.patch:
  Btrfs: only inherit btrfs specific flags when creating files
  (FATE#306586).
- patches.suse/btrfs-8014-trivial-fix-a-potential-memory-leak-in-btrfs_p.patch:
  Refresh.
- patches.suse/btrfs-8017-ratelimit-WARN_ON-in-use_block_rsv.patch:
  Refresh.
- patches.suse/btrfs-do-not-allow-mounting-non-subvolumes-via-subvol.patch:
  Refresh.
- patches.suse/btrfs-push-up-clear_extent_bit-errors-to-callers:
  Refresh.
* Thu Sep 29 2011 tiwai@suse.de
- patches.drivers/lis3-Fix-regression-of-HP-DriveGuard-with-8bit-chip:
  lis3: Fix regression of HP DriveGuard with 8bit chip
  (bnc#721212).
* Thu Sep 29 2011 jankit@suse.de
- patches.fixes/scsi-dh-rdac-use-wwwid-from-c8-to-identify-storage:
  dh_rdac: Use WWID from C8 page instead of Subsystem id from
  C4 page to identify storage (bnc#714786).
* Thu Sep 29 2011 trenn@suse.de
- patches.drivers/acpi_apei_allow_partly_enabling.patch: ACPI
  APEI: Allow enabling of APEI parts via boot param: hest_enable,
  erst_enable (bnc#714106).
* Wed Sep 28 2011 tiwai@suse.de
- patches.fixes/vgaarb-backout-7ad35cf2: Revert "x86/uv/x2apic:
  update for change in pci bridge handling." (bnc#711684).
* Wed Sep 28 2011 tiwai@suse.de
- patches.drivers/drm-i915-DP_PIPE_ENABLED-must-check-transcoder-on-CPT:
  drm/i915: DP_PIPE_ENABLED must check transcoder on CPT
  (bnc#720661).
- patches.drivers/drm-i915-Fix-PCH-port-pipe-select-in-CPT-disable-paths:
  drm/i915: Fix PCH port pipe select in CPT disable paths
  (bnc#720661).
- patches.drivers/drm-i915-Leave-LVDS-registers-unlocked:
  drm/i915: Leave LVDS registers unlocked (bnc#720661).
- patches.drivers/drm-i915-Remove-unused-reg-argument: drm/i915:
  Remove unused 'reg' argument to dp_pipe_enabled (bnc#720661).
- patches.drivers/drm-i915-Wait-for-LVDS-panel-power-sequence:
  drm/i915: Wait for LVDS panel power sequence (bnc#720661).
* Wed Sep 28 2011 eich@suse.de
- patches.fixes/vgaarb-backout-3448a19d: VGA arb: Back out
  Commit 3448a19d.
- patches.fixes/vgaarb-enable-legacy-resources-only-if-device-decodes.patch:
  Refresh.
* Wed Sep 28 2011 mszeredi@suse.cz
- patches.fixes/vfs-fix-the-remaining-automounter-semantics-regressi.patch:
  VFS: Fix the remaining automounter semantics regressions
  (bnc#715496).
- patches.fixes/vfs-pathname-lookup-add-lookup_automount-flag.patch:
  vfs pathname lookup: Add LOOKUP_AUTOMOUNT flag (bnc#715496).
* Mon Sep 26 2011 gregkh@suse.de
- more 3.0.5 patches
- patches.kernel.org/ahci-raid-mode-sata-patch-for-intel-panther-point-deviceids.patch:
  ahci: RAID-mode SATA patch for Intel Panther Point DeviceIDs.
- patches.kernel.org/alsa-fm801-fix-double-free-in-case-of-error-in-tuner-detection.patch:
  ALSA: fm801: Fix double free in case of error in tuner
  detection.
- patches.kernel.org/alsa-fm801-gracefully-handle-failure-of-tuner-auto-detect.patch:
  ALSA: fm801: Gracefully handle failure of tuner auto-detect.
- patches.kernel.org/alsa-usb-audio-clear-chip-probing-on-error-exit.patch:
  ALSA: usb-audio - clear chip->probing on error exit.
- patches.kernel.org/bluetooth-fix-timeout-on-scanning-for-the-second-time.patch:
  Bluetooth: Fix timeout on scanning for the second time.
- patches.kernel.org/btrfs-fix-d_off-in-the-first-dirent.patch:
  btrfs: fix d_off in the first dirent.
- patches.kernel.org/drm-radeon-kms-fix-ddia-enable-on-some-rs690-systems.patch:
  drm/radeon/kms: fix DDIA enable on some rs690 systems.
- patches.kernel.org/isci-change-sas-phy-timeouts-from-54us-to-59us.patch:
  isci: change sas phy timeouts from 54us to 59us.
- patches.kernel.org/isci-fix-event-get-pointer-increment.patch:
  isci: fix event-get pointer increment.
- patches.kernel.org/isci-leave-requests-alone-if-already-terminating.patch:
  isci: Leave requests alone if already terminating.
- patches.kernel.org/libiscsi_tcp-fix-lld-data-allocation.patch:
  libiscsi_tcp: fix LLD data allocation.
- patches.kernel.org/lpfc-8.3.25-adapter-interface-fixes-and-changes.patch:
  lpfc 8.3.25: Adapter Interface fixes and changes.
- patches.kernel.org/lpfc-8.3.25-fabric-and-target-discovery-fixes.patch:
  lpfc 8.3.25: Fabric and Target Discovery Fixes.
- patches.kernel.org/lpfc-8.3.25-miscellaneous-bug-fixes-and-code-cleanup.patch:
  lpfc 8.3.25: Miscellaneous Bug fixes and code cleanup.
- patches.kernel.org/lpfc-8.3.25-pci-and-sr-iov-fixes.patch:
  lpfc 8.3.25: PCI and SR-IOV Fixes.
- patches.kernel.org/lpfc-8.3.25-t10-dif-fixes.patch: lpfc 8.3.25:
  T10 DIF Fixes.
- patches.kernel.org/pci-don-t-crash-when-reading-mpss-from-root-complex.patch:
  pci: Don't crash when reading mpss from root complex.
- patches.kernel.org/perf-symbols-fix-ppc64-segv-in-dso__load_sym-with-debuginfo-files.patch:
  perf symbols: Fix ppc64 SEGV in dso__load_sym with debuginfo
  files.
- patches.kernel.org/usb-host-pci-quirks.c-correct-annotation-of.patch:
  usb/host/pci-quirks.c: correct annotation of
  `ehci_dmi_nohandoff_table'.
- patches.drivers/intel-panther-point-pch-deviceid-fix.patch:
  Delete.
- patches.drivers/lpfc-8.3.25-Adapter-Interface-fixes-and-chan.patch:
  Delete.
- patches.drivers/lpfc-8.3.25-Fabric-and-Target-Discovery-Fixe.patch:
  Delete.
- patches.drivers/lpfc-8.3.25-Miscellaneous-Bug-fixes-and-code.patch:
  Delete.
- patches.drivers/lpfc-8.3.25-PCI-and-SR-IOV-Fixes.patch: Delete.
- patches.drivers/lpfc-8.3.25-T10-DIF-Fixes.patch: Delete.
- patches.fixes/0003-isci-change-sas-phy-timeouts-from-54us-to-59us.patch:
  Delete.
- patches.fixes/0005-isci-Leave-requests-alone-if-already-terminating.patch:
  Delete.
- patches.fixes/0007-isci-fix-event-get-pointer-increment.patch:
  Delete.
- patches.fixes/Bluetooth_Periodic_Inquiry_and_mgmt_discovering_event.patch:
  Delete.
- patches.fixes/libiscsi_tcp-fix-LLD-data-allocation.patch:
  Delete.
- patches.kernel.org/pci-Don_t-crash-when-reading-mpss-from-root-complex.patch:
  Delete.
- patches.suse/btrfs-0098-fix-d_off-in-the-first-dirent.patch:
  Delete.
* Mon Sep 26 2011 rjw@suse.de
- patches.kernel.org/pci-Don_t-crash-when-reading-mpss-from-root-complex.patch:
  pci: Don't crash when reading mpss from root complex
  (bnc#719846).
* Sun Sep 25 2011 rjw@suse.de
- SGI says this patch shouldn't be necessary any more.
- patches.arch/x86-fix_irq_assignment-on-NUMA-systems.patch:
  Delete.
* Sat Sep 24 2011 gregkh@suse.de
- remove old moblin patches that are no longer needed here at all:
- patches.suse/linux-2.6.29-dont-wait-for-mouse.patch: Delete.
- patches.suse/linux-2.6.29-enable-async-by-default.patch: Delete.
- patches.suse/linux-2.6.29-jbd-longer-commit-interval.patch:
  Delete.
- patches.suse/linux-2.6.29-kms-after-sata.patch: Delete.
- patches.suse/linux-2.6.29-silence-acer-message.patch: Delete.
- patches.suse/linux-2.6.29-touchkit.patch: Delete.
* Fri Sep 23 2011 gregkh@suse.de
- more 3.0.5 patches:
- patches.kernel.org/arp-fix-rcu-lockdep-splat-in-arp_process.patch:
  arp: fix rcu lockdep splat in arp_process().
- patches.kernel.org/bridge-fix-a-possible-net_device-leak.patch:
  bridge: fix a possible net_device leak.
- patches.kernel.org/bridge-fix-a-possible-use-after-free.patch:
  bridge: fix a possible use after free.
- patches.kernel.org/bridge-pseudo-header-required-for-the-checksum-of-icmpv6.patch:
  bridge: Pseudo-header required for the checksum of ICMPv6.
- patches.kernel.org/fib-fix-bug_on-in-fib_nl_newrule-when-add-new-fib-rule.patch:
  fib:fix BUG_ON in fib_nl_newrule when add new fib rule.
- patches.kernel.org/ipv4-some-rt_iif-rt_route_iif-conversions.patch:
  ipv4: some rt_iif -> rt_route_iif conversions.
- patches.kernel.org/ipv6-fix-ipv6_getsockopt-for-ipv6_2292pktoptions.patch:
  ipv6: Fix ipv6_getsockopt for IPV6_2292PKTOPTIONS.
- patches.kernel.org/mcast-fix-source-address-selection-for-multicast-listener-report.patch:
  mcast: Fix source address selection for multicast listener
  report.
- patches.kernel.org/net_sched-prio-use-qdisc_dequeue_peeked.patch:
  net_sched: prio: use qdisc_dequeue_peeked.
- patches.kernel.org/netfilter-tcp-and-raw-fix-for-ip_route_me_harder.patch:
  netfilter: TCP and raw fix for ip_route_me_harder.
- patches.kernel.org/revert-sfc-use-write-combining-to-reduce-tx-latency-and-follow-ups.patch:
  Revert "sfc: Use write-combining to reduce TX latency"
  and follow-ups.
- patches.kernel.org/scm-capture-the-full-credentials-of-the-scm-sender.patch:
  scm: Capture the full credentials of the scm sender.
- patches.kernel.org/tcp-fix-validation-of-d-sack.patch: tcp:
  fix validation of D-SACK.
- patches.kernel.org/tcp-initialize-variable-ecn_ok-in-syncookies-path.patch:
  tcp: initialize variable ecn_ok in syncookies path.
- patches.kernel.org/tpm-call-tpm_transmit-with-correct-size.patch:
  TPM: Call tpm_transmit with correct size.
- patches.kernel.org/tpm-zero-buffer-after-copying-to-userspace.patch:
  TPM: Zero buffer after copying to userspace.
- patches.kernel.org/vlan-reset-headers-on-accel-emulation-path.patch:
  vlan: reset headers on accel emulation path.
- patches.kernel.org/xfrm-perform-a-replay-check-after-return-from-async-codepaths.patch:
  xfrm: Perform a replay check after return from async codepaths.
- patches.kernel.org/zorro-defer-device_register-until-all-devices-have-been-identified.patch:
  zorro: Defer device_register() until all devices have been
  identified.
- patches.arch/s390-32-01-qdio_shared_dsci_race: Delete.
- patches.drivers/USB3-0103-ehci-refactor-pci-quirk-to-use-standard-dmi_check_system-met.patch:
  Delete.
- patches.drivers/USB3-0104-ehci-add-pci-quirk-for-Ordissimo-and-RM-Slate-100-too.patch:
  Delete.
- patches.drivers/USB3-0113-USB-PL2303-correctly-handle-baudrates-above-115200.patch:
  Delete.
- patches.drivers/USB3-0127-ASIX-Add-AX88772B-USB-ID.patch:
  Delete.
- patches.drivers/USB3-0134-cdc_ncm-fix-endianness-problem.patch:
  Delete.
- patches.drivers/fcoe-0001-libfc-Enhancement-to-RPORT-state-machine-app.patch:
  Delete.
- patches.drivers/fcoe-0004-fcoe-Unable-to-select-the-exchangeID-from-of.patch:
  Delete.
- patches.drivers/mpt2sas-Added-DID_NO_CONNECT-return-when-dri.patch:
  Delete.
- patches.drivers/mpt2sas-Adding-support-for-customer-specific.patch:
  Delete.
- patches.drivers/tg3-add-5719-and-5720-to-eee_cap-list: Delete.
- patches.drivers/tg3-fix-int-selftest-for-recent-devices: Delete.
- patches.fixes/iscsi_tcp-fix-locking-around-iscsi-sk-user-data.patch:
  Delete.
- patches.fixes/mqueue-fix-mq_open-return-value.patch: Delete.
- patches.fixes/mqueue-refactor-failure-handling.patch: Delete.
- patches.fixes/tg3-Fix-io-failures-after-chip-reset.patch:
  Delete.
- patches.fixes/writeback-introduce-.tagged_writepages-for-the-WB_SY.patch:
  Delete.
- patches.fixes/writeback-update-dirtied_when-for-synced-inode-to-pr.patch:
  Delete.
- patches.suse/intel-perf-add-model-45.patch: Delete.
* Fri Sep 23 2011 ohering@suse.de
- patches.suse/staging-hv-pata_piix-ignore-disks.patch:
  Reduce patch size.
* Fri Sep 23 2011 ohering@suse.de
- patches.suse/mkinitrd-scsi_host_template-proc_name.patch:
  remove duplicate entry in drivers/scsi/eata_pio.c
* Fri Sep 23 2011 ohering@suse.de
- patches.suse/staging-hv-bind-hv_blkkvsc-to-hv_storvsc.patch:
  remove unused alias from sles11sp2 betas and keep only hv_blkvsc
* Fri Sep 23 2011 dsterba@suse.cz
- patches.suse/btrfs-0006-fix-error-check-of-btrfs_lookup_dentry.patch:
  Refresh.
- patches.suse/btrfs-0904-fix-how-we-mount-subvol-whatever.patch:
  Refresh.
- patches.suse/btrfs-0929-make-sure-to-unset-trans-block_rsv-before-runn.patch:
  Btrfs: make sure to unset trans->block_rsv before running
  delayed refs (FATE#306586).
- patches.suse/btrfs-0930-delay-iput-when-deleting-a-block-group.patch:
  Btrfs: delay iput when deleting a block group (FATE#306586).
- patches.suse/btrfs-0931-use-the-inode-s-mapping-mask-for-allocating-pa.patch:
  Btrfs: use the inode's mapping mask for allocating pages
  (FATE#306586).
- patches.suse/btrfs-0932-fix-orphan-cleanup-regression.patch:
  Btrfs: fix orphan cleanup regression (FATE#306586).
- patches.suse/fs-fix-how-we-clear-DCACHE_NEED_LOOKUP.patch:
  Refresh.
- patches.suse/btrfs-0930-make-sure-to-unset-trans-block_rsv-before-runn.patch:
  Delete.
- patches.suse/btrfs-0931-delay-iput-when-deleting-a-block-group.patch:
  Delete.
- patches.suse/btrfs-0933-fix-orphan-cleanup-regression.patch:
  Delete.
* Fri Sep 23 2011 trenn@suse.de
- patches.arch/001-efi_pstore_fixes.patch: efi: Add support for
  using efivars as a pstore backend (bnc#718551).
- patches.arch/002-efi_pstore_fixes.patch: efivars: String
  functions (bnc#718551).
- patches.arch/003-efi_pstore_fixes.patch: efivars: introduce
  utf16_strncmp (bnc#718551).
- patches.arch/004-efi_pstore_fixes.patch: efivars: Use string
  functions in pstore_write (bnc#718551).
- patches.arch/005-efi_pstore_fixes.patch: efivars: Introduce
  PSTORE_EFI_ATTRIBUTES (bnc#718551).
- patches.arch/006-efi_pstore_fixes.patch: efivars: fix warnings
  when CONFIG_PSTORE=n (bnc#718551).
* Fri Sep 23 2011 jkosina@suse.cz
- Update config files: disable KDB on x86_32 before it gets fixed
  there.
* Fri Sep 23 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove forgotten backslash.
* Fri Sep 23 2011 jkosina@suse.cz
- Update config files.
- patches.suse/kdb-fix-cpumask-usage.patch: Refresh.
- patches.suse/kdb-v4.4-3.1-common-1: kdb-v4.4-2.6.32-common-3
  (FATE#303971).
- patches.suse/kdb-v4.4-3.1-ia64-1: kdb-v4.4-2.6.32-common-3
  (FATE#303971).
- patches.suse/kdb-v4.4-3.1-x86-1: kdb-v4.4-2.6.32-common-3
  (FATE#303971).
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/stack-unwind: Refresh.
- patches.xen/xen3-fixup-common: Refresh.
- patches.xen/xen3-patch-2.6.24: Refresh.
- patches.xen/xen3-patch-2.6.27: Refresh.
- patches.xen/xen3-patch-2.6.28: Refresh.
- patches.xen/xen3-patch-2.6.33: Refresh.
- patches.fixes/kdb-no-printk-logging.patch: Delete.
- patches.suse/kdb-bt-with-pt-regs.patch: Delete.
- patches.suse/kdb-build-fixes: Delete.
- patches.suse/kdb-common: Delete.
- patches.suse/kdb-fix-incomplete-backtrace.patch: Delete.
- patches.suse/kdb-fix-kdb_cmds-to-include-the-arch-common-macro:
  Delete.
- patches.suse/kdb-fix-the-multi-word-nop-instructions-in-the-disassembler:
  Delete.
- patches.suse/kdb-fix-uhci-build-issues.patch: Delete.
- patches.suse/kdb-handle-nonexistance-keyboard-controller:
  Delete.
- patches.suse/kdb-ia64: Delete.
- patches.suse/kdb-usb-rework: Delete.
- patches.suse/kdb-x86: Delete.
- patches.suse/kdb-x86-backtrace-code-to-use-the-in-kernel-show_stack-function:
  Delete.
- patches.suse/kdb-x86-build-fixes: Delete.
- patches.suse/kdb_fix_ia64_build.patch: Delete.
- patches.suse/mm-change-anon_vma_linking-for-scalability-kdb.patch:
  Delete.
- patches.suse/x86-add-kdb-support-for-unknown_nmi_error-handler.patch:
  Delete.
- patches.suse/x86-uv-kdb-support-for-uv-nmi-handler.patch:
  Delete.
* Fri Sep 23 2011 mmarek@suse.cz
- patches.drivers/bnx2x-advance-version.patch: bnx2x: advance
  version (bnc#698050, fate#311461).
* Fri Sep 23 2011 jbeulich@novell.com
- Update Xen patches to c/s 1105.
- patches.xen/xen-pci-multi-segment: pass PCI segment information
  to Xen.
- patches.xen/xen3-x86_amd_interlagos_mem_alignment_perf_improve_2_4.patch:
  x86: Add a BSP cpu_dev helper (bnc#711285).
- patches.xen/xen-x86-mmcfg-ACPI-reserved: Delete (merged into other
  patches).
* Fri Sep 23 2011 tiwai@suse.de
- patches.arch/x86-fix-S4-regression: x86: Fix S4 regression
  (bnc#714605).
* Thu Sep 22 2011 rjw@suse.de
- patches.arch/x86-Fix-pointer-dereference-before-call-to-pcie_bus_configure_settings.patch:
  x86: Fix pointer dereference before call to
  pcie_bus_configure_settings (bnc#717372).
* Thu Sep 22 2011 rjw@suse.de
- patches.arch/x86-efi-use-old-memmap.patch: x86: Fix efi boot
  breakage on UV (bnc#718165).
* Thu Sep 22 2011 mmarek@suse.cz
- patches.drivers/bnx2x-add-new-PHY-BCM54616: bnx2x: Add new
  PHY BCM54616 (bnc#698050, fate#311461).
* Thu Sep 22 2011 dsterba@suse.cz
- patches.suse/btrfs-0006-fix-error-check-of-btrfs_lookup_dentry.patch:
  Refresh.
- patches.suse/btrfs-0098-fix-d_off-in-the-first-dirent.patch:
  btrfs: fix d_off in the first dirent (FATE#306586).
- patches.suse/btrfs-0099-fix-pages-truncation-in-btrfs_ioctl_clone.patch:
  Btrfs: fix pages truncation in btrfs_ioctl_clone()
  (FATE#306586).
- patches.suse/btrfs-0100-don-t-make-a-file-partly-checksummed-through-f.patch:
  Btrfs: don't make a file partly checksummed through file clone
  (FATE#306586).
- patches.suse/btrfs-0101-don-t-change-inode-flag-of-the-dest-clone-file.patch:
  Btrfs: don't change inode flag of the dest clone file
  (FATE#306586).
- patches.suse/btrfs-0102-Fix-lseek-return-value-for-error.patch:
  BTRFS: Fix lseek return value for error (FATE#306586).
- patches.suse/btrfs-0103-only-clear-the-need-lookup-flag-after-the-dent.patch:
  Btrfs: only clear the need lookup flag after the dentry is setup
  (FATE#306586).
- patches.suse/btrfs-0104-reserve-sufficient-space-for-ioctl-clone.patch:
  Btrfs: reserve sufficient space for ioctl clone (FATE#306586).
- patches.suse/btrfs-0930-make-sure-to-unset-trans-block_rsv-before-runn.patch:
  Btrfs: make sure to unset trans->block_rsv before running
  delayed refs (FATE#306586).
- patches.suse/btrfs-0931-delay-iput-when-deleting-a-block-group.patch:
  Btrfs: delay iput when deleting a block group (FATE#306586).
- patches.suse/btrfs-0932-use-the-inode-s-mapping-mask-for-allocating-pa.patch:
  Btrfs: use the inode's mapping mask for allocating pages
  (FATE#306586).
- patches.suse/btrfs-0933-fix-orphan-cleanup-regression.patch:
  Btrfs: fix orphan cleanup regression (FATE#306586).
- patches.suse/btrfs-8014-trivial-fix-a-potential-memory-leak-in-btrfs_p.patch:
  Refresh.
- patches.suse/btrfs-push-up-unlock_extent-errors-to-callers:
  Refresh.
- patches.suse/btrfs-8002-Free-inode-mutex-on-lseek-error.patch:
  Delete.
- patches.suse/btrfs-8015-don-t-change-inode-flag-of-the-dest-clone-file.patch:
  Delete.
- patches.suse/btrfs-8016-fix-d_off-in-the-first-dirent.patch:
  Delete.
- patches.suse/btrfs-8019-fix-pages-truncation-in-clone.patch:
  Delete.
- patches.suse/btrfs-reserve-sufficient-space-for-ioctl-clone.patch:
  Delete.
* Thu Sep 22 2011 jjolly@suse.de
- supported.conf: Added /net/rds
* Thu Sep 22 2011 mmarek@suse.cz
- supported.conf: Match whole unsupported directories by wildcards,
  remove drivers/mtd/devices/ps3vram and dependencies.
* Thu Sep 22 2011 mmarek@suse.cz
- patches.suse/supported-flag-wildcards: Match also subdirectories
  with '*'.
- supported.conf: Mark Documentation/* and drivers/staging/* as
  unsupported, except for drivers/stating/hv.
* Thu Sep 22 2011 mmarek@suse.cz
- rpm/split-modules: Print the full path for modules missing in
  supported.conf.
* Thu Sep 22 2011 mmarek@suse.cz
- supported.conf: Fix stray line making net/atm/atm suddenly
  unsupported.
* Thu Sep 22 2011 tonyj@suse.de
- Update config files.
- patches.trace/utrace-core: Delete.
- patches.trace/utrace-core.patch: update utrace core for 3.0
* Thu Sep 22 2011 gregkh@suse.de
- more 3.0.5 patches
- patches.kernel.org/arm-dove-fix-second-spi-initialization-call.patch:
  ARM: Dove: fix second SPI initialization call.
- patches.kernel.org/asix-add-ax88772b-usb-id.patch: ASIX:
  Add AX88772B USB ID.
- patches.kernel.org/b43-fix-beacon-problem-in-ad-hoc-mode.patch:
  b43: Fix beacon problem in ad-hoc mode.
- patches.kernel.org/blk-cgroup-be-able-to-remove-the-record-of-unplugged-device.patch:
  blk-cgroup: be able to remove the record of unplugged device.
- patches.kernel.org/break-out-numa_maps-gather_pte_stats-checks.patch:
  break out numa_maps gather_pte_stats() checks.
- patches.kernel.org/cdc_ncm-fix-endianness-problem.patch:
  cdc_ncm: fix endianness problem.
- patches.kernel.org/ehci-add-pci-quirk-for-ordissimo-and-rm-slate-100-too.patch:
  ehci: add pci quirk for Ordissimo and RM Slate 100 too.
- patches.kernel.org/ehci-refactor-pci-quirk-to-use-standard-dmi_check_system-method.patch:
  ehci: refactor pci quirk to use standard dmi_check_system
  method.
- patches.kernel.org/fcoe-unable-to-select-the-exchangeid-from-offload-pool-for-storage-targets.patch:
  fcoe: Unable to select the exchangeID from offload pool for
  storage targets.
- patches.kernel.org/floppy-use-del_timer_sync-in-init-cleanup.patch:
  floppy: use del_timer_sync() in init cleanup.
- patches.kernel.org/ipc-mqueue.c-fix-mq_open-return-value.patch:
  ipc/mqueue.c: fix mq_open() return value.
- patches.kernel.org/ipc-mqueue.c-refactor-failure-handling.patch:
  ipc/mqueue.c: refactor failure handling.
- patches.kernel.org/iscsi_tcp-fix-locking-around-iscsi-sk-user-data.patch:
  iscsi_tcp: fix locking around iscsi sk user data.
- patches.kernel.org/iwlagn-workaround-bug-crashing-some-aps.patch:
  iwlagn: workaround bug crashing some APs.
- patches.kernel.org/ixgbe-fix-possible-null-buffer-error.patch:
  ixgbe: fix possible null buffer error.
- patches.kernel.org/libfc-enhancement-to-rport-state-machine-applicable-only-for-vn2vn-mode.patch:
  libfc: Enhancement to RPORT state machine applicable only for
  VN2VN mode.
- patches.kernel.org/make-proc-pid-numa_maps-gather_stats-take-variable-page.patch:
  make /proc/$pid/numa_maps gather_stats() take variable page
  size.
- patches.kernel.org/mpt2sas-added-did_no_connect-return-when-driver-remove-and-avoid-shutdown-call.patch:
  mpt2sas: Added DID_NO_CONNECT return when driver remove and
  avoid shutdown call.
- patches.kernel.org/mpt2sas-adding-support-for-customer-specific-branding.patch:
  mpt2sas: Adding support for customer specific branding.
- patches.kernel.org/perf-x86-add-model-45-sandybridge-support.patch:
  perf, x86: Add model 45 SandyBridge support.
- patches.kernel.org/qdio-clear-shared-dsci-before-scheduling-the-queue-handler.patch:
  qdio: clear shared DSCI before scheduling the queue handler.
- patches.kernel.org/rt2800pci-fix-compiler-error-on-powerpc.patch:
  rt2800pci: Fix compiler error on PowerPC.
- patches.kernel.org/rtl2800usb-fix-incorrect-storage-of-mac-address-on.patch:
  rtl2800usb: Fix incorrect storage of MAC address on big-endian
  platforms.
- patches.kernel.org/teach-proc-pid-numa_maps-about-transparent-hugepages.patch:
  teach /proc/$pid/numa_maps about transparent hugepages.
- patches.kernel.org/tg3-add-5719-and-5720-to-eee_cap-list.patch:
  tg3: Add 5719 and 5720 to EEE_CAP list.
- patches.kernel.org/tg3-fix-int-selftest-for-recent-devices.patch:
  tg3: Fix int selftest for recent devices.
- patches.kernel.org/tg3-fix-io-failures-after-chip-reset.patch:
  tg3: Fix io failures after chip reset.
- patches.kernel.org/usb-pl2303-correctly-handle-baudrates-above-115200.patch:
  USB: PL2303: correctly handle baudrates above 115200.
- patches.kernel.org/wireless-reset-beacon_found-while-updating-regulatory.patch:
  wireless: Reset beacon_found while updating regulatory.
- patches.kernel.org/writeback-introduce-.tagged_writepages-for-the-wb_sync_none-sync-stage.patch:
  writeback: introduce .tagged_writepages for the WB_SYNC_NONE
  sync stage.
- patches.kernel.org/writeback-update-dirtied_when-for-synced-inode-to-prevent-livelock.patch:
  writeback: update dirtied_when for synced inode to prevent
  livelock.
- patches.kernel.org/xen-e820-if-there-is-no-dom0_mem-don-t-tweak-extra_pages.patch:
  xen/e820: if there is no dom0_mem=, don't tweak extra_pages.
- patches.kernel.org/xen-use-maximum-reservation-to-limit-amount-of-usable-ram.patch:
  xen: use maximum reservation to limit amount of usable RAM.
- patches.kernel.org/xz-fix-incorrect-xz_buf_error.patch: XZ:
  Fix incorrect XZ_BUF_ERROR.
* Wed Sep 21 2011 gregkh@suse.de
- patches.drivers/pci-set-pci-e-max-payload-size-on-fabric.patch:
  Delete. not needed anymore
* Wed Sep 21 2011 gregkh@suse.de
- patches.fixes/ccwgroup-fix-availability-of-attributes.patch:
  ccwgroup: fix availability of attributes (bnc#717797).
* Wed Sep 21 2011 ohering@suse.de
- patches.suse/mkinitrd-scsi_host_template-proc_name.patch:
  fill scsi_host_template.proc_name and add runtime warning if
  its missing (bnc#718366).
* Wed Sep 21 2011 gregkh@suse.de
- patches.suse/trace-open.patch: Delete. It was for preload only and is no
  longer needed in our trees.
* Wed Sep 21 2011 jjolly@suse.de
- series.conf: When one adds patches, one should make sure the
  series.conf file is updated as well. Fixed git-id:f6f28136
  (bnc#706587)
* Wed Sep 21 2011 mmarek@suse.cz
- Add support for wildcards in supported.conf:
- rpm/kernel-binary.spec.in: Generate Module.supported with all
  lines from supported conf, unsupported modules are marked as "no"
- rpm/split-modules: Use the supported flag in modules, instead of
  parsing the Module.supported file and report modules that have no
  supported marking.
- rpm/check-supported-list: Delete, this is done by split-modules
  now.
* Wed Sep 21 2011 jkosina@suse.cz
- patches.drivers/intel-panther-point-pch-deviceid-fix.patch:
  New RAID DeviceID for Intel Panther Point PCH (bnc#682755
  fate#311837).
* Wed Sep 21 2011 mmarek@suse.cz
- supported.conf: Remove the kernel/ prefix from module paths.
* Wed Sep 21 2011 trenn@suse.de
- patches.drivers/hpwdt_add_next_gen_HP_servers.patch: watchdog:
  hpwdt: add next gen HP servers (bnc#718936).
* Wed Sep 21 2011 tiwai@suse.de
- patches.drivers/iwlwifi-sp1-compatible-options: Add
  SP1-compatible module options to IWLWIFI drivers (bnc#719408).
* Wed Sep 21 2011 tiwai@suse.de
- Update config files:
  Enable CONFIG_IWLWIFI_LEGACY_DEBUG=y to be compatible with SP1
* Wed Sep 21 2011 oneukum@suse.de
- patches.drivers/0001-btusb-add-device-entry-for-Broadcom-SoftSailing.patch:
  btusb: add device entry for Broadcom SoftSailing (bnc#719296).
* Wed Sep 21 2011 tiwai@suse.de
- patches.drivers/snd-hdspm-compat-options: Add dummy compatible
  options to snd-hdspm driver (bnc#719408).
* Tue Sep 20 2011 gregkh@suse.de
- patches.rpmify/fix-WARN_RATELIMIT-for-non-CONFIG_BUG.patch:
  Delete, it's no longer needed.
* Tue Sep 20 2011 gregkh@suse.de
- patches.kernel.org/qla2xxx-correct-inadvertent-loop-state-transitions-during-port-update-handling.patch:
  Refresh.
* Tue Sep 20 2011 gregkh@suse.de
- patches.kernel.org/iwlagn-fix-command-queue-timeout.patch:
  Refresh.
* Tue Sep 20 2011 gregkh@suse.de
- More 3.0.5 patches:
- patches.drivers/hpsa-update-to-hp-version.patch: Refresh.
- patches.kernel.org/acpica-acpi_max_sleep-should-be-2-sec-not-20.patch:
  acpica: ACPI_MAX_SLEEP should be 2 sec, not 20.
- patches.kernel.org/alsa-hda-cirrus-fix-surround-speaker-volume-control-name.patch:
  ALSA: HDA: Cirrus - fix "Surround Speaker" volume control name.
- patches.kernel.org/alsa-hda-realtek-fix-auto-mute-with-hp-lo-configuration.patch:
  ALSA: hda/realtek - Fix auto-mute with HP+LO configuration.
- patches.kernel.org/alsa-pcm-fix-race-condition-in-wait_for_avail.patch:
  ALSA: pcm - fix race condition in wait_for_avail().
- patches.kernel.org/asoc-blackfin-bf5xx-ad193x-fix-codec-device-name.patch:
  ASoC: Blackfin: bf5xx-ad193x: Fix codec device name.
- patches.kernel.org/asoc-fix-reporting-of-partial-jack-updates.patch:
  ASoC: Fix reporting of partial jack updates.
- patches.kernel.org/asoc-mpc5200-replace-of_device-with-platform_device.patch:
  ASoC: MPC5200: replace of_device with platform_device.
- patches.kernel.org/ath9k_hw-fix-calibration-on-5-ghz.patch:
  ath9k_hw: fix calibration on 5 ghz.
- patches.kernel.org/cifs-fix-possible-memory-corruption-in-cifsfindnext.patch:
  cifs: fix possible memory corruption in CIFSFindNext.
- patches.kernel.org/drivers-cpufreq-pcc-cpufreq.c-avoid-null-pointer-dereference.patch:
  drivers/cpufreq/pcc-cpufreq.c: avoid NULL pointer dereference.
- patches.kernel.org/drivers-leds-ledtrig-timer.c-fix-broken-sysfs-delay-handling.patch:
  drivers/leds/ledtrig-timer.c: fix broken sysfs delay handling.
- patches.kernel.org/drm-radeon-don-t-read-from-cp-ring-write-pointer-registers.patch:
  drm/radeon: Don't read from CP ring write pointer registers.
- patches.kernel.org/drm-radeon-kms-fix-typo-in-r100_blit_copy.patch:
  drm/radeon/kms: fix typo in r100_blit_copy.
- patches.kernel.org/drm-radeon-kms-make-gpu-cpu-page-size-handling-consistent-in-blit-code-v2.patch:
  drm/radeon/kms: Make GPU/CPU page size handling consistent in
  blit code (v2).
- patches.kernel.org/e1000-fix-driver-to-be-used-on-pa-risc-c8000-workstations.patch:
  e1000: Fix driver to be used on PA RISC C8000 workstations.
- patches.kernel.org/firewire-ohci-add-no-msi-quirk-for-o2micro-controller.patch:
  firewire: ohci: add no MSI quirk for O2Micro controller.
- patches.kernel.org/fix-the-conflict-between-rwpidforward-and-rw-mount-options.patch:
  Fix the conflict between rwpidforward and rw mount options.
- patches.kernel.org/genirq-make-irq_shutdown-symmetric-vs.-irq_startup-again.patch:
  genirq: Make irq_shutdown() symmetric vs. irq_startup again.
- patches.kernel.org/hpsa-fix-physical-device-lun-and-target-numbering-problem.patch:
  hpsa: fix physical device lun and target numbering problem.
- patches.kernel.org/hpsa-fix-problem-that-obdr-devices-are-not-detected.patch:
  hpsa: fix problem that OBDR devices are not detected.
- patches.kernel.org/ibmveth-checksum-offload-is-always-disabled.patch:
  ibmveth: Checksum offload is always disabled.
- patches.kernel.org/ibmveth-fix-dma-unmap-error.patch: ibmveth:
  Fix DMA unmap error.
- patches.kernel.org/ibmveth-fix-issue-with-dma-mapping-failure.patch:
  ibmveth: Fix issue with DMA mapping failure.
- patches.kernel.org/isci-fix-32-bit-operation-when-config_highmem64g-n.patch:
  isci: fix 32-bit operation when CONFIG_HIGHMEM64G=n.
- patches.kernel.org/isci-fix-sata-response-handling.patch:
  isci: fix sata response handling.
- patches.kernel.org/iwlagn-fix-command-queue-timeout.patch:
  iwlagn: fix command queue timeout.
- patches.kernel.org/iwlegacy-fix-bug_on-info-control.rates.idx-0.patch:
  iwlegacy: fix BUG_ON(info->control.rates.idx < 0).
- patches.kernel.org/mac80211-fix-missing-sta_lock-in-__sta_info_destroy.patch:
  mac80211: fix missing sta_lock in __sta_info_destroy.
- patches.kernel.org/mfd-fix-initialisation-of-tps65910-interrupts.patch:
  mfd: Fix initialisation of tps65910 interrupts.
- patches.kernel.org/mfd-fix-value-of-wm8994_configure_gpio.patch:
  mfd: Fix value of WM8994_CONFIGURE_GPIO.
- patches.kernel.org/mfd-make-omap-usb-host-tll-mode-work-again.patch:
  mfd: Make omap-usb-host TLL mode work again.
- patches.kernel.org/mm-sync-vmalloc-address-space-page-tables-in-alloc_vm_area.patch:
  mm: sync vmalloc address space page tables in alloc_vm_area().
- patches.kernel.org/qla2xxx-correct-inadvertent-loop-state-transitions-during-port-update-handling.patch:
  qla2xxx: Correct inadvertent loop state transitions during
  port-update handling.
- patches.kernel.org/restore-pinning-the-victim-dentry-in-vfs_rmdir-vfs_rename_dir.patch:
  restore pinning the victim dentry in
  vfs_rmdir()/vfs_rename_dir().
- patches.kernel.org/rtlwifi-fix-problem-when-switching-connections.patch:
  rtlwifi: Fix problem when switching connections.
- patches.kernel.org/rtlwifi-rtl8192su-fix-problem-connecting-to-ht-enabled-ap.patch:
  rtlwifi: rtl8192su: Fix problem connecting to HT-enabled AP.
- patches.kernel.org/usb-xhci-set-change-bit-when-warm-reset-change-is-set.patch:
  USB: xhci: Set change bit when warm reset change is set.
- patches.kernel.org/vfs-automount-should-ignore-lookup_follow.patch:
  vfs: automount should ignore LOOKUP_FOLLOW.
- patches.kernel.org/workqueue-lock-cwq-access-in-drain_workqueue.patch:
  workqueue: lock cwq access in drain_workqueue.
- patches.kernel.org/x86-iommu-mark-dmar-irq-as-non-threaded.patch:
  x86, iommu: Mark DMAR IRQ as non-threaded.
- patches.drivers/cpufreq_pcc_sanity_check_acpi_processor_data.patch:
  Delete.
- patches.fixes/0001-isci-fix-sata-response-handling.patch:
  Delete.
- patches.fixes/0002-isci-fix-32-bit-operation-when-CONFIG_HIGHMEM64G-n.patch:
  Delete.
- patches.fixes/cifs-fix-possible-memory-corruption-in-CIFSFindNext.patch:
  Delete.
* Tue Sep 20 2011 mmarek@suse.cz
- patches.suse/supported-flag-underscores: Mark underscores() as
  static.
* Tue Sep 20 2011 mmarek@suse.cz
- patches.suse/supported-flag-wildcards: modpost: Allow wildcards
  in the Module.supported file.
* Tue Sep 20 2011 mmarek@suse.cz
- patches.suse/supported-flag-underscores: modpost: Fix matching
  of dashes and underscores in Module.supported (bnc#719090).
* Tue Sep 20 2011 hare@suse.de
- patches.drivers/ixgbe-Fix-FCOE-memory-leak-for-DDP-packets.patch:
  ixgbe: Fix FCOE memory leak for DDP packets (bnc#719029).
- patches.drivers/ixgbe-setup-per-CPU-PCI-pool-for-FCoE-DDP.patch:
  ixgbe: setup per CPU PCI pool for FCoE DDP (bnc#719029).
* Tue Sep 20 2011 gregkh@suse.de
- More 3.0.5 patches:
- patches.kernel.org/fs-9p-add-os-dependent-open-flags-in-9p-protocol.patch:
  fs/9p: Add OS dependent open flags in 9p protocol.
- patches.kernel.org/fs-9p-use-protocol-defined-value-for-lock-getlock-type-field.patch:
  Refresh.
- patches.kernel.org/pci-export-pcie_bus_configure_settings-symbol.patch:
  PCI: export pcie_bus_configure_settings symbol.
- patches.kernel.org/pci-remove-mrrs-modification-from-mps-setting-code.patch:
  PCI: Remove MRRS modification from MPS setting code.
- patches.kernel.org/pci-set-pci-e-max-payload-size-on-fabric.patch:
  PCI: Set PCI-E Max Payload Size on fabric.
* Mon Sep 19 2011 jeffm@suse.com
- Update config files: Enabled PNFS support (FATE#310250).
* Mon Sep 19 2011 jeffm@suse.com
- patches.drivers/tg3-add-5719-and-5720-to-eee_cap-list: tg3:
  Add 5719 and 5720 to EEE_CAP list (bnc#709075).
- patches.drivers/tg3-add-function-status-reporting: tg3: Add
  function status reporting (bnc#709075).
- patches.drivers/tg3-add-partial-fragment-unmapping-code: tg3:
  Add partial fragment unmapping code (bnc#709075).
- patches.drivers/tg3-add-tx-bd-budgeting-code: tg3: Add tx BD
  budgeting code (bnc#709075).
- patches.drivers/tg3-break-larger-frags-into-4k-chunks-for-5719:
  tg3: Break larger frags into 4k chunks for 5719 (bnc#709075).
- patches.drivers/tg3-check-transitions-to-d0-power-state: tg3:
  Check transitions to D0 power state (bnc#709075).
- patches.drivers/tg3-consolidate-code-that-calls-tg3_tx_set_bd:
  tg3: Consolidate code that calls tg3_tx_set_bd() (bnc#709075).
- patches.drivers/tg3-create-critical-section-around-gpio-toggling:
  tg3: Create critical section around GPIO toggling (bnc#709075).
- patches.drivers/tg3-detect-ape-enabled-devs-earlier: tg3:
  Detect APE enabled devs earlier (bnc#709075).
- patches.drivers/tg3-determine-pci-function-number-in-one-place:
  tg3: Determine PCI function number in one place (bnc#709075).
- patches.drivers/tg3-fix-int-selftest-for-recent-devices: tg3:
  Fix int selftest for recent devices (bnc#709075).
- patches.drivers/tg3-fix-link-down-notify-failure-when-eee-disabled:
  tg3: Fix link down notify failure when EEE disabled
  (bnc#709075).
- patches.drivers/tg3-fix-link-flap-at-100mbps-with-eee-enabled:
  tg3: Fix link flap at 100Mbps with EEE enabled (bnc#709075).
- patches.drivers/tg3-fix-nvram-selftest-failures-for-5720-devs:
  tg3: Fix NVRAM selftest failures for 5720 devs (bnc#709075).
- patches.drivers/tg3-fix-race-in-transmit-time-stamping: tg3:
  fix race in transmit time stamping (bnc#709075).
- patches.drivers/tg3-fix-rss-indirection-table-distribution:
  tg3: Fix RSS indirection table distribution (bnc#709075).
- patches.drivers/tg3-generalize-tg3_skb_error_unmap: tg3:
  Generalize tg3_skb_error_unmap() (bnc#709075).
- patches.drivers/tg3-match-power-source-to-driver-state: tg3:
  Match power source to driver state (bnc#709075).
- patches.drivers/tg3-move-power-state-transitions-to-init_one:
  tg3: Move power state transitions to init_one (bnc#709075).
- patches.drivers/tg3-reintroduce-tg3_tx_ring_info: tg3:
  Reintroduce tg3_tx_ring_info (bnc#709075).
- patches.drivers/tg3-remove-5719-jumbo-frames-and-tso-blocks:
  tg3: Remove 5719 jumbo frames and TSO blocks (bnc#709075).
- patches.drivers/tg3-remove-short-dma-check-for-1st-fragment:
  tg3: Remove short DMA check for 1st fragment (bnc#709075).
- patches.drivers/tg3-remove-unnecessary-read-of-pci_cap_id_exp:
  tg3: remove unnecessary read of PCI_CAP_ID_EXP.
- patches.drivers/tg3-return-size-from-tg3_vpd_readblock: tg3:
  Return size from tg3_vpd_readblock() (bnc#709075).
- patches.drivers/tg3-simplify-tx-bd-assignments: tg3: Simplify
  tx bd assignments (bnc#709075).
- patches.drivers/tg3-workaround-tagged-status-update-bug: tg3:
  Workaround tagged status update bug (bnc#697783, FATE#311457).
- patches.drivers/0183-tg3-Workaround-tagged-status-update-bug.patch:
  Delete.
* Mon Sep 19 2011 jeffm@suse.com
- patches.drivers/bnx2x-add-autogreeen-support: bnx2x: Add
  autogrEEEn support (bnc#709064).
- patches.drivers/bnx2x-add-cl37-bam-for-warpcore: bnx2x: Add
  CL37 BAM for Warpcore (bnc#709064).
- patches.drivers/bnx2x-add-dcbnl-notification: bnx2x: Add dcbnl
  notification (bnc#709064).
- patches.drivers/bnx2x-add-missing-command-in-error-handling-flow:
  bnx2x: add missing command in error handling flow (bnc#709064).
- patches.drivers/bnx2x-change-bcm54616s-to-bcm54618se: bnx2x:
  Change BCM54616S to BCM54618SE (bnc#709064).
- patches.drivers/bnx2x-clear-mdio-access-warning-during-first-driver-load:
  bnx2x: Clear MDIO access warning during first driver load
  (bnc#709064).
- patches.drivers/bnx2x-count-statistic-ramrods-on-eq-to-prevent-mc-assert:
  bnx2x: count statistic ramrods on EQ to prevent MC assert
  (bnc#709064).
- patches.drivers/bnx2x-dcb-rework: bnx2x: DCB rework
  (bnc#709064).
- patches.drivers/bnx2x-dcb-send-all-unmapped-priorities-to-same-cos-as-l2:
  bnx2x: dcb - send all unmapped priorities to same COS as L2
  (bnc#709064).
- patches.drivers/bnx2x-decrease-print-level-to-debug: bnx2x:
  decrease print level to debug (bnc#709064).
- patches.drivers/bnx2x-disable-dcb-on-578xx-since-not-supported-yet:
  bnx2x: disable dcb on 578xx since not supported yet
  (bnc#709064).
- patches.drivers/bnx2x-disable-fcoe-for-578xx-devices-since-not-yet-supported:
  bnx2x: disable FCoE for 578xx devices since not yet supported
  (bnc#709064).
- patches.drivers/bnx2x-disable-loacal-bh-when-scheduling-fcoe-napi:
  bnx2x: disable loacal BH when scheduling FCOE napi (bnc#709064).
- patches.drivers/bnx2x-don-t-access-removed-registers-on-57712-and-above:
  bnx2x: don't access removed registers on 57712 and above
  (bnc#709064).
- patches.drivers/bnx2x-don-t-reset-device-while-reading-its-configuration:
  bnx2x: don't reset device while reading its configuration
  (bnc#709064).
- patches.drivers/bnx2x-enable-fec-for-57810-kr: bnx2x: Enable
  FEC for 57810-KR (bnc#709064).
- patches.drivers/bnx2x-enable-internal-target-read-for-57712-and-up-only:
  bnx2x: enable internal target-read for 57712 and up only
  (bnc#709064).
- patches.drivers/bnx2x-fix-578xx-link-led: bnx2x: Fix 578xx
  link LED (bnc#709064).
- patches.drivers/bnx2x-fix-bcm54618se-invalid-link-indication:
  bnx2x: Fix BCM54618se invalid link indication (bnc#709064).
- patches.drivers/bnx2x-fix-bcm578xx-b0-mdio-access: bnx2x:
  Fix BCM578xx-B0 MDIO access (bnc#709064).
- patches.drivers/bnx2x-fix-bcm578xx-mac-test: bnx2x: Fix BCM578xx
  MAC test (bnc#709064).
- patches.drivers/bnx2x-fix-bcm84833-initialization: bnx2x:
  Fix BCM84833 initialization (bnc#709064).
- patches.drivers/bnx2x-fix-bcm84833-link: bnx2x: Fix BCM84833
  link (bnc#709064).
- patches.drivers/bnx2x-fix-bnx2x_stop_on_error-flow-in-bnx2x_sp_rtnl_task:
  bnx2x: fix bnx2x_stop_on_error flow in bnx2x_sp_rtnl_task
  (bnc#709064).
- patches.drivers/bnx2x-fix-brb-thresholds-for-dropless_fc-mode:
  bnx2x: fix BRB thresholds for dropless_fc mode (bnc#709064).
- patches.drivers/bnx2x-fix-chip-hanging-due-to-tx-pipe-stall:
  bnx2x: Fix chip hanging due to TX pipe stall (bnc#709064).
- patches.drivers/bnx2x-fix-compilation-when-cnic-is-not-selected-in-config:
  bnx2x: Fix compilation when CNIC is not selected in config
  (bnc#709064).
- patches.drivers/bnx2x-fix-ethtool-advertisement: bnx2x: Fix
  ethtool advertisement (bnc#709064).
- patches.drivers/bnx2x-fix-ets-bandwidth: bnx2x: Fix ETS
  bandwidth (bnc#709064).
- patches.drivers/bnx2x-fix-false-link-indication-at-link-partner-when-dac-is-used:
  bnx2x: Fix false link indication at link partner when DAC is
  used (bnc#709064).
- patches.drivers/bnx2x-fix-for-a-host-coalescing-bug-which-impared-latency:
  bnx2x: Fix for a host coalescing bug which impared latency
  (bnc#709064).
- patches.drivers/bnx2x-fix-led-behavior: bnx2x: Fix LED behavior
  (bnc#709064).
- patches.drivers/bnx2x-fix-link-issue-with-dac-over-578xx:
  bnx2x: Fix link issue with DAC over 578xx (bnc#709064).
- patches.drivers/bnx2x-fix-loopback-for-non-10g-link: bnx2x:
  fix loopback for non 10G link (bnc#709064).
- patches.drivers/bnx2x-fix-mb-index-for-4-port-devices: bnx2x:
  fix MB index for 4-port devices (bnc#709064).
- patches.drivers/bnx2x-fix-memory-barriers: bnx2x: fix memory
  barriers (bnc#709064).
- patches.drivers/bnx2x-fix-mf-for-4-port-devices: bnx2x: fix
  MF for 4-port devices (bnc#709064).
- patches.drivers/bnx2x-fix-missing-pause-on-for-578xx: bnx2x:
  Fix missing pause on for 578xx (bnc#709064).
- patches.drivers/bnx2x-fix-remote-fault-handling: bnx2x: Fix
  remote fault handling (bnc#709064).
- patches.drivers/bnx2x-fix-rx-ring-size-report: bnx2x: fix rx
  ring size report (bnc#709064).
- patches.drivers/bnx2x-fix-select_queue-when-fcoe-is-disabled:
  bnx2x: fix select_queue when FCoE is disabled (bnc#709064).
- patches.drivers/bnx2x-fix-warning-message-during-57712-8727-initialization:
  bnx2x: Fix warning message during 57712/8727 initialization
  (bnc#709064).
- patches.drivers/bnx2x-fix-xmac-loopback-test: bnx2x: Fix XMAC
  loopback test (bnc#709064).
- patches.drivers/bnx2x-fixes-for-848x3-phys: bnx2x: fixes for
  848x3 phys (bnc#709064).
- patches.drivers/bnx2x-init-fcoe-fp-only-once: bnx2x: init FCOE
  FP only once (bnc#709064).
- patches.drivers/bnx2x-init-fw_seq-after-undi_unload-is-done:
  bnx2x: init fw_seq after undi_unload is done (bnc#709064).
- patches.drivers/bnx2x-pfc-fixes: bnx2x: PFC fixes (bnc#709064).
- patches.drivers/bnx2x-prevent-race-between-undi_unload-and-load-flows:
  bnx2x: prevent race between undi_unload and load flows
  (bnc#709064).
- patches.drivers/bnx2x-prevent-restarting-tx-during-bnx2x_nic_unload:
  bnx2x: Prevent restarting Tx during bnx2x_nic_unload
  (bnc#709064).
- patches.drivers/bnx2x-properly-clean-indirect-addresses: bnx2x:
  properly clean indirect addresses (bnc#709064).
- patches.drivers/bnx2x-remove-fiber-remote-fault-detection:
  bnx2x: Remove fiber remote fault detection (bnc#709064).
- patches.drivers/bnx2x-remove-unnecessary-dma_sync: bnx2x:
  remove unnecessary dma_sync (bnc#709064).
- patches.drivers/bnx2x-reset-phy-due-to-fan-failure-for-578xx:
  bnx2x: Reset PHY due to fan failure for 578xx (bnc#709064).
- patches.drivers/bnx2x-stop-tx-before-cnic_stop: bnx2x: stop
  tx before CNIC_STOP (bnc#709064).
- patches.drivers/bnx2x-use-bnx2x_q_flg_tpa_ipv6-for-tpa-queue-configuration:
  bnx2x: use BNX2X_Q_FLG_TPA_IPV6 for TPA queue configuration
  (bnc#709064).
- patches.drivers/bnx2x-use-correct-dma_sync-function: bnx2x:
  use correct dma_sync function (bnc#709064).
- patches.drivers/bnx2x-use-pci_pcie_cap: bnx2x: use
  pci_pcie_cap() (bnc#709064).
- patches.drivers/dcb-add-dcb_ieee_getapp_mask-for-drivers-to-query-app-settings:
  dcb: Add dcb_ieee_getapp_mask() for drivers to query APP
  settings.
- patches.drivers/dcb-add-dcbx-capabilities-bitmask-to-the-get_ieee-response:
  dcb: Add DCBX capabilities bitmask to the get_ieee response.
- patches.drivers/dcb-add-ieee_dcb_delapp-and-dcb-op-to-delete-app-entry:
  dcb: Add ieee_dcb_delapp() and dcb op to delete app entry.
- patches.drivers/dcb-add-ieee_dcb_setapp-to-be-used-for-ieee-802-1qaz-app-data:
  dcb: Add ieee_dcb_setapp() to be used for IEEE 802.1Qaz
  APP data.
- patches.drivers/dcb-add-missing-error-check-in-dcb_ieee_set:
  dcb: Add missing error check in dcb_ieee_set().
- patches.drivers/dcb-fix-return-type-on-dcb_setapp: dcb: fix
  return type on dcb_setapp().
- patches.drivers/dcb-use-nlmsg_free-instead-of-kfree: dcb:
  use nlmsg_free() instead of kfree().
- patches.drivers/dcbnl-add-cee-notification: dcbnl: Add CEE
  notification.
- patches.drivers/dcbnl-aggregated-cee-get-operation: dcbnl:
  Aggregated CEE GET operation.
- patches.drivers/dcbnl-unlock-on-an-error-path-in-dcbnl_cee_fill:
  dcbnl: unlock on an error path in dcbnl_cee_fill().
- patches.drivers/net-dcbnl-add-multicast-group-for-dcb: net:
  dcbnl, add multicast group for DCB.
- patches.drivers/rtnetlink-compute-and-store-minimum-ifinfo-dump-size:
  rtnetlink: Compute and store minimum ifinfo dump size.
- patches.suse/ipv6-dont-block-modules-that-depend-on-ipv6-when-blacklisted.patch:
  Refresh.
* Mon Sep 19 2011 jdelvare@suse.de
- Update config files: Drop all remaining drivers related to Intel
  Moorestown or Medfield (MID) platforms.
- supported.conf: Drop i2c-intel-mid, no longer built.
* Mon Sep 19 2011 mmarek@suse.cz
- supported.conf: Fix a typo.
* Mon Sep 19 2011 hare@suse.de
- patches.drivers/bfa-0001-Introduced-generic-address-len-pair-to-r.patch:
  bfa: Introduced generic address len pair to represent DMA
  memory chunk (FATE#311450,bnc#689227).
- patches.drivers/bfa-0002-Introduce-IOC-event-notification-mechani.patch:
  bfa: Introduce IOC event notification mechanism
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0003-Add-pbc-port-disable-check-and-fix-LPS-m.patch:
  bfa: Add pbc port disable check and fix LPS message name
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0004-Brocade-1860-Fabric-Adapter-Hardware-Ena.patch:
  bfa: Brocade-1860 Fabric Adapter Hardware Enablement
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0005-Changes-to-support-vport-disable-and-ena.patch:
  bfa: Changes to support vport disable and enable operations
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0006-IOC-and-PLL-init-changes-for-Brocade-186.patch:
  bfa: IOC and PLL init changes for Brocade-1860 Fabric Adapter
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0007-Brocade-1860-Fabric-Adapter-16Gbs-suppor.patch:
  bfa: Brocade-1860 Fabric Adapter 16Gbs support and flash
  controller fixes (FATE#311450,bnc#689227).
- patches.drivers/bfa-0008-FC-credit-recovery-and-misc-bug-fixes.patch:
  bfa: FC credit recovery and misc bug fixes
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0009-Enhancement-for-fcpim-and-IO-tag-handlin.patch:
  bfa: Enhancement for fcpim and IO tag handling
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0010-Driver-initialization-and-model-descript.patch:
  bfa: Driver initialization and model description fix
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0011-Add-BSG-interface-to-support-ELS-CT-and.patch:
  bfa: Add BSG interface to support ELS, CT and vendor commands
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0012-Update-the-driver-version-to-3.0.2.0.patch:
  bfa: Update the driver version to 3.0.2.0
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0013-Enable-ASIC-block-configuration-and-quer.patch:
  bfa: Enable ASIC block configuration and query
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0014-IOC-bug-fixes.patch: bfa: IOC bug fixes
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0015-Added-Fabric-Assigned-Address-FAA-suppo.patch:
  bfa: Added Fabric Assigned Address(FAA) support
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0016-Brocade-1860-Fabric-Adapter-PLL-init-fix.patch:
  bfa: Brocade-1860 Fabric Adapter PLL init fixes
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0017-Brocade-1860-Fabric-Adapter-vHBA-support.patch:
  bfa: Brocade-1860 Fabric Adapter vHBA support
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0018-DMA-memory-allocation-enhancement.patch:
  bfa: DMA memory allocation enhancement (FATE#311450,bnc#689227).
- patches.drivers/bfa-0019-FCS-bug-fixes.patch: bfa: FCS bug fixes
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0020-Extend-BSG-interface.patch: bfa:
  Extend BSG interface (FATE#311450,bnc#689227).
- patches.drivers/bfa-0021-Added-support-for-CEE-info-and-stats-que.patch:
  bfa: Added support for CEE info and stats query
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0022-Added-support-to-obtain-SFP-info.patch:
  bfa: Added support to obtain SFP info (FATE#311450,bnc#689227).
- patches.drivers/bfa-0023-Added-support-for-flash-configuration.patch:
  bfa: Added support for flash configuration
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0024-Added-HBA-diagnostics-support.patch:
  bfa: Added HBA diagnostics support (FATE#311450,bnc#689227).
- patches.drivers/bfa-0025-Added-support-to-query-PHY.patch:
  bfa: Added support to query PHY (FATE#311450,bnc#689227).
- patches.drivers/bfa-0026-Driver-and-BSG-enhancements.patch:
  bfa: Driver and BSG enhancements (FATE#311450,bnc#689227).
- patches.drivers/bfa-0027-Update-the-driver-version-to-3.0.2.1.patch:
  bfa: Update the driver version to 3.0.2.1
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0028-Add-FC-transport-based-Asynchronous-Even.patch:
  bfa: Add FC-transport based Asynchronous Event Notification
  support (FATE#311450,bnc#689227).
- patches.drivers/bfa-0029-use-negative-error-return-values-in-all.patch:
  bfa: use negative error return values in all functions
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0030-Update-RME-interrupt-handling.patch:
  bfa: Update RME interrupt handling (FATE#311450,bnc#689227).
- patches.drivers/bfa-0031-Check-supported-speed-based-on-port-mode.patch:
  bfa: Check supported speed based on port mode
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0032-Extend-BSG-to-support-more-user-commands.patch:
  bfa: Extend BSG to support more user commands
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0033-Add-support-for-IO-profiling.patch:
  bfa: Add support for IO profiling (FATE#311450,bnc#689227).
- patches.drivers/bfa-0034-Added-support-to-collect-and-reset-fcpor.patch:
  bfa: Added support to collect and reset fcport stats
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0035-Add-support-to-configure-and-query-flash.patch:
  bfa: Add support to configure and query flash boot partition
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0036-Add-support-to-configure-trunking-on-Bro.patch:
  bfa: Add support to configure trunking on Brocade adapter ports
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0037-Added-support-to-configure-QOS-and-colle.patch:
  bfa: Added support to configure QOS and collect stats
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0038-Add-support-to-collect-reset-fabric-st.patch:
  bfa: Add support to collect / reset fabric stats
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0039-Add-support-to-store-driver-configuratio.patch:
  bfa: Add support to store driver configuration in flash
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0040-Introduced-initiator-based-lun-masking-f.patch:
  bfa: Introduced initiator based lun masking feature
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0041-Added-support-to-configure-lunmasking.patch:
  bfa: Added support to configure lunmasking
  (FATE#311450,bnc#689227).
- patches.drivers/bfa-0042-Update-the-driver-version-to-3.0.2.2.patch:
  bfa: Update the driver version to 3.0.2.2
  (FATE#311450,bnc#689227).
* Mon Sep 19 2011 hare@suse.de
- patches.fixes/scsi-dh-rdac-Adding-NetApp-as-a-brand-name-for-rdac.patch:
  scsi_dh_rdac: Adding NetApp as a brand name for rdac
  (bnc#716970).
* Mon Sep 19 2011 duwe@suse.de
- patches.arch/ppc-fix-oops-on-wrong-memory-probe: powerpc: Fix
  oops when echoing bad values to /sys/devices/system/memory/probe
  (bnc#717142).
* Mon Sep 19 2011 duwe@suse.de
- patches.suse/revert-network-error-fixes: inappropriate ioctl
  operation should return ENOTTY (bnc#717500).
* Mon Sep 19 2011 hare@suse.de
- patches.drivers/fcoe-0025-libfc-cache-align-struct-fc_fc.patch:
  libfc: cache align struct fc_fcp_pkt fields (bnc#718265).
- patches.drivers/fcoe-0026-libfc-cache-align-struct-fc_ex.patch:
  libfc: cache align struct fc_exch fields (bnc#718265).
- patches.drivers/fcoe-0027-libfc-cache-align-fc_exch_pool.patch:
  libfc: cache align fc_exch_pool (bnc#718265).
- patches.drivers/fcoe-0028-fcoe-use-real-dev-in-case-of-h.patch:
  fcoe: use real dev in case of HW vlan acceleration (bnc#718265).
* Mon Sep 19 2011 hare@suse.de
- patches.fixes/dm-mpath-never-requeue-request-on-ITL-failure.patch:
  dm mpath: never re-queue request if I_T_L nexus failure and
  no paths (bnc#717848).
- patches.fixes/scsi-Revert-put-stricter-guards-on-queue-dead-chec.patch:
  scsi: Revert 'put stricter guards on queue dead checks'
  (bnc#717848).
- patches.fixes/scsi-don-t-use-execute_in_process_context.patch:
  scsi: don't use execute_in_process_context() (bnc#717848).
* Sun Sep 18 2011 jslaby@suse.de
- patches.fixes/mqueue-fix-mq_open-return-value.patch:
  ipc/mqueue.c: fix mq_open() return value (bnc#691714).
- patches.fixes/mqueue-refactor-failure-handling.patch:
  ipc/mqueue.c: refactor failure handling (bnc#691714).
* Sun Sep 18 2011 jslaby@suse.de
- supported.conf: remove deleted generic_serial based modules.
  They were broken anyway. See commit 412145947a upstream.
* Sat Sep 17 2011 jjolly@suse.de
- patches.drivers/core_0120_XRC_base_implementation.patch:
  IB/core: Implement XRC support at verbs layer (for case in
  which fd is not used when opening an xrc_domain) (bnc#706587).
- patches.drivers/core_0130_XRC_file_descriptors.patch: ib/core:
  Add XRC support for userspace file descriptors (bnc#706587).
- patches.drivers/core_0140_XRC_QP_kernel_app.patch: IB/core:
  implement kernel-space XRC (bnc#706587).
- patches.drivers/core_0150_xrc_rcv.patch: IB/core: Implement
  XRC receive-only QPs for userspace apps (bnc#706587).
- patches.drivers/core_0160_xrc_fix_memleak.patch: IB/core:
  fix memory leak in XRC userspace cleanup (bnc#706587).
- patches.drivers/mlx4_0450_xrc_base_implementation.patch:
  IB/mlx4: Implements XRC support (bnc#706587).
- patches.drivers/mlx4_0460_xrc_kernel.patch: IB/mlx4: Implement
  kernel-space XRC (bnc#706587).
- patches.drivers/mlx4_0470_xrc_rcv.patch: IB/mlx4: Implement
  XRC receive-only QP support (bnc#706587).
- patches.drivers/mlx4_1470_xrc_qp_lookup_lock.patch: IB/mlx4_ib:
  XRC locking fixes, and prevention of null dereference
  (bnc#706587).
- patches.drivers/mlx4_1480_xrc_rcv_spinlock.patch: IB/mlx4_ib:
  Add spinlock to xrc_reg_list changes and scanning in interrupt
  context (bnc#706587).
- patches.drivers/mlx4_x_0150_Fix_mlx4_ib_reg_xrc_rcv_qp_locking.patch:
  IB/mlx4_ib XRC RCV: Fix mlx4_ib_reg_xrc_rcv_qp() locking
  (bnc#706587).
* Sat Sep 17 2011 jslaby@suse.de
- supported.conf: remove ricoh_mmc, the code is now as a PCI quirk.
* Fri Sep 16 2011 trenn@suse.de
- Update config files:
  CONFIG_ACPI_APEI_ERST_DEBUG=m
  [#] CONFIG_ACPI_APEI_MEMORY_FAILURE is not set
  CONFIG_LLIST=y
  for all i386/x86_64 flavors. The latter 2 are newly
  introduced.
- patches.drivers/acpi_apei_disable_suse.patch: Refresh.
- patches.drivers/apei_lockless_list.patch: lib, Add lock-less
  NULL terminated single list (bnc#697859).
- patches.drivers/apei_make_gen_pool_memory_allocator_lockless.patch:
  lib, Make gen_pool memory allocator lockless (bnc#697859).
- patches.drivers/apei_memory_failure_queue.patch: HWPoison:
  add memory_failure_queue() (bnc#697859).
- patches.drivers/apei_pstore_mainline_000.patch: ACPI, APEI,
  Add APEI bit support in generic _OSC call (bnc#697859).
- patches.drivers/apei_pstore_mainline_001.patch: ACPI, APEI,
  Add APEI bit support in generic _OSC call (bnc#697859).
- patches.drivers/apei_pstore_mainline_002.patch: ACPI, APEI,
  ERST, Prevent erst_dbg from loading if ERST is disabled
  (bnc#697859).
- patches.drivers/apei_pstore_mainline_003.patch: ACPI, APEI,
  ERST, Fix erst-dbg long record reading issue (bnc#697859).
- patches.drivers/apei_pstore_mainline_004.patch: ACPI, APEI,
  GHES, Do not ratelimit fatal error printk before panic
  (bnc#697859).
- patches.drivers/apei_pstore_mainline_005.patch: ACPI, APEI,
  Add apei_exec_run_optional (bnc#697859).
- patches.drivers/apei_pstore_mainline_006.patch: ACPI, APEI,
  Use apei_exec_run_optional in APEI EINJ and ERST (bnc#697859).
- patches.drivers/apei_pstore_mainline_007.patch: ACPI, APEI,
  GHES, Prevent GHES to be built as module (bnc#697859).
- patches.drivers/apei_pstore_mainline_008.patch: ACPI, APEI,
  GHES, Support disable GHES at boot time (bnc#697859).
- patches.drivers/apei_pstore_mainline_009.patch: ACPI, APEI,
  Add WHEA _OSC support (bnc#697859).
- patches.drivers/apei_pstore_mainline_010.patch: pstore: Extend
  API for more flexibility in new backends (bnc#697859).
- patches.drivers/apei_pstore_mainline_011.patch: pstore: Add
  extra context for writes and erases (bnc#697859).
- patches.drivers/apei_pstore_mainline_012.patch: pstore: Make
  "part" unsigned (bnc#697859).
- patches.drivers/apei_pstore_mainline_013.patch: pstore: Allow
  the user to explicitly choose a backend (bnc#697859).
- patches.drivers/apei_pstore_mainline_014.patch: ACPI, APEI,
  GHES, printk support for recoverable error via NMI (bnc#697859).
- patches.drivers/apei_pstore_mainline_015.patch: ACPI, APEI,
  GHES, Error records content based throttle (bnc#697859).
- patches.drivers/apei_pstore_mainline_016.patch: ACPI, APEI,
  GHES: Add hardware memory error recovery support (bnc#697859).
- patches.drivers/apei_pstore_mainline_017.patch: ACPI: APEI
  build fix (bnc#697859).
- patches.drivers/apei_pstore_mainline_018.patch: APEI GHES:
  32-bit buildfix (bnc#697859).
- patches.drivers/apei_pstore_mainline_019.patch: ACPI, APEI,
  EINJ Param support is disabled by default (bnc#697859).
- patches.drivers/apei_pstore_mainline_020.patch: APEI: Fix WHEA
  _OSC call (bnc#697859).
- patches.drivers/apei_pstore_mainline_021.patch: ACPI APEI:
  Add Kconfig option IRQ_WORK for GHES (bnc#697859).
* Fri Sep 16 2011 mfasheh@suse.com
- patches.suse/btrfs-0010-go-readonly-on-insert-error-in-btrfs_add_root_.patch:
  Refresh.
- patches.suse/btrfs-0014-Document-BUG-in-find_lock_delalloc_range.patch:
  Refresh.
- patches.suse/btrfs-0020-Remove-BUG_ON-from-__finish_chunk_alloc.patch:
  Refresh.
* Fri Sep 16 2011 mfasheh@suse.com
- patches.suse/btrfs-0001-Don-t-BUG_ON-errors-from-btrfs_create_subvol_r.patch:
  btrfs: Don't BUG_ON errors from btrfs_create_subvol_root().
- patches.suse/btrfs-0002-Don-t-BUG_ON-errors-in-update_ref_for_cow.patch:
  btrfs: Don't BUG_ON() errors in update_ref_for_cow().
- patches.suse/btrfs-0003-Don-t-BUG_ON-kzalloc-error-in-btrfs_lookup_csu.patch:
  btrfs: Don't BUG_ON kzalloc error in btrfs_lookup_csums_range().
- patches.suse/btrfs-0004-make-insert_ptr-void.patch: btrfs:
  make insert_ptr() void.
- patches.suse/btrfs-0005-Don-t-BUG_ON-errors-in-__finish_chunk_alloc.patch:
  btrfs: Don't BUG_ON errors in __finish_chunk_alloc().
- patches.suse/btrfs-0006-fix-error-check-of-btrfs_lookup_dentry.patch:
  btrfs: fix error check of btrfs_lookup_dentry().
- patches.suse/btrfs-0007-make-fixup_low_keys-void.patch: btrfs:
  make fixup_low_keys() void.
- patches.suse/btrfs-0008-make-del_ptr-and-btrfs_del_leaf-void.patch:
  btrfs: make del_ptr() and btrfs_del_leaf() void.
- patches.suse/btrfs-0009-Don-t-BUG_ON-failures-in-find_and_setup_root.patch:
  btrfs: Don't BUG_ON failures in find_and_setup_root().
- patches.suse/btrfs-0010-go-readonly-on-insert-error-in-btrfs_add_root_.patch:
  btrfs: go readonly on insert error in btrfs_add_root_ref().
- patches.suse/btrfs-0011-Go-readonly-on-bad-extent-refs-in-update_ref_f.patch:
  btrfs: Go readonly on bad extent refs in update_ref_for_cow().
- patches.suse/btrfs-0012-Don-t-BUG_ON-errors-from-update_ref_for_cow.patch:
  btrfs: Don't BUG_ON errors from update_ref_for_cow().
- patches.suse/btrfs-0013-Go-readonly-on-tree-errors-in-balance_level.patch:
  btrfs: Go readonly on tree errors in balance_level.
- patches.suse/btrfs-0014-Document-BUG-in-find_lock_delalloc_range.patch:
  btrfs: Document BUG() in find_lock_delalloc_range().
- patches.suse/btrfs-0015-Go-readonly-on-missing-ref-in-btrfs_get_parent.patch:
  btrfs: Go readonly on missing ref in btrfs_get_parent().
- patches.suse/btrfs-0016-make-add_delayed_ref_head-void.patch:
  btrfs: make add_delayed_ref_head() void.
- patches.suse/btrfs-0017-make-add_delayed_tree_ref-void.patch:
  btrfs: make add_delayed_tree_ref() void.
- patches.suse/btrfs-0018-Don-t-BUG_ON-insert-errors-in-btrfs_alloc_dev_.patch:
  btrfs: Don't BUG_ON insert errors in btrfs_alloc_dev_extent().
- patches.suse/btrfs-0019-Remove-BUG_ON-from-__btrfs_alloc_chunk.patch:
  btrfs: Remove BUG_ON from __btrfs_alloc_chunk().
- patches.suse/btrfs-0020-Remove-BUG_ON-from-__finish_chunk_alloc.patch:
  btrfs: Remove BUG_ON from __finish_chunk_alloc().
* Fri Sep 16 2011 duwe@suse.de
- patches.suse/zcrypt-feed-hwrandom:
  With a machine to test on, I could now replace my previous
  guesswork with a working version. (bnc#709266, bnc#709269)
* Fri Sep 16 2011 gregkh@suse.de
- Import future 3.0.5 kernel.org release:
- patches.kernel.org/8250-fix-race-condition-in-serial8250_backup_timeout.patch:
  8250: Fix race condition in serial8250_backup_timeout().
- patches.kernel.org/8250_pci-add-support-for-rosewill-rc-305-4x-serial-port.patch:
  8250_pci: add support for Rosewill RC-305 4x serial port card.
- patches.kernel.org/9p-close-acl-leaks.patch: 9p: close ACL
  leaks.
- patches.kernel.org/acpica-do-not-repair-_tss-return-package-if-_pss-is-present.patch:
  ACPICA: Do not repair _TSS return package if _PSS is present.
- patches.kernel.org/alarmtimers-avoid-possible-denial-of-service-with-high-freq-periodic-timers.patch:
  alarmtimers: Avoid possible denial of service with high freq
  periodic timers.
- patches.kernel.org/alarmtimers-avoid-possible-null-pointer-traversal.patch:
  alarmtimers: Avoid possible null pointer traversal.
- patches.kernel.org/alarmtimers-memset-itimerspec-passed-into-alarm_timer_get.patch:
  alarmtimers: Memset itimerspec passed into alarm_timer_get.
- patches.kernel.org/arch-powerpc-sysdev-fsl_rio.c-correct-iecsr-register-clear.patch:
  arch/powerpc/sysdev/fsl_rio.c: correct IECSR register clear
  value.
- patches.kernel.org/arm-7014-1-cache-l2x0-fix-l2-cache-size-calculation.patch:
  ARM: 7014/1: cache-l2x0: Fix L2 Cache size calculation.
- patches.kernel.org/arm-7081-1-mach-integrator-fix-the-clocksource.patch:
  ARM: 7081/1: mach-integrator: fix the clocksource.
- patches.kernel.org/arm-davinci-da850-evm-read-mac-address-from-spi-flash.patch:
  ARM: davinci: da850 EVM: read mac address from SPI flash.
- patches.kernel.org/arm-davinci-fix-cache-flush-build-error.patch:
  ARM: davinci: fix cache flush build error.
- patches.kernel.org/asoc-ad193x-fix-dac-word-len-setting.patch:
  ASoC: ad193x: fix dac word len setting.
- patches.kernel.org/asoc-ad193x-fix-registers-definition.patch:
  ASoC: ad193x: fix registers definition.
- patches.kernel.org/asoc-soc-jack-fix-checking-return-value-of-request_any_context_irq.patch:
  ASoC: soc-jack: Fix checking return value of
  request_any_context_irq.
- patches.kernel.org/ath9k-fix-ps-wrappers-in-ath9k_set_coverage_class.patch:
  ath9k: Fix PS wrappers in ath9k_set_coverage_class.
- patches.kernel.org/ath9k_hw-fix-sta-ar9485-bringup-issue-due-to-incorrect-mac-address.patch:
  ath9k_hw: Fix STA (AR9485) bringup issue due to incorrect
  MAC address.
- patches.kernel.org/atm-br2684-fix-oops-due-to-skb-dev-being-null.patch:
  atm: br2684: Fix oops due to skb->dev being NULL.
- patches.kernel.org/avoid-dereferencing-a-request_queue-after-last-close.patch:
  Avoid dereferencing a 'request_queue' after last close.
- patches.kernel.org/carl9170-fix-mismatch-in-carl9170_op_set_key-mutex.patch:
  carl9170: Fix mismatch in carl9170_op_set_key mutex lock-unlock.
- patches.kernel.org/drm-nouveau-properly-handle-allocation-failure-in-nouveau_sgdma_populate.patch:
  drm/nouveau: properly handle allocation failure in
  nouveau_sgdma_populate.
- patches.kernel.org/drm-radeon-kms-add-s-r-quirk-for-compaq-presario-v5245eu.patch:
  drm/radeon/kms: add s/r quirk for Compaq Presario V5245EU.
- patches.kernel.org/drm-radeon-kms-evergreen-ni-reset-spi-block-on-cp-resume.patch:
  drm/radeon/kms: evergreen & ni reset SPI block on CP resume.
- patches.kernel.org/drm-radeon-kms-make-sure-pci-max-read-request-size-is-valid-on-evergreen-v2.patch:
  drm/radeon/kms: make sure pci max read request size is valid
  on evergreen+ (v2).
- patches.kernel.org/drm-radeon-kms-set-a-default-max_pixel_clock.patch:
  drm/radeon/kms: set a default max_pixel_clock.
- patches.kernel.org/fix-the-size-of-receive-buffer-packing-onto-virtio-ring.patch:
  Fix the size of receive buffer packing onto VirtIO ring.
- patches.kernel.org/fs-9p-add-fid-before-dentry-instantiation.patch:
  fs/9p: Add fid before dentry instantiation.
- patches.kernel.org/fs-9p-always-ask-new-inode-in-create.patch:
  fs/9p: Always ask new inode in create.
- patches.kernel.org/fs-9p-always-ask-new-inode-in-lookup-for-cache-mode.patch:
  fs/9p: Always ask new inode in lookup for cache mode disabled.
- patches.kernel.org/fs-9p-don-t-update-file-type-when-updating-file-attributes.patch:
  fs/9p: Don't update file type when updating file attributes.
- patches.kernel.org/fs-9p-fid-is-not-valid-after-a-failed-clunk.patch:
  fs/9p: Fid is not valid after a failed clunk.
- patches.kernel.org/fs-9p-fix-invalid-mount-options-args.patch:
  fs/9p: Fix invalid mount options/args.
- patches.kernel.org/fs-9p-use-protocol-defined-value-for-lock-getlock-type-field.patch:
  fs/9p: Use protocol-defined value for lock/getlock 'type' field.
- patches.kernel.org/fs-9p-when-doing-inode-lookup-compare-qid-details-and-inode.patch:
  fs/9p: When doing inode lookup compare qid details and inode
  mode bits.
- patches.kernel.org/hwmon-max16065-fix-current-calculation.patch:
  hwmon: (max16065) Fix current calculation.
- patches.kernel.org/ibmveth-fix-leak-when-recycling-skb-and-hypervisor-returns.patch:
  ibmveth: Fix leak when recycling skb and hypervisor returns
  error.
- patches.kernel.org/igb-fix-wol-on-second-port-of-i350-device.patch:
  igb: fix WOL on second port of i350 device.
- patches.kernel.org/iommu-amd-don-t-take-domain-lock-recursivly.patch:
  iommu/amd: Don't take domain->lock recursivly.
- patches.kernel.org/iommu-amd-make-sure-iommu-need_sync-contains-correct-value.patch:
  iommu/amd: Make sure iommu->need_sync contains correct value.
- patches.kernel.org/irda-fix-smsc-ircc2-section-mismatch-warning.patch:
  irda: fix smsc-ircc2 section mismatch warning.
- patches.kernel.org/kernel-printk-do-not-turn-off-bootconsole-in-printk_late_init-if-keep_bootcon.patch:
  kernel/printk: do not turn off bootconsole in printk_late_init()
  if keep_bootcon.
- patches.kernel.org/md-fix-handling-for-devices-from-2tb-to-4tb-in-0.90.patch:
  md: Fix handling for devices from 2TB to 4TB in 0.90 metadata.
- patches.kernel.org/md-linear-avoid-corrupting-structure-while-waiting-for.patch:
  md/linear: avoid corrupting structure while waiting for rcu_free
  to complete.
- patches.kernel.org/mm-page-allocator-initialise-zlc-for-first-zone-eligible-for-zone_reclaim.patch:
  mm: page allocator: initialise ZLC for first zone eligible
  for zone_reclaim.
- patches.kernel.org/mm-page-allocator-reconsider-zones-for-allocation-after-direct-reclaim.patch:
  mm: page allocator: reconsider zones for allocation after
  direct reclaim.
- patches.kernel.org/mmc-core-prevent-aggressive-clock-gating-racing-with-ios.patch:
  mmc: core: prevent aggressive clock gating racing with ios
  updates.
- patches.kernel.org/mmc-core-use-non-reentrant-workqueue-for-clock-gating.patch:
  mmc: core: use non-reentrant workqueue for clock gating.
- patches.kernel.org/mmc-rename-mmc_host_clk_-ungate-gate-to-mmc_host_clk_-hold-release.patch:
  mmc: rename mmc_host_clk_{ungate|gate} to
  mmc_host_clk_{hold|release}.
- patches.kernel.org/mmc-sdhci-s3c-fix-mmc-card-i-o-problem.patch:
  mmc: sdhci-s3c: Fix mmc card I/O problem.
- patches.kernel.org/mxc-iomux-v3-correct-no_pad_ctrl-definition.patch:
  MXC: iomux-v3: correct NO_PAD_CTRL definition.
- patches.kernel.org/net-9p-fix-client-code-to-fail-more-gracefully-on-protocol-error.patch:
  net/9p: fix client code to fail more gracefully on protocol
  error.
- patches.kernel.org/net-9p-fix-kernel-crash-with-msize-512k.patch:
  net/9p: Fix kernel crash with msize 512K.
- patches.kernel.org/net-9p-fix-the-msize-calculation.patch:
  net/9p: Fix the msize calculation.
- patches.kernel.org/nuvoton-cir-simplify-raw-ir-sample-handling.patch:
  nuvoton-cir: simplify raw IR sample handling.
- patches.kernel.org/omap-serial-allow-ixon-and-ixoff-to-be-disabled.patch:
  omap-serial: Allow IXON and IXOFF to be disabled.
- patches.kernel.org/pata_via-disable-atapi-dma-on-averatec-3200.patch:
  pata_via: disable ATAPI DMA on AVERATEC 3200.
- patches.kernel.org/rapidio-fix-use-of-non-compatible-registers.patch:
  rapidio: fix use of non-compatible registers.
- patches.kernel.org/regulator-tps65910-add-missing-breaks-in-switch-case.patch:
  regulator: tps65910: Add missing breaks in switch/case.
- patches.kernel.org/rt2x00-do-not-drop-usb-dev-reference-counter-on-suspend.patch:
  rt2x00: do not drop usb dev reference counter on suspend.
- patches.kernel.org/rt2x00-fix-crash-in-rt2800usb_get_txwi.patch:
  rt2x00: fix crash in rt2800usb_get_txwi.
- patches.kernel.org/rt2x00-fix-crash-in-rt2800usb_write_tx_desc.patch:
  rt2x00: fix crash in rt2800usb_write_tx_desc.
- patches.kernel.org/rtc-fix-rtc-pie-frequency-limit.patch: rtc:
  Fix RTC PIE frequency limit.
- patches.kernel.org/savagedb-fix-typo-causing-regression-in-savage4-series.patch:
  savagedb: Fix typo causing regression in savage4 series video
  chip detection.
- patches.kernel.org/sched-fix-a-memory-leak-in-__sdt_free.patch:
  sched: Fix a memory leak in __sdt_free().
- patches.kernel.org/sched-move-blk_schedule_flush_plug-out-of-__schedule.patch:
  sched: Move blk_schedule_flush_plug() out of __schedule().
- patches.kernel.org/sched-separate-the-scheduler-entry-for-preemption.patch:
  sched: Separate the scheduler entry for preemption.
- patches.kernel.org/sendmmsg-sendmsg-fix-unsafe-user-pointer-access.patch:
  sendmmsg/sendmsg: fix unsafe user pointer access.
- patches.kernel.org/serial-8250_pnp-add-intermec-cv60-touchscreen-device.patch:
  serial: 8250_pnp: add Intermec CV60 touchscreen device.
- patches.kernel.org/sfi-table-irq-0xff-means-no-interrupt.patch:
  sfi: table irq 0xFF means 'no interrupt'.
- patches.kernel.org/sparc-allow-handling-signals-when-stack-is-corrupted.patch:
  sparc: Allow handling signals when stack is corrupted.
- patches.kernel.org/sparc-fix-array-bounds-error-setting-up-pcic-nmi-trap.patch:
  sparc: fix array bounds error setting up PCIC NMI trap.
- patches.kernel.org/sparc32-sun4d-change-ipi-irq-level-to-prevent-collision.patch:
  sparc32,sun4d: Change IPI IRQ level to prevent collision
  between IPI and timer interrupt.
- patches.kernel.org/sparc32-unbreak-arch_write_unlock.patch:
  sparc32: unbreak arch_write_unlock().
- patches.kernel.org/sparc64-only-panther-cheetah-chips-have-popc.patch:
  sparc64: Only Panther cheetah+ chips have POPC.
- patches.kernel.org/sparc64-remove-unnecessary-macros-from-spinlock_64.h.patch:
  sparc64: remove unnecessary macros from spinlock_64.h.
- patches.kernel.org/sparc64-set-have_c_recordmcount.patch:
  sparc64: Set HAVE_C_RECORDMCOUNT.
- patches.kernel.org/tty-add-spi-prefix-for-spi-modalias.patch:
  tty: Add "spi:" prefix for spi modalias.
- patches.kernel.org/tty-pty-fix-pty-counting.patch: TTY: pty,
  fix pty counting.
- patches.kernel.org/usb-ehci-do-not-rely-on-port_suspend-to-stop-usb-resuming-in-ehci_bus_resume.patch:
  USB: EHCI: Do not rely on PORT_SUSPEND to stop USB resuming
  in ehci_bus_resume().
- patches.kernel.org/usb-ftdi_sio-add-calao-reference-board-support.patch:
  USB: ftdi_sio: add Calao reference board support.
- patches.kernel.org/usb-musb-cppi-fix-build-errors-due-to-dbg-and-missing.patch:
  usb: musb: cppi: fix build errors due to DBG and missing
  musb variable.
- patches.kernel.org/usb-option-add-yuga-device-id-to-driver.patch:
  USB: option: add YUGA device id to driver.
- patches.kernel.org/usb-option-driver-add-pid-of-huawei-vodafone-k3806.patch:
  USB option driver add PID of Huawei Vodafone K3806.
- patches.kernel.org/usb-option-driver-add-pid-of-huawei-vodafone-k4605.patch:
  USB option driver add PID of Huawei Vodafone K4605.
- patches.kernel.org/usb-option-driver-k3765-k4505-avoid-cdc_data-interface.patch:
  USB option driver K3765/K4505 avoid CDC_DATA interface.
- patches.kernel.org/usb-s5p-ehci-fix-a-null-pointer-deference.patch:
  usb: s5p-ehci: fix a NULL pointer deference.
- patches.kernel.org/virtio-can-transfer-virtqueue_num-of-pages.patch:
  VirtIO can transfer VIRTQUEUE_NUM of pages.
- patches.kernel.org/vp7045-fix-buffer-setup.patch: vp7045:
  fix buffer setup.
- patches.kernel.org/x86-perf-check-that-current-mm-is-alive-before-getting-user-callchain.patch:
  x86, perf: Check that current->mm is alive before getting
  user callchain.
- patches.kernel.org/xen-smp-warn-user-why-they-keel-over-nosmp-or-noapic-and-what-to-use-instead.patch:
  xen/smp: Warn user why they keel over - nosmp or noapic and
  what to use instead.
- patches.kernel.org/xen-x86_32-do-not-enable-iterrupts-when-returning-from.patch:
  xen: x86_32: do not enable iterrupts when returning from
  exception in interrupt context.
- patches.kernel.org/xhci-fix-failed-enqueue-in-the-middle-of-isoch-td.patch:
  xhci: Fix failed enqueue in the middle of isoch TD.
- patches.kernel.org/xhci-fix-memory-leak-during-failed-enqueue.patch:
  xhci: Fix memory leak during failed enqueue.
- patches.kernel.org/xhci-fix-port-u3-status-check-condition.patch:
  xHCI: fix port U3 status check condition.
- patches.kernel.org/xhci-handle-zero-length-isochronous-packets.patch:
  xhci: Handle zero-length isochronous packets.
- patches.kernel.org/xhci-remove-tds-from-td-lists-when-urbs-are-canceled.patch:
  xhci: Remove TDs from TD lists when URBs are canceled.
- patches.kernel.org/xhci-report-usb2-port-in-resuming-as-suspend.patch:
  xHCI: report USB2 port in resuming as suspend.
- patches.fixes/mm-page-allocator-initialise-zlc-for-first-zone-eligible-for-zone_reclaim.patch:
  Delete.
- patches.fixes/mm-page-allocator-reconsider-zones-for-allocation-after-direct-reclaim.patch:
  Delete.
- patches.fixes/pty-fix-pty-counting.patch: Delete.
* Fri Sep 16 2011 gregkh@suse.de
- patches.kabi/kabi-add-padding-to-usb-host-structures-for-potential-security-fixes.patch:
  kabi: add padding to USB host structures for potential security
  fixes (FATE#312013).
* Fri Sep 16 2011 gregkh@suse.de
- Update config files. Disable CONFIG_OLPC as this platform is not for
  our kernel packages.
* Fri Sep 16 2011 hare@suse.de
- patches.drivers/fcoe-0001-libfc-Enhancement-to-RPORT-state-machine-app.patch:
  libfc: Enhancement to RPORT state machine applicable only for
  VN2VN mode (bnc#718265).
- patches.drivers/fcoe-0002-libfc-tcm_fc-add-ddp_targ-to-libfc-functi.patch:
  libfc, tcm_fc: add ddp_targ() to libfc function template to
  supprot FCoE DDP in target mode (bnc#718265).
- patches.drivers/fcoe-0003-fcoe-support-ndo_fcoe_ddp_target-for-DDP-i.patch:
  fcoe: support ndo_fcoe_ddp_target() for DDP in FCoE targe
  (bnc#718265).
- patches.drivers/fcoe-0004-fcoe-Unable-to-select-the-exchangeID-from-of.patch:
  fcoe: Unable to select the exchangeID from offload pool for
  storage targets (bnc#718265).
- patches.drivers/fcoe-0005-fcoe-Round-robin-based-selection-of-CPU-for.patch:
  fcoe: Round-robin based selection of CPU for post-processing
  of incoming commands (bnc#718265).
- patches.drivers/fcoe-0006-fcoe-Amends-previous-patch-Round-robin-base.patch:
  fcoe: Amends previous patch, Round-robin based selection of
  CPU for post processing of incoming request for FCoE target
  (bnc#718265).
- patches.drivers/fcoe-0007-libfc-Fix-for-exchange-seq-loopup-failure-whe.patch:
  libfc:Fix for exchange/seq loopup failure when FCoE stack is
  used as target and connected to windows initaitor (bnc#718265).
- patches.drivers/fcoe-0008-libfc-post-reset-event-on-lport-reset.patch:
  libfc: post reset event on lport reset (bnc#718265).
- patches.drivers/fcoe-0009-fcoe-Rearrange-fcoe-port-and-NPIV-port-clean.patch:
  fcoe: Rearrange fcoe port and NPIV port cleanup (bnc#718265).
- patches.drivers/fcoe-0010-scsi-rcu-Convert-call_rcu-fc_rport_free_rcu-to-kfr.patch:
  scsi,rcu: Convert call_rcu(fc_rport_free_rcu) to kfree_rcu()
  (bnc#718265).
- patches.drivers/fcoe-0011-fcoe-remove-unused-ptype-field-in-fcoe_rcv_i.patch:
  fcoe: remove unused ptype field in fcoe_rcv_info (bnc#718265).
- patches.drivers/fcoe-0012-libfc-use-FC_MAX_ERROR_CNT.patch:
  libfc: use FC_MAX_ERROR_CNT (bnc#718265).
- patches.drivers/fcoe-0013-libfc-release-exchg-cache.patch:
  libfc: release exchg cache (bnc#718265).
- patches.drivers/fcoe-0014-libfc-fcoe-ignore-rx-frame-with-wrong-xid-i.patch:
  libfc, fcoe: ignore rx frame with wrong xid info (bnc#718265).
- patches.drivers/fcoe-0015-libfc-two-minor-changes-in-comments.patch:
  libfc: two minor changes in comments (bnc#718265).
- patches.drivers/fcoe-0016-libfc-cleanup-sending-SRR-request.patch:
  libfc: cleanup sending SRR request (bnc#718265).
- patches.drivers/fcoe-0017-libfc-Remove-the-reference-to-FCP-packet-fro.patch:
  libfc: Remove the reference to FCP packet from scsi_cmnd in
  case of error (bnc#718265).
- patches.drivers/fcoe-0018-libfc-fix-warn-on-in-lport-retry.patch:
  libfc: fix warn on in lport retry (bnc#718265).
- patches.drivers/fcoe-0019-fcoe-add-fip-retry-to-avoid-missing-critical.patch:
  fcoe: add fip retry to avoid missing critical keep alive
  (bnc#718265).
- patches.drivers/fcoe-0020-fcoe-cleanup-cpu-selection-for-incoming-requ.patch:
  fcoe: cleanup cpu selection for incoming requests (bnc#718265).
- patches.drivers/fcoe-0021-fcoe-Fix-deadlock-between-fip-s-recv_work-an.patch:
  fcoe: Fix deadlock between fip's recv_work and rtnl
  (bnc#718265).
- patches.drivers/fcoe-0022-libfc-fix-fc_eh_host_reset.patch:
  libfc: fix fc_eh_host_reset (bnc#718265).
- patches.drivers/fcoe-0023-libfc-block-SCSI-eh-thread-for-blocked-rport.patch:
  libfc: block SCSI eh thread for blocked rports (bnc#718265).
- patches.drivers/fcoe-0024-libfc-fix-referencing-to-fc_fcp_pkt-from-the.patch:
  libfc: fix referencing to fc_fcp_pkt from the frame pointer
  via fr_fsp() (bnc#718265).
* Fri Sep 16 2011 mmarek@suse.de
- supported.conf: Mark i2c-pxa as unsupported.
* Fri Sep 16 2011 dsterba@suse.cz
- patches.suse/btrfs-8019-fix-pages-truncation-in-clone.patch:
  Btrfs: fix pages truncation in btrfs_ioctl_clone()
  (FATE#306586).
* Fri Sep 16 2011 dsterba@suse.cz
- patches.suse/btrfs-0087-fix-an-oops-when-deleting-snapshots.patch:
  Btrfs: fix an oops when deleting snapshots (FATE#306586).
- patches.suse/btrfs-0088-fix-warning-in-iput-for-bad-inode.patch:
  btrfs: fix warning in iput for bad-inode (FATE#306586).
- patches.suse/btrfs-0089-skip-locking-if-searching-the-commit-root-in-c.patch:
  Btrfs: skip locking if searching the commit root in csum lookup
  (FATE#306586).
- patches.suse/btrfs-0090-reset-to-appropriate-block-rsv-after-orphan-op.patch:
  Btrfs: reset to appropriate block rsv after orphan operations
  (FATE#306586).
- patches.suse/btrfs-0091-fix-misuse-of-trans-block-rsv.patch:
  Btrfs: fix misuse of trans block rsv (FATE#306586).
- patches.suse/btrfs-0092-fix-unclosed-transaction-handle-in-btrfs_cont_.patch:
  Btrfs: fix unclosed transaction handle in btrfs_cont_expand
  (FATE#306586).
- patches.suse/btrfs-0093-fix-the-file-extent-gap-when-doing-direct-IO.patch:
  Btrfs: fix the file extent gap when doing direct IO
  (FATE#306586).
- patches.suse/btrfs-0094-fix-wrong-nbytes-information-of-the-inode.patch:
  Btrfs: fix wrong nbytes information of the inode (FATE#306586).
- patches.suse/btrfs-0095-xattr-fix-attribute-removal.patch:
  btrfs: xattr: fix attribute removal (FATE#306586).
- patches.suse/btrfs-0096-calc-file-extent-num_bytes-correctly-in-file-c.patch:
  Btrfs: calc file extent num_bytes correctly in file clone
  (FATE#306586).
- patches.suse/btrfs-0097-add-dummy-extent-if-dst-offset-excceeds-file-e.patch:
  Btrfs: add dummy extent if dst offset excceeds file end in
  (FATE#306586).
- patches.suse/btrfs-0908-kill-the-orphan-space-calculation-for-snapshot.patch:
  Refresh.
- patches.suse/btrfs-0922-don-t-increase-the-block_rsv-s-size-when-emerg.patch:
  Btrfs: don't increase the block_rsv's size when emergency
  allocating space (FATE#306586).
- patches.suse/btrfs-0923-set-truncate-block-rsv-s-size.patch:
  Btrfs: set truncate block rsv's size (FATE#306586).
- patches.suse/btrfs-0924-put-the-block-group-cache-after-we-commit-the-.patch:
  Btrfs: put the block group cache after we commit the super
  (FATE#306586).
- patches.suse/btrfs-0925-handle-enospc-accounting-for-free-space-inodes.patch:
  Btrfs: handle enospc accounting for free space inodes
  (FATE#306586).
- patches.suse/btrfs-0926-use-the-transactions-block_rsv-for-the-csum-ro.patch:
  Btrfs: use the transactions block_rsv for the csum root
  (FATE#306586).
- patches.suse/btrfs-0927-don-t-get-the-block_rsv-in-btrfs_free_tree_blo.patch:
  Btrfs: don't get the block_rsv in btrfs_free_tree_block
  (FATE#306586).
- patches.suse/btrfs-0928-stop-passing-a-trans-handle-all-around-the-res.patch:
  Btrfs: stop passing a trans handle all around the reservation
  code (FATE#306586).
- patches.suse/btrfs-8001-kill-space_info-pointer-from-inode-structure.patch:
  Btrfs: kill space_info pointer from inode structure
  (FATE#306586).
- patches.suse/btrfs-8002-Free-inode-mutex-on-lseek-error.patch:
  BTRFS: Free inode mutex on lseek error (FATE#306586).
- patches.suse/btrfs-8003-check-file-extent-backref-offset-underflow.patch:
  btrfs: check file extent backref offset underflow (FATE#306586).
- patches.suse/btrfs-8004-fix-memory-leak-in-btrfs_defrag_file.patch:
  btrfs: fix memory leak in btrfs_defrag_file (FATE#306586).
- patches.suse/btrfs-8005-fix-defragmentation-regression.patch:
  Btrfs: fix defragmentation regression (FATE#306586).
- patches.suse/btrfs-8006-use-i_size_read-in-btrfs_defrag_file.patch:
  Btrfs: use i_size_read() in btrfs_defrag_file() (FATE#306586).
- patches.suse/btrfs-8007-fix-wrong-max_to_defrag-in-btrfs_defrag_file.patch:
  Btrfs: fix wrong max_to_defrag in btrfs_defrag_file()
  (FATE#306586).
- patches.suse/btrfs-8008-honor-extent-thresh-during-defragmentation.patch:
  Btrfs: honor extent thresh during defragmentation (FATE#306586).
- patches.suse/btrfs-8009-return-EINVAL-if-start-total_bytes-in-fitrim-i.patch:
  btrfs: return EINVAL if start > total_bytes in fitrim ioctl
  (FATE#306586).
- patches.suse/btrfs-8010-fix-array-bound-checking.patch: Btrfs:
  fix array bound checking (FATE#306586).
- patches.suse/btrfs-8011-remove-BUG_ON-in-compress_file_range.patch:
  Btrfs: remove BUG_ON() in compress_file_range() (FATE#306586).
- patches.suse/btrfs-8012-fix-direct-io-vs-nodatacow.patch:
  Btrfs: fix direct-io vs nodatacow (FATE#306586).
- patches.suse/btrfs-8013-fix-race-between-multi-task-space-allocation-a.patch:
  Btrfs: fix race between multi-task space allocation and caching
  space (FATE#306586).
- patches.suse/btrfs-8014-trivial-fix-a-potential-memory-leak-in-btrfs_p.patch:
  btrfs: trivial fix, a potential memory leak in
  btrfs_parse_early_options() (FATE#306586).
- patches.suse/btrfs-8015-don-t-change-inode-flag-of-the-dest-clone-file.patch:
  Btrfs: don't change inode flag of the dest clone file
  (FATE#306586).
- patches.suse/btrfs-8016-fix-d_off-in-the-first-dirent.patch:
  btrfs: fix d_off in the first dirent (FATE#306586).
- patches.suse/btrfs-8017-ratelimit-WARN_ON-in-use_block_rsv.patch:
  btrfs: ratelimit WARN_ON in use_block_rsv (FATE#306586).
- patches.suse/btrfs-8018-ratelimit-WARN_ON-before-iput-in-orphan-cleanu.patch:
  btrfs: ratelimit WARN_ON before iput in orphan cleanup
  (FATE#306586).
- patches.suse/btrfs-push-up-clear_extent_bit-errors-to-callers:
  Refresh.
- patches.suse/btrfs-push-up-lock_extent-errors-to-callers:
  Refresh.
- patches.suse/btrfs-push-up-unlock_extent-errors-to-callers:
  Refresh.
- scripts/sequence-patch.sh:
- patches.suse/btrfs-xattr-fix-attribute-removal.patch: Delete.
* Fri Sep 16 2011 gregkh@suse.de
- Update config files: Disable CONFIG_X86_MRST as it is not a target platform
  for our kernel packages.  This allows CONFIG_I2C to go back to being a
  module.
* Thu Sep 15 2011 trenn@suse.de
- patches.arch/x86_amd_interlagos_mem_alignment_perf_improve_1_4.patch:
  x86, amd: Avoid cache aliasing penalties on AMD family 15h
  (bnc#711285).
- patches.arch/x86_amd_interlagos_mem_alignment_perf_improve_2_4.patch:
  x86: Add a BSP cpu_dev helper (bnc#711285).
- patches.arch/x86_amd_interlagos_mem_alignment_perf_improve_3_4.patch:
  x86, amd: Move BSP code to cpu_dev helper (bnc#711285).
- patches.arch/x86_amd_interlagos_mem_alignment_perf_improve_4_4.patch:
  x86-32, amd: Move va_align definition to unbreak 32-bit build
  (bnc#711285).
* Thu Sep 15 2011 tonyj@suse.de
- Forward port perfmon 2.X (ia64) for 3.0 kernel.
- Update config files.
- patches.suse/perfmon2-remove_syscalls.patch: Refresh.
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/perfmon2_ioctl.patch: Refresh.
- patches.xen/xen3-patch-2.6.28: Refresh.
* Thu Sep 15 2011 jbohac@suse.cz
- patches.suse/l2tp_ppp-alias.patch: provide a pppol2tp module
  alias for l2tp_ppp.
- supported.conf:
  * ipt_addrtype renamed to xt_addrtype
  * pppol2tp renamed to l2tp_ppp
  * rtc_core and rtc_lib are now built into the kernel
  * xt_CONNMARK and xt_MARK merged with xt_connmark and xt_mark
* Thu Sep 15 2011 mmarek@suse.de
- rpm/kernel-binary.spec.in: Always abort build if supported modules
  depend on supported ones.
* Thu Sep 15 2011 mmarek@suse.cz
- supported.conf: Update to include new dependencies, removed
  mt9m001, mt9v022, which are only found on some SoC systems.
* Thu Sep 15 2011 hare@suse.de
- Update mpt2sas to 09.100.00.00:
  * patches.drivers/mpt2sas-Added-DID_NO_CONNECT-return-when-dri.patch:
    mpt2sas: Added DID_NO_CONNECT return when driver remove and
    avoid shutdown call (bnc#717573).
  * patches.drivers/mpt2sas-Adding-support-for-customer-specific.patch:
    mpt2sas: Adding support for customer specific branding
    (bnc#717573).
  * patches.drivers/mpt2sas-Bump-version-09.100.00.00.patch:
    mpt2sas: Bump version 09.100.00.00 (bnc#717573).
  * patches.drivers/mpt2sas-MPI-next-revision-header-update.patch:
    mpt2sas MPI next revision header update (bnc#717573).
  * patches.drivers/mpt2sas-Set-max_sector-count-from-module-par.patch:
    mpt2sas: Set max_sector count from module parameter
    (bnc#717573).
  * patches.drivers/mpt2sas-fix-broadcast-AEN-and-task-managemen.patch:
    mpt2sas: fix broadcast AEN and task management issue
    (bnc#717573).
* Thu Sep 15 2011 tiwai@suse.de
- patches.drivers/hp_accel-Add-a-new-PNP-id: hp_accel: Add a
  new PNP id (bnc#717996).
* Thu Sep 15 2011 hare@suse.de
- patches.drivers/lpfc-8.3.25-Change-driver-version-to-8.3.25.patch:
  Fixup patch header.
- patches.drivers/lpfc-8.3.5.45-update: Delete.
- patches.drivers/lpfc-8.3.5.46-update: Delete.
* Thu Sep 15 2011 hare@suse.de
- Update lpfc driver to 8.3.25 (bnc#714274):
  * patches.drivers/lpfc-8.3.25-Adapter-Interface-fixes-and-chan.patch:
    lpfc 8.3.25: Adapter Interface fixes and changes (bnc#714274).
  * patches.drivers/lpfc-8.3.25-Add-FCF-priority-failover-functi.patch:
    lpfc 8.3.25: Add FCF priority failover functionality
    (bnc#714274).
  * patches.drivers/lpfc-8.3.25-Change-driver-version-to-8.3.25.patch:
    lpfc 8.3.25: Change driver version to 8.3.25 (bnc#714274).
  * patches.drivers/lpfc-8.3.25-Enhancements-to-Debug-infrastruc.patch:
    lpfc 8.3.25: Enhancements to Debug infrastructure (bnc#714274).
  * patches.drivers/lpfc-8.3.25-Fabric-and-Target-Discovery-Fixe.patch:
    lpfc 8.3.25: Fabric and Target Discovery Fixes (bnc#714274).
  * patches.drivers/lpfc-8.3.25-Miscellaneous-Bug-fixes-and-code.patch:
    lpfc 8.3.25: Miscellaneous Bug fixes and code cleanup
    (bnc#714274).
  * patches.drivers/lpfc-8.3.25-PCI-and-SR-IOV-Fixes.patch: lpfc
    8.3.25: PCI and SR-IOV Fixes (bnc#714274).
  * patches.drivers/lpfc-8.3.25-T10-DIF-Fixes.patch: lpfc 8.3.25:
    T10 DIF Fixes (bnc#714274).
- Update lpfc driver to 8.3.26 (bnc#714274):
  * patches.drivers/lpfc-8.3.26-Change-driver-version-to-8.3.26.patch:
    lpfc 8.3.26: Change driver version to 8.3.26 (bnc#714274).
  * patches.drivers/lpfc-8.3.26-Fix-HBA-initialization-issues.patch:
    lpfc 8.3.26: Fix HBA initialization issues (bnc#714274).
  * patches.drivers/lpfc-8.3.26-Fix-SYSFS-interface-issues.patch:
    lpfc 8.3.26: Fix SYSFS interface issues (bnc#714274).
  * patches.drivers/lpfc-8.3.26-Fix-issues-pertaining-to-SCSI-FC-protoc.patch:
    lpfc 8.3.26: Fix issues pertaining to SCSI/FC protocol
    (bnc#714274).
* Thu Sep 15 2011 jjolly@suse.de
- patches.arch/s390-36-01-cio-irq-statistics.patch: cio:
  fix incorrect summation count in interrupt statistics
  (bnc#717840,LTC#74949).
- patches.arch/s390-36-02-cpuinfo-warning.patch: kernel: warning
  when accessing /proc/cpuinfo (bnc#717840,LTC#75096).
* Wed Sep 14 2011 nfbrown@suse.de
- patches.fixes/blkdev-fsync.fix: fix block device fallout from
  - >fsync() changes i.e. fix
  patches.suse/fs-push-i_mutex-and-filemap_write_and_wait-down-into.patch
  (bnc#717574).
* Wed Sep 14 2011 hare@suse.de
- Disable SR-IOV for ppc (bnc#711566)
* Tue Sep 13 2011 jslaby@suse.de
- Update config files. (bring back orinoco_pci)
* Tue Sep 13 2011 jbohac@suse.cz
- supported.conf:
  fix some network-related module dependencies (bnc#717160)
* Tue Sep 13 2011 tiwai@suse.de
- supported.conf: Update sound driver modules for 3.0;
  comment out old ieee1394 drivers
* Tue Sep 13 2011 agraf@suse.de
- Update config files (missed out on vanilla).
* Tue Sep 13 2011 agraf@suse.de
- Update config files (disable KVM for PPC due to potential
  performance degradation in non-KVM workloads)
* Mon Sep 12 2011 trenn@suse.de
- patches.drivers/cpufreq_pcc_sanity_check_acpi_processor_data.patch:
  cpufreq: pcc-cpufreq: sanity check to prevent a NULL pointer
  dereference (bnc#=709412).
* Fri Sep  9 2011 ohering@suse.de
- patches.suse/staging-hv-netvsc-module-name.patch:
- patches.suse/staging-hv-storvsc-module-name.patch:
  Use KBUILD_MODNAME
* Fri Sep  9 2011 ohering@suse.de
- patches.suse/staging-hv-netvsc-module-name.patch:
  advertise hv_netvsc instead of netvsc as sysfs driver name
- patches.suse/staging-hv-storvsc-module-name.patch:
  advertise hv_storvsc instead of storvsc as sysfs driver name
  (bnc#716708).
* Fri Sep  9 2011 ohering@suse.de
- Update vanilla config files.
* Fri Sep  9 2011 jeffm@suse.de
- patches.suse/btrfs-add-btrfs_panic: btrfs: Add btrfs_panic().
- patches.suse/btrfs-catch-locking-failures-in-set-clear-extent_bit:
  btrfs: Catch locking failures in {set,clear}_extent_bit.
- patches.suse/btrfs-disk-io-void-functions: btrfs: disk-io.c:
  Make functions with no error conditions return void.
- patches.suse/btrfs-extent_io-return-void: btrfs: extent_io.c:
  Make functions with no error conditions return void.
- patches.suse/btrfs-extent_tree-void-functions: btrfs:
  extent-tree.c: Make functions with no error conditions return
  void.
- patches.suse/btrfs-file-return-void: btrfs: file.c: Make
  functions with no error conditions return void.
- patches.suse/btrfs-make-btrfs_init_compress-return-void: btrfs:
  Make btrfs_init_compress return void.
- patches.suse/btrfs-make-btrfs_invalidate_inodes-return-void:
  btrfs: Make btrfs_invalidate_inodes return void.
- patches.suse/btrfs-make-btrfs_queue_functions-return-void:
  btrfs: async-thread.c: Make functions with no error conditions
  return void.
- patches.suse/btrfs-make-pin_down_extent-return-void: btrfs:
  Make pin_down_extent return void.
- patches.suse/btrfs-make-set_range_writeback-return-void: btrfs:
  Make set_range_writeback return void.
- patches.suse/btrfs-push-up-btrfs_pin_extent-failures: btrfs:
  Push up btrfs_pin_extent failures.
- patches.suse/btrfs-push-up-clear_extent_bit-errors-to-callers:
  btrfs: Push up clear_extent_bit errors to callers.
- patches.suse/btrfs-push-up-lock_extent-errors-to-callers:
  btrfs: Push up lock_extent errors to callers.
- patches.suse/btrfs-push-up-non-looped-btrfs_start_transaction-failures:
  btrfs: Push up non-looped btrfs_start_transaction failures.
- patches.suse/btrfs-push-up-set_extent_bit-errors-to-callers:
  btrfs: Push up set_extent_bit errors to callers.
- patches.suse/btrfs-push-up-submit_bio_hook-failures: btrfs:
  Push up ->submit_bio_hook failures.
- patches.suse/btrfs-push-up-unlock_extent-errors-to-callers:
  btrfs: Push up unlock_extent errors to callers.
- patches.suse/btrfs-return-int-from-btrfs_drop_snapshot: btrfs:
  btrfs_drop_snapshot should return int.
- patches.suse/btrfs-simplify-btrfs_submit_bio_hook: btrfs:
  simplify btrfs_submit_bio_hook.
- patches.suse/btrfs-simplify-tree-merge-hook: btrfs: Factor
  out tree->ops->merge_bio_hook call.
- patches.suse/btrfs-tree-log-void-functions: btrfs: tree-log.c:
  Make functions with no error conditions return void.
- patches.suse/btrfs-volumes-return-void: btrfs: volumes.c:
  Make functions with no error conditions return void.
* Fri Sep  9 2011 jeffm@suse.com
- patches.fixes/kvm-macos.patch: Refresh.
* Thu Sep  8 2011 jbohac@suse.cz
- patches.fixes/bonding-fix-arp_validate-inside-bridge.patch:
  Delete. Obsoleted by upstream commit 3aba891d.
* Thu Sep  8 2011 ohering@suse.de
- patches.suse/staging-hv-storvsc-scsi-proc_name.patch:
  staging/hv: fill scsi/proc_name for the sake of mkinitrd.
  (bnc#716708)
* Thu Sep  8 2011 jbeulich@novell.com
- Update Xen patches to 3.0.4 and c/s 1104.
- patches.xen/frontswap-*: Update to v8 of upstream submission.
- patches.xen/xen3-acpi_processor_delay_cpuidle_init_on_hotplug.patch:
  Delete.
* Wed Sep  7 2011 jeffm@suse.com
- patches.suse/xfs-exports-dmapi: Refresh.
- patches.fixes/xfs-export-debug: Delete.
* Wed Sep  7 2011 jack@suse.cz
- patches.suse/nfs4acl-ext3.diff: Fixed call signature of some functions.
* Tue Sep  6 2011 jeffm@suse.com
- patches.fixes/xfs-export-debug: Refresh.
* Tue Sep  6 2011 jeffm@suse.com
- Update config files: Enable DMAPI.
* Tue Sep  6 2011 jeffm@suse.com
- patches.fixes/xfs-always-use-iget-in-bulkstat-dmapi: Refresh.
- patches.fixes/xfs-dmapi-fix-crash-on-mount: xfs/dmapi: fix
  crash on mount (bnc#458027).
- patches.fixes/xfs-force-when-pinned: Refresh.
- patches.suse/nfs4acl-common.diff: Refresh.
- patches.suse/xfs-3.0-dmapi-fixes: XFS/DMAPI: Update to 3.0 API.
- patches.suse/xfs-dmapi-add-missing-unlocks-after-transaction-commit:
  xfs/dmapi: Add missing unlocks after transaction commit.
- patches.suse/xfs-dmapi-enable: Refresh.
- patches.suse/xfs-dmapi-initialize-the-function-pointer-vector-statically:
  xfs/dmapi: Initialize the function pointer vector statically.
- patches.suse/xfs-dmapi-obtain-vfsmount-for-use-in-xfs_dm_rdwr:
  xfs/dmapi: Obtain vfsmount for use in xfs_dm_rdwr.
- patches.suse/xfs-dmapi-send_correct_flags_for_preunmount_event.patch:
  Refresh.
- patches.suse/xfs-dmapi-src: Refresh.
- patches.suse/xfs-dmapi-xfs-enable: Refresh.
- patches.suse/xfs-exports-dmapi: xfs: Add exports for DMAPI.
- patches.suse/xfs-nfsd-dmapi-aware: Refresh.
- patches.suse/xfs-restore-dmapi-infrastructure: XFS: Restore
  DMAPI infrastructure.
- patches.fixes/xfs-dmapi-fixes: Delete.
* Tue Sep  6 2011 jbohac@suse.cz
- patches.suse/ipv6-dont-block-modules-that-depend-on-ipv6-when-blacklisted.patch:
  allow bonding with blacklisted ipv6 (bnc#585463).
- supported.conf:
- patches.suse/allow_bonding_with_blacklisted_ipv6.patch: Delete.
* Tue Sep  6 2011 mhocko@suse.cz
- patches.suse/pagecache-limit.patch: Refresh.
* Tue Sep  6 2011 ohering@suse.de
- supported.conf: mark hyperv drivers as externall supported
  (bnc#676890)
* Tue Sep  6 2011 mhocko@suse.cz
- patches.suse/x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
  Patch reintroduced because AV vendors are not ready to use FANOTIFY
  interface yet (this reverts 239f59c3 commit).
- patches.xen/xen3-x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
* Tue Sep  6 2011 dsterba@suse.cz
- patches.suse/btrfs-xattr-fix-attribute-removal.patch: btrfs:
  xattr: fix attribute removal (FATE#306586). Fixes xfstests/062.
* Mon Sep  5 2011 mmarek@suse.cz
- config.conf: Enable -xen kmps again.
* Mon Sep  5 2011 jdelvare@suse.de
- supported.conf: Add new hwmon drivers (almost all unsupported),
  update paths of drivers which moved from hwmon to misc or
  platform/x86.
* Mon Sep  5 2011 jdelvare@suse.de
- supported.conf: Update paths of drivers which once lived under
  drivers/i2c/chips.
* Mon Sep  5 2011 jdelvare@suse.de
- supported.conf: Add new i2c bus drivers, core i2c bus drivers,
  and i2c mux drivers, all supported.
* Mon Sep  5 2011 duwe@suse.de
- Update config files:
- ppc _still_ has no TPMs; bnc#711297 reloaded-3.0
- consistently enable suspend to RAM on all power systems.
* Mon Sep  5 2011 duwe@suse.de
- Delete now unused System Z patches:
- patches.arch/s390-04-06-dasd-move-diag-kmsg.patch: Delete.
- patches.arch/s390-10-03-dasd-fix-erp-tcw-alignment.patch:
  Delete.
- patches.arch/s390-11-01-zfcp-ccw_remove_lock_dep.patch: Delete.
- patches.arch/s390-11-02-zfcp-unit_add_lock_dep.patch: Delete.
- patches.arch/s390-11-03-zfcp_unit_remove_lock_dep.patch: Delete.
- patches.arch/s390-23-05-qeth-osxosm.patch: Delete.
- patches.arch/s390-af_iucv-over-hsi: Delete.
- patches.arch/s390-sles11sp2-kmsg.patch: Delete.
- patches.suse/s390-messages-fix: Delete.
* Mon Sep  5 2011 mhocko@suse.cz
- patches.fixes/mm-pagealloc-fix-congestion-wait.patch: Delete.
  It is no longer needed as we have upstream 0e093d99 commit.
* Mon Sep  5 2011 duwe@suse.de
- patches.arch/s390-message-catalog.diff: Refresh.
- patches.arch/s390-35-06-zfcp-kmsg-lun-limit-reached: zfcp:
  Update parameter name in LUN limit kernel message (bnc#713134).
- patches.arch/s390-35-07-af_iucv-over-hsi: Refresh.
* Mon Sep  5 2011 jack@suse.cz
- enabled CONFIG_OCFS2_DEBUG_MASKLOG to match state in SLE11 SP1.
* Mon Sep  5 2011 duwe@suse.de
- patches.arch/s390-35-01-nss-initrd:  NSS creation with initrd
  fails (bnc#713134).
- patches.arch/s390-35-02-page-referenced:  first time swap use
  results in heavy swapping (bnc#713134).
- patches.arch/s390-35-03-zfcp-dif-dix-2: zfcp: non-experimental
  support for DIF/DIX (bnc#713134).
- patches.arch/s390-35-04-zfcp-disable-auto-lun-scan: zfcp:
  disable automatic LUN scanning by default (bnc#713134).
- patches.arch/s390-35-05-qdio-busy_bit: qdio: 2nd stage retry
  on SIGA-W busy conditions (bnc#713134).
- patches.arch/s390-35-07-af_iucv-over-hsi: s390: af_iucv (new
  function): add HiperSockets transport (bnc#708636).
- Update config files.
* Mon Sep  5 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete following KMPs from SP1
  preloads: realtek-r8192ce_pci, realtek-r8192se, rt3090, rt3592
  and rt5390.
* Sat Sep  3 2011 ohering@suse.de
- rpm/kernel-binary.spec.in: Obsolete hyper-v-kmp
  The modprobe.conf rules from the package are not needed anymore
  and the drivers itself are now part of the kernel package
* Fri Sep  2 2011 jack@suse.cz
  Writeback fixes & improvements from 3.1-rc1:
- patches.fixes/mm-properly-reflect-task-dirty-limits-in-dirty_excee.patch:
  mm: properly reflect task dirty limits in dirty_exceeded logic.
- patches.fixes/writeback-don-t-busy-retry-the-inode-on-failed-grab_super_pass.patch:
  don't busy retry the inode on failed grab_super_passive().
- patches.fixes/writeback-don-t-busy-retry-writeback-on-new-freeing-.patch:
  writeback: don't busy retry writeback on new/freeing inodes.
- patches.fixes/writeback-introduce-.tagged_writepages-for-the-WB_SY.patch:
  writeback: introduce .tagged_writepages for the WB_SYNC_NONE sync stage.
- patches.fixes/writeback-skip-balance_dirty_pages-for-in-memory-fs.patch:
  writeback: skip balance_dirty_pages() for in-memory fs.
- patches.fixes/writeback-skip-tmpfs-early-in-balance_dirty_pages_ra.patch:
  writeback: skip tmpfs early in
  balance_dirty_pages_ratelimited_nr().
- patches.fixes/writeback-split-inode_wb_list_lock-into-bdi_writebac.patch:
  writeback: split inode_wb_list_lock into
  bdi_writeback.list_lock.
- patches.fixes/writeback-trace-event-writeback_single_inode.patch:
  writeback: trace event writeback_single_inode.
- patches.fixes/writeback-update-dirtied_when-for-synced-inode-to-pr.patch:
  writeback: update dirtied_when for synced inode to prevent
  livelock.
* Fri Sep  2 2011 jack@suse.cz
- patches.fixes/mm-Fix-assertion-mapping-nrpages-0-in-end_writeback.patch:
  Delete - fixed differently by commit 08142579.
* Fri Sep  2 2011 ohering@suse.de
- patches.suse/staging-hv-vmbus-modalias-show.patch:
  Staging: hv: vmbus: Show the modalias in /sys/bus/vmbus/devices/*/
  (fate#311487).
* Fri Sep  2 2011 oneukum@suse.de
- patches.fixes/Bluetooth_Periodic_Inquiry_and_mgmt_discovering_event.patch:
  Bluetooth: Periodic Inquiry and mgmt discovering event
  (bnc#714911).
* Fri Sep  2 2011 oneukum@suse.de
- Update config files for compatibilty with old
  users of vstusb even on xen, where it makes no sense,
  but the build requires it
* Fri Sep  2 2011 dsterba@suse.cz
- patches.suse/btrfs-0904-fix-how-we-mount-subvol-whatever.patch:
  fix build warning.
* Fri Sep  2 2011 oneukum@suse.de
- Update config files.
* Fri Sep  2 2011 oneukum@suse.de
- patches.suse/0001-USB-resurrect-the-vstusb-driver.patch: USB:
  resurrect the vstusb driver (Michal's list of dropped modules).
* Fri Sep  2 2011 ohering@suse.de
- patches.suse/staging-hv-bind-hv_blkkvsc-to-hv_storvsc.patch:
  bind old hv_blkvsc to hv_storvsc.
* Thu Sep  1 2011 ohering@suse.de
- patches.suse/staging-hv-vmbus-init-on-dmi-match.patch:
  Delete, at the expense of 5 seconds delay when loading hv_vmbus
  on native hardware.
* Thu Sep  1 2011 ohering@suse.de
- patches.suse/staging-hv-pata_piix-ignore-disks.patch:
  ata_piix: ignore disks in a hyper-v guest.
* Wed Aug 31 2011 gregkh@suse.de
- Update config files. CONFIG_VIDEO_GO7007=m and the sub drivers under this.
* Wed Aug 31 2011 gregkh@suse.de
- Update config files. CONFIG_USB_SL811_HCD_ISO=y
* Wed Aug 31 2011 ohering@suse.de
- patches.suse/staging-hv-vmbus-init-on-dmi-match.patch:
  add suse_no_dmi module option
* Wed Aug 31 2011 jslaby@suse.de
- patches.fixes/pty-fix-pty-counting.patch: TTY: pty, fix pty
  counting (bnc#711203).
* Tue Aug 30 2011 ohering@suse.de
- Update hv drivers
  This series removes the hv_blkvsc driver:
  hda becomes sda, sda becomes sdb!
- patches.suse/staging-hv-staging-next-20110829-0303-Staging-hv-storvsc-Inline-free_stor_device.patch:
  Staging: hv: storvsc: Inline free_stor_device().
- patches.suse/staging-hv-staging-next-20110829-0304-Staging-hv-storvsc-Do-not-aquire-an-unnecessary-r.patch:
  Staging: hv: storvsc: Do not aquire an unnecessary reference
  on stor_device.
- patches.suse/staging-hv-staging-next-20110829-0305-Staging-hv-storvsc-Rename-must_get_stor_device.patch:
  Staging: hv: storvsc: Rename must_get_stor_device().
- patches.suse/staging-hv-staging-next-20110829-0306-Staging-hv-storvsc-Rename-get_stor_device.patch:
  Staging: hv: storvsc: Rename get_stor_device().
- patches.suse/staging-hv-staging-next-20110829-0307-Staging-hv-storvsc-Cleanup-alloc_stor_device.patch:
  Staging: hv: storvsc: Cleanup alloc_stor_device().
- patches.suse/staging-hv-staging-next-20110829-0308-Staging-hv-storvsc-Introduce-state-to-manage-the.patch:
  Staging: hv: storvsc: Introduce state to manage the lifecycle
  of stor device.
- patches.suse/staging-hv-staging-next-20110829-0309-Staging-hv-storvsc-Prevent-outgoing-traffic-when.patch:
  Staging: hv: storvsc: Prevent outgoing traffic when stor dev
  is being destroyed.
- patches.suse/staging-hv-staging-next-20110829-0310-Staging-hv-storvsc-Get-rid-of-release_stor_device.patch:
  Staging: hv: storvsc: Get rid of release_stor_device() by
  inlining the code.
- patches.suse/staging-hv-staging-next-20110829-0311-Staging-hv-storvsc-Get-rid-of-final_release_stor_.patch:
  Staging: hv: storvsc: Get rid of final_release_stor_device()
  by inlining code.
- patches.suse/staging-hv-staging-next-20110829-0312-Staging-hv-storvsc-Get-rid-of-the-reference-count.patch:
  Staging: hv: storvsc: Get rid of the reference counting in
  struct storvsc_device.
- patches.suse/staging-hv-staging-next-20110829-0313-Staging-hv-netvsc-Inline-the-code-for-free_net_de.patch:
  Staging: hv: netvsc: Inline the code for free_net_device().
- patches.suse/staging-hv-staging-next-20110829-0314-Staging-hv-netvsc-Cleanup-alloc_net_device.patch:
  Staging: hv: netvsc: Cleanup alloc_net_device().
- patches.suse/staging-hv-staging-next-20110829-0315-Staging-hv-netvsc-Introduce-state-to-manage-the-l.patch:
  Staging: hv: netvsc: Introduce state to manage the lifecycle
  of net device.
- patches.suse/staging-hv-staging-next-20110829-0316-Staging-hv-netvsc-Prevent-outgoing-traffic-when-n.patch:
  Staging: hv: netvsc: Prevent outgoing traffic when netvsc dev
  is destroyed.
- patches.suse/staging-hv-staging-next-20110829-0317-Staging-hv-netvsc-Get-rid-of-release_outbound_net.patch:
  Staging: hv: netvsc: Get rid of release_outbound_net_device()
  by inlining the code.
- patches.suse/staging-hv-staging-next-20110829-0318-Staging-hv-netvsc-Get-rid-of-release_inbound_net_.patch:
  Staging: hv: netvsc: Get rid of release_inbound_net_device()
  by inlining the code.
- patches.suse/staging-hv-staging-next-20110829-0319-Staging-hv-netvsc-Get-rid-of-the-refcnt-field-in.patch:
  Staging: hv: netvsc: Get rid of the refcnt field in struct
  netvsc_device.
- patches.suse/staging-hv-staging-next-20110829-0320-Staging-hv-storvsc-Add-code-to-handle-IDE-devices.patch:
  Staging: hv: storvsc: Add code to handle IDE devices using
  the storvsc driver.
- patches.suse/staging-hv-staging-next-20110829-0321-Staging-hv-storvsc-Handle-IDE-devices-using-the-s.patch:
  Staging: hv: storvsc: Handle IDE devices using the storvsc
  driver.
- patches.suse/staging-hv-staging-next-20110829-0322-Staging-hv-blkvsc-Get-rid-of-blkvsc_drv.c-as-this.patch:
  Staging: hv: blkvsc: Get rid of blkvsc_drv.c as this code is
  not used.
- patches.suse/staging-hv-staging-next-20110829-0323-Staging-hv-storvsc-Optimize-bounce-buffer-handlin.patch:
  Staging: hv: storvsc: Optimize bounce buffer handling for the
  "write" case.
- patches.suse/staging-hv-staging-next-20110829-0324-Staging-hv-storvsc-Optimize-the-bounce-buffer-han.patch:
  Staging: hv: storvsc: Optimize the bounce buffer handling in
  the "read" case.
- patches.suse/staging-hv-staging-next-20110829-0325-Staging-hv-storvsc-Include-storvsc.c-in-storvsc_d.patch:
  Staging: hv: storvsc: Include storvsc.c in storvsc_drv.c.
- patches.suse/staging-hv-staging-next-20110829-0326-Staging-hv-storvsc-Cleanup-storvsc_drv.c-after-ad.patch:
  Staging: hv: storvsc: Cleanup storvsc_drv.c after adding the
  contents of storvsc.c.
- patches.suse/staging-hv-staging-next-20110829-0327-Staging-hv-storvsc-Add-the-contents-of-hyperv_sto.patch:
  Staging: hv: storvsc: Add the contents of hyperv_storage.h
  to storvsc_drv.c.
- patches.suse/staging-hv-staging-next-20110829-0328-Staging-hv-storvsc-Cleanup-storvsc_drv.c-after-ad.patch:
  Staging: hv: storvsc: Cleanup storvsc_drv.c after adding the
  contents of hyperv_storage.h.
- patches.suse/staging-hv-staging-next-20110829-0329-Staging-hv-storvsc-Fixup-srb-and-scsi-status-for.patch:
  Staging: hv: storvsc: Fixup srb and scsi status for INQUIRY
  and MODE_SENSE.
- patches.suse/staging-hv-staging-next-20110829-0330-Staging-hv-storvsc-Fix-a-typo.patch:
  Staging: hv: storvsc: Fix a typo.
- patches.suse/staging-hv-staging-next-20110829-0331-Staging-hv-storvsc-In-case-of-scsi-errors-offline.patch:
  Staging: hv: storvsc: In case of scsi errors offline the device.
- patches.suse/staging-hv-staging-next-20110829-0332-Staging-hv-storvsc-No-need-to-copy-from-bounce-bu.patch:
  Staging: hv: storvsc: No need to copy from bounce buffer in
  case of a failure.
- patches.suse/staging-hv-staging-next-20110829-0333-Staging-hv-util-Forcefully-shutdown-when-shutdown.patch:
  Staging: hv: util: Forcefully shutdown when shutdown is
  requested.
- patches.suse/staging-hv-staging-next-20110829-0334-Staging-hv-util-Adjust-guest-time-in-a-process-co.patch:
  Staging: hv: util: Adjust guest time in a process context.
- patches.suse/staging-hv-staging-next-20110829-0335-Staging-hv-vmbus-Check-before-invoking-the-channe.patch:
  Staging: hv: vmbus: Check before invoking the channel callback.
- patches.suse/staging-hv-staging-next-20110829-0336-Staging-hv-vmbus-Properly-deal-with-de-registerin.patch:
  Staging: hv: vmbus: Properly deal with de-registering channel
  callback.
- patches.suse/staging-hv-staging-next-20110829-0337-Staging-hv-Fix-a-bug-in-vmbus_match.patch:
  Staging: hv: Fix a bug in vmbus_match().
- patches.suse/staging-hv-staging-next-20110829-0338-Staging-hv-vmbus-Get-rid-of-vmbus_on_isr-by-inl.patch:
  Staging: hv: vmbus: Get rid of vmbus_on_isr() by inlining
  the code.
- patches.suse/staging-hv-staging-next-20110829-0339-Staging-hv-vmbus-Do-not-enable-auto-eoi.patch:
  Staging: hv: vmbus: Do not enable auto eoi.
- patches.suse/staging-hv-staging-next-20110829-0340-Staging-hv-vmbus-Fixup-indentation-in-vmbus_acpi_.patch:
  Staging: hv: vmbus: Fixup indentation in vmbus_acpi_add().
- patches.suse/staging-hv-staging-next-20110829-0341-Staging-hv-vmbus-Get-rid-of-some-dated-redundant.patch:
  Staging: hv: vmbus: Get rid of some dated/redundant comments.
- patches.suse/staging-hv-staging-next-20110829-0342-Staging-hv-vmbus-Get-rid-of-an-unnecessary-check.patch:
  Staging: hv: vmbus: Get rid of an unnecessary check in
  vmbus_connect().
- patches.suse/staging-hv-staging-next-20110829-0343-Staging-hv-vmbus-Fix-a-checkpatch-warning-in-ring.patch:
  Staging: hv: vmbus: Fix a checkpatch warning in ring_buffer.c.
- patches.suse/staging-hv-staging-next-20110829-0344-Staging-hv-vmbus-Fix-checkpatch-warnings-in-conne.patch:
  Staging: hv: vmbus: Fix checkpatch warnings in connection.c.
- patches.suse/staging-hv-staging-next-20110829-0345-Staging-hv-mousevsc-Fix-checkpatch-errors-and-war.patch:
  Staging: hv: mousevsc: Fix checkpatch errors and warnings.
- patches.suse/staging-hv-staging-next-20110829-0346-Staging-hv-netvsc-return-negative-error-codes.patch:
  Staging: hv: netvsc: return negative error codes.
- patches.suse/staging-hv-HDIO_GET_IDENTITY.patch: Delete.
- patches.suse/staging-hv-fixup-reference-counting-for-net-and-stor.patch:
  Delete.
- patches.suse/staging-hv-update-to-3.0.patch: Delete.
- patches.suse/staging-hv-vmbus-modalias-namespace.patch: Delete.
- patches.suse/staging-hv-vmbus-modalias-show.patch: Delete.
* Tue Aug 30 2011 jslaby@suse.de
- Linux 3.0.4.
- patches.fixes/x86_mtrr_fix_deadlock_condition.patch: Delete.
- patches.suse/btrfs-0073-detect-wether-a-device-supports-discard.patch:
  Delete.
- patches.suse/btrfs-0074-fix-an-oops-of-log-replay.patch: Delete.
* Mon Aug 29 2011 jack@suse.cz
- Update config files.
- patches.suse/nfs4acl-common.diff: Fixed buggy forward port.
- patches.suse/nfs4acl-ext3.diff: Refresh.
- reenabled patches.suse/nfs4acl-ext3.diff after porting it
* Mon Aug 29 2011 gregkh@suse.de
- supported.conf: add kernel/drivers/s390/net/smsgiucv_app (bnc#712420)
* Mon Aug 29 2011 gregkh@suse.de
- supported.conf: add kernel/arch/s390/crypto/ghash_s390 (bnc#714096)
* Mon Aug 29 2011 gregkh@suse.de
- patches.drivers/pci-export-pcie_bus_configure_settings-symbol.patch:
  PCI: export pcie_bus_configure_settings symbol (bnc#711519).
* Mon Aug 29 2011 gregkh@suse.de
- patches.drivers/pci-set-pci-e-max-payload-size-on-fabric.patch:
  PCI: Set PCI-E Max Payload Size on fabric (bnc#711519).
* Mon Aug 29 2011 dsterba@suse.cz
  Unmerged btrfs upstream fixes.
- patches.suse/btrfs-0901-move-stuff-around-in-btrfs_inode-to-get-better.patch:
  Btrfs: move stuff around in btrfs_inode to get better packing
  (FATE#306586).
- patches.suse/btrfs-0902-kill-reserved_bytes-in-inode.patch:
  Btrfs: kill reserved_bytes in inode (FATE#306586).
- patches.suse/btrfs-0903-use-d_obtain_alias-when-mounting-subvol-subvol.patch:
  Btrfs: use d_obtain_alias when mounting subvol/subvolid
  (FATE#306586).
- patches.suse/btrfs-0904-fix-how-we-mount-subvol-whatever.patch:
  Btrfs: fix how we mount subvol=<whatever> (FATE#306586).
- patches.suse/btrfs-0905-use-bytes_may_use-for-all-ENOSPC-reservations.patch:
  Btrfs: use bytes_may_use for all ENOSPC reservations
  (FATE#306586).
- patches.suse/btrfs-0906-skip-looking-for-delalloc-if-we-don-t-have-fil.patch:
  Btrfs: skip looking for delalloc if we don't have
  - >fill_delalloc (FATE#306586).
- patches.suse/btrfs-0907-calculate-checksum-space-correctly.patch:
  Btrfs: calculate checksum space correctly (FATE#306586).
- patches.suse/btrfs-0908-kill-the-orphan-space-calculation-for-snapshot.patch:
  Btrfs: kill the orphan space calculation for snapshots
  (FATE#306586).
- patches.suse/btrfs-0909-kill-the-durable-block-rsv-stuff.patch:
  Btrfs: kill the durable block rsv stuff (FATE#306586).
- patches.suse/btrfs-0910-fix-how-we-reserve-space-for-deleting-inodes.patch:
  Btrfs: fix how we reserve space for deleting inodes
  (FATE#306586).
- patches.suse/btrfs-0911-ratelimit-the-generation-printk-for-the-free-s.patch:
  Btrfs: ratelimit the generation printk for the free space cache
  (FATE#306586).
- patches.suse/btrfs-0912-kill-unused-parts-of-block_rsv.patch:
  Btrfs: kill unused parts of block_rsv (FATE#306586).
- patches.suse/btrfs-0913-don-t-try-to-commit-in-btrfs_block_rsv_check.patch:
  Btrfs: don't try to commit in btrfs_block_rsv_check
  (FATE#306586).
- patches.suse/btrfs-0914-optimize-how-we-account-for-space-in-truncate.patch:
  Btrfs: optimize how we account for space in truncate
  (FATE#306586).
- patches.suse/btrfs-0915-kill-btrfs_truncate_reserve_metadata.patch:
  Btrfs: kill btrfs_truncate_reserve_metadata (FATE#306586).
- patches.suse/btrfs-0916-only-reserve-space-in-fallocate-if-we-have-to-.patch:
  Btrfs: only reserve space in fallocate if we have to do a
  preallocate (FATE#306586).
- patches.suse/btrfs-0918-reduce-the-amount-of-space-needed-for-truncate.patch:
  Btrfs: reduce the amount of space needed for truncates
  (FATE#306586).
- patches.suse/btrfs-0919-allow-callers-to-specify-if-flushing-can-occur.patch:
  Btrfs: allow callers to specify if flushing can occur for
  btrfs_block_rsv_check (FATE#306586).
- patches.suse/btrfs-0920-fix-call-to-btrfs_search_slot-in-free-space-ca.patch:
  Btrfs: fix call to btrfs_search_slot in free space cache
  (FATE#306586).
- patches.suse/btrfs-0921-fix-space-leak-when-we-fail-to-make-an-allocat.patch:
  Btrfs: fix space leak when we fail to make an allocation
  (FATE#306586).
- patches.suse/fs-fix-how-we-clear-DCACHE_NEED_LOOKUP.patch:
  fs: fix how we clear DCACHE_NEED_LOOKUP (FATE#306586).
* Mon Aug 29 2011 dsterba@suse.cz
  post 3.0 btrfs updates and fixes:
- patches.suse/btrfs-0002-try-to-only-do-one-btrfs_search_slot-in-do_set.patch:
  Btrfs: try to only do one btrfs_search_slot in do_setxattr
  (FATE#306586).
- patches.suse/btrfs-0003-do-transaction-space-reservation-before-joinin.patch:
  Btrfs: do transaction space reservation before joining the
  transaction (FATE#306586).
- patches.suse/btrfs-0004-serialize-flushers-in-reserve_metadata_bytes.patch:
  Btrfs: serialize flushers in reserve_metadata_bytes
  (FATE#306586).
- patches.suse/btrfs-0005-use-the-normal-checksumming-infrastructure-for.patch:
  Btrfs: use the normal checksumming infrastructure for free
  space cache (FATE#306586).
- patches.suse/btrfs-0006-fix-how-we-merge-extent-states-and-deal-with-c.patch:
  Btrfs: fix how we merge extent states and deal with cached
  states (FATE#306586).
- patches.suse/btrfs-0007-don-t-BUG_ON-btrfs_alloc_path-errors.patch:
  btrfs: don't BUG_ON btrfs_alloc_path() errors (FATE#306586).
- patches.suse/btrfs-0008-Don-t-BUG_ON-alloc_path-errors-in-replay_one_b.patch:
  btrfs: Don't BUG_ON alloc_path errors in replay_one_buffer()
  (FATE#306586).
- patches.suse/btrfs-0009-Don-t-BUG_ON-alloc_path-errors-in-btrfs_trunca.patch:
  btrfs: Don't BUG_ON alloc_path errors in
  btrfs_truncate_inode_items (FATE#306586).
- patches.suse/btrfs-0010-Don-t-BUG_ON-alloc_path-errors-in-btrfs_read_l.patch:
  btrfs: Don't BUG_ON alloc_path errors in btrfs_read_locked_inode
  (FATE#306586).
- patches.suse/btrfs-0011-Don-t-BUG_ON-alloc_path-errors-in-btrfs_balanc.patch:
  btrfs: Don't BUG_ON alloc_path errors in btrfs_balance()
  (FATE#306586).
- patches.suse/btrfs-0019-implement-our-own-llseek.patch: Btrfs:
  implement our own ->llseek (FATE#306586).
- patches.suse/btrfs-0021-get-rid-of-useless-dget_parent-in-fs-btrfs-ioctl.c.patch:
  get rid of useless dget_parent() in fs/btrfs/ioctl.c
  (FATE#306586).
- patches.suse/btrfs-0022-get-rid-of-useless-dget_parent-in-btrfs-rename-and-l.patch:
  get rid of useless dget_parent() in btrfs rename() and link()
  (FATE#306586).
- patches.suse/btrfs-0027-Don-t-BUG_ON-alloc_path-errors-in-find_next_ch.patch:
  btrfs: Don't BUG_ON alloc_path errors in find_next_chunk
  (FATE#306586).
- patches.suse/btrfs-0028-don-t-BUG_ON-allocation-errors-in-btrfs_drop_s.patch:
  btrfs: don't BUG_ON allocation errors in btrfs_drop_snapshot
  (FATE#306586).
- patches.suse/btrfs-0029-S_ISREG-mode-is-not-mode-S_IFREG.patch:
  btrfs: S_ISREG(mode) is not mode & S_IFREG.. (FATE#306586).
- patches.suse/btrfs-0031-use-a-worker-thread-to-do-caching.patch:
  Btrfs: use a worker thread to do caching (FATE#306586).
- patches.suse/btrfs-0032-use-find_or_create_page-instead-of-grab_cache_.patch:
  Btrfs: use find_or_create_page instead of grab_cache_page
  (FATE#306586).
- patches.suse/btrfs-0033-don-t-flush-delalloc-arbitrarily.patch:
  Btrfs: don't flush delalloc arbitrarily (FATE#306586).
- patches.suse/btrfs-0034-fix-enospc-problems-with-delalloc.patch:
  Btrfs: fix enospc problems with delalloc (FATE#306586).
- patches.suse/btrfs-0035-tag-pages-for-writeback-in-sync.patch:
  Btrfs: tag pages for writeback in sync (FATE#306586).
- patches.suse/btrfs-0036-fix-BUG_ON-caused-by-ENOSPC-when-relocating-sp.patch:
  Btrfs: fix BUG_ON() caused by ENOSPC when relocating space
  (FATE#306586).
- patches.suse/btrfs-0037-stop-using-highmem-for-extent_buffers.patch:
  Btrfs: stop using highmem for extent_buffers (FATE#306586).
- patches.suse/btrfs-0038-fix-deadlock-when-throttling-transactions.patch:
  Btrfs: fix deadlock when throttling transactions (FATE#306586).
- patches.suse/btrfs-0039-switch-the-btrfs-tree-locks-to-reader-writer.patch:
  Btrfs: switch the btrfs tree locks to reader/writer
  (FATE#306586).
- patches.suse/btrfs-0040-make-a-lockdep-class-for-each-root.patch:
  Btrfs: make a lockdep class for each root (FATE#306586).
- patches.suse/btrfs-0041-remove-lockdep-magic-from-btrfs_next_leaf.patch:
  Btrfs: remove lockdep magic from btrfs_next_leaf (FATE#306586).
- patches.suse/btrfs-0042-reduce-extent_state-lock-contention-for-metada.patch:
  Btrfs: reduce extent_state lock contention for metadata
  (FATE#306586).
- patches.suse/btrfs-0043-use-the-commit_root-for-reading-free_space_ino.patch:
  Btrfs: use the commit_root for reading free_space_inode crcs
  (FATE#306586).
- patches.suse/btrfs-0044-make-sure-reserve_metadata_bytes-doesn-t-leak-.patch:
  Btrfs: make sure reserve_metadata_bytes doesn't leak out
  strange errors (FATE#306586).
- patches.suse/btrfs-0045-load-the-key-from-the-dir-item-in-readdir-into.patch:
  Btrfs: load the key from the dir item in readdir into a fake
  dentry (FATE#306586).
- patches.suse/btrfs-0048-don-t-check-the-return-value-of-__btrfs_add_in.patch:
  Btrfs:don't check the return value of __btrfs_add_inode_defrag
  (FATE#306586).
- patches.suse/btrfs-0049-return-error-to-caller-when-btrfs_unlink-faile.patch:
  Btrfs: return error to caller when btrfs_unlink() failes
  (FATE#306586).
- patches.suse/btrfs-0050-fix-readahead-in-file-defrag.patch:
  Btrfs: fix readahead in file defrag (FATE#306586).
- patches.suse/btrfs-0051-Make-extent-io-callbacks-that-never-fail-retur.patch:
  btrfs: Make extent-io callbacks that never fail return void
  (FATE#306586).
- patches.suse/btrfs-0052-Protect-the-readonly-flag-of-block-group.patch:
  Btrfs: Protect the readonly flag of block group (FATE#306586).
- patches.suse/btrfs-0053-fix-oops-while-writing-data-to-SSD-partitions.patch:
  Btrfs: fix oops while writing data to SSD partitions
  (FATE#306586).
- patches.suse/btrfs-0054-make-btrfs_set_root_node-void.patch:
  btrfs: make btrfs_set_root_node void (FATE#306586).
- patches.suse/btrfs-0055-don-t-print-the-leaf-if-we-had-an-error.patch:
  Btrfs: don't print the leaf if we had an error (FATE#306586).
- patches.suse/btrfs-0056-copy-string-correctly-in-INO_LOOKUP-ioctl.patch:
  Btrfs: copy string correctly in INO_LOOKUP ioctl (FATE#306586).
- patches.suse/btrfs-0057-check-the-nodatasum-flag-when-writing-compress.patch:
  Btrfs: check the nodatasum flag when writing compressed files
  (FATE#306586).
- patches.suse/btrfs-0058-use-wait_event.patch: Btrfs: use
  wait_event() (FATE#306586).
- patches.suse/btrfs-0059-remove-a-BUG_ON-in-btrfs_commit_transaction.patch:
  Btrfs: remove a BUG_ON() in btrfs_commit_transaction()
  (FATE#306586).
- patches.suse/btrfs-0060-remove-remaining-ref-cache-code.patch:
  Btrfs: remove remaining ref-cache code (FATE#306586).
- patches.suse/btrfs-0061-make-acl-functions-really-no-op-if-acl-is-not-.patch:
  Btrfs: make acl functions really no-op if acl is not enabled
  (FATE#306586).
- patches.suse/btrfs-0062-remove-redundant-code-for-dir-item-lookup.patch:
  Btrfs: remove redundant code for dir item lookup (FATE#306586).
- patches.suse/btrfs-0063-clean-up-search_extent_mapping.patch:
  Btrfs: clean up search_extent_mapping() (FATE#306586).
- patches.suse/btrfs-0064-clean-up-code-for-extent_map-lookup.patch:
  Btrfs: clean up code for extent_map lookup (FATE#306586).
- patches.suse/btrfs-0065-clean-up-code-for-merging-extent-maps.patch:
  Btrfs: clean up code for merging extent maps (FATE#306586).
- patches.suse/btrfs-0066-remove-unused-members-from-struct-extent_state.patch:
  Btrfs: remove unused members from struct extent_state
  (FATE#306586).
- patches.suse/btrfs-0067-clean-up-for-insert_state.patch: Btrfs:
  clean up for insert_state() (FATE#306586).
- patches.suse/btrfs-0068-clean-up-for-wait_extent_bit.patch:
  Btrfs: clean up for wait_extent_bit() (FATE#306586).
- patches.suse/btrfs-0069-clean-up-for-find_first_extent_bit.patch:
  Btrfs: clean up for find_first_extent_bit() (FATE#306586).
- patches.suse/btrfs-0070-Remove-unused-variable-last_index-in-file.c.patch:
  Btrfs: Remove unused variable 'last_index' in file.c
  (FATE#306586).
- patches.suse/btrfs-0071-don-t-call-writepages-from-within-write_full_p.patch:
  Btrfs: don't call writepages from within write_full_page
  (FATE#306586).
- patches.suse/btrfs-0072-force-unplugs-when-switching-from-high-to-regu.patch:
  Btrfs: force unplugs when switching from high to regular
  priority bios (FATE#306586).
- patches.suse/btrfs-0073-detect-wether-a-device-supports-discard.patch:
  Btrfs: detect wether a device supports discard (FATE#306586).
- patches.suse/btrfs-0074-fix-an-oops-of-log-replay.patch: Btrfs:
  fix an oops of log replay (FATE#306586).
- patches.suse/btrfs-0075-fix-a-bug-of-balance-on-full-multi-disk-partit.patch:
  Btrfs: fix a bug of balance on full multi-disk partitions
  (FATE#306586).
- patches.suse/btrfs-0076-check-if-there-is-enough-space-for-balancing-s.patch:
  Btrfs: check if there is enough space for balancing smarter
  (FATE#306586).
- patches.suse/btrfs-0077-forced-readonly-when-btrfs_drop_snapshot-fails.patch:
  Btrfs: forced readonly when btrfs_drop_snapshot() fails
  (FATE#306586).
- patches.suse/btrfs-0078-use-plain-page_address-in-header-fields-setget.patch:
  Btrfs: use plain page_address() in header fields setget
  functions (FATE#306586).
- patches.suse/btrfs-0079-memory-leak-in-btrfs_add_inode_defrag.patch:
  btrfs: memory leak in btrfs_add_inode_defrag() (FATE#306586).
- patches.suse/btrfs-0080-fix-wrong-free-space-information.patch:
  Btrfs: fix wrong free space information (FATE#306586).
- patches.suse/btrfs-0081-fix-uninitialized-sync_pending.patch:
  Btrfs: fix uninitialized sync_pending (FATE#306586).
- patches.suse/btrfs-0082-truncate-pages-from-clone-ioctl-target-range.patch:
  Btrfs: truncate pages from clone ioctl target range
  (FATE#306586).
- patches.suse/btrfs-0083-btrfs_permission-s-RO-check-shouldn-t-apply-to.patch:
  btrfs: btrfs_permission's RO check shouldn't apply to device
  nodes (FATE#306586).
- patches.suse/btrfs-0084-unlock-on-error-in-btrfs_file_llseek.patch:
  btrfs: unlock on error in btrfs_file_llseek() (FATE#306586).
- patches.suse/btrfs-0085-set-i_size-properly-when-fallocating-and-we-al.patch:
  Btrfs: set i_size properly when fallocating and we already
  (FATE#306586).
- patches.suse/btrfs-0086-fix-64-bit-divide-problem.patch: Btrfs:
  fix 64 bit divide problem (FATE#306586).
- patches.suse/fs-add-SEEK_HOLE-and-SEEK_DATA-flags.patch: fs:
  add SEEK_HOLE and SEEK_DATA flags (FATE#306586).
- patches.suse/fs-add-a-DCACHE_NEED_LOOKUP-flag-for-d_flags.patch:
  fs: add a DCACHE_NEED_LOOKUP flag for d_flags (FATE#306586).
- patches.suse/fs-add-missing-unlock-in-default_llseek.patch:
  fs: add missing unlock in default_llseek() (FATE#306586).
- patches.suse/fs-handle-SEEK_HOLE-SEEK_DATA-properly-in-all-fs-s-t.patch:
  fs: handle SEEK_HOLE/SEEK_DATA properly in all fs's that define
  their own llseek (FATE#306586).
- patches.suse/fs-push-i_mutex-and-filemap_write_and_wait-down-into.patch:
  fs: push i_mutex and filemap_write_and_wait down into ->fsync()
  handlers (FATE#306586).
* Mon Aug 29 2011 sjayaraman@suse.de
- patches.fixes/cifs-fix-possible-memory-corruption-in-CIFSFindNext.patch:
  cifs: fix possible memory corruption in CIFSFindNext
  (bnc#714001, CVE-2011-3191).
* Mon Aug 29 2011 mmarek@suse.cz
- rpm/kernel-module-subpackage: Drop the 'k' prefix from the kernel
  version (bnc#713448).
* Mon Aug 29 2011 ohering@suse.de
- patches.suse/staging-hv-staging-next-20110825-0001-Staging-hv-vmbus-Don-t-wait-indefinitely-for-IRQ.patch:
  Staging: hv: vmbus: Don't wait indefinitely for IRQ resouces.
- patches.suse/staging-hv-staging-next-20110825-0002-Staging-hv-tools-Fix-a-checkpatch-warning-in-hv_k.patch:
  Staging: hv: tools: Fix a checkpatch warning in hv_kvp_daemon.c.
- patches.suse/staging-hv-staging-next-20110825-0003-Staging-hv-vmbus-Fix-checkpatch-warnings.patch:
  Staging: hv: vmbus: Fix checkpatch warnings.
- patches.suse/staging-hv-staging-next-20110825-0004-Staging-hv-util-kvp-Fix-the-reported-OSVersion-s.patch:
  Staging: hv: util: kvp: Fix the reported OSVersion string.
- patches.suse/staging-hv-staging-next-20110825-0005-Staging-hv-util-kvp-Cleanup-kvp_get_domain_name.patch:
  Staging: hv: util: kvp: Cleanup kvp_get_domain_name().
- patches.suse/staging-hv-staging-next-20110825-0006-Staging-hv-Fix-macros-tab-errors-and-warning-in-d.patch:
  Staging: hv: Fix macros, tab errors and warning in
  drivers/staging/hv/hv_mouse.c.
- patches.suse/staging-hv-staging-next-20110825-0007-Staging-hv-vmbus-VMBUS-is-an-ACPI-enumerated-devi.patch:
  Staging: hv: vmbus: VMBUS is an ACPI enumerated device, get
  rid of the PCI signature.
- patches.suse/staging-hv-staging-next-20110825-0008-Staging-hv-Replace-struct-hv_guid-with-the-uuid-ty.patch:
  Staging: hv: Replace struct hv_guid with the uuid type already
  defined in Linux.
- patches.suse/staging-hv-staging-next-20110825-0009-Staging-hv-vmbus-Introduce-vmbus-ID-space-in-stru.patch:
  Staging: hv: vmbus: Introduce vmbus ID space in struct
  hv_driver.
- patches.suse/staging-hv-staging-next-20110825-0010-Staging-hv-blkvsc-Use-the-newly-introduced-vmbus.patch:
  Staging: hv: blkvsc: Use the newly introduced vmbus ID in the
  blockvsc driver.
- patches.suse/staging-hv-staging-next-20110825-0011-Staging-hv-storvsc-Use-the-newly-introduced-vmbus.patch:
  Staging: hv: storvsc: Use the newly introduced vmbus ID in
  storvsc driver.
- patches.suse/staging-hv-staging-next-20110825-0012-Staging-hv-netvsc-Use-the-newly-introduced-vmbus.patch:
  Staging: hv: netvsc: Use the newly introduced vmbus ID in
  netvsc driver.
- patches.suse/staging-hv-staging-next-20110825-0013-Staging-hv-mousevsc-Use-the-newly-introduced-vmbu.patch:
  Staging: hv: mousevsc: Use the newly introduced vmbus ID in
  mouse driver.
- patches.suse/staging-hv-staging-next-20110825-0014-Staging-hv-util-Make-hv_utils-a-vmbus-device-driv.patch:
  Staging: hv: util: Make hv_utils a vmbus device driver.
- patches.suse/staging-hv-staging-next-20110825-0015-Staging-hv-create-VMBUS_DEVICE-macro-and-use-it.patch:
  Staging: hv: create VMBUS_DEVICE macro and use it.
- patches.suse/staging-hv-staging-next-20110825-0016-Staging-hv-vmbus-Cleanup-vmbus_match.patch:
  Staging: hv: vmbus: Cleanup vmbus_match().
- patches.suse/staging-hv-staging-next-20110825-0017-Staging-hv-vmbus-Cleanup-vmbus_uevent-code.patch:
  Staging: hv: vmbus: Cleanup vmbus_uevent() code.
- patches.suse/staging-hv-staging-next-20110825-0018-Staging-hv-vmbus-Support-the-notion-of-id-tables.patch:
  Staging: hv: vmbus: Support the notion of id tables in
  vmbus_match().
- patches.suse/staging-hv-staging-next-20110825-0019-Staging-hv-vmbus-Get-rid-of-an-unnecessary-includ.patch:
  Staging: hv: vmbus: Get rid of an unnecessary include line
  in vmbus_drv.c.
- patches.suse/staging-hv-staging-next-20110825-0020-Staging-hv-storvsc-Get-rid-of-the-DMI-signature.patch:
  Staging: hv: storvsc: Get rid of the DMI signature.
- patches.suse/staging-hv-staging-next-20110825-0021-Staging-hv-netvsc-Get-rid-of-the-PCI-signature.patch:
  Staging: hv: netvsc: Get rid of the PCI signature.
- patches.suse/staging-hv-staging-next-20110825-0022-Staging-hv-netvsc-Get-rid-of-the-DMI-signature-in.patch:
  Staging: hv: netvsc: Get rid of the DMI signature in
  netvsc_drv.c.
- patches.suse/staging-hv-staging-next-20110825-0023-Staging-hv-util-Get-rid-of-the-DMI-signature-in-h.patch:
  Staging: hv: util: Get rid of the DMI signature in hv_util.c.
- patches.suse/staging-hv-staging-next-20110825-0024-Staging-hv-util-Get-rid-of-the-PCI-signature-in-h.patch:
  Staging: hv: util: Get rid of the PCI signature in hv_util.c.
- patches.suse/staging-hv-staging-next-20110825-0025-Staging-hv-fix-up-driver-registering-mess.patch:
  Staging: hv: fix up driver registering mess.
- patches.suse/staging-hv-staging-next-20110825-0026-Staging-hv-vmbus-Get-rid-of-some-unnecessary-comm.patch:
  Staging: hv: vmbus: Get rid of some unnecessary comments.
- patches.suse/staging-hv-staging-next-20110825-0027-Staging-hv-vmbus-Cleanup-unnecessary-comments-in.patch:
  Staging: hv: vmbus: Cleanup unnecessary comments in hv.c.
- patches.suse/staging-hv-staging-next-20110825-0028-Staging-hv-vmbus-Cleanup-error-handling-in-hv_ini.patch:
  Staging: hv: vmbus: Cleanup error handling in hv_init().
- patches.suse/staging-hv-staging-next-20110825-0029-Staging-hv-vmbus-Get-rid-of-unnecessay-comments-i.patch:
  Staging: hv: vmbus: Get rid of unnecessay comments in
  connection.c.
- patches.suse/staging-hv-staging-next-20110825-0030-Staging-hv-vmbus-Get-rid-of-the-function-dump_gpa.patch:
  Staging: hv: vmbus: Get rid of the function dump_gpadl_body().
- patches.suse/staging-hv-staging-next-20110825-0031-Staging-hv-vmbus-Get-rid-of-the-function-dump_gpa.patch:
  Staging: hv: vmbus: Get rid of the function dump_gpadl_header().
- patches.suse/staging-hv-staging-next-20110825-0032-Staging-hv-vmbus-Rename-openMsg-to-open_msg-in-ch.patch:
  Staging: hv: vmbus: Rename openMsg to open_msg in channel.c.
- patches.suse/staging-hv-staging-next-20110825-0033-Staging-hv-vmbus-Get-rid-of-unnecessary-comments.patch:
  Staging: hv: vmbus: Get rid of unnecessary comments in
  channel.c.
- patches.suse/staging-hv-staging-next-20110825-0034-Staging-hv-vmbus-Change-the-variable-name-openInf.patch:
  Staging: hv: vmbus: Change the variable name openInfo to
  open_info in channel.c.
- patches.suse/staging-hv-staging-next-20110825-0035-Staging-hv-vmbus-Cleanup-error-values-in-ringbuff.patch:
  Staging: hv: vmbus: Cleanup error values in ringbuffer.c.
- patches.suse/staging-hv-staging-next-20110825-0036-Staging-hv-vmbus-Cleanup-the-error-return-value-i.patch:
  Staging: hv: vmbus: Cleanup the error return value in
  vmbus_recvpacket_raw().
- patches.suse/staging-hv-staging-next-20110825-0037-Staging-hv-netvsc-Get-rid-of-an-unnecessary-print.patch:
  Staging: hv: netvsc: Get rid of an unnecessary print statement
  in netvsc_probe().
- patches.suse/staging-hv-staging-next-20110825-0038-Staging-hv-vmbus-Retry-vmbus_post_msg-before-gi.patch:
  Staging: hv: vmbus: Retry vmbus_post_msg() before giving up.
- patches.suse/staging-hv-staging-next-20110825-0039-Staging-hv-storvsc-Cleanup-error-handling-in-stor.patch:
  Staging: hv: storvsc: Cleanup error handling in
  storvsc_dev_add().
- patches.suse/staging-hv-staging-next-20110825-0040-Staging-hv-storvsc-Cleanup-error-handling-in-stor.patch:
  Staging: hv: storvsc: Cleanup error handling in
  storvsc_channel_init().
- patches.suse/staging-hv-staging-next-20110825-0041-Staging-hv-storvsc-Cleanup-error-handling-in-stor.patch:
  Staging: hv: storvsc: Cleanup error handling in
  storvsc_connect_to_vsp().
- patches.suse/staging-hv-staging-next-20110825-0042-Staging-hv-storvsc-Cleanup-error-handling-in-stor.patch:
  Staging: hv: storvsc: Cleanup error handling in storvsc_do_io().
- patches.suse/staging-hv-staging-next-20110825-0043-Storage-hv-storvsc-Get-rid-of-some-unnecessary-DP.patch:
  Storage: hv: storvsc: Get rid of some unnecessary DPRINTs
  from storvsc.c.
- patches.suse/staging-hv-staging-next-20110825-0044-Staging-hv-storvsc-Fix-cleanup-some-dated-comment.patch:
  Staging: hv: storvsc: Fix/cleanup some dated comments in
  storvsc.c.
- patches.suse/staging-hv-staging-next-20110825-0045-Staging-hv-storvsc-Cleanup-returned-error-code-in.patch:
  Staging: hv: storvsc: Cleanup returned error code in
  storvsc_host_reset().
- patches.suse/staging-hv-staging-next-20110825-0046-Staging-hv-storvsc-Cleanup-error-code-returned-in.patch:
  Staging: hv: storvsc: Cleanup error code returned in
  storvsc_probe().
- patches.suse/staging-hv-staging-next-20110825-0047-Staging-hv-storvsc-Cleanup-returned-error-code-in.patch:
  Staging: hv: storvsc: Cleanup returned error code in
  storvsc_drv_init().
- patches.suse/staging-hv-staging-next-20110825-0048-Staging-hv-netvsc-Cleanup-the-returned-error-code.patch:
  Staging: hv: netvsc: Cleanup the returned error code in
  netvsc_probe().
- patches.suse/staging-hv-staging-next-20110825-0049-Staging-hv-netvsc-Cleanup-error-return-codes-in-n.patch:
  Staging: hv: netvsc: Cleanup error return codes in
  netvsc_destroy_recv_buf().
- patches.suse/staging-hv-staging-next-20110825-0050-Staging-hv-netvsc-Cleanup-error-return-values-in.patch:
  Staging: hv: netvsc: Cleanup error return values in
  netvsc_init_recv_buf().
- patches.suse/staging-hv-staging-next-20110825-0051-Staging-hv-netvsc-Cleanup-error-returns-in-netvsc.patch:
  Staging: hv: netvsc: Cleanup error returns in
  netvsc_connect_vsp().
- patches.suse/staging-hv-staging-next-20110825-0052-Staging-hv-netvsc-Cleanup-error-return-values-in.patch:
  Staging: hv: netvsc: Cleanup error return values in
  netvsc_send().
- patches.suse/staging-hv-staging-next-20110825-0053-Staging-hv-netvsc-Cleanup-error-return-codes-in-n.patch:
  Staging: hv: netvsc: Cleanup error return codes in
  netvsc_device_add().
- patches.suse/staging-hv-staging-next-20110825-0054-Staging-hv-netvsc-Cleanup-error-codes-in-rndis_fi.patch:
  Staging: hv: netvsc: Cleanup error codes in
  rndis_filter_receive().
- patches.suse/staging-hv-staging-next-20110825-0055-Staging-hv-netvsc-Cleanup-error-code-in-rndis_fil.patch:
  Staging: hv: netvsc: Cleanup error code in
  rndis_filter_query_device().
- patches.suse/staging-hv-staging-next-20110825-0056-Staging-hv-netvsc-Cleanup-error-return-values-in.patch:
  Staging: hv: netvsc: Cleanup error return values in
  rndis_filter_set_packet_filter().
- patches.suse/staging-hv-staging-next-20110825-0057-Staging-hv-netvsc-Cleanup-error-returns-in-rndis_.patch:
  Staging: hv: netvsc: Cleanup error returns in
  rndis_filter_init_device().
- patches.suse/staging-hv-staging-next-20110825-0058-Staging-hv-netvsc-Cleanup-error-code-in-rndis_fil.patch:
  Staging: hv: netvsc: Cleanup error code in
  rndis_filter_device_add().
- patches.suse/staging-hv-staging-next-20110825-0059-Staging-hv-mouse-Change-the-jump-label-Cleanup-to.patch:
  Staging: hv: mouse: Change the jump label Cleanup to cleanup.
- patches.suse/staging-hv-staging-next-20110825-0060-Staging-hv-netvsc-Change-the-jump-label-Cleanup-t.patch:
  Staging: hv: netvsc: Change the jump label Cleanup to cleanup.
- patches.suse/staging-hv-staging-next-20110825-0061-Staging-hv-netvsc-Change-the-jump-label-Exit-to-e.patch:
  Staging: hv: netvsc: Change the jump label Exit to exit.
- patches.suse/staging-hv-staging-next-20110825-0062-Staging-hv-mouse-Get-rid-of-the-unused-PCI-signat.patch:
  Staging: hv: mouse: Get rid of the unused PCI signature.
- patches.suse/staging-hv-staging-next-20110825-0063-Staging-hv-hv_mouse-remove-deviceinfo_callback-fu.patch:
  Staging: hv: hv_mouse: remove deviceinfo_callback function.
- patches.suse/staging-hv-staging-next-20110825-0064-Staging-hv-hv_mouse-remove-inputreport_callback-f.patch:
  Staging: hv: hv_mouse: remove inputreport_callback function.
- patches.suse/staging-hv-staging-next-20110825-0065-Staging-hv-hv_mouse-remove-a-forward-declaration.patch:
  Staging: hv: hv_mouse: remove a forward declaration.
- patches.suse/staging-hv-staging-next-20110825-0066-Staging-hv-hv_mouse-fix-up-remove-function.patch:
  Staging: hv: hv_mouse: fix up remove() function.
- patches.suse/staging-hv-staging-next-20110825-0562-Staging-hv-Add-struct-hv_vmbus_device_id-to-mod_de.patch:
  Staging: hv: Add struct hv_vmbus_device_id to mod_devicetable.h.
- patches.suse/staging-hv-staging-next-20110825-0563-Staging-hv-add-driver_data-to-hv_vmbus_device_id.patch:
  Staging: hv: add driver_data to hv_vmbus_device_id.
- patches.suse/staging-hv-staging-next-20110825-0568-Staging-hv-Add-code-to-parse-struct-hv_vmbus_devic.patch:
  Staging: hv: Add code to parse struct hv_vmbus_device_id table.
- patches.suse/staging-hv-staging-next-20110825-0570-Staging-hv-file2alias-fix-up-alias-creation-logic.patch:
  Staging: hv: file2alias: fix up alias creation logic for
  hv_vmbus_device_id.
- patches.suse/staging-hv-vmbus-init-on-dmi-match.patch: Refresh.
* Mon Aug 29 2011 ohering@suse.de
- Update staging/hv drivers to 3.1-rc4.
- patches.suse/staging-hv-vmbus-init-on-dmi-match.patch: Refresh.
* Thu Aug 25 2011 jkosina@suse.de
- patches.suse/revert-mkuboot.sh-Fail-if-mkimage-is-missing.patch:
  Delete.
* Thu Aug 25 2011 duwe@suse.de
- Also disable CONFIG_PPC_MPC512x and CONFIG_PPC_MPC52xx;
  Those reselect DEFAULT_UIMAGE.
* Thu Aug 25 2011 jkosina@suse.cz
- patches.fixes/bridge-module-get-put.patch: Refresh to fix wrong
  conflict resolution during rebase.
* Thu Aug 25 2011 hare@suse.de
- patches.fixes/block-check-for-QUEUE_FLAG_DEAD-in-elv_completed_re.patch:
  block: check for QUEUE_FLAG_DEAD in elv_completed_request
  (bko#38842,bnc#714215).
- patches.fixes/block-check-for-QUEUE_FLAG_DEAD-in-elv_put_request.patch:
  block: check for QUEUE_FLAG_DEAD in elv_put_request
  (bko#38842,bnc#714215).
- patches.fixes/scsi_dh_alua-rtpg-flood-during-state-transitioning.patch:
  scsi_dh_alua: rtpg flood during state transitioning
  (bnc#708296).
- patches.arch/s390-09-05-zfcp-ccw_fix_remove_list.patch: Delete.
* Thu Aug 25 2011 duwe@suse.de
- Disable CONFIG_DEFAULT_UIMAGE for ppc32
* Thu Aug 25 2011 tiwai@suse.de
- patches.drivers/USB3-0004-USB-Add-authorized_default-parameter-to-the-usbcore-module.patch:
  patches.suse/dm-mpath-leastpending-path-update: Refresh, to be
  applicable via series2git
* Thu Aug 25 2011 mhocko@suse.cz
- patches.suse/slab-memless-node-01-introduce-numa_mem_id.patch:
  Delete. Deprecated by upstrem 7aac7898
- patches.suse/slab-memless-node-02-slab-use-numa_mem_id.patch:
  Delete. Deprecated by upstrem 7d6e6d09
- patches.suse/slab-memless-node-03-ia64-memoryless-nodes.patch:
  Delete. Deprecated by upstrem fd1197f1
- patches.suse/slab-memless-node-04-kernel-profile-memoryless-nodes.patch:
  Delete. Deprecated by upstrem 3dd6b5fb
* Thu Aug 25 2011 hare@suse.de
- Forward port hpsa patches to 3.0:
  * patches.drivers/hpsa-section-annotations: hpsa: annotation
  fixes.
  * patches.drivers/hpsa-update-to-hp-version.patch
* Thu Aug 25 2011 hare@suse.de
- Forward port cciss patches to 3.0:
  * patches.drivers/cciss-update-to-4.6.28.patch
  * patches.fixes/cciss-unmap-xfer-buffer-correctly
- Delete old patches:
  * patches.drivers/bfa-2.1.2.1-update
  * patches.fixes/cciss-remove-scan-thread.patch
* Thu Aug 25 2011 jkosina@suse.cz
- patches.suse/revert-mkuboot.sh-Fail-if-mkimage-is-missing.patch:
  Revert "mkuboot.sh: Fail if mkimage is missing".
* Thu Aug 25 2011 hare@suse.de
- patches.drivers/lpfc-8.3.5.3-update: Delete.
- patches.drivers/lpfc-8.3.5.6-update: Delete.
- patches.drivers/lpfc-8.3.5.8.2p-update: Delete.
- patches.drivers/qla4xxx-5.01.00-k9-5.01.00.00.11.01-k10.patch:
  Delete.
- patches.drivers/qla4xxx-5.01.00.00.11.01-k11_5.01.00.00.11.01-k12.patch:
  Delete.
- patches.drivers/qla4xxx-5.01.00.00.11.01-k12_5.01.00.00.11.01-k13.patch:
  Delete.
- patches.drivers/qla4xxx-5.01.00.00.11.01-k13_5.01.00.00.11.01-k14.patch:
  Delete.
- patches.fixes/ipr-strstrip-retval-fix: Delete.
* Wed Aug 24 2011 jbohac@suse.cz
- Update config files.
- patches.suse/netfilter-ipv4options: Refresh.
* Wed Aug 24 2011 jkosina@suse.de
- Update config files: disable FSL_SPI on ppc (unsupported
  anyway).
* Wed Aug 24 2011 jeffm@suse.com
- Re-enabled more kmsg patches:
  - patches.arch/s390-04-06-dasd-move-diag-kmsg.patch
  - patches.arch/s390-23-05-qeth-osxosm.patch
* Wed Aug 24 2011 jkosina@suse.de
- Update config files: disable MCP8XXX on ppc (unsupported
  anyway).
* Wed Aug 24 2011 jeffm@suse.com
- patches.drivers/libata-unlock-hpa-by-default: Delete. Obsoleted
  by on-demand unlocking in 2.6.35 (d8d9129e).
* Wed Aug 24 2011 jeffm@suse.com
- patches.drivers/USB3-0004-USB-Add-authorized_default-parameter-to-the-usbcore-module.patch:
  Refresh.
- patches.suse/stack-unwind: Refresh.
- patches.suse/supported-flag: Refresh.
- patches.suse/supported-flag-enterprise: Refresh.
* Wed Aug 24 2011 tiwai@suse.de
- Update config files.  Disable CONFIG_DRM_NOUVEAU.
* Wed Aug 24 2011 jeffm@suse.com
- Re-enabled KMSG_IDS and patches.arch/s390-message-catalog.diff.
* Wed Aug 24 2011 mhocko@suse.cz
- patches.suse/pagecache-limit-dirty.diff: Refresh.
- patches.suse/pagecache-limit-unmapped.diff: Refresh.
- patches.suse/pagecache-limit.patch: Refresh.
* Wed Aug 24 2011 jkosina@suse.de
- Update config files, build fixes:
  + disable ACPI_HED for ia64
  + disabled NOUVEAU for ia64
  + disable DEBUG_STACK_USAGE for ia64 -debug
  + disable KMSG_IDS for s390
- series.conf: disable a bunch of printk changes specific to s390
  for jjolly to fix
* Wed Aug 24 2011 jeffm@suse.com
- Re-enabled patches.suse/mm-compaction-migrate-pages-ia64.patch
* Wed Aug 24 2011 jeffm@suse.com
- Update config files: Synced vanilla with default from each arch.
* Wed Aug 24 2011 hare@suse.de
- patches.drivers/mpt2sas-09.102.00.00-update: mpt2sas: Update
  to version 09.102.00.00 (FATE#311801,bnc#680809).
- patches.drivers/mpt2sas-04.100.01.02-update: Delete.
- patches.drivers/mpt2sas-04.100.01.04-update: Delete.
- patches.drivers/mpt2sas-base-map-resources: Delete.
* Wed Aug 24 2011 tiwai@suse.de
- Update config files.  Enable CONFIG_FIREWIRE=m & co.
* Wed Aug 24 2011 hare@suse.de
- patches.drivers/aacraid-24701-update: Delete.
- patches.drivers/aacraid-24702-update: Delete.
- patches.drivers/qla2xxx-8.03.01.05.11.1-k8-update: Delete.
- patches.drivers/qla2xxx-8.03.01.07.11.1-k8-update: Delete.
- patches.drivers/qla2xxx-fix-tgt-init-prli-payload.diff: Delete.
* Wed Aug 24 2011 hare@suse.de
- patches.suse/dm-mpath-disable-abort-queue: Delete.
* Wed Aug 24 2011 hare@suse.de
- patches.fixes/scsi-return-success-for-fc_block_scsi_eh: Return
  'SUCCESS' for fc_block_scsi_eh() instead of '0' (bnc#613330).
- patches.fixes/scsi-short-circuit-scsi_abort_eh_cmnds:
  Short-circuit scsi_abort_eh_cmds() for FAST_IO_FAIL
  (bnc#591401).
- patches.fixes/scsi-allow-fc-lld-to-fast-fail-scsi-eh: Delete.
- patches.fixes/scsi-update-fc_block_scsi_eh: Delete.
* Wed Aug 24 2011 hare@suse.de
- Update ALUA device handler:
  * patches.fixes/scsi-dh-alua-always-update-tpgs-status:
    scsi_dh_alua: always update TPGS status on activate.
  * patches.fixes/scsi-dh-check-for-sdev-state-in-store_dh_state:
    scsi_dh: Check for sdev state in store_dh_state() (bnc#616080).
  * patches.fixes/scsi-dh-fixup-kernel-doc: scsi_dh: Fixup
    kernel-doc comments.
  * patches.fixes/scsi-dh-queuedata-accessors: Use queuedata
    accessors for device handler (bnc#486001).
  * patches.fixes/scsi-evaluate-tpgs-setting: scsi_dh_alua:
    Evaluate TPGS setting from inquiry data.
  * patches.suse/scsi-dh-implement-match-callback: scsi_dh:
    Implement match callback function.
- Delete old patches:
  * patches.drivers/hpsa-only-unmap-buffer-when-allocated
  * patches.fixes/scsi-add-tgps-setting
  * patches.fixes/scsi-dh-alua-crash-on-stpg-failback
  * patches.fixes/scsi-dh-alua-handle-all-states
  * patches.fixes/scsi-dh-alua-retry-UA
  * patches.fixes/scsi-dh-alua-send-stpg
  * patches.fixes/scsi-dh-check-for-sdev-state-before-calling-activate:
  * patches.fixes/scsi-dh-rdac-add-ibm-174x
  * patches.fixes/scsi-dh-rdac-add-stk
  * patches.fixes/scsi_dh-make-alua-handler-asynchronous
* Wed Aug 24 2011 mhocko@suse.cz
- patches.suse/x86-mark_rodata_rw.patch: Delete. Patch obsoleted
  because we now have CONFIG_FANOTIFY
- patches.xen/xen3-x86-mark_rodata_rw.patch: Delete.
* Wed Aug 24 2011 mhocko@suse.cz
- patches.fixes/Fix-unmap_vma-bug-related-to-mmu_notifiers.patch:
  Refresh.
* Tue Aug 23 2011 jeffm@suse.de
- patches.suse/gfs2-ro-mounts-only.patch: Added fix to refuse
  mounting a file system with a dirty journal instead of removing
  the writable file ops.
- patches.suse/gfs2-ro-fixes.patch: Delete.
* Tue Aug 23 2011 jbohac@suse.cz
- patches.suse/netfilter-ipt_LOG-mac: Delete.
  The new qeth driver (since v2.6.26, 4a71df50) uses a standard
  ethernet hard_header_len, so this workaround is no longer needed
  (bnc#176921)
* Tue Aug 23 2011 tiwai@suse.de
- Update config files.  Reverted many MFD_* for embedded devices.
  DVB_FE_CUSTOMISE=y and enable all frontends.
* Tue Aug 23 2011 jbohac@suse.cz
- patches.suse/enable_nf_conntrack_accounting_by_default.patch:
  enable nf_conntrack accounting by default.
- patches.fixes/netfilter-remove-pointless-config_nf_ct_acct-warning:
  Delete.
* Tue Aug 23 2011 tiwai@suse.de
- Update config files.  Disable BRCM* staging drivers
* Tue Aug 23 2011 jbeulich@novell.com
- Update Xen config files.
- config.conf: Re-enable Xen flavors.
* Tue Aug 23 2011 jslaby@suse.de
- patches.rpmify/spi-mpc8xxx_spi-len.patch: SPI: fix build with
  CONFIG_SPI_FSL_ESPI=m.
* Mon Aug 22 2011 rjw@suse.de
- patches.arch/x86-efi-10-merge-contiguous-early-reservations:
  Delete.
* Mon Aug 22 2011 rjw@suse.de
- patches.arch/acpi_srat-pxm-rev-ia64.patch: Delete.
- patches.arch/acpi_srat-pxm-rev-store.patch: Delete.
- patches.arch/acpi_srat-pxm-rev-x86-64.patch: Delete.
* Mon Aug 22 2011 rjw@suse.de
- patches.arch/x86-UV-map-ACPI-tables-as-cacheable.patch: Delete.
* Mon Aug 22 2011 jeffm@suse.de
- patches.suse/s390-messages-fix: s390 message catalog: build
  fixes.
* Mon Aug 22 2011 jslaby@suse.de
- patches.suse/suse-ppc32-mol-3.0-fixes.patch: Delete.
- patches.suse/suse-ppc32-mol-BIT: Delete.
- patches.suse/suse-ppc32-mol-get-property: Delete.
- patches.suse/suse-ppc32-mol-handle-mm-fault: Delete.
- patches.suse/suse-ppc32-mol-ioctl: Delete.
- patches.suse/suse-ppc32-mol-kbuild.patch: Delete.
- patches.suse/suse-ppc32-mol-semaphore: Delete.
- patches.suse/suse-ppc32-mol-sheep: Delete.
- patches.suse/suse-ppc32-mol.patch: Delete.
  It is not supported and causes a build failure.
* Mon Aug 22 2011 mhocko@suse.cz
- patches.fixes/mm-do_fault-preallocate-cow-page.patch: Refresh.
* Mon Aug 22 2011 mhocko@suse.cz
- patches.fixes/memcg-fix-hierarchical-oom-locking.patch: Refresh.
- patches.fixes/memcg-make-oom_lock-0-and-1-based-rather-than-coutne.patch:
  compile fix.
* Mon Aug 22 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Restore (from master branch).
* Mon Aug 22 2011 jbeulich@novell.com
- Update Xen patches to 3.0.3 and c/s 1103.
- Update config files.
* Mon Aug 22 2011 mhocko@suse.cz
- patches.fixes/cpusets-randomize-node-rotor-used-in-cpuset_mem_spre.patch:
  Refresh.
* Mon Aug 22 2011 mhocko@suse.cz
- patches.suse/silent-stack-overflow-2.patch: Delete. No longer
  needed because we now have 320b2b8d and 8ca3eb08 upstream commits.
* Mon Aug 22 2011 hare@suse.de
- Update config files.
- patches.drivers/mptfusion-Update-to-4.28.00.00suse.patch:
  Update to match 3.0 driver version.
- patches.drivers/mpt-fusion-4.22.00.00-update: Delete.
* Mon Aug 22 2011 mhocko@suse.cz
- patches.drivers/VMware-Balloon-driver-2.6.32.28.patch: Delete.
  Driver is identical in 3.0
* Mon Aug 22 2011 mszeredi@suse.cz
- Update config files.
- patches.suse/squashfs-3.4.patch: Refresh.
* Mon Aug 22 2011 mszeredi@suse.cz
- Update config files.
- patches.suse/squashfs-3.4.patch: Refresh.
* Mon Aug 22 2011 tiwai@suse.de
- rpm/kernel-binary.spec.in: More obsoletes for firewire and
  compat-ath9k
* Mon Aug 22 2011 tiwai@suse.de
- rpm/kernel-binary.spec.in: Add obsolets for firewire, iwlagn,
  compat-ath9k KMPs
* Mon Aug 22 2011 hare@suse.de
- Fixup patches for series2git:
  * patches.drivers/ixgbe-entropy-source.patch
  * patches.drivers/tg3-entropy-source.patch
  * patches.fixes/dm-release-map_lock-before-set_disk_ro
  * patches.fixes/dm-table-switch-to-readonly
  * patches.suse/dm-mpath-accept-failed-paths
- patches.suse/staging-Update-dst-to-handle-FLUSH-FUA.patch:
  Remove obsolete patch.
- Reshuffle and re-enable:
  * patches.suse/scsi-netlink-ml-module-param
  * patches.fixes/scsi-error-netlink-GFP_ATOMIC.patch
* Mon Aug 22 2011 tiwai@suse.de
- Update config files: changed CONFIG_SND_HDA_INPUT_BEEP_MODE to
  be compatible with SP1
* Mon Aug 22 2011 tiwai@suse.de
- supported.conf: updated for hd-audio drivers
* Mon Aug 22 2011 tiwai@suse.de
- patches.drivers/synaptics-hp-new-model.diff: Refresh, enabled
  again.
- patches.fixes/vgaarb-enable-legacy-resources-only-if-device-decodes.patch:
  Refresh, enabled again.
- patches.suse/acpi-video-switch-option: Refresh, enabled again.
- patches.drm/*: Delete.
- patches.fixes/bug-691216_hp_accel-resume-warning-fix.diff:
  Delete.
* Mon Aug 22 2011 jbeulich@novell.com
- misc/xen-port-patches.py: Move...
- scripts/xen-port-patches.py: ... here and update from master branch.
* Mon Aug 22 2011 nfbrown@suse.de
- patches.fixes/md-raid1-throttle: Refresh.
- patches.fixes/nfs-slot-table-alloc: Refresh.
- patches.fixes/nfs-sync-writes: Delete.
- patches.fixes/nfsd-06-sunrpc-cache-retry-cache-lookups-that-return-ETIMEDO.patch:
  Delete.
- patches.fixes/sunrpc-cache-completion.fix: Delete.
  Update nfsd and md patches for 3.0
* Sun Aug 21 2011 jslaby@suse.de
- patches.suse/suse-ppc32-mol-3.0-fixes.patch: MOL: fix build
  on newer kernels.
* Sun Aug 21 2011 mgalbraith@suse.de
- Fix fuzz
- patches.arch/bug-610783_uv_nortsched_boot_option.patch: Refresh.
* Sun Aug 21 2011 mgalbraith@suse.de
- Re-activate fixed up patch.
- patches.fixes/sched-rtsched_debug-boot-option.patch: Refresh.
* Sun Aug 21 2011 gregkh@suse.de
- Update config files: fix x86-64 vanilla config file based on the
  stable branch's version so it will at least build properly.
* Sat Aug 20 2011 jslaby@suse.de
- patches.suse/remove-syslog-WARN_ON.patch: Remove triggerable
  WARN_ONCE from check_syslog_permissions.
* Sat Aug 20 2011 jslaby@suse.de
- patches.suse/remove-syslog-WARN_ON.patch: Remove triggerable
  WARN_ONCE from check_syslog_permissions.
* Sat Aug 20 2011 mgalbraith@suse.de
- Pick up sched fixes/cleanups leading to and including the TIP merge
  of CFS Hard Limits (FATE#311682).  Drop 2.6.32 backports.
- patches.suse/sched-Balance-RT-tasks-when-forked-as-well:
  sched: Balance RT tasks when forked as well.
- patches.suse/sched-Cleanup-duplicate-local-variable-in-enqueue-and-dequeue_task_fair:
  sched: Cleanup duplicate local variable in [enqueue|dequeue]_task_fair.
- patches.suse/sched-Do-not-attempt-to-destroy-uninitialized-rt_bandwidth:
  sched: Do not attempt to destroy uninitialized rt_bandwidth.
- patches.suse/sched-Fix-harmless-typo-CONFG_FAIR_GROUP_SCHED:
  sched: Fix (harmless) typo 'CONFG_FAIR_GROUP_SCHED'.
- patches.suse/sched-Kill-WAKEUP_PREEMPT:
  sched: Kill WAKEUP_PREEMPT.
- patches.suse/sched-Remove-noop-in-lowest_flag_domain: sched:
  Remove noop in lowest_flag_domain().
- patches.suse/sched-Remove-noop-in-next_prio:
  sched: Remove noop in next_prio().
- patches.suse/sched-Remove-resetting-exec_start-in-put_prev_task_rt:
  sched: Remove resetting exec_start in put_prev_task_rt().
- patches.suse/sched-Remove-rq-avg_load_per_task:
  sched: Remove rq->avg_load_per_task.
- patches.suse/sched-Remove-unused-function-cpu_cfs_rq:
  sched: Remove unused function cpu_cfs_rq().
- patches.suse/sched-Reorder-root_domain-to-remove-64-bit-alignment-padding:
  sched: Reorder root_domain to remove 64 bit alignment padding.
- patches.suse/sched-Replace-use-of-entity_key:
  sched: Replace use of entity_key().
- patches.suse/sched-Separate-group-scheduling-code-more-clearly:
  sched: Separate group-scheduling code more clearly.
- patches.suse/sched-Use-pushable_tasks-to-determine-next-highest-prio:
  sched: Use pushable_tasks to determine next highest prio.
- patches.suse/sched-accumulate-per-cfs_rq-cpu-usage-and-charge-against-bandwidth:
  sched: Accumulate per-cfs_rq cpu usage and charge against bandwidth.
- patches.suse/sched-add-a-timer-to-handle-CFS-bandwidth-refresh:
  sched: Add a timer to handle CFS bandwidth refresh (FATE#311682).
- patches.suse/sched-add-documentation-for-bandwidth-control:
  sched: Add documentation for bandwidth control (FATE#311682).
- patches.suse/sched-add-exports-tracking-cfs-bandwidth-control-statistics:
  sched: Add exports tracking cfs bandwidth control statistics (FATE#311682).
- patches.suse/sched-add-support-for-throttling-group-entities:
  sched: Add support for throttling group entities (FATE#311682).
- patches.suse/sched-add-support-for-unthrottling-group-entities:
  sched: Add support for unthrottling group entities (FATE#311682).
- patches.suse/sched-allow-for-positional-tg_tree-walks:
  sched: Allow for positional tg_tree walks (FATE#311682).
- patches.suse/sched-cgroup-Optimize-load_balance_fair:
  sched, cgroup: Optimize load_balance_fair().
- patches.suse/sched-cpupri-Fix-memory-barriers-for-vec-updates-to-always-be-in-order:
  sched/cpupri: Fix memory barriers for vec updates to always be in order.
- patches.suse/sched-cpupri-Remove-cpupri-pri_active:
  sched/cpupri: Remove cpupri->pri_active.
- patches.suse/sched-cpupri-Remove-the-vec-lock:
  sched/cpupri: Remove the vec->lock.
- patches.suse/sched-expire-invalid-runtime:
  sched: Expire invalid runtime (FATE#311682).
- patches.suse/sched-fix-broken-SCHED_RESET_ON_FORK-handling:
  sched: fix broken SCHED_RESET_ON_FORK handling.
- patches.suse/sched-fixlet-dont-update-shares-twice-on-on_rq-parent:
  sched: Don't update shares twice on on_rq parent.
- patches.suse/sched-implement-hierarchical-task-accounting-for-SCHED_OTHER:
  sched: Implement hierarchical task accounting for SCHED_OTHER (FATE#311682).
- patches.suse/sched-introduce-primitives-to-account-for-CFS-bandwidth-tracking:
  sched: Introduce primitives to account for CFS bandwidth tracking (FATE#311682).
- patches.suse/sched-migrate-throttled-tasks-on-HOTPLUG:
  sched: Migrate throttled tasks on HOTPLUG (FATE#311682).
- patches.suse/sched-prevent-buddy-interactions-with-throttled-entities:
  sched: Prevent buddy interactions with throttled entities (FATE#311682).
- patches.suse/sched-prevent-interactions-with-throttled-entities:
  sched: Prevent interactions with throttled entities (FATE#311682).
- patches.suse/sched-return-unused-runtime-on-group-dequeue:
  sched: Return unused runtime on group dequeue (FATE#311682).
- patches.suse/sched-rt-Fix-rq-rt-pushable_tasks-bug-in-push_rt_task:
  sched, rt: Fix rq->rt.pushable_tasks bug in push_rt_task().
- patches.suse/sched-throttle-entities-exceeding-their-allowed-bandwidth:
  sched: Throttle entities exceeding their allowed bandwidth (FATE#311682).
- patches.suse/sched-update-correct-entitys-runtime-in-check_preempt_wakeup:
  sched: update correct entity's runtime in check_preempt_wakeup().
- patches.suse/sched-validate-CFS-quota-hierarchies:
  sched: Validate CFS quota hierarchies (FATE#311682).
- Fix sched-rtsched_debug-boot-option.patch spin/raw_spin[lock/unlock] merge error
- patches.fixes/sched-rtsched_debug-boot-option.patch: Refresh.
- Obsoleted patches:
- patches.suse/01-18-sched-fixlet-dont-update-shares-twice-on-on_rq-parent: Delete.
- patches.suse/02-18-sched-hierarchical-task-accounting-for-SCHED_OTHER: Delete.
- patches.suse/03-18-sched-introduce-primitives-to-account-for-CFS-bandwidth-tracking: Delete.
- patches.suse/04-18-sched-validate-CFS-quota-hierarchies: Delete.
- patches.suse/05-18-sched-accumulate-per-cfs_rq-cpu-usage-and-charge-against-bandwidth: Delete.
- patches.suse/06-18-sched-add-a-timer-to-handle-CFS-bandwidth-refresh: Delete.
- patches.suse/07-18-sched-expire-invalid-runtime: Delete.
- patches.suse/08-18-sched-add-support-for-throttling-group-entities: Delete.
- patches.suse/09-18-sched-add-support-for-unthrottling-group-entities: Delete.
- patches.suse/10-18-sched-allow-for-positional-tg_tree-walks: Delete.
- patches.suse/11-18-sched-prevent-interactions-with-throttled-entities: Delete.
- patches.suse/12-18-sched-prevent-buddy-interactions-with-throttled-entities: Delete.
- patches.suse/13-18-sched-migrate-throttled-tasks-on-HOTPLUG: Delete.
- patches.suse/14-18-sched-throttle-entities-exceeding-their-allowed-bandwidth: Delete.
- patches.suse/15-18-sched-add-exports-tracking-cfs-bandwidth-control-statistics: Delete.
- patches.suse/16-18-sched-return-unused-runtime-on-group-dequeue: Delete.
- patches.suse/18-18-sched-add-documentation-for-bandwidth-control: Delete.
* Sat Aug 20 2011 jslaby@suse.de
- patches.suse/panic-on-io-nmi-SLE11-user-space-api.patch:
  Refresh.
  Fix and reenable.
* Sat Aug 20 2011 jslaby@suse.de
- patches.fixes/make-note_interrupt-fast.diff: Delete.
  __do_IRQ from ia64 lapic code is no longer called, because they use
  genirqs properly. So this patch doesn't make sense anymore. If we need
  something to do at all, then it's adding action_ret == IRQ_NONE test
  into handle_percpu_irq before jumping into note_interrupt.
* Sat Aug 20 2011 jslaby@suse.de
- patches.arch/bug-610783_uv_nortsched_boot_option.patch: Refresh.
  Let's disable scheduler patches. They think rq->lock is spinlock.
  But in 3.0, it's raw_spinlock.
* Sat Aug 20 2011 jslaby@suse.de
- Linux 3.0.3.
- patches.drivers/USB_xhci_fix_OS_want_to_own_HC.patch: Delete.
* Sat Aug 20 2011 jslaby@suse.de
- Linux 3.0.2.
- patches.drm/drm-033-i915-Fix-typo-in-DRM_I915_OVERLAY_PUT_IMAGE-ioctl:
  Delete.
- patches.drm/drm-034-i915-Initialize-RCS-ring-status-page-address-in:
  Delete.
- patches.drm/drm-035-i915-load-the-LUT-before-pipe-enable-on-ILK:
  Delete.
- patches.drm/drm-036-i915-Hold-mode_config-mutex-during-hotplug-procedure:
  Delete.
- patches.drm/drm-037-i915-pch-Fix-integer-math-bugs-in-panel-fitting:
  Delete.
- patches.drm/drm-038-Separate-EDID-Header-Check-from-EDID-Block-Check:
  Delete.
- patches.drm/drm-039-radeon-Extended-DDC-Probing-for-Connectors-with:
  Delete.
- patches.drm/drm-040-radeon-Log-Subsystem-Vendor-and-Device-Information:
  Delete.
- patches.drm/drm-041-radeon-Extended-DDC-Probing-for-ECS-A740GM-M-DVI:
  Delete.
* Sat Aug 20 2011 jslaby@suse.de
- Linux 3.0.1.
- patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops:
  Refresh.
- patches.arch/x86_intel_set_default_energy_perf_bias.patch:
  Delete.
- patches.drivers/USB3-0105-USB-EHCI-go-back-to-using-the-system-clock-for-QH-unlinks.patch:
  Delete.
- patches.drm/drm-030-radeon-kms-fix-i2c-map-for-rv250-280:
  Delete.
- patches.drm/drm-031-radeon-kms-add-missing-vddci-setting-on-NI:
  Delete.
- patches.drm/drm-032-radeon-kms-fix-DP-training-for-DPEncoderService:
  Delete.
* Sat Aug 20 2011 gregkh@suse.de
- supported.conf: mark xhci-hcd as supported and as part of base
* Sat Aug 20 2011 jeffm@suse.com
- patches.fixes/proc-scsi-scsi-fix.diff: Delete.
* Sat Aug 20 2011 jeffm@suse.com
- Update config files: Disabled CONFIG_DEBUG_STACK_USAGE on
  non-debug flavors.
* Fri Aug 19 2011 jeffm@suse.com
- patches.arch/ppc-vio-modalias.patch: Delete.
* Fri Aug 19 2011 jeffm@suse.de
- Eliminated patches.suse/ppc-no-LDFLAGS_MODULE.patch by including
  crtsavres.o in kernel-devel for ppc.
* Fri Aug 19 2011 dsterba@suse.cz
- patches.suse/btrfs-fix-dio-locking.patch: Delete.
* Fri Aug 19 2011 jkosina@suse.cz
- series.conf: fix marker for olh -> ohering
* Fri Aug 19 2011 jkosina@suse.cz
- series.conf: annotate fixup responsibilities
* Fri Aug 19 2011 jeffm@suse.com
- patches.arch/x86-efi-09-ignore-EFI_RESERVED_TYPE: Refresh.
- patches.arch/x86-efi-10-merge-contiguous-early-reservations:
  Refresh.
- patches.arch/ppc-vmcoreinfo.diff: Delete.
- patches.arch/x86-UV-Fix-uninitialized-uvhub_mask.patch: Delete.
- patches.suse/of_platform_driver.module-owner.patch: Delete.
* Fri Aug 19 2011 mmarek@suse.cz
- Initial merge of 3.0, lots of patches are disabled with a
  +needs_update guard in series.conf, config files might have errors
  xen is disabled.
* Wed Aug 17 2011 mhocko@suse.cz
- patches.fixes/memcg-fix-hierarchical-oom-locking.patch: memcg:
  fix hierarchical oom locking (bnc#705487).
* Thu Aug 11 2011 gregkh@suse.de
- USB 3 update, 3.0 -> 3.1-rc1
- patches.drivers/USB3-0001-xhci-Remove-some-unnecessary-casts-and-tidy-some-endian-swap.patch:
  xhci: Remove some unnecessary casts and tidy some endian
  swap code.
- patches.drivers/USB3-0004-USB-Add-authorized_default-parameter-to-the-usbcore-module.patch:
  USB: Add "authorized_default" parameter to the usbcore module.
- patches.drivers/USB3-0007-USB-wusbcore-return-negative-error-codes.patch:
  USB: wusbcore: return negative error codes.
- patches.drivers/USB3-0008-ehci-hcd-remove-EOL-from-MODULE_PARM_DESC-for-hird-option.patch:
  ehci-hcd: remove EOL from MODULE_PARM_DESC for 'hird' option.
- patches.drivers/USB3-0022-iph-use-default-get_stats.patch:
  iph: use default get_stats.
- patches.drivers/USB3-0097-Staging-Merge-ENE-UB6250-MS-card-codes-from-keucr-to-drivers.patch:
  Staging: Merge ENE UB6250 MS card codes from keucr to
  drivers/usb/storage/ene_ub6250.c.
- patches.drivers/USB3-0099-drivers-usb-atm-ueagle-atm-use-__packed.patch:
  drivers: usb: atm: ueagle-atm: use __packed.
- patches.drivers/USB3-0100-drivers-usb-atm-ueagle-atm-Add-missing-const-qualifier.patch:
  drivers: usb: atm: ueagle-atm: Add missing const qualifier.
- patches.drivers/USB3-0101-USB-EHCI-Move-sysfs-related-bits-into-ehci-sysfs.c.patch:
  USB: EHCI: Move sysfs related bits into ehci-sysfs.c.
- patches.drivers/USB3-0103-ehci-refactor-pci-quirk-to-use-standard-dmi_check_system-met.patch:
  ehci: refactor pci quirk to use standard dmi_check_system
  method.
- patches.drivers/USB3-0104-ehci-add-pci-quirk-for-Ordissimo-and-RM-Slate-100-too.patch:
  ehci: add pci quirk for Ordissimo and RM Slate 100 too.
- patches.drivers/USB3-0105-USB-EHCI-go-back-to-using-the-system-clock-for-QH-unlinks.patch:
  USB: EHCI: go back to using the system clock for QH unlinks.
- patches.drivers/USB3-0106-USB-mon-Allow-to-use-usbmon-without-debugfs.patch:
  USB: mon: Allow to use usbmon without debugfs.
- patches.drivers/USB3-0113-USB-PL2303-correctly-handle-baudrates-above-115200.patch:
  USB: PL2303: correctly handle baudrates above 115200.
- patches.drivers/USB3-0120-drivers-net-static-should-be-at-beginning-of-declaration.patch:
  drivers/net: static should be at beginning of declaration.
- patches.drivers/USB3-0127-ASIX-Add-AX88772B-USB-ID.patch:
  ASIX: Add AX88772B USB ID.
- patches.drivers/USB3-0132-ASIX-Simplify-condition-in-rx_fixup.patch:
  ASIX: Simplify condition in rx_fixup().
- patches.drivers/USB3-0133-ASIX-Use-only-11-bits-of-header-for-data-size.patch:
  ASIX: Use only 11 bits of header for data size.
- patches.drivers/USB3-0134-cdc_ncm-fix-endianness-problem.patch:
  cdc_ncm: fix endianness problem.
- patches.drivers/USB_xhci_fix_OS_want_to_own_HC.patch: Refresh.
* Thu Aug 11 2011 gregkh@suse.de
- patches.suse/kdb-common: Refresh.
- patches.suse/kdb-fix-uhci-build-issues.patch: KDB: fix uhci
  build issues.
* Thu Aug 11 2011 gregkh@suse.de
- Final USB 3 2.6.39 -> 3.0 update
- KDB is broken, I need to figure out how to resolve that, and will do so next...
- Update config files.
- patches.drivers/USB3-0203-USB-remove-remaining-usages-of-hcd-state-from-usbcore-and-fi.patch:
  USB: remove remaining usages of hcd->state from usbcore and
  fix regression.
- patches.drivers/USB3-0206-usb-storage-Correct-adjust_quirks-to-include-latest-flags.patch:
  usb-storage: Correct adjust_quirks to include latest flags.
- patches.drivers/USB3-0207-USB-UHCI-Add-support-for-big-endian-mmio.patch:
  USB: UHCI: Add support for big endian mmio.
- patches.drivers/USB3-0208-USB-UHCI-Use-ACCESS_ONCE-rather-than-using-a-full-compiler-b.patch:
  USB: UHCI: Use ACCESS_ONCE rather than using a full compiler
  barrier.
- patches.drivers/USB3-0209-USB-UHCI-Add-support-for-big-endian-descriptors.patch:
  USB: UHCI: Add support for big endian descriptors.
- patches.drivers/USB3-0210-USB-UHCI-Support-big-endian-GRUSBHC-HC.patch:
  USB: UHCI: Support big endian GRUSBHC HC.
- patches.drivers/USB3-0213-CDC-NCM-release-interfaces-fix-in-unbind.patch:
  CDC NCM: release interfaces fix in unbind().
- patches.drivers/USB3-0214-xhci-Clear-stopped_td-when-Stop-Endpoint-command-completes.patch:
  xhci: Clear stopped_td when Stop Endpoint command completes.
- patches.drivers/USB3-0215-xhci-Don-t-submit-commands-when-the-host-is-dead.patch:
  xhci: Don't submit commands when the host is dead.
- patches.drivers/USB3-0216-xhci-STFU-Remove-function-tracing.patch:
  xhci: STFU: Remove function tracing.
- patches.drivers/USB3-0217-xhci-STFU-Don-t-print-event-ring-dequeue-pointer.patch:
  xhci: STFU: Don't print event ring dequeue pointer.
- patches.drivers/USB3-0218-xhci-STFU-Be-quieter-during-URB-submission-and-completion.patch:
  xhci: STFU: Be quieter during URB submission and completion.
- patches.drivers/USB3-0220-Intel-xhci-Support-EHCI-xHCI-port-switching.patch:
  Intel xhci: Support EHCI/xHCI port switching.
- patches.drivers/USB3-0221-Intel-xhci-Ignore-spurious-successful-event.patch:
  Intel xhci: Ignore spurious successful event.
- patches.drivers/USB3-0222-Intel-xhci-Limit-number-of-active-endpoints-to-64.patch:
  Intel xhci: Limit number of active endpoints to 64.
- patches.drivers/USB3-0223-drivers-net-usb-catc.c-Fix-potential-deadlock-in-catc_ctrl_r.patch:
  drivers/net/usb/catc.c: Fix potential deadlock in
  catc_ctrl_run().
- patches.drivers/USB3-0224-xhci-Bigendian-fix-for-skip_isoc_td.patch:
  xhci: Bigendian fix for skip_isoc_td().
- patches.drivers/USB3-0225-usbnet-cdc_ncm-add-missing-.reset_resume-hook.patch:
  usbnet/cdc_ncm: add missing .reset_resume hook.
- patches.drivers/USB3-0226-xhci-Bigendian-fix-for-xhci_check_bandwidth.patch:
  xhci: Bigendian fix for xhci_check_bandwidth().
- patches.drivers/USB3-0227-xhci-Add-defines-for-hardcoded-slot-states.patch:
  xhci: Add defines for hardcoded slot states.
- patches.drivers/USB3-0228-xhci-Do-not-issue-device-reset-when-device-is-not-setup.patch:
  xhci: Do not issue device reset when device is not setup.
- patches.drivers/USB3-0229-xhci-Disable-MSI-for-some-Fresco-Logic-hosts.patch:
  xhci: Disable MSI for some Fresco Logic hosts.
- patches.drivers/USB3-0231-option-add-Zoom-4597-modem-USB-IDs.patch:
  option: add Zoom 4597 modem USB IDs.
- patches.drivers/USB3-0232-option-add-Alcatel-X200-to-sendsetup-blacklist.patch:
  option: add Alcatel X200 to sendsetup blacklist.
- patches.drivers/USB3-0233-option-add-Prolink-PH300-modem-IDs.patch:
  option: add Prolink PH300 modem IDs.
- patches.drivers/USB3-0234-USB-option-Add-blacklist-for-ZTE-K3765-Z-19d2-2002.patch:
  USB: option Add blacklist for ZTE K3765-Z (19d2:2002).
- patches.drivers/USB3-0246-usb-storage-redo-incorrect-reads.patch:
  usb-storage: redo incorrect reads.
- patches.drivers/USB3-0248-USB-CONFIG_USB_GADGET_DUALSPEED-is-not-user-configurable.patch:
  USB: CONFIG_USB_GADGET_DUALSPEED is not user-configurable.
- patches.drivers/USB3-0249-drivers-usb-host-ohci-pxa27x.c-add-missing-clk_put.patch:
  drivers/usb/host/ohci-pxa27x.c: add missing clk_put.
- patches.drivers/USB3-0250-Revert-USB-option-add-ID-for-ZTE-MF-330.patch:
  Revert "USB: option: add ID for ZTE MF 330".
- patches.drivers/USB3-0254-USB-TI-3410-5052-USB-Serial-Driver-Fix-mem-leak-when-firmwar.patch:
  USB: TI 3410/5052 USB Serial Driver: Fix mem leak when firmware
  is too big.
- patches.drivers/USB3-0256-USB-Free-bandwidth-when-usb_disable_device-is-called.patch:
  USB: Free bandwidth when usb_disable_device is called.
- patches.drivers/USB3-0257-xhci-Don-t-warn-about-zeroed-bMaxBurst-descriptor-field.patch:
  xhci: Don't warn about zeroed bMaxBurst descriptor field.
- patches.drivers/USB3-0258-xHCI-1.0-Force-Stopped-Event-FSE.patch:
  xHCI 1.0: Force Stopped Event(FSE).
- patches.drivers/USB3-0259-USB-change-maintainership-of-ohci-hcd-and-ehci-hcd.patch:
  USB: change maintainership of ohci-hcd and ehci-hcd.
- patches.drivers/USB3-0262-net-usb-Add-Samsung-Kalmia-driver-for-Samsung-GT-B3730.patch:
  net/usb: Add Samsung Kalmia driver for Samsung GT-B3730.
- patches.drivers/USB3-0263-xHCI-1.0-Incompatible-Device-Error.patch:
  xHCI 1.0: Incompatible Device Error.
- patches.drivers/USB3-0264-xhci-Add-reset-on-resume-quirk-for-asrock-p67-host.patch:
  xhci: Add reset on resume quirk for asrock p67 host.
- patches.drivers/USB3-0265-xhci-Always-set-urb-status-to-zero-for-isoc-endpoints.patch:
  xhci: Always set urb->status to zero for isoc endpoints.
- patches.drivers/USB3-0267-net-usb-kalmia-Various-fixes-for-better-support-of-non-x86-a.patch:
  net/usb: kalmia: Various fixes for better support of non-x86
  architectures.
- patches.drivers/USB3-0268-net-usb-kalmia-signedness-bug-in-kalmia_bind.patch:
  net/usb/kalmia: signedness bug in kalmia_bind().
- patches.drivers/USB3-0270-USB-Add-new-FT232H-chip-to-drivers-usb-serial-ftdi_sio.c.patch:
  USB: Add new FT232H chip to drivers/usb/serial/ftdi_sio.c.
- patches.drivers/USB3-0272-usb-r8a66597-hcd-fix-cannot-detect-low-full-speed-device.patch:
  usb: r8a66597-hcd: fix cannot detect low/full speed device.
- patches.drivers/USB3-0273-usbnet-Remove-over-broad-module-alias-from-zaurus.patch:
  usbnet: Remove over-broad module alias from zaurus.
- patches.drivers/USB3-0275-USB-fix-regression-occurring-during-device-removal.patch:
  USB: fix regression occurring during device removal.
- patches.drivers/USB3-0276-USB-additional-regression-fix-for-device-removal.patch:
  USB: additional regression fix for device removal.
- patches.drivers/USB3-0277-hso-fix-a-use-after-free-condition.patch:
  hso: fix a use after free condition.
- patches.drivers/USB3-intel-xhci-add-pci-id-for-panther-point-xhci-host.patch:
  Intel xhci: Add PCI id for Panther Point xHCI host.
- patches.drivers/USB_xhci_fix_OS_want_to_own_HC.patch: Refresh.
- patches.drivers/intel-add-panther-point-pch-support.patch:
  Refresh.
- patches.suse/kdb-common: Refresh.
* Thu Aug 11 2011 gregkh@suse.de
- more USB 3 2.6.39 -> 3.0 patches
- patches.drivers/USB3-0161-USB-cp210x-fix-typo-Telegesys-should-have-been-Telegesis.patch:
  USB: cp210x: fix typo, Telegesys should have been Telegesis.
- patches.drivers/USB3-0163-usb-fix-warning-in-usbtest-module-v2.patch:
  usb: fix warning in usbtest module v2.
- patches.drivers/USB3-0166-USB-cdc_acm-Fix-oops-when-Droids-MuIn-LCD-is-connected.patch:
  USB: cdc_acm: Fix oops when Droids MuIn LCD is connected.
- patches.drivers/USB3-0169-xhci-Fix-bug-in-control-transfer-cancellation.patch:
  xhci: Fix bug in control transfer cancellation.
- patches.drivers/USB3-0170-ehci-pci-quirk-cleanup.patch: ehci:
  pci quirk cleanup.
- patches.drivers/USB3-0171-ehci-workaround-for-pci-quirk-timeout-on-ExoPC.patch:
  ehci: workaround for pci quirk timeout on ExoPC.
- patches.drivers/USB3-0172-xhci-move-the-common-code-to-a-function-to-get-max-ports-and.patch:
  xhci: move the common code to a function to get max ports and
  port array.
- patches.drivers/USB3-0173-CDC-NCM-Add-mising-short-packet-in-cdc_ncm-driver.patch:
  CDC NCM: Add mising short packet in cdc_ncm driver.
- patches.drivers/USB3-0184-drivers-usb-serial-opticon.c-Release-resources-on-kmalloc-fa.patch:
  drivers/usb/serial/opticon.c: Release resources on kmalloc
  failure.
- patches.drivers/USB3-0188-xhci-Fix-memory-leak-in-ring-cache-deallocation.patch:
  xhci: Fix memory leak in ring cache deallocation.
- patches.drivers/USB3-0189-xhci-Fix-memory-leak-bug-when-dropping-endpoints.patch:
  xhci: Fix memory leak bug when dropping endpoints.
- patches.drivers/USB3-0190-USB-option-add-support-for-Huawei-E353-device.patch:
  USB: option: add support for Huawei E353 device.
- patches.drivers/USB3-0194-EHCI-don-t-rescan-interrupt-QHs-needlessly.patch:
  EHCI: don't rescan interrupt QHs needlessly.
- patches.drivers/USB3-0196-usb-storage-fix-up-the-unusual_realtek-device-list.patch:
  usb-storage: fix up the unusual_realtek device list.
* Thu Aug 11 2011 gregkh@suse.de
- USB 3 work, the big xhci 1.0 update (FATE#311390), as part of the
  USB backport of 2.6.39 -> 3.0
- patches.drivers/USB3-0100-xhci-1.0-Update-TD-size-field-format.patch:
  xhci 1.0: Update TD size field format.
- patches.drivers/USB3-0101-xhci-1.0-Set-transfer-burst-count-field.patch:
  xhci 1.0: Set transfer burst count field.
- patches.drivers/USB3-0102-xhci-1.0-Set-transfer-burst-last-packet-count-field.patch:
  xhci 1.0: Set transfer burst last packet count field.
- patches.drivers/USB3-0123-USB-ehci-remove-structure-packing-from-ehci_def.patch:
  USB: ehci: remove structure packing from ehci_def.
- patches.drivers/USB3-0124-USB-ldusb-add-several-new-devices.patch:
  USB: ldusb: add several new devices.
- patches.drivers/USB3-0133-USB-EHCI-Support-controllers-with-big-endian-capability-regs.patch:
  USB: EHCI: Support controllers with big endian capability regs.
- patches.drivers/USB3-0141-USB-UHCI-Remove-PCI-dependencies-from-uhci-hub.patch:
  USB: UHCI: Remove PCI dependencies from uhci-hub.
- patches.drivers/USB3-0142-USB-UHCI-Allow-dynamic-assignment-of-bus-specific-functions.patch:
  USB: UHCI: Allow dynamic assignment of bus specific functions.
- patches.drivers/USB3-0143-USB-UHCI-Codingstyle-fixes.patch:
  USB: UHCI: Codingstyle fixes.
- patches.drivers/USB3-0144-USB-UHCI-Move-PCI-specific-functions-to-uhci-pci.c.patch:
  USB: UHCI: Move PCI specific functions to uhci-pci.c.
- patches.drivers/USB3-0145-USB-UHCI-Wrap-I-O-register-accesses.patch:
  USB: UHCI: Wrap I/O register accesses.
- patches.drivers/USB3-0146-USB-UHCI-Support-non-PCI-host-controllers.patch:
  USB: UHCI: Support non-PCI host controllers.
- patches.drivers/USB3-0147-USB-UHCI-Add-support-for-GRLIB-GRUSBHC-controller.patch:
  USB: UHCI: Add support for GRLIB GRUSBHC controller.
- patches.drivers/USB3-0152-xHCI-1.0-Setup-Stage-TRB-Transfer-Type-flag.patch:
  xHCI 1.0: Setup Stage TRB Transfer Type flag.
- patches.drivers/USB3-0153-xHCI-1.0-Control-endpoint-average-TRB-length-field-set.patch:
  xHCI 1.0: Control endpoint average TRB length field set.
- patches.drivers/USB3-0154-xHCI-1.0-Isoch-endpoint-CErr-field-set.patch:
  xHCI 1.0: Isoch endpoint CErr field set.
- patches.drivers/USB3-0155-xHCI-1.0-Block-Interrupts-for-Isoch-transfer.patch:
  xHCI 1.0: Block Interrupts for Isoch transfer.
- patches.drivers/USB3-0156-xHCI-1.0-TT_THINK_TIME-set.patch:
  xHCI 1.0: TT_THINK_TIME set.
- patches.drivers/USB3-0157-xHCI-1.0-Max-Exit-Latency-Too-Large-Error.patch:
  xHCI 1.0: Max Exit Latency Too Large Error.
- patches.suse/kdb-common: Refresh.
* Thu Aug 11 2011 gregkh@suse.de
- USB 3 update, more 2.6.39 -> 3.0 patches
- patches.drivers/USB3-0054-USB-cdc-wdm-reset-handling-according-to-new-requirements.patch:
  USB: cdc-wdm: reset handling according to new requirements.
- patches.drivers/USB3-0055-Bind-only-modem-AT-command-endpoint-to-option-module.patch:
  Bind only modem AT command endpoint to option module.
- patches.drivers/USB3-0056-USB-documentation-update-for-the-pre_reset-method.patch:
  USB: documentation update for the pre_reset method.
- patches.drivers/USB3-0074-usb-hcd-don-t-return-0-on-error-in-usb_add_hcd.patch:
  usb/hcd: don't return 0 on error in usb_add_hcd().
- patches.drivers/USB3-0077-USB-ohci-s3c2410-use-__devinit-and-__devexit-macros-for-prob.patch:
  USB: ohci-s3c2410: use __devinit and __devexit macros for
  probe and remove.
- patches.drivers/USB3-0078-USB-ohci-s3c2410-use-resource_size.patch:
  USB: ohci-s3c2410: use resource_size().
- patches.drivers/USB3-0080-USB-add-queued-unlinks-test-case-to-usbtest-driver.patch:
  USB: add queued-unlinks test case to usbtest driver.
- patches.drivers/USB3-0081-usb-core-Change-usb_create_sysfs_intf_files-return-type-to-v.patch:
  usb: core: Change usb_create_sysfs_intf_files()' return type
  to void.
- patches.drivers/USB3-0082-xhci-hcd-Include-linux-slab.h-in-xhci-pci.c.patch:
  xhci-hcd: Include <linux/slab.h> in xhci-pci.c.
- patches.drivers/USB3-0083-SCSI-usb-storage-do-not-increment-cmd-serial_number.patch:
  usb-storage: do not increment cmd->serial_number.
- patches.drivers/USB3-0084-usb-usbtest-print-super-on-super-speed.patch:
  usb/usbtest: print super on super speed.
- patches.drivers/USB3-0085-usb-usbtest-fix-test10-on-superpseed.patch:
  usb/usbtest: fix test10 on superpseed.
- patches.drivers/USB3-0087-xhci-Make-xHCI-driver-endian-safe.patch:
  xhci: Make xHCI driver endian-safe.
- patches.drivers/USB3-0088-xhci-Add-rmb-between-reading-event-validity-event-data-acces.patch:
  xhci: Add rmb() between reading event validity & event data
  access.
- patches.drivers/USB3-0089-xhci-Add-an-assertion-to-check-for-virt_dev-0-bug.patch:
  xhci: Add an assertion to check for virt_dev=0 bug.
- patches.drivers/USB3-0090-xhci-Remove-recursive-call-to-xhci_handle_event.patch:
  xhci: Remove recursive call to xhci_handle_event.
- patches.drivers/USB3-0091-usb-ch9-use-proper-endianess-for-wBytesPerInterval.patch:
  usb/ch9: use proper endianess for wBytesPerInterval.
- patches.drivers/USB3-0092-xHCI-warm-reset-support.patch: xHCI:
  warm reset support.
- patches.drivers/USB3-0093-xHCI-Clear-link-state-change-support.patch:
  xHCI: Clear link state change support.
- patches.drivers/USB3-0094-xHCI-Set-link-state-support.patch:
  xHCI: Set link state support.
- patches.drivers/USB3-0095-xHCI-report-USB3.0-portstatus-comply-with-USB3.0-specificati.patch:
  xHCI: report USB3.0 portstatus comply with USB3.0 specification.
- patches.drivers/USB3-0096-usbcore-Refine-USB3.0-device-suspend-and-resume.patch:
  usbcore: Refine USB3.0 device suspend and resume.
- patches.drivers/USB3-0097-usbcore-warm-reset-USB3-port-in-SS.Inactive-state.patch:
  usbcore: warm reset USB3 port in SS.Inactive state.
- patches.drivers/USB3-0098-xhci-Remove-sparse-warning-about-cmd_status.patch:
  xhci: Remove sparse warning about cmd_status.
- patches.drivers/USB3-0099-xhci-1.0-Only-interrupt-on-short-packet-for-IN-EPs.patch:
  xhci 1.0: Only interrupt on short packet for IN EPs.
* Thu Aug 11 2011 gregkh@suse.de
- Enable the first bit of USB 3 2.6.39 -> 3.0 patches, again.
- Update config files.
- patches.drivers/USB3-0001-net-convert-SMSC-USB-net-drivers-to-hw_features.patch:
  Delete.
* Thu Aug 11 2011 duwe@suse.de
- patches.arch/s390-33-01-qeth-nr-out-queues: qeth: wrong number
  of output queues for HiperSockets (bnc#711765).
- patches.drivers/ehea-statsbuf-GFP_KERNEL: ehea: Allocate stats
  buffer with GFP_KERNEL (bnc#711592).
* Thu Aug 11 2011 dsterba@suse.de
- patches.suse/btrfs-add-btrfs_trim_fs-to-handle-FITRIM.patch:
  Btrfs: add btrfs_trim_fs() to handle FITRIM (FATE#306586).
- patches.suse/btrfs-drop-unused-parameter-from-btrfs_release_path.patch:
  Refresh.
- patches.suse/btrfs-fix-oops-of-empty-filesystem-after-balance.patch:
  Refresh.
- patches.suse/btrfs-make-free-space-cache-code-generic.patch:
  Refresh.
- patches.suse/btrfs-support-reading-writing-on-disk-free-ino-cache.patch:
  Refresh.
* Thu Aug 11 2011 gregkh@suse.de
- and yet, even when trying to just "revert all my previous changes" to
  fix the build, it breaks the build again.  It's time for some wine...
- Update config files.
* Thu Aug 11 2011 gregkh@suse.de
- comment out the last USB3 update from series.conf, as I obviously
  can't get it right this evening.  Hopefully in the morning, with a new
  start, all will be better and I can actually get it right without
  breaking the build, three times in a row...
* Thu Aug 11 2011 gregkh@suse.de
- fix up build breakage in:
  patches.drivers/USB3-0027-usb-don-t-enter-usb-subdirectories-directly.patch:
* Thu Aug 11 2011 jbohac@suse.cz
- Fix VLAN on tg3 and cxgb4 (bnc#709300).
- patches.drivers/0131-tg3-Fix-inline-keyword-usage.patch:
  Refresh.
- patches.drivers/0143-net-tg3-convert-to-hw_features.patch:
  Refresh.
- patches.drivers/0163-tg3-Convert-u32-flag-flg2-flg3-uses-to-bitmap.patch:
  Refresh.
- patches.drivers/0166-tg3-Set-tx-bug-flags-for-more-devices.patch:
  Refresh.
- patches.drivers/0175-tg3-Consolidate-all-netdev-feature-assignments.patch:
  Refresh.
- patches.drivers/cxgb4-chelsio-t4-driver-compat: Refresh.
- patches.drivers/0113-tg3-Use-new-VLAN-code.patch: Delete.
- patches.drivers/cxgb4-update-to-utilize-the-newer-vlan-infrastructure:
  Delete.
* Thu Aug 11 2011 gregkh@suse.de
- USB 3 2.6.39 -> 3.0, first round of easy patches
- Update config files.
- patches.drivers/USB3-0001-net-convert-SMSC-USB-net-drivers-to-hw_features.patch:
  net: convert SMSC USB net drivers to hw_features.
- patches.drivers/USB3-0002-usb-plusb-Whitespace.patch: usb:
  plusb: Whitespace.
- patches.drivers/USB3-0003-usb-plusb-Add-support-for-PL-25A1.patch:
  usb: plusb: Add support for PL-25A1.
- patches.drivers/USB3-0004-usb-plusb-Add-debug-to-reset-function.patch:
  usb: plusb: Add debug to reset function.
- patches.drivers/USB3-0005-rndis_host-Poll-status-before-control-channel-where-necessar.patch:
  rndis_host: Poll status before control channel where necessary.
- patches.drivers/USB3-0008-USB-change-the-way-we-initialize-format-strings.patch:
  USB: change the way we initialize format strings.
- patches.drivers/USB3-0009-USB-cdc-acm-add-missing-newlines-to-dev_dbg-and-dev_err.patch:
  USB: cdc-acm: add missing newlines to dev_dbg and dev_err.
- patches.drivers/USB3-0010-USB-cdc-acm-use-dev_err-to-report-failed-allocations.patch:
  USB: cdc-acm: use dev_err to report failed allocations.
- patches.drivers/USB3-0011-USB-cdc-acm-clean-up-dev_err-and-dev_dbg.patch:
  USB: cdc-acm: clean up dev_err and dev_dbg.
- patches.drivers/USB3-0012-USB-cdc-acm-replace-dbg-macros-with-dev_dbg.patch:
  USB: cdc-acm: replace dbg macros with dev_dbg.
- patches.drivers/USB3-0013-USB-cdc-acm-clean-up-verbose-debug.patch:
  USB: cdc-acm: clean up verbose debug.
- patches.drivers/USB3-0014-USB-cdc-acm-use-dev_vdbg-in-read-write-paths.patch:
  USB: cdc-acm: use dev_vdbg in read/write paths.
- patches.drivers/USB3-0015-USB-cdc-acm-remove-version-information-and-changelog.patch:
  USB: cdc-acm: remove version information and changelog.
- patches.drivers/USB3-0016-USB-cdc-acm-remove-superfluous-prototype.patch:
  USB: cdc-acm: remove superfluous prototype.
- patches.drivers/USB3-0017-USB-cdc-acm-remove-unused-drain-delay-code.patch:
  USB: cdc-acm: remove unused drain-delay code.
- patches.drivers/USB3-0018-USB-cdc-acm-clean-up-rx_buflimit-references.patch:
  USB: cdc-acm: clean up rx_buflimit references.
- patches.drivers/USB3-0019-USB-cdc-acm-clean-up-open-error-handling.patch:
  USB: cdc-acm: clean up open error handling.
- patches.drivers/USB3-0020-USB-cdc-acm-clean-up-read-urb-allocation.patch:
  USB: cdc-acm: clean up read urb allocation.
- patches.drivers/USB3-0021-USB-cdc-acm-re-write-read-processing.patch:
  USB: cdc-acm: re-write read processing.
- patches.drivers/USB3-0023-USB-remove-dead-code-from-usb_deregister_dev.patch:
  USB: remove dead code from usb_deregister_dev().
- patches.drivers/USB3-0025-USB-sl811-add-Kconfig-option-for-ISOCHRONOUS-mode.patch:
  USB: sl811: add Kconfig option for ISOCHRONOUS mode.
- patches.drivers/USB3-0027-usb-don-t-enter-usb-subdirectories-directly.patch:
  usb: don't enter usb subdirectories directly.
- patches.drivers/USB3-0028-USB-UHCI-remove-uses-of-hcd-state.patch:
  USB: UHCI: remove uses of hcd->state.
- patches.drivers/USB3-0029-USB-UHCI-don-t-try-to-revive-a-dead-controller.patch:
  USB: UHCI: don't try to revive a dead controller.
- patches.drivers/USB3-0030-usb-ftdi-elan-Drop-__TIME__-usage.patch:
  usb: ftdi-elan: Drop __TIME__ usage.
- patches.drivers/USB3-0031-usb-u132-hcd-Drop-__TIME__-usage.patch:
  usb: u132-hcd: Drop __TIME__ usage.
- patches.drivers/USB3-0038-Revert-USB-sam-ba-add-driver-for-Atmel-SAM-Boot-Assistant-SA.patch:
  Revert "USB: sam-ba: add driver for Atmel SAM Boot Assistant
  (SAM-BA)".
- patches.drivers/USB3-0045-rndis_host-Quirky-devices-are-still-point-to-point.patch:
  rndis_host: Quirky devices are still 'point-to-point'.
- patches.drivers/USB3-0046-drivers-net-usb-usbnet.c-Use-FIELD_SIZEOF-macro-in-usbnet_in.patch:
  drivers/net/usb/usbnet.c: Use FIELD_SIZEOF macro in
  usbnet_init() function.
* Thu Aug 11 2011 gregkh@suse.de
- Fix up some USB3 fuzz issues that got introduced with the ehci and cdc_ether changes.
- patches.drivers/USB3-0001-net-use-helpers-to-access-mc-list-v2.patch:
  Refresh.
- patches.drivers/USB3-0001-net-use-helpers-to-access-uc-list-v2.patch:
  Refresh.
- patches.drivers/USB3-0002-drivers-usb-Remove-unnecessary-return-s-from-void-functions.patch:
  Refresh.
- patches.drivers/USB3-0036-USB-remove-bogus-USB_PORT_FEAT_-_SPEED-symbols.patch:
  Refresh.
- patches.drivers/USB3-0037-USB-straighten-out-port-feature-vs.-port-status-usage.patch:
  Refresh.
- patches.drivers/USB3-0040-usb-serial-Use-tty_port-version-console-instead-of-usb_seria.patch:
  Refresh.
- patches.drivers/USB3-0044-USB-xhci-Add-watchdog-timer-for-URB-cancellation.patch:
  Refresh.
- patches.drivers/USB3-0046-USB-ehci-Minor-constant-fix-for-SCHEDULE_SLOP.patch:
  Refresh.
- patches.drivers/USB3-0047-USB-ehci-Respect-IST-when-scheduling-new-split-iTDs.patch:
  Refresh.
- patches.drivers/USB3-0049-USB-add-a-remove-hardware-sysfs-attribute.patch:
  Refresh.
- patches.drivers/USB3-0049-USB-xhci-Fix-error-path-when-configuring-endpoints.patch:
  Refresh.
- patches.drivers/USB3-0050-USB-xhci-Refactor-code-to-free-or-cache-endpoint-rings.patch:
  Refresh.
- patches.drivers/USB3-0051-USB-xhci-Allow-allocation-of-commands-without-input-contexts.patch:
  Refresh.
- patches.drivers/USB3-0052-USB-EHCI-EHCI-1.1-addendum-preparation.patch:
  Refresh.
- patches.drivers/USB3-0052-usb-fix-serial-build-when-SYSRQ-is-disabled.patch:
  Refresh.
- patches.drivers/USB3-0053-USB-EHCI-EHCI-1.1-addendum-Basic-LPM-feature-support.patch:
  Refresh.
- patches.drivers/USB3-0054-USB-EHCI-EHCI-1.1-addendum-Enable-Per-port-change-detect-bit.patch:
  Refresh.
- patches.drivers/USB3-0055-USB-xhci-Notify-the-xHC-when-a-device-is-reset.patch:
  Refresh.
- patches.drivers/USB3-0056-USB-Add-call-to-notify-xHC-of-a-device-reset.patch:
  Refresh.
- patches.drivers/USB3-0057-USB-ehci-add-call-of-free_cached_itd_list-function-in-disabl.patch:
  Refresh.
- patches.drivers/USB3-0057-USB-pl2303-increase-the-bulk-out-buffer-size-to-256-byte.patch:
  Refresh.
- patches.drivers/USB3-0058-USB-ehci-fix-audio-record-functionality-for-some-Full-speed-.patch:
  Refresh.
- patches.drivers/USB3-0058-USB-pl2303-increase-bulk-in-buffer-size-to-256-byte.patch:
  Refresh.
- patches.drivers/USB3-0068-USB-pl2303-switch-to-generic-read-implementation.patch:
  Refresh.
- patches.drivers/USB3-0073-USB-pl2303-switch-to-generic-write-implementation.patch:
  Refresh.
- patches.drivers/USB3-0074-USB-pl2303-use-generic-close.patch:
  Refresh.
- patches.drivers/USB3-0077-USB-convert-usb_hcd-bitfields-into-atomic-flags.patch:
  Refresh.
- patches.drivers/USB3-0078-USB-remove-the-auto_pm-flag.patch:
  Refresh.
- patches.drivers/USB3-0090-USB-rename-USB_SPEED_VARIABLE-to-USB_SPEED_WIRELESS.patch:
  Refresh.
- patches.drivers/USB3-0109-USB-xhci-Add-memory-allocation-for-USB3-bulk-streams.patch:
  Refresh.
- patches.drivers/USB3-0110-USB-xhci-Correct-assumptions-about-number-of-rings-per-endpo.patch:
  Refresh.
- patches.drivers/USB3-0113-USB-ehci-Elide-I-O-watchdog-on-NEC-parts.patch:
  Refresh.
- patches.drivers/USB3-0114-USB-prepare-for-changover-to-Runtime-PM-framework.patch:
  Refresh.
- patches.drivers/USB3-0119-USB-EHCI-remove-dead-code-in-the-periodic-scheduler.patch:
  Refresh.
- patches.drivers/USB3-0126-USB-xhci-Make-reverting-an-alt-setting-unfailable.patch:
  Refresh.
- patches.drivers/USB3-0129-USB-Check-bandwidth-when-switching-alt-settings.patch:
  Refresh.
- patches.drivers/USB3-0131-USB-remove-the-usb_host_ss_ep_comp-structure.patch:
  Refresh.
- patches.drivers/USB3-0133-USB-change-locking-for-device-level-autosuspend.patch:
  Refresh.
- patches.drivers/USB3-0133-USB-xhci-Avoid-double-free-after-streams-are-disabled.patch:
  Refresh.
- patches.drivers/USB3-0134-USB-consolidate-remote-wakeup-routines.patch:
  Refresh.
- patches.drivers/USB3-0136-USB-implement-usb_enable_autosuspend.patch:
  Refresh.
- patches.drivers/USB3-0144-wimax-i2400m-usb-remove-unnecessary-power-management.patch:
  Refresh.
- patches.drivers/USB3-0145-USB-cdc_ether-remove-unneeded-check.patch:
  Refresh.
- patches.drivers/USB3-0148-USB-hub-make-USB-device-id-constant.patch:
  Refresh.
- patches.drivers/USB3-0149-const-constify-remaining-dev_pm_ops.patch:
  Refresh.
- patches.drivers/USB3-0161-USB-xhci-Set-stream-ID-to-0-after-cleaning-up-stalls.patch:
  Refresh.
- patches.drivers/USB3-0169-USB-pl2303-use-tty_insert_flip_string_fixed_flag.patch:
  Refresh.
- patches.drivers/USB3-0193-usbnet-use-eth-d-name-for-known-ethernet-devices.patch:
  Refresh.
- patches.drivers/USB3-0200-USB-Fix-duplicate-sysfs-problem-after-device-reset.patch:
  Refresh.
- patches.drivers/USB3-0217-USB-ehci-phy-low-power-mode-bug-fixing.patch:
  Refresh.
- patches.drivers/USB3-0231-USB-tty-Prune-uses-of-tty_request_room-in-the-USB-layer.patch:
  Refresh.
- patches.drivers/USB3-0239-USB-pl2303-initial-TIOCGSERIAL-support.patch:
  Refresh.
- patches.drivers/USB3-0243-USB-pl2303-remove-unnecessary-reset-of-usb_device-in-urbs.patch:
  Refresh.
- patches.drivers/USB3-0245-echi-dbgp-Add-kernel-debugger-support-for-the-usb-debug-port.patch:
  Refresh.
- patches.drivers/USB3-0306-drivers-net-usb-Add-new-driver-ipheth.patch:
  Refresh.
- patches.drivers/USB3-0318-USB-xhci-Set-EP0-dequeue-ptr-after-reset-of-configured-devic.patch:
  Refresh.
- patches.drivers/USB3-0318-usb-Increase-timeout-value-for-device-reset.patch:
  Refresh.
- patches.drivers/usb3-paper-over-warn_on-warning-in-drivers-usb-core-driver.c.patch:
  Refresh.
* Wed Aug 10 2011 gregkh@suse.de
- Fix up the cdc_ether mess for wwan devices.  This fixes the build error that
  was previously happening, and now properly detects a wider range of devices
  and tells userspace how to handle them correctly.
- patches.drivers/USB3-0001-usbnet-Use-wwan-d-interface-name-for-mobile-broadband-device.patch:
  Refresh.
- patches.drivers/USB3-0007-cdc_ether-Identify-MBM-devices-by-GUID-in-MDLM-descriptor.patch:
  cdc_ether: Identify MBM devices by GUID in MDLM descriptor.
- patches.drivers/USB3-0012-cdc-ether-Implement-reset_resume.patch:
  Refresh.
- patches.drivers/USB3-0013-usbnet-cdc-ether-Autosuspend-for-online-devices.patch:
  Refresh.
- patches.drivers/USB3-0191-net-usb-Ethernet-quirks-for-the-LG-VL600-4G-modem.patch:
  Refresh.
- patches.drivers/USB3-0224-cdc_ether-new-PID-for-Ericsson-C3607w-to-the-whitelist-resub.patch:
  cdc_ether: new PID for Ericsson C3607w to the whitelist
  (resubmit).
- patches.drivers/USB3-0242-usbnet-add-support-for-some-Huawei-modems-with-cdc-ether-por.patch:
  usbnet: add support for some Huawei modems with cdc-ether ports.
- patches.drivers/USB3-0251-net-usb-mark-LG-VL600-LTE-modem-ethernet-interface-as-WWAN.patch:
  Refresh.
- patches.drivers/USB3-0321-cdc_ether-fix-autosuspend-for-mbm-devices.patch:
  cdc_ether: fix autosuspend for mbm devices.
* Wed Aug 10 2011 gregkh@suse.de
- USB 3.  Final chunk of .38 -> .39 patches.
- patches.drivers/USB3-0217-USB-host-Fix-lockdep-warning-in-AMD-PLL-quirk.patch:
  USB host: Fix lockdep warning in AMD PLL quirk.
- patches.drivers/USB3-0221-usb-Fix-qcserial-memory-leak-on-rmmod.patch:
  usb: Fix qcserial memory leak on rmmod.
- patches.drivers/USB3-0222-usb-qcserial-avoid-pointing-to-freed-memory.patch:
  usb: qcserial avoid pointing to freed memory.
- patches.drivers/USB3-0223-usb-qcserial-add-missing-errorpath-kfrees.patch:
  usb: qcserial add missing errorpath kfrees.
- patches.drivers/USB3-0228-USB-xhci-unsigned-char-never-equals-1.patch:
  USB: xhci: unsigned char never equals -1.
- patches.drivers/USB3-0229-USB-xhci-remove-excessive-inline-markings.patch:
  USB: xhci - remove excessive 'inline' markings.
- patches.drivers/USB3-0230-USB-xhci-simplify-logic-of-skipping-missed-isoc-TDs.patch:
  USB: xhci: simplify logic of skipping missed isoc TDs.
- patches.drivers/USB3-0232-xhci-Fix-NULL-pointer-deref-in-handle_port_status.patch:
  xhci: Fix NULL pointer deref in handle_port_status().
- patches.drivers/USB3-0233-USB-xhci-also-free-streams-when-resetting-devices.patch:
  USB: xhci - also free streams when resetting devices.
- patches.drivers/USB3-0234-USB-Fix-unplug-of-device-with-active-streams.patch:
  USB: Fix unplug of device with active streams.
- patches.drivers/USB3-0235-usbcore-Bug-fix-system-can-t-suspend-with-USB3.0-device-conn.patch:
  usbcore: Bug fix: system can't suspend with USB3.0 device
  connected to USB3.0 hub.
- patches.drivers/USB3-0236-xhci-Tell-USB-core-both-roothubs-lost-power.patch:
  xhci: Tell USB core both roothubs lost power.
- patches.drivers/USB3-0237-xHCI-Implement-AMD-PLL-quirk.patch:
  xHCI: Implement AMD PLL quirk.
- patches.drivers/USB3-0238-usbnet-Fix-up-FLAG_POINTTOPOINT-and-FLAG_MULTI_PACKET-overla.patch:
  usbnet: Fix up 'FLAG_POINTTOPOINT' and 'FLAG_MULTI_PACKET'
  overlaps.
- patches.drivers/USB3-0240-cdc_ncm-fix-short-packet-issue-on-some-devices.patch:
  cdc_ncm: fix short packet issue on some devices.
- patches.drivers/USB3-0241-usbnet-Resubmit-interrupt-URB-if-device-is-open.patch:
  usbnet: Resubmit interrupt URB if device is open.
- patches.drivers/USB3-0246-smsc95xx-fix-reset-check.patch:
  smsc95xx: fix reset check.
- patches.drivers/USB3-0248-xHCI-Clear-PLC-in-xhci_bus_resume.patch:
  xHCI: Clear PLC in xhci_bus_resume().
- patches.drivers/USB3-0249-usbnet-runtime-pm-fix-out-of-memory.patch:
  usbnet: runtime pm: fix out of memory.
- patches.drivers/USB3-0250-ipheth-Properly-distinguish-length-and-alignment-in-URBs-and.patch:
  ipheth: Properly distinguish length and alignment in URBs
  and skbs.
- patches.drivers/USB3-0251-net-usb-mark-LG-VL600-LTE-modem-ethernet-interface-as-WWAN.patch:
  net/usb: mark LG VL600 LTE modem ethernet interface as WWAN.
- patches.drivers/USB_xhci_fix_OS_want_to_own_HC.patch: Refresh.
* Wed Aug 10 2011 gregkh@suse.de
- more USB 3 updates, .39 patches still.
- Update config files.
- patches.drivers/USB3-0160-xhci-Fixes-for-suspend-resume-of-shared-HCDs.patch:
  xhci: Fixes for suspend/resume of shared HCDs.
- patches.drivers/USB3-0161-xhci-Return-canceled-URBs-immediately-when-host-is-halted.patch:
  xhci: Return canceled URBs immediately when host is halted.
- patches.drivers/USB3-0162-USB-Remove-bogus-USB_PORT_STAT_SUPER_SPEED-symbol.patch:
  USB: Remove bogus USB_PORT_STAT_SUPER_SPEED symbol.
- patches.drivers/USB3-0163-USB-Disable-auto-suspend-for-USB-3.0-hubs.patch:
  USB: Disable auto-suspend for USB 3.0 hubs.
- patches.drivers/USB3-0164-xhci-Update-internal-dequeue-pointers-after-stalls.patch:
  xhci: Update internal dequeue pointers after stalls.
- patches.drivers/USB3-0166-xhci-Clean-up-cycle-bit-math-used-during-stalls.patch:
  xhci: Clean up cycle bit math used during stalls.
- patches.drivers/USB3-0167-USB-Add-support-for-SuperSpeed-isoc-endpoints.patch:
  USB: Add support for SuperSpeed isoc endpoints.
- patches.drivers/USB3-0168-NET-cdc-phonet-fix-stop-queue-handling.patch:
  NET: cdc-phonet, fix stop-queue handling.
- patches.drivers/USB3-0170-USB-Hub-Do-not-call-device_set_wakeup_capable-under-spinlock.patch:
  USB / Hub: Do not call device_set_wakeup_capable() under
  spinlock.
- patches.drivers/USB3-0174-NET-smsc95xx-don-t-use-stack-for-async-writes-to-the-device.patch:
  NET: smsc95xx: don't use stack for async writes to the device.
- patches.drivers/USB3-0178-USB-Do-not-pass-negative-length-to-snoop_urb.patch:
  USB: Do not pass negative length to snoop_urb().
- patches.drivers/USB3-0185-usb-wwan-fix-compilation-without-CONFIG_PM_RUNTIME.patch:
  usb: wwan: fix compilation without CONFIG_PM_RUNTIME.
- patches.drivers/USB3-0186-USB-Fix-bad-dma-problem-on-WDM-device-disconnect.patch:
  USB: Fix 'bad dma' problem on WDM device disconnect.
- patches.drivers/USB3-0191-net-usb-Ethernet-quirks-for-the-LG-VL600-4G-modem.patch:
  net/usb: Ethernet quirks for the LG-VL600 4G modem.
- patches.drivers/USB3-0193-usbnet-use-eth-d-name-for-known-ethernet-devices.patch:
  usbnet: use eth%%d name for known ethernet devices.
- patches.drivers/USB3-0194-usb-serial-fix-function-args-warnings-dropping-filp.patch:
  usb/serial: fix function args warnings, dropping *filp.
- patches.drivers/USB3-0195-net-Add-support-for-SMSC-LAN9530-LAN9730-and-LAN89530.patch:
  net: Add support for SMSC LAN9530, LAN9730 and LAN89530.
- patches.drivers/USB_xhci_fix_OS_want_to_own_HC.patch: Refresh.
* Wed Aug 10 2011 gregkh@suse.de
- more USB 3 updates, .39 patches still.
- Update config files.
- patches.drivers/USB3-0103-USB-host-Move-AMD-PLL-quirk-to-pci-quirks.c.patch:
  USB host: Move AMD PLL quirk to pci-quirks.c.
- patches.drivers/USB3-0105-wusb-fix-find_first_zero_bit-return-value-check.patch:
  wusb: fix find_first_zero_bit() return value check.
- patches.drivers/USB3-0107-USB-Remove-delay_t-unused-variable-from-sierra_ms.c-driver-i.patch:
  USB: Remove delay_t unused variable from sierra_ms.c driver
  initialisation code.
- patches.drivers/USB3-0108-USB-Remove-unused-is_iso-from-fsl_udc_core.c.patch:
  USB: Remove unused is_iso from fsl_udc_core.c.
- patches.drivers/USB3-0109-USB-Remove-unused-timeout-from-io_edgeport.c.patch:
  USB: Remove unused timeout from io_edgeport.c.
- patches.drivers/USB3-0111-USB-move-usbcore-away-from-hcd-state.patch:
  USB: move usbcore away from hcd->state.
- patches.drivers/USB3-0114-USB-OHCI-use-pci_dev-revision.patch:
  USB: OHCI: use pci_dev->revision.
- patches.drivers/USB3-0116-Staging-Merge-ENE-UB6250-SD-card-codes-from-keucr-to-drivers.patch:
  Staging: Merge ENE UB6250 SD card codes from keucr to
  drivers/usb/storage.
- patches.drivers/USB3-0118-USB-serial-option-Apply-OPTION_BLACKLIST_SENDSETUP-also-for-.patch:
  USB: serial: option: Apply OPTION_BLACKLIST_SENDSETUP also
  for ZTE MF626.
- patches.drivers/USB3-0119-USB-serial-ftdi_sio-adding-support-for-OLIMEX-ARM-USB-OCD-H.patch:
  USB: serial: ftdi_sio: adding support for OLIMEX ARM-USB-OCD-H.
- patches.drivers/USB3-0120-ehci-atmel-fix-section-mismatch-warning.patch:
  ehci-atmel: fix section mismatch warning.
- patches.drivers/USB3-0121-USB-Only-treat-lasting-over-current-conditions-as-errors.patch:
  USB: Only treat lasting over-current conditions as errors.
- patches.drivers/USB3-0126-USB-ene_ub6250-fix-memory-leak-in-ene_load_bincode.patch:
  USB: ene_ub6250: fix memory leak in ene_load_bincode().
- patches.drivers/USB3-0127-usb-storage-ene_ub6250-depends-on-USB_STORAGE.patch:
  usb-storage: ene_ub6250 depends on USB_STORAGE.
- patches.drivers/USB3-0128-usb-storage-fix-menu-ordering.patch:
  usb-storage: fix menu ordering.
- patches.drivers/USB3-0130-xhci-Remove-old-no-op-test.patch:
  xhci: Remove old no-op test.
- patches.drivers/USB3-0131-USB-Remove-bitmap-define-from-hcd.h.patch:
  USB: Remove bitmap #define from hcd.h.
- patches.drivers/USB3-0132-USB-Fix-usb_add_hcd-checkpatch-errors.patch:
  USB: Fix usb_add_hcd() checkpatch errors.
- patches.drivers/USB3-0133-xhci-Rework-port-suspend-structures-for-limited-ports.patch:
  xhci: Rework port suspend structures for limited ports.
- patches.drivers/USB3-0134-xhci-Rename-variables-and-reduce-register-reads.patch:
  xhci: Rename variables and reduce register reads.
- patches.drivers/USB3-0135-xHCI-Remove-redundant-variable-in-xhci_resume.patch:
  xHCI: Remove redundant variable in xhci_resume().
- patches.drivers/USB3-0136-xHCI-prolong-host-controller-halt-time-limit.patch:
  xHCI: prolong host controller halt time limit.
- patches.drivers/USB3-0137-xhci-Remove-references-to-HC_STATE_HALT.patch:
  xhci: Remove references to HC_STATE_HALT.
- patches.drivers/USB3-0138-usb-Initialize-hcd-state-roothubs.patch:
  usb: Initialize hcd->state roothubs.
- patches.drivers/USB3-0139-xhci-Remove-references-to-HC_STATE_RUNNING.patch:
  xhci: Remove references to HC_STATE_RUNNING.
- patches.drivers/USB3-0140-USB-3.0-Hub-Changes.patch: USB 3.0
  Hub Changes.
- patches.drivers/USB3-0141-USB-Clear-warm-port-reset-change.patch:
  USB: Clear "warm" port reset change.
- patches.drivers/USB3-0142-usb-Make-USB-3.0-roothub-have-a-SS-EP-comp-descriptor.patch:
  usb: Make USB 3.0 roothub have a SS EP comp descriptor.
- patches.drivers/USB3-0143-xhci-Modify-check-for-TT-info.patch:
  xhci: Modify check for TT info.
- patches.drivers/USB3-0144-xhci-Always-use-usb_hcd-in-URB-instead-of-converting-xhci_hc.patch:
  xhci: Always use usb_hcd in URB instead of converting xhci_hcd.
- patches.drivers/USB3-0145-xhci-Change-hcd_priv-into-a-pointer.patch:
  xhci: Change hcd_priv into a pointer.
- patches.drivers/USB3-0146-usb-Make-usb_hcd_pci_probe-labels-more-descriptive.patch:
  usb: Make usb_hcd_pci_probe labels more descriptive.
- patches.drivers/USB3-0147-usb-Refactor-irq-enabling-out-of-usb_add_hcd.patch:
  usb: Refactor irq enabling out of usb_add_hcd().
- patches.drivers/USB3-0148-usb-Change-usb_hcd-bandwidth_mutex-to-a-pointer.patch:
  usb: Change usb_hcd->bandwidth_mutex to a pointer.
- patches.drivers/USB3-0149-usb-Store-bus-type-in-usb_hcd-not-in-driver-flags.patch:
  usb: Store bus type in usb_hcd, not in driver flags.
- patches.drivers/USB3-0150-usb-Make-core-allocate-resources-per-PCI-device.patch:
  usb: Make core allocate resources per PCI-device.
- patches.drivers/USB3-0151-USB-Set-usb_hcd-state-and-flags-for-shared-roothubs.patch:
  USB: Set usb_hcd->state and flags for shared roothubs.
- patches.drivers/USB3-0152-xhci-Index-with-a-port-array-instead-of-PORTSC-addresses.patch:
  xhci: Index with a port array instead of PORTSC addresses.
- patches.drivers/USB3-0153-xhci-Refactor-bus-suspend-state-into-a-struct.patch:
  xhci: Refactor bus suspend state into a struct.
- patches.drivers/USB3-0154-xhci-Change-xhci_find_slot_id_by_port-API.patch:
  xhci: Change xhci_find_slot_id_by_port() API.
- patches.drivers/USB3-0155-xhci-Register-second-xHCI-roothub.patch:
  xhci: Register second xHCI roothub.
- patches.drivers/USB3-0156-xhci-Return-a-USB-3.0-hub-descriptor-for-USB3-roothub.patch:
  xhci: Return a USB 3.0 hub descriptor for USB3 roothub.
- patches.drivers/USB3-0157-xhci-Limit-roothub-ports-to-15-USB3-31-USB2-ports.patch:
  xhci: Limit roothub ports to 15 USB3 & 31 USB2 ports.
- patches.drivers/USB3-0158-xhci-Make-roothub-functions-deal-with-device-removal.patch:
  xhci: Make roothub functions deal with device removal.
- patches.drivers/USB3-0159-xhci-Fix-re-init-on-power-loss-after-resume.patch:
  xhci: Fix re-init on power loss after resume.
- patches.suse/kdb-common: Refresh.
* Wed Aug 10 2011 gregkh@suse.de
- More USB3 patches
- patches.drivers/USB3-0067-USB-serial-keyspan-Fix-possible-null-pointer-dereference.patch:
  USB: serial: keyspan: Fix possible null pointer dereference.
- patches.drivers/USB3-0068-USB-serial-mos7720-Fix-possible-null-pointer-dereference.patch:
  USB: serial: mos7720: Fix possible null pointer dereference.
- patches.drivers/USB3-0074-USB-use-device-number-instead-of-address.patch:
  USB: use "device number" instead of "address".
- patches.drivers/USB3-0077-USB-serial-drivers-need-to-use-larger-bulk-in-buffers.patch:
  USB: serial drivers need to use larger bulk-in buffers.
- patches.drivers/USB3-0078-USB-fix-unsafe-USB_SS_MAX_STREAMS-definition.patch:
  USB: fix unsafe USB_SS_MAX_STREAMS() definition.
- patches.drivers/USB3-0079-USB-opticon-add-rts-and-cts-support.patch:
  USB: opticon: add rts and cts support.
- patches.drivers/USB3-0080-drivers-usb-wusbhc.h-remove-one-to-many-l-s-in-the-word.patch:
  drivers:usb:wusbhc.h remove one to many l's in the word.
- patches.drivers/USB3-0082-usb-host-uhci-hcd.c-Remove-one-to-many-n-s-in-a-word.patch:
  usb: host: uhci-hcd.c Remove one to many n's in a word.
- patches.drivers/USB3-0083-usb-core-hub.c-Remove-one-to-many-n-s-in-a-word.patch:
  usb: core: hub.c Remove one to many n's in a word.
- patches.drivers/USB3-0091-USB-serial-keyspan_pda-fix-potential-tty-NULL-dereferences.patch:
  USB: serial/keyspan_pda, fix potential tty NULL dereferences.
- patches.suse/kdb-common: Refresh.
* Wed Aug 10 2011 jbeulich@novell.com
- Update Xen patches to 2.6.32.44 and c/s 1102.
- patches.xen/xen-blkfront-hvm-no-cdrom: In HVM guests do not
  take over the CDROM device (bnc#645893).
- patches.xen/xen-x86-mmcfg-ACPI-reserved: x86: report
  ACPI-reserved state of PCI MMCONFIG region to hypervisor.
- patches.xen/xen3-001-cpuidle__fail_to_register_if_CONFIG_CPU_IDLE.patch:
  cpuidle: fail to register if !CONFIG_CPU_IDLE
  (fate#311818,fate#311942).
- patches.xen/xen3-005-intel_idle__native_hardware_cpuidle_driver_for_latest_Intel_processors.patch:
  intel_idle: native hardware cpuidle driver for latest Intel
  processors (fate#311818,fate#311942).
- patches.xen/xen3-0654-drm-ttm-add-pool-wc-uc-page-allocator-V3.patch:
  drm/ttm: add pool wc/uc page allocator V3 (fate#310916).
- patches.xen/xen3-function-graph-x86-replace-unbalanced-ret-with-jmp:
  function-graph/x86: Replace unbalanced ret with jmp.
* Wed Aug 10 2011 duwe@suse.de
- Disable TPMs on power. They don't seem to exist and loading their
  drivers causes Oopses (bnc#711297)
* Wed Aug 10 2011 gregkh@suse.de
- some tty patches needed for the USB 3 code (well, for the drivers)
- patches.drivers/USB3-0056-tiocmget-kill-off-the-passing-of-the-struct-file.patch:
  tiocmget: kill off the passing of the struct file.
- patches.drivers/USB3-0057-tiocmset-kill-the-file-pointer-argument.patch:
  tiocmset: kill the file pointer argument.
- patches.drivers/USB3-0058-tty-remove-filp-from-the-USB-tty-ioctls.patch:
  tty: remove filp from the USB tty ioctls.
- patches.drivers/USB3-0059-tty-now-phase-out-the-ioctl-file-pointer-for-good.patch:
  tty: now phase out the ioctl file pointer for good.
* Wed Aug 10 2011 gregkh@suse.de
- USB 3 update .38 -> .39, first portion
- Update config files.
- patches.drivers/USB3-0001-USB-add-helper-to-convert-USB-error-codes.patch:
  USB: add helper to convert USB error codes.
- patches.drivers/USB3-0002-USB-Core-Fix-minor-coding-style-issues.patch:
  USB: Core: Fix minor coding style issues.
- patches.drivers/USB3-0003-USB-wusbcore-rh.c-Typo-change-desciptor-to-descriptor.patch:
  USB: wusbcore: rh.c Typo change desciptor to descriptor.
- patches.drivers/USB3-0004-USB-ehci-dbgp-fix-typo-in-startup-message.patch:
  USB: ehci-dbgp: fix typo in startup message.
- patches.drivers/USB3-0006-USB-ftdi_sio-fix-resolution-of-2232H-baud-rate-dividers.patch:
  USB: ftdi_sio: fix resolution of 2232H baud rate dividers.
- patches.drivers/USB3-0007-USB-usb_storage-add-ums-realtek-driver.patch:
  USB: usb_storage: add ums-realtek driver.
- patches.drivers/USB3-0008-USB-usbtest-Add-tests-to-ensure-HCDs-can-accept-byte-aligned.patch:
  USB: usbtest - Add tests to ensure HCDs can accept byte
  aligned buffers.
- patches.drivers/USB3-0012-USB-serial-mct_u232-added-_ioctl-_msr_to_icount-and-_get_ico.patch:
  USB: serial: mct_u232: added _ioctl, _msr_to_icount and
  _get_icount functions.
- patches.drivers/USB3-0015-USB-host-Move-AMD-PLL-quirk-to-pci-quirks.c.patch:
  USB host: Move AMD PLL quirk to pci-quirks.c.
- patches.drivers/USB3-0016-USB-EHCI-Remove-dead-code-from-ehci-sched.c.patch:
  USB: EHCI: Remove dead code from ehci-sched.c.
- patches.drivers/USB3-0017-USB-EHCI-Cleanup-and-rewrite-ehci_vdgb.patch:
  USB: EHCI: Cleanup and rewrite ehci_vdgb().
- patches.drivers/USB3-0018-USB-EHCI-Rearrange-EHCI_URB_TRACE-code-to-avoid-GCC-4.6-warn.patch:
  USB: EHCI: Rearrange EHCI_URB_TRACE code to avoid GCC-4.6
  warnings.
- patches.drivers/USB3-0019-USB-EHCI-Rearrange-create_companion_file-to-avoid-GCC-4.6-wa.patch:
  USB: EHCI: Rearrange create_companion_file() to avoid GCC-4.6
  warnings.
- patches.drivers/USB3-0020-USB-usbmon-fix-up-docs-and-text-API-for-sparse-ISO.patch:
  USB: usbmon: fix-up docs and text API for sparse ISO.
- patches.drivers/USB3-0021-USB-HCD-Add-usb_hcd-prefix-to-exported-functions.patch:
  USB: HCD: Add usb_hcd prefix to exported functions.
- patches.drivers/USB3-0022-USB-HCD-Add-driver-hooks-for-un-map_urb_for_dma.patch:
  USB: HCD: Add driver hooks for (un)?map_urb_for_dma.
- patches.drivers/USB3-0027-Revert-USB-host-Move-AMD-PLL-quirk-to-pci-quirks.c.patch:
  Revert "USB host: Move AMD PLL quirk to pci-quirks.c".
- patches.drivers/USB3-0033-USB-Mark-EHCI-LPM-functions-as-__maybe_unused.patch:
  USB: Mark EHCI LPM functions as __maybe_unused.
- patches.drivers/USB3-0034-USB-isp1760-Implement-solution-for-erratum-2.patch:
  USB: isp1760: Implement solution for erratum 2.
- patches.drivers/USB3-0036-usb_wwan-fix-error-in-marking-device-busy.patch:
  usb_wwan: fix error in marking device busy.
- patches.drivers/USB3-0037-usb_wwan-fix-runtime-PM-in-error-case.patch:
  usb_wwan: fix runtime PM in error case.
- patches.drivers/USB3-0038-usb_wwan-data-consistency-in-error-case.patch:
  usb_wwan: data consistency in error case.
- patches.drivers/USB3-0039-usb_wwan-error-case-of-resume.patch:
  usb_wwan: error case of resume.
- patches.drivers/USB3-0040-usb_wwan-fix-error-case-in-close.patch:
  usb_wwan: fix error case in close().
- patches.drivers/USB3-0041-USB-sierra-error-handling-in-runtime-PM.patch:
  USB: sierra: error handling in runtime PM.
- patches.drivers/USB3-0042-USB-usb.h-Make-comment-match-the-defines-it-describes.patch:
  USB: usb.h: Make comment match the defines it describes.
- patches.drivers/USB3-0043-usb_storage-realtek_cr-patch-fix-sparse-warning.patch:
  usb_storage: realtek_cr patch: fix sparse warning.
- patches.drivers/USB3-0044-usb_storage-realtek_cr-patch-add-const-modifier.patch:
  usb_storage: realtek_cr patch: add const modifier.
- patches.drivers/USB3-0047-USB-don-t-run-ehci_reset-in-ehci_run-for-tdi-device.patch:
  USB: don't run ehci_reset in ehci_run for tdi device.
* Tue Aug  9 2011 dsterba@suse.cz
- patches.suse/btrfs-truncate-pages-from-clone-ioctl-target-range.patch:
  Btrfs: truncate pages from clone ioctl target range
  (bnc#698540).
* Tue Aug  9 2011 mfasheh@suse.com
- patches.suse/0001-btrfs-Don-t-BUG_ON-errors-from-btrfs_create_subvol_r.patch:
  Refresh.
- patches.suse/0001-btrfs-Handle-NULL-inode-return-from-btrfs_lookup_den.patch:
  Refresh.
- patches.suse/0001-btrfs-don-t-BUG_ON-btrfs_alloc_path-errors.patch:
  Refresh.
- patches.suse/0002-btrfs-Don-t-BUG_ON-alloc_path-errors-in-replay_one_b.patch:
  Refresh.
- patches.suse/0003-btrfs-Don-t-BUG_ON-alloc_path-errors-in-btrfs_trunca.patch:
  Refresh.
- patches.suse/0004-btrfs-Don-t-BUG_ON-alloc_path-errors-in-btrfs_read_l.patch:
  Refresh.
- patches.suse/0005-btrfs-Don-t-BUG_ON-alloc_path-errors-in-btrfs_balanc.patch:
  Refresh.
- patches.suse/0006-btrfs-Don-t-BUG_ON-alloc_path-errors-in-find_next_ch.patch:
  Refresh.
- patches.suse/0007-btrfs-don-t-BUG_ON-allocation-errors-in-btrfs_drop_s.patch:
  Refresh.
* Tue Aug  9 2011 dsterba@suse.cz
- patches.suse/btrfs-reserve-sufficient-space-for-ioctl-clone.patch:
  Btrfs: reserve sufficient space for ioctl clone (bnc#698540).
- patches.suse/patches.suse/btrfs-reserve-sufficient-space-for-ioctl-clone.patch:
  enable, previous patch fixes the crash.
* Mon Aug  8 2011 jslaby@suse.de
- Update to 2.6.32.44
- patches.arch/x86_64-hpet-64bit-timer.patch: Refresh.
- patches.drivers/cciss-update-to-3.6.26.patch: Refresh.
- patches.drivers/cciss-update-to-4.6.28.patch: Refresh.
- patches.fixes/sched-rtsched_debug-boot-option.patch: Refresh.
- patches.suse/cifs-064-add-separate-cred_uid-field-to-sesInfo.patch:
  Refresh.
- patches.suse/cifs-150-convert-cifs_tcp_ses_lock-from-a-rwlock-to-a-sp.patch:
  Refresh.
- patches.suse/perf-allow-for-custom-overflow-handlers: Refresh.
- patches.xen/kexec-move-segment-code-i386.patch: Refresh.
- patches.xen/kexec-move-segment-code-x86_64.patch: Refresh.
- patches.arch/x86-hpet-pre-read: Delete.
- patches.drivers/USB3-0203-USB-pl2303.h-checkpatch-cleanups.patch:
  Delete.
- patches.drivers/USB3-0314-USB-pl2303-add-AdLink-ND-6530-USB-IDs.patch:
  Delete.
- patches.fixes/cifs-ensure-credentials-match-when-using-existing-session:
  Delete.
- patches.fixes/gre-fix-netns-vs-proto-registration-ordering:
  Delete.
- patches.fixes/proc-restrict-access-to-proc-pid-io: Delete.
- patches.fixes/ses-requesting-a-fault-indication: Delete.
- patches.fixes/tunnels-fix-netns-vs-proto-registration-ordering:
  Delete.
- patches.suse/cifs-052-clean-up-cifs_find_smb_ses-try-2.patch:
  Delete.
* Mon Aug  8 2011 mmarek@suse.cz
- patches.suse/0004-netdev-ethtool-RXHASH-flag: Delete (bnc#710969).
- patches.drivers/cxgb4-chelsio-t4-driver-compat: Refresh.
- patches.suse/0005-ethtool-Add-support-for-vlan-accleration:
  Refresh.
* Mon Aug  8 2011 mgalbraith@suse.de
- Fix rtsched_debug "Danger Will Robinson" warnings to only
  be emitted if the current task is still a realtime task.
  This will not be the case once the runqueue is throttled,
  which led to false "potential runaway" warnings pointing
  the finger at SCHED_OTHER tasks which had been given the
  CPU while the realtime hog waits for runtime refill.
- patches.fixes/sched-rtsched_debug-boot-option.patch: Refresh.
* Mon Aug  8 2011 trenn@suse.de
  Remove arch/x86/kernel/traps.c parts (bnc#708720):
- patches.drivers/001-apei_infrastructure.patch: Refresh.
* Sun Aug  7 2011 tiwai@suse.de
- rpm/kernel-binary.spec.in: obsoletes drm-kmp <= 3.0
* Sun Aug  7 2011 tiwai@suse.de
- patches.drm/drm-033-i915-Fix-typo-in-DRM_I915_OVERLAY_PUT_IMAGE-ioctl:
  drm/i915: Fix typo in DRM_I915_OVERLAY_PUT_IMAGE ioctl define.
- patches.drm/drm-034-i915-Initialize-RCS-ring-status-page-address-in:
  drm/i915: Initialize RCS ring status page address in
  intel_render_ring_init_dri.
- patches.drm/drm-035-i915-load-the-LUT-before-pipe-enable-on-ILK:
  drm/i915: load the LUT before pipe enable on ILK+.
- patches.drm/drm-036-i915-Hold-mode_config-mutex-during-hotplug-procedure:
  drm/i915: Hold mode_config->mutex during hotplug processing.
- patches.drm/drm-037-i915-pch-Fix-integer-math-bugs-in-panel-fitting:
  drm/i915/pch: Fix integer math bugs in panel fitting.
- patches.drm/drm-038-Separate-EDID-Header-Check-from-EDID-Block-Check:
  drm: Separate EDID Header Check from EDID Block Check.
- patches.drm/drm-039-radeon-Extended-DDC-Probing-for-Connectors-with:
  drm/radeon: Extended DDC Probing for Connectors with Improperly
  Wired DDC Lines (here: Asus M2A-VM HDMI).
- patches.drm/drm-040-radeon-Log-Subsystem-Vendor-and-Device-Information:
  drm/radeon: Log Subsystem Vendor and Device Information.
- patches.drm/drm-041-radeon-Extended-DDC-Probing-for-ECS-A740GM-M-DVI:
  drm/radeon: Extended DDC Probing for ECS A740GM-M DVI-D
  Connector.
* Sat Aug  6 2011 jslaby@suse.de
- patches.drivers/coredump-04-use-task-comm-instead-of-unknown.patch:
  coredump: use task comm instead of (unknown) (bnc#710868
  fate#309473).
- patches.drivers/coredump-05-escape-in-hostname-and-comm.patch:
  coredump: escape / in hostname and comm (bnc#710868
  fate#309473).
- patches.drivers/coredump-06-do_coredump-fix-the-ispipe-error-check.patch:
  do_coredump: fix the "ispipe" error check (bnc#710868
  fate#309473).
* Sat Aug  6 2011 jslaby@suse.de
- patches.drivers/intr-remap-allow-disabling-source-id-checking.patch:
  intr-remap: allow disabling source id checking (bnc#710352).
* Sat Aug  6 2011 gregkh@suse.de
- patches.drivers/USB3-0059-USB-CDC-NCM-host-driver.patch:
  fix build error in that linux/asm.h is not a file.
* Fri Aug  5 2011 gregkh@suse.de
- USB 3.0 update .37->.38 patchset
- Update config files.
- patches.drivers/USB3-0002-usb-ohci-sh-Set-IRQ-as-shared.patch:
  usb: ohci-sh: Set IRQ as shared.
- patches.drivers/USB3-0004-drivers-net-usb-Update-WARN-uses.patch:
  drivers/net/usb: Update WARN uses.
- patches.drivers/USB3-0005-Staging-beceem-Move-ZTE-TU25-s-USB-id-to-the-beceem-module.patch:
  Staging: beceem: Move ZTE TU25's USB id to the beceem module.
- patches.drivers/USB3-0006-USB-ssu100-remove-max_packet_size-calculation.patch:
  USB: ssu100: remove max_packet_size calculation.
- patches.drivers/USB3-0016-usb-USB3.0-ch11-definitions.patch:
  usb: USB3.0 ch11 definitions.
- patches.drivers/USB3-0017-usb-dummy_hcd-code-simplification.patch:
  usb: dummy_hcd code simplification.
- patches.drivers/USB3-0020-hso-Fix-unused-variable-warning.patch:
  hso: Fix unused variable warning.
- patches.drivers/USB3-0022-drivers-usb-host-uhci-hcd.c-Remove-unnecessary-casts-of-pci_.patch:
  drivers/usb/host/uhci-hcd.c: Remove unnecessary casts of
  pci_get_drvdata.
- patches.drivers/USB3-0032-drivers-net-usb-Remove-unnecessary-casts-of-netdev_priv.patch:
  drivers/net/usb: Remove unnecessary casts of netdev_priv.
- patches.drivers/USB3-0034-USB-ce4100-Add-support-for-CE4100-EHCI-IP-block-to-EHCI-driv.patch:
  USB: ce4100: Add support for CE4100 EHCI IP block to EHCI
  driver.
- patches.drivers/USB3-0044-usbmon-correct-length-for-isochronous.patch:
  usbmon: correct length for isochronous.
- patches.drivers/USB3-0045-USB-Remove-unnecessary-casts-of-void-ptr-returning-alloc-fun.patch:
  USB: Remove unnecessary casts of void ptr returning alloc
  function return values.
- patches.drivers/USB3-0046-usb-wwan-implement-TIOCGSERIAL-and-TIOCSSERIAL-to-avoid-bloc.patch:
  usb-wwan: implement TIOCGSERIAL and TIOCSSERIAL to avoid
  blocking close(2).
- patches.drivers/USB3-0058-usbnet-changes-for-upcoming-cdc_ncm-driver.patch:
  usbnet: changes for upcoming cdc_ncm driver.
- patches.drivers/USB3-0059-USB-CDC-NCM-host-driver.patch:
  USB CDC NCM host driver.
- patches.drivers/USB3-0096-USB-whci-hcd-fix-compiler-warning.patch:
  USB: whci-hcd: fix compiler warning.
- patches.drivers/USB3-0098-USB-host-uhci-q-Fixed-minor-coding-style-issues.patch:
  USB: host: uhci-q: Fixed minor coding style issues.
- patches.drivers/USB3-0101-USB-serial-usb_wwan-Add-missing-uaccess.h-fix-build-failure.patch:
  USB: serial: usb_wwan: Add missing uaccess.h / fix build
  failure.
- patches.drivers/USB3-0123-USB-uas-Fix-up-the-Sense-IU.patch:
  USB: uas: Fix up the Sense IU.
- patches.drivers/USB3-0124-USB-uas-Use-kzalloc-instead-of-kmalloc.patch:
  USB: uas: Use kzalloc instead of kmalloc.
- patches.drivers/USB3-0125-USB-uas-Rename-sense-pipe-and-sense-urb-to-status-pipe-and-s.patch:
  USB: uas: Rename sense pipe and sense urb to status pipe and
  status urb.
- patches.drivers/USB3-0126-USB-uas-Ensure-we-only-bind-to-a-UAS-interface.patch:
  USB: uas: Ensure we only bind to a UAS interface.
- patches.drivers/USB3-0127-USB-uas-Use-GFP_NOIO-instead-of-GFP_KERNEL-in-I-O-submission.patch:
  USB: uas: Use GFP_NOIO instead of GFP_KERNEL in I/O submission
  path.
- patches.drivers/USB3-0138-USB-serial-ftdi_sio-add-support-for-TIOCSERGETLSR.patch:
  USB: serial: ftdi_sio: add support for TIOCSERGETLSR.
- patches.drivers/USB3-0140-usb-Use-static-const-consolidate-code.patch:
  usb: Use static const, consolidate code.
- patches.drivers/USB3-0143-speedtch-don-t-abuse-struct-delayed_work.patch:
  speedtch: don't abuse struct delayed_work.
- patches.drivers/USB3-0145-USB-cdc_ether-remove-unneeded-check.patch:
  USB: cdc_ether: remove unneeded check.
- patches.drivers/USB3-0152-USB-CDC-NCM-Don-t-deref-NULL-in-cdc_ncm_rx_fixup-and-don-t-u.patch:
  USB CDC NCM: Don't deref NULL in cdc_ncm_rx_fixup() and don't
  use uninitialized variable.
- patches.drivers/USB3-0153-xhci-Resume-bus-on-any-port-status-change.patch:
  xhci: Resume bus on any port status change.
- patches.drivers/USB3-0154-xHCI-synchronize-irq-in-xhci_suspend.patch:
  xHCI: synchronize irq in xhci_suspend().
- patches.drivers/USB3-0155-xhci-Do-not-run-xhci_cleanup_msix-with-irq-disabled.patch:
  xhci: Do not run xhci_cleanup_msix with irq disabled.
- patches.drivers/USB3-0157-xhci-Use-GFP_NOIO-during-device-reset.patch:
  xhci: Use GFP_NOIO during device reset.
- patches.drivers/USB3-0158-xHCI-fix-queue_trb-in-isoc-transfer.patch:
  xHCI: fix queue_trb in isoc transfer.
- patches.drivers/USB3-0159-xHCI-remove-redundant-parameter-in-giveback_first_trb.patch:
  xHCI: remove redundant parameter in giveback_first_trb().
- patches.drivers/USB3-0160-xHCI-fix-cycle-bit-set-in-giveback_first_trb.patch:
  xHCI: fix cycle bit set in giveback_first_trb().
- patches.drivers/USB3-0161-xHCI-replace-dev_dbg-with-xhci_dbg.patch:
  xHCI: replace dev_dbg() with xhci_dbg().
- patches.drivers/USB3-0162-xHCI-fix-printk_ratelimit-usage.patch:
  xHCI: fix printk_ratelimit() usage.
- patches.drivers/USB3-0163-xhci-Remove-more-doorbell-related-reads.patch:
  xhci: Remove more doorbell-related reads.
- patches.drivers/USB3-0164-USB-CDC-NCM-tx_fixup-race-condition-fix.patch:
  USB CDC NCM: tx_fixup() race condition fix.
- patches.drivers/USB3-0168-USB-qcaux-add-Pantech-UML290-device-ID.patch:
  USB: qcaux: add Pantech UML290 device ID.
- patches.drivers/USB3-0175-USB-cdc-wdm-fix-misuse-of-logical-operation-in-place-of-bito.patch:
  USB: cdc-wdm: fix misuse of logical operation in place of bitop.
- patches.drivers/USB3-0181-USB-uss720-remove-duplicate-USB-device.patch:
  USB: uss720: remove duplicate USB device.
- patches.drivers/USB3-0185-USB-serial-add-missing-.usb_driver-field-in-serial-drivers.patch:
  USB serial: add missing .usb_driver field in serial drivers.
- patches.drivers/USB3-0196-USB-NET-KL5KUSB101-Fix-mem-leak-in-error-path-of-kaweth_down.patch:
  USB NET KL5KUSB101: Fix mem leak in error path of
  kaweth_download_firmware().
- patches.drivers/USB3-0206-USB-SL811HS-HCD-Fix-memory-leak-in-sl811h_urb_enqueue.patch:
  USB SL811HS HCD: Fix memory leak in sl811h_urb_enqueue().
- patches.drivers/USB3-0218-CDC-NCM-errata-updates-for-cdc.h.patch:
  CDC NCM errata updates for cdc.h.
- patches.drivers/USB3-0219-USB-CDC-NCM-errata-updates-for-cdc_ncm-host-driver.patch:
  USB CDC NCM errata updates for cdc_ncm host driver.
- patches.drivers/USB3-0220-USB-Network-driver-infrastructure-Fix-leak-when-usb_autopm_g.patch:
  USB Network driver infrastructure: Fix leak when
  usb_autopm_get_interface() returns less than zero in kevent().
- patches.drivers/USB3-0221-Net-USB-Option-hso-Do-not-dereference-NULL-pointer.patch:
  Net, USB, Option, hso: Do not dereference NULL pointer.
- patches.drivers/USB3-0227-USB-Reset-USB-3.0-devices-on-re-discovery.patch:
  USB: Reset USB 3.0 devices on (re)discovery.
- patches.drivers/USB3-0228-USB-serial-usb_wwan-fix-tty-NULL-dereference.patch:
  USB: serial/usb_wwan, fix tty NULL dereference.
- patches.drivers/USB3-0231-Revert-USB-Reset-USB-3.0-devices-on-re-discovery.patch:
  Revert "USB: Reset USB 3.0 devices on (re)discovery".
- patches.drivers/USB3-0236-USB-Reset-USB-3.0-devices-on-re-discovery.patch:
  USB: Reset USB 3.0 devices on (re)discovery.
- patches.drivers/USB3-0237-USB-xhci-rework-xhci_print_ir_set-to-get-ir-set-from-xhci-it.patch:
  USB: xhci: rework xhci_print_ir_set() to get ir set from
  xhci itself.
- patches.drivers/USB3-0238-USB-xhci-fix-couple-sparse-annotations.patch:
  USB: xhci: fix couple sparse annotations.
- patches.drivers/USB3-0239-USB-xhci-mark-local-functions-as-static.patch:
  USB: xhci: mark local functions as static.
- patches.drivers/USB3-0240-Added-support-for-usb-ethernet-0x0fe6-0x9700.patch:
  Added support for usb ethernet (0x0fe6, 0x9700).
- patches.drivers/USB3-0242-f_phonet-avoid-pskb_pull-fix-OOPS-with-CONFIG_HIGHMEM.patch:
  f_phonet: avoid pskb_pull(), fix OOPS with CONFIG_HIGHMEM.
- patches.suse/kdb-common: Refresh.
* Fri Aug  5 2011 ohering@suse.de
- disable CONFIG_HYPERV_MOUSE, hv_mouse still broken (bnc#710790)
* Fri Aug  5 2011 tiwai@suse.de
- Update config files: Enable radeon KMS for i386 and x86-64
* Fri Aug  5 2011 gregkh@suse.de
- move a patch higher up the series to let things build properly:
- patches.suse/kernel.h-add-pr_warn-for-symmetry-to-dev_warn-netdev.patch:
  kernel.h: add pr_warn for symmetry to dev_warn, netdev_warn
  (FATE#309728, FATE#309730, BNC#686840).
- patches.suse/oprofile-026-kernel.h-add-pr_warn-for-symmetry-to-dev_warn-netdev.patch:
  Delete.
* Fri Aug  5 2011 gregkh@suse.de
- patches.drivers/USB3-0124-scsi-sd-add-a-no_read_capacity_16-scsi_device-flag.patch:
  Refresh to fix build error in sd.ko that was fixed up in a kernel merge commit, no wonder I missed it...
* Fri Aug  5 2011 gregkh@suse.de
- USB 3 update, final .36->.37 patches
- patches.drivers/0001-V4L-DVB-uvc-Enable-USB-autosuspend-by-default-on-uvc.patch:
  Refresh.
- patches.drivers/USB3-0094-usb-musb-host-unmap-the-buffer-for-PIO-data-transfers.patch:
  usb: musb: host: unmap the buffer for PIO data transfers.
- patches.drivers/USB3-0102-usb-change-to-new-flag-variable.patch:
  usb: change to new flag variable.
- patches.drivers/USB3-0103-USB-cdc-acm-fix-code-indentation.patch:
  USB: cdc-acm: fix code indentation.
- patches.drivers/USB3-0104-USB-Add-more-empty-functions-in-otg.h.patch:
  USB: Add more empty functions in otg.h.
- patches.drivers/USB3-0111-USB-UHCI-add-native-scatter-gather-support-v1.patch:
  USB: UHCI: add native scatter-gather support(v1).
- patches.drivers/USB3-0115-USB-EHCI-remove-PCI-assumption.patch:
  Refresh.
- patches.drivers/USB3-0115-USB-usbtest-fix-coding-style.patch:
  USB: usbtest fix coding style.
- patches.drivers/USB3-0116-USB-EHCI-simplify-remainder-computations.patch:
  Refresh.
- patches.drivers/USB3-0116-USB-usbtest-ensure-correct-isoc-data-length.patch:
  USB: usbtest - ensure correct isoc data length.
- patches.drivers/USB3-0117-USB-EHCI-add-missing-frame-microframe-conversion.patch:
  Refresh.
- patches.drivers/USB3-0118-USB-EHCI-reorganize-isochronous-scheduler-routine.patch:
  Refresh.
- patches.drivers/USB3-0119-USB-EHCI-remove-dead-code-in-the-periodic-scheduler.patch:
  Refresh.
- patches.drivers/USB3-0120-USB-introduce-unmap_urb_setup_for_dma.patch:
  USB: introduce unmap_urb_setup_for_dma().
- patches.drivers/USB3-0123-scsi-sr-add-no_read_disc_info-scsi_device-flag.patch:
  scsi/sr: add no_read_disc_info scsi_device flag.
- patches.drivers/USB3-0123-usb-storage-add-new-no_read_disc_info-quirk.patch:
  usb-storage: add new no_read_disc_info quirk.
- patches.drivers/USB3-0124-scsi-sd-add-a-no_read_capacity_16-scsi_device-flag.patch:
  scsi/sd: add a no_read_capacity_16 scsi_device flag.
- patches.drivers/USB3-0124-usb-storage-add-new-no_read_capacity_16-quirk.patch:
  usb-storage: add new no_read_capacity_16 quirk.
- patches.drivers/USB3-0127-usb-core-endpoint-Fix-error-path.patch:
  usb: core: endpoint: Fix error path.
- patches.drivers/USB3-0129-usb-makefile-cleanup.patch: usb:
  makefile cleanup.
- patches.drivers/USB3-0131-usb-usb3.0-ch9-definitions.patch:
  usb: usb3.0 ch9 definitions.
- patches.drivers/USB3-0133-USB-visor-fix-initialisation-of-UX50-TH55-devices.patch:
  USB: visor: fix initialisation of UX50/TH55 devices.
- patches.drivers/USB3-0135-USB-ftdi_sio-set-device-latency-timeout-at-port-probe.patch:
  USB: ftdi_sio: set device latency timeout at port probe.
- patches.drivers/USB3-0137-USB-opticon-Add-Opticon-OPN2001-write-support.patch:
  USB: opticon: Add Opticon OPN2001 write support.
- patches.drivers/USB3-0138-USB-opticon-Whitespace-fixes-in-opticon-driver.patch:
  USB: opticon: Whitespace fixes in opticon driver.
- patches.drivers/USB3-0142-USB-xHCI-Add-pointer-to-udev-in-struct-xhci_virt_device.patch:
  USB: xHCI: Add pointer to udev in struct xhci_virt_device.
- patches.drivers/USB3-0143-USB-xHCI-change-xhci_reset_device-to-allocate-new-device.patch:
  USB: xHCI: change xhci_reset_device() to allocate new device.
- patches.drivers/USB3-0144-USB-core-use-kernel-assigned-address-for-devices-under-xHCI.patch:
  USB: core: use kernel assigned address for devices under xHCI.
- patches.drivers/USB3-0145-usb-Fix-issue-with-USB-3.0-devices-after-system-resume.patch:
  usb: Fix issue with USB 3.0 devices after system resume.
- patches.drivers/USB3-0146-USB-xHCI-port-power-management-implementation.patch:
  USB: xHCI: port power management implementation.
- patches.drivers/USB3-0147-USB-xHCI-port-remote-wakeup-implementation.patch:
  USB: xHCI: port remote wakeup implementation.
- patches.drivers/USB3-0148-USB-xHCI-bus-power-management-implementation.patch:
  USB: xHCI: bus power management implementation.
- patches.drivers/USB3-0149-USB-xHCI-PCI-power-management-implementation.patch:
  USB: xHCI: PCI power management implementation.
- patches.drivers/USB3-0151-USB-xhci-Fix-compile-error-when-CONFIG_PM-n.patch:
  USB: xhci: Fix compile error when CONFIG_PM=n.
- patches.drivers/USB3-0152-USB-isp116x-hcd-use-resource_size-instead-of-defining-its-ow.patch:
  USB: isp116x-hcd - use resource_size instead of defining its
  own resource_len macro.
- patches.drivers/USB3-0153-USB-isp1362-hcd-use-resource_size-instead-of-defining-its-ow.patch:
  USB: isp1362-hcd - use resource_size instead of defining its
  own resource_len macro.
- patches.drivers/USB3-0154-USB-ohci-sh-use-resource_size-instead-of-defining-its-own-re.patch:
  USB: ohci-sh - use resource_size instead of defining its own
  resource_len macro.
- patches.drivers/USB3-0155-usb-Fix-linker-errors-with-CONFIG_PM-n.patch:
  usb: Fix linker errors with CONFIG_PM=n.
- patches.drivers/USB3-0159-USB-ehci-fix-remove-of-ehci-debugfs-dir.patch:
  Refresh.
- patches.drivers/USB3-0164-USB-mct_u232-fix-broken-close.patch:
  USB: mct_u232: fix broken close.
- patches.drivers/USB3-0171-usbnet-fix-usb_autopm_get_interface-failure-v1.patch:
  usbnet: fix usb_autopm_get_interface failure(v1).
- patches.drivers/USB3-0185-usb.h-fix-ioctl-kernel-doc-info.patch:
  usb.h: fix ioctl kernel-doc info.
- patches.drivers/USB3-0192-USB-xhci-Use-GFP_ATOMIC-under-spin_lock.patch:
  USB: xhci: Use GFP_ATOMIC under spin_lock.
- patches.drivers/USB3-0194-usb-subtle-increased-memory-usage-in-u_serial.patch:
  usb: subtle increased memory usage in u_serial.
- patches.drivers/USB3-0199-Revert-USB-xhci-Use-GFP_ATOMIC-under-spin_lock.patch:
  Revert "USB: xhci: Use GFP_ATOMIC under spin_lock".
- patches.drivers/USB3-0200-xhci-Remove-excessive-printks-with-shared-IRQs.patch:
  xhci: Remove excessive printks with shared IRQs.
- patches.drivers/USB3-0201-xHCI-release-spinlock-when-setup-interrupt.patch:
  xHCI: release spinlock when setup interrupt.
- patches.drivers/USB3-0202-xHCI-fix-wMaxPacketSize-mask.patch:
  xHCI: fix wMaxPacketSize mask.
- patches.drivers/USB3-0203-xhci-Fix-command-ring-replay-after-resume.patch:
  xhci: Fix command ring replay after resume.
- patches.drivers/USB3-0205-USB-ehci-fix-debugfs-lpm-permissions.patch:
  USB: ehci: fix debugfs 'lpm' permissions.
- patches.drivers/USB3-0213-USB-EHCI-AMD-periodic-frame-list-table-quirk.patch:
  USB: EHCI: AMD periodic frame list table quirk.
- patches.drivers/USB3-0214-USB-isp1362-hcd-fix-section-mismatch-warning.patch:
  USB: isp1362-hcd - fix section mismatch warning.
- patches.drivers/USB3-0218-xhci-Fix-reset-device-and-configure-endpoint-commands.patch:
  xhci: Fix reset-device and configure-endpoint commands.
- patches.drivers/USB3-0219-xhci-Setup-array-of-USB-2.0-and-USB-3.0-ports.patch:
  xhci: Setup array of USB 2.0 and USB 3.0 ports.
- patches.drivers/USB3-0220-xhci-Don-t-let-the-USB-core-disable-SuperSpeed-ports.patch:
  xhci: Don't let the USB core disable SuperSpeed ports.
- patches.drivers/USB3-0225-hso-fix-disable_net.patch: hso:
  fix disable_net.
- patches.drivers/USB3-0227-USB-yurex-add-.llseek-fop-to-file_operations.patch:
  USB: yurex: add .llseek fop to file_operations.
- patches.drivers/USB3-0229-USB-ehci-disable-LPM-and-PPCD-for-nVidia-MCP89-chips.patch:
  USB: ehci: disable LPM and PPCD for nVidia MCP89 chips.
- patches.drivers/USB3-0230-USB-fix-autosuspend-bug-in-usb-serial.patch:
  USB: fix autosuspend bug in usb-serial.
- patches.drivers/USB3-0231-USB-EHCI-Disable-langwell-penwell-LPM-capability.patch:
  Refresh.
- patches.drivers/USB3-0231-xhci-Fix-issue-with-port-array-setup-and-buggy-hosts.patch:
  xhci: Fix issue with port array setup and buggy hosts.
- patches.drivers/USB3-0232-hso-IP-checksuming-doesn-t-work-on-GE0301-option-cards.patch:
  hso: IP checksuming doesn't work on GE0301 option cards.
- patches.drivers/USB3-0240-asix-add-USB-ID-for-Logitec-LAN-GTJ-U2A.patch:
  asix: add USB ID for Logitec LAN-GTJ U2A.
- patches.drivers/USB3-0241-net-Add-USB-PID-for-new-MOSCHIP-USB-ethernet-controller-MCS7.patch:
  net: Add USB PID for new MOSCHIP USB ethernet controller
  MCS7832 variant.
- patches.drivers/USB3-0242-USB-mcs7830-return-negative-if-auto-negotiate-fails.patch:
  USB: mcs7830: return negative if auto negotiate fails.
- patches.drivers/USB_xhci_fix_OS_want_to_own_HC.patch: Refresh.
- patches.fixes/usb-ehci-amd-periodic-frame-list-table-quirk.patch:
  Delete.
* Thu Aug  4 2011 rgoldwyn@suse.de
- patches.fixes/qla2xxx-skip-msix-correction.diff: Skip MSI-X
  for qla2xxx (bnc#693513).
* Thu Aug  4 2011 gregkh@suse.de
- first half of USB3 .36->.37 patchset
- Update config files.
- patches.drivers/USB3-0002-drivers-usb-Remove-unnecessary-return-s-from-void-functions.patch:
  drivers/usb: Remove unnecessary return's from void functions.
- patches.drivers/USB3-0004-Revert-drivers-usb-Remove-unnecessary-return-s-from-void-fun.patch:
  Revert "drivers/usb: Remove unnecessary return's from void
  functions" partially.
- patches.drivers/USB3-0005-introduce-cx82310_eth-Conexant-CX82310-based-ADSL-router-USB.patch:
  introduce cx82310_eth: Conexant CX82310-based ADSL router USB
  ethernet driver.
- patches.drivers/USB3-0006-cxacru-ignore-cx82310_eth-devices.patch:
  cxacru: ignore cx82310_eth devices.
- patches.drivers/USB3-0007-cx82310_eth-check-usb_string-return-value-for-error.patch:
  cx82310_eth: check usb_string() return value for error.
- patches.drivers/USB3-0008-cx82310_eth-allow-empty-URBs.patch:
  cx82310_eth: allow empty URBs.
- patches.drivers/USB3-0009-usb-Fix-up-r8a66597-hcd-section-mismatches.patch:
  usb: Fix up r8a66597-hcd section mismatches.
- patches.drivers/USB3-0020-Revert-drivers-usb-Remove-unnecessary-return-s-from-void-fun.patch:
  Revert "drivers/usb: Remove unnecessary return's from void
  functions" for musb gadget.
- patches.drivers/USB3-0021-ARM-ohci-pxa27x-enable-OHCI-over-U2DC-for-pxa3xx.patch:
  ARM: ohci-pxa27x: enable OHCI over U2DC for pxa3xx.
- patches.drivers/USB3-0025-smsc95xx-generate-random-MAC-address-once-not-every-ifup.patch:
  smsc95xx: generate random MAC address once, not every ifup.
- patches.drivers/USB3-0026-tty-Make-tiocgicount-a-handler.patch:
  tty: Make tiocgicount a handler.
- patches.drivers/USB3-0027-tty-Convert-the-USB-drivers-to-the-new-icount-interface.patch:
  tty: Convert the USB drivers to the new icount interface.
- patches.drivers/USB3-0028-tty-Fix-warning-left-over-from-TIOCGICOUNT-changes.patch:
  tty: Fix warning left over from TIOCGICOUNT changes.
- patches.drivers/USB3-0036-USB-sam-ba-add-driver-for-Atmel-SAM-Boot-Assistant-SAM-BA.patch:
  USB: sam-ba: add driver for Atmel SAM Boot Assistant (SAM-BA).
- patches.drivers/USB3-0037-USB-Gadget-Verify-VBUS-current-before-setting-the-device-sel.patch:
  USB Gadget: Verify VBUS current before setting the device
  self-powered bit.
- patches.drivers/USB3-0038-USB-core-update-comment-to-match-current-function-name.patch:
  USB: core: update comment to match current function name.
- patches.drivers/USB3-0052-USB-output-an-error-message-when-the-pipe-type-doesn-t-match.patch:
  USB: output an error message when the pipe type doesn't match
  the endpoint type.
- patches.drivers/USB3-0058-usb-ftdi-elan-Convert-mutex-to-semaphore.patch:
  usb: ftdi-elan: Convert "mutex" to semaphore.
- patches.drivers/USB3-0062-USB-Change-acm_iad_descriptor-bFunctionProtocol-to-USB_CDC_A.patch:
  USB: Change acm_iad_descriptor bFunctionProtocol to
  USB_CDC_ACM_PROTO_AT_V25TER.
- patches.drivers/USB3-0063-USB-ohci-sm501-add-iounmap-on-error-path.patch:
  USB: ohci-sm501: add iounmap on error path.
- patches.drivers/USB3-0066-USB-isp1362-hcd-Removes-CONFIG_USB_OTG-dependent-code-fix-bu.patch:
  USB: isp1362-hcd: Removes CONFIG_USB_OTG dependent code,
  fix build breakage.
- patches.drivers/USB3-0070-usb-host-oxu210hp-hcd-Use-static-const-char-const-where-poss.patch:
  usb: host: oxu210hp-hcd: Use static const char * const where
  possible.
- patches.drivers/USB3-0072-usb-omap-ohci-Missing-driver-unregister-in-module-exit.patch:
  usb: omap: ohci: Missing driver unregister in module exit.
- patches.drivers/USB3-0075-USB-cdc.h-ncm-typo-and-style-fixes.patch:
  USB: cdc.h: ncm: typo and style fixes.
- patches.drivers/USB3-0076-Revert-USB-ncm-added-ncm.h-with-auxiliary-definitions.patch:
  Revert "USB: ncm: added ncm.h with auxiliary definitions".
- patches.drivers/USB3-0077-USB-cdc.h-ncm-add-missed-constants-and-structures.patch:
  USB: cdc.h: ncm: add missed constants and structures.
- patches.drivers/USB3-0079-USB-serial-Enable-USB-autosuspend-by-default-on-qcserial.patch:
  USB: serial: Enable USB autosuspend by default on qcserial.
- patches.drivers/USB3-0081-USB-cdc.h-ncm-fix-one-more-typo.patch:
  USB: cdc.h: ncm: fix one more typo.
- patches.drivers/USB3-0082-USB-qcserial-Enable-Diagnostics-Monitor-and-GPS-ports-on-Gob.patch:
  USB: qcserial: Enable Diagnostics Monitor and GPS ports on
  Gobi 2000.
- patches.drivers/USB3-0083-USB-storage-Use-USB_-prefix-instead-of-US_-prefix.patch:
  USB: storage: Use USB_ prefix instead of US_ prefix.
- patches.drivers/USB3-0084-USB-Move-USB-Storage-definitions-to-their-own-header-file.patch:
  USB: Move USB Storage definitions to their own header file.
- patches.drivers/USB3-0085-USB-Add-UAS-driver.patch: USB:
  Add UAS driver.
- patches.drivers/USB3-0085-block-remove-req_hardbarrier_UAS.patch:
  block: remove REQ_HARDBARRIER.
- patches.drivers/USB3-0087-USB-add-driver-for-Meywa-Denki-Kayac-YUREX.patch:
  USB: add driver for Meywa-Denki & Kayac YUREX.
- patches.drivers/USB3-0088-USB-yurex-assign-a-real-minor-number-to-the-driver.patch:
  USB: yurex: assign a real minor number to the driver.
- patches.drivers/USB3-0089-USB-yurex-fix-memory-leak-and-corrupted-messages.patch:
  USB: yurex: fix memory leak and corrupted messages.
* Thu Aug  4 2011 mmarek@suse.cz
- patches.drivers/0001-ixgbe-fix-WOL-register-setup-for-82599:
  ixgbe: fix WOL register setup for 82599 (bnc#691742,
  fate#311957).
- patches.drivers/0002-ixgbe-Mailbox-header-and-code-module:
  ixgbe: Mailbox header and code module (bnc#691742, fate#311957).
- patches.drivers/0003-ixgbe-Add-SR-IOV-register-structure-and-bit-defines:
  ixgbe: Add SR-IOV register, structure and bit defines
  (bnc#691742, fate#311957).
- patches.drivers/0004-ixgbe-Add-SR-IOV-specific-features: ixgbe:
  Add SR-IOV specific features (bnc#691742, fate#311957).
- patches.drivers/0005-ixgbe-Add-SR-IOV-specific-modules-to-driver-Makefile:
  ixgbe: Add SR-IOV specific modules to driver Makefile
  (bnc#691742, fate#311957).
- patches.drivers/0006-ixgbe-Add-SR-IOV-feature-enablement-code:
  ixgbe: Add SR-IOV feature enablement code (bnc#691742,
  fate#311957).
- patches.drivers/0007-ixgbe-Refactor-common-code-between-82598-82599-to-accommodate-new-hardware:
  ixgbe: Refactor common code between 82598 & 82599 to accommodate
  new hardware (bnc#691742, fate#311957).
- patches.drivers/0008-ixgbe-add-support-for-a-new-82599-10G-Base-T-device:
  ixgbe:add support for a new 82599 10G Base-T device (bnc#691742,
  fate#311957).
- patches.drivers/0009-ixgbe-move-all-Rx-DMA-control-register-writes-to-one-central-location:
  ixgbe: move all Rx DMA control register writes to one central
  location (bnc#691742, fate#311957).
- patches.drivers/0010-ixgbe-change-mac_type-if-statements-to-switch-statements:
  ixgbe: change mac_type if statements to switch statements
  (bnc#691742, fate#311957).
- patches.drivers/0011-ixgbe-make-silicon-specific-functions-generic:
  ixgbe: make silicon specific functions generic (bnc#691742,
  fate#311957).
- patches.drivers/0012-ixgbe-move-CPU-variable-from-ring-into-q_vector-add-ring--q_vector:
  ixgbe: move CPU variable from ring into q_vector, add
  ring->q_vector (bnc#691742, fate#311957).
- patches.drivers/0013-ixgbe-add-MAC-and-PHY-support-for-x540:
  ixgbe: add MAC and PHY support for x540 (bnc#691742,
  fate#311957).
- patches.drivers/0014-ixgbe-add-support-for-x540-MAC: ixgbe:
  add support for x540 MAC (bnc#691742, fate#311957).
- patches.drivers/0015-ixgbe-fix-X540-to-use-it-s-own-info-struct:
  ixgbe: fix X540 to use it's own info struct (bnc#691742,
  fate#311957).
- patches.drivers/0016-ixgbe-add-support-for-new-HW: ixgbe:
  add support for new HW (bnc#691742, fate#311957).
* Thu Aug  4 2011 tiwai@suse.de
- Disable patches.drm/2098-drm-do-not-leak-kernel-*, as printk %%pK
  format isn't supported in SP2 kernel
* Thu Aug  4 2011 tiwai@suse.de
- patches.drivers/i915-fix-ironlake-edp-panel-setup-v4: Delete.
* Thu Aug  4 2011 tiwai@suse.de
- patches.drm/drm-010-revert-shrinker-changes: drm: Revert
  shrinker changes for 2.6.32 (fate#310916).
- patches.drm/drm-020-revert-broken-vga-output-at-boot:
  drm/i915/lvds: Fix status register check.
- patches.drm/drm-021-drm-i915-redetect-connections-at-resume:
  drm/i915: re-detect connections at resume.
- patches.drm/drm-022-drm-fix-fb-switch-after-s4: drm: Fix fb
  after S4.
- patches.drm/drm-030-radeon-kms-fix-i2c-map-for-rv250-280:
  drm/radeon/kms: fix i2c map for rv250/280.
- patches.drm/drm-031-radeon-kms-add-missing-vddci-setting-on-NI:
  drm/radeon/kms: add missing vddci setting on NI+.
- patches.drm/drm-032-radeon-kms-fix-DP-training-for-DPEncoderService:
  drm/radeon/kms: fix DP training for DPEncoderService revision
  bigger than 1.1.
* Thu Aug  4 2011 tiwai@suse.de
- patches.drm/drm-001-drm_err-use-printk: drm: Revert the new
  printk() format in drm_err() for 2.6.32 (fate#310916).
- patches.drm/drm-002-revert-slowwork-conversion: drm: Revert
  to use slow_work for 2.6.32 (fate#310916).
- patches.drm/drm-003-slow-work-oops-fix: drm: Fix Oops with
  slow_work in 2.6.32 (fate#310916).
- patches.drm/drm-004-revert-use-shmem_read_page: drm: Revert
  shmem_read_mapping_page() for 2.6.32 (fate#310916).
- patches.drm/drm-005-i830-build-fix: Fix build of i830 module
  with the updated drm stack (fate#310916).
- patches.drm/drm-006-io_mapping-merge-fixes: Fix merge errors
  to correct io_mappin_map_atomic*() (fate#310916).
- patches.drm/drm-007-revert-fb-debug-hooks: drm: Revert new
  fb_debug_* hooks for 2.6.32 (fate#310916).
- patches.drm/drm-008-radeon-backlight-compat: drm/radeon:
  Revert new backlight API (fate#310916).
- patches.drm/drm-009-radeon-i2c-new-ops-revert: drm: Revert
  i2c changes in drm/radeon for 2.6.32 (fate#310916).
- patches.drm/drm-compat-for-3.0: drm: add compatibility
  definitions (fate#310916).
* Thu Aug  4 2011 tiwai@suse.de
- Update config files for DRM/AGP updates
* Thu Aug  4 2011 tiwai@suse.de
- patches.xen/xen3-patch-2.6.32: Refresh. Fix for 3.0-agp
* Thu Aug  4 2011 tiwai@suse.de
- patches.drm/*: Update DRM and AGP stack as of 3.0-kernel for new
  hardware (fate#310916)
- patches.arch/0017-x86-k8-gart-Decouple-handling-of-garts-and.patch:
  Refresh.
- patches.arch/0018-x86-k8-Rename-k8.-ch-to-amd_nb.-ch-and.patch:
  Refresh.
- patches.arch/x86_agpgart-g33-stoeln-fix-2.patch: Delete.
* Thu Aug  4 2011 tiwai@suse.de
  Preliminary changes for DRM; add patches.drm and remove old patches
* Thu Aug  4 2011 duwe@suse.de
- patches.arch/s390-zfcp-dif-dix: zfcp: support for T10 DIF /
  DIX (bnc#708635).
- Update config files.
- patches.suse/modify-change_queue_depth-to-take-in-reason-why-it-is-being-called.patch:
  Refresh.
* Wed Aug  3 2011 nfbrown@suse.de
- patches.kernel.org/export_wake_up_locked_key: export
  __wake_up_locked_key as may be needed for NFS update
  (FATE#310250).
* Wed Aug  3 2011 duwe@suse.de
- patches.arch/s390-af_iucv-over-hsi: s390: af_iucv (new
  function): add HiperSockets transport (bnc#708636).
* Wed Aug  3 2011 ohering@suse.de
- patches.suse/staging-hv-HDIO_GET_IDENTITY.patch:
  remove support for ioctl, its not supported upstream (bnc#709332)
* Wed Aug  3 2011 dsterba@suse.cz
- patches.suse/btrfs-allow-cross-subvolume-file-clone.patch:
  update and disable in series.conf for now, exposes a bug in delayed-inode
  code.
* Wed Aug  3 2011 duwe@suse.de
- patches.arch/s390-32-02-qeth_ipv6_vlan: qeth: l3 ipv6 vlan
  not working on shared OSA chpid (bnc#709866).
* Wed Aug  3 2011 duwe@suse.de
- patches.arch/s390-32-01-qdio_shared_dsci_race:
  clear shared DSCI before scheduling the queue handler
  (bnc#709866).
* Wed Aug  3 2011 dsterba@suse.cz
- patches.suse/btrfs-allow-cross-subvolume-file-clone.patch:
  btrfs: allow cross-subvolume file clone (bnc#698540).
* Wed Aug  3 2011 trenn@suse.de
  Cleanup and split kmsg_dumper patches out of pstore ones,
  no code change:
- patches.drivers/001-apei_infrastructure.patch: Refresh.
- patches.drivers/001-kmsg_dump.patch: new error reporting
  interface with APEI (fate#311705).
- patches.drivers/002-kmsg_dump.patch: gcc-4.6: printk: use
  stable variable to dump kmsg buffer (fate#311705).
- patches.drivers/011a-apei-pstore: pstore: X86 platform interface
  using ACPI/APEI/ERST (fate#311705).
- patches.drivers/002-apei_pstore.patch: Delete.
- patches.drivers/004-apei-pstore: Delete.
* Wed Aug  3 2011 hare@suse.de
- patches.drivers/qla4xxx-5.02.10.01.11.2-k0-update: qla4xxx:
  Update to 5.02.10.01.11.2-k0 (bnc#689435).
- patches.drivers/qla4xxx-Remove-host_lock-in-queuecommand-fun.patch:
  qla4xxx: Remove host_lock in queuecommand function (bnc#689436).
* Wed Aug  3 2011 trenn@suse.de
  Tiny patches for pcc-cpufreq driver which looked worth adding:
- patches.drivers/001-pcc-cpufreq-fixes.patch: Fix PCC driver
  error path (none).
- patches.drivers/002-pcc-cpufreq-fixes.patch: pcc driver should
  check for pcch method before calling _OSC (none).
- patches.drivers/003-pcc-cpufreq-fixes.patch: fix double freeing
  in error path of pcc-cpufreq (none).
- patches.drivers/004-pcc-cpufreq-fixes.patch: Fix memory leaks
  in pcc_cpufreq_do_osc (none).
- patches.drivers/005-pcc-cpufreq-fixes.patch: pcc-cpufreq:
  don't load driver if get_freq fails during init (none).
- patches.drivers/006-pcc-cpufreq-fixes.patch: pcc-cpufreq:
  remove duplicate statements (none).
- patches.drivers/007-pcc-cpufreq-fixes.patch: Fix _OSC UUID in
  pcc-cpufreq (none).
* Wed Aug  3 2011 jeffm@suse.com
- supported.conf: Add qlcnic to supported list (bnc#698272)
* Wed Aug  3 2011 jeffm@suse.com
- patches.drivers/bnx2-add-mcp-dump: bnx2: Add MCP dump
  (bnc#709063).
- patches.drivers/bnx2-close-device-if-tx_timeout-reset-fails:
  bnx2: Close device if tx_timeout reset fails (bnc#709063).
- patches.drivers/bnx2-fix-endian-swapping-on-firmware-version-string:
  bnx2: Fix endian swapping on firmware version string
  (bnc#709063).
- patches.drivers/bnx2-read-iscsi-config-from-shared-memory-during-probe:
  bnx2: Read iSCSI config from shared memory during ->probe()
  (bnc#709063).
- patches.drivers/cnic-Add-VLAN-ID-as-a-parameter-during-netevent-upca.patch:
  Refresh.
- patches.drivers/cnic-fix-context-id-space-calculation: cnic:
  Fix Context ID space calculation (bnc#709063).
- patches.drivers/cnic-fix-port_mode-setting: cnic: Fix port_mode
  setting (bnc#709063).
- patches.drivers/cnic-fix-ring-setup-shutdown-code: cnic:
  Fix ring setup/shutdown code (bnc#709063).
- patches.drivers/cnic-replace-get_random_bytes-with-random32:
  cnic: Replace get_random_bytes() with random32() (bnc#709063).
- patches.drivers/cnic-return-proper-error-code-if-we-fail-to-send-netlink-message:
  cnic: Return proper error code if we fail to send netlink
  message (bnc#709063).
- patches.drivers/cnic-wait-for-all-context-ids-to-be-deleted-before-sending-fcoe_destroy_func:
  cnic: Wait for all Context IDs to be deleted before sending
  FCOE_DESTROY_FUNC (bnc#709063).
* Tue Aug  2 2011 jeffm@suse.com
- patches.drivers/bnx2x-broken-self-test-in-sf-mode-on-578xx:
  bnx2x: Broken self-test in SF mode on 578xx (bnc#698050).
- patches.drivers/bnx2x-configure-silent-stripping-for-a-vid0-vlan-tag:
  bnx2x: configure silent stripping for a VID0 VLAN tag
  (bnc#698050).
- patches.drivers/bnx2x-fixed-ethtool-d-for-578xx: bnx2x: Fixed
  ethtool -d for 578xx (bnc#698050).
- patches.drivers/bnx2x-implementation-for-netdev-ndo_fcoe_get_wwn:
  bnx2x: Implementation for netdev->ndo_fcoe_get_wwn (bnc#698050).
- patches.drivers/bnx2x-parity-errors-recovery-for-578xx: bnx2x:
  Parity errors recovery for 578xx (bnc#698050).
- patches.drivers/bnx2x-read-fip-mac-from-shmem-in-single-function-mode:
  bnx2x: Read FIP mac from SHMEM in single function mode
  (bnc#698050).
* Tue Aug  2 2011 jeffm@suse.com
- patches.drivers/be2net-request-native-mode-each-time-the-card-is-reset:
  be2net: request native mode each time the card is reset
  (bnc#708274).
* Tue Aug  2 2011 duwe@suse.de
- patches.arch/ppc-fate-311669-03: Delete.
- patches.arch/ppc-fate-311669-04: Delete.
- patches.arch/ppc-fate-311669-05: Delete.
- patches.arch/ppc-fate-311687-03-kmsg_dump_more_events: Delete.
* Tue Aug  2 2011 ohering@suse.de
- patches.suse/staging-hv-HDIO_GET_IDENTITY.patch:
  provide correct model string, append guid (bnc#709332)
* Tue Aug  2 2011 hare@suse.de
- patches.fixes/scsi-dh-alua-decode-rtpg-extended-header:
  scsi_dh_alua: Decode RTPG extended header format (FATE#311300).
* Tue Aug  2 2011 tiwai@suse.de
- patches.xen/xen3-patch-2.6.31: Refresh for intel-agp patch.
* Tue Aug  2 2011 tiwai@suse.de
- Refresh Xen patches for DRM-3.0 update
  patches.xen/xen3-patch-2.6.29: Refresh.
  patches.xen/xen3-patch-2.6.31: Refresh.
  patches.xen/xen3-patch-2.6.32: Refresh.
- patches.xen/xen3-patch-2.6.35: Xen patch for 2.6.35.
* Tue Aug  2 2011 oneukum@suse.de
- patches.drivers/USB_xhci_fix_OS_want_to_own_HC.patch:
  USB: xhci: fix OS want to own HC.
* Tue Aug  2 2011 nfbrown@suse.de
- patches.suse/dm-raid45-dm_put.fix: Remove incorrect dm_put
  calls from dm-raid45 (bnc#706485).
* Mon Aug  1 2011 mfasheh@suse.com
- patches.suse/0001-btrfs-Don-t-BUG_ON-errors-from-btrfs_create_subvol_r.patch:
  btrfs: Don't BUG_ON errors from btrfs_create_subvol_root().
- patches.suse/0001-btrfs-Handle-NULL-inode-return-from-btrfs_lookup_den.patch:
  btrfs: Handle NULL inode return from btrfs_lookup_dentry().
- patches.suse/0001-btrfs-don-t-BUG_ON-btrfs_alloc_path-errors.patch:
  btrfs: don't BUG_ON btrfs_alloc_path() errors.
- patches.suse/0002-btrfs-Don-t-BUG_ON-alloc_path-errors-in-replay_one_b.patch:
  btrfs: Don't BUG_ON alloc_path errors in replay_one_buffer().
- patches.suse/0003-btrfs-Don-t-BUG_ON-alloc_path-errors-in-btrfs_trunca.patch:
  btrfs: Don't BUG_ON alloc_path errors in
  btrfs_truncate_inode_items.
- patches.suse/0004-btrfs-Don-t-BUG_ON-alloc_path-errors-in-btrfs_read_l.patch:
  btrfs: Don't BUG_ON alloc_path errors in
  btrfs_read_locked_inode.
- patches.suse/0005-btrfs-Don-t-BUG_ON-alloc_path-errors-in-btrfs_balanc.patch:
  btrfs: Don't BUG_ON alloc_path errors in btrfs_balance().
- patches.suse/0006-btrfs-Don-t-BUG_ON-alloc_path-errors-in-find_next_ch.patch:
  btrfs: Don't BUG_ON alloc_path errors in find_next_chunk.
- patches.suse/0007-btrfs-don-t-BUG_ON-allocation-errors-in-btrfs_drop_s.patch:
  btrfs: don't BUG_ON allocation errors in btrfs_drop_snapshot.
* Mon Aug  1 2011 jkosina@suse.cz
- patches.suse/stop_machine-implement-lazy: Delete. Unused and
  not needed.
* Mon Aug  1 2011 trenn@suse.de
  split out most of patches.drivers/002-apei_pstore.patch
  into mainline commits:
- patches.arch/ppc-fate-311687-kmsg_dump: Refresh.
- patches.drivers/002-apei_pstore.patch: Refresh.
- patches.drivers/004-apei-pstore: gcc-4.6: printk: use stable
  variable to dump kmsg buffer (fate#311705).
- patches.drivers/005-apei-pstore: pstore: new filesystem
  interface to platform persistent storage (fate#311705).
- patches.drivers/006-apei-pstore: pstore: fix build warning
  for unused return value from sysfs_create_file (fate#311705).
- patches.drivers/007-apei-pstore: kmsg_dump: add kmsg_dump()
  calls to the reboot, halt, poweroff and emergency_restart paths
  (fate#311705).
- patches.drivers/008-apei-pstore: printk: use RCU to prevent
  potential lock contention in kmsg_dump (fate#311705).
- patches.drivers/009-apei-pstore: Some fixes for pstore
  (fate#311705).
- patches.drivers/010-apei-pstore: pstore: use mount option
  instead sysfs to tweak kmsg_bytes (fate#311705).
- patches.drivers/011-apei-pstore: pstore: cleanups to
  pstore_dump() (fate#311705).
- patches.drivers/012-apei-pstore: Fix common misspellings
  (fate#311705).
- patches.drivers/013-apei-pstore: pstore: Fix Kconfig
  dependencies for apei->pstore (fate#311705).
- patches.drivers/014-apei-pstore: pstore: fix one type of return
  value in pstore (fate#311705).
- patches.drivers/015-apei-pstore: pstore: fix pstore filesystem
  mount/remount issue (fate#311705).
- patches.drivers/016-apei-pstore: pstore: fix potential logic
  issue in pstore read interface (fate#311705).
- patches.drivers/017-apei-pstore: kmsg_dump.h: fix build when
  CONFIG_PRINTK is disabled (fate#311705).
* Mon Aug  1 2011 ohering@suse.de
- patches.suse/staging-hv-HDIO_GET_IDENTITY.patch: hv: return
  correct data for HDIO_GET_IDENTITY ioctl (bnc#709332).
* Mon Aug  1 2011 rw@suse.de
- patches.arch/x86-efi-07-introduce-e820-check_early:
  double MAX_EARLY_RES and improve 'check_early()'.
- patches.arch/x86-efi-09-ignore-EFI_RESERVED_TYPE: Refresh.
- patches.arch/x86-efi-10-merge-contiguous-early-reservations:
  x86, efi: Merge contiguous early reservations.  (bnc#681242)
* Mon Aug  1 2011 mmarek@suse.cz
- rpm/modversions: Support for new genksyms format with E# tags for enum
  constants.
* Mon Aug  1 2011 hare@suse.de
- patches.drivers/isci-add-compat-isci_compath.h:
  Re-add after it got lost with the latest update.
- patches.drivers/0000-isci-mainline-update.patch: Refresh.
* Mon Aug  1 2011 hare@suse.de
- Fixup compilation failures:
  * patches.fixes/block-strict-rq_affinity
  * patches.fixes/block-strict-rq_affinity-fix-warning
* Mon Aug  1 2011 hare@suse.de
- patches.fixes/block-strict-rq_affinity: block: strict
  rq_affinity (bnc#709528).
- patches.fixes/block-strict-rq_affinity-fix-warning: block:
  fix warning with calling smp_processor_id() in preemptible
  section (bnc#709528).
* Mon Aug  1 2011 hare@suse.de
- patches.drivers/0000-isci-mainline-update.patch: isci: update
  to mainline version (bnc#709528).
- patches.drivers/0001-isci-remove-unused-SC_LIBRARY_HANDLE_T-typedef.patch:
  isci: remove unused SC_LIBRARY_HANDLE_T typedef
  (FATE#311808,bnc#709528).
- patches.drivers/0002-isci-remove-SCI_INVALID_HANDLE.patch:
  isci: remove SCI_INVALID_HANDLE (FATE#311808,bnc#709528).
- patches.drivers/0003-isci-kill-SCI_IO_REQUEST_DATA_DIRECTION.patch:
  isci: kill SCI_IO_REQUEST_DATA_DIRECTION
  (FATE#311808,bnc#709528).
- patches.drivers/0004-isci-kill-sci_types.h.patch: isci: kill
  sci_types.h (FATE#311808,bnc#709528).
- patches.drivers/0005-isci-removing-unused-loglevel-module-param.patch:
  isci: removing unused loglevel module param
  (FATE#311808,bnc#709528).
- patches.drivers/0006-isci-remote-device-and-node-cleanup-step1.patch:
  isci: remote device and node cleanup step1
  (FATE#311808,bnc#709528).
- patches.drivers/0007-isci-coding-style-changes-for-remote-device.patch:
  isci: coding style changes for remote device
  (FATE#311808,bnc#709528).
- patches.drivers/0008-isci-c99-tables-cleanup-step1.patch:
  isci: c99 tables cleanup step1 (FATE#311808,bnc#709528).
- patches.drivers/0009-isci-cleanup-core-consolidation-leftovers.patch:
  isci: cleanup core consolidation leftovers
  (FATE#311808,bnc#709528).
- patches.drivers/0010-isci-coding-style-changes-for-remote-device.patch:
  isci: coding style changes for remote device
  (FATE#311808,bnc#709528).
- patches.drivers/0011-isci-kill-a-callback-cast.patch: isci:
  kill a callback cast (FATE#311808,bnc#709528).
- patches.drivers/0012-isci-remove-SCIC_DEBUG_ENABLED-and-fixup-an-odd-ma.patch:
  isci: remove SCIC_DEBUG_ENABLED, and fixup an odd macro
  (FATE#311808,bnc#709528).
- patches.drivers/0013-isci-bypass-scic_controller_get_handler_methods.patch:
  isci: bypass scic_controller_get_handler_methods()
  (FATE#311808,bnc#709528).
- patches.drivers/0014-isci-cleanup-starting-state-handling.patch:
  isci: cleanup "starting" state handling
  (FATE#311808,bnc#709528).
- patches.drivers/0015-isci-enable-interrupts-during-controller-start-and.patch:
  isci: enable interrupts during controller start, and flush
  discovery (FATE#311808,bnc#709528).
- patches.drivers/0016-isci-implement-error-isr.patch: isci:
  implement error isr (FATE#311808,bnc#709528).
- patches.drivers/0017-isci-advertise-linkrate.patch: isci:
  advertise linkrate (FATE#311808,bnc#709528).
- patches.drivers/0018-isci-debug-fixes.patch: isci: debug fixes
  (FATE#311808,bnc#709528).
- patches.drivers/0019-isci-remove-scic_controller_get_handler_methods-and.patch:
  isci: remove scic_controller_get_handler_methods and ilk
  (FATE#311808,bnc#709528).
- patches.drivers/0020-isci-Initialize-proc_name-field-in-scsi_host_templa.patch:
  isci: Initialize proc_name field in scsi_host_template
  (FATE#311808,bnc#709528).
- patches.drivers/0021-isci-Move-firmware-loading-to-per-PCI-device.patch:
  isci: Move firmware loading to per PCI device
  (FATE#311808,bnc#709528).
- patches.drivers/0022-isci-phy-state-machine-cleanup-step1.patch:
  isci: phy state machine cleanup step1 (FATE#311808,bnc#709528).
- patches.drivers/0023-isci-fix-no-outbound-task-timeout-default-value.patch:
  isci: fix "no outbound task timeout" default value
  (FATE#311808,bnc#709528).
- patches.drivers/0024-isci-Move-transport-layer-registers-from-port-to-ph.patch:
  isci: Move transport layer registers from port to phy
  (FATE#311808,bnc#709528).
- patches.drivers/0025-isci-Add-support-for-user-parameters-in-SCIC-layer.patch:
  isci: Add support for user parameters in SCIC layer
  (FATE#311808,bnc#709528).
- patches.drivers/0026-isci-clean-up-remaining-silicon-revision-ifdefs-in.patch:
  isci: clean up remaining silicon revision ifdefs in phy init
  (FATE#311808,bnc#709528).
- patches.drivers/0027-isci-Add-Support-for-new-TC-completion-codes.patch:
  isci: Add Support for new TC completion codes
  (FATE#311808,bnc#709528).
- patches.drivers/0028-isci-fix-for-asserts-during-aborts-resets-to-SAS-SA.patch:
  isci: fix for asserts during aborts/resets to SAS/SATA in APC
  mode (FATE#311808,bnc#709528).
- patches.drivers/0029-isci-Removed-special-macros-that-does-64bit-address.patch:
  isci: Removed special macros that does 64bit address math
  (FATE#311808,bnc#709528).
- patches.drivers/0030-isci-Make-the-driver-copy-data-directly-from-and-to.patch:
  isci: Make the driver copy data directly from and to sg for PIO
  (FATE#311808,bnc#709528).
- patches.drivers/0031-isci-have-the-driver-use-native-SG-calls-and-DMA-AP.patch:
  isci: have the driver use native SG calls and DMA-API
  (FATE#311808,bnc#709528).
- patches.drivers/0032-isci-Change-event-notify-calls-from-scic_cb_-to-is.patch:
  isci: Change event notify calls from scic_cb_* to isci_event_*
  (FATE#311808,bnc#709528).
- patches.drivers/0033-isci-Removing-deprecated-functions.patch:
  isci: Removing deprecated functions (FATE#311808,bnc#709528).
- patches.drivers/0034-isci-fix-sas-address-reporting.patch:
  isci: fix sas address reporting (FATE#311808,bnc#709528).
- patches.drivers/0035-isci-rework-timer-api.patch: isci: rework
  timer api (FATE#311808,bnc#709528).
- patches.drivers/0036-isci-workaround-port-task-scheduler-starvation-issu.patch:
  isci: workaround port task scheduler starvation issue
  (FATE#311808,bnc#709528).
- patches.drivers/0037-isci-handle-cases-where-a-d2h-fis-is-used-report-an.patch:
  isci: handle cases where a d2h fis is used report an ncq error
  (FATE#311808,bnc#709528).
- patches.drivers/0038-isci-controller-stop-start-fixes.patch:
  isci: controller stop/start fixes (FATE#311808,bnc#709528).
- patches.drivers/0039-isci-Adding-support-for-phy-enable-and-disable.patch:
  isci: Adding support for phy enable and disable
  (FATE#311808,bnc#709528).
- patches.drivers/0040-isci-Cleanup-warning-messages-for-phy-resets.patch:
  isci: Cleanup warning messages for phy resets
  (FATE#311808,bnc#709528).
- patches.drivers/0041-isci-fix-hang-after-target-reset.patch:
  isci: fix hang after target reset (FATE#311808,bnc#709528).
- patches.drivers/0042-isci-pad-stp-and-smp-request-sizes.patch:
  isci: pad stp and smp request sizes (FATE#311808,bnc#709528).
- patches.drivers/0043-isci-enable-isci-for-dmar-builds.patch:
  isci: enable isci for dmar builds (FATE#311808,bnc#709528).
- patches.drivers/0044-isci-kill-isci_host-list-in-favor-of-an-array.patch:
  isci: kill isci_host list in favor of an array
  (FATE#311808,bnc#709528).
- patches.drivers/0045-isci-remove-sci_device_handle.patch:
  isci: remove sci_device_handle (FATE#311808,bnc#709528).
- patches.drivers/0046-isci-kill-host-quiesce-mechanism.patch:
  isci: kill "host quiesce" mechanism (FATE#311808,bnc#709528).
- patches.drivers/0047-isci-replace-isci_remote_device-completion-with-eve.patch:
  isci: replace isci_remote_device completion with event queue
  (FATE#311808,bnc#709528).
- patches.drivers/0048-isci-preallocate-remote-devices.patch:
  isci: preallocate remote devices (FATE#311808,bnc#709528).
- patches.drivers/0049-isci-replace-remote_device_lock-with-scic_lock.patch:
  isci: replace remote_device_lock  with scic_lock
  (FATE#311808,bnc#709528).
- patches.drivers/0050-isci-cleanup-debug-leftovers-in-isci.h.patch:
  isci: cleanup debug leftovers in isci.h
  (FATE#311808,bnc#709528).
- patches.drivers/0051-isci-isci_request_cleanup_completed_loiterer-checks.patch:
  isci: isci_request_cleanup_completed_loiterer checks task
  before task_done (FATE#311808,bnc#709528).
- patches.drivers/0052-isci-Changes-in-isci_host_completion_routine.patch:
  isci: Changes in isci_host_completion_routine
  (FATE#311808,bnc#709528).
- patches.drivers/0053-isci-fix-completion-abort-path.patch:
  isci: fix completion / abort path (FATE#311808,bnc#709528).
- patches.drivers/0054-isci-Any-reset-indicated-on-an-I-O-completion-escal.patch:
  isci: Any reset indicated on an I/O completion escalates it
  to the error path (FATE#311808,bnc#709528).
- patches.drivers/0055-isci-save-the-i-o-tag-outside-the-scic-request-stru.patch:
  isci: save the i/o tag outside the scic request structure
  (FATE#311808,bnc#709528).
- patches.drivers/0056-isci-Cleaning-up-task-execute-path.patch:
  isci: Cleaning up task execute path (FATE#311808,bnc#709528).
- patches.drivers/0057-isci-Code-review-change-for-completion-pointer-clea.patch:
  isci: Code review change for completion pointer cleanup
  (FATE#311808,bnc#709528).
- patches.drivers/0058-isci-Termination-handling-cleanup-added-terminatio.patch:
  isci: Termination handling cleanup, added termination timeouts
  (FATE#311808,bnc#709528).
- patches.drivers/0059-isci-Fix-TMF-build-for-SAS-SATA-LUN-reset-cases.patch:
  isci: Fix TMF build for SAS/SATA LUN reset cases
  (FATE#311808,bnc#709528).
- patches.drivers/0060-isci-Fixed-BUG_ON-in-isci_abort_task_process_cb-cal.patch:
  isci: Fixed BUG_ON in isci_abort_task_process_cb callback
  (FATE#311808,bnc#709528).
- patches.drivers/0061-isci-Errors-in-the-submit-path-for-SATA-devices-man.patch:
  isci: Errors in the submit path for SATA devices manage the
  ap lock (FATE#311808,bnc#709528).
- patches.drivers/0062-isci-Always-set-response-status-for-requests-going.patch:
  isci: Always set response/status for requests going into the
  error path (FATE#311808,bnc#709528).
- patches.drivers/0063-isci-All-pending-requests-are-terminated-before-sto.patch:
  isci: All pending requests are terminated before stopping the
  device (FATE#311808,bnc#709528).
- patches.drivers/0064-isci-add-isci_id-attribute.patch: isci:
  add "isci_id" attribute (FATE#311808,bnc#709528).
- patches.drivers/0065-isci-fix-incorrect-assumptions-about-task-dev-and.patch:
  isci: fix incorrect assumptions about task->dev and
  task->dev->port being NULL (FATE#311808,bnc#709528).
- patches.drivers/0066-isci-don-t-hold-scic_lock-over-calls-to-sas_task_ab.patch:
  isci: don't hold scic_lock over calls to sas_task_abort()
  (FATE#311808,bnc#709528).
- patches.drivers/0067-isci-task.h-compile-and-checkpatch-fixes.patch:
  isci: task.h compile and checkpatch fixes
  (FATE#311808,bnc#709528).
- patches.drivers/0068-isci-reset-hardware-at-init.patch: isci:
  reset hardware at init (FATE#311808,bnc#709528).
- patches.drivers/0069-isci-Add-support-for-probing-OROM-for-OEM-params.patch:
  isci: Add support for probing OROM for OEM params
  (FATE#311808,bnc#709528).
- patches.drivers/0070-isci-Adding-EFI-variable-skeletal-support.patch:
  isci: Adding EFI variable skeletal support
  (FATE#311808,bnc#709528).
- patches.drivers/0071-isci-add-support-for-2-more-oem-parmeters.patch:
  isci: add support for 2 more oem parmeters
  (FATE#311808,bnc#709528).
- patches.drivers/0072-isci-update-efi-variable-name-and-guid.patch:
  isci: update efi variable name and guid
  (FATE#311808,bnc#709528).
- patches.drivers/0073-isci-copy-the-oem-parameters-instead-of-assign.patch:
  isci: copy the oem parameters instead of assign
  (FATE#311808,bnc#709528).
- patches.drivers/0074-isci-fixup-with-testing-from-isci-OROM-in-BIOS.patch:
  isci: fixup with testing from isci OROM in BIOS
  (FATE#311808,bnc#709528).
- patches.drivers/0075-isci-Fixup-for-OEM-parameter-EFI-variable-retrieval.patch:
  isci: Fixup for OEM parameter EFI variable retrieval
  (FATE#311808,bnc#709528).
- patches.drivers/0076-isci-fix-oem-parameter-initialization-and-mode-dete.patch:
  isci: fix oem parameter initialization and mode detection
  (FATE#311808,bnc#709528).
- patches.drivers/0077-isci-exposing-user-parameters-via-module-params.patch:
  isci: exposing user parameters via module params
  (FATE#311808,bnc#709528).
- patches.drivers/0078-isci-fix-apc-mode-definition.patch: isci:
  fix apc mode definition (FATE#311808,bnc#709528).
- patches.drivers/0079-isci-fix-a-build-warning.patch: isci:
  fix a build warning (FATE#311808,bnc#709528).
- patches.drivers/0080-isci-Remove-event_-calls-as-they-are-just-wrappers.patch:
  isci: Remove event_* calls as they are just wrappers
  (FATE#311808,bnc#709528).
- patches.drivers/0081-isci-reorder-init-to-cleanup-unneeded-declarations.patch:
  isci: reorder init to cleanup unneeded declarations
  (FATE#311808,bnc#709528).
- patches.drivers/0082-isci-kill-some-long-macros.patch: isci:
  kill some long macros (FATE#311808,bnc#709528).
- patches.drivers/0083-isci-namespacecheck-cleanups.patch: isci:
  namespacecheck cleanups (FATE#311808,bnc#709528).
- patches.drivers/0084-isci-remove-unused-remote_device_started.patch:
  isci: remove unused "remote_device_started"
  (FATE#311808,bnc#709528).
- patches.drivers/0085-isci-Remove-screaming-data-types.patch:
  isci: Remove "screaming" data types (FATE#311808,bnc#709528).
- patches.drivers/0086-isci-Properly-handle-requests-in-the-aborting-sta.patch:
  isci: Properly handle requests in the "aborting" state
  (FATE#311808,bnc#709528).
- patches.drivers/0087-isci-Free-host-lock-for-SATA-STP-abort-escalation-a.patch:
  isci: Free host lock for SATA/STP abort escalation at submission
  time (FATE#311808,bnc#709528).
- patches.drivers/0088-isci-Fix-use-of-SATA-soft-reset-state-machine.patch:
  isci: Fix use of SATA soft reset state machine
  (FATE#311808,bnc#709528).
- patches.drivers/0089-isci-Qualify-when-the-host-lock-is-managed-for-STP.patch:
  isci: Qualify when the host lock is managed for STP/SATA
  callbacks (FATE#311808,bnc#709528).
- patches.drivers/0090-isci-cleanup-isci_remote_device-_not-_ready-interfa.patch:
  isci: cleanup isci_remote_device[_not]_ready interface
  (FATE#311808,bnc#709528).
- patches.drivers/0091-isci-fix-fragile-conditional-isci_host-lookups.patch:
  isci: fix fragile/conditional isci_host lookups
  (FATE#311808,bnc#709528).
- patches.drivers/0092-isci-remove-mmio-wrappers.patch: isci:
  remove mmio wrappers (FATE#311808,bnc#709528).
- patches.drivers/0093-isci-remove-base_controller-abstraction.patch:
  isci: remove base_controller abstraction
  (FATE#311808,bnc#709528).
- patches.drivers/0094-isci-remove-base_request-abstraction.patch:
  isci: remove base_request abstraction (FATE#311808,bnc#709528).
- patches.drivers/0095-isci-kill-dead-data-structurs-in-scic_io_request.h.patch:
  isci: kill dead data structurs in scic_io_request.h
  (FATE#311808,bnc#709528).
- patches.drivers/0096-isci-simplify-request-state-handlers.patch:
  isci: simplify request state handlers (FATE#311808,bnc#709528).
- patches.drivers/0097-isci-simplify-dma-coherent-allocation.patch:
  isci: simplify dma coherent allocation (FATE#311808,bnc#709528).
- patches.drivers/0098-isci-remove-scic_controller-state-handlers.patch:
  isci: remove scic_controller state handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0099-isci-remove-base_remote_device-abstraction.patch:
  isci: remove base_remote_device abstraction
  (FATE#311808,bnc#709528).
- patches.drivers/0100-isci-remove-base_port-abstraction.patch:
  isci: remove base_port abstraction (FATE#311808,bnc#709528).
- patches.drivers/0101-isci-remove-base_phy-abstraction.patch:
  isci: remove base_phy abstraction (FATE#311808,bnc#709528).
- patches.drivers/0102-isci-replace-sci_sas_link_rate-with-sas_linkrate.patch:
  isci: replace sci_sas_link_rate with sas_linkrate
  (FATE#311808,bnc#709528).
- patches.drivers/0103-isci-sparse-warnings-cleanup.patch: isci:
  sparse warnings cleanup (FATE#311808,bnc#709528).
- patches.drivers/0104-isci-audit-usage-of-BUG_ON-macro-in-isci-driver.patch:
  isci: audit usage of BUG_ON macro in isci driver
  (FATE#311808,bnc#709528).
- patches.drivers/0105-isci-fix-oem-parameter-header-definition.patch:
  isci: fix oem parameter header definition
  (FATE#311808,bnc#709528).
- patches.drivers/0106-isci-validate-oem-parameters-early-and-fallback.patch:
  isci: validate oem parameters early, and fallback
  (FATE#311808,bnc#709528).
- patches.drivers/0107-isci-replace-this_-and-the_-variables-with-more-m.patch:
  isci: replace this_* and the_* variables with more meaningful
  names (FATE#311808,bnc#709528).
- patches.drivers/0108-isci-rely-on-irq-core-for-intx-multiplexing-and-si.patch:
  isci: rely on irq core for intx multiplexing, and silence
  screaming intx (FATE#311808,bnc#709528).
- patches.drivers/0109-isci-make-a-remote_node_context-a-proper-member-of.patch:
  isci: make a remote_node_context a proper member of a
  remote_device (FATE#311808,bnc#709528).
- patches.drivers/0110-isci-remove-rnc-device-back-pointer.patch:
  isci: remove rnc->device back pointer (FATE#311808,bnc#709528).
- patches.drivers/0111-isci-unify-remote_device-data-structures.patch:
  isci: unify remote_device data structures
  (FATE#311808,bnc#709528).
- patches.drivers/0112-isci-move-remote_device-handling-out-of-the-core.patch:
  isci: move remote_device handling out of the core
  (FATE#311808,bnc#709528).
- patches.drivers/0113-isci-cleanup-remote-device-construction-and-comment.patch:
  isci: cleanup remote device construction and comments
  (FATE#311808,bnc#709528).
- patches.drivers/0114-isci-kill-smp_discover_response_protocols-in-favor.patch:
  isci: kill smp_discover_response_protocols in favor of
  domain_device.dev_type (FATE#311808,bnc#709528).
- patches.drivers/0115-isci-kill-smp_discover_response.patch:
  isci: kill smp_discover_response (FATE#311808,bnc#709528).
- patches.drivers/0116-isci-remove-usage-of-sci_sas_address-in-scic_sds_re.patch:
  isci: remove usage of sci_sas_address in scic_sds_remote_device
  (FATE#311808,bnc#709528).
- patches.drivers/0117-isci-remove-scic_sds_remote_device_get_port_index.patch:
  isci: remove scic_sds_remote_device_get_port_index
  (FATE#311808,bnc#709528).
- patches.drivers/0118-isci-removing-non-working-ATAPI-code.patch:
  isci: removing non-working ATAPI code (FATE#311808,bnc#709528).
- patches.drivers/0119-isci-allow-fallback-to-option-rom-if-efi-variable-r.patch:
  isci: allow fallback to option-rom if efi variable retrieval
  fails (FATE#311808,bnc#709528).
- patches.drivers/0120-isci-Remove-excessive-log-noise-with-expander-hot-u.patch:
  isci: Remove excessive log noise with expander hot-unplug
  (FATE#311808,bnc#709528).
- patches.drivers/0121-isci-Implement-SCU-AFE-recipe-10.patch:
  isci: Implement SCU AFE recipe 10 (FATE#311808,bnc#709528).
- patches.drivers/0122-isci-Removed-struct-sci_base_object-from-state-mach.patch:
  isci: Removed struct sci_base_object from state machine
  (FATE#311808,bnc#709528).
- patches.drivers/0123-isci-Removed-sci_base_object-from-scic_sds_controll.patch:
  isci: Removed sci_base_object from scic_sds_controller
  (FATE#311808,bnc#709528).
- patches.drivers/0124-isci-Removed-sci_base_object-from-scic_sds_phy.patch:
  isci: Removed sci_base_object from scic_sds_phy
  (FATE#311808,bnc#709528).
- patches.drivers/0125-isci-Removed-sci_base_object-from-scic_sds_port.patch:
  isci: Removed sci_base_object from scic_sds_port
  (FATE#311808,bnc#709528).
- patches.drivers/0126-isci-Removed-sci_base_object-from-scic_sds_remote_d.patch:
  isci: Removed sci_base_object from scic_sds_remote_device
  (FATE#311808,bnc#709528).
- patches.drivers/0127-isci-Removed-sci_base_object-from-scic_sds_remote_n.patch:
  isci: Removed sci_base_object from scic_sds_remote_node_context
  (FATE#311808,bnc#709528).
- patches.drivers/0128-isci-Removed-sci_base_object-from-scic_sds_request.patch:
  isci: Removed sci_base_object from scic_sds_request
  (FATE#311808,bnc#709528).
- patches.drivers/0129-isci-Removed-sci_object.h-from-project.patch:
  isci: Removed sci_object.h from project
  (FATE#311808,bnc#709528).
- patches.drivers/0130-isci-merge-remote_device-substates-into-a-single-st.patch:
  isci: merge remote_device substates into a single state machine
  (FATE#311808,bnc#709528).
- patches.drivers/0131-isci-kill-scic_remote_device_get_connection_rate.patch:
  isci: kill scic_remote_device_get_connection_rate
  (FATE#311808,bnc#709528).
- patches.drivers/0132-isci-fix-remote_device-start_io-regressions.patch:
  isci: fix remote_device start_io regressions
  (FATE#311808,bnc#709528).
- patches.drivers/0133-isci-unify-remote_device-start_handlers.patch:
  isci: unify remote_device start_handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0134-isci-unify-remote_device-stop_handlers.patch:
  isci: unify remote_device stop_handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0135-isci-kill-remote_device-fail_handler.patch:
  isci: kill remote_device fail_handler (FATE#311808,bnc#709528).
- patches.drivers/0136-isci-unify-remote_device-destruct_handlers.patch:
  isci: unify remote_device destruct_handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0137-isci-unify-remote_device-reset_handlers.patch:
  isci: unify remote_device reset_handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0138-isci-unify-remote_device-reset_complete_handlers.patch:
  isci: unify remote_device reset_complete_handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0139-isci-unify-remote_device-start_io_handlers.patch:
  isci: unify remote_device start_io_handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0140-isci-unify-remote_device-complete_io_handlers.patch:
  isci: unify remote_device complete_io_handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0141-isci-kill-remote_device-continue_io_handler.patch:
  isci: kill remote_device continue_io_handler
  (FATE#311808,bnc#709528).
- patches.drivers/0142-isci-unify-remote_device-start_task_handlers.patch:
  isci: unify remote_device start_task_handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0143-isci-kill-remote_device-complete_task_handler.patch:
  isci: kill remote_device complete_task_handler
  (FATE#311808,bnc#709528).
- patches.drivers/0144-isci-unify-remote_device-suspend_handlers.patch:
  isci: unify remote_device suspend_handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0145-isci-kill-remote_device-resume_handler.patch:
  isci: kill remote_device resume_handler
  (FATE#311808,bnc#709528).
- patches.drivers/0146-isci-unify-remote_device-event_handlers.patch:
  isci: unify remote_device event_handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0147-isci-unify-remote_device-frame_handlers.patch:
  isci: unify remote_device frame_handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0148-isci-kill-scic_sds_remote_device.state_handlers.patch:
  isci: kill scic_sds_remote_device.state_handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0149-isci-Removing-unused-define-SCIC_SDS_4_ENABLED.patch:
  isci: Removing unused define SCIC_SDS_4_ENABLED
  (FATE#311808,bnc#709528).
- patches.drivers/0150-isci-remove-compile-time-Kconfig-silicon-configur.patch:
  isci: remove compile-time (Kconfig) silicon configuration
  (FATE#311808,bnc#709528).
- patches.drivers/0151-isci-Convert-SATA-fis-data-structures-to-Linux-nati.patch:
  isci: Convert SATA fis data structures to Linux native
  (FATE#311808,bnc#709528).
- patches.drivers/0152-isci-Convert-ATA-defines-to-Linux-native-defines.patch:
  isci: Convert ATA defines to Linux native defines
  (FATE#311808,bnc#709528).
- patches.drivers/0153-isci-Convert-SAS-identify-address-frame-to-Linux-Na.patch:
  isci: Convert SAS identify address frame to Linux Native format
  (FATE#311808,bnc#709528).
- patches.drivers/0154-isci-Collapsing-of-phy_type-data-structure.patch:
  isci: Collapsing of phy_type data structure
  (FATE#311808,bnc#709528).
- patches.drivers/0155-isci-renaming-sas_capabilities-to-scic_phy_cap.patch:
  isci: renaming sas_capabilities to scic_phy_cap
  (FATE#311808,bnc#709528).
- patches.drivers/0156-isci-Fixup-SSP-command-IU-and-task-IU.patch:
  isci: Fixup SSP command IU and task IU (FATE#311808,bnc#709528).
- patches.drivers/0157-isci-Convert-of-sci_ssp_response_iu-to-ssp_response.patch:
  isci: Convert of sci_ssp_response_iu to ssp_response_iu
  (FATE#311808,bnc#709528).
- patches.drivers/0158-isci-Fixup-of-smp-request.patch: isci:
  Fixup of smp request (FATE#311808,bnc#709528).
- patches.drivers/0159-isci-Converting-smp_response-to-Linux-native-smp_re.patch:
  isci: Converting smp_response to Linux native smp_resp
  (FATE#311808,bnc#709528).
- patches.drivers/0160-isci-remove-redundant-copies-of-IAF.patch:
  isci: remove redundant copies of IAF (FATE#311808,bnc#709528).
- patches.drivers/0161-isci-fixup-SAS-iaf-protocols-data-structure.patch:
  isci: fixup SAS iaf protocols data structure
  (FATE#311808,bnc#709528).
- patches.drivers/0162-isci-Remove-SCIC_SWAP_DWORD.patch: isci:
  Remove SCIC_SWAP_DWORD() (FATE#311808,bnc#709528).
- patches.drivers/0163-isci-Using-Linux-SSP-frame-header.patch:
  isci: Using Linux SSP frame header (FATE#311808,bnc#709528).
- patches.drivers/0164-isci-removing-intel_-.h-headers.patch:
  isci: removing intel_*.h headers (FATE#311808,bnc#709528).
- patches.drivers/0165-isci-fix-ata-locking.patch: isci: fix
  ata locking (FATE#311808,bnc#709528).
- patches.drivers/0166-isci-implement-I_T_nexus_reset.patch:
  isci: implement I_T_nexus_reset (FATE#311808,bnc#709528).
- patches.drivers/0167-isci-unify-isci_host-data-structures.patch:
  isci: unify isci_host data structures (FATE#311808,bnc#709528).
- patches.drivers/0168-isci-Removing-unnecessary-functions-in-request.c.patch:
  isci: Removing unnecessary functions in request.c
  (FATE#311808,bnc#709528).
- patches.drivers/0169-isci-kill-scic_controller_get_port_handle-function.patch:
  isci: kill scic_controller_get_port_handle function
  (FATE#311808,bnc#709528).
- patches.drivers/0170-isci-remove-scic_sds_port_increment_request_count.patch:
  isci: remove scic_sds_port_increment_request_count
  (FATE#311808,bnc#709528).
- patches.drivers/0171-isci-rnc-state-machine-table-c99-conversion.patch:
  isci: rnc state machine table c99 conversion
  (FATE#311808,bnc#709528).
- patches.drivers/0172-isci-unify-phy-data-structures.patch:
  isci: unify phy data structures (FATE#311808,bnc#709528).
- patches.drivers/0173-isci-unify-port-data-structures.patch:
  isci: unify port data structures (FATE#311808,bnc#709528).
- patches.drivers/0174-isci-move-stp-request-info-to-scic_sds_request.patch:
  isci: move stp request info to scic_sds_request
  (FATE#311808,bnc#709528).
- patches.drivers/0175-isci-make-sgl-explicit-aligned-request-object-membe.patch:
  isci: make sgl explicit/aligned request object member
  (FATE#311808,bnc#709528).
- patches.drivers/0176-isci-move-task-context-alignment-from-run-time-to-c.patch:
  isci: move task context alignment from run-time to compile time
  (FATE#311808,bnc#709528).
- patches.drivers/0177-isci-make-command-response-iu-explicit-request-obje.patch:
  isci: make command/response iu explicit request object members
  (FATE#311808,bnc#709528).
- patches.drivers/0178-isci-unify-request-data-structures.patch:
  isci: unify request data structures (FATE#311808,bnc#709528).
- patches.drivers/0179-isci-unify-constants.patch: isci: unify
  constants (FATE#311808,bnc#709528).
- patches.drivers/0180-isci-move-core-controller-to-host.patch:
  isci: move core/controller to host (FATE#311808,bnc#709528).
- patches.drivers/0181-isci-uplevel-register-hardware-data-structures-and.patch:
  isci: uplevel register hardware data structures and unsolicited
  frame handling (FATE#311808,bnc#709528).
- patches.drivers/0182-isci-uplevel-state-machine.patch: isci:
  uplevel state machine (FATE#311808,bnc#709528).
- patches.drivers/0183-isci-uplevel-request-infrastructure.patch:
  isci: uplevel request infrastructure (FATE#311808,bnc#709528).
- patches.drivers/0184-isci-uplevel-phy-infrastructure.patch:
  isci: uplevel phy infrastructure (FATE#311808,bnc#709528).
- patches.drivers/0185-isci-uplevel-port-infrastructure.patch:
  isci: uplevel port infrastructure (FATE#311808,bnc#709528).
- patches.drivers/0186-isci-merge-ssp-task-management-substates-into-prima.patch:
  isci: merge ssp task management substates into primary state
  machine (FATE#311808,bnc#709528).
- patches.drivers/0187-isci-merge-smp-request-substates-into-primary-state.patch:
  isci: merge smp request substates into primary state machine
  (FATE#311808,bnc#709528).
- patches.drivers/0188-isci-merge-stp-request-substates-into-primary-state.patch:
  isci: merge stp request substates into primary state machine
  (FATE#311808,bnc#709528).
- patches.drivers/0189-isci-unify-request-abort-handlers.patch:
  isci: unify request abort handlers (FATE#311808,bnc#709528).
- patches.drivers/0190-isci-unify-request-start-handlers.patch:
  isci: unify request start handlers (FATE#311808,bnc#709528).
- patches.drivers/0191-isci-unify-request-frame-handlers.patch:
  isci: unify request frame handlers (FATE#311808,bnc#709528).
- patches.drivers/0192-isci-remove-request-task-context-completion-state-h.patch:
  isci: remove request task context completion state handler
  (FATE#311808,bnc#709528).
- patches.drivers/0193-isci-remove-the-completion-and-event-state-handlers.patch:
  isci: remove the completion and event state handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0194-isci-merge-phy-substates.patch: isci:
  merge phy substates (FATE#311808,bnc#709528).
- patches.drivers/0195-isci-unify-phy-start-handlers.patch:
  isci: unify phy start handlers (FATE#311808,bnc#709528).
- patches.drivers/0196-isci-unify-phy-stop-handlers.patch: isci:
  unify phy stop handlers (FATE#311808,bnc#709528).
- patches.drivers/0197-isci-unify-phy-reset-handlers.patch:
  isci: unify phy reset handlers (FATE#311808,bnc#709528).
- patches.drivers/0198-isci-remove-phy-destruct-handlers.patch:
  isci: remove phy destruct handlers (FATE#311808,bnc#709528).
- patches.drivers/0199-isci-unify-phy-frame-handlers.patch:
  isci: unify phy frame handlers (FATE#311808,bnc#709528).
- patches.drivers/0200-isci-unify-phy-event-handlers.patch:
  isci: unify phy event handlers (FATE#311808,bnc#709528).
- patches.drivers/0201-isci-unify-phy-consume_power-handlers.patch:
  isci: unify phy consume_power handlers (FATE#311808,bnc#709528).
- patches.drivers/0202-isci-clarify-phy-to-port-lookups.patch:
  isci: clarify phy to port lookups (FATE#311808,bnc#709528).
- patches.drivers/0203-isci-c99-port-state-handlers.patch: isci:
  c99 port state handlers (FATE#311808,bnc#709528).
- patches.drivers/0204-isci-merge-port-ready-substates-into-primary-state.patch:
  isci: merge port ready substates into primary state machine
  (FATE#311808,bnc#709528).
- patches.drivers/0205-isci-remove-port-start-handler.patch:
  isci: remove port start handler (FATE#311808,bnc#709528).
- patches.drivers/0206-isci-unify-port-stop-handlers.patch:
  isci: unify port stop handlers (FATE#311808,bnc#709528).
- patches.drivers/0207-isci-remove-port-destruct-handler.patch:
  isci: remove port destruct handler (FATE#311808,bnc#709528).
- patches.drivers/0208-isci-unify-port-reset-add_phy-and-remove_phy-hand.patch:
  isci: unify port reset, add_phy, and remove_phy handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0209-isci-remove-port-frame-and-event-handlers.patch:
  isci: remove port frame and event handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0210-isci-unify-port-link_up-and-link_down-handlers.patch:
  isci: unify port link_up and link_down handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0211-isci-unify-port-start_io-and-complete_io-handlers.patch:
  isci: unify port start_io and complete_io handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0212-isci-unify-rnc-event-handlers.patch:
  isci: unify rnc event handlers (FATE#311808,bnc#709528).
- patches.drivers/0213-isci-unify-rnc-destruct-handlers.patch:
  isci: unify rnc destruct handlers (FATE#311808,bnc#709528).
- patches.drivers/0214-isci-unify-rnc-suspend-resume-handlers.patch:
  isci: unify rnc suspend/resume handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0215-isci-unify-rnc-start-io-task-handlers.patch:
  isci: unify rnc start{io|task} handlers
  (FATE#311808,bnc#709528).
- patches.drivers/0216-isci-add-some-type-safety-to-the-state-machine-inte.patch:
  isci: add some type safety to the state machine interface
  (FATE#311808,bnc#709528).
- patches.drivers/0217-isci-replace-isci_timer-list-with-proper-embedded-t.patch:
  isci: replace isci_timer list with proper embedded timers
  (FATE#311808,bnc#709528).
- patches.drivers/0218-isci-convert-port-config-agent-timer-to-sci_timer.patch:
  isci: convert port config agent timer to sci_timer
  (FATE#311808,bnc#709528).
- patches.drivers/0219-isci-convert-phy-sata_timeout_timer-to-sci_timer.patch:
  isci: convert phy sata_timeout_timer to sci_timer
  (FATE#311808,bnc#709528).
- patches.drivers/0220-isci-convert-power-control-timer-to-sci_timer.patch:
  isci: convert power control timer to sci_timer
  (FATE#311808,bnc#709528).
- patches.drivers/0221-isci-convert-scic_timeout_timer-to-sci_timer.patch:
  isci: convert scic_timeout_timer to sci_timer
  (FATE#311808,bnc#709528).
- patches.drivers/0222-isci-convert-phy_startup_timer-to-sci_timer.patch:
  isci: convert phy_startup_timer to sci_timer
  (FATE#311808,bnc#709528).
- patches.drivers/0223-isci-Remove-tmf-timeout_timer.patch:
  isci: Remove tmf timeout_timer (FATE#311808,bnc#709528).
- patches.drivers/0224-isci-remove-isci_timer-interface.patch:
  isci: remove isci_timer interface (FATE#311808,bnc#709528).
- patches.drivers/0225-isci-removing-the-kmalloc-in-smp-request-construct.patch:
  isci: removing the kmalloc in smp request construct
  (FATE#311808,bnc#709528).
- patches.drivers/0226-isci-Retrieve-the-EFI-variable-for-OEM-parameter.patch:
  isci: Retrieve the EFI variable for OEM parameter
  (FATE#311808,bnc#709528).
- patches.drivers/0227-isci-Removing-unused-variables-compiler-warnings.patch:
  isci: Removing unused variables compiler warnings
  (FATE#311808,bnc#709528).
- patches.drivers/0228-isci-state-machine-cleanup.patch: isci:
  state machine cleanup (FATE#311808,bnc#709528).
- patches.drivers/0229-isci-additional-state-machine-cleanup.patch:
  isci: additional state machine cleanup (FATE#311808,bnc#709528).
- patches.drivers/0230-isci-Added-support-for-C0-to-SCU-Driver.patch:
  isci: Added support for C0 to SCU Driver
  (FATE#311808,bnc#709528).
- patches.drivers/0231-isci-remove-min-memory-infrastructure.patch:
  isci: remove 'min memory' infrastructure
  (FATE#311808,bnc#709528).
- patches.drivers/0232-isci-Move-the-reset-delay-after-the-remote-node-res.patch:
  isci: Move the reset delay after the remote node resumption
  (FATE#311808,bnc#709528).
- patches.drivers/0233-isci-filter-broadcast-change-notifications-during-S.patch:
  isci: filter broadcast change notifications during SMP phy
  resets (FATE#311808,bnc#709528).
- patches.drivers/0234-isci-Add-decode-for-SMP-request-retry-error-conditi.patch:
  isci: Add decode for SMP request retry error condition
  (FATE#311808,bnc#709528).
- patches.drivers/0235-isci-Requests-that-do-not-start-must-be-set-to-com.patch:
  isci: Requests that do not start must be set to "complete"
  (FATE#311808,bnc#709528).
- patches.drivers/0236-isci-Handle-timed-out-request-terminations-correctl.patch:
  isci: Handle timed-out request terminations correctly
  (FATE#311808,bnc#709528).
- patches.drivers/0237-isci-fix-isci_terminate_pending-list-management.patch:
  isci: fix isci_terminate_pending() list management
  (FATE#311808,bnc#709528).
- patches.drivers/0238-isci-Explicitly-decode-remote-node-ready-and-suspen.patch:
  isci: Explicitly decode remote node ready and suspended states
  (FATE#311808,bnc#709528).
- patches.drivers/0239-isci-Hard-reset-failure-will-link-reset-all-phys-in.patch:
  isci: Hard reset failure will link reset all phys in the port
  (FATE#311808,bnc#709528).
- patches.drivers/0240-isci-Disable-link-layer-hang-detection.patch:
  isci: Disable link layer hang detection
  (FATE#311808,bnc#709528).
- patches.drivers/0241-isci-cleanup-optimize-pool-implementation.patch:
  isci: cleanup/optimize pool implementation
  (FATE#311808,bnc#709528).
- patches.drivers/0242-isci-cleanup-tag-macros.patch: isci:
  cleanup tag macros (FATE#311808,bnc#709528).
- patches.drivers/0243-isci-cleanup-optimize-queue-increment-macros.patch:
  isci: cleanup/optimize queue increment macros
  (FATE#311808,bnc#709528).
- patches.drivers/0244-isci-cleanup-request-allocation.patch:
  isci: cleanup request allocation (FATE#311808,bnc#709528).
- patches.drivers/0245-isci-fix-ssp-response-iu-buffer-size-in-isci_tmf.patch:
  isci: fix ssp response iu buffer size in isci_tmf
  (FATE#311808,bnc#709528).
- patches.drivers/0246-isci-atomic-device-lookup-and-reference-counting.patch:
  isci: atomic device lookup and reference counting
  (FATE#311808,bnc#709528).
- patches.drivers/0247-isci-kill-isci_remote_device_change_state.patch:
  isci: kill isci_remote_device_change_state()
  (FATE#311808,bnc#709528).
- patches.drivers/0248-isci-kill-device_sequence.patch: isci:
  kill device_sequence (FATE#311808,bnc#709528).
- patches.drivers/0249-isci-fix-smp-response-frame-overrun.patch:
  isci: fix smp response frame overrun (FATE#311808,bnc#709528).
- patches.drivers/0250-isci-fix-dma_unmap_sg-usage.patch: isci:
  fix dma_unmap_sg usage (FATE#311808,bnc#709528).
- patches.drivers/0251-isci-fix-support-for-arbitrarily-large-smp-requests.patch:
  isci: fix support for arbitrarily large smp requests
  (FATE#311808,bnc#709528).
- patches.drivers/0252-isci-fix-isci_task_execute_tmf-completion.patch:
  isci: fix isci_task_execute_tmf completion
  (FATE#311808,bnc#709528).
- patches.drivers/0253-isci-possible-buffer-overflow-in-isci_parse_oem_par.patch:
  isci: possible buffer overflow in isci_parse_oem_parameters
  fixed (FATE#311808,bnc#709528).
- patches.drivers/0254-isci-fix-frame-received-locking.patch:
  isci: fix frame received locking (FATE#311808,bnc#709528).
- patches.drivers/0255-isci-Terminate-dev-requests-on-FIS-err-bit-rx-in-NC.patch:
  isci: Terminate dev requests on FIS err bit rx in NCQ
  (FATE#311808,bnc#709528).
- patches.drivers/0256-isci-unify-can_queue-tracking-on-the-tci_pool-uple.patch:
  isci: unify can_queue tracking on the tci_pool, uplevel tag
  assignment (FATE#311808,bnc#709528).
- patches.drivers/0257-isci-combine-request-flags.patch: isci:
  combine request flags (FATE#311808,bnc#709528).
- patches.drivers/0258-isci-preallocate-requests.patch: isci:
  preallocate requests (FATE#311808,bnc#709528).
- patches.drivers/0259-isci-rename-clean-up-scic_sds_stp_request.patch:
  isci: rename / clean up scic_sds_stp_request
  (FATE#311808,bnc#709528).
- patches.drivers/0260-isci-unify-isci_request-and-scic_sds_request.patch:
  isci: unify isci_request and scic_sds_request
  (FATE#311808,bnc#709528).
- patches.drivers/0261-isci-unify-isci_phy-and-scic_sds_phy.patch:
  isci: unify isci_phy and scic_sds_phy (FATE#311808,bnc#709528).
- patches.drivers/0262-isci-fix-scic_sds_remote_device_terminate_requests.patch:
  isci: fix scic_sds_remote_device_terminate_requests
  (FATE#311808,bnc#709528).
- patches.drivers/0263-isci-unify-isci_port-and-scic_sds_port.patch:
  isci: unify isci_port and scic_sds_port
  (FATE#311808,bnc#709528).
- patches.drivers/0264-isci-unify-isci_remote_device-and-scic_sds_remote_d.patch:
  isci: unify isci_remote_device and scic_sds_remote_device
  (FATE#311808,bnc#709528).
- patches.drivers/0265-isci-unify-isci_host-and-scic_sds_controller.patch:
  isci: unify isci_host and scic_sds_controller
  (FATE#311808,bnc#709528).
- patches.drivers/0266-isci-retire-scic_sds_-and-scic_-prefixes.patch:
  isci: retire scic_sds_ and scic_ prefixes
  (FATE#311808,bnc#709528).
- patches.drivers/0267-isci-kill-get-set-macros.patch: isci:
  kill 'get/set' macros (FATE#311808,bnc#709528).
- patches.drivers/0268-isci-merge-sata.-ch-into-request.c.patch:
  isci: merge sata.[ch] into request.c (FATE#311808,bnc#709528).
- patches.drivers/0269-isci-merge-scu_unsolicited_frame.h-into-unsolicited.patch:
  isci: merge scu_unsolicited_frame.h into
  unsolicited_frame_control.h (FATE#311808,bnc#709528).
- patches.drivers/0270-isci-cleanup-silicon-revision-detection.patch:
  isci: cleanup silicon revision detection
  (FATE#311808,bnc#709528).
- patches.drivers/0271-isci-pare-back-error-messsages.patch:
  isci: pare back error messsages (FATE#311808,bnc#709528).
- patches.drivers/0272-isci-Device-reset-should-request-sas_phy_reset-phy.patch:
  isci: Device reset should request sas_phy_reset(phy, true)
  (FATE#311808,bnc#709528).
- patches.drivers/0273-isci-fix-checkpatch-errors.patch: isci:
  fix checkpatch errors (FATE#311808,bnc#709528).
- patches.fixes/0001-isci-fix-sata-response-handling.patch:
  isci: fix sata response handling (FATE#311808,bnc#709528).
- patches.fixes/0002-isci-fix-32-bit-operation-when-CONFIG_HIGHMEM64G-n.patch:
  isci: fix 32-bit operation when CONFIG_HIGHMEM64G=n
  (FATE#311808,bnc#709528).
- patches.fixes/0003-isci-change-sas-phy-timeouts-from-54us-to-59us.patch:
  isci: change sas phy timeouts from 54us to 59us
  (FATE#311808,bnc#709528).
- patches.fixes/0004-isci-Adding-documentation-to-API-change-and-fixup-s.patch:
  isci: Adding documentation to API change and fixup sysfs
  registration (FATE#311808,bnc#709528).
- patches.fixes/0005-isci-Leave-requests-alone-if-already-terminating.patch:
  isci: Leave requests alone if already terminating
  (FATE#311808,bnc#709528).
- patches.fixes/0006-isci-dynamic-interrupt-coalescing.patch:
  isci: dynamic interrupt coalescing (FATE#311808,bnc#709528).
- patches.fixes/0007-isci-fix-event-get-pointer-increment.patch:
  isci: fix event-get pointer increment (FATE#311808,bnc#709528).
- patches.fixes/0008-isci-add-version-number.patch: isci: add
  version number (FATE#311808,bnc#709528).
* Mon Aug  1 2011 trenn@suse.de
  Always disable APEI by default:
- patches.drivers/acpi_apei_disable_suse.patch: Refresh.
* Mon Aug  1 2011 duwe@suse.de
- patches.arch/ppc-fate-311687-kmsg_dump: core: Add kernel message
  dumper to call on oopses and panics (bnc#701198, FATE#311687).
- patches.suse/kdump-dump_after_notifier.patch: Refresh.
- patches.arch/ppc-fate-311687-01-kmsg_dump: Delete.
- patches.arch/ppc-fate-311687-02-kmsg_dump_on_kexec: Delete.
* Mon Aug  1 2011 hare@suse.de
- patches.fixes/iscsi_boot_sysfs-have-this-module-check-for-null-on.patch:
  iscsi_boot_sysfs: have this module check for null on destruction
  (bnc#709467).
- patches.fixes/iscsi_ibft-be2iscsi-iscsi_boot-fix-boot-kobj-data.patch:
  iscsi_ibft, be2iscsi, iscsi_boot: fix boot kobj data lifetime
  management (bnc#709467).
- patches.fixes/iscsi_tcp-fix-locking-around-iscsi-sk-user-data.patch:
  iscsi_tcp: fix locking around iscsi sk user data (bnc#709467).
- patches.fixes/libiscsi_tcp-fix-LLD-data-allocation.patch:
  libiscsi_tcp: fix LLD data allocation (bnc#709467).
* Mon Aug  1 2011 hare@suse.de
- patches.drivers/cnic-Add-VLAN-ID-as-a-parameter-during-netevent-upca.patch:
  cnic: Add VLAN ID as a parameter during netevent upcall
  (bnc#709068).
- patches.fixes/kvm-stable-fix-information-leak-to-userland.patch:
  Fixup for series2git.
- patches.xen/xen3-patch-2.6.30: Fixup for series2git.
* Sat Jul 30 2011 tonyj@suse.de
- Update config files (add HAVE_MIXED_BREAKPOINTS_REGS for ppc64 hw breakpt)
- Fix debug/trace build errors in latest ibm submission:
  add patches.fixes/ksym_tracer_increment_count_race.patch
  add patches.fixes/ksym_tracer_remove_trace_stat.patch
  refresh patches.suse/ppc64-hwbp-15.patch
* Sat Jul 30 2011 mmarek@suse.cz
- Update config files: Disable VMXNET3 on !X86.
* Fri Jul 29 2011 mmarek@suse.cz
- patches.drivers/0001-vmxnet-trivial-annotation-of-protocol-constant.patch:
  vmxnet: trivial annotation of protocol constant (bnc#674189,
  fate#311981).
- patches.drivers/0002-net-Getting-rid-of-the-x86-dependency-to-built-vmxne.patch:
  net: Getting rid of the x86 dependency to built vmxnet3
  (bnc#674189, fate#311981).
- patches.drivers/0003-drivers-net-Move-and-to-end-of-previous-line.patch:
  drivers/net: Move && and || to end of previous line (bnc#674189,
  fate#311981).
- patches.drivers/0004-drivers-net-use-DEFINE_PCI_DEVICE_TABLE.patch:
  drivers/net/: use DEFINE_PCI_DEVICE_TABLE() (bnc#674189,
  fate#311981).
- patches.drivers/0005-net-use-netdev_mc_count-and-netdev_mc_empty-when-app.patch:
  net: use netdev_mc_count and netdev_mc_empty when appropriate
  (bnc#674189, fate#311981).
- patches.drivers/0006-net-convert-multiple-drivers-to-use-netdev_for_each_.patch:
  net: convert multiple drivers to use netdev_for_each_mc_addr,
  part6 (bnc#674189, fate#311981).
- patches.drivers/0007-drivers-net-last_rx-elimination.patch:
  drivers: net: last_rx elimination (bnc#674189, fate#311981).
- patches.drivers/0008-net-trans_start-cleanups.patch: net:
  trans_start cleanups (bnc#674189, fate#311981).
- patches.drivers/0009-drivers-net-vmxnet3-Use-kzalloc.patch:
  drivers/net/vmxnet3: Use kzalloc (bnc#674189, fate#311981).
- patches.drivers/0010-vmxnet3-fail-when-try-to-setup-unsupported-features.patch:
  vmxnet3: fail when try to setup unsupported features
  (bnc#674189, fate#311981).
- patches.drivers/0011-vmxnet3-remove-duplicate-include.patch:
  vmxnet3: remove duplicate #include (bnc#674189, fate#311981).
- patches.drivers/0015-vmxnet3-make-bit-twiddle-routines-inline.patch:
  vmxnet3: make bit twiddle routines inline (bnc#674189,
  fate#311981).
- patches.drivers/0016-vmxnet3-Remove-incorrect-implementation-of-ethtool_o.patch:
  vmxnet3: Remove incorrect implementation of
  ethtool_ops::get_flags() (bnc#674189, fate#311981).
- patches.drivers/0017-vmxnet3-annotate-hwaddr-members-as-__iomem-pointers.patch:
  vmxnet3: annotate hwaddr members as __iomem pointers
  (bnc#674189, fate#311981).
- patches.drivers/0018-vmxnet3-fix-typo-setting-confPA.patch:
  vmxnet3: fix typo setting confPA (bnc#674189, fate#311981).
- patches.drivers/0019-vmxnet3-remove-set_flag_le-16-64-helpers.patch:
  vmxnet3: remove set_flag_le{16,64} helpers (bnc#674189,
  fate#311981).
- patches.drivers/0020-vmxnet3-remove-unnecessary-byteswapping-in-BAR-writi.patch:
  vmxnet3: remove unnecessary byteswapping in BAR writing macros
  (bnc#674189, fate#311981).
- patches.drivers/0027-net-next-Add-multiqueue-support-to-vmxnet3-driver.patch:
  net-next: Add multiqueue support to vmxnet3 driver (bnc#674189,
  fate#311981).
- patches.drivers/0028-vmxnet3-fix-compilation-when-RSS-is-disabled.patch:
  vmxnet3: fix compilation when RSS is disabled (bnc#674189,
  fate#311981).
- patches.drivers/0029-drivers-net-don-t-use-flush_scheduled_work.patch:
  drivers/net: don't use flush_scheduled_work() (bnc#674189,
  fate#311981).
- patches.drivers/0031-net-Fix-drivers-advertising-HW_CSUM-feature-to-use-c.patch:
  net: Fix drivers advertising HW_CSUM feature to use csum_start.
- patches.drivers/0032-vmxnet3-locking-problems-in-xmit.patch:
  vmxnet3: locking problems in xmit (bnc#674189, fate#311981).
- patches.drivers/0033-drivers-net-Use-static-const.patch:
  drivers/net/*/: Use static const (bnc#674189, fate#311981).
- patches.drivers/0034-vmxnet3-fix-ring-size-update.patch:
  vmxnet3: fix ring size update (bnc#674189, fate#311981).
- patches.drivers/0035-vmxnet3-Preserve-the-MAC-address-configured-by-ifcon.patch:
  vmxnet3: Preserve the MAC address configured by ifconfig
  (bnc#674189, fate#311981).
- patches.drivers/0036-vmxnet3-Enable-HW-Rx-VLAN-stripping-by-default.patch:
  vmxnet3: Enable HW Rx VLAN stripping by default (bnc#674189,
  fate#311981).
- patches.drivers/0037-vmxnet3-Provide-required-number-of-bytes-in-first-SG.patch:
  vmxnet3: Provide required number of bytes in first SG buffer
  (bnc#674189, fate#311981).
- patches.drivers/0038-vmxnet3-Make-ethtool-handlers-multiqueue-aware.patch:
  vmxnet3: Make ethtool handlers multiqueue aware (bnc#674189,
  fate#311981).
- patches.drivers/0039-vmxnet3-Disable-napi-in-suspend-reenable-in-resume.patch:
  vmxnet3: Disable napi in suspend, reenable in resume
  (bnc#674189, fate#311981).
- patches.drivers/0040-vmxnet3-Add-locking-for-access-to-command-register.patch:
  vmxnet3: Add locking for access to command register (bnc#674189,
  fate#311981).
- patches.drivers/0041-vmxnet3-Dont-allocate-extra-MSI-x-vectors.patch:
  vmxnet3: Dont allocate extra MSI-x vectors (bnc#674189,
  fate#311981).
- patches.drivers/0042-Fix-common-misspellings.patch: Fix common
  misspellings (bnc#674189, fate#311981).
- patches.drivers/0043-vmxnet3-Consistently-disable-irqs-when-taking-adapte.patch:
  vmxnet3: Consistently disable irqs when taking adapter->cmd_lock
  (bnc#674189, fate#311981).
- patches.drivers/0044-vmxnet3-Use-single-tx-queue-when-CONFIG_PCI_MSI-not-.patch:
  vmxnet3: Use single tx queue when CONFIG_PCI_MSI not defined
  (bnc#674189, fate#311981).
- patches.drivers/0045-vmxnet3-fix-starving-rx-ring-whenoc_skb-kb-fails.patch:
  vmxnet3: fix starving rx ring whenoc_skb kb fails (bnc#674189,
  fate#311981).
- patches.drivers/0046-vmxnet3-round-down-of-queues-to-power-of-two.patch:
  vmxnet3: round down # of queues to power of two (bnc#674189,
  fate#311981).
- patches.xen/xen3-patch-2.6.32: Refresh.
* Fri Jul 29 2011 tonyj@suse.de
- patches.fixes/oprofile_bios_ctr.patch: Delete
  Obsoleted by following 2 upstream patches:
  oprofile-007-x86-warn-user-if-a-counter-is-already-activ.patch
  oprofile-008-x86-add-comment-to-counter-in-use-warning.patch
* Fri Jul 29 2011 tonyj@suse.de
- Delete patches obsoleted by previous PEBS checkin (fate#311939)
  patches.suse/perf-0261-x86-Undo-some-some-_counter-_event-renames.patch
  patches.suse/perf-0262-x86-implement-ARCH_PERFMON_EVENTSEL-bit-masks.patch
  patches.suse/perf-0270-x86-Use-helper-function-in-x86_pmu_enable_all.patch
  patches.suse/perf-0271-x86-Calculate-perfctr-msr-addresses-in-helper-f.patch
  patches.suse/perf-0272-x86-Add-new-AMD-family-15h-msrs-to-perfctr-rese.patch
  patches.suse/perf-0273-x86-Store-perfctr-msr-addresses-in-config_base-.patch
  patches.suse/perf-0274-x86-Add-support-for-AMD-family-15h-core-counter.patch
  patches.suse/perf-0275-x86-Fix-pre-defined-cache-misses-event-for-AMD-.patch
  patches.suse/perf-0276-x86-Fix-AMD-family-15h-FPU-event-constraints.patch
* Fri Jul 29 2011 tonyj@suse.de
- Rework ppc64 hardware break point patches.
  patches.suse/ppc64-hardware-breakpoints.patch: Delete original
  patches.suse/ppc64-hwbp-{1-24}.patch: Add new series split by commit
- patches.xen/xen3-patch-2.6.30: Refresh.
* Fri Jul 29 2011 mmarek@suse.cz
- patches.suse/ethtool-Add-support-for-control-of-RX-flow-hash-indi.patch:
  ethtool: Add support for control of RX flow hash indirection
  (bnc#674189, fate#311981).
- patches.suse/ethtool-Fix-filter-addition-when-caching-n-tuple-fil.patch:
  ethtool: Fix filter addition when caching n-tuple filters
  (bnc#674189, fate#311981).
- patches.suse/net-Introduce-skb_checksum_start_offset.patch: net:
  Introduce skb_checksum_start_offset() (bnc#674189, fate#311981).
* Fri Jul 29 2011 duwe@suse.de
- patches.arch/ppc-early-scan_dispatch_log-safeguard: powerpc:
  Fix oops if scan_dispatch_log is called too early (bnc#707988).
- patches.drivers/ibmvscsi_recover_reset_notready: ibmvscsi:
  Improve CRQ reset reliability (bnc#708809).
* Fri Jul 29 2011 mmarek@suse.cz
- patches.drivers/0166-bnx2x-Look-inside-vlan-when-determining-checksum-pro.patch:
  Refresh.
- patches.suse/vlan-Add-function-to-retrieve-EtherType-from-vlan-packets:
  vlan: Add function to retrieve EtherType from vlan packets
  (bnc#691742, fate#311957).
* Fri Jul 29 2011 mmarek@suse.cz
- patches.drivers/0142-tg3-implement-ethtool-set_phys_id.patch:
  Refresh.
- patches.drivers/cxgb4-chelsio-t4-driver-compat: Refresh.
- patches.suse/0001-ethtool-Add-reset-operation: [PATCHv2 1/8]
  ethtool: Add reset operation (bnc#691742, fate#311957).
- patches.suse/0002-ethtool-Introduce-n-tuple-filter-programming-support:
  [PATCHv2 2/8] ethtool: Introduce n-tuple filter programming
  support (bnc#691742, fate#311957).
- patches.suse/0003-ethtool-Fix-includes-build-break:
  [PATCHv2 3/8] ethtool: Fix includes build break (bnc#691742,
  fate#311957).
- patches.suse/0004-netdev-ethtool-RXHASH-flag: [PATCHv2 4/8]
  netdev: ethtool RXHASH flag (bnc#691742, fate#311957).
- patches.suse/0005-ethtool-Add-support-for-vlan-accleration:
  [PATCHv2 5/8] ethtool: Add support for vlan accleration
  (bnc#691742, fate#311957).
- patches.suse/0007-ethtool-Change-ETHTOOL_PHYS_ID-implementation-to-allow-dropping-RTNL:
  [PATCHv2 7/8] ethtool: Change ETHTOOL_PHYS_ID implementation
  to allow dropping RTNL (bnc#691742, fate#311957).
* Fri Jul 29 2011 mgalbraith@suse.de
- Add a realtime debug and/or safety net boot option.  If the
  user runs a 100%% CPU hog on a box booted with rtsched_debug
  option, the box will survive and warn.
- patches.fixes/sched-rtsched_debug-boot-option.patch:
  Add rtsched_debug boot option (bnc#708730).
- patches.arch/bug-610783_uv_nortsched_boot_option.patch: Refresh.
* Fri Jul 29 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete intel-e1000e-kmp after e1000e
  has been updated.
* Fri Jul 29 2011 trenn@suse.de
- patches.fixes/x86_mtrr_fix_deadlock_condition.patch: Update
  references (bnc#706410).
* Fri Jul 29 2011 trenn@suse.de
  Replace patch with x86-tip patch fixing online/offline cpu issues
  by using cpu_active instead of online (bnc#706410):
- patches.fixes/x86_mtrr_fix_deadlock_condition.patch: x86,
  mtrr: lock stop machine during MTRR rendezvous sequence.
- patches.fixes/010-numa-hotadd.patch: Delete.
* Fri Jul 29 2011 jack@suse.cz
- patches.fixes/mm-remove-unused-nonblocking-and-congestion-checks.patch:
  Refresh.
- patches.fixes/writeback-avoid-unnecessary-determine_dirtyable_memo.patch:
  writeback: avoid unnecessary determine_dirtyable_memory call
  (bnc#699354).
- patches.fixes/writeback-balance_dirty_pages-reduce-calls-to-global.patch:
  writeback: balance_dirty_pages(): reduce calls to
  global_page_state (bnc#699354).
- patches.fixes/writeback-limit-write_cache_pages-integrity-scanning.patch:
  writeback: limit write_cache_pages integrity scanning to
  current EOF (bnc#699354).
- patches.fixes/xfs-handle-negative-wbc-nr_to_write-during-sync-writ.patch:
  xfs: handle negative wbc->nr_to_write during sync writeback
  (bnc#699354).
- patches.fixes/xfs-remove-nr_to_write-writeback-windup.patch:
  xfs: remove nr_to_write writeback windup (bnc#699354).
* Fri Jul 29 2011 jack@suse.cz
- patches.fixes/mm-remove-unused-nonblocking-and-congestion-checks.patch:
  Refresh.
- patches.fixes/writeback-avoid-unnecessary-determine_dirtyable_memo.patch:
  writeback: avoid unnecessary determine_dirtyable_memory call
  (bnc#699354).
- patches.fixes/writeback-balance_dirty_pages-reduce-calls-to-global.patch:
  writeback: balance_dirty_pages(): reduce calls to
  global_page_state (bnc#699354).
- patches.fixes/writeback-limit-write_cache_pages-integrity-scanning.patch:
  writeback: limit write_cache_pages integrity scanning to
  current EOF (bnc#699354).
- patches.fixes/xfs-handle-negative-wbc-nr_to_write-during-sync-writ.patch:
  xfs: handle negative wbc->nr_to_write during sync writeback
  (bnc#699354).
- patches.fixes/xfs-remove-nr_to_write-writeback-windup.patch:
  xfs: remove nr_to_write writeback windup (bnc#699354).
* Fri Jul 29 2011 jslaby@suse.de
- patches.fixes/tg3-Fix-io-failures-after-chip-reset.patch: tg3:
  Fix io failures after chip reset (bnc#705962).
* Fri Jul 29 2011 dsterba@suse.cz
- patches.suse/btrfs-do-not-allow-mounting-non-subvolumes-via-subvol.patch:
  btrfs: do not allow mounting non-subvolumes via subvol option
  (bnc#703204).
* Fri Jul 29 2011 jkosina@suse.cz
- series.conf: add forgotten
  patches.xen/xen3-intel-additional-Intel-Cougar-Point.patch
* Fri Jul 29 2011 oneukum@suse.de
- patches.drivers/0001-V4L-DVB-uvc-Enable-USB-autosuspend-by-default-on-uvc.patch:
  Enabling USB autosuspend for uvc devices.
  This was overlooked in the big backport.
* Fri Jul 29 2011 jankit@suse.de
- supported.conf: Mark sgiioc4 ide driver as supported
  (bnc#706913).
* Fri Jul 29 2011 mmarek@suse.cz
- e1000e update (fate#311825):
- patches.drivers/0001-e1000e-Use-the-instance-of-net_device_stats-from-net.patch:
  e1000e: Use the instance of net_device_stats from net_device
  (bnc#699092, fate#311825).
- patches.drivers/0003-e1000e-Fix-erroneous-display-of-stats-by-ethtool-S.patch:
  e1000e: Fix erroneous display of stats by ethtool -S
  (bnc#699092, fate#311825).
- patches.drivers/0006-e1000e-check-WoL-mode-is-among-set-of-supported-mode.patch:
  e1000e: check WoL mode is among set of supported modes
  (bnc#699092, fate#311825).
- patches.drivers/0007-e1000e-add-missing-tests-for-82583-in-ethtool-functi.patch:
  e1000e: add missing tests for 82583 in ethtool functions
  (bnc#699092, fate#311825).
- patches.drivers/0008-e1000e-clearing-interrupt-timers-causes-descriptors-.patch:
  e1000e: clearing interrupt timers causes descriptors to get
  flushed (bnc#699092, fate#311825).
- patches.drivers/0009-e1000e-function-pointers-for-ethtool-set-get-offload.patch:
  e1000e: function pointers for ethtool set/get offloads
  (bnc#699092, fate#311825).
- patches.drivers/0010-e1000e-don-t-clean-Rx-ring-while-resetting.patch:
  e1000e: don't clean Rx ring while resetting (bnc#699092,
  fate#311825).
- patches.drivers/0011-e1000e-link-reporting-problems.patch:
  e1000e: link reporting problems (bnc#699092, fate#311825).
- patches.drivers/0012-e1000e-improper-return-code-signage.patch:
  e1000e: improper return code signage (bnc#699092, fate#311825).
- patches.drivers/0013-e1000e-disable-K1-on-PCH-LOM-when-in-PHY-loopback-mo.patch:
  e1000e: disable K1 on PCH LOM when in PHY loopback mode
  (bnc#699092, fate#311825).
- patches.drivers/0014-e1000e-Incorrect-MII-Link-beat-reporting.patch:
  e1000e: Incorrect MII Link beat reporting (bnc#699092,
  fate#311825).
- patches.drivers/0015-e1000e-cleanup-redundant-include-s.patch:
  e1000e: cleanup redundant #include's (bnc#699092, fate#311825).
- patches.drivers/0016-e1000e-consolidate-two-dbug-macros-into-one-simpler-.patch:
  e1000e: consolidate two dbug macros into one simpler one
  (bnc#699092, fate#311825).
- patches.drivers/0017-e1000e-cleanup-ops-function-pointers.patch:
  e1000e: cleanup ops function pointers (bnc#699092, fate#311825).
- patches.drivers/0018-e1000e-update-copyright-information.patch:
  e1000e: update copyright information (bnc#699092, fate#311825).
- patches.drivers/0019-e1000e-remove-comments-regarding-a-non-existent-api-.patch:
  e1000e: remove comments regarding a non-existent api module
  (bnc#699092, fate#311825).
- patches.drivers/0020-e1000e-provide-comment-for-82571-workaround.patch:
  e1000e: provide comment for 82571 workaround (bnc#699092,
  fate#311825).
- patches.drivers/0021-e1000e-set-bools-to-true-false-instead-of-1-0.patch:
  e1000e: set bools to true/false instead of 1/0 (bnc#699092,
  fate#311825).
- patches.drivers/0022-e1000e-cleanup-shift-indentation-left-by-exiting-ear.patch:
  e1000e: cleanup - shift indentation left by exiting early in
  e1000_tso (bnc#699092, fate#311825).
- patches.drivers/0023-e1000e-cleanup-functions-that-clear-hardware-statist.patch:
  e1000e: cleanup functions that clear hardware statistics
  (bnc#699092, fate#311825).
- patches.drivers/0024-e1000e-set-pm_qos-DMA-latency-requirement-per-interf.patch:
  e1000e: set pm_qos DMA latency requirement per interface when
  needed (bnc#699092, fate#311825).
- patches.drivers/0025-e1000e-do-not-error-out-on-identification-LED-init-f.patch:
  e1000e: do not error out on identification LED init failure
  (bnc#699092, fate#311825).
- patches.drivers/0026-e1000e-remove-redundant-might_sleep.patch:
  e1000e: remove redundant might_sleep() (bnc#699092,
  fate#311825).
- patches.drivers/0027-e1000e-cosmetic-group-local-variables-of-the-same-ty.patch:
  e1000e: cosmetic - group local variables of the same type
  (bnc#699092, fate#311825).
- patches.drivers/0028-e1000e-update-Tx-Unit-hang-detection-message.patch:
  e1000e: update Tx Unit hang detection message (bnc#699092,
  fate#311825).
- patches.drivers/0029-e1000e-provide-family-specific-functions-to-manage-V.patch:
  e1000e: provide family-specific functions to manage VLAN filter
  arrays (bnc#699092, fate#311825).
- patches.drivers/0030-e1000e-guard-against-buffer-overflow-in-cable-length.patch:
  e1000e: guard against buffer overflow in cable length tables
  (bnc#699092, fate#311825).
- patches.drivers/0031-e1000e-provide-family-specific-PHY-power-up-down-ope.patch:
  e1000e: provide family-specific PHY power up/down operations
  (bnc#699092, fate#311825).
- patches.drivers/0032-e1000e-ensure-the-link-state-is-correct-for-serdes-l.patch:
  e1000e: ensure the link state is correct for serdes links
  (bnc#699092, fate#311825).
- patches.drivers/0034-e1000e-comment-corrections.patch: e1000e:
  comment corrections (bnc#699092, fate#311825).
- patches.drivers/0035-e1000e-add-debug-messages.patch: e1000e:
  add debug messages (bnc#699092, fate#311825).
- patches.drivers/0036-e1000e-PHY-type-cleanups-in-e1000e_check_downshift.patch:
  e1000e: PHY type cleanups in e1000e_check_downshift()
  (bnc#699092, fate#311825).
- patches.drivers/0037-e1000e-Use-sizeof-struct-rather-than-pointer-in-e100.patch:
  e1000e: Use sizeof struct rather than pointer in
  e1000_get_eeprom() (bnc#699092, fate#311825).
- patches.drivers/0039-e1000e-check_polarity-function-pointers-not-set-for-.patch:
  e1000e: check_polarity function pointers not set for 8257x
  (bnc#699092, fate#311825).
- patches.drivers/0040-e1000e-refactor-PHY-ID-detection-workaround.patch:
  e1000e: refactor PHY ID detection workaround (bnc#699092,
  fate#311825).
- patches.drivers/0041-e1000e-correct-ICH-PCH-PHY-operations-function-point.patch:
  e1000e: correct ICH/PCH PHY operations function pointers
  (bnc#699092, fate#311825).
- patches.drivers/0043-e1000e-minor-correction-to-name-of-bit-in-CTRL_EXT-r.patch:
  e1000e: minor correction to name of bit in CTRL_EXT register
  (bnc#699092, fate#311825).
- patches.drivers/0044-e1000e-replace-incorrect-use-of-GG82563_REG-macro.patch:
  e1000e: replace incorrect use of GG82563_REG macro (bnc#699092,
  fate#311825).
- patches.drivers/0045-e1000e-only-perform-ESB2-MDIC-workaround-on-certain-.patch:
  e1000e: only perform ESB2 MDIC workaround on certain
  configurations (bnc#699092, fate#311825).
- patches.drivers/0046-e1000e-LED-settings-in-EEPROM-ignored-on-82571-and-8.patch:
  e1000e: LED settings in EEPROM ignored on 82571 and 82572
  (bnc#699092, fate#311825).
- patches.drivers/0049-e1000e-don-t-accumulate-PHY-statistics-on-PHY-read-f.patch:
  e1000e: don't accumulate PHY statistics on PHY read failure
  (bnc#699092, fate#311825).
- patches.drivers/0050-e1000e-perform-10-100-adaptive-IFS-only-on-parts-tha.patch:
  e1000e: perform 10/100 adaptive IFS only on parts that support
  it (bnc#699092, fate#311825).
- patches.drivers/0051-e1000e-e1000e_enable_tx_pkt_filtering-returns-wrong-.patch:
  e1000e: e1000e_enable_tx_pkt_filtering() returns wrong value
  (bnc#699092, fate#311825).
- patches.drivers/0052-e1000e-fix-and-commonize-code-for-setting-the-receiv.patch:
  e1000e: fix and commonize code for setting the receive address
  registers (bnc#699092, fate#311825).
- patches.drivers/0053-e1000e-MDIO-slow-mode-should-always-be-done-for-8257.patch:
  e1000e: MDIO slow mode should always be done for 82577
  (bnc#699092, fate#311825).
- patches.drivers/0054-e1000e-workaround-link-issues-on-busy-hub-in-half-du.patch:
  e1000e: workaround link issues on busy hub in half duplex on
  82577/82578 (bnc#699092, fate#311825).
- patches.drivers/0055-e1000e-use-alternate-MAC-address-on-ESB2-if-availabl.patch:
  e1000e: use alternate MAC address on ESB2 if available
  (bnc#699092, fate#311825).
- patches.drivers/0056-e1000e-provide-MAC-family-specific-function-to-set-L.patch:
  e1000e: provide MAC-family-specific function to set LAN ID
  (bnc#699092, fate#311825).
- patches.drivers/0057-e1000e-genericize-the-update-multicast-address-list.patch:
  e1000e: genericize the update multicast address list
  (bnc#699092, fate#311825).
- patches.drivers/0058-e1000-e1000e-igb-igbvf-ixgb-ixgbe-Fix-tests-of-unsig.patch:
  e1000/e1000e/igb/igbvf/ixgb/ixgbe: Fix tests of unsigned in
  * _tx_map() (bnc#699092, fate#311825).
- patches.drivers/0061-net-Fix-IPv6-GSO-type-checks-in-Intel-ethernet-drive.patch:
  net: Fix IPv6 GSO type checks in Intel ethernet drivers
  (bnc#699092, fate#311825).
- patches.drivers/0062-e1000e-Fix-namespace-conflicts-wrt.-e1000_has_link.patch:
  e1000e: Fix namespace conflicts wrt. e1000_has_link (bnc#699092,
  fate#311825).
- patches.drivers/0063-net-e1000e-convert-to-use-mc-helpers.patch:
  net: e1000e: convert to use mc helpers (bnc#699092,
  fate#311825).
- patches.drivers/0064-tree-wide-Assorted-spelling-fixes.patch:
  tree-wide: Assorted spelling fixes (bnc#699092, fate#311825).
- patches.drivers/0065-e1000e-fix-packet-corruption-and-tx-hang-during-NFSv.patch:
  e1000e: fix packet corruption and tx hang during NFSv2
  (bnc#699092, fate#311825).
- patches.drivers/0069-e1000e-do-not-modify-tx_queue_len-on-link-speed-chan.patch:
  e1000e: do not modify tx_queue_len on link speed change
  (bnc#699092, fate#311825).
- patches.drivers/0070-e1000e-Use-pr_-level-and-netdev_-level.patch:
  e1000e: Use pr_<level> and netdev_<level> (bnc#699092,
  fate#311825).
- patches.drivers/0071-include-cleanup-Update-gfp.h-and-slab.h-includes-to-.patch:
  include cleanup: Update gfp.h and slab.h includes to prepare for
  breaking implicit slab.h inclusion from percpu.h (bnc#699092,
  fate#311825).
- patches.drivers/0072-e1000e-typo-corrections.patch: e1000e:
  typo corrections (bnc#699092, fate#311825).
- patches.drivers/0074-e1000e-use-static-params-to-save-stack-space.patch:
  e1000e: use static params to save stack space (bnc#699092,
  fate#311825).
- patches.drivers/0076-drivers-net-use-skb_headlen.patch: drivers:
  net: use skb_headlen() (bnc#699092, fate#311825).
- patches.drivers/0077-e1000e-enable-disable-ASPM-L0s-and-L1-and-ERT-accord.patch:
  e1000e: enable/disable ASPM L0s and L1 and ERT according to
  hardware errata (bnc#699092, fate#311825).
- patches.drivers/0079-e1000e-add-registers-etc.-printout-code-just-before-.patch:
  e1000e: add registers etc. printout code just before resetting
  adapters (bnc#699092, fate#311825).
- patches.drivers/0080-e1000e-Fix-oops-caused-by-ASPM-patch.patch:
  e1000e: Fix oops caused by ASPM patch (bnc#699092, fate#311825).
- patches.drivers/0081-e1000e-save-skb-counts-in-TX-to-avoid-cache-misses.patch:
  e1000e: save skb counts in TX to avoid cache misses (bnc#699092,
  fate#311825).
- patches.drivers/0082-e1000e-reduce-writes-of-RX-producer-ptr.patch:
  e1000e: reduce writes of RX producer ptr (bnc#699092,
  fate#311825).
- patches.drivers/0083-e1000e-Remove-unnessary-log-message.patch:
  e1000e: Remove unnessary log message (bnc#699092, fate#311825).
- patches.drivers/0084-e1000e-Save-irq-into-netdev-structure.patch:
  e1000e: Save irq into netdev structure (bnc#699092,
  fate#311825).
- patches.drivers/0085-e1000e-increase-rx-fifo-size-to-36K-on-82574-and-825.patch:
  e1000e: increase rx fifo size to 36K on 82574 and 82583
  (bnc#699092, fate#311825).
- patches.drivers/0086-e1000-e1000e-implement-a-simple-interrupt-moderation.patch:
  e1000/e1000e: implement a simple interrupt moderation
  (bnc#699092, fate#311825).
- patches.drivers/0087-e1000e-reset-MAC-PHY-interconnect-on-82577-82578-dur.patch:
  e1000e: reset MAC-PHY interconnect on 82577/82578 during Sx->S0
  (bnc#699092, fate#311825).
- patches.drivers/0088-e1000e-Reset-82577-82578-PHY-before-first-PHY-regist.patch:
  e1000e: Reset 82577/82578 PHY before first PHY register read
  (bnc#699092, fate#311825).
- patches.drivers/0090-e1000e-use-static-params-to-save-stack-space-part-2.patch:
  e1000e: use static params to save stack space (part 2)
  (bnc#699092, fate#311825).
- patches.drivers/0091-e1000e-bad-state-after-running-ethtool-diagnostics-w.patch:
  e1000e: bad state after running ethtool diagnostics with AMT
  enabled (bnc#699092, fate#311825).
- patches.drivers/0092-e1000e-initialize-manageability-IPMI-pass-through-in.patch:
  e1000e: initialize manageability (IPMI) pass-through in
  82574/82583 (bnc#699092, fate#311825).
- patches.drivers/0093-e1000e-s-w-initiated-LSC-MSI-X-interrupts-not-genera.patch:
  e1000e: s/w initiated LSC MSI-X interrupts not generated;
  no transmit (bnc#699092, fate#311825).
- patches.drivers/0094-e1000e-cleanup-multiple-common-exit-points.patch:
  e1000e: cleanup multiple common exit points (bnc#699092,
  fate#311825).
- patches.drivers/0095-e1000e-Remove-EN_MAC_ADDR_FILTER-check-from-enable_m.patch:
  e1000e: Remove EN_MAC_ADDR_FILTER check from
  enable_mng_pass_thru check (bnc#699092, fate#311825).
- patches.drivers/0096-e1000e-Cleanup-e1000_sw_lcd_config_ich8lan.patch:
  e1000e: Cleanup e1000_sw_lcd_config_ich8lan() (bnc#699092,
  fate#311825).
- patches.drivers/0097-e1000e-Incorrect-function-pointer-set-for-force_spee.patch:
  e1000e: Incorrect function pointer set for force_speed_duplex
  on 82577 (bnc#699092, fate#311825).
- patches.drivers/0098-e1000e-fix-checks-for-manageability-enabled-and-mana.patch:
  e1000e: fix checks for manageability enabled and management
  pass-through (bnc#699092, fate#311825).
- patches.drivers/0099-e1000e-move-settting-of-flow-control-refresh-timer-t.patch:
  e1000e: move settting of flow control refresh timer to link
  setup code (bnc#699092, fate#311825).
- patches.drivers/0100-e1000e-Fix-cleanup-PHY-reset-code-for-ICHx-PCHx.patch:
  e1000e: Fix/cleanup PHY reset code for ICHx/PCHx (bnc#699092,
  fate#311825).
- patches.drivers/0101-e1000e-add-PCI-device-id-to-enable-support-for-82567.patch:
  e1000e: add PCI device id to enable support for 82567V-4
  (bnc#699092, fate#311825).
- patches.drivers/0102-drivers-net-Remove-unnecessary-returns-from-void-fun.patch:
  drivers/net: Remove unnecessary returns from void function()s
  (bnc#699092, fate#311825).
- patches.drivers/0103-e1000e-change-logical-negate-to-bitwise.patch:
  e1000e: change logical negate to bitwise (bnc#699092,
  fate#311825).
- patches.drivers/0104-e1000e-cleanup-ethtool-loopback-setup-code.patch:
  e1000e: cleanup ethtool loopback setup code (bnc#699092,
  fate#311825).
- patches.drivers/0105-e1000e-cleanup-e1000_sw_lcd_config_ich8lan.patch:
  e1000e: cleanup e1000_sw_lcd_config_ich8lan() (bnc#699092,
  fate#311825).
- patches.drivers/0106-e1000e-separate-out-PHY-statistics-register-updates.patch:
  e1000e: separate out PHY statistics register updates
  (bnc#699092, fate#311825).
- patches.drivers/0107-e1000e-fix-check-for-manageability-on-ICHx-PCH.patch:
  e1000e: fix check for manageability on ICHx/PCH (bnc#699092,
  fate#311825).
- patches.drivers/0108-e1000e-initial-support-for-82579-LOMs.patch:
  e1000e: initial support for 82579 LOMs (bnc#699092,
  fate#311825).
- patches.drivers/0109-e1000e-enable-support-for-EEE-on-82579.patch:
  e1000e: enable support for EEE on 82579 (bnc#699092,
  fate#311825).
- patches.drivers/0110-e1000e-update-copyright-information.patch:
  e1000e: update copyright information (bnc#699092, fate#311825).
- patches.drivers/0111-e1000e-update-driver-version-number.patch:
  e1000e: update driver version number (bnc#699092, fate#311825).
- patches.drivers/0112-e1000e-avoid-polling-h-w-registers-during-link-negot.patch:
  e1000e: avoid polling h/w registers during link negotiation
  (bnc#699092, fate#311825).
- patches.drivers/0113-e1000e-do-not-touch-PHY-page-800-registers-when-link.patch:
  e1000e: do not touch PHY page 800 registers when link speed
  is 1000Mbps (bnc#699092, fate#311825).
- patches.drivers/0114-e1000e-packet-split-should-not-be-used-with-early-re.patch:
  e1000e: packet split should not be used with early receive
  (bnc#699092, fate#311825).
- patches.drivers/0115-e1000e-disable-gig-speed-when-in-S0-Sx-transition.patch:
  e1000e: disable gig speed when in S0->Sx transition (bnc#699092,
  fate#311825).
- patches.drivers/0116-e1000e-fail-when-try-to-setup-unsupported-features.patch:
  e1000e: fail when try to setup unsupported features (bnc#699092,
  fate#311825).
- patches.drivers/0118-e1000e-suppress-compile-warnings-on-certain-archs.patch:
  e1000e: suppress compile warnings on certain archs (bnc#699092,
  fate#311825).
- patches.drivers/0119-e1000e-remove-EEE-module-parameter.patch:
  e1000e: remove EEE module parameter (bnc#699092, fate#311825).
- patches.drivers/0120-e1000e-disable-EEE-support-by-default.patch:
  e1000e: disable EEE support by default (bnc#699092,
  fate#311825).
- patches.drivers/0122-e1000e-Drop-a-useless-statement.patch:
  e1000e: Drop a useless statement (bnc#699092, fate#311825).
- patches.drivers/0126-e1000e-Fix-irq_synchronize-in-MSI-X-case.patch:
  e1000e: Fix irq_synchronize in MSI-X case (bnc#699092,
  fate#311825).
- patches.drivers/0127-e1000e-correct-MAC-PHY-interconnect-register-offset-.patch:
  e1000e: correct MAC-PHY interconnect register offset for 82579
  (bnc#699092, fate#311825).
- patches.drivers/0128-e100-e1000-igb-ixgb-Add-missing-read-memory-barrier.patch:
  e100/e1000*/igb*/ixgb*: Add missing read memory barrier
  (bnc#699092, fate#311825).
- patches.drivers/0129-e1000e-disable-ASPM-L1-on-82573.patch:
  e1000e: disable ASPM L1 on 82573 (bnc#699092, fate#311825).
- patches.drivers/0130-e1000e-don-t-check-for-alternate-MAC-addr-on-parts-t.patch:
  e1000e: don't check for alternate MAC addr on parts that don't
  support it (bnc#699092, fate#311825).
- patches.drivers/0131-drivers-net-Remove-address-use-from-assignments-of-f.patch:
  drivers/net: Remove address use from assignments of function
  pointers (bnc#699092, fate#311825).
- patches.drivers/0132-drivers-net-avoid-some-skb-ip_summed-initializations.patch:
  drivers/net: avoid some skb->ip_summed initializations
  (bnc#699092, fate#311825).
- patches.drivers/0133-e1000e-Simplify-MSI-interrupt-testing.patch:
  e1000e: Simplify MSI interrupt testing (bnc#699092,
  fate#311825).
- patches.drivers/0134-e1000e-82577-8-9-issues-with-device-in-Sx.patch:
  e1000e: 82577/8/9 issues with device in Sx (bnc#699092,
  fate#311825).
- patches.drivers/0135-e1000e-82579-SMBus-address-and-LEDs-incorrect-after-.patch:
  e1000e: 82579 SMBus address and LEDs incorrect after device
  reset (bnc#699092, fate#311825).
- patches.drivers/0136-e1000e-82566DC-fails-to-get-link.patch:
  e1000e: 82566DC fails to get link (bnc#699092, fate#311825).
- patches.drivers/0137-e1000e-82579-unaccounted-missed-packets.patch:
  e1000e: 82579 unaccounted missed packets (bnc#699092,
  fate#311825).
- patches.drivers/0138-e1000e-82579-jumbo-frame-workaround-causing-CRC-erro.patch:
  e1000e: 82579 jumbo frame workaround causing CRC errors
  (bnc#699092, fate#311825).
- patches.drivers/0139-e1000e-82579-do-not-gate-auto-config-of-PHY-by-hardw.patch:
  e1000e: 82579 do not gate auto config of PHY by hardware during
  nominal use (bnc#699092, fate#311825).
- patches.drivers/0140-e1000-e1000e-igb-ixgb-ixgbe-set-NETIF_F_HIGHDMA-for-.patch:
  e1000/e1000e/igb/ixgb/ixgbe: set NETIF_F_HIGHDMA for VLAN
  feature flags (bnc#699092, fate#311825).
- patches.drivers/0142-e1000e-use-hardware-writeback-batching.patch:
  e1000e: use hardware writeback batching (bnc#699092,
  fate#311825).
- patches.drivers/0144-e1000e-Fix-for-offline-diag-test-failure-at-first-ca.patch:
  e1000e: Fix for offline diag test failure at first call
  (bnc#699092, fate#311825).
- patches.drivers/0148-e1000e-Add-check-for-reset-flags-before-displaying-r.patch:
  e1000e: Add check for reset flags before displaying reset
  message (bnc#699092, fate#311825).
- patches.drivers/0150-drivers-net-e1000e-Remove-unnecessary-semicolons.patch:
  drivers/net/e1000e: Remove unnecessary semicolons (bnc#699092,
  fate#311825).
- patches.drivers/0151-e1000e-82571-SerDes-link-handle-null-code-word-from-.patch:
  e1000e: 82571 SerDes link handle null code word from partner
  (bnc#699092, fate#311825).
- patches.drivers/0152-e1000e-82574-intermittently-fails-to-initialize-with.patch:
  e1000e: 82574 intermittently fails to initialize with
  manageability f/w (bnc#699092, fate#311825).
- patches.drivers/0153-e1000e-add-netpoll-support-for-MSI-MSI-X-IRQ-modes.patch:
  e1000e: add netpoll support for MSI/MSI-X IRQ modes (bnc#699092,
  fate#311825).
- patches.drivers/0156-Intel-Wired-LAN-drivers-Use-static-const.patch:
  Intel Wired LAN drivers: Use static const (bnc#699092,
  fate#311825).
- patches.drivers/0157-e1000e-fix-double-initialization-in-blink-path.patch:
  e1000e: fix double initialization in blink path (bnc#699092,
  fate#311825).
- patches.drivers/0158-e1000e-82571-based-mezzanine-card-can-fail-ethtool-l.patch:
  e1000e: 82571-based mezzanine card can fail ethtool link test
  (bnc#699092, fate#311825).
- patches.drivers/0160-e1000e-82577-8-must-acquire-h-w-semaphore-before-wor.patch:
  e1000e: 82577/8 must acquire h/w semaphore before workaround
  (bnc#699092, fate#311825).
- patches.drivers/0161-e1000e-82571-Serdes-can-fail-to-get-link.patch:
  e1000e: 82571 Serdes can fail to get link (bnc#699092,
  fate#311825).
- patches.drivers/0162-e1000e-82577-8-9-mis-configured-OEM-bits-during-S0-S.patch:
  e1000e: 82577/8/9 mis-configured OEM bits during S0->Sx
  (bnc#699092, fate#311825).
- patches.drivers/0163-e1000e-82579-PHY-incorrectly-identified-during-init.patch:
  e1000e: 82579 PHY incorrectly identified during init
  (bnc#699092, fate#311825).
- patches.drivers/0164-e1000e-support-new-PBA-format-from-EEPROM.patch:
  e1000e: support new PBA format from EEPROM (bnc#699092,
  fate#311825).
- patches.drivers/0165-e1000e-prevent-null-ptr-dereference-in-e1000_tx_queu.patch:
  e1000e: prevent null ptr dereference in e1000_tx_queue()
  (bnc#699092, fate#311825).
- patches.drivers/0166-e1000e-minor-error-message-corrections.patch:
  e1000e: minor error message corrections (bnc#699092,
  fate#311825).
- patches.drivers/0167-e1000e-static-analysis-tools-complain-of-a-possible-.patch:
  e1000e: static analysis tools complain of a possible null ptr
  p dereference (bnc#699092, fate#311825).
- patches.drivers/0168-e1000e-increment-the-driver-version.patch:
  e1000e: increment the driver version (bnc#699092, fate#311825).
- patches.drivers/0169-drivers-net-don-t-use-flush_scheduled_work.patch:
  drivers/net: don't use flush_scheduled_work() (bnc#699092,
  fate#311825).
- patches.drivers/0171-e1000e-checkpatch-error-macro-panethesis.patch:
  e1000e: checkpatch error - macro panethesis (bnc#699092,
  fate#311825).
- patches.drivers/0172-e1000e-checkpatch-error-trailing-statements.patch:
  e1000e: checkpatch error - trailing statements (bnc#699092,
  fate#311825).
- patches.drivers/0173-e1000e-checkpatch-error-open-braces.patch:
  e1000e: checkpatch error - open braces (bnc#699092,
  fate#311825).
- patches.drivers/0174-e1000e-checkpatch-warnings-braces.patch:
  e1000e: checkpatch warnings - braces (bnc#699092, fate#311825).
- patches.drivers/0175-e1000e-cleanup-variables-set-but-not-used.patch:
  e1000e: cleanup variables set but not used (bnc#699092,
  fate#311825).
- patches.drivers/0176-e1000e-convert-calls-of-ops.-read-write-_reg-to-e1e_.patch:
  e1000e: convert calls of ops.[read|write]_reg to e1e_[r|w]phy
  (bnc#699092, fate#311825).
- patches.drivers/0177-e1000e-properly-bounds-check-string-functions.patch:
  e1000e: properly bounds-check string functions (bnc#699092,
  fate#311825).
- patches.drivers/0178-e1000e-use-either_crc_le-rather-than-re-write-it.patch:
  e1000e: use either_crc_le() rather than re-write it (bnc#699092,
  fate#311825).
- patches.drivers/0179-e1000e-power-off-PHY-after-reset-when-interface-is-d.patch:
  e1000e: power off PHY after reset when interface is down
  (bnc#699092, fate#311825).
- patches.drivers/0180-e1000e-add-custom-set_d-0-3-_lplu_state-function-poi.patch:
  e1000e: add custom set_d[0|3]_lplu_state function pointer for
  82574 (bnc#699092, fate#311825).
- patches.drivers/0181-e1000e-update-Copyright-for-2011.patch:
  e1000e: update Copyright for 2011 (bnc#699092, fate#311825).
- patches.drivers/0184-e1000e-reduce-scope-of-some-variables-remove-unneces.patch:
  e1000e: reduce scope of some variables, remove unnecessary ones
  (bnc#699092, fate#311825).
- patches.drivers/0185-e1000e-Use-kmemdup-rather-than-duplicating-its-imple.patch:
  e1000e: Use kmemdup rather than duplicating its implementation
  (bnc#699092, fate#311825).
- patches.drivers/0186-e1000e-tx_timeout-should-not-increment-for-non-hang-.patch:
  e1000e: tx_timeout should not increment for non-hang events
  (bnc#699092, fate#311825).
- patches.drivers/0187-e1000e-replace-unbounded-sprintf-with-snprintf.patch:
  e1000e: replace unbounded sprintf with snprintf (bnc#699092,
  fate#311825).
- patches.drivers/0188-e1000e-use-correct-pointer-when-memcpy-ing-a-2-dimen.patch:
  e1000e: use correct pointer when memcpy'ing a 2-dimensional
  array (bnc#699092, fate#311825).
- patches.drivers/0189-e1000e-return-appropriate-errors-for-ethtool-r.patch:
  e1000e: return appropriate errors for 'ethtool -r' (bnc#699092,
  fate#311825).
- patches.drivers/0190-e1000e-check-down-flag-in-tasks.patch:
  e1000e: check down flag in tasks (bnc#699092, fate#311825).
- patches.drivers/0191-e1000e-flush-all-writebacks-before-unload.patch:
  e1000e: flush all writebacks before unload (bnc#699092,
  fate#311825).
- patches.drivers/0194-e1000e-use-dev_kfree_skb_irq-instead-of-dev_kfree_sk.patch:
  e1000e: use dev_kfree_skb_irq() instead of dev_kfree_skb()
  (bnc#699092, fate#311825).
- patches.drivers/0195-e1000e-magic-number-cleanup-ETH_ALEN.patch:
  e1000e: magic number cleanup - ETH_ALEN (bnc#699092,
  fate#311825).
- patches.drivers/0196-e1000e-extend-timeout-for-ethtool-link-test-diagnost.patch:
  e1000e: extend timeout for ethtool link test diagnostic
  (bnc#699092, fate#311825).
- patches.drivers/0197-e1000e-extend-EEE-LPI-timer-to-prevent-dropped-link.patch:
  e1000e: extend EEE LPI timer to prevent dropped link
  (bnc#699092, fate#311825).
- patches.drivers/0198-e1000e-do-not-toggle-LANPHYPC-value-bit-when-PHY-res.patch:
  e1000e: do not toggle LANPHYPC value bit when PHY reset is
  blocked (bnc#699092, fate#311825).
- patches.drivers/0199-e1000e-disable-jumbo-frames-on-82579-when-MACsec-ena.patch:
  e1000e: disable jumbo frames on 82579 when MACsec enabled in
  EEPROM (bnc#699092, fate#311825).
- patches.drivers/0200-e1000e-do-not-suggest-the-driver-supports-Wake-on-AR.patch:
  e1000e: do not suggest the driver supports Wake-on-ARP
  (bnc#699092, fate#311825).
- patches.drivers/0201-e1000e-bump-version-number.patch: e1000e:
  bump version number (bnc#699092, fate#311825).
- patches.drivers/0203-Fix-common-misspellings.patch: Fix common
  misspellings (bnc#699092, fate#311825).
- patches.drivers/0205-e1000e-PCIe-link-speed-in-GT-s-not-GB-s.patch:
  e1000e: PCIe link speed in GT/s, not GB/s (bnc#699092,
  fate#311825).
- patches.drivers/0210-ethtool-Use-full-32-bit-speed-range-in-ethtool-s-set.patch:
  ethtool: Use full 32 bit speed range in ethtool's set_settings
  (bnc#699092, fate#311825).
- patches.drivers/0211-ethtool-cosmetic-Use-ethtool-ethtool_cmd_speed-API.patch:
  ethtool: cosmetic: Use ethtool ethtool_cmd_speed API
  (bnc#699092, fate#311825).
- patches.drivers/0212-net-igb-e1000-e1000e-more-robust-ethtool-duplex-spee.patch:
  net/igb/e1000/e1000e: more robust ethtool duplex/speed
  configuration (bnc#699092, fate#311825).
- patches.drivers/0213-e1000e-minor-comment-cleanups.patch:
  e1000e: minor comment cleanups (bnc#699092, fate#311825).
- patches.drivers/0215-Add-appropriate-linux-prefetch.h-include-for-prefetc.patch:
  Add appropriate <linux/prefetch.h> include for prefetch users
  (bnc#699092, fate#311825).
- patches.drivers/0217-e1000e-disable-far-end-loopback-mode-on-ESB2.patch:
  e1000e: disable far-end loopback mode on ESB2 (bnc#699092,
  fate#311825).
- patches.drivers/0218-e1000e-82579-intermittently-disabled-during-S0-Sx.patch:
  e1000e: 82579 intermittently disabled during S0->Sx (bnc#699092,
  fate#311825).
- patches.drivers/0219-e1000e-log-when-swflag-is-cleared-unexpectedly-on-IC.patch:
  e1000e: log when swflag is cleared unexpectedly on ICH/PCH
  devices (bnc#699092, fate#311825).
- patches.drivers/0221-e1000e-access-multiple-PHY-registers-on-same-page-at.patch:
  e1000e: access multiple PHY registers on same page at the same
  time (bnc#699092, fate#311825).
- patches.drivers/0222-e1000e-Clear-host-wakeup-bit-on-82577-8-without-touc.patch:
  e1000e: Clear host wakeup bit on 82577/8 without touching PHY
  page 800 (bnc#699092, fate#311825).
- patches.drivers/0223-e1000e-update-driver-version.patch:
  e1000e: update driver version (bnc#699092, fate#311825).
- patches.drivers/0224-e1000e-remove-unnecessary-reads-of-PCI_CAP_ID_EXP.patch:
  e1000e: remove unnecessary reads of PCI_CAP_ID_EXP (bnc#699092,
  fate#311825).
- patches.drivers/0226-e1000e-remove-e1000_queue_stats.patch:
  e1000e: remove e1000_queue_stats (bnc#699092, fate#311825).
- patches.drivers/e1000e-entropy-source.patch: Refresh.
- patches.drivers/e1000e-remove-use-of-skb_dma_map.patch: Move up.
* Fri Jul 29 2011 mhocko@suse.cz
- patches.fixes/cpusets-randomize-node-rotor-used-in-cpuset_mem_spre.patch:
  fixed mem_rotor overflow
* Fri Jul 29 2011 jkosina@suse.cz
- patches.xen/xen3-intel-additional-Intel-Cougar-Point.patch:
  x86/PCI: irq and pci_ids patch for additional Intel Cougar
  Point DeviceIDs (bnc#708269).
* Thu Jul 28 2011 tiwai@suse.de
- patches.xen/xen3-auto-common.diff: Refresh.
* Thu Jul 28 2011 mhocko@suse.cz
- patches.fixes/cpusets-randomize-node-rotor-used-in-cpuset_mem_spre.patch:
  Compile fix for !x86_64 architectures which do not have NUMA_NO_NODE
* Thu Jul 28 2011 duwe@suse.de
- patches.arch/s390-31-02-ap-status-struct-packed: ap: Fix
  ap_queue_status structure declaration (bnc#705906).
- patches.fixes/page-referenced: kernel: first time swap use
  results in heavy swapping (bnc#705906).
* Thu Jul 28 2011 jack@suse.cz
- patches.fixes/mm-more-unused-nonblocking-and-congestion-checks.patch:
  writeback: remove nonblocking/encountered_congestion references
  (bnc#699354).
- patches.fixes/mm-pay-attention-to-wbc-nr_to_write.patch:
  Refresh.
- patches.fixes/mm-remove-unused-nonblocking-and-congestion-checks.patch:
  writeback: remove unused nonblocking and congestion checks
  (bnc#699354).
- patches.fixes/mm-write_cache_pages-terminate-nr_to_write-negative.patch:
  Refresh.
* Thu Jul 28 2011 mhocko@suse.cz
- patches.fixes/cpusets-randomize-node-rotor-used-in-cpuset_mem_spre.patch:
  cpusets: randomize node rotor used in cpuset_mem_spread_node()
  (bnc#602150).
* Thu Jul 28 2011 jack@suse.cz
- patches.fixes/mm-pay-attention-to-wbc-nr_to_write.patch:
  writeback: pay attention to wbc->nr_to_write in
  write_cache_pages (bnc#699354).
- patches.fixes/mm-write_cache_pages-terminate-nr_to_write-negative.patch:
  writeback: write_cache_pages doesn't terminate at nr_to_write <=
  0 (bnc#699354).
* Thu Jul 28 2011 mhocko@suse.cz
- patches.fixes/memcg-change-memcg_oom_mutex-to-spinlock.patch:
  memcg: change memcg_oom_mutex to spinlock (bnc#705487)
- patches.fixes/memcg-make-oom_lock-0-and-1-based-rather-than-coutne.patch:
  memcg: make oom_lock 0 and 1 based rather than counter
  (bnc#705487).
* Thu Jul 28 2011 jankit@suse.de
- patches.fixes/fs-fix-null-ref-discard_alignment: Fix oops when
  accessing discard_alignment sysfs file. (bnc #707917).
* Wed Jul 27 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Build a -hmac subpackage with HMACs
  for the kernel and modules (fate#312218).
- rpm/gen-hmacs: Helper script.
* Wed Jul 27 2011 jkosina@suse.cz
- patches.drivers/intel-additional-Intel-Cougar-Point.patch:
  Refresh - fix typo.
* Wed Jul 27 2011 duwe@suse.de
- patches.arch/ppc-normalize-xtime-after-rounding: time: Normalize
  xtime after rounding (bnc#685226).
- patches.suse/ppc-temporary-bugon-timer-workaround.patch: Delete.
* Wed Jul 27 2011 jkosina@suse.cz
- patches.drivers/intel-add-panther-point-pch-support.patch:
  Core Driver Enabling for Intel Panther Point PCH (bnc#682755
  fate#311837): rename the patch to fix typo; update upstream
  references.
* Wed Jul 27 2011 jkosina@suse.cz
- patches.drivers/intel-additional-Intel-Cougar-Point.patch:
  x86/PCI: irq and pci_ids patch for additional Intel Cougar
  Point DeviceIDs (bnc#708269).
* Wed Jul 27 2011 mmarek@suse.cz
- patches.drivers/cxgb4-chelsio-t4-driver-compat: Remove now
  duplicate PCI_EXP_LNKSTA_CLS_{2_5,5_0}GB defines.
* Wed Jul 27 2011 mmarek@suse.cz
- igb backport (FATE#311863)
- patches.drivers/0001-igb-remove-unused-temp-variable-from-stats-clearing-.patch:
  igb: remove unused temp variable from stats clearing path
  (FATE#311863 ,bnc#699089).
- patches.drivers/0002-igb-update-comments-for-serdes-config-and-update-to-.patch:
  igb: update comments for serdes config and update to handle
  duplex (FATE#311863 ,bnc#699089).
- patches.drivers/0003-igb-update-the-approach-taken-to-acquiring-and-relea.patch:
  igb: update the approach taken to acquiring and releasing the
  phy lock (FATE#311863 ,bnc#699089).
- patches.drivers/0004-igb-add-locking-to-reads-of-the-i2c-interface.patch:
  igb: add locking to reads of the i2c interface (FATE#311863
  ,bnc#699089).
- patches.drivers/0005-igb-add-combined-function-for-setting-rar-and-pool-b.patch:
  igb: add combined function for setting rar and pool bits
  (FATE#311863 ,bnc#699089).
- patches.drivers/0006-igb-make-use-of-the-uta-to-allow-for-promiscous-mode.patch:
  igb: make use of the uta to allow for promiscous mode filter
  (FATE#311863 ,bnc#699089).
- patches.drivers/0008-igb-add-function-to-handle-mailbox-lock.patch:
  igb: add function to handle mailbox lock (FATE#311863
  ,bnc#699089).
- patches.drivers/0009-igb-fix-a-few-items-where-weren-t-correctly-setup-fo.patch:
  igb: fix a few items where weren't correctly setup for mbx
  timeout (FATE#311863 ,bnc#699089).
- patches.drivers/0010-igb-change-how-we-handle-alternate-mac-addresses.patch:
  igb: change how we handle alternate mac addresses (FATE#311863
  ,bnc#699089).
- patches.drivers/0011-igb-remove-microwire-support-from-igb.patch:
  igb: remove microwire support from igb (FATE#311863
  ,bnc#699089).
- patches.drivers/0012-igb-move-the-generic-copper-link-setup-code-into-e10.patch:
  igb: move the generic copper link setup code into e1000_phy.c
  (FATE#311863 ,bnc#699089).
- patches.drivers/0013-igb-add-code-to-retry-a-phy-read-in-the-event-of-fai.patch:
  igb: add code to retry a phy read in the event of failure on
  link check (FATE#311863 ,bnc#699089).
- patches.drivers/0014-igb-add-additional-error-handling-to-the-phy-code.patch:
  igb: add additional error handling to the phy code (FATE#311863
  ,bnc#699089).
- patches.drivers/0015-igb-add-flushes-between-RAR-writes-when-setting-mac-.patch:
  igb: add flushes between RAR writes when setting mac address
  (FATE#311863 ,bnc#699089).
- patches.drivers/0016-igb-Use-the-instance-of-net_device_stats-from-net_de.patch:
  igb: Use the instance of net_device_stats from net_device
  (FATE#311863 ,bnc#699089).
- patches.drivers/0018-igb-Fix-erroneous-display-of-stats-by-ethtool-S.patch:
  igb: Fix erroneous display of stats by ethtool -S (FATE#311863
  ,bnc#699089).
- patches.drivers/0020-igb-remove-rx-checksum-good-counter.patch:
  igb: remove rx checksum good counter (FATE#311863 ,bnc#699089).
- patches.drivers/0021-igb-increase-minimum-rx-buffer-size-to-1K.patch:
  igb: increase minimum rx buffer size to 1K (FATE#311863
  ,bnc#699089).
- patches.drivers/0022-igb-move-the-tx-and-rx-ring-specific-config-into-sep.patch:
  igb: move the tx and rx ring specific config into seperate
  functions (FATE#311863 ,bnc#699089).
- patches.drivers/0023-igb-remove-rx_ps_hdr_len.patch: igb:
  remove rx_ps_hdr_len (FATE#311863 ,bnc#699089).
- patches.drivers/0024-igb-move-SRRCTL-register-configuration-into-ring-spe.patch:
  igb: move SRRCTL register configuration into ring specific
  config (FATE#311863 ,bnc#699089).
- patches.drivers/0025-igb-change-the-head-and-tail-offsets-into-pointers.patch:
  igb: change the head and tail offsets into pointers (FATE#311863
  ,bnc#699089).
- patches.drivers/0026-igb-add-pci-device-pointer-to-ring-structure.patch:
  igb: add pci device pointer to ring structure (FATE#311863
  ,bnc#699089).
- patches.drivers/0027-igb-move-rx_buffer_len-into-the-ring-structure.patch:
  igb: move rx_buffer_len into the ring structure (FATE#311863
  ,bnc#699089).
- patches.drivers/0028-igb-move-alloc_failed-and-csum_err-stats-into-per-rx.patch:
  igb: move alloc_failed and csum_err stats into per rx-ring stat
  (FATE#311863 ,bnc#699089).
- patches.drivers/0029-igb-add-a-flags-value-to-the-ring.patch:
  igb: add a flags value to the ring (FATE#311863 ,bnc#699089).
- patches.drivers/0030-igb-place-a-pointer-to-the-netdev-struct-in-the-ring.patch:
  igb: place a pointer to the netdev struct in the ring itself
  (FATE#311863 ,bnc#699089).
- patches.drivers/0031-igb-move-the-multiple-receive-queue-configuration-in.patch:
  igb: move the multiple receive queue configuration into seperate
  function (FATE#311863 ,bnc#699089).
- patches.drivers/0032-igb-delay-VF-reset-notification-until-after-interrup.patch:
  igb: delay VF reset notification until after interrupts are
  enabed (FATE#311863 ,bnc#699089).
- patches.drivers/0033-igb-setup-vlan-tag-replication-stripping-in-igb_vmm_.patch:
  igb: setup vlan tag replication stripping in igb_vmm_control
  (FATE#311863 ,bnc#699089).
- patches.drivers/0034-igb-re-use-ring-configuration-code-in-ethtool-testin.patch:
  igb: re-use ring configuration code in ethtool testing
  (FATE#311863 ,bnc#699089).
- patches.drivers/0035-igb-make-tx-ring-map-and-free-functionality-non-stat.patch:
  igb: make tx ring map and free functionality non-static
  (FATE#311863 ,bnc#699089).
- patches.drivers/0036-igb-make-ethtool-use-core-xmit-map-and-free-function.patch:
  igb: make ethtool use core xmit map and free functionality
  (FATE#311863 ,bnc#699089).
- patches.drivers/0037-igb-add-single-vector-msi-x-testing-to-interrupt-tes.patch:
  igb: add single vector msi-x testing to interrupt test
  (FATE#311863 ,bnc#699089).
- patches.drivers/0038-igb-cleanup-todo-code-found-in-igb_ethtool.c.patch:
  igb: cleanup "todo" code found in igb_ethtool.c (FATE#311863
  ,bnc#699089).
- patches.drivers/0039-igb-add-support-for-seperate-tx-usecs-setting-in-eth.patch:
  igb: add support for seperate tx-usecs setting in ethtool
  (FATE#311863 ,bnc#699089).
- patches.drivers/0041-igb-misc-cleanups-within-igb_ethtool.c.patch:
  igb: misc cleanups within igb_ethtool.c (FATE#311863
  ,bnc#699089).
- patches.drivers/0045-igb-rework-handling-of-the-vfta-and-vlvf-registers-i.patch:
  igb: rework handling of the vfta and vlvf registers in relation
  to mng_vlan (FATE#311863 ,bnc#699089).
- patches.drivers/0046-igb-move-vf-init-into-a-seperate-function.patch:
  igb: move vf init into a seperate function (FATE#311863
  ,bnc#699089).
- patches.drivers/0047-igb-only-process-global-stats-in-igb_update_stats.patch:
  igb: only process global stats in igb_update_stats (FATE#311863
  ,bnc#699089).
- patches.drivers/0048-igb-move-global_quad_port_a-from-global-into-local-s.patch:
  igb: move global_quad_port_a from global into local static
  define (FATE#311863 ,bnc#699089).
- patches.drivers/0049-igb-make-tx-hang-check-multiqueue-check-eop-descript.patch:
  igb: make tx hang check multiqueue, check eop descriptor
  (FATE#311863 ,bnc#699089).
- patches.drivers/0050-igb-cleanup-code-related-to-ring-resource-allocation.patch:
  igb: cleanup code related to ring resource allocation and free
  (FATE#311863 ,bnc#699089).
- patches.drivers/0051-igb-change-queue-ordering-for-82576-based-adapters.patch:
  igb: change queue ordering for 82576 based adapters (FATE#311863
  ,bnc#699089).
- patches.drivers/0053-igb-Remove-invalid-stats-counters.patch:
  igb: Remove invalid stats counters (FATE#311863 ,bnc#699089).
- patches.drivers/0054-igb-cleanup-igb.h-header-whitespace-and-some-structu.patch:
  igb: cleanup igb.h header whitespace and some structure
  formatting (FATE#311863 ,bnc#699089).
- patches.drivers/0055-igb-cleanup-igb-xmit-frame-path.patch:
  igb: cleanup igb xmit frame path (FATE#311863 ,bnc#699089).
- patches.drivers/0056-igb-cleanup-clean_rx_irq_adv-and-alloc_rx_buffers_ad.patch:
  igb: cleanup clean_rx_irq_adv and alloc_rx_buffers_adv
  (FATE#311863 ,bnc#699089).
- patches.drivers/0057-igb-replace-unecessary-adapter-hw-with-just-hw-where.patch:
  igb: replace unecessary &adapter->hw with just hw where
  applicable (FATE#311863 ,bnc#699089).
- patches.drivers/0058-igb-add-pci_dev-in-few-spots-to-clean-up-use-of-dev_.patch:
  igb: add pci_dev in few spots to clean up use of
  dev_err/info/warn (FATE#311863 ,bnc#699089).
- patches.drivers/0059-igb-limit-minimum-mtu-to-68-to-keep-ip-bound-to-inte.patch:
  igb: limit minimum mtu to 68 to keep ip bound to interface
  (FATE#311863 ,bnc#699089).
- patches.drivers/0060-igb-open-up-SCTP-checksum-offloads-to-all-MACs-82576.patch:
  igb: open up SCTP checksum offloads to all MACs 82576 and newer
  (FATE#311863 ,bnc#699089).
- patches.drivers/0061-igb-cleanup-whitespace-issues-in-igb_main.c.patch:
  igb: cleanup whitespace issues in igb_main.c (FATE#311863
  ,bnc#699089).
- patches.drivers/0062-igb-Fix-warnings-in-igb_set_ringparam.patch:
  igb: Fix warnings in igb_set_ringparam() (FATE#311863
  ,bnc#699089).
- patches.drivers/0063-igb-change-type-for-ring-sizes-to-u16-in-igb_set_rin.patch:
  igb: change type for ring sizes to u16 in igb_set_ring_param
  (FATE#311863 ,bnc#699089).
- patches.drivers/0064-igb-move-timesync-init-into-a-seperate-function.patch:
  igb: move timesync init into a seperate function (FATE#311863
  ,bnc#699089).
- patches.drivers/0065-igb-when-number-of-CPUs-4-combine-tx-rx-queues-to-al.patch:
  igb: when number of CPUs > 4 combine tx/rx queues to allow
  more queues (FATE#311863 ,bnc#699089).
- patches.drivers/0066-igb-Rework-how-netdev-stats-is-handled.patch:
  igb: Rework how netdev->stats is handled (FATE#311863
  ,bnc#699089).
- patches.drivers/0067-igb-removed-unused-tx-rx-total-bytes-packets-from-ad.patch:
  igb: removed unused tx/rx total bytes/packets from adapter
  struct (FATE#311863 ,bnc#699089).
- patches.drivers/0068-igb-check-for-packets-on-all-tx-rings-when-link-is-d.patch:
  igb: check for packets on all tx rings when link is down
  (FATE#311863 ,bnc#699089).
- patches.drivers/0069-igb-only-recycle-page-if-it-is-on-our-numa-node.patch:
  igb: only recycle page if it is on our numa node (FATE#311863
  ,bnc#699089).
- patches.drivers/0070-drivers-net-request_irq-Remove-unnecessary-leading-f.patch:
  drivers/net: request_irq - Remove unnecessary leading & from
  second arg (FATE#311863 ,bnc#699089).
- patches.drivers/0075-drivers-net-Move-and-to-end-of-previous-line.patch:
  drivers/net: Move && and || to end of previous line (FATE#311863
  ,bnc#699089).
- patches.drivers/0076-igb-fix-handling-of-mailbox-collisions-between-PF-VF.patch:
  igb: fix handling of mailbox collisions between PF/VF
  (FATE#311863 ,bnc#699089).
- patches.drivers/0077-igb-do-not-force-pcs-link-when-in-KX-mode.patch:
  igb: do not force pcs link when in KX mode (FATE#311863
  ,bnc#699089).
- patches.drivers/0078-igb-do-not-force-retry-count-to-1-on-82580-phy.patch:
  igb: do not force retry count to 1 on 82580 phy (FATE#311863
  ,bnc#699089).
- patches.drivers/0079-igb-correctly-offset-82575-flow-control-watermarks-b.patch:
  igb: correctly offset 82575 flow control watermarks by 16 bytes
  (FATE#311863 ,bnc#699089).
- patches.drivers/0081-drivers-net-use-DEFINE_PCI_DEVICE_TABLE.patch:
  drivers/net/: use DEFINE_PCI_DEVICE_TABLE() (FATE#311863
  ,bnc#699089).
- patches.drivers/0082-igb-add-support-for-device-reset-interrupt.patch:
  igb: add support for device reset interrupt (FATE#311863
  ,bnc#699089).
- patches.drivers/0083-igb-igbvf-cleanup-exception-handling-in-tx_map_adv.patch:
  igb/igbvf: cleanup exception handling in tx_map_adv (FATE#311863
  ,bnc#699089).
- patches.drivers/0084-net-Fix-IPv6-GSO-type-checks-in-Intel-ethernet-drive.patch:
  net: Fix IPv6 GSO type checks in Intel ethernet drivers
  (FATE#311863 ,bnc#699089).
- patches.drivers/0085-net-use-helpers-to-access-uc-list-V2.patch:
  net: use helpers to access uc list V2 (FATE#311863 ,bnc#699089).
- patches.drivers/0086-igb-make-certain-to-reassign-legacy-interrupt-vector.patch:
  igb: make certain to reassign legacy interrupt vectors after
  reset (FATE#311863 ,bnc#699089).
- patches.drivers/0087-tree-wide-Assorted-spelling-fixes.patch:
  tree-wide: Assorted spelling fixes (FATE#311863 ,bnc#699089).
- patches.drivers/0088-net-use-netdev_mc_count-and-netdev_mc_empty-when-app.patch:
  net: use netdev_mc_count and netdev_mc_empty when appropriate
  (FATE#311863 ,bnc#699089).
- patches.drivers/0090-igb-remove-unecessary-q_vector-declarations-and-remo.patch:
  igb: remove unecessary q_vector declarations and remove
  itr_shift (FATE#311863 ,bnc#699089).
- patches.drivers/0091-igb-add-support-for-wake-on-link.patch:
  igb: add support for wake-on-link (FATE#311863 ,bnc#699089).
- patches.drivers/0092-igb-Report-link-status-in-ethtool-when-interface-is-.patch:
  igb: Report link status in ethtool when interface is down
  (FATE#311863 ,bnc#699089).
- patches.drivers/0093-igb-ignore-EEPROM-APME-check-when-shutting-down-serd.patch:
  igb: ignore EEPROM APME check when shutting down serdes link
  (FATE#311863 ,bnc#699089).
- patches.drivers/0094-igb-Power-down-link-when-interface-is-down.patch:
  igb: Power down link when interface is down (FATE#311863
  ,bnc#699089).
- patches.drivers/0095-igb-call-pci_save_state-after-pci_restore_state.patch:
  igb: call pci_save_state after pci_restore_state (FATE#311863
  ,bnc#699089).
- patches.drivers/0096-igb-Allocate-rings-seperately-instead-of-as-a-block.patch:
  igb: Allocate rings seperately instead of as a block
  (FATE#311863 ,bnc#699089).
- patches.drivers/0097-igb-remove-adaptive-IFS-from-driver.patch:
  igb: remove adaptive IFS from driver (FATE#311863 ,bnc#699089).
- patches.drivers/0098-igb-cap-interrupts-at-20K-per-queue-when-in-itr-mode.patch:
  igb: cap interrupts at 20K per queue when in itr mode 3
  (FATE#311863 ,bnc#699089).
- patches.drivers/0099-igb-only-support-SRRCTL_DROP_EN-when-using-multiple-.patch:
  igb: only support SRRCTL_DROP_EN when using multiple queues
  (FATE#311863 ,bnc#699089).
- patches.drivers/0100-igb-only-read-phy-specific-stats-if-in-internal-phy-.patch:
  igb: only read phy specific stats if in internal phy mode
  (FATE#311863 ,bnc#699089).
- patches.drivers/0101-igb-inline-igb_maybe_stop_tx.patch: igb:
  inline igb_maybe_stop_tx (FATE#311863 ,bnc#699089).
- patches.drivers/0102-igb-move-gso_segs-into-buffer_info-structure.patch:
  igb: move gso_segs into buffer_info structure (FATE#311863
  ,bnc#699089).
- patches.drivers/0103-igb-minor-type-cleanups.patch: igb:
  minor type cleanups (FATE#311863 ,bnc#699089).
- patches.drivers/0104-igb-remove-unused-vmolr-value.patch: igb:
  remove unused vmolr value (FATE#311863 ,bnc#699089).
- patches.drivers/0105-igb-use-igb_free_q_vectors-to-cleanup-failure-in-igb.patch:
  igb: use igb_free_q_vectors to cleanup failure in
  igb_alloc_q_vectors (FATE#311863 ,bnc#699089).
- patches.drivers/0106-igb-change-descriptor-control-thresholds.patch:
  igb: change descriptor control thresholds (FATE#311863
  ,bnc#699089).
- patches.drivers/0107-igb-update-tx-DMA-mapping-error-handling.patch:
  igb: update tx DMA mapping error handling (FATE#311863
  ,bnc#699089).
- patches.drivers/0108-net-convert-multiple-drivers-to-use-netdev_for_each_.patch:
  net: convert multiple drivers to use netdev_for_each_mc_addr,
  part4 (FATE#311863 ,bnc#699089).
- patches.drivers/0110-igb-Do-not-overwrite-mdicnfg-register-when-accessing.patch:
  igb: Do not overwrite mdicnfg register when accessing 82580 phy
  (FATE#311863 ,bnc#699089).
- patches.drivers/0111-igb-cleanup-usage-of-virtualization-registers.patch:
  igb: cleanup usage of virtualization registers (FATE#311863
  ,bnc#699089).
- patches.drivers/0113-igb-count-Rx-FIFO-errors-correctly.patch:
  igb: count Rx FIFO errors correctly (FATE#311863 ,bnc#699089).
- patches.drivers/0114-igb-do-not-modify-tx_queue_len-on-link-speed-change.patch:
  igb: do not modify tx_queue_len on link speed change
  (FATE#311863 ,bnc#699089).
- patches.drivers/0116-igb-use-correct-bits-to-identify-if-managability-is-.patch:
  igb: use correct bits to identify if managability is enabled
  (FATE#311863 ,bnc#699089).
- patches.drivers/0117-include-cleanup-Update-gfp.h-and-slab.h-includes-to-.patch:
  include cleanup: Update gfp.h and slab.h includes to prepare for
  breaking implicit slab.h inclusion from percpu.h (FATE#311863
  ,bnc#699089).
- patches.drivers/0118-igb-update-hw_debug-macro-to-make-use-of-netdev_dbg-.patch:
  igb: update hw_debug macro to make use of netdev_dbg call
  (FATE#311863 ,bnc#699089).
- patches.drivers/0119-igb-add-per-packet-timestamping.patch:
  igb: add per-packet timestamping (FATE#311863 ,bnc#699089).
- patches.drivers/0121-igb-modify-register-test-for-i350-to-reflect-read-on.patch:
  igb: modify register test for i350 to reflect read only bits
  in RDLEN/TDLEN (FATE#311863 ,bnc#699089).
- patches.drivers/0122-igb-restrict-WoL-for-82576-ET2-Quad-Port-Server-Adap.patch:
  igb: restrict WoL for 82576 ET2 Quad Port Server Adapter
  (FATE#311863 ,bnc#699089).
- patches.drivers/0123-igb-double-increment-nr_frags.patch: igb:
  double increment nr_frags (FATE#311863 ,bnc#699089).
- patches.drivers/0124-igb-add-support-for-reporting-5GT-s-during-probe-on-.patch:
  igb: add support for reporting 5GT/s during probe on PCIe Gen2
  (FATE#311863 ,bnc#699089).
- patches.drivers/0125-igb-convert-igb-from-using-PCI-DMA-functions-to-usin.patch:
  igb: convert igb from using PCI DMA functions to using DMA
  API functions (FATE#311863 ,bnc#699089).
- patches.drivers/0126-igb-add-registers-etc.-printout-code-just-before-res.patch:
  igb: add registers etc. printout code just before resetting
  adapters (FATE#311863 ,bnc#699089).
- patches.drivers/0127-igb-Clean-up-left-over-prototype-of-igb_get_hw_dev_n.patch:
  igb: Clean up left over prototype of igb_get_hw_dev_name()
  (FATE#311863 ,bnc#699089).
- patches.drivers/0128-igb-reduce-cache-misses-on-tx-cleanup.patch:
  igb: reduce cache misses on tx cleanup (FATE#311863
  ,bnc#699089).
- patches.drivers/0129-drivers-net-Remove-unnecessary-returns-from-void-fun.patch:
  drivers/net: Remove unnecessary returns from void function()s
  (FATE#311863 ,bnc#699089).
- patches.drivers/0130-igb-fix-PHY-config-access-on-82580.patch:
  igb: fix PHY config access on 82580 (FATE#311863 ,bnc#699089).
- patches.drivers/0131-igb-Use-only-a-single-Tx-queue-in-SR-IOV-mode.patch:
  igb: Use only a single Tx queue in SR-IOV mode (FATE#311863
  ,bnc#699089).
- patches.drivers/0132-igb-Fix-Tx-hangs-seen-when-loading-igb-with-max_vfs-.patch:
  igb: Fix Tx hangs seen when loading igb with max_vfs > 7
  (FATE#311863 ,bnc#699089).
- patches.drivers/0133-igb-correct-link-test-not-being-run-when-link-is-dow.patch:
  igb: correct link test not being run when link is down
  (FATE#311863 ,bnc#699089).
- patches.drivers/0134-igb-Add-comment.patch: igb: Add comment
  (FATE#311863 ,bnc#699089).
- patches.drivers/0135-igb-drop-support-for-UDP-hashing-w-RSS.patch:
  igb: drop support for UDP hashing w/ RSS (FATE#311863
  ,bnc#699089).
- patches.drivers/0136-ixgbe-igb-catch-invalid-VF-settings.patch:
  ixgbe/igb: catch invalid VF settings (FATE#311863 ,bnc#699089).
- patches.drivers/0137-igb-add-support-for-SGMII-based-MDIO-PHYs.patch:
  igb: add support for SGMII-based MDIO PHYs (FATE#311863
  ,bnc#699089).
- patches.drivers/0138-igb-restore-EEPROM-values-of-MDICNFG-on-reset-with-8.patch:
  igb: restore EEPROM values of MDICNFG on reset with 82580
  (FATE#311863 ,bnc#699089).
- patches.drivers/0139-igb-Use-irq_synchronize-per-vector-when-using-MSI-X.patch:
  igb: Use irq_synchronize per vector when using MSI-X
  (FATE#311863 ,bnc#699089).
- patches.drivers/0140-igb-Program-MDICNFG-register-prior-to-PHY-init.patch:
  igb: Program MDICNFG register prior to PHY init (FATE#311863
  ,bnc#699089).
- patches.drivers/0141-e100-e1000-igb-ixgb-Add-missing-read-memory-barrier.patch:
  e100/e1000*/igb*/ixgb*: Add missing read memory barrier
  (FATE#311863 ,bnc#699089).
- patches.drivers/0144-drivers-net-Remove-address-use-from-assignments-of-f.patch:
  drivers/net: Remove address use from assignments of function
  pointers (FATE#311863 ,bnc#699089).
- patches.drivers/0146-igb-clear-VF_PROMISC-bits-instead-of-setting-all-oth.patch:
  igb: clear VF_PROMISC bits instead of setting all other bits
  (FATE#311863 ,bnc#699089).
- patches.drivers/0147-igb-Add-support-for-DH89xxCC.patch: igb:
  Add support for DH89xxCC (FATE#311863 ,bnc#699089).
- patches.drivers/0148-e1000-e1000e-igb-ixgb-ixgbe-set-NETIF_F_HIGHDMA-for-.patch:
  e1000/e1000e/igb/ixgb/ixgbe: set NETIF_F_HIGHDMA for VLAN
  feature flags (FATE#311863 ,bnc#699089).
- patches.drivers/0149-drivers-net-return-operator-cleanup.patch:
  drivers/net: return operator cleanup (FATE#311863 ,bnc#699089).
- patches.drivers/0150-igb-Use-netif_set_real_num_-rx-tx-_queues.patch:
  igb: Use netif_set_real_num_{rx,tx}_queues() (FATE#311863
  ,bnc#699089).
- patches.drivers/0151-igb-add-check-for-fiber-serdes-devices-to-igb_set_sp.patch:
  igb: add check for fiber/serdes devices to igb_set_spd_dplx;
  (FATE#311863 ,bnc#699089).
- patches.drivers/0154-vlan-Don-t-check-for-vlan-group-before-vlan_tx_tag_p.patch:
  vlan: Don't check for vlan group before vlan_tx_tag_present
  (FATE#311863 ,bnc#699089).
- patches.drivers/0155-igb-Fix-unused-variable-warning.patch:
  igb: Fix unused variable warning (FATE#311863 ,bnc#699089).
- patches.drivers/0157-Intel-Wired-LAN-drivers-Use-static-const.patch:
  Intel Wired LAN drivers: Use static const (FATE#311863
  ,bnc#699089).
- patches.drivers/0158-igb-Add-new-function-to-read-part-number-from-EEPROM.patch:
  igb: Add new function to read part number from EEPROM in string
  format (FATE#311863 ,bnc#699089).
- patches.drivers/0159-igb-v-ixgbe-don-t-use-flush_scheduled_work.patch:
  igb,ixgbe: don't use flush_scheduled_work() (FATE#311863
  ,bnc#699089).
- patches.drivers/0160-igb-Fix-overwrite-of-the-VF-s-flags.patch:
  igb: Fix overwrite of the VF's flags (FATE#311863 ,bnc#699089).
- patches.drivers/0161-igb-Warn-on-attempt-to-override-administratively-set.patch:
  igb: Warn on attempt to override administratively set MAC/VLAN
  (FATE#311863 ,bnc#699089).
- patches.drivers/0162-igb-Some-fine-tuning.patch: igb: Some
  fine tuning (FATE#311863 ,bnc#699089).
- patches.drivers/0163-igb-Add-Anti-spoofing-feature-support.patch:
  igb: Add Anti-spoofing feature support (FATE#311863
  ,bnc#699089).
- patches.drivers/0164-igb-Add-support-for-i340-Quad-Port-Fiber-Adapter.patch:
  igb: Add support for i340 Quad Port Fiber Adapter (FATE#311863
  ,bnc#699089).
- patches.drivers/0165-igb-Enable-PF-side-of-SR-IOV-support-for-i350-device.patch:
  igb: Enable PF side of SR-IOV support for i350 devices
  (FATE#311863 ,bnc#699089).
- patches.drivers/0166-igb-add-support-for-VF-Transmit-rate-limit-using-ipr.patch:
  igb: add support for VF Transmit rate limit using iproute2
  (FATE#311863 ,bnc#699089).
- patches.drivers/0167-igb-Update-Intel-copyright-notice-for-driver-source.patch:
  igb: Update Intel copyright notice for driver source
  (FATE#311863 ,bnc#699089).
- patches.drivers/0168-igb-update-version-string.patch: igb:
  update version string (FATE#311863 ,bnc#699089).
- patches.drivers/0169-igb-warn-if-max_vfs-limit-is-exceeded.patch:
  igb: warn if max_vfs limit is exceeded (FATE#311863
  ,bnc#699089).
- patches.drivers/0170-igb-Fix-reg-pattern-test-in-ethtool-for-i350-devices.patch:
  igb: Fix reg pattern test in ethtool for i350 devices
  (FATE#311863 ,bnc#699089).
- patches.drivers/0171-igb-Fix-strncpy-calls-to-be-safe-per-source-code-rev.patch:
  igb: Fix strncpy calls to be safe per source code review tools
  (FATE#311863 ,bnc#699089).
- patches.drivers/0172-igb-Add-stats-output-for-OS2BMC-feature-on-i350-devi.patch:
  igb: Add stats output for OS2BMC feature on i350 devices
  (FATE#311863 ,bnc#699089).
- patches.drivers/0173-igb-Add-Energy-Efficient-Ethernet-EEE-for-i350-devic.patch:
  igb: Add Energy Efficient Ethernet (EEE) for i350 devices
  (FATE#311863 ,bnc#699089).
- patches.drivers/0174-igb-Update-NVM-functions-to-work-with-i350-devices.patch:
  igb: Update NVM functions to work with i350 devices (FATE#311863
  ,bnc#699089).
- patches.drivers/0175-igb-Add-DMA-Coalescing-feature-to-driver.patch:
  igb: Add DMA Coalescing feature to driver (FATE#311863
  ,bnc#699089).
- patches.drivers/0176-igb-Bump-version-to-3.0.6.patch: igb:
  Bump version to 3.0.6 (FATE#311863 ,bnc#699089).
- patches.drivers/0177-igb-fix-hw-timestamping.patch: igb:
  fix hw timestamping (FATE#311863 ,bnc#699089).
- patches.drivers/0178-igb-Add-messaging-for-thermal-sensor-events-on-i350-.patch:
  igb: Add messaging for thermal sensor events on i350 devices
  (FATE#311863 ,bnc#699089).
- patches.drivers/0179-Fix-common-misspellings.patch: Fix common
  misspellings (FATE#311863 ,bnc#699089).
- patches.drivers/0180-igb-fix-typo-in-igb_validate_nvm_checksum_82580.patch:
  igb: fix typo in igb_validate_nvm_checksum_82580 (FATE#311863
  ,bnc#699089).
- patches.drivers/0181-igb-introduce-igb_thermal_sensor_event-for-sensor-ch.patch:
  igb: introduce igb_thermal_sensor_event for sensor checking
  (FATE#311863 ,bnc#699089).
- patches.drivers/0182-ethtool-Use-full-32-bit-speed-range-in-ethtool-s-set.patch:
  ethtool: Use full 32 bit speed range in ethtool's set_settings
  (FATE#311863 ,bnc#699089).
- patches.drivers/0183-ethtool-cosmetic-Use-ethtool-ethtool_cmd_speed-API.patch:
  ethtool: cosmetic: Use ethtool ethtool_cmd_speed API
  (FATE#311863 ,bnc#699089).
- patches.drivers/0184-net-igb-e1000-e1000e-more-robust-ethtool-duplex-spee.patch:
  net/igb/e1000/e1000e: more robust ethtool duplex/speed
  configuration (FATE#311863 ,bnc#699089).
- patches.drivers/0185-igb-Add-check-for-invalid-size-to-igb_get_invariants.patch:
  igb: Add check for invalid size to igb_get_invariants_82575()
  (FATE#311863 ,bnc#699089).
- patches.drivers/0187-Add-appropriate-linux-prefetch.h-include-for-prefetc.patch:
  Add appropriate <linux/prefetch.h> include for prefetch users
  (FATE#311863 ,bnc#699089).
- patches.drivers/0188-igb-fix-i350-SR-IOV-failture.patch: igb:
  fix i350 SR-IOV failture (FATE#311863 ,bnc#699089).
- patches.drivers/igb-entropy-source.patch: Refresh.
- patches.drivers/igb-remove-use-of-skb_dma_map.patch: Refresh and move up.
- patches.drivers/net-add-netdev_alloc_skb_ip_al: Move up.
- patches.drivers/net-use-netdev_alloc_skb_ip_al: Move up.
* Wed Jul 27 2011 jankit@suse.de
- patches.fixes/scsi_transport_spi-export-host-width-and-HBA-id:
  Update Git-* tags, to reflect that the patch has been accepted upstream.
* Tue Jul 26 2011 trenn@suse.de
  Revert __meminit from hugetlb_sysfs_add_hstate again.
- patches.fixes/017-numa-hotadd.patch: Refresh.
* Tue Jul 26 2011 trenn@suse.de
  Fix compile warnings:
- patches.fixes/mm-fix_possible_compile_issue_page_cgroup.patch:
  Refresh.
* Tue Jul 26 2011 agraf@suse.de
- patches.fixes/kvm-stable-fix-information-leak-to-userland.patch:
  KVM: x86: fix information leak to userland (bnc#706696).
* Tue Jul 26 2011 tiwai@suse.de
- patches.drivers/alsa-sp2-hda-001-Support-max-codecs-to-8-for-Nvidia:
  ALSA: hda - Support max codecs to 8 for nvidia hda controller
  (bnc#708376).
- patches.drivers/alsa-sp2-hda-002-Make-CONFIG_SND_HDA_POWER_SAVE-depending:
  ALSA: hda - Make CONFIG_SND_HDA_POWER_SAVE depending on
  CONFIG_PM (bnc#708376).
- patches.drivers/alsa-sp2-hda-003-Add-post_suspend-patch-ops:
  ALSA: hda - Add post_suspend patch ops (bnc#708376).
- patches.drivers/alsa-sp2-hda-004-Allow-codec-specific-set_power_state-ops:
  ALSA: hda - Allow codec-specific set_power_state ops
  (bnc#708376).
* Tue Jul 26 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-119-Fix-invalid-mute-led-state-on-resume-of-IDT:
  ALSA: hda - Fix invalid mute led state on resume of IDT codecs
  (bnc#708376).
- patches.drivers/alsa-sp1-hda-120-Make-sure-mute-led-reflects-master-mute-state:
  ALSA: hda - Make sure mute led reflects master mute state
  (bnc#708376).
- patches.drivers/alsa-sp1-hda-121-Add-support-of-4-internal-speakers-on-cNB:
  ALSA: hda - Add support of the 4 internal speakers on certain
  HP laptops (bnc#708376).
* Tue Jul 26 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-100-keep-ABI-for-LSI-modem-driver:
  Delete.  No SP1-kABI patch needed.
- patches.drivers/alsa-sp1-hda-116-Reorganize-controller-quriks-with-bit-flags:
  Refresh.
* Tue Jul 26 2011 dsterba@suse.cz
  Delete unused patches.
- patches.suse/btrfs-constify-xattr_handler.patch: Delete.
- patches.suse/btrfs-update-the-delayed-inode-code-to-use-the-btrfs.patch:
  Delete.
- patches.suse/btrfs-use-bitmap_set-clear.patch: Delete.
- patches.suse/btrfs-use-printk_ratelimited-instead-of-printk_ratel.patch:
  Delete.
* Tue Jul 26 2011 mhocko@suse.cz
- patches.fixes/mm-do_fault-preallocate-cow-page.patch: updated
  reference - patch got merged
* Tue Jul 26 2011 trenn@suse.de
- patches.fixes/mm-fix_possible_compile_issue_page_cgroup.patch:
  Fix node_start/end_pfn() definition for mm/page_cgroup.c
  (bnc#708160).
* Mon Jul 25 2011 trenn@suse.de
- patches.fixes/mm-fix_memoryless_nodes_exact_nid.patch: memcg:
  fix init_page_cgroup nid with sparsemem (bnc#708160).
* Mon Jul 25 2011 duwe@suse.de
- fix kernel build by relocating previous patch
* Mon Jul 25 2011 duwe@suse.de
- patches.arch/ppc-pcie-bridge-support: fully support
  pcie multi-function adapters using pcie bridges/switches
  (bnc#706882).
* Mon Jul 25 2011 duwe@suse.de
- complete FATE#311650:
- patches.arch/ppc-fate-311650-07: ibmveth: Add scatter-gather
  support (bnc#700514, FATE#311650).
- patches.arch/ppc-fate-311650-11-veth-remove-procfs-support:
  ibmveth: remove procfs code (bnc#700514, FATE#311650).
- patches.arch/ppc-fate-311650-cosmetics-and-versionbump: ibmveth:
  fix coding style and bump the version number (bnc#700514,
  FATE#311650).
* Mon Jul 25 2011 hare@suse.de
- patches.drivers/lpfc-8.3.5.46-update: lpfc: Update to version
  8.3.5.46 (bnc#686702).
- patches.fixes/scsi_lib-pause-between-error-retries.patch:
  scsi_lib: pause between error retries (bnc#675127).
* Sat Jul 23 2011 trenn@suse.de
- patches.fixes/cpu_down_fix_uncorrect_bug_on.patch: cpu: Remove
  incorrect BUG_ON (bnc#707389).
* Sat Jul 23 2011 mgalbraith@suse.de
- patches.fixes/sched-Allow-for-overlapping-sched_domain-spans:
  sched: Allow for overlapping sched_domain spans (bnc#706838).
- patches.fixes/sched-Avoid-creating-superfluous-NUMA-domains-on-non-NUMA-systems:
  sched: Avoid creating superfluous NUMA domains on non-NUMA systems (bnc#706838).
- patches.fixes/sched-Break-out-cpu_power-from-the-sched_group-structure:
  sched: Break out cpu_power from the sched_group structure (bnc#706838).
* Fri Jul 22 2011 jkosina@suse.cz
- Update config files: enable CONFIG_INTEL_TXT (bnc#707666
  FATE##311962) for x86_64.
* Fri Jul 22 2011 brogers@suse.com
- patches.suse/pci-check-caps-from-sysfs-file-open-to-read-device.patch:
  Refresh.
- patches.suse/sysfs-add-struct-file-to-bin_attr-callbacks.patch:
  Refresh.
* Fri Jul 22 2011 duwe@suse.de
- patches.arch/ppc-pseries-remove-xics-badness: powerpc: Remove
  redundant xics badness warning (bnc#707094).
* Fri Jul 22 2011 duwe@suse.de
- patches.arch/ppc-extended_h_cede-add_offline_states: Update
  references (bnc#550447 / FATE#307059, bnc#706841),
  reflecting merge of bnc#706841 fix.
* Fri Jul 22 2011 jbeulich@novell.com
- Update Xen patches to 2.6.32.43 and c/s 1098.
- Update Xen config files.
- patches.xen/xen-x86-bigmem: Extend and update references
  (bnc#700856).
- patches.xen/xen3-006-numa-hotadd.patch: mem-hotplug: avoid
  multiple zones sharing same boot strapping boot_pageset
  (fate#311831,bnc#703100).
- patches.xen/xen3-USB3-0077-USB-convert-usb_hcd-bitfields-into-atomic-flags.patch:
  USB: convert usb_hcd bitfields into atomic flags.
- patches.xen/xen3-acpi_processor_delay_cpuidle_init_on_hotplug.patch:
  acpi processor hotplug: Delay most initialization to cpu online
  (fate#311831,bnc#703100).
- patches.xen/xen3-hw-breakpoints-modifying-generic-debug-exception-to-use-thread-specific-debug-registers:
  hw-breakpoints: modifying generic debug exception to
  usethread-specific debug registers.
- patches.xen/xen3-hw-breakpoints-prepare-the-code-for-hardware-breakpoint-interfaces:
  hw-breakpoints: prepare the code for Hardware Breakpoint
  interfaces.
- patches.xen/xen3-hw-breakpoints-reset-bits-in-dr6-after-the-corresponding-exception-is-handled:
  hw-breakpoints: reset bits in dr6 after the corresponding
  exceptionis handled.
- patches.xen/xen3-hw-breakpoints-rewrite-the-hw-breakpoints-layer-on-top-of-perf-events:
  hw-breakpoints: Rewrite the hw-breakpoints layer on top of
  perf events.
- patches.xen/xen3-hw-breakpoints-use-the-new-wrapper-routines-to-access-debug-registers-in-process-thread-code:
  hw-breakpoints: use the new wrapper routines to access
  debugregisters in process/thread code.
- patches.xen/xen3-intel-add-partner-point-pch-support.patch:
  Core Driver Enabling for Intel Panther Point PCH (bnc#682755
  fate#311837).
- patches.xen/xen3-intel-perf-0108-plus-pmu.patch: perf,
  arch: Cleanup perf-pmu init vs lockup-detector (fate#311939,
  bnc#704917).
- patches.xen/xen3-kprobes-x86-32-move-irq-exit-functions-to-kprobes-section:
  kprobes/x86-32: Move irq-exit functions to kprobes section.
- patches.xen/xen3-kprobes-x86-fix-to-add-__kprobes-to-in-kernel-fault-handing-functions:
  kprobes/x86: Fix to add __kprobes to in-kernel fault handing
  functions.
- patches.xen/xen3-revert-x86-under-bios-control-restore-ap-s-apic_lvtthmr-to-the-bsp-value:
  revert: x86: Under BIOS control,restore AP's APIC_LVTTHMR to
  the BSP value.
- patches.xen/xen3-x86-hw-breakpoints-actually-flush-thread-breakpoints-in-flush_thread:
  x86/hw-breakpoints: Actually flush thread breakpoints
  inflush_thread().
- patches.xen/xen3-x86-mce-fix-up-mce-naming-nomenclature: x86,
  mce: Fix up MCE naming nomenclature.
- patches.xen/xen3-x86-under-bios-control-restore-ap-s-apic_lvtthmr-to-the-bsp-value:
  x86: Under BIOS control, restore AP's APIC_LVTTHMR to the
  BSP value.
- patches.xen/xen3-x86_64-unwind-annotations: Refresh.
- patches.xen/xen3-perf-0001-Single-patch-that-merges-f4c4176-into-sles11.patch:
  Delete.
* Fri Jul 22 2011 mgalbraith@suse.de
- ppc default failed build on a config error, run_oldconfig.sh
- Update config files.
* Fri Jul 22 2011 mgalbraith@suse.de
- Update CFS hard limits to V7.2 for FATE 311682
- patches.suse/01-18-sched-fixlet-dont-update-shares-twice-on-on_rq-parent:
  sched: (fixlet) dont update shares twice on on_rq (FATE#311682).
- patches.suse/02-18-sched-hierarchical-task-accounting-for-SCHED_OTHER:
  sched: hierarchical task accounting for SCHED_OTHER (FATE#311682).
- patches.suse/03-18-sched-introduce-primitives-to-account-for-CFS-bandwidth-tracking:
  sched: introduce primitives to account for CFS bandwidth tracking (FATE#311682).
- patches.suse/04-18-sched-validate-CFS-quota-hierarchies:
  sched: validate CFS quota hierarchies (FATE#311682).
- patches.suse/05-18-sched-accumulate-per-cfs_rq-cpu-usage-and-charge-against-bandwidth:
  sched: accumulate per-cfs_rq cpu usage and charge against bandwidth (FATE#311682).
- patches.suse/06-18-sched-add-a-timer-to-handle-CFS-bandwidth-refresh:
  sched: add a timer to handle CFS bandwidth refresh (FATE#311682).
- patches.suse/07-18-sched-expire-invalid-runtime:
  sched: expire invalid runtime (FATE#311682).
- patches.suse/08-18-sched-add-support-for-throttling-group-entities:
  sched: add support for throttling group entities (FATE#311682).
- patches.suse/09-18-sched-add-support-for-unthrottling-group-entities:
  sched: add support for unthrottling group entities (FATE#311682).
- patches.suse/10-18-sched-allow-for-positional-tg_tree-walks:
  sched: allow for positional tg_tree walks (FATE#311682).
- patches.suse/11-18-sched-prevent-interactions-with-throttled-entities:
  sched: prevent interactions with throttled entities (FATE#311682).
- patches.suse/12-18-sched-prevent-buddy-interactions-with-throttled-entities:
  sched: prevent buddy interactions with throttled entities (FATE#311682).
- patches.suse/13-18-sched-migrate-throttled-tasks-on-HOTPLUG:
  sched: migrate throttled tasks on HOTPLUG (FATE#311682).
- patches.suse/14-18-sched-throttle-entities-exceeding-their-allowed-bandwidth:
  sched: throttle entities exceeding their allowed (FATE#311682).
- patches.suse/15-18-sched-add-exports-tracking-cfs-bandwidth-control-statistics:
  sched: add exports tracking cfs bandwidth control statistics (FATE#311682).
- patches.suse/16-18-sched-return-unused-runtime-on-group-dequeue:
  sched: return unused runtime on group dequeue (FATE#311682).
- patches.suse/18-18-sched-add-documentation-for-bandwidth-control:
  sched: add documentation for bandwidth control (FATE#311682).
- patches.suse/01-15-sched-fixlet-dont-update-shares-twice-on-on_rq-parent: Delete.
- patches.suse/02-15-sched-hierarchical-task-accounting-for-SCHED_OTHER: Delete.
- patches.suse/03-15-sched-introduce-primitives-to-account-for-CFS-bandwidth-tracking: Delete.
- patches.suse/03-15-sched-introduce-primitives-to-account-for-CFS-bandwidth-tracking-fix: Delete.
- patches.suse/04-15-sched-validate-CFS-quota-hierarchies: Delete.
- patches.suse/04-15-sched-validate-CFS-quota-hierarchies-fix: Delete.
- patches.suse/05-15-sched-add-a-timer-to-handle-CFS-bandwidth-refresh: Delete.
- patches.suse/06-15-sched-accumulate-per-cfs_rq-cpu-usage-and-charge-against-bandwidth: Delete.
- patches.suse/07-15-sched-expire-invalid-runtime: Delete.
- patches.suse/08-15-sched-throttle-cfs_rq-entities-which-exceed-their-local-runtime: Delete.
- patches.suse/09-15-sched-unthrottle-cfs_rqs-who-ran-out-of-quota-at-period-refresh: Delete.
- patches.suse/10-15-sched-allow-for-positional-tg_tree-walks: Delete.
- patches.suse/11-15-sched-prevent-interactions-between-throttled-entities-and-load-balance: Delete.
- patches.suse/12-15-sched-migrate-throttled-tasks-on-HOTPLUG: Delete.
- patches.suse/13-15-sched-add-exports-tracking-cfs-bandwidth-control-statistics: Delete.
- patches.suse/14-15-sched-return-unused-runtime-on-voluntary-sleep: Delete.
- patches.suse/15-15-sched-add-documentation-for-bandwidth-control: Delete.
- patches.suse/16-15-sched-fix-hotplug-lockup: Delete.
* Thu Jul 21 2011 jbohac@suse.cz
- patches.fixes/net-deliver-skbs-on-inactive-slaves-to-exact-matches.patch:
  Refresh (fix typo).
* Thu Jul 21 2011 trenn@suse.de
- patches.drivers/x86_amd_microcode_be_less_verbose.patch: x86:
  ucode-amd: Don't warn when no ucode is available for a CPU
  revision (bnc#706557).
* Thu Jul 21 2011 trenn@suse.de
  Fix double calling some functions in processor_start()
- patches.arch/acpi_processor_fix_cpuidle_unregister.patch:
  Refresh.
- patches.arch/acpi_processor_split_add.patch: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Thu Jul 21 2011 jbohac@suse.cz
- patches.fixes/net-deliver-skbs-on-inactive-slaves-to-exact-matches.patch:
  net: deliver skbs on inactive slaves to exact matches
  (bnc#649355).
- patches.fixes/net-fix-deliver_no_wcard-regression-on-loopback-device.patch:
  net: fix deliver_no_wcard regression on loopback device
  (bnc#649355).
* Thu Jul 21 2011 mmarek@suse.cz
- Get rid of private copies of skb_checksum_none_assert()
- patches.drivers/drivers_net_avoid_some_skb-_ip_summed_initializations:
  drivers/net: avoid some skb->ip_summed initializations.
- patches.drivers/0063-drivers-net-avoid-some-skb-ip_summed-initializations.patch:
  Refresh.
- patches.drivers/0103-tg3-Move-EEE-definitions-into-mdio.h.patch:
  Refresh.
- patches.drivers/0182-tg3-enable-transmit-time-stamping.patch:
  Refresh.
- patches.drivers/0188-tg3-Migrate-phy-preprocessor-defs-to-system-defs.patch:
  Refresh.
- patches.drivers/cxgb4-chelsio-t4-driver-compat: Refresh.
- Rename patches.drivers/020-drivers_net_avoid_some_skb-_ip_summed_initializations
  to patches.drivers/020-igbvf-drivers_net_avoid_some_skb-_ip_summed_initializations.
* Thu Jul 21 2011 jdelvare@suse.de
- patches.fixes/natsemi-long-cable-fix: natsemi: make cable
  length magic configurable (bnc#225091, bnc#704361).
- patches.fixes/net-natsemi-fix-module-parameter-permissions.patch:
  net/natsemi: Fix module parameter permissions.
* Thu Jul 21 2011 mmarek@suse.cz
- igbvf update (fate#311862)
- patches.drivers/001-net_Convert_ethtool_get_stats_self_test_count_ops_to_get_sset_count:
  net: Convert ethtool {get_stats, self_test}_count() ops to
  get_sset_count() (bnc#699087, fate#311862).
- patches.drivers/002-drivers_net_request_irq_-_Remove_unnecessary_leading_from_second_arg:
  drivers/net: request_irq - Remove unnecessary leading & from
  second arg (bnc#699087, fate#311862).
- patches.drivers/003-igbvf_remove_skb_dma_map_unmap_call_from_drivers:
  igbvf: remove skb_dma_map/unmap call from drivers (bnc#699087,
  fate#311862).
- patches.drivers/004-drivers_net_Move_and_to_end_of_previous_line:
  drivers/net: Move && and || to end of previous line (bnc#699087,
  fate#311862).
- patches.drivers/005-igbvf_avoid_reset_storms_due_to_mailbox_issues:
  igbvf: avoid reset storms due to mailbox issues (bnc#699087,
  fate#311862).
- patches.drivers/006-igbvf_Make_igbvf_error_message_more_informative:
  igbvf: Make igbvf error message more informative (bnc#699087,
  fate#311862).
- patches.drivers/007-drivers_net_igbvf_netdev.c_use_pM_to_shown_MAC_address:
  drivers/net/igbvf/netdev.c: use %%pM to shown MAC address
  (bnc#699087, fate#311862).
- patches.drivers/008-drivers_net_use_DEFINE_PCI_DEVICE_TABLE:
  drivers/net/: use DEFINE_PCI_DEVICE_TABLE() (bnc#699087,
  fate#311862).
- patches.drivers/009-e1000_e1000e_igb_igbvf_ixgb_ixgbe_Fix_tests_of_unsigned_in_tx_map:
  e1000/e1000e/igb/igbvf/ixgb/ixgbe: Fix tests of unsigned in
  * _tx_map() (bnc#699087, fate#311862).
- patches.drivers/010-igb_igbvf_cleanup_exception_handling_in_tx_map_adv:
  igb/igbvf: cleanup exception handling in tx_map_adv (bnc#699087,
  fate#311862).
- patches.drivers/011-net_Fix_IPv6_GSO_type_checks_in_Intel_ethernet_drivers:
  net: Fix IPv6 GSO type checks in Intel ethernet drivers
  (bnc#699087, fate#311862).
- patches.drivers/012-igbvf_fix_issue_w_mapped_as_page_being_left_set_after_unmap:
  igbvf: fix issue w/ mapped_as_page being left set after unmap
  (bnc#699087, fate#311862).
- patches.drivers/013-net_use_netdev_mc_count_and_netdev_mc_empty_when_appropriate:
  net: use netdev_mc_count and netdev_mc_empty when appropriate
  (bnc#699087, fate#311862).
- patches.drivers/014-net_convert_multiple_drivers_to_use_netdev_for_each_mc_addr_part4:
  net: convert multiple drivers to use netdev_for_each_mc_addr,
  part4 (bnc#699087, fate#311862).
- patches.drivers/015-igbvf_do_not_modify_tx_queue_len_on_link_speed_change:
  igbvf: do not modify tx_queue_len on link speed change
  (bnc#699087, fate#311862).
- patches.drivers/016-include_cleanup_Update_gfp.h_and_slab.h_includes_to_prepare_for_breaking_implicit_slab.h_inclusion_from_percpu.h:
  include cleanup: Update gfp.h and slab.h includes to prepare for
  breaking implicit slab.h inclusion from percpu.h (bnc#699087,
  fate#311862).
- patches.drivers/017-igbvf_double_increment_nr_frags: igbvf:
  double increment nr_frags (bnc#699087, fate#311862).
- patches.drivers/018-drivers_net_Remove_unnecessary_returns_from_void_function_s:
  drivers/net: Remove unnecessary returns from void function()s
  (bnc#699087, fate#311862).
- patches.drivers/019-e100_e1000_igb_ixgb_Add_missing_read_memory_barrier:
  e100/e1000*/igb*/ixgb*: Add missing read memory barrier
  (bnc#699087, fate#311862).
- patches.drivers/020-drivers_net_avoid_some_skb-_ip_summed_initializations:
  drivers/net: avoid some skb->ip_summed initializations
  (bnc#699087, fate#311862).
- patches.drivers/021-drivers_net_return_operator_cleanup:
  drivers/net: return operator cleanup (bnc#699087, fate#311862).
- patches.drivers/022-igbvf_Remove_unneeded_pm_qos_calls: igbvf:
  Remove unneeded pm_qos* calls (bnc#699087, fate#311862).
- patches.drivers/023-igbvf_fix_panic_on_load: igbvf: fix panic
  on load (bnc#699087, fate#311862).
- patches.drivers/024-igbvf_Update_version_and_Copyright: igbvf:
  Update version and Copyright (bnc#699087, fate#311862).
- patches.drivers/025-igbvf_Remove_some_dead_code_in_igbvf: igbvf:
  Remove some dead code in igbvf (bnc#699087, fate#311862).
- patches.drivers/026-netdev_Use_default_implementation_of_ethtool_ops_get_link_where_possible:
  netdev: Use default implementation of ethtool_ops::get_link
  where possible (bnc#699087, fate#311862).
- patches.drivers/027-igb_ixgbe_don_t_use_flush_scheduled_work:
  igb[v],ixgbe: don't use flush_scheduled_work() (bnc#699087,
  fate#311862).
- patches.drivers/028-igbvf_force_link_checking_when_mailbox_timeout_has_occurred:
  igbvf: force link checking when mailbox timeout has occurred
  (bnc#699087, fate#311862).
- patches.drivers/029-igbvf_add_support_for_i350_VF_device: igbvf:
  add support for i350 VF device (bnc#699087, fate#311862).
* Thu Jul 21 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete brocade-bna-kmp (fate#311451).
* Thu Jul 21 2011 tiwai@suse.de
- supported.conf: Add iw_cxgb4
* Thu Jul 21 2011 tiwai@suse.de
- patches.drivers/iw_cxgb4-0001-RDMA-cxgb4-Add-driver-for-Chelsio-T4-RNIC:
  RDMA/cxgb4: Add driver for Chelsio T4 RNIC (fate#311869).
- patches.drivers/iw_cxgb4-0002-Add-cxgb4-and-iw_cxgb4-entries:
  MAINTAINERS: Add cxgb4 and iw_cxgb4 entries (fate#311869).
- Update config files.
* Thu Jul 21 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Add two more fixes, git
  commit IDs, and another bugzilla reference.
* Thu Jul 21 2011 brogers@suse.com
- patches.suse/KVM-remove-CAP_SYS_RAWIO-requirement-from-kvm_vm_io.patch:
  KVM: remove CAP_SYS_RAWIO requirement from
  kvm_vm_ioctl_assign_irq (bnc#706131).
- patches.suse/pci-check-caps-from-sysfs-file-open-to-read-device.patch:
  pci: check caps from sysfs file open to read device dependent
  config space (bnc#706131).
- patches.suse/sysfs-add-struct-file-to-bin_attr-callbacks.patch:
  sysfs: add struct file* to bin_attr callbacks (bnc#706131).
* Wed Jul 20 2011 mmarek@suse.cz
- patches.suse/0001-net-use-net_eq-to-compare-nets.patch: net:
  use net_eq to compare nets (bnc#687049, fate#311957).
- patches.suse/0002-net-Move-and-to-end-of-previous-line.patch:
  net: Move && and || to end of previous line (bnc#687049,
  fate#311957).
- patches.suse/0003-const-struct-nla_policy.patch: const: struct
  nla_policy (bnc#687049, fate#311957).
- patches.suse/0004-include-cleanup-Update-gfp.h-and-slab.h-includes-to-.patch:
  include cleanup: Update gfp.h and slab.h includes to
  (bnc#687049, fate#311957).
- patches.suse/0005-dcbnl-add-support-for-ieee8021Qaz-attributes.patch:
  dcbnl: add support for ieee8021Qaz attributes (bnc#687049,
  fate#311957).
- patches.suse/0006-dcbnl-add-appliction-tlv-handlers.patch:
  dcbnl: add appliction tlv handlers (bnc#687049, fate#311957).
- patches.suse/0007-net_dcb-add-application-notifiers.patch:
  net_dcb: add application notifiers (bnc#687049, fate#311957).
- patches.suse/0008-dcbnl-adding-DCBX-engine-capability.patch:
  dcbnl: adding DCBX engine capability (bnc#687049, fate#311957).
- patches.suse/0009-dcbnl-adding-DCBX-feature-flags-get-set.patch:
  dcbnl: adding DCBX feature flags get-set (bnc#687049,
  fate#311957).
- patches.suse/0010-dcbnl-cleanup.patch: dcbnl: cleanup
  (bnc#687049, fate#311957).
- patches.suse/0011-dcbnl-more-informed-return-values-for-new-dcbnl-rout.patch:
  dcbnl: more informed return values for new dcbnl (bnc#687049,
  fate#311957).
- patches.suse/0012-dcb-unlock-on-error-in-dcbnl_ieee_get.patch:
  dcb: unlock on error in dcbnl_ieee_get() (bnc#687049,
  fate#311957).
- patches.suse/0013-dcb-use-after-free-in-dcb_flushapp.patch:
  dcb: use after free in dcb_flushapp() (bnc#687049, fate#311957).
- patches.suse/0014-dcbnl-make-get_app-handling-symmetric-for-IEEE-and-C.patch:
  dcbnl: make get_app handling symmetric for IEEE and (bnc#687049,
  fate#311957).
- patches.suse/0015-net-dcb-application-priority-is-per-net_device.patch:
  net: dcb: application priority is per net_device (bnc#687049,
  fate#311957).
- patches.suse/0016-Don-t-potentially-dereference-NULL-in-net-dcb-dcbnl..patch:
  Don't potentially dereference NULL in (bnc#687049, fate#311957).
- patches.suse/0017-net-dcbnl-check-correct-ops-in-dcbnl_ieee_set.patch:
  net: dcbnl: check correct ops in dcbnl_ieee_set() (bnc#687049,
  fate#311957).
- patches.suse/0018-dcbnl-add-support-for-retrieving-peer-configuration-.patch:
  dcbnl: add support for retrieving peer configuration -
  (bnc#687049, fate#311957).
- patches.suse/0019-dcbnl-add-support-for-retrieving-peer-configuration-.patch:
  dcbnl: add support for retrieving peer configuration -
  (bnc#687049, fate#311957).
- patches.suse/0020-net-dcbnl-Update-copyright-dates.patch: net:
  dcbnl: Update copyright dates (bnc#687049, fate#311957).
- patches.suse/0021-dcb-Add-DCBX-capabilities-bitmask-to-the-get_ieee-re.patch:
  dcb: Add DCBX capabilities bitmask to the get_ieee (bnc#687049,
  fate#311957).
- patches.suse/0022-net-dcbnl-add-multicast-group-for-DCB.patch:
  net: dcbnl, add multicast group for DCB (bnc#687049,
  fate#311957).
- patches.suse/0023-dcb-Add-ieee_dcb_setapp-to-be-used-for-IEEE-802.1Qaz.patch:
  dcb: Add ieee_dcb_setapp() to be used for IEEE (bnc#687049,
  fate#311957).
- patches.suse/0024-dcb-Add-ieee_dcb_delapp-and-dcb-op-to-delete-app-ent.patch:
  dcb: Add ieee_dcb_delapp() and dcb op to delete app (bnc#687049,
  fate#311957).
- patches.suse/0025-dcb-Add-dcb_ieee_getapp_mask-for-drivers-to-query-AP.patch:
  dcb: Add dcb_ieee_getapp_mask() for drivers to query
  (bnc#687049, fate#311957).
- patches.suse/0026-dcb-fix-return-type-on-dcb_setapp.patch:
  dcb: fix return type on dcb_setapp() (bnc#687049, fate#311957).
- patches.suse/0027-dcb-Add-missing-error-check-in-dcb_ieee_set.patch:
  dcb: Add missing error check in dcb_ieee_set() (bnc#687049,
  fate#311957).
- patches.suse/0028-dcb-use-nlmsg_free-instead-of-kfree.patch:
  dcb: use nlmsg_free() instead of kfree() (bnc#687049,
  fate#311957).
- patches.suse/0029-dcbnl-Aggregated-CEE-GET-operation.patch:
  dcbnl: Aggregated CEE GET operation (bnc#687049, fate#311957).
- patches.suse/0030-dcbnl-Add-CEE-notification.patch: dcbnl:
  Add CEE notification (bnc#687049, fate#311957).
- patches.suse/0031-dcbnl-unlock-on-an-error-path-in-dcbnl_cee_fill.patch:
  dcbnl: unlock on an error path in dcbnl_cee_fill() (bnc#687049,
  fate#311957).
* Wed Jul 20 2011 mmarek@suse.cz
- Add the ixgbevf driver (fate#311956):
- patches.drivers/0001-ixgbevf-Macros-data-structures-useful-defines-and.patch:
  ixgbevf: Macros, data structures, useful defines and registers
  (bnc#699085, fate#311956).
- patches.drivers/0002-ixgbevf-82599-Virtual-Function-core-functions-and-h.patch:
  ixgbevf: 82599 Virtual Function core functions and header
  (bnc#699085, fate#311956).
- patches.drivers/0003-ixgbevf-Mailbox-communication.patch:
  ixgbevf: Mailbox communication (bnc#699085, fate#311956).
- patches.drivers/0004-ixgbevf-Driver-main-and-ethool-interface-module-and.patch:
  ixgbevf: Driver main and ethool interface module and main header
  (bnc#699085, fate#311956).
- patches.drivers/0005-ixgbevf-Driver-Makefile.patch: ixgbevf:
  Driver Makefile (bnc#699085, fate#311956).
- patches.drivers/0006-ixgbevf-Kconfig-Makefile-and-Documentation.patch:
  ixgbevf: Kconfig, Makefile and Documentation (bnc#699085,
  fate#311956).
- patches.drivers/0007-ixgbevf-Take-action-when-the-PF-notifies-the-VF-it.patch:
  ixgbevf: Take action when the PF notifies the VF it is resetting
  (bnc#699085, fate#311956).
- patches.drivers/0008-ixgbevf-Fix-panics-in-the-VF-driver.patch:
  ixgbevf: Fix panics in the VF driver (bnc#699085, fate#311956).
- patches.drivers/0009-ixgbevf-Tell-network-stack-to-stop-tx-when-the-VF-d.patch:
  ixgbevf: Tell network stack to stop tx when the VF detects PF
  reset (bnc#699085, fate#311956).
- patches.drivers/0010-ixgbevf-Fix-IPv6-GSO-type-checks.patch:
  ixgbevf: Fix IPv6 GSO type checks (bnc#699085, fate#311956).
- patches.drivers/0011-ixgbevf-Fix-VF-Stats-accounting-after-reset.patch:
  ixgbevf: Fix VF Stats accounting after reset (bnc#699085,
  fate#311956).
- patches.drivers/0012-ixgbevf-Shorten-up-delay-timer-for-watchdog-task.patch:
  ixgbevf: Shorten up delay timer for watchdog task (bnc#699085,
  fate#311956).
- patches.drivers/0013-ixgbevf-Message-formatting-cleanups.patch:
  ixgbevf: Message formatting cleanups (bnc#699085, fate#311956).
- patches.drivers/0014-ixgbevf-Fix-signed-unsigned-int-error.patch:
  ixgbevf: Fix signed/unsigned int error (bnc#699085,
  fate#311956).
- patches.drivers/0015-ixgbevf-ethtool-cosmetic-Use-ethtool-ethtool_cmd_speed-API.patch:
  ethtool: cosmetic: Use ethtool ethtool_cmd_speed API
  (bnc#699085, fate#311956).
- patches.drivers/0016-ixgbevf-Add-macvlan-support-in-the-set-rx-mode-op.patch:
  ixgbevf: Add macvlan support in the set rx mode op (bnc#699085,
  fate#311956).
- patches.drivers/0017-ixgbevf-Add-appropriate-linux-prefetch.h-include-for-prefe.patch:
  Add appropriate <linux/prefetch.h> include for prefetch users
  (bnc#699085, fate#311956).
- patches.drivers/0018-ixgbevf-Update-the-driver-string.patch:
  ixgbevf: Update the driver string (bnc#699085, fate#311956).
- patches.drivers/0019-ixgbevf-Fix-bungled-declaration-of-ixgbevf_mbx_ops.patch:
  ixgbevf: Fix bungled declaration of ixgbevf_mbx_ops (bnc#699085,
  fate#311956).
- patches.drivers/0020-ixgbevf-remove-unnecessary-ampersands.patch:
  ixgbevf: remove unnecessary ampersands (bnc#699085,
  fate#311956).
* Wed Jul 20 2011 jeffm@suse.com
- patches.drivers/bnx2x-enable-lro-disablement: bnx2x - enable
  LRO disablement (bnc#698050).
- patches.drivers/bnx2x-fix-compat-to-allow-multiqueue: bnx2x -
  fix compat to allow multiqueue (bnc#698050).
- patches.drivers/bnx2x-fix-inappropriate-msg-lvl: bnx2x -
  fix inappropriate msg lvl (bnc#698050).
- patches.drivers/bnx2x-fix-vlan-stripping-configuration: bnx2x -
  fix VLAN stripping configuration (bnc#698050).
* Wed Jul 20 2011 jeffm@suse.com
- patches.fixes/proc-restrict-access-to-proc-pid-io: proc:
  restrict access to /proc/PID/io (CVE-2011-2495 bnc#703155).
* Wed Jul 20 2011 mgorman@suse.de
- patches.fixes/mm-allow-non-rt-sleep-__lock_page.patch: Update
  references (bnc#699916).
- patches.fixes/mm-fix_priority-inversion-__lock_page.patch:
  Update references (bnc#699916).
* Wed Jul 20 2011 hare@suse.de
- patches.drivers/hpsa-update-to-hp-version.patch: Fixup
  definition of DIRECT_LOOKUP_BIT (bnc#706821).
* Tue Jul 19 2011 hare@suse.de
- patches.drivers/ixgbe-Make-descriptor-ring-allocations-NUMA-aware.patch:
  ixgbe: Make descriptor ring allocations NUMA-aware
  (FATE#311997).
- patches.drivers/ixgbe-add-a-refcnt-when-turning-on-off-FCoE-offload.patch:
  ixgbe: add a refcnt when turning on/off FCoE offload capability
  (FATE#311997).
- patches.drivers/ixgbe-cleanup-variable-initialization.patch:
  ixgbe: cleanup variable initialization (FATE#311997).
- patches.drivers/ixgbe-entropy-source.patch: Refresh.
- patches.drivers/ixgbe-remove-some-redundant-code-in-setting-FCoE-FI.patch:
  ixgbe: remove some redundant code in setting FCoE FIP filter
  (FATE#311997).
- patches.drivers/ixgbe-update-all-DESC_ADV-macros-to-accept-a-ring-p.patch:
  ixgbe: update all DESC_ADV macros to accept a ring pointer
  (FATE#311997).
- patches.drivers/ixgbe-update-copyright-dates.patch: ixgbe:
  update copyright dates (FATE#311997).
* Tue Jul 19 2011 hare@suse.de
- patches.drivers/aacraid-Add-new-code-for-PMC-Sierra-s-SRC-ba.patch:
  aacraid: Add new code for PMC-Sierra's SRC based controller
  family (bnc#705472,FATE#311522).
* Tue Jul 19 2011 hare@suse.de
- patches.suse/net-add-ndo_fcoe_ddp_target-to-support-FCoE-DDP-i.patch:
  net: add ndo_fcoe_ddp_target() to support FCoE DDP in target
  mode (bnc#699950).
- patches.suse/vlan-add-support-to-ndo_fcoe_ddp_target.patch:
  vlan: add support to ndo_fcoe_ddp_target() (bnc#699950).
- patches.suse/vlan-allow-null-vlan-id-to-be-used.patch: Refresh.
* Tue Jul 19 2011 jjolly@suse.de
- patches.arch/s390-fate311926-ap-type10-toleration.patch:
  ap: Toleration for ap bus devices with device type 10
  (bnc#703653,LTC#69692,FATE#311926).
* Mon Jul 18 2011 jeffm@suse.com
- patches.drivers/cxgb3-fix-device-opening-error-path: cxgb3:
  fix device opening error path (FATE#311470 bnc#694966).
- patches.drivers/cxgb3-fix-panic-in-free_tx_desc: cxgb3: Fix
  panic in free_tx_desc() (FATE#311470 bnc#694966).
- patches.drivers/cxgb3-skb_record_rx_queue-now-records-the-queue-index-relative-to-the-net_device:
  cxgb3: skb_record_rx_queue now records the queue index relative
  to the net_device (FATE#311470 bnc=694966).
* Mon Jul 18 2011 jack@suse.cz
- patches.fixes/vfs-fix_double_put_in_sync_filesystems.patch:
  Fix double put in sync_filesystems() (bnc#706472).
* Mon Jul 18 2011 mmarek@suse.cz
- Fix config files after 71b7422.
* Mon Jul 18 2011 mmarek@suse.cz
- Enable the writeback patches again, the performance regression is
  solved in SP2 (bnc#703786#c2)
- patches.suse/laptop-mode-Make-flushes-per-device.patch: Refresh.
* Mon Jul 18 2011 duwe@suse.de
- supported.conf: mark pseries_energy.ko as supported (by IBM)
  (bnc#706473 / FATE 311643)
* Mon Jul 18 2011 jeffm@suse.com
- Update config files.
- patches.drivers/bna-add-appropriate-linux-prefetch-h-include-for-prefetch-users:
  Add appropriate <linux/prefetch.h> include for prefetch users
  (FATE#311451 bnc#689230).
- patches.drivers/bna-brocade-10gb-ethernet-device-driver: bna:
  Brocade 10Gb Ethernet device driver (FATE#311451 bnc#689230).
- patches.drivers/bna-check-for-null-before-deref-in-bnad_cb_tx_cleanup:
  bna: Check for NULL before deref in bnad_cb_tx_cleanup
  (FATE#311451 bnc#689230).
- patches.drivers/bna-compatibility-fixes-for-sle11sp2-backport:
  bna: Compatibility fixes for SLE11SP2 backport (FATE#311451
  bnc#689230).
- patches.drivers/bna-delete-get_flags-and-set_flags-ethtool-methods:
  bna: Delete get_flags and set_flags ethtool methods (FATE#311451
  bnc#689230).
- patches.drivers/bna-drivers-net-return-operator-cleanup:
  drivers/net: return operator cleanup (FATE#311451 bnc#689230).
- patches.drivers/bna-enable-pure-priority-tagged-packet-reception-and-rxf-uninit-cleanup-fix:
  bna: Enable pure priority tagged packet reception and rxf
  uninit cleanup fix (FATE#311451 bnc#689230).
- patches.drivers/bna-ethtool-cosmetic-use-ethtool-ethtool_cmd_speed-api:
  ethtool: cosmetic: Use ethtool ethtool_cmd_speed API
  (FATE#311451 bnc#689230).
- patches.drivers/bna-ethtool-use-full-32-bit-speed-range-in-ethtool-s-set_settings:
  ethtool: Use full 32 bit speed range in ethtool's set_settings
  (FATE#311451 bnc#689230).
- patches.drivers/bna-fix-call-trace-when-interrupts-are-disabled-while-sleeping-function-kzalloc-is-called:
  Fix call trace when interrupts are disabled while sleeping
  function kzalloc is called (FATE#311451 bnc#689230).
- patches.drivers/bna-fix-common-misspellings: Fix common
  misspellings (FATE#311451 bnc#689230).
- patches.drivers/bna-fix-ethtool-register-dump-and-reordered-an-api:
  bna: Fix ethtool register dump and reordered an API (FATE#311451
  bnc#689230).
- patches.drivers/bna-fix-for-clean-fw-re-initialization: bna:
  fix for clean fw re-initialization (FATE#311451 bnc#689230).
- patches.drivers/bna-fix-for-handling-firmware-heartbeat-failure:
  bna: Fix for handling firmware heartbeat failure (FATE#311451
  bnc#689230).
- patches.drivers/bna-fix-for-tx-queue: bna: Fix for TX queue
  (FATE#311451 bnc#689230).
- patches.drivers/bna-fix-interrupt-handling: bna: fix interrupt
  handling (FATE#311451 bnc#689230).
- patches.drivers/bna-fix-memory-leak-during-rx-path-cleanup: bna:
  fix memory leak during RX path cleanup (FATE#311451 bnc#689230).
- patches.drivers/bna-fix-set-but-unused-variables: bna: Fix
  set-but-unused variables (FATE#311451 bnc#689230).
- patches.drivers/bna-fix-stats-handling: bna: fix stats handling
  (FATE#311451 bnc#689230).
- patches.drivers/bna-fixed-build-break-for-allyesconfig: bna:
  Fixed build break for allyesconfig (FATE#311451 bnc#689230).
- patches.drivers/bna-ioc-failure-auto-recovery-fix: bna: IOC
  failure auto recovery fix (FATE#311451 bnc#689230).
- patches.drivers/bna-ioc-uninit-check-and-misc-cleanup: bna:
  IOC uninit check and misc cleanup (FATE#311451 bnc#689230).
- patches.drivers/bna-net-bna-fix-compile-warning-of-bfa_ioc_smem_pgoff-defined-but-not-used:
  net:bna: fix compile warning of ‘bfa_ioc_smem_pgoff’
  defined but not used (FATE#311451 bnc#689230).
- patches.drivers/bna-net-bna-fix-lock-imbalance: NET: bna,
  fix lock imbalance (FATE#311451 bnc#689230).
- patches.drivers/bna-off-by-one: bna: off by one (FATE#311451
  bnc#689230).
- patches.drivers/bna-port-enable-disable-sync-and-txq-priority-fix:
  bna: Port enable disable sync and txq priority fix (FATE#311451
  bnc#689230).
- patches.drivers/bna-remove-unnecessary-memset-0: bna: Remove
  unnecessary memset(,0,) (FATE#311451 bnc#689230).
- patches.drivers/bna-removed-unused-code: bna: Removed unused
  code (FATE#311451 bnc#689230).
- patches.drivers/bna-restore-vlan-filter-table: bna: Restore
  VLAN filter table (FATE#311451 bnc#689230).
- patches.drivers/bna-scope-and-dead-code-cleanup: bna: scope
  and dead code cleanup (FATE#311451 bnc#689230).
- patches.drivers/bna-txrx-and-datapath-fix: bna: TxRx and
  datapath fix (FATE#311451 bnc#689230).
- patches.drivers/bna-update-the-driver-version-to-2-3-2-3: bna:
  Update the driver version to 2.3.2.3 (FATE#311451 bnc#689230).
- patches.drivers/bna-use-device-model-dma-api: bna: use device
  model DMA API (FATE#311451 bnc#689230).
- patches.drivers/bna-vlan-don-t-check-for-vlan-group-before-vlan_tx_tag_present:
  vlan: Don't check for vlan group before vlan_tx_tag_present
  (FATE#311451 bnc#689230).
* Mon Jul 18 2011 mmarek@suse.cz
- patches.suse/laptop-mode-Make-flushes-per-device.patch: Fix build.
* Mon Jul 18 2011 duwe@suse.de
- patches.suse/zcrypt-feed-hwrandom: s390: provide hardware
  randomness from zcrypt card to /dev/random (fate 310591).
* Mon Jul 18 2011 hare@suse.de
- bnx2fc update to 1.0.4:
  * patches.drivers/bnx2fc-Do-not-arm-CQ-when-there-are-no-CQEs.patch:
    bnx2fc: Do not arm CQ when there are no CQEs (bnc#698053,
    FATE#311462).
  * patches.drivers/bnx2fc-Enable-REC-CONF-support-for-the-session.patch:
    bnx2fc: Enable REC & CONF support for the session (bnc#698053,
    FATE#311462).
  * patches.drivers/bnx2fc-Enable-support-for-sequence-level-error-reco.patch:
    bnx2fc: Enable support for sequence level error recovery
    (bnc#698053, FATE#311462).
  * patches.drivers/bnx2fc-Fix-kernel-panic-when-deleting-NPIV-ports.patch:
    bnx2fc: Fix kernel panic when deleting NPIV ports (bnc#698053,
    FATE#311462).
  * patches.drivers/bnx2fc-HSI-changes-for-tape.patch: bnx2fc:
    HSI changes for tape (bnc#698053, FATE#311462).
  * patches.drivers/bnx2fc-Handle-REC_TOV-error-code-from-firmware.patch:
    bnx2fc: Handle REC_TOV error code from firmware (bnc#698053,
    FATE#311462).
  * patches.drivers/bnx2fc-Introduce-interface-structure-for-each-vlan.patch:
    bnx2fc: Introduce interface structure for each vlan interface
    (bnc#698053, FATE#311462).
  * patches.drivers/bnx2fc-REC-SRR-link-service-request-and-response-ha.patch:
    bnx2fc: REC/SRR link service request and response handling
    (bnc#698053, FATE#311462).
  * patches.drivers/bnx2fc-Replace-printks-with-KERN_ALERT-to-KERN_ERR.patch:
    bnx2fc: Replace printks with KERN_ALERT to KERN_ERR/KERN_INFO
    (bnc#698053, FATE#311462).
  * patches.drivers/bnx2fc-Support-sequence-cleanup-task.patch:
    bnx2fc: Support 'sequence cleanup' task (bnc#698053, FATE#311462).
  * patches.drivers/bnx2fc-Tx-BDs-cache-in-write-tasks.patch:
    bnx2fc: Tx BDs cache in write tasks (bnc#698053, FATE#311462).
  * patches.drivers/bnx2fc-Update-copyright-and-bump-version-to-1.0.4.patch:
    bnx2fc: Update copyright and bump version to 1.0.4 (bnc#698053,
    FATE#311462).
  * patches.drivers/bnx2fc-hold-tgt-lock-when-calling-cmd_release.patch:
    bnx2fc: hold tgt lock when calling cmd_release (bnc#698053,
    FATE#311462).
  * patches.drivers/bnx2fc-host-stats-show-the-link-speed-unknown-on.patch:
    bnx2fc: host stats show the link speed 'unknown' on NIC
    partitioned interfaces (bnc#698053, FATE#311462).
  * patches.drivers/bnx2fc-scsi_dma_unmap-not-invoked-on-IO-completio.patch:
    bnx2fc: scsi_dma_unmap() not invoked on IO completions
    (bnc#698053, FATE#311462).
* Mon Jul 18 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-117-add-Intel-Panther-Point-HDMI-codec-id:
  Refresh; added the missing module-alias definition for PPT.
* Fri Jul 15 2011 mhocko@suse.cz
- patches.fixes/mm-do_fault-preallocate-cow-page.patch:
  mm: preallocate page before lock_page() at filemap COW
  (bnc#7000995).
* Fri Jul 15 2011 tonyj@suse.de
- patches.suse/intel-perf-0001-pmu.patch: perf, x86: Add PEBS
  infrastructure (fate#311939, bnc#704917).
- patches.suse/intel-perf-0002-pmu.patch: perf, x86: Implement
  simple LBR support (fate#311939, bnc#704917).
- patches.suse/intel-perf-0003-pmu.patch: perf, x86: use LBR
  for PEBS IP+1 fixup (fate#311939, bnc#704917).
- patches.suse/intel-perf-0004-pmu.patch: perf, x86: Clean up
  IA32_PERF_CAPABILITIES usage (fate#311939, bnc#704917).
- patches.suse/intel-perf-0005-pmu.patch: perf, x86: Expose
  the full PEBS record using PERF_SAMPLE_RAW (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0006-pmu.patch: perf, x86: Fix silly
  bug in data store buffer allocation (fate#311939, bnc#704917).
- patches.suse/intel-perf-0007-pmu.patch: perf, x86: Disable
  PEBS on clovertown chips (fate#311939, bnc#704917).
- patches.suse/intel-perf-0008-pmu.patch: perf, x86: Clear the
  LBRs on init (fate#311939, bnc#704917).
- patches.suse/intel-perf-0009-pmu.patch: perf, x86: Robustify
  PEBS fixup (fate#311939, bnc#704917).
- patches.suse/intel-perf-0010-pmu.patch: perf, x86: Avoid double
  disable on throttle vs ioctl(PERF_IOC_DISABLE) (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0011-pmu.patch: perf, x86: Fix pebs
  drains (fate#311939, bnc#704917).
- patches.suse/intel-perf-0012-pmu.patch: perf, x86: Fix PEBS
  enable/disable vs cpuc->enabled (fate#311939, bnc#704917).
- patches.suse/intel-perf-0013-pmu.patch: perf, x86: Fix LBR
  enable/disable vs cpuc->enabled (fate#311939, bnc#704917).
- patches.suse/intel-perf-0014-pmu.patch: perf, x86: Reorder
  intel_pmu_enable_all() (fate#311939, bnc#704917).
- patches.suse/intel-perf-0015-pmu.patch: perf, x86: Deal with
  multiple state bits for pebs-fmt1 (fate#311939, bnc#704917).
- patches.suse/intel-perf-0016-pmu.patch: perf, x86: Fix silly bug
  in intel_pmu_pebs_{enable,disable} (fate#311939, bnc#704917).
- patches.suse/intel-perf-0017-pmu.patch: perf, x86: Don't reset
  the LBR as frequently (fate#311939, bnc#704917).
- patches.suse/intel-perf-0018-pmu.patch: perf, x86: Remove
  checking_{wr,rd}msr() usage (fate#311939, bnc#704917).
- patches.suse/intel-perf-0019-pmu.patch: perf, x86: Fixup the
  PEBS handler for Core2 cpus (fate#311939, bnc#704917).
- patches.suse/intel-perf-0020-pmu.patch: perf, x86: Fix LBR
  read-out (fate#311939, bnc#704917).
- patches.suse/intel-perf-0021-pmu.patch: perf, x86: Fix the
  !CONFIG_CPU_SUP_INTEL build (fate#311939, bnc#704917).
- patches.suse/intel-perf-0022-pmu.patch: perf: Introduce new
  perf_fetch_caller_regs() for hot regs snapshot (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0023-pmu.patch: perf: export
  perf_trace_regs and perf_arch_fetch_caller_regs (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0024-pmu.patch: perf, x86: Implement
  initial P4 PMU driver (fate#311939, bnc#704917).
- patches.suse/intel-perf-0025-pmu.patch: x86, perf: Fix NULL
  deref on not assigned x86_pmu (fate#311939, bnc#704917).
- patches.suse/intel-perf-0026-pmu.patch: x86, perf: Unmask
  LVTPC only if we have APIC supported (fate#311939, bnc#704917).
- patches.suse/intel-perf-0027-pmu.patch: perf, x86: Enable
  not tagged retired instruction counting on P4s (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0028-pmu.patch: perf: Fix unexported
  generic perf_arch_fetch_caller_regs (fate#311939, bnc#704917).
- patches.suse/intel-perf-0029-pmu.patch: perf, x86: Report
  error code that returned from x86_pmu.hw_config() (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0030-pmu.patch: perf/core, x86:
  Reduce number of CONFIG_X86_LOCAL_APIC macros (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0031-pmu.patch: perf/core, x86: Remove
  cpu_hw_events.interrupts (fate#311939, bnc#704917).
- patches.suse/intel-perf-0032-pmu.patch: perf/core, x86: Remove
  duplicate perf_event_mask variable (fate#311939, bnc#704917).
- patches.suse/intel-perf-0033-pmu.patch: x86, perf: Use
  apic_write unconditionally (fate#311939, bnc#704917).
- patches.suse/intel-perf-0034-pmu.patch: perf, x86: Add a key
  to simplify template lookup in Pentium-4 PMU (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0035-pmu.patch: perf, x86: Add cache
  events for the Pentium-4 PMU (fate#311939, bnc#704917).
- patches.suse/intel-perf-0036-pmu.patch: perf_events: Fix
  resource leak in x86 __hw_perf_event_init() (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0037-pmu.patch: x86, perf: Fix
  few cosmetic dabs for P4 pmu (comments and constantify)
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0038-pmu.patch: x86, perf: Add raw
  events support for the P4 PMU (fate#311939, bnc#704917).
- patches.suse/intel-perf-0039-pmu.patch: perf, x86: Clean up
  debugctlmsr bit definitions (fate#311939, bnc#704917).
- patches.suse/intel-perf-0040-pmu.patch: perf, x86: Add Nehelem
  PMU programming errata workaround (fate#311939, bnc#704917).
- patches.suse/intel-perf-0041-pmu.patch: perf: Use hot regs with
  software sched switch/migrate events (fate#311939, bnc#704917).
- patches.suse/intel-perf-0042-pmu.patch: perf, x86: Undo some
  some *_counter* -> *_event* renames (fate#311939, bnc#704917).
- patches.suse/intel-perf-0043-pmu.patch: perf, x86: implement
  ARCH_PERFMON_EVENTSEL bit masks (fate#311939, bnc#704917).
- patches.suse/intel-perf-0044-pmu.patch: perf, x86: Fix up the
  ANY flag stuff (fate#311939, bnc#704917).
- patches.suse/intel-perf-0045-pmu.patch: perf, x86: Fix
  __initconst vs const (fate#311939, bnc#704917).
- patches.suse/intel-perf-0046-pmu.patch: perf, x86: Add Nehalem
  programming quirk to Westmere (fate#311939, bnc#704917).
- patches.suse/intel-perf-0047-pmu.patch: perf: Drop the frame
  reliablity check (fate#311939, bnc#704917).
- patches.suse/intel-perf-0048-pmu.patch: perf: Enhance perf to
  allow for guest statistic collection from host (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0049-pmu.patch: perf & kvm: Clean up
  some of the guest profiling callback API details (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0050-pmu.patch: perf, x86: Move perfctr
  init code to x86_setup_perfctr() (fate#311939, bnc#704917).
- patches.suse/intel-perf-0051-pmu.patch: perf, x86: Move
  x86_setup_perfctr() (fate#311939, bnc#704917).
- patches.suse/intel-perf-0052-pmu.patch: perf, x86: Call
  x86_setup_perfctr() from .hw_config() (fate#311939, bnc#704917).
- patches.suse/intel-perf-0053-pmu.patch: perf, x86: Pass enable
  bit mask to __x86_pmu_enable_event() (fate#311939, bnc#704917).
- patches.suse/intel-perf-0054-pmu.patch: perf, x86: Use weight
  instead of cmask in for_each_event_constraint() (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0055-pmu.patch: perf, x86: Remove PEBS
  SAMPLE_RAW support (fate#311939, bnc#704917).
- patches.suse/intel-perf-0056-pmu.patch: perf, x86: Consolidate
  some code repetition (fate#311939, bnc#704917).
- patches.suse/intel-perf-0057-pmu.patch: perf, x86: Improve
  the PEBS ABI (fate#311939, bnc#704917).
- patches.suse/intel-perf-0058-pmu.patch: perf, x86: implement
  group scheduling transactional APIs (fate#311939, bnc#704917).
- patches.suse/intel-perf-0059-pmu.patch: x86, perf: P4 PMU --
  configure predefined events (fate#311939, bnc#704917).
- patches.suse/intel-perf-0060-pmu.patch: x86, perf: P4 PMU --
  protect sensible procedures from preemption (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0061-pmu.patch: x86, perf: P4 PMU --
  Get rid of redundant check for array index (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0062-pmu.patch: x86, perf: P4 PMU --
  check for proper event index in RAW events (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0063-pmu.patch: x86, perf: P4 PMU --
  use hash for p4_get_escr_idx() (fate#311939, bnc#704917).
- patches.suse/intel-perf-0064-pmu.patch: x86, perf: P4 PMU -
  fix counters management logic (fate#311939, bnc#704917).
- patches.suse/intel-perf-0065-pmu.patch: perf, x86: P4 PMU --
  handle unflagged events (fate#311939, bnc#704917).
- patches.suse/intel-perf-0066-pmu.patch: perf, x86: P4 PMU --
  fix typo in unflagged NMI handling (fate#311939, bnc#704917).
- patches.suse/intel-perf-0067-pmu.patch: perf, x86: P4 PMU --
  do a real check for ESCR address being in hash (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0068-pmu.patch: perf, x86:
  P4_pmu_schedule_events -- use smp_processor_id instead of raw_
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0069-pmu.patch: perf, trace: Fix !x86
  build bug (fate#311939, bnc#704917).
- patches.suse/intel-perf-0070-pmu.patch: perf_events: Fix event
  scheduling issues introduced by transactional API (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0071-pmu.patch: perf, x86: Make a
  second write to performance counter if needed (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0072-pmu.patch: perf_events: Fix Intel
  Westmere event constraints (fate#311939, bnc#704917).
- patches.suse/intel-perf-0073-pmu.patch: perf, x86: Fix incorrect
  branches event on AMD CPUs (fate#311939, bnc#704917).
- patches.suse/intel-perf-0074-pmu.patch: perf, x86: P4 PMU --
  redesign cache events (fate#311939, bnc#704917).
- patches.suse/intel-perf-0075-pmu.patch: perf, x86: P4 PMU
  - - update nmi irq statistics and unmask lvt entry properly
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0076-pmu.patch: perf, x86: Fix Intel-nhm
  PMU programming errata workaround (fate#311939, bnc#704917).
- patches.suse/intel-perf-0077-pmu.patch: perf: Drop unappropriate
  tests on arch callchains (fate#311939, bnc#704917).
- patches.suse/intel-perf-0078-pmu.patch: perf, x86, Pentium4:
  Clear the P4_CCCR_FORCE_OVF flag (fate#311939, bnc#704917).
- patches.suse/intel-perf-0079-pmu.patch: perf, x86, Pentium4:
  Add RAW events verification (fate#311939, bnc#704917).
- patches.suse/intel-perf-0080-pmu.patch: perf, x86: Fix
  accidentally ack'ing a second event on intel perf counter
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0081-pmu.patch: perf, x86: Fix
  handle_irq return values (fate#311939, bnc#704917).
- patches.suse/intel-perf-0082-pmu.patch: perf, x86: Try to handle
  unknown nmis with an enabled PMU (fate#311939, bnc#704917).
- patches.suse/intel-perf-0083-pmu.patch: perf_events: Fix
  BTS interrupt handling to avoid being dazed by NMI (v2)
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0084-pmu.patch: perf, x86: Catch
  spurious interrupts after disabling counters (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0085-pmu.patch: perf, x86: Handle in
  flight NMIs on P4 platform (fate#311939, bnc#704917).
- patches.suse/intel-perf-0086-pmu.patch: perf, gcc-4.6: Fix
  set but unused variable (fate#311939, bnc#704917).
- patches.suse/intel-perf-0087-pmu.patch: perf_events: Fix bogus
  AMD64 generic TLB events (fate#311939, bnc#704917).
- patches.suse/intel-perf-0088-pmu.patch: perf, x86: Extract
  PEBS/BTS buffer free routines (fate#311939, bnc#704917).
- patches.suse/intel-perf-0089-pmu.patch: perf, x86: Extract
  PEBS/BTS allocation functions (fate#311939, bnc#704917).
- patches.suse/intel-perf-0090-pmu.patch: perf, x86: Extract DS
  alloc/free functions (fate#311939, bnc#704917).
- patches.suse/intel-perf-0091-pmu.patch: perf, x86: Fixup the
  precise_ip computation (fate#311939, bnc#704917).
- patches.suse/intel-perf-0092-pmu.patch: perf, x86: Less
  disastrous PEBS/BTS buffer allocation failure (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0093-pmu.patch: perf, x86: Clean up
  reserve_ds_buffers() signature (fate#311939, bnc#704917).
- patches.suse/intel-perf-0094-pmu.patch: perf, x86: Use NUMA
  aware allocations for PEBS/BTS/DS allocations (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0095-pmu.patch: x86, perf, nmi: Disable
  perf if counters are not accessible (fate#311939, bnc#704917).
- patches.suse/intel-perf-0096-pmu.patch: perf: Introduce
  is_sampling_event() (fate#311939, bnc#704917).
- patches.suse/intel-perf-0097-pmu.patch: perf, x86: Detect
  broken BIOSes that corrupt the PMU (fate#311939, bnc#704917).
- patches.suse/intel-perf-0098-pmu.patch: perf, x86: Provide a
  PEBS capable cycle event (fate#311939, bnc#704917).
- patches.suse/intel-perf-0099-pmu.patch: perf, x86: P4 PMU -
  Fix unflagged overflows handling (fate#311939, bnc#704917).
- patches.suse/intel-perf-0100-pmu.patch: perf: Fix Pentium4
  raw event validation (fate#311939, bnc#704917).
- patches.suse/intel-perf-0101-pmu.patch: perf, x86: P4 PMU:
  Fix spurious NMI messages (fate#311939, bnc#704917).
- patches.suse/intel-perf-0102-pmu.patch: perf, x86: Use helper
  function in x86_pmu_enable_all() (fate#311939, bnc#704917).
- patches.suse/intel-perf-0103-pmu.patch: perf, x86: Calculate
  perfctr msr addresses in helper functions (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0104-pmu.patch: perf, x86: Add new
  AMD family 15h msrs to perfctr reservation code (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0105-pmu.patch: perf, x86: Store
  perfctr msr addresses in config_base/event_base (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0106-pmu.patch: perf, x86: Add support
  for AMD family 15h core counters (fate#311939, bnc#704917).
- patches.suse/intel-perf-0107-pmu.patch: perf, x86: Add Intel
  SandyBridge CPU support (fate#311939, bnc#704917).
- patches.suse/intel-perf-0108-plus-pmu.patch: perf, arch: Cleanup
  perf-pmu init vs lockup-detector (fate#311939, bnc#704917).
- patches.suse/intel-perf-0108-pmu.patch: perf_events: Update
  PEBS event constraints (fate#311939, bnc#704917).
- patches.suse/intel-perf-0109-pmu.patch: perf: Add support for
  supplementary event registers (fate#311939, bnc#704917).
- patches.suse/intel-perf-0110-pmu.patch: perf: Fix LLC-* events
  on Intel Nehalem/Westmere (fate#311939, bnc#704917).
- patches.suse/intel-perf-0111-pmu.patch: perf: Avoid the
  percore allocations if the CPU is not HT capable (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0112-pmu.patch: perf, x86: Clean up
  SandyBridge PEBS events (fate#311939, bnc#704917).
- patches.suse/intel-perf-0113-pmu.patch: perf, x86:
  Use INTEL_*_CONSTRAINT() for all PEBS event constraints
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0114-pmu.patch: perf, x86: Fix Intel
  fixed counters base initialization (fate#311939, bnc#704917).
- patches.suse/intel-perf-0115-pmu.patch: perf, x86: P4 PMU
  - Read proper MSR register to catch unflagged overflows
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0116-pmu.patch: perf, x86: Complain
  louder about BIOSen corrupting CPU/PMU state and continue
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0117-pmu.patch: perf, x86: P4 PMU -
  clean up the code a bit (fate#311939, bnc#704917).
- patches.suse/intel-perf-0118-pmu.patch: perf, x86: Fix
  pre-defined cache-misses event for AMD family 15h cpus
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0119-pmu.patch: perf, x86: Fix AMD
  family 15h FPU event constraints (fate#311939, bnc#704917).
- patches.suse/intel-perf-0120-pmu.patch: perf, x86:
  Use ALTERNATIVE() to check for X86_FEATURE_PERFCTR_CORE
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0121-pmu.patch: perf: Support Xeon
  E7's via the Westmere PMU driver (fate#311939, bnc#704917).
- patches.suse/intel-perf-0122-pmu.patch: x86, perf event:
  Turn off unstructured raw event access to offcore registers
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0123-pmu.patch: perf, x86: P4 PMU --
  Use perf_sample_data_init helper (fate#311939, bnc#704917).
- patches.suse/intel-perf-0124-pmu.patch: perf, x86: Update/fix
  Intel Nehalem cache events (fate#311939, bnc#704917).
- patches.suse/intel-perf-0125-pmu.patch: perf events, x86, P4:
  Fix typo in comment (fate#311939, bnc#704917).
- patches.suse/intel-perf-0126-pmu.patch: perf, x86: Fix BTS
  condition (fate#311939, bnc#704917).
- patches.suse/intel-perf-0127-pmu.patch: perf events, x86:
  Work around the Nehalem AAJ80 erratum (fate#311939, bnc#704917).
- patches.suse/intel-perf-0128-pmu.patch: perf events: Add
  stalled cycles generic event - PERF_COUNT_HW_STALLED_CYCLES
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0129-pmu.patch: perf events, x86:
  Mark constrant tables read mostly (fate#311939, bnc#704917).
- patches.suse/intel-perf-0130-pmu.patch: perf, x86, nmi: Move
  LVT un-masking into irq handlers (fate#311939, bnc#704917).
- patches.suse/intel-perf-0131-pmu.patch: perf event, x86:
  Use better stalled cycles metric (fate#311939, bnc#704917).
- patches.suse/intel-perf-0132-pmu.patch: perf events: Add
  generic front-end and back-end stalled cycle event definitions
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0133-pmu.patch: perf, x86: Add new
  stalled cycles events for Intel and AMD CPUs (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0134-pmu.patch: perf events, x86: Add
  Westmere stalled-cycles-frontend/backend events (fate#311939,
  bnc#704917).
- patches.suse/intel-perf-0135-pmu.patch: perf events, x86:
  Add SandyBridge stalled-cycles-frontend/backend events
  (fate#311939, bnc#704917).
- patches.suse/intel-perf-0136-pmu.patch: perf events, x86: Fix
  Intel Nehalem and Westmere last level cache event definitions
  (fate#311939, bnc#704917).
* Fri Jul 15 2011 brogers@suse.com
- patches.fixes/mm-avoid-null-pointer-deref-in-sync_mm_rss.patch:
  mm: avoid null-pointer deref in sync_mm_rss() (bnc#704163).
* Fri Jul 15 2011 trenn@suse.de
  Boxboro-EX: Memory/CPU hot add - Fate#311831:
- patches.arch/acpi_processor_delay_cpuidle_init_on_hotplug.patch:
  acpi processor hotplug: Delay most initialization to cpu online
  (fate#311831,bnc#703100).
- patches.arch/acpi_processor_fix_cpuidle_unregister.patch:
  acpi processor: Avoid WARN message on processor driver removal
  (fate#311831,bnc#703100).
- patches.arch/acpi_processor_split_add.patch: acpi processor:
  Split up acpi_processor_add() (fate#311831,bnc#703100).
- patches.arch/intel_idle_register_per_cpu.patch: intel_idle:
  Split up and provide per CPU initialization func
  (fate#311831,bnc#703100).
- patches.fixes/001-numa-hotadd.patch: memory-hotplug:
  create /sys/firmware/memmap entry for new memory
  (fate#311831,bnc#703100).
- patches.fixes/002-numa-hotadd.patch: slab: add memory hotplug
  support (fate#311831,bnc#703100).
- patches.fixes/003-numa-hotadd.patch: x86, mm: Separate
  x86_64 vmalloc_sync_all() into separate functions
  (fate#311831,bnc#703100).
- patches.fixes/004-numa-hotadd.patch: cpu/mem hotplug: enable
  CPUs online before local memory online (fate#311831,bnc#703100).
- patches.fixes/005a-numa-hotadd.patch: mm: do not iterate over
  NR_CPUS in __zone_pcp_update() (fate#311831,bnc#703100).
- patches.fixes/006-numa-hotadd.patch: mem-hotplug: avoid
  multiple zones sharing same boot strapping boot_pageset
  (fate#311831,bnc#703100).
- patches.fixes/007-numa-hotadd.patch: mem-hotplug: fix
  potential race while building zonelist for new populated zone
  (fate#311831,bnc#703100).
- patches.fixes/008-numa-hotadd.patch: x86-64, mem: Update
  all PGDs for direct mapping and vmemmap mapping changes
  (fate#311831,bnc#703100).
- patches.fixes/009-numa-hotadd.patch: x86, mtrr: Use stop machine
  context to rendezvous all the cpu's (fate#311831,bnc#703100).
- patches.fixes/010-numa-hotadd.patch: x86, mtrr:
  lock stop machine during MTRR rendezvous sequence
  (fate#311831,bnc#703100,bnc#672008).
- patches.fixes/011-numa-hotadd.patch: mem-hotplug: introduce
  {un}lock_memory_hotplug() (fate#311831,bnc#703100).
- patches.fixes/012-numa-hotadd.patch: memory hotplug: one more
  lock on memory hotplug (fate#311831,bnc#703100).
- patches.fixes/013-numa-hotadd.patch: mm, mem-hotplug:
  recalculate lowmem_reserve when memory hotplug occurs
  (fate#311831,bnc#703100).
- patches.fixes/014-numa-hotadd.patch: mm/memory_hotplug.c:
  fix building of node hotplug zonelist (fate#311831,bnc#703100).
- patches.fixes/015-numa-hotadd.patch:  mm, hotplug: fix error
  handling in mem_online_node() (fate#311831,bnc#703100).
- patches.fixes/016-numa-hotadd.patch: mm, hotplug: protect
  zonelist building with zonelists_mutex (fate#311831,bnc#703100).
- patches.fixes/017-numa-hotadd.patch: hugetlb: fix section
  mismatches (fate#311831,bnc#703100).
- patches.fixes/018-numa-hotadd.patch: x86, mm: fix uninitialized
  addr in kernel_physical_mapping_init() (fate#311831,bnc#703100).
- patches.xen/xen3-auto-common.diff: Refresh.
- patches.xen/xen3-patch-2.6.19: Refresh.
- patches.xen/xen3-patch-2.6.23: Refresh.
- patches.xen/xen3-patch-2.6.24: Refresh.
- patches.xen/xen3-patch-2.6.27: Refresh.
- patches.xen/xen3-patch-2.6.32: Refresh.
* Thu Jul 14 2011 rw@suse.de
- patches.arch/x86-efi-00-introduce-free_boot_mem_late,
  patches.arch/x86-efi-01-remove-virtual-mode-SetVirtualAddressMap,
  patches.arch/x86-efi-02-consolidate-NX-control,
  patches.arch/x86-efi-03-merge-contiguous-memory-regions,
  patches.arch/x86-efi-04-minimize-SetVirtualAddressMap,
  patches.arch/x86-efi-05-ensure-complete-mapping,
  patches.arch/x86-efi-06-retain-boot-service-code-longer,
  patches.arch/x86-efi-07-introduce-e820-check_early,
  patches.arch/x86-efi-08-reserve_early-only-unreserved-regions,
  patches.arch/x86-efi-09-ignore-EFI_RESERVED_TYPE:
  Backport of a series of patches for 3.0, which significantly improve
  support for recent UEFI systems.   (bnc#568848, bnc#655434, bnc#681242)
* Thu Jul 14 2011 mhocko@suse.cz
- patches.fixes/arch-mm-filter-disallowed-nodes-from-arch-specific-s.patch:
  arch, mm: filter disallowed nodes from arch specific show_mem
  functions (bnc#705433).
- patches.fixes/lib-arch-add-filter-argument-to-show_mem-and-fix-pri.patch:
  lib, arch: add filter argument to show_mem and fix private
  implementations (bnc#705433).
- patches.fixes/oom-suppress-nodes-that-are-not-allowed-from-meminfo-on-page-alloc.patch:
  oom: suppress nodes that are not allowed from meminfo on page
  alloc failure (bnc#705433).
- patches.fixes/oom-suppress-nodes-that-are-not-allowed-from-meminfo.patch:
  oom: suppress nodes that are not allowed from meminfo on oom
  kill (bnc#705433).
- patches.fixes/oom-suppress-show_mem-for-many-nodes-in-irq-context-.patch:
  oom: suppress show_mem() for many nodes in irq context on page
  alloc failure (bnc#705433).
- patches.suse/SoN-08-mm-page_alloc-emerg.patch: Refresh.
* Thu Jul 14 2011 ohering@suse.de
- patches.suse/staging-hv-fixup-reference-counting-for-net-and-stor.patch:
  Fixup reference counting for both net and stor devices.
- patches.suse/staging-hv-vmbus-init-on-dmi-match.patch:
  only load the driver in a hyper-v guest (bnc#704957).
- patches.suse/staging-hv-vmbus-modalias-namespace.patch:
- patches.suse/staging-hv-vmbus-modalias-show.patch: hv:
  show the modalias files in /sys/bus/vmbus/devices/*/ (fate#311487).
* Thu Jul 14 2011 jkosina@suse.cz
- patches.drivers/intel-add-partner-point-pch-support.patch:
  Core Driver Enabling for Intel Panther Point PCH (bnc#682755
  fate#311837).
* Thu Jul 14 2011 mszeredi@suse.cz
- patches.fixes/fs-d_validate-fixes.patch: fs: d_validate fixes
  (bnc#701170).
* Thu Jul 14 2011 jack@suse.cz
- Disable:
    patches.fixes/writeback-fix-sb-locking.diff
    patches.fixes/writeback-check-background-flush-after-work.diff
    patches.fixes/writeback-stop-background-for-other-work.diff
    patches.fixes/writeback-avoid-new-file-livelock.diff
    patches.fixes/writeback-avoid-WB_SYNC_ALL-livelock.diff
  as they cause sync(1) to have larger overhead (bnc#703786)
* Thu Jul 14 2011 mgorman@suse.de
- patches.suse/mm-thp-fix-dev-zero.patch:
  mm: thp: fix /dev/zero MAP_PRIVATE and vm_flags cleanups (bnc#701163,
  CVE-2011-2479).
* Wed Jul 13 2011 brogers@suse.com
- patches.suse/0001-9p-connect-fixes.patch: 9p connect fixes
  (FATE#311639).
- patches.suse/0002-Kill-9p-readlink.patch: Kill 9p readlink()
  (FATE#311639).
- patches.suse/0003-net-9p-fix-virtio-transport-to-correctly-update-stat.patch:
  net/9p: fix virtio transport to correctly update status on
  connect (FATE#311639).
- patches.suse/0004-net-9p-fail-when-user-specifies-a-transport-which-we.patch:
  net/9p: fail when user specifies a transport which we can't find
  (FATE#311639).
- patches.suse/0005-net-9p-fix-statsize-inside-twstat.patch:
  net/9p: fix statsize inside twstat (FATE#311639).
- patches.suse/0006-9p-Include-fsync-support-for-9p-client.patch:
  9p: Include fsync support for 9p client (FATE#311639).
- patches.suse/0007-9p-fix-option-parsing.patch: 9p: fix option
  parsing (FATE#311639).
- patches.suse/0008-9p-Fix-the-kernel-crash-on-a-failed-mount.patch:
  9p: Fix the kernel crash on a failed mount (FATE#311639).
- patches.suse/0009-9p-fix-memory-leak-in-v9fs_parse_options.patch:
  9p: fix memory leak in v9fs_parse_options() (FATE#311639).
- patches.suse/0010-9p-fix-p9_client_destroy-unconditional-calling-v9fs_.patch:
  9p: fix p9_client_destroy unconditional calling v9fs_put_trans
  (FATE#311639).
- patches.suse/0011-net-9p-Add-multi-channel-support.patch:
  net/9p: Add multi channel support (FATE#311639).
- patches.suse/0012-net-9p-Remove-MAX_9P_CHAN-limit.patch:
  net/9p: Remove MAX_9P_CHAN limit (FATE#311639).
- patches.suse/0013-net-9p-Handle-mount-errors-correctly.patch:
  net/9p: Handle mount errors correctly (FATE#311639).
- patches.suse/0014-9P2010.L-handshake-Add-VFS-flags.patch:
  9P2010.L handshake: Add VFS flags (FATE#311639).
- patches.suse/0015-9P2010.L-handshake-Add-mount-option.patch:
  9P2010.L handshake: Add mount option (FATE#311639).
- patches.suse/0016-9P2010.L-handshake-Remove-dotu-variable.patch:
  9P2010.L handshake: Remove "dotu" variable (FATE#311639).
- patches.suse/0017-9P2010.L-handshake-.L-protocol-negotiation.patch:
  9P2010.L handshake: .L protocol negotiation (FATE#311639).
- patches.suse/0018-fs-9p-Add-hardlink-support-to-.u-extension.patch:
  fs/9p: Add hardlink support to .u extension (FATE#311639).
- patches.suse/0019-net-9p-Use-the-tag-name-in-the-config-space-for-iden.patch:
  net/9p: Use the tag name in the config space for identifying
  mount point (FATE#311639).
- patches.suse/0020-net-9p-Add-sysfs-mount_tag-file-for-virtio-9P-device.patch:
  net/9p: Add sysfs mount_tag file for virtio 9P device
  (FATE#311639).
- patches.suse/0021-fs-9p-re-init-the-wstat-in-readdir-loop.patch:
  fs/9p: re-init the wstat in readdir loop (FATE#311639).
- patches.suse/0022-9p-Change-the-name-of-new-protocol-from-9p2010.L-to-.patch:
  9p: Change the name of new protocol from 9p2010.L to 9p2000.L
  (FATE#311639).
- patches.suse/0023-9p-Fixes-a-simple-bug-enabling-writes-beyond-2GB.patch:
  9p: Fixes a simple bug enabling writes beyond 2GB (FATE#311639).
- patches.suse/0024-9p-Fix-setting-of-protocol-flags-in-v9fs_session_inf.patch:
  9p: Fix setting of protocol flags in v9fs_session_info structure
  (FATE#311639).
- patches.suse/0025-9p-documentation-update.patch: 9p:
  documentation update (FATE#311639).
- patches.suse/0026-fs-9p-Clunk-the-fid-resulting-from-partial-walk-of-t.patch:
  fs/9p: Clunk the fid resulting from partial walk of the name
  (FATE#311639).
- patches.suse/0027-9p-drop-nlink-remove.patch: 9p: drop nlink
  remove (FATE#311639).
- patches.suse/0028-9p-Make-sure-we-are-able-to-clunk-the-cached-fid-on-.patch:
  9p: Make sure we are able to clunk the cached fid on umount
  (FATE#311639).
- patches.suse/0029-9p-Creating-files-with-names-too-long-should-fail-wi.patch:
  9p: Creating files with names too long should fail with
  ENAMETOOLONG (FATE#311639).
- patches.suse/0030-9p-return-on-mutex_lock_interruptible.patch:
  9p: return on mutex_lock_interruptible() (FATE#311639).
- patches.suse/0031-9p-saving-negative-to-unsigned-char.patch:
  9p: saving negative to unsigned char (FATE#311639).
- patches.suse/0032-9p-add-bdi-backing-to-mount-session.patch:
  9p: add bdi backing to mount session (FATE#311639).
- patches.suse/0033-Backport-fix-for-bdi-patch-to-make-it-work-with-SLES.patch:
  Backport fix for bdi patch to make it work with SLES kernel
  (FATE#311639).
- patches.suse/0034-9p-VFS-switches-for-9p2000.L-protocol-and-client-cha.patch:
  9p: VFS switches for 9p2000.L: protocol and client changes
  (FATE#311639).
- patches.suse/0035-9p-VFS-switches-for-9p2000.L-VFS-switches.patch:
  9p: VFS switches for 9p2000.L: VFS switches (FATE#311639).
- patches.suse/0036-9p-add-9P2000.L-statfs-operation.patch:
  9p: add 9P2000.L statfs operation (FATE#311639).
- patches.suse/0037-9p-add-9P2000.L-rename-operation.patch:
  9p: add 9P2000.L rename operation (FATE#311639).
- patches.suse/0038-fs-9p-Make-sure-we-properly-instantiate-dentry.patch:
  fs/9p: Make sure we properly instantiate dentry (FATE#311639).
- patches.suse/0039-9p-Add-mksock-support.patch:     9p: Add
  mksock support (FATE#311639).
- patches.suse/0040-9p-cleanup-remove-unneeded-assignment.patch:
  9p: cleanup: remove unneeded assignment (FATE#311639).
- patches.suse/0041-9p-Optimize-TCREATE-by-eliminating-a-redundant-fid-c.patch:
  9p: Optimize TCREATE by eliminating a redundant fid clone
  (FATE#311639).
- patches.suse/0042-9p-Pass-the-correct-end-of-buffer-to-p9stat_read.patch:
  9p: Pass the correct end of buffer to p9stat_read (FATE#311639).
- patches.suse/0043-virtio_9p.h-needs-linux-types.h.patch:
  virtio_9p.h needs <linux/types.h> (FATE#311639).
- patches.suse/0044-9p-Make-use-of-iounit-for-read-write.patch:
  9p: Make use of iounit for read/write (FATE#311639).
- patches.suse/0045-9p-readdir-implementation-for-9p2000.L.patch:
  9p: readdir implementation for 9p2000.L (FATE#311639).
- patches.suse/0046-net-9p-Handle-the-server-returned-error-properly.patch:
  net/9p: Handle the server returned error properly (FATE#311639).
- patches.suse/0047-fs-9p-Pass-the-correct-user-credentials-during-attac.patch:
  fs/9p: Pass the correct user credentials during attach
  (FATE#311639).
- patches.suse/0048-9p-getattr-client-implementation-for-9P2000.L-protoc.patch:
  9p: getattr client implementation for 9P2000.L protocol
  (FATE#311639).
- patches.suse/0049-9p-Implement-client-side-of-setattr-for-9P2000.L-pro.patch:
  9p: Implement client side of setattr for 9P2000.L protocol
  (FATE#311639).
- patches.suse/0050-9p-Define-and-implement-TLINK-for-9P2000.L.patch:
  9p: Define and implement TLINK for 9P2000.L (FATE#311639).
- patches.suse/0051-9p-Define-and-implement-TLINK-for-9P2000.L.patch:
  9p: Define and implement TLINK for 9P2000.L (FATE#311639).
- patches.suse/0052-9p-Define-and-implement-TSYMLINK-for-9P2000.L.patch:
  9p: Define and implement TSYMLINK for 9P2000.L (FATE#311639).
- patches.suse/0053-9p-Implement-TMKNOD.patch:     9p: Implement
  TMKNOD (FATE#311639).
- patches.suse/0054-9p-Implement-TMKDIR.patch:     9p: Implement
  TMKDIR (FATE#311639).
- patches.suse/0055-fs-9p-This-patch-implements-TLCREATE-for-9p2000.L-pr.patch:
  fs/9p: This patch implements TLCREATE for 9p2000.L protocol
  (FATE#311639).
- patches.suse/0056-9p-Implement-LOPEN.patch:     9p: Implement
  LOPEN (FATE#311639).
- patches.suse/0057-fs-9p-Prevent-parallel-rename-when-doing-fid_lookup.patch:
  fs/9p: Prevent parallel rename when doing fid_lookup
  (FATE#311639).
- patches.suse/0058-fs-9p-destroy-fid-on-failed-remove.patch:
  fs/9p: destroy fid on failed remove (FATE#311639).
- patches.suse/0059-fs-9p-remove-sparse-warning-in-vfs_inode.patch:
  fs/9p: remove sparse warning in vfs_inode (FATE#311639).
- patches.suse/0060-virtio_9p.h-include-linux-types.h.patch:
  virtio_9p.h: include linux/types.h (FATE#311639).
- patches.suse/0061-9p-potential-ERR_PTR-dereference.patch:
  9p: potential ERR_PTR() dereference (FATE#311639).
- patches.suse/0062-net-9p-trans_fd.c-Fix-unsigned-return-type.patch:
  net/9p/trans_fd.c: Fix unsigned return type (FATE#311639).
- patches.suse/0063-fs-9p-net-9p-memory-leak-fixes.patch:
  fs/9p, net/9p: memory leak fixes (FATE#311639).
- patches.suse/0064-fs-9p-Fix-error-handling-in-v9fs_get_sb.patch:
  fs/9p: Fix error handling in v9fs_get_sb (FATE#311639).
- patches.suse/0065-9p-Check-for-NULL-fid-in-v9fs_dir_release.patch:
  9p: Check for NULL fid in v9fs_dir_release() (FATE#311639).
- patches.suse/0066-fs-9p-Use-the-correct-dentry-operations.patch:
  fs/9p: Use the correct dentry operations (FATE#311639).
- patches.suse/0067-fs-9p-Don-t-use-dotl-version-of-mknod-for-dotu-inode.patch:
  fs/9p: Don't use dotl version of mknod for dotu inode operations
  (FATE#311639).
- patches.suse/0068-net-9p-fix-memory-handling-allocation-in-rdma_reques.patch:
  net/9p: fix memory handling/allocation in rdma_request()
  (FATE#311639).
- patches.suse/0069-net-9p-Mount-only-matching-virtio-channels.patch:
  net/9p: Mount only matching virtio channels (FATE#311639).
- patches.suse/0070-9p-client-code-cleanup.patch:     9p: client
  code cleanup (FATE#311639).
- patches.suse/0071-9p-remove-unneeded-checks.patch:     9p:
  remove unneeded checks (FATE#311639).
- patches.suse/0072-fs-9p-setrlimit-fix-for-9p-write.patch:
  fs/9p: setrlimit fix for 9p write (FATE#311639).
- patches.suse/0073-9p-Pass-the-correct-end-of-buffer-to-p9dirent_read.patch:
  9p: Pass the correct end of buffer to p9dirent_read
  (FATE#311639).
- patches.suse/0074-fs-9p-mkdir-fix-for-setting-S_ISGID-bit-as-per-paren.patch:
  fs/9p: mkdir fix for setting S_ISGID bit as per parent directory
  (FATE#311639).
- patches.suse/0075-net-9p-This-patch-implements-TLERROR-RLERROR-on-the-.patch:
  net/9p: This patch implements TLERROR/RLERROR on the 9P client
  (FATE#311639).
- patches.suse/0076-9p-Add-a-Direct-IO-support-for-non-cached-operations.patch:
  9p: Add a Direct IO support for non-cached operations
  (FATE#311639).
- patches.suse/0077-fs-9p-Remove-the-redundant-rsize-calculation-in-v9fs.patch:
  fs/9p: Remove the redundant rsize calculation in
  v9fs_file_write() (FATE#311639).
- patches.suse/0078-net-9p-Add-a-Warning-to-catch-NULL-fids-passed-to-p9.patch:
  net/9p: Add a Warning to catch NULL fids passed to
  p9_client_clunk() (FATE#311639).
- patches.suse/0079-fs-9p-Add-file_operations-for-cached-mode-in-dotl-pr.patch:
  [fs/9p] Add file_operations for cached mode in dotl protocol
  (FATE#311639).
- patches.suse/0080-9p-Introduce-client-side-TFSYNC-RFSYNC-for-dotl.patch:
  [9p] Introduce client side TFSYNC/RFSYNC for dotl (FATE#311639).
- patches.suse/0081-Backport-fix-change-fsync-signature-to-make-it-compa.patch:
  Backport fix: change fsync signature to make it compatible
  with SLES kernel (FATE#311639).
- patches.suse/0082-9p-Implement-TLOCK.patch:     9p: Implement
  TLOCK (FATE#311639).
- patches.suse/0083-9p-Implement-TGETLOCK.patch:     9p: Implement
  TGETLOCK (FATE#311639).
- patches.suse/0084-9p-Use-V9FS_MAGIC-in-statfs.patch:     9p:
  Use V9FS_MAGIC in statfs (FATE#311639).
- patches.suse/0085-9p-Implement-TREADLINK-operation-for-9p2000.L.patch:
  9p: Implement TREADLINK operation for 9p2000.L (FATE#311639).
- patches.suse/0086-net-9p-Serialize-virtqueue-operations-to-make-VirtIO.patch:
  [net/9p]Serialize virtqueue operations to make VirtIO transport
  SMP safe (FATE#311639).
- patches.suse/0087-net-9p-Add-waitq-to-VirtIO-transport.patch:
  net/9p: Add waitq to VirtIO transport (FATE#311639).
- patches.suse/0088-fs-9p-Use-mknod-9p-operation-on-create-without-open-.patch:
  fs/9p: Use mknod 9p operation on create without open request
  (FATE#311639).
- patches.suse/0089-fs-9p-Add-missing-iput-in-v9fs_vfs_lookup.patch:
  fs/9p: Add missing iput in v9fs_vfs_lookup (FATE#311639).
- patches.suse/0090-fs-9p-Use-generic_file_open-with-lookup_instantiate_.patch:
  fs/9p: Use generic_file_open with lookup_instantiate_filp
  (FATE#311639).
- patches.suse/0091-net-9p-Return-error-if-we-fail-to-encode-protocol-da.patch:
  net/9p: Return error if we fail to encode protocol data
  (FATE#311639).
- patches.suse/0092-9p-Add-datasync-to-client-side-TFSYNC-RFSYNC-for-dot.patch:
  9p: Add datasync to client side TFSYNC/RFSYNC for dotl
  (FATE#311639).
- patches.suse/0093-net-9p-Return-error-on-read-with-NULL-buffer.patch:
  net/9p: Return error on read with NULL buffer (FATE#311639).
- patches.suse/0094-net-9p-protocol.c-Remove-duplicated-macros.patch:
  net/9p/protocol.c: Remove duplicated macros (FATE#311639).
- patches.suse/0095-fs-9p-fix-menu-presentation.patch:     fs/9p:
  fix menu presentation (FATE#311639).
- patches.suse/0096-fs-9p-Move-dotl-inode-operations-into-a-seperate-fil.patch:
  fs/9p: Move dotl inode operations into a seperate file
  (FATE#311639).
- patches.suse/0097-fs-9p-Simplify-the-.L-create-operation.patch:
  fs/9p: Simplify the .L create operation (FATE#311639).
- patches.suse/0098-net-9p-Use-proper-data-types.patch:
  net/9p: Use proper data types (FATE#311639).
- patches.suse/0099-fs-9p-TREADLINK-bugfix.patch:     fs/9p:
  TREADLINK bugfix (FATE#311639).
- patches.suse/0100-fs-9p-fix-spelling-typo.patch:     fs/9p:
  fix spelling typo (FATE#311639).
- patches.suse/0101-fs-9p-Don-t-set-dentry-d_op-in-create-routines.patch:
  fs/9p: Don't set dentry->d_op in create routines (FATE#311639).
- patches.suse/0102-Backport-fix-set-root-d_op-and-add-dummy-revalidate-.patch:
  Backport fix: set root->d_op and add dummy revalidate func
  (FATE#311639).
- patches.suse/0103-net-9p-Preparation-and-helper-functions-for-zero-cop.patch:
  [net/9p] Preparation and helper functions for zero copy
  (FATE#311639).
- patches.suse/0104-net-9p-Assign-type-of-transaction-to-tc-pdu-id-which.patch:
  [net/9p] Assign type of transaction to tc->pdu->id which is
  otherwise unsed (FATE#311639).
- patches.suse/0105-net-9p-Add-gup-zero_copy-support-to-VirtIO-transport.patch:
  [net/9p] Add gup/zero_copy support to VirtIO transport layer
  (FATE#311639).
- patches.suse/0106-net-9p-Add-preferences-to-transport-layer.patch:
  [net/9p] Add preferences to transport layer (FATE#311639).
- patches.suse/0107-net-9p-Read-side-zerocopy-changes-for-9P2000.L-proto.patch:
  [net/9p] Read side zerocopy changes for 9P2000.L protocol
  (FATE#311639).
- patches.suse/0108-net-9p-Write-side-zerocopy-changes-for-9P2000.L-prot.patch:
  [net/9p] Write side zerocopy changes for 9P2000.L protocol
  (FATE#311639).
- patches.suse/0109-net-9p-readdir-zerocopy-changes-for-9P2000.L-protoco.patch:
  [net/9p] readdir zerocopy changes for 9P2000.L protocol
  (FATE#311639).
- patches.suse/0110-net-9p-Handle-Zero-Copy-TREAD-RERROR-case-in-dotl-ca.patch:
  [net/9p] Handle Zero Copy TREAD/RERROR case in !dotl case
  (FATE#311639).
- patches.suse/0111-net-9p-Small-non-IO-PDUs-for-zero-copy-supporting-tr.patch:
  [net/9p] Small non-IO PDUs for zero-copy supporting transports
  (FATE#311639).
* Wed Jul 13 2011 trenn@suse.de
- patches.fixes/proc_irq_ease_smp_affinity_setting.patch: bitmap,
  irq: add smp_affinity_list interface to /proc/irq (bnc#700448).
* Wed Jul 13 2011 jslaby@suse.de
- Update to 2.6.32.43
- patches.fixes/PM-Hibernate-Avoid-hitting-OOM-during-preallocation-of-memory.patch:
  Delete.
- patches.fixes/PM-Hibernate-Fix-free_unnecessary_pages.patch:
  Delete.
- patches.fixes/ksm-fix-null-pointer-dereference-in-scan_get_next_rmap_item.patch:
  Delete.
- patches.fixes/tty-ldisc-do-not-close-until-there-are-readers.patch:
  Delete.
- patches.kabi/kabi-fix-struct-clocksource-breakage.patch: kabi:
  fix struct clocksource breakage.
- patches.kabi/revert-mm-prevent-concurrent-unmap_mapping_range-on-.patch:
  Revert "mm: prevent concurrent unmap_mapping_range() on the
  same inode".
- patches.fixes/mm-prevent-concurrent-unmap_mapping_range-on-.patch:
  mm: prevent concurrent unmap_mapping_range() on the same inode.
- patches.rpmify/fix-WARN_RATELIMIT-for-non-CONFIG_BUG.patch:
  fix WARN_RATELIMIT for non CONFIG_BUG.
* Wed Jul 13 2011 tonyj@suse.de
- patches.fixes/audit-filter-rules-cred-perf.patch: Update SP1 patch
  with upstream commit info.  No code changes.
* Wed Jul 13 2011 tonyj@suse.de
- patches.fixes/audit-filter-rules-cred-perf.patch: Update SP1 patch
  with upstream commit info.
* Wed Jul 13 2011 hare@suse.de
- patches.drivers/pmcraid-add-support-for-set-timestamp-comman.patch:
  pmcraid: add support for set timestamp command and other fixes
  (FATE#311474,bnc#690611).
- patches.drivers/pmcraid-disable-msix-and-expand-device-confi.patch:
  pmcraid: disable msix and expand device config entry
  (FATE#311474,bnc#690611).
* Wed Jul 13 2011 hare@suse.de
- patches.xen/xen3-auto-common.diff: Re-add removed Makefile
  hunk.
* Wed Jul 13 2011 eich@suse.de
- patches.fixes/vgaarb-enable-legacy-resources-only-if-device-decodes.patch:
  VGA arb: Only enable legacy resources if device really
  decodes them.
* Wed Jul 13 2011 nfbrown@suse.de
- patches.fixes/md-bitmap-flush-when-readonly: Flush the md
  bitmap when switching to read-only (bnc#701977).
* Tue Jul 12 2011 hare@suse.de
- patches.suse/add-target-mode-infrastructure.patch:
  Fixup build failure on utsrelease.
* Tue Jul 12 2011 hare@suse.de
- Update config files.
- patches.suse/add-target-mode-infrastructure.patch:
  drivers/target: Add target-mode infrastructure
  (FATE#311801,bnc#687068).
- patches.suse/target-Backport-for-SLES11-SP2.patch: target:
  Backport for SLES11 SP2 (FATE#311801,bnc#687068).
- patches.xen/xen3-auto-common.diff: Refresh.
- supported.conf: Mark target core modules as supported.
* Tue Jul 12 2011 mhocko@suse.cz
- patches.fixes/memcg-bugfix-check-mem_cgroup_disabled-at-split-fixu.patch:
  memcg: bugfix check mem_cgroup_disabled() at split fixup
  (bnc#704592).
- patches.fixes/memcg-change-page_cgroup_zoneinfo-signature.patch:
  memcg: change page_cgroup_zoneinfo signature (bnc#704592).
- patches.fixes/memcg-charged-pages-always-have-valid-per-memcg-zone.patch:
  memcg: charged pages always have valid per-memcg zone info
  (bnc#704592).
- patches.fixes/memcg-condense-page_cgroup-to-page-lookup-points.patch:
  memcg: condense page_cgroup-to-page lookup points (bnc#704592).
- patches.fixes/memcg-count-the-soft_limit-reclaim-in-global-backgro.patch:
  memcg: count the soft_limit reclaim in global background reclaim
  (bnc#704592).
- patches.fixes/memcg-css_id-must-be-called-under-rcu_read_lock.patch:
  memcg: css_id() must be called under rcu_read_lock()
  (bnc#704592).
- patches.fixes/memcg-fix-css_id-RCU-locking-for-real.patch:
  memcg: fix css_id() RCU locking for real (bnc#704592).
- patches.fixes/memcg-fix-css_is_ancestor-RCU-locking.patch:
  memcg: fix css_is_ancestor() RCU locking (bnc#704592).
- patches.fixes/memcg-fix-false-positive-VM_BUG-on-non-SMP.patch:
  memcg: fix false positive VM_BUG on non-SMP (bnc#704592).
- patches.fixes/memcg-fix-memory-migration-of-shmem-swapcache.patch:
  memcg: fix memory migration of shmem swapcache (bnc#704592).
- patches.fixes/memcg-fix-mis-accounting-of-file-mapped-racy-with-mi.patch:
  memcg: fix mis-accounting of file mapped racy with migration
  (bnc#704592).
- patches.fixes/memcg-fix-off-by-one-when-calculating-swap-cgroup-ma.patch:
  memcg: fix off-by-one when calculating swap cgroup map length
  (bnc#704592).
- patches.fixes/memcg-fix-race-in-file_mapped-accounting.patch:
  memcg: fix race in file_mapped accounting (bnc#704592).
- patches.fixes/memcg-fix-race-in-file_mapped-accouting-flag-managem.patch:
  memcg: fix race in file_mapped accouting flag management
  (bnc#704592).
- patches.fixes/memcg-fix-wake-up-in-oom-wait-queue.patch: memcg:
  fix wake up in oom wait queue (bnc#704592).
- patches.fixes/memcg-give-current-access-to-memory-reserves-if-it-s.patch:
  memcg: give current access to memory reserves if it's trying
  to die (bnc#704592).
- patches.fixes/memcg-kill-unnecessary-initialization-in-mem_cgroup_.patch:
  memcg: kill unnecessary initialization in
  mem_cgroup_shrink_node_zone() (bnc#704592).
- patches.fixes/memcg-make-oom-killer-a-no-op-when-no-killable-task-.patch:
  memcg: make oom killer a no-op when no killable task can be
  found (bnc#704592).
- patches.fixes/memcg-mark-init_section_page_cgroup-properly.patch:
  memcg: mark init_section_page_cgroup() properly (bnc#704592).
- patches.fixes/memcg-more-mem_cgroup_uncharge-batching.patch:
  memcg: more mem_cgroup_uncharge() batching (bnc#704592).
- patches.fixes/memcg-move-memcg-reclaimable-page-into-tail-of-inact.patch:
  memcg: move memcg reclaimable page into tail of inactive list
  (bnc#704592).
- patches.fixes/memcg-move-page-freeing-code-out-of-lock.patch:
  memcg: move page-freeing code out of lock (bnc#704592).
- patches.fixes/memcg-never-OOM-when-charging-huge-pages.patch:
  memcg: never OOM when charging huge pages (bnc#704592).
- patches.fixes/memcg-no-uncharged-pages-reach-page_cgroup_zoneinfo.patch:
  memcg: no uncharged pages reach page_cgroup_zoneinfo
  (bnc#704592).
- patches.fixes/memcg-prevent-endless-loop-when-charging-huge-pages-.patch:
  memcg: prevent endless loop when charging huge pages to
  near-limit group (bnc#704592).
- patches.fixes/memcg-remove-NULL-check-from-lookup_page_cgroup-resu.patch:
  memcg: remove NULL check from lookup_page_cgroup() result
  (bnc#704592).
- patches.fixes/memcg-remove-direct-page_cgroup-to-page-pointer.patch:
  memcg: remove direct page_cgroup-to-page pointer (bnc#704592).
- patches.fixes/memcg-remove-memcg-reclaim_param_lock.patch:
  memcg: remove memcg->reclaim_param_lock (bnc#704592).
- patches.fixes/memcg-remove-unused-page-flag-bitfield-defines.patch:
  memcg: remove unused page flag bitfield defines (bnc#704592).
- patches.fixes/memcg-rework-usage-of-stats-by-soft-limit.patch:
  memcg: rework usage of stats by soft limit (bnc#704592).
- patches.fixes/memcg-sc.nr_to_reclaim-should-be-initialized.patch:
  memcg: sc.nr_to_reclaim should be initialized (bnc#704592).
- patches.fixes/memcg-soft-limit-reclaim-should-end-at-limit-not-bel.patch:
  memcg: soft limit reclaim should end at limit not below
  (bnc#704592).
- patches.fixes/memcg-use-for_each_mem_cgroup.patch: memcg:
  use for_each_mem_cgroup (bnc#704592).
- patches.fixes/mm-thp-optimize-memcg-charge-in-khugepaged.patch:
  mm: thp: optimize memcg charge in khugepaged (bnc#704592).
- patches.suse/cgroups-blkio-subsystem-as-module.patch: Refresh.
* Tue Jul 12 2011 eich@suse.de
- patches.fixes/drm_i85x_watermark_fix.patch:
  IS_MOBILE() catches 85x, so we'd always try to use the 9xx FIFO sizing;
  since there's an explicit 85x version, this seems wrong.
  v2: Handle 830m correctly too.
- patches.fixes/drm_i85x_chip_id_fix.patch:
  pci.ids and the datasheet both say it's 358e, not 35e8.
  (bnc #677443).
* Mon Jul 11 2011 tonyj@suse.de
- patches.fixes/perf-eliminate-getimeofday.patch: perf record:
  remove unneeded gettimeofday() call (bnc#607339).
* Mon Jul 11 2011 mhocko@suse.cz
- patches.suse/memcg-unify-charge-uncharge-quantities-to-units-of-pages.patch:
  Refresh. Use hpage_nr_pages rather than compound_order (bnc#704592)
* Mon Jul 11 2011 trenn@suse.de
  Cleanup: Remove patches already added by others or which are not needed:
- patches.arch/012-intel_idle__Change_mode_755__644.patch: Delete.
- patches.drivers/2009-10-12-0001-mce-edac-Use-an-atomic-notifier-for-MCEs-decoding.patch:
  Delete.
- patches.drivers/2009-10-12-0003-x86-Export-k8-physical-topology.patch:
  Delete.
- patches.drivers/Modified-2010-03-08-0001-Driver-core-Constify-struct-sysfs_ops-in-struct-kob.patch:
  Delete.
- patches.drivers/Modified-2010-05-25-0001-kernel.h-add-pr_warn-for-symmetry-to-dev_warn-netd.patch:
  Delete.
* Mon Jul 11 2011 hare@suse.de
- Remove unused patches:
  * patches.suse/blk-queue-unprep-fn
  * patches.suse/gfs2-generalize-flags-for-blkdev_issue_fn-functio.patch
  * patches.suse/scsi-Retry-commands-with-UNIT_ATTENTION-sense-code.patch
  * patches.suse/staging-hv-host-lock-push-down.patch
* Mon Jul 11 2011 jjolly@suse.de
- patches.arch/s390-sles11sp2-kmsg.patch: kmsg: add descriptions
  for new messages (bnc#702651,LTC#72829).
* Sat Jul  9 2011 mgalbraith@suse.de
- patches.fixes/sched-divide-by-zero-workaround-and-diag.diff:
  Delete.
* Fri Jul  8 2011 jkosina@suse.cz
- patches.suse/ppc-temporary-bugon-timer-workaround.patch:
  Refresh.
* Fri Jul  8 2011 jkosina@suse.cz
- patches.suse/ppc-temporary-bugon-timer-workaround.patch: ppc:
  temporary workaround for ppc timer BUG_ON() (bnc#702384).
* Fri Jul  8 2011 rjw@suse.de
- patches.fixes/PM-Hibernate-Avoid-hitting-OOM-during-preallocation-of-memory.patch:
  PM / Hibernate: Avoid hitting OOM during preallocation of
  memory.
- patches.fixes/PM-Hibernate-Fix-free_unnecessary_pages.patch:
  PM / Hibernate: Fix free_unnecessary_pages().
* Fri Jul  8 2011 hare@suse.de
- patches.drivers/igb-support-for-VF-configuration-tools.patch:
  Refresh.
* Fri Jul  8 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-118-Add-a-fix-up-for-HP-RP5800:
  patch name corrected, fixed the upstream git commit id
* Fri Jul  8 2011 hare@suse.de
- patches.drivers/igb-rework-use-of-VMOLR-in-regards-to-PF-and-VFs.patch:
  Fixup compilation error.
* Fri Jul  8 2011 hare@suse.de
- Fixup patches for series2git:
  * patches.drivers/0335-New-7.0-FW-bnx2x-cnic-bnx2i-bnx2fc.patch
  * patches.drivers/merge-branch-master-of-master-kernel-org-pub-scm-linux-kernel-git-davem-net-2-6
  * patches.suse/events-rename-trace_event_template-to-declare_event_class
  * patches.suse/hw-breakpoints-prepare-the-code-for-hardware-breakpoint-interfaces
  * patches.suse/hw-breakpoints-rewrite-the-hw-breakpoints-layer-on-top-of-perf-events
  * patches.suse/hw-breakpoints-use-the-new-wrapper-routines-to-access-debug-registers-in-process-thread-code
  * patches.suse/hw-breakpoints-x86-architecture-implementation-of-hardware-breakpoint-interfaces
  * patches.suse/ksym_tracer-extract-trace-entry-from-struct-trace_ksym
  * patches.suse/merge-hw-breakpoints-rewrite-the-hw-breakpoints-layer-on-top-of-perf-events
  * patches.suse/perf_events-add-event-constraints-support-for-intel-processors
  * patches.suse/perf_events-x86-fix-event-constraints-code
  * patches.suse/revert-x86-apic-fix-spurious-error-interrupts-triggering-on-all-non-boot-aps
  * patches.suse/trace_syscalls-set-event_enter_-sname-data-to-its-metadata
  * patches.suse/tracing-add-kprobe-based-event-tracer
  * patches.suse/tracing-create-new-define_event_print
  * patches.suse/tracing-create-new-trace_event_template
  * patches.suse/tracing-kprobe-tracer-assigns-new-event-ids-for-each-event
  * patches.suse/tracing-kprobes-cleanup-kprobe-tracer-code
  * patches.suse/tracing-profile-add-filter-support
  * patches.suse/tracing-syscalls-make-syscall-events-print-callbacks-static
  * patches.suse/x86-hw-breakpoints-actually-flush-thread-breakpoints-in-flush_thread
  * patches.xen/xen3-patch-2.6.30
* Fri Jul  8 2011 hare@suse.de
- Add igb update (FATE#311304).
* Thu Jul  7 2011 hare@suse.de
- Revert accidental low_latency change:
  * patches.suse/blkio-Implement-group_isolation-tunable.patch:
    Refresh.
  * patches.suse/cfq-iosched-Always-provide-group-isolation.patch:
    Refresh.
  * patches.suse/cfq-iosched-Implement-tunable-group_idle.patch:
    Refresh.
  * patches.suse/cfq-iosched-commenting-non-obvious-initialization.patch:
    Refresh.
  * patches.suse/cfq-iosched-fix-ncq-detection-code.patch:
    Reset latency to 0.
  * patches.suse/cfq-iosched-reduce-write-depth-only-if-sync-was-del.patch:
    Refresh.
* Thu Jul  7 2011 gregkh@suse.de
- patches.xen/xen3-auto-xen-drivers.diff: fix hcd->poll_rh build error.
  Hand edited the patch, odds are, something in the xen patch refresh in
  the future will break this, but the xen developer can fix that up.
* Thu Jul  7 2011 gregkh@suse.de
- USB 3.0 update, .35->.36.  ISO support should now be complete.
- Update config files.
- patches.drivers/USB3-0100-usb-storage-freecom-Fixed-several-coding-style-issues.patch:
  usb: storage: freecom: Fixed several coding style issues.
- patches.drivers/USB3-0101-USB-autoconvert-trivial-BKL-users-to-private-mutex.patch:
  USB: autoconvert trivial BKL users to private mutex.
- patches.drivers/USB3-0103-USB-misc-Remove-unnecessary-casts-of-private_data.patch:
  USB: misc: Remove unnecessary casts of private_data.
- patches.drivers/USB3-0109-USB-io_ti.c-don-t-return-0-if-writing-the-download-record-fa.patch:
  USB: io_ti.c: don't return 0 if writing the download record
  failed.
- patches.drivers/USB3-0114-USB-xHCI-Supporting-MSI-MSI-X.patch:
  USB: xHCI: Supporting MSI/MSI-X.
- patches.drivers/USB3-0115-USB-EHCI-remove-PCI-assumption.patch:
  USB: EHCI: remove PCI assumption.
- patches.drivers/USB3-0116-USB-EHCI-simplify-remainder-computations.patch:
  USB: EHCI: simplify remainder computations.
- patches.drivers/USB3-0117-USB-EHCI-add-missing-frame-microframe-conversion.patch:
  USB: EHCI: add missing frame -> microframe conversion.
- patches.drivers/USB3-0118-USB-EHCI-reorganize-isochronous-scheduler-routine.patch:
  USB: EHCI: reorganize isochronous scheduler routine.
- patches.drivers/USB3-0119-USB-EHCI-remove-dead-code-in-the-periodic-scheduler.patch:
  USB: EHCI: remove dead code in the periodic scheduler.
- patches.drivers/USB3-0124-USB-xHCI-handle_tx_event-refactor-finish_td.patch:
  USB: xHCI: handle_tx_event() refactor: finish_td.
- patches.drivers/USB3-0125-USB-xHCI-handle_tx_event-refactor-process_ctrl_td.patch:
  USB: xHCI: handle_tx_event() refactor: process_ctrl_td.
- patches.drivers/USB3-0126-USB-xHCI-handle_tx_event-refactor-process_bulk_intr_td.patch:
  USB xHCI: handle_tx_event() refactor: process_bulk_intr_td.
- patches.drivers/USB3-0127-USB-xHCI-remove-redundant-print-messages.patch:
  USB: xHCI: remove redundant print messages.
- patches.drivers/USB3-0128-USB-xHCI-adds-new-cases-to-trb_comp_code-switch.patch:
  USB: xHCI: adds new cases to trb_comp_code switch.
- patches.drivers/USB3-0129-USB-xHCI-Missed-Service-Error-Event-process.patch:
  USB: xHCI: Missed Service Error Event process.
- patches.drivers/USB3-0130-USB-xHCI-Introduce-urb_priv-structure.patch:
  USB: xHCI: Introduce urb_priv structure.
- patches.drivers/USB3-0131-USB-xHCI-Isochronous-transfer-implementation.patch:
  USB: xHCI: Isochronous transfer implementation.
- patches.drivers/USB3-0132-USB-xHCI-allocate-bigger-ring-for-isochronous-endpoint.patch:
  USB: xHCI: allocate bigger ring for isochronous endpoint.
- patches.drivers/USB3-0133-USB-xHCI-Isoc-urb-enqueue.patch:
  USB: xHCI: Isoc urb enqueue.
- patches.drivers/USB3-0155-USB-accept-RNDIS-configs-if-there-s-no-alternative.patch:
  USB: accept RNDIS configs if there's no alternative.
- patches.drivers/USB3-0159-USB-ehci-fix-remove-of-ehci-debugfs-dir.patch:
  USB: ehci: fix remove of ehci debugfs dir.
- patches.drivers/USB3-0160-USB-usb-storage-implement-autosuspend.patch:
  USB: usb-storage: implement autosuspend.
- patches.drivers/USB3-0161-USB-add-USB-serial-ssu100-driver.patch:
  USB: add USB serial ssu100 driver.
- patches.drivers/USB3-0162-USB-fix-linux-usb.h-kernel-doc-warnings.patch:
  USB:: fix linux/usb.h kernel-doc warnings.
- patches.drivers/USB3-0163-USB-xhci-Performance-move-functions-that-find-ep-ring.patch:
  USB: xhci: Performance - move functions that find ep ring.
- patches.drivers/USB3-0164-USB-xhci-Performance-move-interrupt-handlers-into-xhci-ring..patch:
  USB: xhci: Performance - move interrupt handlers into
  xhci-ring.c.
- patches.drivers/USB3-0165-USB-xhci-Performance-move-xhci_work-into-xhci_irq.patch:
  USB: xhci: Performance - move xhci_work() into xhci_irq().
- patches.drivers/USB3-0166-USB-xhci-Remove-unnecessary-reads-of-IRQ_PENDING-register.patch:
  USB: xhci: Remove unnecessary reads of IRQ_PENDING register.
- patches.drivers/USB3-0167-USB-xhci-Make-xhci_handle_event-static.patch:
  USB: xhci: Make xhci_handle_event() static.
- patches.drivers/USB3-0168-USB-xhci-Minimize-HW-event-ring-dequeue-pointer-writes.patch:
  USB: xhci: Minimize HW event ring dequeue pointer writes.
- patches.drivers/USB3-0169-USB-xhci-Make-xhci_set_hc_event_deq-static.patch:
  USB: xhci: Make xhci_set_hc_event_deq() static.
- patches.drivers/USB3-0170-USB-xhci-Reduce-reads-and-writes-of-interrupter-registers.patch:
  USB: xhci: Reduce reads and writes of interrupter registers.
- patches.drivers/USB3-0171-USB-xhci-Don-t-flush-doorbell-writes.patch:
  USB: xhci: Don't flush doorbell writes.
- patches.drivers/USB3-0172-USB-xhci-Set-DMA-mask-for-host.patch:
  USB: xhci: Set DMA mask for host.
- patches.drivers/USB3-0174-USB-usbtest-support-test-device-with-only-one-iso-in-or-iso-.patch:
  USB: usbtest: support test device with only one iso-in or
  iso-out endpoint.
- patches.drivers/USB3-0176-USB-remove-fake-address-of-expressions.patch:
  USB: remove fake "address-of" expressions.
- patches.drivers/USB3-0177-USB-serial-fix-stalled-writes.patch:
  USB: serial: fix stalled writes.
- patches.drivers/USB3-0182-ipheth-add-support-for-iPhone-4.patch:
  ipheth: add support for iPhone 4.
- patches.drivers/USB3-0187-USB-serial-fix-leak-of-usb-serial-module-refrence-count.patch:
  USB: serial: fix leak of usb serial module refrence count.
- patches.drivers/USB3-0193-USB-ssu100-add-locking-for-port-private-data-in-ssu100.patch:
  USB: ssu100: add locking for port private data in ssu100.
- patches.drivers/USB3-0194-USB-ssu100-refine-process_packet-in-ssu100.patch:
  USB: ssu100: refine process_packet in ssu100.
- patches.drivers/USB3-0195-USB-ssu100-remove-duplicate-defines-in-ssu100.patch:
  USB: ssu100: remove duplicate #defines in ssu100.
- patches.drivers/USB3-0196-USB-ssu100-add-register-parameter-to-ssu100_setregister.patch:
  USB: ssu100: add register parameter to ssu100_setregister.
- patches.drivers/USB3-0197-USB-ssu100-rework-logic-for-TIOCMIWAIT.patch:
  USB: ssu100: rework logic for TIOCMIWAIT.
- patches.drivers/USB3-0198-USB-serial-export-symbol-usb_serial_generic_disconnect.patch:
  USB: serial: export symbol usb_serial_generic_disconnect.
- patches.drivers/USB3-0199-USB-ssu100-add-disconnect-function-for-ssu100.patch:
  USB: ssu100: add disconnect function for ssu100.
- patches.drivers/USB3-0200-USB-ssu100-set-tty_flags-in-ssu100_process_packet.patch:
  USB: ssu100: set tty_flags in ssu100_process_packet.
- patches.drivers/USB3-0204-USB-serial-io_ti.c-don-t-return-0-if-writing-the-download-re.patch:
  USB: serial: io_ti.c: don't return 0 if writing the download
  record failed.
- patches.drivers/USB3-0207-USB-xHCI-update-ring-dequeue-pointer-when-process-missed-tds.patch:
  USB: xHCI: update ring dequeue pointer when process missed tds.
- patches.drivers/USB3-0208-USB-iowarrior-fix-misuse-of-return-value-of-copy_to_user.patch:
  USB: iowarrior: fix misuse of return value of copy_to_user().
- patches.drivers/USB3-0209-USB-adutux-fix-misuse-of-return-value-of-copy_to_user.patch:
  USB: adutux: fix misuse of return value of copy_to_user().
- patches.drivers/USB3-0215-USB-option-fix-incorrect-novatel-entries.patch:
  USB: option: fix incorrect novatel entries.
- patches.drivers/USB3-0219-usb-allow-drivers-to-use-allocated-bandwidth-until-unbound.patch:
  usb: allow drivers to use allocated bandwidth until unbound.
- patches.drivers/USB3-0220-USB-ssu100-turn-off-debug-flag.patch:
  USB: ssu100: turn off debug flag.
- patches.drivers/USB3-0224-USB-cxacru-Use-a-bulk-int-URB-to-access-the-command-endpoint.patch:
  USB: cxacru: Use a bulk/int URB to access the command endpoint.
- patches.drivers/USB3-0228-ipheth-remove-incorrect-devtype-to-WWAN.patch:
  ipheth: remove incorrect devtype to WWAN.
- patches.drivers/USB3-0231-USB-EHCI-Disable-langwell-penwell-LPM-capability.patch:
  USB: EHCI: Disable langwell/penwell LPM capability.
- supported.conf:
- patches.drivers/USB3-0244-USB-remove-unused-usb_buffer_alloc-and-usb_buffer_free-macro.patch:
  Delete.
* Wed Jul  6 2011 jeffm@suse.com
- supported.conf: Added cxgb4 as a dependency of cxgb4i
* Wed Jul  6 2011 gregkh@suse.de
- patches.drivers/USB3-0002-usbnet-Print-device-statistics-as-unsigned.patch:
  Refresh.
- patches.drivers/USB3-0008-usb-pegasus-fixed-coding-style-issues.patch:
  Refresh.
- patches.drivers/USB3-0009-usbnet-remove-direct-access-to-urb-status.patch:
  Refresh.
- patches.drivers/USB3-0014-ehci-hcd-Fix-typo-in-an-error-message.patch:
  Refresh.
- patches.drivers/USB3-0015-hso-remove-driver-version.patch:
  Refresh.
- patches.drivers/USB3-0015-include-linux-usb-audio.h-add-__attribute__-packed.patch:
  Refresh.
- patches.drivers/USB3-0021-usbnet-use-jiffies-in-schedule_timeout-not-msecs.patch:
  Refresh.
- patches.drivers/USB3-0028-hso-Add-new-product-ID.patch: Refresh.
- patches.drivers/USB3-0031-usbnet-remove-noisy-and-hardly-useful-printk.patch:
  Refresh.
- patches.drivers/USB3-0033-usbnet-rx_submit-should-return-an-error-code.patch:
  Refresh.
* Wed Jul  6 2011 gregkh@suse.de
- USB 3.0 work, .35->.36 half done
- patches.drivers/USB3-0002-usbnet-Print-device-statistics-as-unsigned.patch:
  usbnet: Print device statistics as unsigned.
- patches.drivers/USB3-0008-usb-pegasus-fixed-coding-style-issues.patch:
  usb: pegasus: fixed coding style issues.
- patches.drivers/USB3-0009-usbnet-remove-direct-access-to-urb-status.patch:
  usbnet: remove direct access to urb->status.
- patches.drivers/USB3-0015-hso-remove-driver-version.patch:
  hso: remove driver version.
- patches.drivers/USB3-0021-usbnet-use-jiffies-in-schedule_timeout-not-msecs.patch:
  usbnet: use jiffies in schedule_timeout(), not msecs.
- patches.drivers/USB3-0028-hso-Add-new-product-ID.patch: hso:
  Add new product ID.
- patches.drivers/USB3-0031-usbnet-remove-noisy-and-hardly-useful-printk.patch:
  usbnet: remove noisy and hardly useful printk.
- patches.drivers/USB3-0033-usbnet-rx_submit-should-return-an-error-code.patch:
  usbnet: rx_submit() should return an error code.
- patches.drivers/USB3-0034-tty-Fix-the-digi-acceleport-driver-NULL-checks.patch:
  tty: Fix the digi acceleport driver NULL checks.
- patches.drivers/USB3-0035-cdc-acm-remove-dead-code.patch:
  cdc-acm: remove dead code.
- patches.drivers/USB3-0036-USB-fix-failure-path-in-usb_add_hcd.patch:
  USB: fix failure path in usb_add_hcd().
- patches.drivers/USB3-0037-USB-don-t-stop-root-hub-status-polls-too-soon.patch:
  USB: don't stop root-hub status polls too soon.
- patches.drivers/USB3-0038-USB-add-check-to-detect-host-controller-hardware-removal.patch:
  USB: add check to detect host controller hardware removal.
- patches.drivers/USB3-0039-USB-UHCI-acquire-spinlock-before-calling-start_rh.patch:
  USB: UHCI: acquire spinlock before calling start_rh().
- patches.drivers/USB3-0040-USB-speedtouch-fixed-brace-and-spacing-coding-style-issues.patch:
  USB: speedtouch: fixed brace and spacing coding style issues.
- patches.drivers/USB3-0041-USB-speedtouch-fixed-more-brace-and-spacing-coding-style-iss.patch:
  USB: speedtouch: fixed more brace and spacing coding style
  issues.
- patches.drivers/USB3-0042-USB-xhci-Remove-obsolete-debugging-printk.patch:
  USB: xhci: Remove obsolete debugging printk.
- patches.drivers/USB3-0043-USB-iuu_phoenix-Add-support-for-different-baud-rates.patch:
  USB: iuu_phoenix: Add support for different baud rates.
- patches.drivers/USB3-0044-USB-EHCI-make-CONFIG_USB_EHCI_TT_NEWSCHED-default-to-Y.patch:
  USB: EHCI: make CONFIG_USB_EHCI_TT_NEWSCHED default to Y.
- patches.drivers/USB3-0047-USB-core-endpoint-Fix-Coding-Styles.patch:
  USB: core endpoint: Fix Coding Styles.
- patches.drivers/USB3-0049-USB-host-Eliminate-NULL-dereference.patch:
  USB: host: Eliminate NULL dereference.
- patches.drivers/USB3-0050-USB-isd200.c-Remove-unnecessary-kmalloc-cast.patch:
  USB: isd200.c: Remove unnecessary kmalloc cast.
- patches.drivers/USB3-0052-USB-EHCI-EHCI-1.1-addendum-preparation.patch:
  USB: EHCI: EHCI 1.1 addendum: preparation.
- patches.drivers/USB3-0053-USB-EHCI-EHCI-1.1-addendum-Basic-LPM-feature-support.patch:
  USB: EHCI: EHCI 1.1 addendum: Basic LPM feature support.
- patches.drivers/USB3-0054-USB-EHCI-EHCI-1.1-addendum-Enable-Per-port-change-detect-bit.patch:
  USB: EHCI: EHCI 1.1 addendum: Enable Per-port change detect
  bits.
- patches.drivers/USB3-0055-USB-option-Remove-duplicate-AMOI_VENDOR_ID.patch:
  USB: option: Remove duplicate AMOI_VENDOR_ID.
- patches.drivers/USB3-0056-Revert-USB-Adding-support-for-HTC-Smartphones-to-ipaq.patch:
  Revert "USB: Adding support for HTC Smartphones to ipaq".
- patches.drivers/USB3-0058-usb-conexant-fixed-spacing-and-brace-coding-style-issues.patch:
  usb: conexant: fixed spacing and brace coding style issues.
- patches.drivers/USB3-0060-usb-atm-fixed-spacing-and-indentation-coding-style-issues.patch:
  usb: atm: fixed spacing and indentation coding style issues.
- patches.drivers/USB3-0063-USB-BKL-Remove-BKL-use-for-usb-serial-driver-probing.patch:
  USB-BKL: Remove BKL use for usb serial driver probing.
- patches.drivers/USB3-0064-USB-BKL-Remove-BKL-use-in-uhci-debug.patch:
  USB-BKL: Remove BKL use in uhci-debug.
- patches.drivers/USB3-0077-USB-convert-usb_hcd-bitfields-into-atomic-flags.patch:
  USB: convert usb_hcd bitfields into atomic flags.
- patches.drivers/USB3-0079-USB-refactor-the-powermac-specific-ASIC-clock-code.patch:
  USB: refactor the powermac-specific ASIC clock code.
- patches.drivers/USB3-0086-USB-usblp-fixed-switch-brace-whitespace-and-spacing-coding-s.patch:
  USB: usblp: fixed switch, brace, whitespace and spacing coding
  style issues.
- patches.drivers/USB3-0087-USB-drivers-usb-Makefile-conditionally-descend-to-early.patch:
  USB: drivers/usb/Makefile: conditionally descend to 'early'.
- patches.drivers/USB3-0088-USB-xhci-trivial-use-ARRAY_SIZE.patch:
  USB: xhci: trivial: use ARRAY_SIZE.
- patches.drivers/USB3-0089-USB-EHCI-fix-NULL-pointer-dererence-in-HCDs-that-use-HCD_LOC.patch:
  USB: EHCI: fix NULL pointer dererence in HCDs that use
  HCD_LOCAL_MEM.
- patches.drivers/USB3-0092-USB-serial-io_ti-Don-t-return-0-if-writing-the-download-reco.patch:
  USB: serial: io_ti: Don't return 0 if writing the download
  record failed.
- patches.suse/kdb-common: Refresh.
* Wed Jul  6 2011 jslaby@suse.de
- patches.arch/x86-Introduce-struct-fpu-and-related-API.patch:
  Refresh.
- patches.arch/x86-ptrace-xstate-support.patch: Rename to
  patches.arch/x86-xstate-01-ptrace-support.patch
- patches.arch/x86-xstate-02-ptrace-generic-PTRACE_GETREGSET-SETREGSET.patch:
  ptrace: Add support for generic
  PTRACE_GETREGSET/PTRACE_SETREGSET (bnc#698803 fate#311964).
- patches.arch/x86-xstate-03-fix-returned-error.patch: ptrace:
  Fix ptrace_regset() comments and diagnose errors specifically
  (bnc#698803 fate#311964).
- patches.arch/x86-xstate-04-simplify-xstateregs_get.patch: x86,
  ptrace: Simplify xstateregs_get() (bnc#698803 fate#311964).
- patches.arch/x86-xstate-05-remove-set_stopped_child_used_math.patch:
  x86, ptrace: Remove set_stopped_child_used_math() infpregs_set
  (bnc#698803 fate#311964).
- patches.arch/xsaveopt-05-sync-xsave-memory-layout.patch:
  Refresh.
* Wed Jul  6 2011 jdelvare@suse.de
- patches.drivers/mpt-fusion-fix-races-with-deleted.patch:
  Add a note about upstream equivalent fix.
* Wed Jul  6 2011 jeffm@suse.com
- Update config files.
- patches.drivers/cxgb4-add-a-missing-error-interrupt: cxgb4:
  add a missing error interrupt (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-add-const-to-static-arrays: cxgb4:
  add const to static arrays (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-add-hw-and-fw-support-code: cxgb4:
  Add HW and FW support code (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-add-main-driver-file-and-driver-makefile:
  cxgb4: Add main driver file and driver Makefile (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-add-new-pci-ids: cxgb4: add new PCI IDs
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-add-packet-queues-and-packet-dma-code:
  cxgb4: Add packet queues and packet DMA code (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-add-register-message-and-fw-definitions:
  cxgb4: Add register, message, and FW definitions (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-add-remaining-driver-headers-and-l2t-management:
  cxgb4: Add remaining driver headers and L2T management
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-add-user-manipulation-of-the-rss-table:
  cxgb4: add user manipulation of the RSS table (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-advertise-netif_f_tso_ecn: cxgb4:
  advertise NETIF_F_TSO_ECN (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-allocate-more-space-for-msi-x-interrupt-names:
  cxgb4: allocate more space for MSI-X interrupt names
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-avoid-duplicating-some-resource-freeing-code:
  cxgb4: avoid duplicating some resource freeing code
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-chelsio-t4-driver-compat: cxgb4: Chelsio
  T4 driver (compat) (bnc#694966, FATE#311470).
- patches.drivers/cxgb4-configure-hw-vlan-extraction-through-fw:
  cxgb4: configure HW VLAN extraction through FW (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-correct-formatting-of-msi-x-interrupt-names:
  cxgb4: correct formatting of MSI-X interrupt names (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-disable-an-interrupt-that-is-neither-used-nor-serviced:
  cxgb4: disable an interrupt that is neither used nor serviced
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-distinguish-between-1-lane-kr-kx-and-4-lane-kr-kx-kx4-ports:
  cxgb4: distinguish between 1-lane KR/KX and 4-lane KR/KX/KX4
  ports (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-do-not-read-the-clock-frequency-from-vpd:
  cxgb4: do not read the clock frequency from VPD (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-don-t-offload-rx-checksums-for-ipv6-fragments:
  cxgb4: don't offload Rx checksums for IPv6 fragments
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-dynamically-determine-flash-size-and-fw-image-location:
  cxgb4: dynamically determine flash size and FW image location
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-enable-pcie-relaxed-ordering: cxgb4:
  enable PCIe relaxed ordering (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-exclude-registers-with-read-side-effects-from-register-dumps:
  cxgb4: exclude registers with read side effects from register
  dumps (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-extend-vpd-parsing: cxgb4: extend VPD
  parsing (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-fix-crash-due-to-manipulating-queues-before-registration:
  cxgb4: fix crash due to manipulating queues before registration
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-fix-for-new-ndo_get_stats64-signature:
  cxgb4: fix for new ndo_get_stats64 signature (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-fix-initial-addition-of-mac-address:
  cxgb4: fix initial addition of MAC address (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-fix-mac-address-hash-filter: cxgb4:
  fix MAC address hash filter (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-fix-setting-of-the-function-number-in-transmit-descriptors:
  cxgb4: fix setting of the function number in transmit
  descriptors (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-fix-tso-descriptors: cxgb4: fix TSO
  descriptors (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-fix-wrong-shift-direction: cxgb4: fix
  wrong shift direction (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-function-namespace-cleanup-v3: cxgb4:
  function namespace cleanup (v3) (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-get-on-chip-queue-info-from-fw-and-create-a-memory-window-for-them:
  cxgb4: get on-chip queue info from FW and create a memory
  window for them (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-handle-rx-tx-queue-ranges-not-starting-at-0:
  cxgb4: handle Rx/Tx queue ranges not starting at 0 (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-implement-eeh: cxgb4: implement EEH
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-implement-the-ethtool_grxfh-command:
  cxgb4: implement the ETHTOOL_GRXFH command (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-increase-serial-number-length: cxgb4:
  increase serial number length (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-keep-interrupts-available-when-the-ports-are-brought-down:
  cxgb4: keep interrupts available when the ports are brought down
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-make-unnecessarily-global-functions-static:
  cxgb4: Make unnecessarily global functions static (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-minor-cleanup: cxgb4: minor cleanup
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-move-the-choice-of-interrupt-type-before-net_device-registration:
  cxgb4: move the choice of interrupt type before net_device
  registration (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-notify-upper-drivers-if-the-device-is-already-up-when-they-load:
  cxgb4: notify upper drivers if the device is already up when
  they load (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-numa-aware-tx-queue-allocations: cxgb4:
  NUMA-aware Tx queue allocations (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-parse-the-vpd-instead-of-relying-on-a-static-vpd-layout:
  cxgb4: parse the VPD instead of relying on a static VPD layout
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-print-port-information-after-registering-each-netdev:
  cxgb4: print port information after registering each netdev
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-propagate-link-initialization-errors-to-ndo_open-s-callers:
  cxgb4: propagate link initialization errors to .ndo_open's
  callers (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-rearrange-initialization-code-in-preparation-for-eeh:
  cxgb4: rearrange initialization code in preparation for EEH
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-remove-a-bitmap: cxgb4: remove a bitmap
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-remove-a-bogus-pci-function-number-check:
  cxgb4: remove a bogus PCI function number check (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-remove-call-to-stop-tx-queues-at-load-time:
  cxgb4: remove call to stop TX queues at load time (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-remove-the-name-field-from-the-adapter-structure:
  cxgb4: remove the name field from the adapter structure
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-report-gro-stats-with-ethtool-s: cxgb4:
  report GRO stats with ethtool -S (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-report-the-pcie-link-speed: cxgb4:
  report the PCIe link speed (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-set-dev_id-to-the-port-number: cxgb4:
  set dev_id to the port number (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-set-skb-rxhash: cxgb4: set skb->rxhash
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-set-the-number-of-queues-before-device-registration:
  cxgb4: set the number of queues before device registration
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-support-eeprom-read-write-on-functions-other-than-0:
  cxgb4: support eeprom read/write on functions other than 0
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-support-running-the-driver-on-pci-functions-besides-0:
  cxgb4: support running the driver on PCI functions besides 0
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-switch-to-64-bit-inteface-statistics:
  cxgb4: switch to 64 bit inteface statistics (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-update-driver-version: cxgb4: update
  driver version (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-update-fw-definitions: cxgb4: update FW
  definitions (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-update-pci-ids: cxgb4: update PCI ids
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-update-to-utilize-the-newer-vlan-infrastructure:
  cxgb4: update to utilize the newer VLAN infrastructure
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-use-kfree_skb-for-skb-pointers: cxgb4:
  Use kfree_skb for skb pointers (FATE#311470, bnc#694966).
- patches.drivers/cxgb4-use-netif_set_real_num_-rx-tx-_queues:
  cxgb4: Use netif_set_real_num_{rx,tx}_queues() (FATE#311470,
  bnc#694966).
- patches.drivers/cxgb4-use-ntohs-on-__be16-value-instead-of-htons:
  cxgb4: Use ntohs() on __be16 value instead of htons()
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4vf-add-code-to-provision-t4-pci-e-sr-iov-virtual-functions-with-hardware-resources:
  cxgb4vf: Add code to provision T4 PCI-E SR-IOV Virtual Functions
  with hardware resources (FATE#311470, bnc#694966).
- patches.drivers/cxgb4vf-add-new-macros-and-definitions-for-hardware-constants:
  cxgb4vf: Add new macros and definitions for hardware constants
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4vf-small-changes-to-message-processing-structures-macros:
  cxgb4vf: small changes to message processing structures/macros
  (FATE#311470, bnc#694966).
- patches.drivers/cxgb4vf-update-to-latest-t4-firmware-api-file:
  cxgb4vf: update to latest T4 firmware API file (FATE#311470,
  bnc#694966).
- patches.drivers/drivers-net-avoid-some-skb-ip_summed-initializations:
  drivers/net: avoid some skb->ip_summed initializations
  (FATE#311470, bnc#694966).
- patches.drivers/ethtool-change-ethtool_op_set_flags-to-validate-flags:
  ethtool: Change ethtool_op_set_flags to validate flags
  (FATE#311470, bnc#694966).
- patches.drivers/llseek-automatically-add-llseek-fop: llseek:
  automatically add .llseek fop (FATE#311470, bnc#694966).
- patches.drivers/merge-branch-master-of-master-kernel-org-pub-scm-linux-kernel-git-davem-net-2-6:
  Merge branch 'master' of
  master.kernel.org:/pub/scm/linux/kernel/git/davem/net-2.6
  (FATE#311470, bnc#694966).
- patches.drivers/net-hook-up-cxgb4-to-kconfig-and-makefile:
  net: Hook up cxgb4 to Kconfig and Makefile.
* Tue Jul  5 2011 jeffm@suse.com
- patches.suse/scsi-pmcraid-remove-duplicate-struct-member:
  pmcraid: remove duplicate struct member.
* Tue Jul  5 2011 jeffm@suse.com
- patches.drivers/0272-cnic-Prevent-status-block-race-conditions-with-hardw.patch:
  cnic: Prevent status block race conditions with hardware
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0273-cnic-Fix-lost-interrupt-on-bnx2x.patch:
  cnic: Fix lost interrupt on bnx2x (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0274-bnx2x-fix-non-pmf-device-load-flow.patch:
  bnx2x: fix non-pmf device load flow (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0275-bnx2x-fix-link-notification.patch: bnx2x:
  fix link notification (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0276-bnx2x-NPAR-prevent-HW-access-in-D3-state.patch:
  bnx2x: (NPAR) prevent HW access in D3 state (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0277-bnx2x-fix-MaxBW-configuration.patch: bnx2x:
  fix MaxBW configuration (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0278-bnx2x-fix-swap-of-rx-ticks-and-tx-ticks-parameters-i.patch:
  bnx2x: fix swap of rx-ticks and tx-ticks parameters in interrupt
  coalescing flow (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0279-bnx2-Update-firmware-and-version.patch:
  bnx2: Update firmware and version (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0280-drivers-net-Fix-declaration-ordering-in-inline-funct.patch:
  drivers net: Fix declaration ordering in inline functions
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0281-Fix-common-misspellings.patch: Fix common
  misspellings (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0282-bnx2x-Update-firmware-to-6.2.9.patch:
  bnx2x: Update firmware to 6.2.9 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0283-bnx2x-don-t-write-dcb-llfc-fields-in-STORM-memory.patch:
  bnx2x: don't write dcb/llfc fields in STORM memory (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0284-bnx2x-cnic-Disable-iSCSI-if-DCBX-negotiation-is-succ.patch:
  bnx2x, cnic: Disable iSCSI if DCBX negotiation is successful
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0285-cnic-Fix-rtnl-deadlock.patch: cnic: Fix
  rtnl deadlock (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0286-bnx2x-Fix-set-but-unused-variables.patch:
  bnx2x: Fix set-but-unused variables (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0287-bnx2x-Fix-port-identification-problem.patch:
  bnx2x: Fix port identification problem (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0288-bnx2x-cosmetics-Using-ethtool_cmd_speed-API.patch:
  bnx2x: cosmetics: Using ethtool_cmd_speed() API (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0289-bnx2x-fix-UDP-csum-offload.patch: bnx2x:
  fix UDP csum offload (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0290-bnx2-cancel-timer-on-device-removal.patch:
  bnx2: cancel timer on device removal (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0291-ethtool-Use-full-32-bit-speed-range-in-ethtool-s-set.patch:
  ethtool: Use full 32 bit speed range in ethtool's set_settings
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0292-ethtool-cosmetic-Use-ethtool-ethtool_cmd_speed-API.patch:
  ethtool: cosmetic: Use ethtool ethtool_cmd_speed API
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0293-bnx2x-link-report-improvements.patch:
  bnx2x: link report improvements (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0294-bnx2x-allow-WoL-on-every-function-in-MF-modes.patch:
  bnx2x: allow WoL on every function in MF modes (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0295-bnx2x-Do-storage-mac-address-validation-for-SF-mode.patch:
  bnx2x: Do storage mac address validation for SF mode
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0296-bnx2x-improve-memory-handling-low-memory-recovery-fl.patch:
  bnx2x: improve memory handling, low memory recovery flows
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0297-bnx2x-update-year-to-2011-and-version-to-1.62.12-0.patch:
  bnx2x: update year to 2011 and version to 1.62.12-0 (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0298-bnx2x-function-descriptions-format-fixed.patch:
  bnx2x: function descriptions format fixed (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0299-drivers-net-add-prefetch-header-for-prefetch-users.patch:
  drivers/net: add prefetch header for prefetch users (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0300-bnx2x-call-dev_kfree_skb_any-instead-of-dev_kfree_sk.patch:
  bnx2x: call dev_kfree_skb_any instead of dev_kfree_skb
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0301-bnx2x-properly-handle-CFC-DEL-in-cnic-flow.patch:
  bnx2x: properly handle CFC DEL in cnic flow (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0302-bnx2x-fix-DMAE-timeout-according-to-hw-specification.patch:
  bnx2x: fix DMAE timeout according to hw specifications
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0303-bnx2x-allow-device-properly-initialize-after-hotplug.patch:
  bnx2x: allow device properly initialize after hotplug
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0304-bnx2i-Fixed-packet-error-created-when-the-sq_size-is.patch:
  bnx2i: Fixed packet error created when the sq_size is set to 16
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0305-bnx2i-Updated-the-connection-shutdown-cleanup-timeou.patch:
  bnx2i: Updated the connection shutdown/cleanup timeout
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0306-bnx2i-Optimized-the-iSCSI-offload-performance.patch:
  bnx2i: Optimized the iSCSI offload performance (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0307-bnx2x-fix-inverted-condition.patch: bnx2x:
  fix inverted condition (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0308-bnx2x-protect-sequence-increment-with-mutex.patch:
  bnx2x: protect sequence increment with mutex (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0309-bnx2x-Add-new-phy-BCM8722.patch: bnx2x:
  Add new phy BCM8722 (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0310-bnx2x-Fix-port-type-display.patch: bnx2x:
  Fix port type display (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0311-bnx2x-Change-return-status-type.patch:
  bnx2x: Change return status type (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0312-bnx2x-Add-TX-fault-check-for-fiber-PHYs.patch:
  bnx2x: Add TX fault check for fiber PHYs (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0313-bnx2x-Fix-over-current-port-display.patch:
  bnx2x: Fix over current port display (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0314-bnx2x-Fix-BCM84833-settings.patch: bnx2x:
  Fix BCM84833 settings (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0315-bnx2x-Fix-grammar-and-relocate-code.patch:
  bnx2x: Fix grammar and relocate code (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0316-bnx2x-Adjust-BCM8726-module-detection-settings.patch:
  bnx2x: Adjust BCM8726 module detection settings (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0317-bnx2x-Fix-link-status-sync.patch: bnx2x:
  Fix link status sync (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0318-bnx2x-Modify-XGXS-functions.patch: bnx2x:
  Modify XGXS functions (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0319-bnx2x-Improve-cl45-access-methods.patch:
  bnx2x: Improve cl45 access methods (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0320-cnic-Fix-interrupt-logic.patch: cnic:
  Fix interrupt logic (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0321-cnic-Fix-race-conditions-with-firmware.patch:
  cnic: Fix race conditions with firmware (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0322-cnic-Randomize-initial-TCP-port-for-iSCSI-connection.patch:
  cnic: Randomize initial TCP port for iSCSI connections
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0323-cnic-Improve-NETDEV_UP-event-handling.patch:
  cnic: Improve NETDEV_UP event handling (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0324-cnic-bnx2-Check-iSCSI-support-early-in-bnx2_init_one.patch:
  cnic, bnx2: Check iSCSI support early in bnx2_init_one()
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0325-cnic-Move-indexing-function-pointers-to-struct-kcq_i.patch:
  cnic: Move indexing function pointers to struct kcq_info
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0326-bnx2x-do-not-allocate-FCoE-ring-if-disabled.patch:
  bnx2x: do not allocate FCoE ring if disabled (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0327-bnx2x-remove-references-to-intr_sem.patch:
  bnx2x: remove references to intr_sem (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0328-bnx2x-put-start-bd-csum-in-separate-function.patch:
  bnx2x: put start bd csum in separate function (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0329-bnx2x-avoid-release-of-unrequested-irqs.patch:
  bnx2x: avoid release of unrequested irqs (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0330-bnx2x-disable-fairness-if-ETS-is-enabled.patch:
  bnx2x: disable fairness if ETS is enabled (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0331-bnx2x-do-not-call-link-update-without-HW-notificatio.patch:
  bnx2x: do not call link update without HW notification
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0332-bnx2x-dump-FW-memory-when-appropriate-msglvl-is-rais.patch:
  bnx2x: dump FW memory when appropriate msglvl is raised
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0333-bnx2x-removed-unused-variables.patch:
  bnx2x: removed unused variables (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0334-bnx2x-Created-bnx2x_sp.patch: bnx2x:
  Created bnx2x_sp (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0335-New-7.0-FW-bnx2x-cnic-bnx2i-bnx2fc.patch:
  New 7.0 FW: bnx2x, cnic, bnx2i, bnx2fc (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0336-bnx2x-57712-parity-handling.patch: bnx2x:
  57712 parity handling (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0337-bnx2x-update-DCB-data-during-PMF-migration.patch:
  bnx2x: update DCB data during PMF migration (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0338-bnx2x-Cosmetic-changes.patch: bnx2x:
  Cosmetic changes (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0339-bnx2x-Add-new-MAC-support-for-578xx.patch:
  bnx2x: Add new MAC support for 578xx (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0340-bnx2x-Add-Warpcore-support-for-578xx.patch:
  bnx2x: Add Warpcore support for 578xx (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0341-bnx2x-Add-new-PHY-54616s.patch: bnx2x:
  Add new PHY 54616s (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0342-bnx2x-Adjust-ETS-to-578xx.patch: bnx2x:
  Adjust ETS to 578xx (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0343-bnx2x-Adjust-BCM84833-to-BCM578xx.patch:
  bnx2x: Adjust BCM84833 to BCM578xx (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0344-bnx2x-Add-a-periodic-task-for-link-PHY-events.patch:
  bnx2x: Add a periodic task for link PHY events (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0345-bnx2x-Rename-LASI-registers-to-definitions-in-mdio.h.patch:
  bnx2x: Rename LASI registers to definitions in mdio.h
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0346-bnx2x-PFC-support-for-578xx.patch: bnx2x:
  PFC support for 578xx (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0347-bnx2x-Update-date-to-2011-06-13-and-version-to-1.70..patch:
  bnx2x: Update date to 2011/06/13 and version to 1.70.00-0
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0348-cnic-bnx2i-Add-support-for-new-devices-57800-57810-a.patch:
  cnic, bnx2i: Add support for new devices - 57800, 57810,
  and 57840 (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/bnx2i-fix-null-ptr-ref-in-conn-get-param: bnx2i:
  fix null ptr ref in conn get param (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
* Tue Jul  5 2011 jeffm@suse.com
- patches.suse/ieee1394-host-lock-push-down.patch: ieee1394 host
  lock push-down.
* Tue Jul  5 2011 jeffm@suse.de
- patches.drivers/hpsa-exported-hpsa_init_one-cant-be-static-__devinit:
  hpsa: Exported hpsa_init_one() can't be static __devinit.
* Tue Jul  5 2011 jdelvare@suse.de
- patches.drivers/intel-patsburg-support.patch,
  patches.drivers/ipmi-add-parameter-to-limit-cpu-usage-in-kipmid.patch,
  patches.drivers/watchdog-hpwdt-allow-full-range-of-timer-values-supported-by-hardware.patch,
  patches.drivers/watchdog-hpwdt-introduce-secs_to_ticks-macro.patch,
  patches.fixes/bonding-802.3ad-fix-state-machine-locking.patch:
  Update upstream references.
* Tue Jul  5 2011 jdelvare@suse.de
- patches.drivers/hwmon-amd-fam15h-power.patch,
  patches.drivers/hwmon-coretemp-add-pkgtemp-support.patch,
  patches.drivers/i2c-i801-no-devices-on-IDF-channels.patch,
  patches.drivers/i2c-i801-support-multiple-instances.patch,
  patches.drivers/intel-patsburg-support-IDF-channels.patch,
  Update upstream references.
* Tue Jul  5 2011 jdelvare@suse.de
- patches.drivers/hwmon-coretemp-add-pkgtemp-support.patch:
  Update (bnc#698797, FATE#311941).
* Tue Jul  5 2011 jdelvare@suse.de
- supported.conf: The coretemp driver is now supported
  (FATE#311941).
* Mon Jul  4 2011 lidongyang@novell.com
- patches.drivers/igb-replace-the-VF-clear_to_send-with-a-flags-value.patch:
  (FATE#311304)
- patches.drivers/igb-rework-use-of-VMOLR-in-regards-to-PF-and-VFs.patch:
  (FATE#311304)
- patches.drivers/pci-Add-SR-IOV-convenience-functions-and-macros.patch:
  (FATE#311304)
- patches.drivers/if_link-Add-SR-IOV-configuration-methods.patch:
  (FATE#311304)
- patches.drivers/net-Add-netdev-ops-for-SR-IOV-configuration.patch:
  (FATE#311304)
- patches.drivers/rtnetlink-Add-VF-config-code-to-rtnetlink.patch:
  (FATE#311304)
- patches.drivers/igb-support-for-VF-configuration-tools.patch:
  (FATE#311304)
* Mon Jul  4 2011 gregkh@suse.de
- patches.drivers/usb3-paper-over-warn_on-warning-in-drivers-usb-core-driver.c.patch:
  USB3: paper over WARN_ON warning in drivers/usb/core/driver.c.
* Mon Jul  4 2011 trenn@suse.de
- Update config files.
- patches.drivers/acpi_apei_add_apei_bit_support_in_generic_OSC_call_3_4.patch:
  ACPI, APEI, Add APEI bit support in generic _OSC call
  (bnc#697859).
- patches.drivers/acpi_apei_add_whea_osc_support_4_4.patch:
  ACPI, APEI, Add WHEA _OSC support (bnc#697859).
- patches.drivers/acpi_apei_disable_suse.patch: Disable all APEI
  parts with one boot param (bnc#697859).
- patches.drivers/acpi_apei_ghes_prevent_ghes_to_be_built_as_module_1_4.patch:
  ACPI, APEI, GHES, Prevent GHES to be built as module
  (bnc#697859).
- patches.drivers/acpi_apei_ghes_support_disable_ghes_at_boot_time_2_4.patch:
  ACPI, APEI, GHES, Support disable GHES at boot time
  (bnc#697859).
- patches.drivers/acpi_apei_hest_detect_duplicated_hardware_error_source_id.patch:
  ACPI, APEI, HEST, Detect duplicated hardware error source ID
  (bnc#697859).
* Mon Jul  4 2011 tiwai@suse.de
- patches.suse/bootsplash-color-fix: Fix invalid color overrides
  in bootsplash consoles (bnc#584493).
* Sun Jul  3 2011 jdelvare@suse.de
- patches.arch/x86-enable-package-level-power-notification.patch:
  Package level power notification (FATE#311941, bnc#698801).
- patches.arch/0001-x86-cpu-Add-AMD-core-boosting-feature-flag-to-proc-c.patch:
  Refresh.
- patches.drivers/edac_do_not_taint_on_correctable_errors.patch:
  Refresh.
- patches.suse/revert-x86-under-bios-control-restore-ap-s-apic_lvtthmr-to-the-bsp-value:
  Refresh.
- patches.suse/x86-under-bios-control-restore-ap-s-apic_lvtthmr-to-the-bsp-value:
  Refresh.
* Sun Jul  3 2011 trenn@suse.de
- patches.drivers/edac_do_not_taint_on_correctable_errors.patch:
  x86, MCE: Do not taint when handling correctable errors
  (bnc#692709).
* Sun Jul  3 2011 trenn@suse.de
  Add git commit id tag and slight correction:
- patches.arch/x86_cpu_hotplug_map_numa_node_correctly.patch:
  Refresh.
* Sat Jul  2 2011 tonyj@suse.de
- Update config files. Enable KSYM_TRACER for ppc64 debug/trace flavor.
  Commit 7f57393b incorrectly reverted this change. ec4115ff fixed but
  only with defaults.
* Sat Jul  2 2011 tonyj@suse.de
- patches.suse/perf-userspace-no-werror.patch: disable -Werror
  for perf userspace (none).
* Sat Jul  2 2011 tonyj@suse.de
- Commit 1a433eaf8 "Do less prefetching on list walking ..." breaks perf
  userspace
- patches.suse/list-prefetch-optimization.diff: Refresh.
* Fri Jul  1 2011 gregkh@suse.de
- USB 3.0, final bit of .34->.35 update.
- patches.drivers/USB3-0211-USB-serial-add-special-case-for-processing-of-empty-read-urb.patch:
  USB: serial: add special case for processing of empty read urbs.
- patches.drivers/USB3-0212-USB-empeg-reimplement-using-generic-framework.patch:
  USB: empeg: reimplement using generic framework.
- patches.drivers/USB3-0213-USB-ipaq-reimplement-using-generic-framework.patch:
  USB: ipaq: reimplement using generic framework.
- patches.drivers/USB3-0214-USB-spcp8x5-reimplement-using-generic-framework.patch:
  USB: spcp8x5: reimplement using generic framework.
- patches.drivers/USB3-0216-USB-visor-reimplement-using-generic-framework.patch:
  USB: visor: reimplement using generic framework.
- patches.drivers/USB3-0217-USB-cp210x-use-generic-open-to-start-reading-from-device.patch:
  USB: cp210x: use generic open to start reading from device.
- patches.drivers/USB3-0218-USB-belkin_sa-minor-clean-ups.patch:
  USB: belkin_sa: minor clean-ups.
- patches.drivers/USB3-0219-USB-belkin_sa-clean-up-open.patch:
  USB: belkin_sa: clean up open.
- patches.drivers/USB3-0220-USB-belkin_sa-implement-line-status-handling.patch:
  USB: belkin_sa: implement line status handling.
- patches.drivers/USB3-0221-USB-visor-increase-bulk-out-buffer-size.patch:
  USB: visor: increase bulk-out buffer size.
- patches.drivers/USB3-0224-USB-usb_debug-set-bulk-out-size-at-probe.patch:
  USB: usb_debug: set bulk out size at probe.
- patches.drivers/USB3-0225-USB-cypress_m8-remove-unused-drain-define.patch:
  USB: cypress_m8: remove unused drain define.
- patches.drivers/USB3-0226-USB-cypress_m8-use-kfifo-to-implement-write-buffering.patch:
  USB: cypress_m8: use kfifo to implement write buffering.
- patches.drivers/USB3-0227-USB-oti6858-use-kfifo-to-implement-write-buffering.patch:
  USB: oti6858: use kfifo to implement write buffering.
- patches.drivers/USB3-0228-USB-oti6858-use-port-write-fifo.patch:
  USB: oti6858: use port write fifo.
- patches.drivers/USB3-0229-USB-usb-storage-trivial-debug-improvements.patch:
  USB: usb-storage: trivial debug improvements.
- patches.drivers/USB3-0230-usb-storage-always-print-quirks.patch:
  usb-storage: always print quirks.
- patches.drivers/USB3-0231-USB-safe_serial-reimplement-write-using-generic-framework.patch:
  USB: safe_serial: reimplement write using generic framework.
- patches.drivers/USB3-0232-USB-safe_serial-reimplement-read-using-generic-framework.patch:
  USB: safe_serial: reimplement read using generic framework.
- patches.drivers/USB3-0233-USB-safe_serial-straighten-out-read-processing.patch:
  USB: safe_serial: straighten out read processing.
- patches.drivers/USB3-0234-USB-aircable-fix-incorrect-write-buffer-length.patch:
  USB: aircable: fix incorrect write-buffer length.
- patches.drivers/USB3-0236-USB-ti_usb-use-kfifo-to-implement-write-buffering.patch:
  USB: ti_usb: use kfifo to implement write buffering.
- patches.drivers/USB3-0237-USB-io_ti-remove-unsused-private-counter.patch:
  USB: io_ti: remove unsused private counter.
- patches.drivers/USB3-0238-USB-io_ti-use-kfifo-to-implement-write-buffering.patch:
  USB: io_ti: use kfifo to implement write buffering.
- patches.drivers/USB3-0240-USB-kl5usb105-minor-clean-ups.patch:
  USB: kl5usb105: minor clean ups.
- patches.drivers/USB3-0241-USB-kl5usb105-reimplement-using-generic-framework.patch:
  USB: kl5usb105: reimplement using generic framework.
- patches.drivers/USB3-0242-USB-ftdi_sio-fix-legacy-SIO-device-header.patch:
  USB: ftdi_sio: fix legacy SIO-device header.
- patches.drivers/USB3-0244-USB-remove-unused-usb_buffer_alloc-and-usb_buffer_free-macro.patch:
  USB: remove unused usb_buffer_alloc and usb_buffer_free macros.
- patches.drivers/USB3-0245-echi-dbgp-Add-kernel-debugger-support-for-the-usb-debug-port.patch:
  echi-dbgp: Add kernel debugger support for the usb debug port.
- patches.drivers/USB3-0251-hso-add-support-for-new-products.patch:
  hso: add support for new products.
- patches.drivers/USB3-0252-drivers-net-usb-asix.c-Fix-pointer-cast.patch:
  drivers/net/usb/asix.c: Fix pointer cast.
- patches.drivers/USB3-0269-USB-xhci-Print-NEC-firmware-version.patch:
  USB: xhci: Print NEC firmware version.
- patches.drivers/USB3-0275-USB-ftdi_sio-fix-DTR-RTS-line-modes.patch:
  USB: ftdi_sio: fix DTR/RTS line modes.
- patches.drivers/USB3-0278-USB-serial-digi_acceleport-Eliminate-a-NULL-pointer-derefere.patch:
  USB: serial: digi_acceleport: Eliminate a NULL pointer
  dereference.
- patches.drivers/USB3-0280-asix-check-packet-size-against-mtu-ETH_HLEN-instead-of-ETH_F.patch:
  asix: check packet size against mtu+ETH_HLEN instead of
  ETH_FRAME_LEN.
- patches.drivers/USB3-0281-hso-remove-setting-of-low_latency-flag.patch:
  hso: remove setting of low_latency flag.
- patches.drivers/USB3-0285-USB-xHCI-Fix-bug-in-link-TRB-activation-change.patch:
  USB: xHCI: Fix bug in link TRB activation change.
- patches.drivers/USB3-0291-USB-fix-oops-in-usb_sg_init.patch:
  USB: fix oops in usb_sg_init().
- patches.drivers/USB3-0292-USB-serial-ftdi-correct-merge-conflict-with-CONTEC-id.patch:
  USB: serial: ftdi: correct merge conflict with CONTEC id.
- patches.drivers/USB3-0295-USB-qcserial-fix-a-memory-leak-in-qcprobe-error-path.patch:
  USB: qcserial: fix a memory leak in qcprobe error path.
- patches.drivers/USB3-0304-net-Revert-rndis_host-Poll-status-channel-before-control-cha.patch:
  net: Revert "rndis_host: Poll status channel before control
  channel".
- patches.drivers/USB3-0305-usbnet-Set-parent-device-early-for-netdev_printk.patch:
  usbnet: Set parent device early for netdev_printk().
- patches.drivers/USB3-0314-USB-New-PIDs-for-Qualcomm-gobi-2000-qcserial.patch:
  USB: New PIDs for Qualcomm gobi 2000 (qcserial).
- patches.drivers/USB3-0316-USB-xHCI-Fix-another-bug-in-link-TRB-activation-change.patch:
  USB: xHCI: Fix another bug in link TRB activation change.
- patches.drivers/USB3-0317-USB-Fix-USB3.0-Port-Speed-Downgrade-after-port-reset.patch:
  USB: Fix USB3.0 Port Speed Downgrade after port reset.
- patches.drivers/USB3-0318-USB-xhci-Set-EP0-dequeue-ptr-after-reset-of-configured-devic.patch:
  USB: xhci: Set EP0 dequeue ptr after reset of configured device.
- patches.drivers/USB3-0321-USB-xhci-Set-Mult-field-in-endpoint-context-correctly.patch:
  USB: xhci: Set Mult field in endpoint context correctly.
- patches.drivers/USB3-0322-USB-usb-storage-fix-initializations-of-urb-fields.patch:
  USB: usb-storage: fix initializations of urb fields.
* Fri Jul  1 2011 jeffm@suse.de
- patches.suse/kprobes-checks-probe-address-is-instruction-boudary-on-x86:
  Refresh.
- patches.suse/merge-d7a4b414eed51f1653bb05ebe84122bf9a7ae18b:
  Refresh.
* Fri Jul  1 2011 jeffm@suse.de
- patches.fixes/perf-fix-hw_breakpoint-dependancy.patch: Refresh.
* Fri Jul  1 2011 brogers@suse.com
- Fix issues with kvm backport (bnc#702133)
- patches.drivers/vhost_net-a-kernel-level-virtio-server.patch:
  Refresh.
- patches.suse/kvm-0001-KVM-SVM-Add-clean-bits-infrastructure-code.patch:
  Refresh.
- patches.suse/kvm-0001-KVM-SVM-Implement-infrastructure-for-TSC_RATE_MSR.patch:
  Refresh.
- patches.suse/kvm-0002-KVM-SVM-Add-clean-bit-for-intercetps-tsc-offset-a.patch:
  Refresh.
- patches.suse/kvm-0002-KVM-X86-Let-kvm-clock-report-the-right-tsc-frequency.patch:
  Refresh.
- patches.suse/kvm-0002-KVM-x86-fix-CR8-handling.patch: Refresh.
- patches.suse/kvm-0003-KVM-cleanup-emulate_instruction.patch:
  Refresh.
- patches.suse/kvm-0004-KVM-SVM-Add-clean-bit-for-the-ASID.patch:
  Refresh.
- patches.suse/kvm-0004-KVM-X86-Implement-call-back-to-propagate-virtual_tsc.patch:
  Refresh.
- patches.suse/kvm-0005-KVM-SVM-Add-clean-bit-for-interrupt-state.patch:
  Refresh.
- patches.suse/kvm-0005-KVM-SVM-enhance-MOV-CR-intercept-handler.patch:
  Refresh.
- patches.suse/kvm-0005-KVM-X86-Implement-userspace-interface-to-set-virtual.patch:
  Refresh.
- patches.suse/kvm-0006-KVM-SVM-Add-clean-bit-for-NPT-state.patch:
  Refresh.
- patches.suse/kvm-0006-KVM-SVM-enhance-mov-DR-intercept-handler.patch:
  Refresh.
- patches.suse/kvm-0007-KVM-SVM-Add-clean-bit-for-control-registers.patch:
  Refresh.
- patches.suse/kvm-0007-KVM-SVM-implement-enhanced-INVLPG-intercept.patch:
  Refresh.
- patches.suse/kvm-0008-KVM-SVM-Add-clean-bit-for-DR6-and-DR7.patch:
  Refresh.
- patches.suse/kvm-0008-KVM-SVM-copy-instruction-bytes-from-VMCB.patch:
  Refresh.
- patches.suse/kvm-0009-KVM-SVM-Add-clean-bit-for-GDT-and-IDT.patch:
  Refresh.
- patches.suse/kvm-0010-KVM-SVM-Add-clean-bit-for-Segements-and-CPL.patch:
  Refresh.
- patches.suse/kvm-0012-KVM-SVM-Add-clean-bit-for-LBR-state.patch:
  Refresh.
- patches.suse/kvm-KVM-Activate-fpu-on-clts.patch: Refresh.
- patches.suse/kvm-KVM-Add-accessor-for-reading-cr4-or-some-bits-of-c.patch:
  KVM: Add accessor for reading cr4 (or some bits of cr4)
  (FATE#311768).
- patches.suse/kvm-KVM-Allow-kvm_load_guest_fpu-even-when-vcpu-fpu.patch:
  KVM: Allow kvm_load_guest_fpu() even when !vcpu->fpu_active
  (FATE#311768).
- patches.suse/kvm-KVM-Drop-kvm_-load-put-_guest_fpu-exports.patch:
  KVM: Drop kvm_{load,put}_guest_fpu() exports (FATE#311768).
- patches.suse/kvm-KVM-Fix-xsave-and-xcr-save-restore-memory-leak.patch:
  Refresh.
- patches.suse/kvm-KVM-Lazify-fpu-activation-and-deactivation.patch:
  Refresh.
- patches.suse/kvm-KVM-Replace-read-accesses-of-vcpu-arch.cr0-by-an-a.patch:
  KVM: Replace read accesses of vcpu->arch.cr0 by an accessor
  (FATE#311768).
- patches.suse/kvm-KVM-SVM-Fix-SVM_CR0_SELECTIVE_MASK.patch:
  KVM: SVM: Fix SVM_CR0_SELECTIVE_MASK (FATE#311768).
- patches.suse/kvm-KVM-SVM-Initialize-fpu_active-in-init_vmcb.patch:
  KVM: SVM: Initialize fpu_active in init_vmcb() (FATE#311768).
- patches.suse/kvm-KVM-SVM-Lazy-fpu-with-npt.patch: KVM: SVM:
  Lazy fpu with npt (FATE#311768).
- patches.suse/kvm-KVM-SVM-Restore-unconditional-cr0-intercept-under.patch:
  KVM: SVM: Restore unconditional cr0 intercept under npt
  (FATE#311768).
- patches.suse/kvm-KVM-SVM-Selective-cr0-intercept.patch: KVM:
  SVM: Selective cr0 intercept (FATE#311768).
- patches.suse/kvm-KVM-Set-cr0.et-when-the-guest-writes-cr0.patch:
  KVM: Set cr0.et when the guest writes cr0 (FATE#311768).
- patches.suse/kvm-KVM-VMX-Allow-the-guest-to-own-some-cr0-bits.patch:
  KVM: VMX: Allow the guest to own some cr0 bits (FATE#311768).
- patches.suse/kvm-KVM-VMX-Avoid-writing-HOST_CR0-every-entry.patch:
  KVM: VMX: Avoid writing HOST_CR0 every entry.
- patches.suse/kvm-KVM-VMX-Enable-XSAVE-XRSTOR-for-guest.patch:
  Refresh.
- patches.suse/kvm-KVM-VMX-Give-the-guest-ownership-of-cr0.ts-when-th.patch:
  KVM: VMX: Give the guest ownership of cr0.ts when the fpu is
  active (FATE#311768).
- patches.suse/kvm-KVM-VMX-Inform-user-about-INTEL_TXT-dependency.patch:
  Refresh.
- patches.suse/kvm-KVM-VMX-Pass-cr0.mp-through-to-the-guest-when-the.patch:
  KVM: VMX: Pass cr0.mp through to the guest when the fpu is
  active (FATE#311768).
- patches.suse/kvm-KVM-VMX-Wire-up-.fpu_activate-callback.patch:
  KVM: VMX: Wire up .fpu_activate() callback (FATE#311768).
- patches.suse/kvm-KVM-x86-Enable-AVX-for-guest.patch: Refresh.
- patches.suse/kvm-KVM-x86-Use-FPU-API.patch: Refresh.
- patches.suse/kvm-KVM-x86-Use-unlazy_fpu-for-host-FPU.patch:
  Refresh.
- patches.suse/kvm-KVM-x86-XSAVE-XRSTOR-live-migration-support.patch:
  Refresh.
- patches.suse/kvm-x86-Export-FPU-API-for-KVM-use.patch: Refresh.
* Fri Jul  1 2011 jeffm@suse.com
- Refactored patches.suse/perf-0001-Single-patch-that-merges-f4c4176-into-sles11.patch into constituent patches:
  - patches.suse/events-harmonize-event-field-names-and-print-output-names:
    events: Harmonize event field names and print output names.
  - patches.suse/events-rename-trace_event_template-to-declare_event_class:
    events: Rename TRACE_EVENT_TEMPLATE() to DECLARE_EVENT_CLASS().
  - patches.suse/ftrace-add-kernel-command-line-graph-function-filtering:
    ftrace: add kernel command line graph function filtering.
  - patches.suse/ftrace-c-add-define-pr_fmtfmt-kbuild_modname-fmt:
    ftrace.c: Add #define pr_fmt(fmt) KBUILD_MODNAME ": " fmt.
  - patches.suse/ftrace-copy-ftrace_graph_filter-boot-param-using-strlcpy:
    ftrace: Copy ftrace_graph_filter boot param using strlcpy.
  - patches.suse/ftrace-fix-trace_add_event_call-to-initialize-list:
    ftrace: Fix trace_add_event_call() to initialize list.
  - patches.suse/ftrace-fix-trace_remove_event_call-to-lock-trace_event_mutex:
    ftrace: Fix trace_remove_event_call() to lock trace_event_mutex.
  - patches.suse/ftrace-rename-set_bootup_ftrace-into-set_cmdline_ftrace:
    ftrace: Rename set_bootup_ftrace into set_cmdline_ftrace.
  - patches.suse/function-graph-x86-replace-unbalanced-ret-with-jmp:
    function-graph/x86: Replace unbalanced ret with jmp.
  - patches.suse/hw-breakpoint-attribute-authorship-of-hw-breakpoint-related-files:
    hw-breakpoint: Attribute authorship of hw-breakpoint related
    files.
  - patches.suse/hw-breakpoint-move-asm-generic-hw_breakpoint-h-to-linux-hw_breakpoint-h:
    hw-breakpoint: Move asm-generic/hw_breakpoint.h to
    linux/hw_breakpoint.h.
  - patches.suse/hw-breakpoints-add-two-reserved-fields-for-future-extensions:
    hw-breakpoints: Add two reserved fields for future extensions.
  - patches.suse/hw-breakpoints-arbitrate-access-to-pmu-following-registers-constraints:
    hw-breakpoints: Arbitrate access to pmu following registers
    constraints.
  - patches.suse/hw-breakpoints-check-the-breakpoint-params-from-perf-tools:
    hw-breakpoints: Check the breakpoint params from perf tools.
  - patches.suse/hw-breakpoints-cleanup-hw-breakpoint-registers-before-kexec:
    hw-breakpoints: cleanup HW Breakpoint registers before kexec.
  - patches.suse/hw-breakpoints-drop-callback-and-task-parameters-from-modify-helper:
    hw-breakpoints: Drop callback and task parameters from modify
    helper.
  - patches.suse/hw-breakpoints-fix-broken-a-out-format-dump:
    hw-breakpoints: Fix broken a.out format dump.
  - patches.suse/hw-breakpoints-fix-broken-hw-breakpoint-sample-module:
    hw-breakpoints: Fix broken hw-breakpoint sample module.
  - patches.suse/hw-breakpoints-fix-build-on-perf-architectures:
    hw-breakpoints: Fix build on !perf architectures.
  - patches.suse/hw-breakpoints-fix-misordered-ifdef:
    hw-breakpoints: Fix misordered ifdef.
  - patches.suse/hw-breakpoints-fix-task-bound-breakpoint-slot-allocation:
    hw-breakpoints: Fix task-bound breakpoint slot allocation.
  - patches.suse/hw-breakpoints-fix-unused-function-in-off-case:
    hw-breakpoints: Fix unused function in off-case.
  - patches.suse/hw-breakpoints-ftrace-plugin-for-kernel-symbol-tracing-using-hw-breakpoint-interfaces:
    hw-breakpoints: ftrace plugin for kernel symbol tracing using
    HW Breakpoint interfaces.
  - patches.suse/hw-breakpoints-handle-bad-modify_user_hw_breakpoint-off-case-return-value:
    hw-breakpoints: Handle bad modify_user_hw_breakpoint off-case
    return value.
  - patches.suse/hw-breakpoints-improve-in-kernel-event-creation-error-granularity:
    hw-breakpoints: Improve in-kernel event creation error
    granularity.
  - patches.suse/hw-breakpoints-include-only-linux-perf_event-h-from-kernel-part-of-bp-headers:
    hw-breakpoints: Include only linux/perf_event.h from kernel
    part of bp headers.
  - patches.suse/hw-breakpoints-introducing-generic-hardware-breakpoint-handler-interfaces:
    hw-breakpoints: introducing generic hardware breakpoint
    handler interfaces.
  - patches.suse/hw-breakpoints-keep-track-of-user-disabled-breakpoints:
    hw-breakpoints: Keep track of user disabled breakpoints.
  - patches.suse/hw-breakpoints-modify-breakpoints-without-unregistering-them:
    hw-breakpoints: Modify breakpoints without unregistering them.
  - patches.suse/hw-breakpoints-modify-ptrace-routines-to-access-breakpoint-registers:
    hw-breakpoints: modify Ptrace routines to access breakpoint
    registers.
  - patches.suse/hw-breakpoints-modify-signal-handling-code-to-refrain-from-re-enabling-hw-breakpoints:
    hw-breakpoints: modify signal handling code to refrain from
    re-enabling HW Breakpoints.
  - patches.suse/hw-breakpoints-modifying-generic-debug-exception-to-use-thread-specific-debug-registers:
    hw-breakpoints: modifying generic debug exception to use
    thread-specific debug registers.
  - patches.suse/hw-breakpoints-prepare-the-code-for-hardware-breakpoint-interfaces:
    hw-breakpoints: prepare the code for Hardware Breakpoint
    interfaces.
  - patches.suse/hw-breakpoints-provide-an-off-case-for-counter_arch_bp:
    hw-breakpoints: Provide an off-case for counter_arch_bp().
  - patches.suse/hw-breakpoints-remove-x86-specific-headers-from-core-file:
    hw-breakpoints: Remove x86 specific headers from core file.
  - patches.suse/hw-breakpoints-reset-bits-in-dr6-after-the-corresponding-exception-is-handled:
    hw-breakpoints: reset bits in dr6 after the corresponding
    exception is handled.
  - patches.suse/hw-breakpoints-rewrite-the-hw-breakpoints-layer-on-top-of-perf-events:
    hw-breakpoints: Rewrite the hw-breakpoints layer on top of
    perf events.
  - patches.suse/hw-breakpoints-sample-hw-breakpoint-over-kernel-data-address:
    hw-breakpoints: sample HW breakpoint over kernel data address.
  - patches.suse/hw-breakpoints-separate-the-kernel-part-from-breakpoint-headers:
    hw-breakpoints: Separate the kernel part from breakpoint
    headers.
  - patches.suse/hw-breakpoints-simplify-error-handling-in-breakpoint-creation-requests:
    hw-breakpoints: Simplify error handling in breakpoint creation
    requests.
  - patches.suse/hw-breakpoints-use-overflow-handler-instead-of-the-event-callback:
    hw-breakpoints: Use overflow handler instead of the event
    callback.
  - patches.suse/hw-breakpoints-use-struct-perf_event_attr-to-define-kernel-breakpoints:
    hw-breakpoints: Use struct perf_event_attr to define kernel
    breakpoints.
  - patches.suse/hw-breakpoints-use-struct-perf_event_attr-to-define-user-breakpoints:
    hw-breakpoints: Use struct perf_event_attr to define user
    breakpoints.
  - patches.suse/hw-breakpoints-use-the-new-wrapper-routines-to-access-debug-registers-in-process-thread-code:
    hw-breakpoints: use the new wrapper routines to access debug
    registers in process/thread code.
  - patches.suse/hw-breakpoints-wrap-in-the-kvm-breakpoint-active-state-check:
    hw-breakpoints: Wrap in the KVM breakpoint active state check.
  - patches.suse/hw-breakpoints-x86-architecture-implementation-of-hardware-breakpoint-interfaces:
    hw-breakpoints: x86 architecture implementation of Hardware
    Breakpoint interfaces.
  - patches.suse/hw-breakpoints-x86-fix-modular-kvm-build:
    hw-breakpoints, x86: Fix modular KVM build.
  - patches.suse/hw-breakpoints-zeroe-the-breakpoint-attrs-on-initialization:
    hw-breakpoints: Zeroe the breakpoint attrs on initialization.
  - patches.suse/kernel-hw_breakpoint-c-fix-local-global-shadowing:
    kernel/hw_breakpoint.c: Fix local/global shadowing.
  - patches.suse/kprobe-tracer-compare-both-of-event-name-and-event-group-to-find-probe:
    kprobe-tracer: Compare both of event-name and event-group to
    find probe.
  - patches.suse/kprobes-checks-probe-address-is-instruction-boudary-on-x86:
    kprobes: Checks probe address is instruction boudary on x86.
  - patches.suse/kprobes-cleanup-fix_riprel-using-insn-decoder-on-x86:
    kprobes: Cleanup fix_riprel() using insn decoder on x86.
  - patches.suse/kprobes-fix-to-add-__kprobes-to-notify_die:
    kprobes: Fix to add __kprobes to notify_die.
  - patches.suse/kprobes-prevent-re-registration-of-the-same-kprobe:
    kprobes: Prevent re-registration of the same kprobe.
  - patches.suse/kprobes-prohibit-to-probe-native_get_debugreg:
    kprobes: Prohibit to probe native_get_debugreg.
  - patches.suse/kprobes-x86-32-move-irq-exit-functions-to-kprobes-section:
    kprobes/x86-32: Move irq-exit functions to kprobes section.
  - patches.suse/kprobes-x86-64-allow-to-reenter-probe-on-post_handler:
    kprobes/x86-64: Allow to reenter probe on post_handler.
  - patches.suse/kprobes-x86-64-fix-to-move-common_interrupt-to-kprobes-text:
    kprobes/x86-64: Fix to move common_interrupt to .kprobes.text.
  - patches.suse/kprobes-x86-call-bug-when-reentering-probe-into-kprobes_hit_ss:
    kprobes/x86: Call BUG() when reentering probe into
    KPROBES_HIT_SS.
  - patches.suse/kprobes-x86-fix-to-add-__kprobes-to-in-kernel-fault-handing-functions:
    kprobes/x86: Fix to add __kprobes to in-kernel fault handing
    functions.
  - patches.suse/ksym_tracer-extract-trace-entry-from-struct-trace_ksym:
    ksym_tracer: Extract trace entry from struct trace_ksym.
  - patches.suse/ksym_tracer-fix-breakpoint-removal-after-modification:
    ksym_tracer: Fix breakpoint removal after modification.
  - patches.suse/ksym_tracer-fix-memory-leak: ksym_tracer: Fix
    memory leak.
  - patches.suse/ksym_tracer-fix-the-output-of-stat-tracing:
    ksym_tracer: Fix the output of stat tracing.
  - patches.suse/ksym_tracer-fix-validation-of-access-type:
    ksym_tracer: Fix validation of access type.
  - patches.suse/ksym_tracer-fix-validation-of-length-of-access-type:
    ksym_tracer: Fix validation of length of access type.
  - patches.suse/ksym_tracer-nil-terminate-user-input-filter:
    ksym_tracer: NIL-terminate user input filter.
  - patches.suse/ksym_tracer-remove-ksym_selftest_entry:
    ksym_tracer: Remove KSYM_SELFTEST_ENTRY.
  - patches.suse/ksym_tracer-report-error-when-failed-to-re-register-hbp:
    ksym_tracer: Report error when failed to re-register hbp.
  - patches.suse/ksym_tracer-rewrite-ksym_trace_filter_read:
    ksym_tracer: Rewrite ksym_trace_filter_read().
  - patches.suse/ksym_tracer-support-read-accesses-independent-of-read-write:
    ksym_tracer: Support read accesses independent of read/write.
  - patches.suse/last-patch:
  - patches.suse/mce-edac-use-an-atomic-notifier-for-mces-decoding:
    mce, edac: Use an atomic notifier for MCEs decoding.
  - patches.suse/merge-8f8ffe2485bcaa890800681451d380779cea06af:
    Merge commit 'tracing/core' into tracing/kprobes.
  - patches.suse/merge-d7a4b414eed51f1653bb05ebe84122bf9a7ae18b:
    Merge commit 'linus/master' into tracing/kprobes.
  - patches.suse/merge-eadb8a091b27a840de7450f84ecff5ef13476424:
    Merge branch 'linus' into tracing/hw-breakpoints.
  - patches.suse/merge-hw-breakpoints-rewrite-the-hw-breakpoints-layer-on-top-of-perf-events:
  - patches.suse/missing-merge: ksym: remove ksym_trace_entry.
  - patches.suse/perf-add-die_if-macro-for-error-checking: perf:
    Add DIE_IF() macro for error checking.
  - patches.suse/perf-add-kernel-side-syscall-events-support-for-breakpoints:
    perf: Add kernel side syscall events support for breakpoints.
  - patches.suse/perf-add-perf-kmem-tool: perf: Add 'perf kmem'
    tool.
  - patches.suse/perf-add-perf-probe-document: perf: Add perf-probe
    document.
  - patches.suse/perf-add-perf-probe-subcommand-a-kprobe-event-setup-helper:
    perf: Add perf probe subcommand, a kprobe-event setup helper.
  - patches.suse/perf-allow-for-custom-overflow-handlers: perf:
    Allow for custom overflow handlers.
  - patches.suse/perf-annotate-add-the-cmp_null-function-and-make-use-of-it:
    perf annotate: Add the cmp_null function and make use of it.
  - patches.suse/perf-annotate-fix-perf-data-parsing: perf annotate:
    Fix perf data parsing.
  - patches.suse/perf-annotate-remove-requirement-of-passing-a-symbol-name:
    perf annotate: Remove requirement of passing a symbol name.
  - patches.suse/perf-annotate-use-the-sym_priv_size-area-for-the-histogram:
    perf annotate: Use the sym_priv_size area for the histogram.
  - patches.suse/perf-bench-add-all-pseudo-subsystem-and-all-pseudo-suite:
    perf bench: Add "all" pseudo subsystem and "all" pseudo suite.
  - patches.suse/perf-bench-add-builtin-bench-c-general-framework-for-benchmark-suites:
    perf bench: Add builtin-bench.c: General framework for
    benchmark suites.
  - patches.suse/perf-bench-add-format-constants-to-bench-h-for-unified-output-formatting:
    perf bench: Add format constants to bench.h for unified output
    formatting.
  - patches.suse/perf-bench-add-memcpy-benchmark: perf bench:
    Add memcpy() benchmark.
  - patches.suse/perf-bench-add-new-directory-and-header-for-new-subcommand-bench:
    perf bench: Add new directory and header for new subcommand
    'bench'.
  - patches.suse/perf-bench-add-new-document-about-perf-bench:
    perf bench: Add new document about perf-bench.
  - patches.suse/perf-bench-add-new-subcommand-bench-to-perf-c:
    perf bench: Add new subcommand 'bench' to perf.c.
  - patches.suse/perf-bench-add-sched-messaging-c-benchmark-for-scheduler-and-ipc-mechanisms-based-on-hackbench:
    perf bench: Add sched-messaging.c: Benchmark for scheduler
    and IPC mechanisms based on hackbench.
  - patches.suse/perf-bench-add-sched-pipe-c-benchmark-for-pipe-system-call:
    perf bench: Add sched-pipe.c: Benchmark for pipe() system call.
  - patches.suse/perf-bench-add-subcommand-bench-to-the-makefile:
    perf bench: Add subcommand 'bench' to the Makefile.
  - patches.suse/perf-bench-clean-up-bench-bench-h: perf bench:
    Clean up bench/bench.h.
  - patches.suse/perf-bench-fix-bench-sched-pipe-c-to-wait-for-child-process:
    perf bench: Fix bench/sched-pipe.c to wait for child process.
  - patches.suse/perf-bench-improve-builtin-bench-c-for-more-friendly-output:
    perf bench: Improve builtin-bench.c for more friendly output.
  - patches.suse/perf-bench-improve-sched-message-c-with-more-comfortable-output:
    perf bench: Improve sched-message.c with more comfortable
    output.
  - patches.suse/perf-bench-improve-sched-pipe-c-with-more-comfortable-output:
    perf bench: Improve sched-pipe.c with more comfortable output.
  - patches.suse/perf-bench-make-the-mem-memcpy-tests-more-user-friendly:
    perf bench: Make the mem/memcpy tests more user-friendly.
  - patches.suse/perf-bench-modify-bench-bench-messaging-c-to-adopt-unified-output-formatting:
    perf bench: Modify bench/bench-messaging.c to adopt unified
    output formatting.
  - patches.suse/perf-bench-modify-builtin-bench-c-for-processing-common-options:
    perf bench: Modify builtin-bench.c for processing common
    options.
  - patches.suse/perf-bench-modify-builtin-h-for-new-prototype:
    perf bench: Modify builtin.h for new prototype.
  - patches.suse/perf-bench-modify-builtin-pipe-c-for-processing-common-options:
    perf bench: Modify builtin-pipe.c for processing common options.
  - patches.suse/perf-bench-modify-command-list-txt-for-the-entry-of-perf-bench:
    perf bench: Modify command-list.txt for the entry of perf-bench.
  - patches.suse/perf-buildid-list-always-show-the-dso-name:
    perf buildid-list: Always show the DSO name.
  - patches.suse/perf-buildid-list-fix-copy-n-paste-help-message:
    perf buildid-list: Fix copy'n'paste help message.
  - patches.suse/perf-buildid-list-new-plumbing-command: perf
    buildid-list: New plumbing command.
  - patches.suse/perf-check-libdwarf-apis-for-perf-probe: perf:
    Check libdwarf APIs for perf probe.
  - patches.suse/perf-clean-up-trivial-style-issues-in-builtin-help-c:
    perf: Clean up trivial style issues in builtin-help.c.
  - patches.suse/perf-core-add-a-callback-to-perf-events: perf/core:
    Add a callback to perf events.
  - patches.suse/perf-core-provide-a-kernel-internal-interface-to-get-to-performance-counters:
    perf/core: Provide a kernel-internal interface to get to
    performance counters.
  - patches.suse/perf-diff-change-the-default-sort-order-to-dso-symbol:
    perf diff: Change the default sort order to "dso,symbol".
  - patches.suse/perf-diff-fix-documentation: perf diff: Fix
    documentation.
  - patches.suse/perf-diff-improve-the-help-text: perf diff:
    Improve the help text.
  - patches.suse/perf-diff-introduce-tool-to-show-performance-difference:
    perf diff: Introduce tool to show performance difference.
  - patches.suse/perf-diff-percent-calcs-should-use-double-values:
    perf diff: Percent calcs should use double values.
  - patches.suse/perf-diff-use-perf_session__fprintf_hists-just-like-perf-record:
    perf diff: Use perf_session__fprintf_hists just like 'perf
    record'.
  - patches.suse/perf-events-allow-per-task-per-cpu-counters:
    perf events: Allow per-task-per-cpu counters.
  - patches.suse/perf-events-do-not-generate-function-trace-entries-in-perf-code:
    perf events: Do not generate function trace entries in perf
    code.
  - patches.suse/perf-events-hw_breakpoints-don-t-include-asm-hw_breakpoint-h-in-user-space:
    perf events: hw_breakpoints: Don't include asm/hw_breakpoint.h
    in user space.
  - patches.suse/perf-fix-event-scaling-for-inherited-counters:
    perf: Fix event scaling for inherited counters.
  - patches.suse/perf-fix-locking-for-perf_format_group: perf:
    Fix locking for PERF_FORMAT_GROUP.
  - patches.suse/perf-fix-perf_format_group-scale-info: perf:
    Fix PERF_FORMAT_GROUP scale info.
  - patches.suse/perf-fix-time-locking: perf: Fix time locking.
  - patches.suse/perf-hw_breakpoints-fix-percpu-namespace-clash:
    perf: hw_breakpoints: Fix percpu namespace clash.
  - patches.suse/perf-kmem-add-help-file: perf kmem: Add help file.
  - patches.suse/perf-kmem-add-new-option-to-show-raw-ip: perf kmem:
    Add new option to show raw ip.
  - patches.suse/perf-kmem-add-sort-hit-and-sort-frag: perf kmem:
    Add --sort hit and --sort frag.
  - patches.suse/perf-kmem-collect-cross-node-allocation-statistics:
    perf kmem: Collect cross node allocation statistics.
  - patches.suse/perf-kmem-default-to-sort-by-fragmentation:
    perf kmem: Default to sort by fragmentation.
  - patches.suse/perf-kmem-fix-unused-argument-build-warning:
    perf kmem: Fix unused argument build warning.
  - patches.suse/perf-kmem-measure-kmalloc-kfree-cpu-ping-pong-call-sites:
    perf kmem: Measure kmalloc/kfree CPU ping-pong call-sites.
  - patches.suse/perf-kmem-resolve-symbols: perf kmem: Resolve
    symbols.
  - patches.suse/perf-kmem-show-usage-if-no-option-is-specified:
    perf kmem: Show usage if no option is specified.
  - patches.suse/perf-make-common-sample_event-parser: perf:
    Make common SAMPLE_EVENT parser.
  - patches.suse/perf-optimize-__perf_event_read: perf: Optimize
    __perf_event_read().
  - patches.suse/perf-optimize-perf_event_comm_ctx: perf: Optimize
    perf_event_comm_ctx().
  - patches.suse/perf-optimize-perf_event_mmap_ctx: perf: Optimize
    perf_event_mmap_ctx().
  - patches.suse/perf-optimize-perf_event_task_ctx: perf: Optimize
    perf_event_task_ctx().
  - patches.suse/perf-optimize-perf_event_task_sched_out: perf:
    Optimize perf_event_task_sched_out.
  - patches.suse/perf-optimize-perf_swevent_ctx_event: perf:
    Optimize perf_swevent_ctx_event().
  - patches.suse/perf-optimize-some-swcounter-attr-sample_period-1-paths:
    perf: Optimize some swcounter attr.sample_period==1 paths.
  - patches.suse/perf-probe-add-argv_split-from-lib-argv_split-c:
    perf probe: Add argv_split() from lib/argv_split.c.
  - patches.suse/perf-probe-add-glob-matching-support-on-del:
    perf probe: Add glob matching support on --del.
  - patches.suse/perf-probe-add-list-option-for-listing-current-probe-events:
    perf probe: Add --list option for listing current probe events.
  - patches.suse/perf-probe-add-perf-probe-command-support-without-libdwarf:
    perf probe: Add perf probe command support without libdwarf.
  - patches.suse/perf-probe-add-probe-finder-h-without-libdwarf:
    perf probe: Add probe-finder.h without libdwarf.
  - patches.suse/perf-probe-annotate-variable-initialization:
    perf probe: Annotate variable initialization.
  - patches.suse/perf-probe-change-a-debugging-message-from-pr_info-to-pr_debug:
    perf probe: Change a debugging message from pr_info to pr_debug.
  - patches.suse/perf-probe-change-event-list-format: perf probe:
    Change event list format.
  - patches.suse/perf-probe-change-probe-added-message-more-user-friendly:
    perf probe: Change probe-added message more user-friendly.
  - patches.suse/perf-probe-check-build-id-of-vmlinux: perf probe:
    Check build-id of vmlinux.
  - patches.suse/perf-probe-check-e_snprintf-format-string: perf
    probe: Check e_snprintf() format string.
  - patches.suse/perf-probe-check-hyphen-only-argument: perf probe:
    Check hyphen only argument.
  - patches.suse/perf-probe-check-symbols-in-symtab-kallsyms:
    perf probe: Check symbols in symtab/kallsyms.
  - patches.suse/perf-probe-check-the-result-of-e_snprintf: perf
    probe: Check the result of e_snprintf().
  - patches.suse/perf-probe-cleanup-struct-session-in-builtin-probe-c:
    perf probe: Cleanup struct session in builtin-probe.c.
  - patches.suse/perf-probe-fix-add-probe-command-syntax-without-add-option:
    perf probe: Fix add-probe command syntax without --add option.
  - patches.suse/perf-probe-fix-argv-array-size-in-probe-parser:
    perf probe: Fix argv array size in probe parser.
  - patches.suse/perf-probe-fix-del-to-show-info-instead-of-warning:
    perf probe: Fix --del to show info instead of warning.
  - patches.suse/perf-probe-fix-del-to-update-current-event-list:
    perf probe: Fix --del to update current event list.
  - patches.suse/perf-probe-fix-event-namelist-to-duplicate-string:
    perf probe: Fix event namelist to duplicate string.
  - patches.suse/perf-probe-fix-probe-array-index-for-multiple-probe-points:
    perf probe: Fix probe array index for multiple probe points.
  - patches.suse/perf-probe-fix-strtailcmp-to-compare-s1and-s20:
    perf probe: Fix strtailcmp() to compare s1and s2.
  - patches.suse/perf-probe-fix-to-show-which-probe-point-is-not-found:
    perf probe: Fix to show which probe point is not found.
  - patches.suse/perf-probe-move-probe-event-utility-functions-to-probe-event-c:
    perf probe: Move probe event utility functions to probe-event.c.
  - patches.suse/perf-probe-print-debug-messages-using-pr_: perf
    probe: Print debug messages using pr_*().
  - patches.suse/perf-probe-reject-second-attempt-of-adding-same-name-event:
    perf probe: Reject second attempt of adding same-name event.
  - patches.suse/perf-probe-remove-event-suffix-number-_0: perf
    probe: Remove event suffix number _0.
  - patches.suse/perf-probe-show-need-dwarf-message-only-if-it-is-really-needed:
    perf probe: Show need-dwarf message only if it is really needed.
  - patches.suse/perf-probe-simplify-event-naming: perf probe:
    Simplify event naming.
  - patches.suse/perf-probe-support-del-option: perf probe:
    Support --del option.
  - patches.suse/perf-probe-support-event-name-for-add-option:
    perf probe: Support event name for --add option.
  - patches.suse/perf-probe-support-vmlinux-on-cwd-by-default:
    perf probe: Support vmlinux on cwd by default.
  - patches.suse/perf-probe-update-perf-probe-document: perf probe:
    Update perf-probe document.
  - patches.suse/perf-probe-use-pr_debug-for-debug-message: perf
    probe: Use pr_debug for debug message.
  - patches.suse/perf-probe-use-strlist__for_each-macros-in-probe-event-c:
    perf probe: Use strlist__for_each macros in probe-event.c.
  - patches.suse/perf-probes-exit-searching-after-finding-target-function:
    perf/probes: Exit searching after finding target function.
  - patches.suse/perf-probes-fall-back-to-non-dwarf-if-possible:
    perf/probes: Fall back to non-dwarf if possible.
  - patches.suse/perf-probes-improve-command-line-option-of-perf-probe:
    perf/probes: Improve command-line option of perf-probe.
  - patches.suse/perf-probes-improve-error-messages: perf/probes:
    Improve error messages.
  - patches.suse/perf-probes-improve-probe-point-syntax-of-perf-probe:
    perf/probes: Improve probe point syntax of perf-probe.
  - patches.suse/perf-probes-rename-perf-probe-events-group-name:
    perf/probes: Rename perf probe events group name.
  - patches.suse/perf-probes-support-function-entry-relative-line-number:
    perf/probes: Support function entry relative line number.
  - patches.suse/perf-probes-update-documentation-perf-probe-txt:
    perf/probes: Update Documentation/perf-probe.txt.
  - patches.suse/perf-record-fix-race-where-process-can-disappear-while-reading-its-proc-pid-tasks:
    perf record: Fix race where process can disappear while reading
    its /proc/pid/tasks.
  - patches.suse/perf-record-rename-perf-data-to-perf-data-old-if-force-f-is-used:
    perf record: Rename perf.data to perf.data.old if --force/-f
    is used.
  - patches.suse/perf-record-x86-print-more-intelligent-error-message-when-sampling-fails:
    perf record, x86: Print more intelligent error message when
    sampling fails.
  - patches.suse/perf-remove-pointless-union-that-wraps-the-hw-breakpoint-fields:
    perf: Remove pointless union that wraps the hw breakpoint
    fields.
  - patches.suse/perf-remove-the-event-callback-from-perf-events:
    perf: Remove the "event" callback from perf events.
  - patches.suse/perf-remove-unused-struct-perf_event-event_callback:
    perf: Remove unused struct perf_event::event_callback.
  - patches.suse/perf-report-do-map-lookups-in-resolve_callchain:
    perf report: Do map lookups in resolve_callchain().
  - patches.suse/perf-report-fix-cut-n-paste-error-recently-introduced:
    perf report: Fix cut'n'paste error recently introduced.
  - patches.suse/perf-report-generalize-perf_session__fprintf_hists:
    perf report: Generalize perf_session__fprintf_hists().
  - patches.suse/perf-report-use-kernel_maps__find_symbol-as-fallback-to-find-vdsos-etc:
    perf report: Use kernel_maps__find_symbol as fallback to find
    vdsos, etc.
  - patches.suse/perf-sched-add-c-option-to-measure-on-a-specific-cpu:
    perf sched: Add -C option to measure on a specific CPU.
  - patches.suse/perf-sched-add-max-delay-time-snapshot: perf sched:
    Add max delay time snapshot.
  - patches.suse/perf-sched-fix-build-failure-on-sparc: perf sched:
    Fix build failure on sparc.
  - patches.suse/perf-sched-fix-for-getting-task-s-execution-time:
    perf sched: Fix for getting task's execution time.
  - patches.suse/perf-sched-fix-perf-sched-trace: perf/sched: Fix
    'perf sched trace'.
  - patches.suse/perf-sched-remove-dead-code: perf sched: Remove
    dead code.
  - patches.suse/perf-scripting-fix-build: perf scripting:
    Fix build.
  - patches.suse/perf-session-adopt-resolve_callchain: perf session:
    Adopt resolve_callchain.
  - patches.suse/perf-session-adopt-the-sample_type-variable:
    perf session: Adopt the sample_type variable.
  - patches.suse/perf-session-ditch-register_perf_file_handler:
    perf session: Ditch register_perf_file_handler.
  - patches.suse/perf-session-event-statistics-also-are-per-session:
    perf session: Event statistics also are per session.
  - patches.suse/perf-session-move-kmaps-to-perf_session: perf
    session: Move kmaps to perf_session.
  - patches.suse/perf-session-move-perf-report-specific-hits-out-of-perf_session__fprintf_hists:
    perf session: Move perf report specific hits out of
    perf_session__fprintf_hists.
  - patches.suse/perf-session-move-the-global-threads-list-to-perf_session:
    perf session: Move the global threads list to perf_session.
  - patches.suse/perf-session-move-the-hist_entries-rb-tree-to-perf_session:
    perf session: Move the hist_entries rb tree to perf_session.
  - patches.suse/perf-session-pass-the-perf_session-to-the-event-handling-operations:
    perf session: Pass the perf_session to the event handling
    operations.
  - patches.suse/perf-session-reduce-the-number-of-parms-to-perf_session__process_events:
    perf session: Reduce the number of parms to
    perf_session__process_events.
  - patches.suse/perf-session-register-the-idle-thread-in-perf_session__process_events:
    perf session: Register the idle thread in
    perf_session__process_events.
  - patches.suse/perf-simplify-__perf_event_read: perf: Simplify
    __perf_event_read.
  - patches.suse/perf-simplify-__perf_event_sync_stat: perf:
    Simplify __perf_event_sync_stat.
  - patches.suse/perf-stat-add-branch-performance-events-to-default-output:
    perf stat: Add branch performance events to default output.
  - patches.suse/perf-stat-add-branch-performance-metric: perf stat:
    Add branch performance metric.
  - patches.suse/perf-stat-count-branches-first: perf stat: Count
    branches first.
  - patches.suse/perf-stat-do-not-print-ratio-when-task-clock-event-is-not-counted:
    perf stat: Do not print ratio when task-clock event is not
    counted.
  - patches.suse/perf-stat-re-align-the-default_attrs-array:
    perf stat: Re-align the default_attrs array.
  - patches.suse/perf-symbols-add-a-long_name_len-member-to-struct-dso:
    perf symbols: Add a long_name_len member to struct dso.
  - patches.suse/perf-symbols-add-a-type-field-to-struct-map:
    perf symbols: Add a 'type' field to struct map.
  - patches.suse/perf-symbols-add-missing-variables-entry-to-map_type__name:
    perf symbols: Add missing "Variables" entry to map_type__name.
  - patches.suse/perf-symbols-add-support-for-variable-symtabs:
    perf symbols: Add support for 'variable' symtabs.
  - patches.suse/perf-symbols-adopt-the-strlists-for-dso-comm:
    perf symbols: Adopt the strlists for dso, comm.
  - patches.suse/perf-symbols-allow-lookups-by-symbol-name-too:
    perf symbols: Allow lookups by symbol name too.
  - patches.suse/perf-symbols-avoid-annoying-message-about-loading-symbols:
    perf symbols: Avoid annoying message about loading symbols.
  - patches.suse/perf-symbols-better-support-for-multiple-symbol-tables-per-dso:
    perf symbols: Better support for multiple symbol tables per dso.
  - patches.suse/perf-symbols-call-the-symbol-filter-in-dso__synthesize_plt_symbols:
    perf symbols: Call the symbol filter in
    dso__synthesize_plt_symbols().
  - patches.suse/perf-symbols-capture-the-running-kernel-buildid-too:
    perf symbols: Capture the running kernel buildid too.
  - patches.suse/perf-symbols-change-the-kernel-dso-name-if-it-comes-from-kallsyms:
    perf symbols: Change the kernel DSO name if it comes from
    kallsyms.
  - patches.suse/perf-symbols-check-vmlinux-buildid: perf symbols:
    Check vmlinux buildid.
  - patches.suse/perf-symbols-ditch-dso-find_symbol: perf symbols:
    Ditch dso->find_symbol.
  - patches.suse/perf-symbols-do-lazy-symtab-loading-for-the-kernel-modules-too:
    perf symbols: Do lazy symtab loading for the kernel &
    modules too.
  - patches.suse/perf-symbols-dsos__read_build_ids-should-read-both-user-and-kernel-buildids:
    perf symbols: dsos__read_build_ids() should read both user
    and kernel buildids.
  - patches.suse/perf-symbols-factor-out-buildid-reading-routine:
    perf symbols: Factor out buildid reading routine.
  - patches.suse/perf-symbols-filename__read_build_id-should-look-at-notes-section-too:
    perf symbols: Filename__read_build_id should look at .notes
    section too.
  - patches.suse/perf-symbols-fix-comparision-of-build_ids: perf
    symbols: Fix comparision of build_ids.
  - patches.suse/perf-symbols-fix-elf-header-errors-during-perf-kmem-record:
    perf symbols: Fix ELF header errors during "perf kmem record".
  - patches.suse/perf-symbols-fixup-kernel_maps__fixup_end-end-map:
    perf symbols: Fixup kernel_maps__fixup_end end map.
  - patches.suse/perf-symbols-initialize-dso-loaded: perf symbols:
    Initialize dso->loaded.
  - patches.suse/perf-symbols-introduce-dso__build_id_equal:
    perf symbols: Introduce dso__build_id_equal.
  - patches.suse/perf-symbols-introduce-elf-counterparts-to-symbol_type__is_a:
    perf symbols: Introduce ELF counterparts to symbol_type__is_a.
  - patches.suse/perf-symbols-introduce-symbol_type__is_a: perf
    symbols: Introduce symbol_type__is_a.
  - patches.suse/perf-symbols-kernel_maps-should-be-an-array-of-map__nr_types-entries:
    perf symbols: Kernel_maps should be an array of MAP__NR_TYPES
    entries.
  - patches.suse/perf-symbols-kill-struct-build_id_list-and-die-another-day:
    perf symbols: Kill struct build_id_list and die() another day.
  - patches.suse/perf-symbols-look-for-vmlinux-in-more-places:
    perf symbols: Look for vmlinux in more places.
  - patches.suse/perf-symbols-make-symbol_conf-global: perf symbols:
    Make symbol_conf global.
  - patches.suse/perf-symbols-make-the-kallsyms-loading-routines-part-of-the-dso-class:
    perf symbols: Make the kallsyms loading routines part of the
    dso class.
  - patches.suse/perf-symbols-move-symbol-filtering-to-event__preprocess_sample:
    perf symbols: Move symbol filtering to
    event__preprocess_sample().
  - patches.suse/perf-symbols-old-versions-of-elf-h-don-t-have-nt_gnu_build_id:
    perf symbols: Old versions of elf.h don't have NT_GNU_BUILD_ID.
  - patches.suse/perf-symbols-pass-the-offset-to-perf_header__read_build_ids:
    perf symbols: Pass the offset to perf_header__read_build_ids().
  - patches.suse/perf-symbols-perf_header__read_build_ids-offset-n-size-should-be-u64:
    perf symbols: perf_header__read_build_ids() offset'n'size
    should be u64.
  - patches.suse/perf-symbols-record-the-build_ids-of-kernel-modules-too:
    perf symbols: Record the build_ids of kernel modules too.
  - patches.suse/perf-symbols-remove-unrelated-actions-from-dso__load_kernel_sym:
    perf symbols: Remove unrelated actions from
    dso__load_kernel_sym.
  - patches.suse/perf-symbols-rename-find_symbol-routines-to-find_function:
    perf symbols: Rename find_symbol routines to find_function.
  - patches.suse/perf-symbols-rename-kernel_mapto-kernel_maps__functions:
    perf symbols: Rename kernel_mapto kernel_map__functions.
  - patches.suse/perf-symbols-rename-kthreads-to-kmaps-using-another-abstraction-for-it:
    perf symbols: Rename kthreads to kmaps, using another
    abstraction for it.
  - patches.suse/perf-symbols-show-messages-about-module-loading-only-if-verbose-1:
    perf symbols: Show messages about module loading only if
    verbose >= 1.
  - patches.suse/perf-symbols-simplify-symbol-machinery-setup:
    perf symbols: Simplify symbol machinery setup.
  - patches.suse/perf-symbols-split-the-dsos-list-into-kernel-and-user-parts:
    perf symbols: Split the dsos list into kernel and user parts.
  - patches.suse/perf-symbols-support-multiple-symtabs-in-struct-thread:
    perf symbols: Support multiple symtabs in struct thread.
  - patches.suse/perf-symbols-unexport-kernel_map__functions:
    perf symbols: Unexport kernel_map__functions.
  - patches.suse/perf-symbols-use-the-buildids-if-present: perf
    symbols: Use the buildids if present.
  - patches.suse/perf-symbols-when-not-using-modules-discard-its-symbols:
    perf symbols: When not using modules, discard its symbols.
  - patches.suse/perf-timechart-add-a-process-filter: perf
    timechart: Add a process filter.
  - patches.suse/perf-timechart-fix-header-handling: perf timechart:
    Fix header handling.
  - patches.suse/perf-timechart-remove-open-coded-event-parsing-code:
    perf timechart: Remove open-coded event parsing code.
  - patches.suse/perf-tools-add-bunch-of-missing-headers-to-lib_h:
    perf tools: Add bunch of missing headers to LIB_H.
  - patches.suse/perf-tools-add-debugfs-utility-routines-for-perf:
    perf tools: Add debugfs utility routines for perf.
  - patches.suse/perf-tools-add-for_each-macros-for-strlist:
    perf tools: Add for_each macros for strlist.
  - patches.suse/perf-tools-add-ia64-support-for-tools-perf:
    perf tools: Add ia64 support for tools/perf/.
  - patches.suse/perf-tools-add-latency-format-to-trace-output:
    perf tools: Add latency format to trace output.
  - patches.suse/perf-tools-add-missing-tools-perf-util-include-string-h:
    perf tools: Add missing tools/perf/util/include/string.h.
  - patches.suse/perf-tools-add-new-perf_atoll-function-to-parse-string-representing-size-in-bytes:
    perf tools: Add new perf_atoll() function to parse string
    representing size in bytes.
  - patches.suse/perf-tools-add-perf-data-to-gitignore: perf tools:
    Add perf.data to .gitignore.
  - patches.suse/perf-tools-add-signed-flag-setting-back-into-trace-event-parse-c:
    perf tools: Add 'signed' flag setting back into
    trace-event-parse.c.
  - patches.suse/perf-tools-add-support-for-breakpoint-events-in-perf-tools:
    perf tools: Add support for breakpoint events in perf tools.
  - patches.suse/perf-tools-add-unmap_ip-operation-to-struct-map:
    perf tools: Add ->unmap_ip operation to struct map.
  - patches.suse/perf-tools-align-long-options-which-have-no-short-forms:
    perf tools: Align long options which have no short forms.
  - patches.suse/perf-tools-allow-building-for-arm: perf tools:
    Allow building for ARM.
  - patches.suse/perf-tools-alpha-add-alpha-support-to-perf-h:
    perf tools, Alpha: Add Alpha support to perf.h.
  - patches.suse/perf-tools-bind-callchains-to-the-first-sort-dimension-column:
    perf tools: Bind callchains to the first sort dimension column.
  - patches.suse/perf-tools-bring-linear-set-of-section-headers-for-features:
    perf tools: Bring linear set of section headers for features.
  - patches.suse/perf-tools-consolidate-symbol-resolving-across-all-tools:
    perf tools: Consolidate symbol resolving across all tools.
  - patches.suse/perf-tools-correct-size-computation-in-tracepoint_id_to_path:
    perf tools: Correct size computation in tracepoint_id_to_path().
  - patches.suse/perf-tools-correct-size-given-to-memset: perf
    tools: Correct size given to memset.
  - patches.suse/perf-tools-create-maps-for-modules-when-processing-kallsyms:
    perf tools: Create maps for modules when processing kallsyms.
  - patches.suse/perf-tools-create-util-sort-and-use-it: perf tools:
    Create util/sort.and use it.
  - patches.suse/perf-tools-debug-h-needs-to-include-event-h-for-event_t:
    perf tools: Debug.h needs to include event.h for event_t.
  - patches.suse/perf-tools-default-to-1-khz-auto-sampling-freq-events:
    perf tools: Default to 1 KHz auto-sampling freq events.
  - patches.suse/perf-tools-delay-loading-symtabs-till-we-hit-a-map-with-it:
    perf tools: Delay loading symtabs till we hit a map with it.
  - patches.suse/perf-tools-do-not-manually-count-string-lengths:
    perf tools: Do not manually count string lengths.
  - patches.suse/perf-tools-don-t-die-in-do_write: perf tools:
    Don't die() in do_write().
  - patches.suse/perf-tools-don-t-die-in-mmap_dispatch_perf_file:
    perf tools: Don't die() in mmap_dispatch_perf_file.
  - patches.suse/perf-tools-don-t-die-in-perf_header__add_attr:
    perf tools: Don't die() in perf_header__add_attr().
  - patches.suse/perf-tools-don-t-die-in-perf_header__new: perf
    tools: Don't die() in perf_header__new().
  - patches.suse/perf-tools-don-t-die-in-perf_header_attr__add_id:
    perf tools: Don't die() in perf_header_attr__add_id().
  - patches.suse/perf-tools-don-t-die-in-perf_header_attr__new:
    perf tools: Don't die in perf_header_attr__new().
  - patches.suse/perf-tools-drop-asm-types-h-wrapper: perf tools:
    Drop asm/types.h wrapper.
  - patches.suse/perf-tools-eliminate-some-more-die-uses-in-library-functions:
    perf tools: Eliminate some more die() uses in library functions.
  - patches.suse/perf-tools-factor-out-the-map-initialization:
    perf tools: Factor out the map initialization.
  - patches.suse/perf-tools-fix-_gnu_source-macro-related-strndup-build-error:
    perf tools: Fix _GNU_SOURCE macro related strndup() build error.
  - patches.suse/perf-tools-fix-backslash-processing-on-trace-print-formats:
    perf tools: Fix backslash processing on trace print formats.
  - patches.suse/perf-tools-fix-bprintk-reading-in-trace-output:
    perf tools: Fix bprintk reading in trace output.
  - patches.suse/perf-tools-fix-compilation-on-powerpc: perf tools:
    Fix compilation on powerpc.
  - patches.suse/perf-tools-fix-counter-sample-frequency-breakage:
    perf tools: Fix counter sample frequency breakage.
  - patches.suse/perf-tools-fix-missing-symtabs-printouts: perf
    tools: Fix missing symtabs printouts.
  - patches.suse/perf-tools-fix-missing-top-level-callchain:
    perf tools: Fix missing top level callchain.
  - patches.suse/perf-tools-fix-syntax-in-documentation: perf tools:
    Fix syntax in documentation.
  - patches.suse/perf-tools-fix-thread-comm-resolution-in-perf-sched:
    perf tools: Fix thread comm resolution in perf sched.
  - patches.suse/perf-tools-generalize-event-synthesizing-routines:
    perf tools: Generalize event synthesizing routines.
  - patches.suse/perf-tools-generalize-perf_header__adds_read:
    perf tools: Generalize perf_header__adds_read().
  - patches.suse/perf-tools-handle-and-in-parsing-trace-print-format:
    perf tools: Handle - and + in parsing trace print format.
  - patches.suse/perf-tools-handle-arrays-in-print-fields-for-trace-parsing:
    perf tools: Handle arrays in print fields for trace parsing.
  - patches.suse/perf-tools-handle-as-typecast-in-trace-parsing:
    perf tools: Handle * as typecast in trace parsing.
  - patches.suse/perf-tools-handle-both-versions-of-ftrace-output:
    perf tools: Handle both versions of ftrace output.
  - patches.suse/perf-tools-handle-newlines-in-trace-parsing-better:
    perf tools: Handle newlines in trace parsing better.
  - patches.suse/perf-tools-handle-print-concatenations-in-event-format-file:
    perf tools: Handle print concatenations in event format file.
  - patches.suse/perf-tools-handle-the-case-with-and-without-the-signed-trace-field:
    perf tools: Handle the case with and without the "signed"
    trace field.
  - patches.suse/perf-tools-handle-trace-parsing-of-and: perf tools:
    Handle trace parsing of < and >.
  - patches.suse/perf-tools-improve-kernel-modules-symbol-lookup:
    perf tools: Improve kernel/modules symbol lookup.
  - patches.suse/perf-tools-improve-message-about-missing-symtabs-for-deleted-dsos:
    perf tools: Improve message about missing symtabs for deleted
    DSOs.
  - patches.suse/perf-tools-improve-thread-comm-resolution-in-perf-sched:
    perf tools: Improve thread comm resolution in perf sched.
  - patches.suse/perf-tools-introduce-bitmask-ed-additional-headers:
    perf tools: Introduce bitmask'ed additional headers.
  - patches.suse/perf-tools-introduce-dsos__fprintf_buildid:
    perf tools: Introduce dsos__fprintf_buildid.
  - patches.suse/perf-tools-introduce-perf_session-class: perf
    tools: Introduce perf_session class.
  - patches.suse/perf-tools-introduce-zalloc-for-the-common-calloc1-n-case:
    perf tools: Introduce zalloc() for the common calloc(1, N) case.
  - patches.suse/perf-tools-make-symbol_conf-static: perf tools:
    Make symbol_conf static.
  - patches.suse/perf-tools-merge-trace-info-content-into-perf-data:
    perf tools: Merge trace.info content into perf.data.
  - patches.suse/perf-tools-misc-small-fixes: perf tools: Misc
    small fixes.
  - patches.suse/perf-tools-modify-perf-routines-to-use-new-debugfs-routines:
    perf tools: Modify perf routines to use new debugfs routines.
  - patches.suse/perf-tools-move-dereference-after-null-test:
    perf tools: Move dereference after NULL test.
  - patches.suse/perf-tools-move-graph_line-and-graph_dotted_line-from-top:
    perf tools: Move graph_line and graph_dotted_line from top.
  - patches.suse/perf-tools-move-hist-entries-printing-routines-from-perf-report:
    perf tools: Move hist entries printing routines from perf
    report.
  - patches.suse/perf-tools-move-hist_entry__add-common-code-to-hist-c:
    perf tools: Move hist_entry__add common code to hist.c.
  - patches.suse/perf-tools-move-the-build-id-storage-operations-to-headers:
    perf tools: Move the build-id storage operations to headers.
  - patches.suse/perf-tools-move-threads-last_match-to-threads-c:
    perf tools: Move threads & last_match to threads.c.
  - patches.suse/perf-tools-no-need-for-three-rb_trees-for-sorting-hist-entries:
    perf tools: No need for three rb_trees for sorting hist entries.
  - patches.suse/perf-tools-notify-user-when-unrecognized-event-is-specified:
    perf tools: Notify user when unrecognized event is specified.
  - patches.suse/perf-tools-optimize-parse_subsystem_tracepoint_event:
    perf tools: Optimize parse_subsystem_tracepoint_event().
  - patches.suse/perf-tools-output-perf-list-to-stdout-not-stderr:
    perf tools: Output 'perf list' to stdout not stderr.
  - patches.suse/perf-tools-perf_header__read-shouldn-t-die:
    perf tools: perf_header__read() shouldn't die().
  - patches.suse/perf-tools-proc-modules-names-don-t-always-match-its-name:
    perf tools: /proc/modules names don't always match its name.
  - patches.suse/perf-tools-protect-header-files-with-a-consistent-style:
    perf tools: Protect header files with a consistent style.
  - patches.suse/perf-tools-provide-backward-compatibility-with-previous-perf-data-version:
    perf tools: Provide backward compatibility with previous
    perf.data version.
  - patches.suse/perf-tools-put-common-histogram-functions-in-their-own-file:
    perf tools: Put common histogram functions in their own file.
  - patches.suse/perf-tools-read-the-build-ids-from-the-header-layer:
    perf tools: Read the build-ids from the header layer.
  - patches.suse/perf-tools-remove-all-char-typecasts-and-use-const-in-prototype:
    perf tools: Remove all char * typecasts and use const in
    prototype.
  - patches.suse/perf-tools-remove-expensive-old-debug-code-from-perf-top:
    perf tools: Remove expensive old debug code from perf top.
  - patches.suse/perf-tools-remove-show_mask-bitmask: perf tools:
    Remove show_mask bitmask.
  - patches.suse/perf-tools-remove-unused-wrapper-routines: perf
    tools: Remove unused wrapper routines.
  - patches.suse/perf-tools-reorganize-event-processing-routines-lotsa-dups-killed:
    perf tools: Reorganize event processing routines, lotsa
    dups killed.
  - patches.suse/perf-tools-replace-m-with-a-in-sscanf: perf tools:
    Replace %%m with %%a in sscanf.
  - patches.suse/perf-tools-rewrite-and-improve-support-for-kernel-modules:
    perf tools: Rewrite and improve support for kernel modules.
  - patches.suse/perf-tools-simplify-the-symbol-priv-area-mechanism:
    perf tools: Simplify the symbol priv area mechanism.
  - patches.suse/perf-tools-split-up-build-id-saving-into-fetch-and-write:
    perf tools: Split up build id saving into fetch and write.
  - patches.suse/perf-tools-start-the-perf-data-mapping-at-data-offset-in-perf-trace:
    perf tools: Start the perf.data mapping at data offset in
    perf trace.
  - patches.suse/perf-tools-still-continue-on-failed-parsing-of-an-event:
    perf tools: Still continue on failed parsing of an event.
  - patches.suse/perf-tools-synthetize-the-targeted-process:
    perf tools: Synthetize the targeted process.
  - patches.suse/perf-tools-unify-debug-messages-mechanisms:
    perf tools: Unify debug messages mechanisms.
  - patches.suse/perf-tools-unify-perf-data-mapping-and-events-handling:
    perf tools: Unify perf.data mapping and events handling.
  - patches.suse/perf-tools-up-the-verbose-level-for-some-really-verbose-stuff:
    perf tools: Up the verbose level for some really verbose stuff.
  - patches.suse/perf-tools-use-common-process_event-functions-for-annotate-and-report:
    perf tools: Use common process_event functions for annotate
    and report.
  - patches.suse/perf-tools-use-declare_bitmap-instead-of-an-open-coded-array:
    perf tools: Use DECLARE_BITMAP instead of an open-coded array.
  - patches.suse/perf-tools-use-kernel-bitmap-library: perf tools:
    Use kernel bitmap library.
  - patches.suse/perf-tools-use-perf_header__set-has_feat-whenever-possible:
    perf tools: Use perf_header__set/has_feat whenever possible.
  - patches.suse/perf-tools-use-rb_tree-for-maps: perf tools:
    Use rb_tree for maps.
  - patches.suse/perf-tools-use-strsep-over-strtok_r-for-parsing-single-line:
    perf tools: Use strsep() over strtok_r() for parsing single
    line.
  - patches.suse/perf-top-allocate-space-only-for-the-number-of-counters-used:
    perf top: Allocate space only for the number of counters used.
  - patches.suse/perf-top-always-show-the-dso-column-even-if-its-all-the-same:
    perf top: Always show the DSO column, even if its all the same.
  - patches.suse/perf-top-auto-adjust-symbol-and-dso-widths:
    perf top: Auto adjust symbol and dso widths.
  - patches.suse/perf-top-don-t-allocate-the-source-parsing-members-upfront:
    perf top: Don't allocate the source parsing members upfront.
  - patches.suse/perf-top-fix-symbol-annotation: perf top: Fix
    symbol annotation.
  - patches.suse/perf-top-introduce-helper-function-to-access-symbol-from-sym_entry:
    perf top: Introduce helper function to access symbol from
    sym_entry.
  - patches.suse/perf-top-introduce-hide_-user-kernel-_symbols:
    perf top: Introduce --hide_{user,kernel}_symbols.
  - patches.suse/perf-top-keep-the-default-of-asking-for-kernel-module-symbols:
    perf top: Keep the default of asking for kernel module symbols.
  - patches.suse/perf-top-remove-dead-min-max-_ip-unused-variables:
    perf top: Remove dead {min,max}_ip unused variables.
  - patches.suse/perf-top-support-userspace-symbols-too: perf top:
    Support userspace symbols too.
  - patches.suse/perf-top-suppress-dso-column-if-only-one-is-present:
    perf top: Suppress DSO column if only one is present.
  - patches.suse/perf-top-use-all-the-lines-in-the-screen: perf top:
    Use all the lines in the screen.
  - patches.suse/perf-trace-add-a-scripts-perl-bin-for-perf-trace-shell-scripts:
    perf trace: Add a scripts/perl/bin for perf trace shell scripts.
  - patches.suse/perf-trace-add-documentation-for-perf-trace-perl-support:
    perf trace: Add Documentation for perf trace Perl support.
  - patches.suse/perf-trace-add-filter-suppport: perf trace:
    Add filter Suppport.
  - patches.suse/perf-trace-add-flag-symbolic-format_flags: perf
    trace: Add flag/symbolic format_flags.
  - patches.suse/perf-trace-add-interface-to-access-perf-data-from-perl-handlers:
    perf trace: Add interface to access perf data from Perl
    handlers.
  - patches.suse/perf-trace-add-perf-trace-scripting-support-modules-for-perl:
    perf trace: Add perf trace scripting support modules for Perl.
  - patches.suse/perf-trace-add-perl-scripting-support: perf trace:
    Add Perl scripting support.
  - patches.suse/perf-trace-add-scripting-ops: perf trace: Add
    scripting ops.
  - patches.suse/perf-trace-add-string-dynamic-cases-to-format_flags:
    perf trace: Add string/dynamic cases to format_flags.
  - patches.suse/perf-trace-add-subsystem-string-to-struct-event:
    perf trace: Add subsystem string to struct event.
  - patches.suse/perf-trace-read_tracing_data-should-die-another-day:
    perf trace: Read_tracing_data should die() another day.
  - patches.suse/perf-trace-remove-dead-code: perf trace: Remove
    dead code.
  - patches.suse/perf-trace-scripting-add-fedora-libperl-install-note-to-doc:
    perf trace/scripting: Add Fedora libperl install note to doc.
  - patches.suse/perf-trace-scripting-add-record-and-report-options:
    perf trace/scripting: Add 'record' and 'report' options.
  - patches.suse/perf-trace-scripting-add-support-for-script-args:
    perf trace/scripting: Add support for script args.
  - patches.suse/perf-trace-scripting-check-return-val-of-perl_run:
    perf trace/scripting: Check return val of perl_run().
  - patches.suse/perf-trace-scripting-don-t-display-scripting-unsupported-msg-unnecessarily:
    perf trace/scripting: Don't display 'scripting unsupported'
    msg unnecessarily.
  - patches.suse/perf-trace-scripting-don-t-install-unneeded-files:
    perf trace/scripting: Don't install unneeded files.
  - patches.suse/perf-trace-scripting-fix-compile-error-when-libperl-not-installed:
    perf trace/scripting: Fix compile error when libperl not
    installed.
  - patches.suse/perf-trace-scripting-fix-perl-common_-access-functions:
    perf trace/scripting: Fix Perl common_* access functions.
  - patches.suse/perf-trace-scripting-ignore-shadowed-variable-warning-for-perf-trace-perl-c:
    perf trace/scripting: Ignore shadowed variable warning for
    perf-trace-perl.c.
  - patches.suse/perf-trace-scripting-list-available-scripts:
    perf trace/scripting: List available scripts.
  - patches.suse/perf-trace-scripting-silence-perl_embed_-backtick-errors:
    perf trace/scripting: Silence PERL_EMBED_* backtick errors.
  - patches.suse/perf-trace-scripting-update-documentation: perf
    trace/scripting: Update Documentation.
  - patches.suse/perf-use-die-for-error-cases-in-perf-probe: perf:
    Use die() for error cases in perf-probe.
  - patches.suse/perf-use-eprintf-for-debug-messages-in-perf-probe:
    perf: Use eprintf() for debug messages in perf-probe.
  - patches.suse/perf-util-remove-setup_sorting-dups: perf util:
    Remove setup_sorting dups.
  - patches.suse/perf-x86-add-simple-group-validation: perf, x86:
    Add simple group validation.
  - patches.suse/perf_event-add-alignment-faults-and-emulation-faults-software-events:
    perf_event: Add alignment-faults and emulation-faults software
    events.
  - patches.suse/perf_event-allocate-children-s-perf_event_ctxp-at-the-right-time:
    perf_event: Allocate children's perf_event_ctxp at the right
    time.
  - patches.suse/perf_event-clean-up-__perf_event_init_context:
    perf_event: Clean up __perf_event_init_context().
  - patches.suse/perf_event-cleanup-for-cpu_clock_perf_event_update:
    perf_event: Cleanup for cpu_clock_perf_event_update().
  - patches.suse/perf_event-eliminate-raw-size: perf_event:
    Eliminate raw->size.
  - patches.suse/perf_event-fix-__dsos__write_buildid_table:
    perf_event: Fix __dsos__write_buildid_table().
  - patches.suse/perf_event-fix-compile-error: perf_event: Fix
    compile error.
  - patches.suse/perf_event-fix-perf_swevent_hrtimer-variable-initialization:
    perf_event: Fix perf_swevent_hrtimer() variable initialization.
  - patches.suse/perf_event-fix-raw-event-processing: perf_event:
    Fix raw event processing.
  - patches.suse/perf_event-fix-variable-initialization-in-other-codepaths:
    perf_event: Fix variable initialization in other codepaths.
  - patches.suse/perf_event-optimize-perf_output_lock: perf_event:
    Optimize perf_output_lock().
  - patches.suse/perf_event-remove-redundant-zero-fill: perf_event:
    Remove redundant zero fill.
  - patches.suse/perf_event-x86-annotate-init-functions-and-data:
    perf_event, x86: Annotate init functions and data.
  - patches.suse/perf_event-x86-mce-use-trace_event-for-mce-logging:
    perf_event, x86, mce: Use TRACE_EVENT() for MCE logging.
  - patches.suse/perf_events-add-event-constraints-support-for-intel-processors:
    perf_events: Add event constraints support for Intel processors.
  - patches.suse/perf_events-check-for-filters-on-fixed-counter-events:
    perf_events: Check for filters on fixed counter events.
  - patches.suse/perf_events-disable-events-when-we-detach-them:
    perf_events: Disable events when we detach them.
  - patches.suse/perf_events-fix-__perf_event_exit_task-vs-update_event_times-locking:
    perf_events: Fix __perf_event_exit_task()
    vs. update_event_times() locking.
  - patches.suse/perf_events-fix-bad-software-trace-event-recursion-counting:
    perf_events: Fix bad software/trace event recursion counting.
  - patches.suse/perf_events-fix-bogus-copy_to_user-in-perf_event_read_group:
    perf_events: Fix bogus copy_to_user() in
    perf_event_read_group().
  - patches.suse/perf_events-fix-default-watermark-calculation:
    perf_events: Fix default watermark calculation.
  - patches.suse/perf_events-fix-modular-build: perf_events:
    Fix modular build.
  - patches.suse/perf_events-fix-perf_event_attr-layout:
    perf_events: Fix perf_event_attr layout.
  - patches.suse/perf_events-fix-read-bogus-counts-when-in-error-state:
    perf_events: Fix read() bogus counts when in error state.
  - patches.suse/perf_events-fix-style-nits: perf_events: Fix
    style nits.
  - patches.suse/perf_events-optimize-the-swcounter-hotpath:
    perf_events: Optimize the swcounter hotpath.
  - patches.suse/perf_events-restore-sanity-to-scaling-land:
    perf_events: Restore sanity to scaling land.
  - patches.suse/perf_events-undo-copy-paste-damage: perf_events:
    Undo copy/paste damage.
  - patches.suse/perf_events-undo-some-recursion-damage:
    perf_events: Undo some recursion damage.
  - patches.suse/perf_events-update-the-context-time-on-exit:
    perf_events: Update the context time on exit.
  - patches.suse/perf_events-x86-fix-event-constraints-code:
    perf_events, x86: Fix event constraints code.
  - patches.suse/perf_events-x86-fix-validate_event-bug:
    perf_events, x86: Fix validate_event bug.
  - patches.suse/powerpc-create-ppc_warn_alignment-to-match-ppc_warn_emulated:
    powerpc: Create PPC_WARN_ALIGNMENT to match PPC_WARN_EMULATED.
  - patches.suse/powerpc-export-powerpc_debugfs_root: powerpc:
    Export powerpc_debugfs_root.
  - patches.suse/powerpc-perf_event-add-alignment-faults-and-emulation-faults-software-events:
    powerpc: perf_event: Add alignment-faults and emulation-faults
    software events.
  - patches.suse/powerpc-perf_event-cleanup-copy_page-output-by-hiding-setup-symbol:
    powerpc: perf_event: Cleanup copy_page output by hiding
    setup symbol.
  - patches.suse/powerpc-perf_event-cleanup-output-by-adding-symbols:
    powerpc: perf_event: Cleanup output by adding symbols.
  - patches.suse/powerpc-perf_event-hide-iseries_check_pending_irqs:
    powerpc: perf_event: Hide iseries_check_pending_irqs.
  - patches.suse/powerpc-tracing-add-hypervisor-call-tracepoints:
    powerpc: tracing: Add hypervisor call tracepoints.
  - patches.suse/powerpc-tracing-add-powerpc-tracepoints-for-interrupt-entry-and-exit:
    powerpc: tracing: Add powerpc tracepoints for interrupt entry
    and exit.
  - patches.suse/powerpc-tracing-add-powerpc-tracepoints-for-timer-entry-and-exit:
    powerpc: tracing: Add powerpc tracepoints for timer entry
    and exit.
  - patches.suse/powerpc-tracing-give-hypervisor-call-tracepoints-access-to-arguments:
    powerpc: tracing: Give hypervisor call tracepoints access
    to arguments.
  - patches.suse/revert-x86-apic-fix-spurious-error-interrupts-triggering-on-all-non-boot-aps:
    revert-x86, apic: Fix spurious error interrupts triggering on
    all non-boot APs.
  - patches.suse/revert-x86-under-bios-control-restore-ap-s-apic_lvtthmr-to-the-bsp-value:
    revert: x86: Under BIOS control, restore AP's APIC_LVTTHMR to
    the BSP value.
  - patches.suse/sched-mark-sched_clock-as-notrace: sched: Mark
    sched_clock() as notrace.
  - patches.suse/testmmiotrace-c-add-and-use-pr_fmtfmt:
    testmmiotrace.c: Add and use pr_fmt(fmt).
  - patches.suse/trace-kprobe-support-delete-probe-syntax:
    trace-kprobe: Support delete probe syntax.
  - patches.suse/trace-syscalls-change-ret-param-in-struct-syscall_trace_exit-to-long:
    trace/syscalls: Change ret param in struct syscall_trace_exit
    to long.
  - patches.suse/trace_kprobes-always-show-group-name:
    trace_kprobes: Always show group name.
  - patches.suse/trace_kprobes-don-t-output-zero-offset:
    trace_kprobes: Don't output zero offset.
  - patches.suse/trace_kprobes-fix-a-memory-leak-bug-and-check-kstrdup-return-value:
    trace_kprobes: Fix a memory leak bug and check kstrdup()
    return value.
  - patches.suse/trace_kprobes-fix-memory-leak: trace_kprobes:
    Fix memory leak.
  - patches.suse/trace_syscalls-add-syscall-nr-field:
    trace_syscalls: Add syscall nr field.
  - patches.suse/trace_syscalls-add-syscall_nr-field-to-struct-syscall_metadata:
    trace_syscalls: Add syscall_nr field to struct syscall_metadata.
  - patches.suse/trace_syscalls-remove-duplicate-init_enter_-sname:
    trace_syscalls: Remove duplicate init_enter_##sname().
  - patches.suse/trace_syscalls-remove-enter_id-exit_id:
    trace_syscalls: Remove enter_id exit_id.
  - patches.suse/trace_syscalls-remove-unused-event_syscall_enter-and-event_syscall_exit:
    trace_syscalls: Remove unused event_syscall_enter and
    event_syscall_exit.
  - patches.suse/trace_syscalls-remove-unused-syscall_name_to_nr:
    trace_syscalls: Remove unused syscall_name_to_nr().
  - patches.suse/trace_syscalls-set-event_enter_-sname-data-to-its-metadata:
    trace_syscalls: Set event_enter_##sname->data to its metadata.
  - patches.suse/trace_syscalls-simplify-syscall-profile:
    trace_syscalls: Simplify syscall profile.
  - patches.suse/tracepoint-add-signal-deliver-event: tracepoint:
    Add signal deliver event.
  - patches.suse/tracepoint-add-signal-loss-events: tracepoint:
    Add signal loss events.
  - patches.suse/tracepoint-move-signal-sending-tracepoint-to-events-signal-h:
    tracepoint: Move signal sending tracepoint to events/signal.h.
  - patches.suse/tracing-add-define_event-define_single_event-support-to-docbook:
    tracing: Add DEFINE_EVENT(), DEFINE_SINGLE_EVENT() support
    to docbook.
  - patches.suse/tracing-add-kprobe-based-event-tracer: tracing:
    Add kprobe-based event tracer.
  - patches.suse/tracing-add-kprobe-based-event-tracer-documentation:
    tracing: Add kprobe-based event tracer documentation.
  - patches.suse/tracing-add-kprobes-event-profiling-interface:
    tracing: Add kprobes event profiling interface.
  - patches.suse/tracing-bkl-add-bkl-ftrace-events: tracing/bkl:
    Add bkl ftrace events.
  - patches.suse/tracing-convert-module-refcnt-events-to-define_event:
    tracing: Convert module refcnt events to DEFINE_EVENT.
  - patches.suse/tracing-convert-softirq-events-to-define_event:
    tracing: Convert softirq events to DEFINE_EVENT.
  - patches.suse/tracing-convert-some-block-events-to-define_event:
    tracing: Convert some block events to DEFINE_EVENT.
  - patches.suse/tracing-convert-some-ext4-events-to-define_trace:
    tracing: Convert some ext4 events to DEFINE_TRACE.
  - patches.suse/tracing-convert-some-jbd2-events-to-define_event:
    tracing: Convert some jbd2 events to DEFINE_EVENT.
  - patches.suse/tracing-convert-some-kmem-events-to-define_event:
    tracing: Convert some kmem events to DEFINE_EVENT.
  - patches.suse/tracing-convert-some-power-events-to-define_event:
    tracing: Convert some power events to DEFINE_EVENT.
  - patches.suse/tracing-convert-some-sched-trace-events-to-define_event-and-_print:
    tracing: Convert some sched trace events to DEFINE_EVENT
    and _PRINT.
  - patches.suse/tracing-convert-some-workqueue-events-to-define_event:
    tracing: Convert some workqueue events to DEFINE_EVENT.
  - patches.suse/tracing-create-new-define_event_print: tracing:
    Create new DEFINE_EVENT_PRINT.
  - patches.suse/tracing-create-new-trace_event_template: tracing:
    Create new TRACE_EVENT_TEMPLATE.
  - patches.suse/tracing-document-have_syscall_tracepoints-needs:
    tracing: Document HAVE_SYSCALL_TRACEPOINTS needs.
  - patches.suse/tracing-enable-__cold-functions: tracing: Enable
    "__cold" functions.
  - patches.suse/tracing-enable-records-during-the-module-load:
    tracing: Enable records during the module load.
  - patches.suse/tracing-event-cleanup-the-useless-dentry-variable:
    tracing/event: Cleanup the useless dentry variable.
  - patches.suse/tracing-events-add-signed-field-to-format-files:
    tracing/events: Add 'signed' field to format files.
  - patches.suse/tracing-events-fix-locking-imbalance-in-the-filter-code:
    tracing/events: Fix locking imbalance in the filter code.
  - patches.suse/tracing-filters-cleanup-useless-headers:
    tracing/filters: Cleanup useless headers.
  - patches.suse/tracing-filters-fix-to-make-system-filter-work:
    tracing/filters: Fix to make system filter work.
  - patches.suse/tracing-filters-provide-basic-regex-support:
    tracing/filters: Provide basic regex support.
  - patches.suse/tracing-filters-refactor-subsystem-filter-code:
    tracing/filters: Refactor subsystem filter code.
  - patches.suse/tracing-filters-unify-the-regex-parsing-helpers:
    tracing/filters: Unify the regex parsing helpers.
  - patches.suse/tracing-filters-use-a-different-op-for-glob-match:
    tracing/filters: Use a different op for glob match.
  - patches.suse/tracing-fix-ring-buffer-and-ksym-tracer-merge-interaction:
    tracing: Fix ring-buffer and ksym tracer merge interaction.
  - patches.suse/tracing-forget-about-the-nmi-buffer-for-syscall-events:
    tracing: Forget about the NMI buffer for syscall events.
  - patches.suse/tracing-ftrace-dynamic-ftrace_event_call-support:
    tracing: Ftrace dynamic ftrace_event_call support.
  - patches.suse/tracing-ftrace-fix-to-check-create_event_dir-when-adding-new-events:
    tracing/ftrace: Fix to check create_event_dir() when adding
    new events.
  - patches.suse/tracing-generate-names-for-each-kprobe-event-automatically:
    tracing: Generate names for each kprobe event automatically.
  - patches.suse/tracing-kprobe-tracer-assigns-new-event-ids-for-each-event:
    tracing: Kprobe tracer assigns new event ids for each event.
  - patches.suse/tracing-kprobe-tracer-supports-more-than-6-arguments:
    tracing: Kprobe-tracer supports more than 6 arguments.
  - patches.suse/tracing-kprobes-add-argument-name-support:
    tracing/kprobes: Add argument name support.
  - patches.suse/tracing-kprobes-add-event-profiling-support:
    tracing/kprobes: Add event profiling support.
  - patches.suse/tracing-kprobes-add-failure-messages-for-debugging:
    tracing/kprobes: Add failure messages for debugging.
  - patches.suse/tracing-kprobes-add-prefix-to-special-variables:
    tracing/kprobes: Add $ prefix to special variables.
  - patches.suse/tracing-kprobes-add-probe-handler-dispatcher-to-support-perf-and-ftrace-concurrent-use:
    tracing/kprobes: Add probe handler dispatcher to support perf
    and ftrace concurrent use.
  - patches.suse/tracing-kprobes-avoid-field-name-confliction:
    tracing/kprobes: Avoid field name confliction.
  - patches.suse/tracing-kprobes-change-trace_arg-to-probe_arg:
    tracing/kprobes: Change trace_arg to probe_arg.
  - patches.suse/tracing-kprobes-cleanup-kprobe-tracer-code:
    tracing/kprobes: Cleanup kprobe tracer code.
  - patches.suse/tracing-kprobes-disable-kprobe-events-by-default-after-creation:
    tracing/kprobes: Disable kprobe events by default after
    creation.
  - patches.suse/tracing-kprobes-dump-the-culprit-kprobe-in-case-of-kprobe-recursion:
    tracing/kprobes: Dump the culprit kprobe in case of kprobe
    recursion.
  - patches.suse/tracing-kprobes-fix-field-creation-s-bad-error-handling:
    tracing/kprobes: Fix field creation's bad error handling.
  - patches.suse/tracing-kprobes-fix-format-typo-in-trace_kprobes:
    tracing/kprobes: Fix format typo in trace_kprobes.
  - patches.suse/tracing-kprobes-fix-probe-offset-to-be-unsigned:
    tracing/kprobes: Fix probe offset to be unsigned.
  - patches.suse/tracing-kprobes-fix-profiling-alignment-for-perf_counter-buffer:
    tracing/kprobes: Fix profiling alignment for perf_counter
    buffer.
  - patches.suse/tracing-kprobes-fix-trace_probe-registration-order:
    tracing/kprobes: Fix trace_probe registration order.
  - patches.suse/tracing-kprobes-make-special-variable-names-more-self-explainable:
    tracing/kprobes: Make special variable names more
    self-explainable.
  - patches.suse/tracing-kprobes-remove-ra-special-variable:
    tracing/kprobes: Remove '$ra' special variable.
  - patches.suse/tracing-kprobes-rename-kprobe-tracer-to-kprobe-event:
    tracing/kprobes: Rename Kprobe-tracer to kprobe-event.
  - patches.suse/tracing-kprobes-robustify-fixed-field-names-against-variable-field-names-conflicts:
    tracing/kprobes: Robustify fixed field names against variable
    field names conflicts.
  - patches.suse/tracing-kprobes-show-event-name-in-trace-output:
    tracing/kprobes: Show event name in trace output.
  - patches.suse/tracing-kprobes-support-custom-subsystem-for-each-kprobe-event:
    tracing/kprobes: Support custom subsystem for each kprobe event.
  - patches.suse/tracing-kprobes-update-kprobe-tracer-selftest-against-new-syntax:
    tracing/kprobes: Update kprobe-tracer selftest against new
    syntax.
  - patches.suse/tracing-kprobes-use-global-event-perf-buffers-in-kprobe-tracer:
    tracing/kprobes: Use global event perf buffers in kprobe tracer.
  - patches.suse/tracing-ksym_tracer-fix-the-output-of-ksym-tracer:
    tracing/ksym_tracer: fix the output of ksym tracer.
  - patches.suse/tracing-ksym_tracer-fix-write-operation-of-ksym_trace_filter:
    tracing/ksym_tracer: fix write operation of ksym_trace_filter.
  - patches.suse/tracing-ksym_tracer-support-quick-clear-for-ksym_trace_filter-v2:
    tracing/ksym_tracer: support quick clear for ksym_trace_filter
  - - v2.
  - patches.suse/tracing-move-syscalls-metadata-handling-from-arch-to-core:
    tracing: Move syscalls metadata handling from arch to core.
  - patches.suse/tracing-perf_events-protect-the-buffer-from-recursion-in-perf:
    tracing, perf_events: Protect the buffer from recursion in perf.
  - patches.suse/tracing-profile-add-filter-support:
    tracing/profile: Add filter support.
  - patches.suse/tracing-pushdown-the-bkl-tracepoints-calls:
    tracing: Pushdown the bkl tracepoints calls.
  - patches.suse/tracing-remove-unneeded-pointer-casts: tracing:
    Remove unneeded pointer casts.
  - patches.suse/tracing-remove-unused-ftrace_trace_addr-helper:
    tracing: Remove unused ftrace_trace_addr helper.
  - patches.suse/tracing-rename-lockdep-event-subsystem-into-lock:
    tracing: Rename 'lockdep' event subsystem into 'lock'.
  - patches.suse/tracing-rename-set_ftrace-to-set_bootup_ftrace:
    tracing: Rename set_ftrace to set_bootup_ftrace.
  - patches.suse/tracing-restore-original-format-of-sched-events:
    tracing: Restore original format of sched events.
  - patches.suse/tracing-restore-the-const-qualifier-for-field-names-and-types-definition:
    tracing: Restore the const qualifier for field names and
    types definition.
  - patches.suse/tracing-slab-define-kmem_cache_alloc_notrace-ifdef-config_tracing:
    tracing, slab: Define kmem_cache_alloc_notrace ifdef
    CONFIG_TRACING.
  - patches.suse/tracing-slab-fix-no-callsite-ifndef-config_kmemtrace:
    tracing, slab: Fix no callsite ifndef CONFIG_KMEMTRACE.
  - patches.suse/tracing-support-multiple-pids-in-set_pid_ftrace-file:
    tracing: Support multiple pids in set_pid_ftrace file.
  - patches.suse/tracing-syscalls-make-syscall-events-print-callbacks-static:
    tracing/syscalls: Make syscall events print callbacks static.
  - patches.suse/tracing-use-the-perf-recursion-protection-from-trace-event:
    tracing: Use the perf recursion protection from trace event.
  - patches.suse/x86-add-aes-opcodes-to-opcode-map: x86: Add AES
    opcodes to opcode map.
  - patches.suse/x86-add-amd-prefetch-and-3dnow-opcodes-to-opcode-map:
    x86: Add AMD prefetch and 3DNow! opcodes to opcode map.
  - patches.suse/x86-add-intel-fma-instructions-to-x86-opcode-map:
    x86: Add Intel FMA instructions to x86 opcode map.
  - patches.suse/x86-add-mmx-sse-opcode-groups-to-opcode-map: x86:
    Add MMX/SSE opcode groups to opcode map.
  - patches.suse/x86-add-mmx-support-for-instruction-decoder: x86:
    Add MMX support for instruction decoder.
  - patches.suse/x86-add-pclmulq-to-x86-opcode-map: x86: Add
    pclmulq to x86 opcode map.
  - patches.suse/x86-add-pt_regs-register-and-stack-access-apis:
    x86: Add pt_regs register and stack access APIs.
  - patches.suse/x86-add-verbose-option-to-insn-decoder-test: x86:
    Add verbose option to insn decoder test.
  - patches.suse/x86-add-via-processor-instructions-in-opcodes-decoder:
    x86: Add VIA processor instructions in opcodes decoder.
  - patches.suse/x86-allow-x86-32-instruction-decoder-selftest-on-x86-64:
    x86: Allow x86-32 instruction decoder selftest on x86-64.
  - patches.suse/x86-apic-fix-spurious-error-interrupts-triggering-on-all-non-boot-aps:
    x86, apic: Fix spurious error interrupts triggering on all
    non-boot APs.
  - patches.suse/x86-avx-instruction-set-decoder-support: x86:
    AVX instruction set decoder support.
  - patches.suse/x86-check-awk-features-before-generating-inat-tables-c:
    x86: Check awk features before generating inat-tables.c.
  - patches.suse/x86-compile-insn-c-and-inat-c-only-for-kprobes:
    x86: Compile insn.c and inat.c only for KPROBES.
  - patches.suse/x86-fix-comments-of-register-stack-access-functions:
    x86: Fix comments of register/stack access functions.
  - patches.suse/x86-fix-group-attribute-decoding-bug: x86: Fix
    group attribute decoding bug.
  - patches.suse/x86-fix-insn-decoder-test-typos: x86: Fix insn
    decoder test typos.
  - patches.suse/x86-fix-sse-opcode-map-bug: x86: Fix SSE opcode
    map bug.
  - patches.suse/x86-fix-x86-instruction-decoder-selftest-to-check-only-text:
    x86: Fix x86 instruction decoder selftest to check only .text.
  - patches.suse/x86-fixup-wrong-debug-exception-frame-link-in-stacktraces:
    x86: Fixup wrong debug exception frame link in stacktraces.
  - patches.suse/x86-fixup-wrong-irq-frame-link-in-stacktraces:
    x86: Fixup wrong irq frame link in stacktraces.
  - patches.suse/x86-hw-breakpoints-actually-flush-thread-breakpoints-in-flush_thread:
    x86/hw-breakpoints: Actually flush thread breakpoints in
    flush_thread().
  - patches.suse/x86-hw-breakpoints-don-t-lose-ge-flag-while-disabling-a-breakpoint:
    x86/hw-breakpoints: Don't lose GE flag while disabling a
    breakpoint.
  - patches.suse/x86-hw_breakpoint-c-arch_check_va_in_kernelspace-and-hw_breakpoint_handler-should-be-static:
    x86: hw_breakpoint.c arch_check_va_in_kernelspace and
    hw_breakpoint_handler should be static.
  - patches.suse/x86-insn-decoder-test-checks-objdump-version:
    x86: insn decoder test checks objdump version.
  - patches.suse/x86-insn-delete-empty-or-incomplete-inat-tables-c:
    x86 insn: Delete empty or incomplete inat-tables.c.
  - patches.suse/x86-instruction-decoder-api: x86: Instruction
    decoder API.
  - patches.suse/x86-instruction-decoder-fix-test_get_len-build-rules:
    x86, instruction decoder: Fix test_get_len build rules.
  - patches.suse/x86-instruction-decoder-test-should-generate-build-warning:
    x86: Instruction decoder test should generate build warning.
  - patches.suse/x86-mark-ptrace_get_debugreg-as-static: x86:
    Mark ptrace_get_debugreg() as static.
  - patches.suse/x86-mark-the-thermal-init-functions-__init: x86:
    Mark the thermal init functions __init.
  - patches.suse/x86-mce-add-__cpuinit-to-hotplug-callback-functions:
    x86, mce: Add __cpuinit to hotplug callback functions.
  - patches.suse/x86-mce-add-a-global-mce-init-helper: x86, mce:
    Add a global MCE init helper.
  - patches.suse/x86-mce-fix-__init-annotations: x86, mce: Fix
    __init annotations.
  - patches.suse/x86-mce-fix-up-mce-naming-nomenclature: x86, mce:
    Fix up MCE naming nomenclature.
  - patches.suse/x86-merge-inat_rexpfx-into-inat_pfx_: x86: Merge
    INAT_REXPFX into INAT_PFX_*.
  - patches.suse/x86-perf-events-check-if-we-have-apic-enabled:
    x86, perf events: Check if we have APIC enabled.
  - patches.suse/x86-perf-exclude-the-debug-stack-from-the-callchains:
    x86/perf: Exclude the debug stack from the callchains.
  - patches.suse/x86-perf-probe-fix-warning-in-test_get_len: x86,
    perf probe: Fix warning in test_get_len().
  - patches.suse/x86-ptrace-fix-regs_get_argument_nth-to-add-correct-offset:
    x86/ptrace: Fix regs_get_argument_nth() to add correct offset.
  - patches.suse/x86-remove-unused-config-macros-from-instruction-decoder-selftest:
    x86: Remove unused config macros from instruction decoder
    selftest.
  - patches.suse/x86-rename-global-percpu-symbol-dr7-to-cpu_dr7:
    x86: Rename global percpu symbol dr7 to cpu_dr7.
  - patches.suse/x86-show-symbol-name-if-insn-decoder-test-failed:
    x86: Show symbol name if insn decoder test failed.
  - patches.suse/x86-tighten-conditionals-on-mce-related-statistics:
    x86: Tighten conditionals on MCE related statistics.
  - patches.suse/x86-under-bios-control-restore-ap-s-apic_lvtthmr-to-the-bsp-value:
    x86: Under BIOS control, restore AP's APIC_LVTTHMR to the
    BSP value.
  - patches.suse/x86-x86-instruction-decoder-build-time-selftest:
    x86: X86 instruction decoder build-time selftest.
* Fri Jul  1 2011 gregkh@suse.de
- more USB 3.0 work, .34->.35  still not finished with .35
- patches.drivers/USB3-0190-USB-ipw-clean-up-dtr-rts-handling.patch:
  USB: ipw: clean up dtr-rts handling.
- patches.drivers/USB3-0191-USB-ipw-remove-dummy-port_probe-and-port_remove.patch:
  USB: ipw: remove dummy port_probe and port_remove.
- patches.drivers/USB3-0192-USB-ipw-reimplement-using-generic-framework.patch:
  USB: ipw: reimplement using generic framework.
- patches.drivers/USB3-0193-USB-io_edgeport-Use-kzalloc.patch:
  USB: io_edgeport: Use kzalloc.
- patches.drivers/USB3-0194-USB-cp210x-remove-redundant-disconnect.patch:
  USB: cp210x: remove redundant disconnect().
- patches.drivers/USB3-0195-USB-FHCI-cq_get-should-check-kfifo_out-s-return-value.patch:
  USB: FHCI: cq_get() should check kfifo_out()'s return value.
- patches.drivers/USB3-0196-USB-mct_u232.h-checkpatch-cleanups.patch:
  USB: mct_u232.h: checkpatch cleanups.
- patches.drivers/USB3-0197-USB-belkin_sa.h-checkpatch-cleanups.patch:
  USB: belkin_sa.h: checkpatch cleanups.
- patches.drivers/USB3-0198-USB-cypress_m8.h-checkpatch-cleanups.patch:
  USB: cypress_m8.h: checkpatch cleanups.
- patches.drivers/USB3-0199-USB-ftdi_sio-checkpatch-cleanups.patch:
  USB: ftdi_sio: checkpatch cleanups.
- patches.drivers/USB3-0200-USB-io_edgeport-checkpatch-cleanups.patch:
  USB: io_edgeport: checkpatch cleanups.
- patches.drivers/USB3-0201-USB-kl5kusb105.h-checkpatch-cleanups.patch:
  USB: kl5kusb105.h: checkpatch cleanups.
- patches.drivers/USB3-0202-USB-kobil_sct.h-checkpatch-cleanups.patch:
  USB: kobil_sct.h: checkpatch cleanups.
- patches.drivers/USB3-0203-USB-pl2303.h-checkpatch-cleanups.patch:
  USB: pl2303.h: checkpatch cleanups.
- patches.drivers/USB3-0204-USB-visor.h-checkpatch-cleanups.patch:
  USB: visor.h: checkpatch cleanups.
- patches.drivers/USB3-0205-USB-usb.h-checkpatch-cleanups.patch:
  USB: usb.h: checkpatch cleanups.
- patches.drivers/USB3-0206-USB-include-usb-.h-checkpatch-cleanup.patch:
  USB: include/usb/*.h checkpatch cleanup.
- patches.drivers/USB3-0207-USB-remove-match_device.patch: USB:
  remove match_device.
- patches.drivers/USB3-0208-USB-xhci-fix-compiler-warning.patch:
  USB: xhci: fix compiler warning.
* Fri Jul  1 2011 duwe@suse.de
- Update config files for hardware breakpoints.
* Fri Jul  1 2011 duwe@suse.de
- patches.fixes/perfcounter-no-update-if-register-shrinks:
  declare "u64 delta;" missed by IBM backport.
* Fri Jul  1 2011 duwe@suse.de
- patches.drivers/powerpc-eeh-add-support-for-rtas-ibm-config-pe:
  powerpc/eeh: Add support for ibm,configure-pe RTAS call
  (bnc#699495).
- patches.drivers/powerpc-eeh-display-bus-and-device-location:
  powerpc/eeh: Display eeh error location for bus and device
  (bnc#699495).
- patches.drivers/powerpc-eeh-retry-unsupported-fundamental-reset-function:
  powerpc/pseries/eeh: Handle functional reset on non-PCIe device
  (bnc#699495).
- patches.drivers/powerpc-eeh-set-pe-freset: powerpc/pseries/eeh:
  Propagate needs_freset flag to device at PE (bnc#699495).
- patches.fixes/perfcounter-no-update-if-register-shrinks:
  backport: POWER: perf_event: Skip updating kernel counters if
  register value shrinks (bnc#695243).
- patches.drivers/eeh-fix-early-boot-oops: Delete.
  Obsoleted by the eeh changes above.
* Fri Jul  1 2011 hare@suse.de
- Update config files.
- patches.drivers/bnx2fc-driver.patch: bnx2fc: Add new driver
  (FATE#311462,bnc#698053).
- patches.drivers/cxgb3i-change-cxgb3i-to-use-libcxgbi.patch:
  Refresh.
- patches.drivers/cxgb4i-v5-iscsi-driver.patch: Refresh.
- patches.suse/iscsi-boot-mv-iscsi_boot_sysfs-to-drivers-sc.patch:
  Refresh.
- supported.conf: Mark bnx2fc as supported.
* Fri Jul  1 2011 mmarek@suse.cz
- Delete the novfs patches, the module will be shipped in a
  sepparate novfs-kmp package.
* Fri Jul  1 2011 hare@suse.de
- patches.drivers/cciss-update-to-3.6.26.patch: cciss: Update
  to version 3.6.26 (FATE#311200,bnc#703422).
- patches.drivers/cciss-update-to-4.6.28.patch: cciss: Update
  to version 4.6.28 (FATE#311200,bnc#703422).
- patches.drivers/hpsa-update-to-hp-version.patch: hpsa: Update
  to latest code drop from HP (FATE#311201,bnc#703426).
- patches.drivers/hpsa-update-to-mainline.patch: hpsa: Update
  to latest mainline version (FATE#311201,bnc#703426).
* Fri Jul  1 2011 jbeulich@novell.com
- patches.xen/xen-x86-ioremap_xen.patch: Replace by...
- patches.xen/xen3-001-apei_infrastructure.patch: APEI infrastructure
  support (fate#311701,fate#311703,fate#311704,fate#311771,fate#311706,
  fate#311772,bnc#697859).
- patches.xen/xen3-USB3-0029-USB-make-hcd.h-public-drivers-dependency.patch:
  USB: make hcd.h public (drivers dependency).
- patches.xen/xen3-USB3-0038-USB-remove-uses-of-URB_NO_SETUP_DMA_MAP.patch:
  USB: remove uses of URB_NO_SETUP_DMA_MAP.
- Refresh other Xen patches.
* Fri Jul  1 2011 tonyj@suse.de
- Update config files.
- patches.fixes/hw_breakpoint-fix-cpu-offset.patch: ksym_tracer:
  Fix to make the tracer work (FATE#311653, BNC#702123).
- patches.fixes/perf-fix-hw_breakpoint-dependancy.patch:
  hw-breakpoints: Fix hardware breakpoints -> perf events
  dependency (FATE#311653, BNC#702123).
- patches.suse/ppc64-hardware-breakpoints.patch: Powerpc Hardware
  Breakpoint Support (FATE#311653, BNC#702123).
- patches.xen/xen3-patch-2.6.30: Refresh.
* Fri Jul  1 2011 gregkh@suse.de
- more USB 3.0 work, .34->.35  still not finished with .35, eyes going blurry...
- patches.drivers/USB3-0130-USB-export-the-new-ch11.h-file-to-userspce.patch:
  USB: export the new ch11.h file to userspce.
- patches.drivers/USB3-0131-USB-remove-the-usb_host_ss_ep_comp-structure.patch:
  USB: remove the usb_host_ss_ep_comp structure.
- patches.drivers/USB3-0132-USB-remove-URB_NO_SETUP_DMA_MAP.patch:
  USB: remove URB_NO_SETUP_DMA_MAP.
- patches.drivers/USB3-0133-USB-xhci-Avoid-double-free-after-streams-are-disabled.patch:
  USB: xhci: Avoid double free after streams are disabled.
- patches.drivers/USB3-0135-USB-qcaux-add-Samsung-U520-device-ID.patch:
  USB: qcaux: add Samsung U520 device ID.
- patches.drivers/USB3-0140-USB-whci-declare-functions-as-static.patch:
  USB: whci: declare functions as static.
- patches.drivers/USB3-0141-USB-oti6858-declare-send_data-as-static.patch:
  USB: oti6858: declare send_data() as static.
- patches.drivers/USB3-0142-usb-sisusb_con.c-fix-shadows-sparse-warning.patch:
  usb: sisusb_con.c: fix shadows sparse warning.
- patches.drivers/USB3-0143-usb-u132-hcd.c-fix-shadows-sparse-warning.patch:
  usb: u132-hcd.c: fix shadows sparse warning.
- patches.drivers/USB3-0144-USB-Add-definition-for-the-Pipe-Usage-descriptor.patch:
  USB: Add definition for the Pipe Usage descriptor.
- patches.drivers/USB3-0145-USB-Add-a-usb_pipe_endpoint-convenience-function.patch:
  USB: Add a usb_pipe_endpoint() convenience function.
- patches.drivers/USB3-0146-USB-Turn-interface_to_usbdev-into-an-inline-function.patch:
  USB: Turn interface_to_usbdev into an inline function.
- patches.drivers/USB3-0147-USB-Change-the-scatterlist-type-in-struct-urb.patch:
  USB: Change the scatterlist type in struct urb.
- patches.drivers/USB3-0150-USB-simplify-usb_sg_init.patch: USB:
  simplify usb_sg_init().
- patches.drivers/USB3-0152-USB-ftdi_sio-switch-to-generic-write-implementation.patch:
  USB: ftdi_sio: switch to generic write implementation.
- patches.drivers/USB3-0153-USB-ftdi_sio-clean-up-SIO-write-support.patch:
  USB: ftdi_sio: clean up SIO write support.
- patches.drivers/USB3-0154-USB-aircable-rewrite-using-generic-read-and-write-implementa.patch:
  USB: aircable: rewrite using generic read and write
  implementations.
- patches.drivers/USB3-0155-USB-serial-reimplement-generic-fifo-based-writes.patch:
  USB: serial: reimplement generic fifo-based writes.
- patches.drivers/USB3-0156-USB-serial-remove-multi-urb-write-from-generic-driver.patch:
  USB: serial: remove multi-urb write from generic driver.
- patches.drivers/USB3-0161-USB-xhci-Set-stream-ID-to-0-after-cleaning-up-stalls.patch:
  USB: xhci: Set stream ID to 0 after cleaning up stalls.
- patches.drivers/USB3-0162-USB-fix-u132-hcd-code-data-warning.patch:
  USB: fix u132-hcd code/data warning.
- patches.drivers/USB3-0164-USB-tty-fix-incorrect-use-of-tty_insert_flip_string_fixed_fl.patch:
  USB: tty: fix incorrect use of
  tty_insert_flip_string_fixed_flag.
- patches.drivers/USB3-0165-USB-ark3116-reimplement-read-processing.patch:
  USB: ark3116: reimplement read processing.
- patches.drivers/USB3-0166-USB-usbcore-Do-not-disable-USB3-protocol-ports-in-hub_activa.patch:
  USB: usbcore: Do not disable USB3 protocol ports in
  hub_activate().
- patches.drivers/USB3-0168-USB-ftdi_sio-use-tty_insert_flip_string_fixed_flag.patch:
  USB: ftdi_sio: use tty_insert_flip_string_fixed_flag.
- patches.drivers/USB3-0169-USB-pl2303-use-tty_insert_flip_string_fixed_flag.patch:
  USB: pl2303: use tty_insert_flip_string_fixed_flag.
- patches.drivers/USB3-0170-USB-ftdi_sio-clean-up-line-status-handling.patch:
  USB: ftdi_sio: clean up line-status handling.
- patches.drivers/USB3-0175-USB-xhci-Transfer-ring-link-TRB-activation-change.patch:
  USB: xhci: Transfer ring link TRB activation change.
- patches.drivers/USB3-0179-USB-add-missing-in-map_urb_for_dma.patch:
  USB: add missing "{}" in map_urb_for_dma.
- patches.drivers/USB3-0181-USB-remove-usb_find_device.patch:
  USB: remove usb_find_device.
- patches.drivers/USB3-0182-USB-xhci-Remove-the-arbitrary-limit-of-15-xHCI-ports.patch:
  USB: xhci: Remove the arbitrary limit of 15 xHCI ports.
- patches.drivers/USB3-0187-USB-ir-usb-allow-custom-bulk-buffer-size-without-reallocatio.patch:
  USB: ir-usb: allow custom bulk buffer size without reallocation.
- patches.drivers/USB3-0188-USB-ir-usb-fix-set_termios-race.patch:
  USB: ir-usb: fix set_termios race.
* Fri Jul  1 2011 gregkh@suse.de
- supported.conf: mark usb_wwan as supported
* Fri Jul  1 2011 gregkh@suse.de
- patches.drivers/USB3-0006-NET-usb-Adding-URB_ZERO_PACKET-flag-to-usbnet.c.patch:
  Refresh.
- patches.drivers/USB3-0018-rndis_host-Poll-status-channel-before-control-channel.patch:
  Refresh.
- patches.drivers/USB3-0020-drivers-net-usb-asix.c-Fix-unaligned-accesses.patch:
  Refresh.
- patches.drivers/USB3-0021-drivers-net-usb-Use-kmemdup.patch:
  Refresh.
- patches.drivers/USB3-0022-drivers-net-usb-Use-kmemdup.patch:
  Refresh.
- patches.drivers/USB3-0023-drivers-net-usb-Use-kmemdup.patch:
  Refresh.
- patches.drivers/USB3-0024-pegasus-fix-USB-device-ID-for-ETX-US2.patch:
  Refresh.
* Fri Jul  1 2011 gregkh@suse.de
- USB 3.0 update, 1/2 of the .34->35 update
- Update config files.
- patches.drivers/USB3-0006-NET-usb-Adding-URB_ZERO_PACKET-flag-to-usbnet.c.patch:
  NET: usb: Adding URB_ZERO_PACKET flag to usbnet.c.
- patches.drivers/USB3-0015-include-linux-usb-audio.h-add-__attribute__-packed.patch:
  include/linux/usb/audio.h: add __attribute__((packed)).
- patches.drivers/USB3-0018-rndis_host-Poll-status-channel-before-control-channel.patch:
  rndis_host: Poll status channel before control channel.
- patches.drivers/USB3-0020-drivers-net-usb-asix.c-Fix-unaligned-accesses.patch:
  drivers/net/usb/asix.c: Fix unaligned accesses.
- patches.drivers/USB3-0021-drivers-net-usb-Use-kmemdup.patch:
  drivers/net/usb: Use kmemdup.
- patches.drivers/USB3-0022-drivers-net-usb-Use-kmemdup.patch:
  drivers/net/usb: Use kmemdup.
- patches.drivers/USB3-0023-drivers-net-usb-Use-kmemdup.patch:
  drivers/net/usb: Use kmemdup.
- patches.drivers/USB3-0024-pegasus-fix-USB-device-ID-for-ETX-US2.patch:
  pegasus: fix USB device ID for ETX-US2.
- patches.drivers/USB3-0027-USB-xhci-Limit-bus-sg_tablesize-to-62-TRBs.patch:
  USB: xhci: Limit bus sg_tablesize to 62 TRBs.
- patches.drivers/USB3-0029-USB-make-hcd.h-public-drivers-dependency.patch:
  USB: make hcd.h public (drivers dependency).
- patches.drivers/USB3-0030-USB-make-hub.h-public-drivers-dependency.patch:
  USB: make hub.h public (drivers dependency).
- patches.drivers/USB3-0031-USB-split-hub.h-into-ch11.h-and-merge-in-hcd.h.patch:
  USB: split hub.h into ch11.h and merge-in hcd.h.
- patches.drivers/USB3-0032-USB-sisusbvga-Remove-the-BKL-from-ioctl.patch:
  USB: sisusbvga: Remove the BKL from ioctl.
- patches.drivers/USB3-0033-USB-cdc-acm-make-bitfields-unsigned.patch:
  USB: cdc-acm: make bitfields unsigned.
- patches.drivers/USB3-0034-USB-Remove-large-struct-from-the-stack-in-USB-storage-isd200.patch:
  USB: Remove large struct from the stack in USB storage isd200
  driver.
- patches.drivers/USB3-0035-USB-remove-duplicated-include.patch:
  USB: remove duplicated #include.
- patches.drivers/USB3-0036-USB-remove-bogus-USB_PORT_FEAT_-_SPEED-symbols.patch:
  USB: remove bogus USB_PORT_FEAT_*_SPEED symbols.
- patches.drivers/USB3-0037-USB-straighten-out-port-feature-vs.-port-status-usage.patch:
  USB: straighten out port feature vs. port status usage.
- patches.drivers/USB3-0038-USB-remove-uses-of-URB_NO_SETUP_DMA_MAP.patch:
  USB: remove uses of URB_NO_SETUP_DMA_MAP.
- patches.drivers/USB3-0039-USB-ehci-au1xxx-does-not-need-EHCI-IO-watchdog.patch:
  USB: ehci-au1xxx does not need EHCI IO watchdog.
- patches.drivers/USB3-0040-usb-serial-Use-tty_port-version-console-instead-of-usb_seria.patch:
  usb-serial: Use tty_port version console instead of
  usb_serial_port.
- patches.drivers/USB3-0050-usb-console-pass-baud-from-console-to-the-initial-tty-open.patch:
  usb-console: pass baud from console to the initial tty open.
- patches.drivers/USB3-0051-USB-Serial-Driver-ZIO-Motherboard.patch:
  USB Serial Driver: ZIO Motherboard.
- patches.drivers/USB3-0052-usb-fix-serial-build-when-SYSRQ-is-disabled.patch:
  usb: fix serial build when SYSRQ is disabled.
- patches.drivers/USB3-0053-USB-Add-a-new-quirk-USB_QUIRK_HONOR_BNUMINTERFACES.patch:
  USB: Add a new quirk: USB_QUIRK_HONOR_BNUMINTERFACES.
- patches.drivers/USB3-0054-USB-serial-allow-drivers-to-define-bulk-buffer-sizes.patch:
  USB: serial: allow drivers to define bulk buffer sizes.
- patches.drivers/USB3-0055-USB-cp210x-increase-the-bulk-out-buffer-size-to-256-byte.patch:
  USB: cp210x: increase the bulk-out buffer size to 256 byte.
- patches.drivers/USB3-0056-USB-cp210x-increase-bulk-in-buffer-size-to-256-byte.patch:
  USB: cp210x: increase bulk-in buffer size to 256 byte.
- patches.drivers/USB3-0057-USB-pl2303-increase-the-bulk-out-buffer-size-to-256-byte.patch:
  USB: pl2303: increase the bulk-out buffer size to 256 byte.
- patches.drivers/USB3-0058-USB-pl2303-increase-bulk-in-buffer-size-to-256-byte.patch:
  USB: pl2303: increase bulk-in buffer size to 256 byte.
- patches.drivers/USB3-0059-USB-serial-fix-generic-chars_in_buffer.patch:
  USB: serial: fix generic chars_in_buffer.
- patches.drivers/USB3-0060-USB-serial-fix-missing-locking-on-fifo-in-write-callback.patch:
  USB: serial: fix missing locking on fifo in write callback.
- patches.drivers/USB3-0061-USB-serial-clear-fifo-on-close.patch:
  USB: serial: clear fifo on close.
- patches.drivers/USB3-0062-USB-serial-refactor-generic-close.patch:
  USB: serial: refactor generic close.
- patches.drivers/USB3-0063-USB-serial-refactor-read-urb-submission-in-generic-driver.patch:
  USB: serial: refactor read urb submission in generic driver.
- patches.drivers/USB3-0064-USB-serial-remove-unnecessary-re-initialisation-of-generic-u.patch:
  USB: serial: remove unnecessary re-initialisation of generic
  urbs.
- patches.drivers/USB3-0065-USB-cp210x-use-generic-submit_read_urb-at-open.patch:
  USB: cp210x: use generic submit_read_urb at open.
- patches.drivers/USB3-0066-USB-serial-clean-up-read-processing-in-generic-driver.patch:
  USB: serial: clean up read processing in generic driver.
- patches.drivers/USB3-0067-USB-serial-generalise-generic-read-implementation.patch:
  USB: serial: generalise generic read implementation.
- patches.drivers/USB3-0068-USB-pl2303-switch-to-generic-read-implementation.patch:
  USB: pl2303: switch to generic read implementation.
- patches.drivers/USB3-0069-USB-serial-export-generic-throttle-and-unthrottle.patch:
  USB: serial: export generic throttle and unthrottle.
- patches.drivers/USB3-0070-USB-ftdi_sio-switch-to-generic-read-implementation.patch:
  USB: ftdi_sio: switch to generic read implementation.
- patches.drivers/USB3-0071-USB-serial-clean-up-some-error-and-debug-messages-in-generic.patch:
  USB: serial: clean up some error and debug messages in generic
  driver.
- patches.drivers/USB3-0072-USB-serial-clean-up-generic-write-start-busy-test.patch:
  USB: serial: clean up generic write start busy test.
- patches.drivers/USB3-0073-USB-pl2303-switch-to-generic-write-implementation.patch:
  USB: pl2303: switch to generic write implementation.
- patches.drivers/USB3-0074-USB-pl2303-use-generic-close.patch:
  USB: pl2303: use generic close.
- patches.drivers/USB3-0075-USB-usb_debug-use-the-generic-kfifo-based-write-implementati.patch:
  USB: usb_debug: use the generic kfifo-based write
  implementation.
- patches.drivers/USB3-0076-USB-serial-allow-custom-multi-urb-write-bulk-callbacks.patch:
  USB: serial: allow custom multi-urb write bulk callbacks.
- patches.drivers/USB3-0077-USB-serial-re-implement-multi-urb-writes-in-generic-driver.patch:
  USB: serial: re-implement multi-urb writes in generic driver.
- patches.drivers/USB3-0078-USB-serial-generalise-write-buffer-preparation.patch:
  USB: serial: generalise write buffer preparation.
- patches.drivers/USB3-0079-USB-ftdi_sio-fix-some-coding-style-issues.patch:
  USB: ftdi_sio: fix some coding style issues.
- patches.drivers/USB3-0081-USB-option.c-option_indat_callback-Resubmit-some-unsuccessfu.patch:
  USB: option.c: option_indat_callback: Resubmit some unsuccessful
  URBs.
- patches.drivers/USB3-0098-USB-fix-usbmon-and-DMA-mapping-for-scatter-gather-URBs.patch:
  USB: fix usbmon and DMA mapping for scatter-gather URBs.
- patches.drivers/USB3-0103-usb-serial-Add-generic-USB-wwan-support.patch:
  usb serial: Add generic USB wwan support.
- patches.drivers/USB3-0104-USB-option-Use-generic-USB-wwan-code.patch:
  USB: option: Use generic USB wwan code.
- patches.drivers/USB3-0105-USB-qcserial-Use-generic-USB-wwan-code.patch:
  USB: qcserial: Use generic USB wwan code.
- patches.drivers/USB3-0106-USB-qcserial-Add-support-for-Qualcomm-Gobi-2000-devices.patch:
  USB: qcserial: Add support for Qualcomm Gobi 2000 devices.
- patches.drivers/USB3-0107-USB-Add-parsing-of-SuperSpeed-endpoint-companion-descriptor.patch:
  USB: Add parsing of SuperSpeed endpoint companion descriptor.
- patches.drivers/USB3-0108-USB-Add-stream-ID-field-to-struct-urb.patch:
  USB: Add stream ID field to struct urb.
- patches.drivers/USB3-0109-USB-xhci-Add-memory-allocation-for-USB3-bulk-streams.patch:
  USB: xhci: Add memory allocation for USB3 bulk streams.
- patches.drivers/USB3-0110-USB-xhci-Correct-assumptions-about-number-of-rings-per-endpo.patch:
  USB: xhci: Correct assumptions about number of rings per
  endpoint.
- patches.drivers/USB3-0111-USB-Support-for-allocating-USB-3.0-streams.patch:
  USB: Support for allocating USB 3.0 streams.
- patches.drivers/USB3-0112-USB-storage-Remove-unneeded-SL11R-unusual_devs-entry.patch:
  USB: storage: Remove unneeded SL11R unusual_devs entry.
- patches.drivers/USB3-0113-USB-ehci-Elide-I-O-watchdog-on-NEC-parts.patch:
  USB: ehci: Elide I/O watchdog on NEC parts.
- patches.drivers/USB3-0115-USB-ueagle-fix-Coding-Styles.patch:
  USB: ueagle: fix Coding Styles.
- patches.drivers/USB3-0116-USB-devices-fix-Coding-Styles.patch:
  USB: devices: fix Coding Styles.
- patches.drivers/USB3-0117-USB-rename-usb_buffer_alloc-and-usb_buffer_free-users.patch:
  USB: rename usb_buffer_alloc() and usb_buffer_free() users.
- patches.drivers/USB3-0118-USB-usbserial-mos7720-add-support-for-parallel-port-on-mosch.patch:
  USB: usbserial: mos7720: add support for parallel port on
  moschip 7715.
- patches.drivers/USB3-0119-USB-usbserial-mos7720-cleanup-consolidation-replace-send_mos.patch:
  USB: usbserial: mos7720: cleanup, consolidation, replace
  send_mos_cmd with {read,write}_mos_reg.
- patches.drivers/USB3-0120-USB-usbserial-fix-mos7720-dependencies.patch:
  USB: usbserial: fix mos7720 dependencies.
- patches.drivers/USB3-0121-usb-cdc-ncm-constants-and-structures-added.patch:
  usb: cdc: ncm constants and structures added.
- patches.drivers/USB3-0122-USB-ncm-added-ncm.h-with-auxiliary-definitions.patch:
  USB: ncm: added ncm.h with auxiliary definitions.
- patches.drivers/USB3-0123-USB-core-config.c-usb_get_configuration-simplified.patch:
  USB: core: config.c: usb_get_configuration() simplified.
- patches.drivers/USB3-0124-USB-clean-up-some-host-controller-sparse-warnings.patch:
  USB: clean up some host controller sparse warnings.
- patches.drivers/USB3-0127-USB-sisusbvga-Remove-the-BKL-from-open.patch:
  USB: sisusbvga: Remove the BKL from open.
- patches.drivers/USB3-0128-USB-mos7840-Cleanup-useless-header.patch:
  USB: mos7840: Cleanup useless header.
- patches.suse/kdb-common: Refresh.
* Thu Jun 30 2011 gregkh@suse.de
- USB 3.0 update, .33->.34 patches
- Update config files.
- patches.drivers/USB3-0001-drivers-net-usb-rtl8150.c-use-pM-to-shown-MAC-address.patch:
  drivers/net/usb/rtl8150.c: use %%pM to shown MAC address.
- patches.drivers/USB3-0001-net-use-helpers-to-access-mc-list-v2.patch:
  net: use helpers to access mc list V2.
- patches.drivers/USB3-0001-net-use-helpers-to-access-uc-list-v2.patch:
  net: use helpers to access uc list V2.
- patches.drivers/USB3-0001-usb-tty-add-a-function-to-insert-a-string-of-characters.patch:
  USB: tty: Add a function to insert a string of characters with
  the same flag.
- patches.drivers/USB3-0001-usbnet-Use-wwan-d-interface-name-for-mobile-broadband-device.patch:
  usbnet: Use wwan%%d interface name for mobile broadband devices.
- patches.drivers/USB3-0002-drivers-net-usb-catc.c-use-pM-to-shown-MAC-address.patch:
  drivers/net/usb/catc.c: use %%pM to shown MAC address.
- patches.drivers/USB3-0003-MCS7830-USB-Ether-add-Rx-error-support.patch:
  MCS7830 USB-Ether: add Rx error support.
- patches.drivers/USB3-0004-MCS7830-USB-Ether-Spelling-corrections.patch:
  MCS7830 USB-Ether: Spelling corrections.
- patches.drivers/USB3-0005-MCS7830-USB-Ether-change-register-define.patch:
  MCS7830 USB-Ether: change register define.
- patches.drivers/USB3-0006-MCS7830-USB-Ether-resume-_with_-working-link-via-.reset_resu.patch:
  MCS7830 USB-Ether: resume _with_ working link, via .reset_resume
  support.
- patches.drivers/USB3-0006-usbnet-Set-link-down-initially-for-drivers-that-update-link-.patch:
  Refresh.
- patches.drivers/USB3-0010-net-dm9601-convert-to-use-mc-helpers.patch:
  net: dm9601: convert to use mc helpers.
- patches.drivers/USB3-0012-net-use-netdev_mc_count-and-netdev_mc_empty-when-appropriate.patch:
  net: use netdev_mc_count and netdev_mc_empty when appropriate.
- patches.drivers/USB3-0013-usbnet-cdc-ether-Autosuspend-for-online-devices.patch:
  Refresh.
- patches.drivers/USB3-0015-usbnet-Convert-dev-dbg-err-warn-info-macros-to-netdev_-level.patch:
  usbnet: Convert dev(dbg|err|warn|info) macros to netdev_<level>.
- patches.drivers/USB3-0016-drivers-net-usb-Use-netif_-level-logging-facilities.patch:
  drivers/net/usb: Use netif_<level> logging facilities.
- patches.drivers/USB3-0017-net-usb-convert-to-use-netdev_for_each_mc_addr.patch:
  net/usb: convert to use netdev_for_each_mc_addr.
- patches.drivers/USB3-0025-Lower-USB-storage-settling-delay-to-something-more-reasonabl.patch:
  Lower USB storage settling delay to something more reasonable.
- patches.drivers/USB3-0031-USB-cxacru-return-an-empty-value-for-modulation-if-there-is-.patch:
  USB: cxacru: return an empty value for modulation if there is
  no connection.
- patches.drivers/USB3-0032-USB-cxacru-check-data-length-is-not-negative.patch:
  USB: cxacru: check data length is not negative.
- patches.drivers/USB3-0033-USB-cxacru-check-device-isn-t-being-removed-during-sysfs-cal.patch:
  USB: cxacru: check device isn't being removed during sysfs
  calls.
- patches.drivers/USB3-0034-USB-cxacru-document-how-to-interact-with-the-flash-memory.patch:
  USB: cxacru: document how to interact with the flash memory.
- patches.drivers/USB3-0035-USB-cxacru-firmware-writes-on-OHCI-are-slow-log-progress.patch:
  USB: cxacru: firmware writes on OHCI are slow, log progress.
- patches.drivers/USB3-0036-USB-cxacru-add-write-only-sysfs-attribute-for-modem-configur.patch:
  USB: cxacru: add write-only sysfs attribute for modem
  configuration.
- patches.drivers/USB3-0037-USB-cxacru-remove-cxacru-cf.bin-loader.patch:
  USB: cxacru: remove cxacru-cf.bin loader.
- patches.drivers/USB3-0038-USB-cxacru-increment-driver-version.patch:
  USB: cxacru: increment driver version.
- patches.drivers/USB3-0039-USB-ftdi_sio-fix-error-message-on-close.patch:
  USB: ftdi_sio: fix error message on close.
- patches.drivers/USB3-0040-USB-ftdi_sio-remove-obsolete-comment.patch:
  USB: ftdi_sio: remove obsolete comment.
- patches.drivers/USB3-0041-USB-serial-fix-typo-in-debug-message.patch:
  USB: serial: fix typo in debug message.
- patches.drivers/USB3-0042-USB-ftdi_sio-fix-initialisation-of-latency-timeout.patch:
  USB: ftdi_sio: fix initialisation of latency timeout.
- patches.drivers/USB3-0043-USB-ftdi_sio-remove-support-for-5-and-6-data-bits.patch:
  USB: ftdi_sio: remove support for 5 and 6 data bits.
- patches.drivers/USB3-0046-USB-serial-mct_usb232-move-DMA-buffers-to-heap.patch:
  USB: serial mct_usb232: move DMA buffers to heap.
- patches.drivers/USB3-0047-cdc_acm-add-reset_resume-method.patch:
  cdc_acm: add reset_resume method.
- patches.drivers/USB3-0048-USB-check-the-endpoint-type-against-the-pipe-type.patch:
  USB: check the endpoint type against the pipe type.
- patches.drivers/USB3-0049-USB-xhci-Fix-error-path-when-configuring-endpoints.patch:
  USB: xhci: Fix error path when configuring endpoints.
- patches.drivers/USB3-0050-USB-xhci-Refactor-code-to-free-or-cache-endpoint-rings.patch:
  USB: xhci: Refactor code to free or cache endpoint rings.
- patches.drivers/USB3-0051-USB-xhci-Allow-allocation-of-commands-without-input-contexts.patch:
  USB: xhci: Allow allocation of commands without input contexts.
- patches.drivers/USB3-0052-USB-xhci-Refactor-test-for-vendor-specific-completion-codes.patch:
  USB: xhci: Refactor test for vendor-specific completion codes.
- patches.drivers/USB3-0053-USB-xhci-Refactor-code-to-clear-port-change-bits.patch:
  USB: xhci: Refactor code to clear port change bits.
- patches.drivers/USB3-0054-USB-xhci-Allow-roothub-ports-to-be-disabled.patch:
  USB: xhci: Allow roothub ports to be disabled.
- patches.drivers/USB3-0055-USB-xhci-Notify-the-xHC-when-a-device-is-reset.patch:
  USB: xhci: Notify the xHC when a device is reset.
- patches.drivers/USB3-0056-USB-Add-call-to-notify-xHC-of-a-device-reset.patch:
  USB: Add call to notify xHC of a device reset.
- patches.drivers/USB3-0057-USB-ehci-add-call-of-free_cached_itd_list-function-in-disabl.patch:
  USB: ehci: add call of free_cached_itd_list() function in
  disable_periodic().
- patches.drivers/USB3-0058-USB-ehci-fix-audio-record-functionality-for-some-Full-speed-.patch:
  USB: ehci: fix audio record functionality for some Full speed
  sound blaster devices.
- patches.drivers/USB3-0068-USB-xhci-No-GFP_KERNEL-in-block-error-handling.patch:
  USB: xhci: No GFP_KERNEL in block error handling.
- patches.drivers/USB3-0069-USB-wusb-check-CHID-is-all-zeros-before-stopping-the-host.patch:
  USB: wusb: check CHID is all zeros before stopping the host.
- patches.drivers/USB3-0072-USB-storage-Never-reset-devices-that-will-morph-to-an-old-mo.patch:
  USB: storage: Never reset devices that will morph to an
  old mode.
- patches.drivers/USB3-0073-USB-Export-QUIRK_RESET_MORPHS-through-sysfs.patch:
  USB: Export QUIRK_RESET_MORPHS through sysfs.
- patches.drivers/USB3-0074-USB-cypress_m8-stop-using-USB-debug-driver-config.patch:
  USB: cypress_m8: stop using USB debug driver config.
- patches.drivers/USB3-0075-USB-cypress_m8-unify-confusing-new-baudrate-check.patch:
  USB: cypress_m8: unify confusing new baudrate check.
- patches.drivers/USB3-0076-USB-cypress_m8-allow-unstable-baud-rates.patch:
  USB: cypress_m8: allow unstable baud rates.
- patches.drivers/USB3-0086-usbmon-add-bus-number-to-text-API.patch:
  usbmon: add bus number to text API.
- patches.drivers/USB3-0087-USB-cdc_acm-Add-support-for-pbLua-console-port.patch:
  USB: cdc_acm: Add support for pbLua console port.
- patches.drivers/USB3-0088-USB-cdc_acm-Silence-It-is-not-a-modem.-error-for-pbLua-devic.patch:
  USB: cdc_acm: Silence "It is not a modem." error for pbLua
  devices.
- patches.drivers/USB3-0090-USB-rename-USB_SPEED_VARIABLE-to-USB_SPEED_WIRELESS.patch:
  USB: rename USB_SPEED_VARIABLE to USB_SPEED_WIRELESS.
- patches.drivers/USB3-0091-USB-ftdi_sio-use-error-code-from-usb-stack-in-read_latency_t.patch:
  USB: ftdi_sio: use error code from usb stack in
  read_latency_timer.
- patches.drivers/USB3-0092-USB-ftdi_sio-fix-latency-timeout-endianess-bug.patch:
  USB: ftdi_sio: fix latency-timeout endianess bug.
- patches.drivers/USB3-0093-USB-ftdi_sio-fix-DMA-buffers-on-stack.patch:
  USB: ftdi_sio: fix DMA buffers on stack.
- patches.drivers/USB3-0094-USB-ftdi_sio-clean-up-modem-status-handling.patch:
  USB: ftdi_sio: clean up modem status handling.
- patches.drivers/USB3-0095-USB-ftdi_sio-remove-unnecessary-initialisations.patch:
  USB: ftdi_sio: remove unnecessary initialisations.
- patches.drivers/USB3-0096-USB-usblp-Remove-checks-no-longer-needed-with-the-new-runtim.patch:
  USB: usblp: Remove checks no longer needed with the new runtime
  PM system.
- patches.drivers/USB3-0110-USB-ch341-replace-printk-warnings-with-dev_err.patch:
  USB: ch341: replace printk warnings with dev_err.
- patches.drivers/USB3-0111-USB-ch341-fix-DMA-buffer-on-stack.patch:
  USB: ch341: fix DMA buffer on stack.
- patches.drivers/USB3-0112-USB-ch341-use-le16_to_cpup-to-be-explicit-about-endianess.patch:
  USB: ch341: use le16_to_cpup to be explicit about endianess.
- patches.drivers/USB3-0113-USB-cypress_m8-fix-DMA-buffer-on-stack.patch:
  USB: cypress_m8: fix DMA buffer on stack.
- patches.drivers/USB3-0114-USB-cypress_m8-fix-endianess-bug.patch:
  USB: cypress_m8: fix endianess bug.
- patches.drivers/USB3-0115-USB-io_ti-fix-DMA-buffers-on-stack.patch:
  USB: io_ti: fix DMA buffers on stack.
- patches.drivers/USB3-0116-USB-keyspan_pda-fix-DMA-buffers-on-stack.patch:
  USB: keyspan_pda: fix DMA buffers on stack.
- patches.drivers/USB3-0117-USB-kl5kusb105-fix-DMA-buffers-on-stack.patch:
  USB: kl5kusb105: fix DMA buffers on stack.
- patches.drivers/USB3-0118-USB-mos7720-fix-DMA-buffers-on-stack-and-clean-up-send_mos_c.patch:
  USB: mos7720: fix DMA buffers on stack and clean up
  send_mos_cmd.
- patches.drivers/USB3-0120-USB-oti6858-fix-DMA-buffer-on-stack.patch:
  USB: oti6858: fix DMA buffer on stack.
- patches.drivers/USB3-0121-USB-visor-fix-DMA-buffers-on-stack.patch:
  USB: visor: fix DMA buffers on stack.
- patches.drivers/USB3-0122-USB-kobil_sct-clean-up-kobil_set_termios.patch:
  USB: kobil_sct: clean up kobil_set_termios.
- patches.drivers/USB3-0123-USB-serial-fix-DMA-buffers-on-stack-for-io_edgeport.c.patch:
  USB: serial: fix DMA buffers on stack for io_edgeport.c.
- patches.drivers/USB3-0124-USB-ch341-use-get_unaligned_le16-in-break_ctl.patch:
  USB: ch341: use get_unaligned_le16 in break_ctl.
- patches.drivers/USB3-0125-USB-cypress_m8-use-put_unaligned_le32-where-necessary.patch:
  USB: cypress_m8: use put_unaligned_le32() where necessary.
- patches.drivers/USB3-0126-USB-FHCI-Correct-the-size-argument-to-kzalloc.patch:
  USB: FHCI: Correct the size argument to kzalloc.
- patches.drivers/USB3-0127-USB-c67x00-use-resource_size.patch:
  USB: c67x00: use resource_size().
- patches.drivers/USB3-0128-USB-xhci-Fix-compile-issues-with-xhci_get_slot_state.patch:
  USB: xhci: Fix compile issues with xhci_get_slot_state().
- patches.drivers/USB3-0131-USB-Use-bInterfaceNumber-in-bandwidth-allocations.patch:
  USB: Use bInterfaceNumber in bandwidth allocations.
- patches.drivers/USB3-0132-USB-rearrange-code-in-usb_probe_interface.patch:
  USB: rearrange code in usb_probe_interface.
- patches.drivers/USB3-0133-USB-change-locking-for-device-level-autosuspend.patch:
  USB: change locking for device-level autosuspend.
- patches.drivers/USB3-0134-USB-consolidate-remote-wakeup-routines.patch:
  USB: consolidate remote wakeup routines.
- patches.drivers/USB3-0135-USB-use-the-device-lock-for-persist_enabled.patch:
  USB: use the device lock for persist_enabled.
- patches.drivers/USB3-0136-USB-implement-usb_enable_autosuspend.patch:
  USB: implement usb_enable_autosuspend.
- patches.drivers/USB3-0137-USB-change-handling-of-negative-autosuspend-delays.patch:
  USB: change handling of negative autosuspend delays.
- patches.drivers/USB3-0140-USB-fix-crash-in-uhci_scan_schedule.patch:
  USB: fix crash in uhci_scan_schedule.
- patches.drivers/USB3-0144-USB-class-make-USB-device-id-constant.patch:
  USB class: make USB device id constant.
- patches.drivers/USB3-0145-USB-serial-make-USB-device-id-constant.patch:
  USB serial: make USB device id constant.
- patches.drivers/USB3-0146-USB-image-make-USB-device-id-constant.patch:
  USB image: make USB device id constant.
- patches.drivers/USB3-0147-USB-misc-make-USB-device-id-constant.patch:
  USB misc: make USB device id constant.
- patches.drivers/USB3-0148-USB-hub-make-USB-device-id-constant.patch:
  USB hub: make USB device id constant.
- patches.drivers/USB3-0149-USB-host-make-Open-Firmware-device-id-constant.patch:
  USB host: make Open Firmware device id constant.
- patches.drivers/USB3-0150-USB-gadget-make-Open-Firmware-device-id-constant.patch:
  USB gadget: make Open Firmware device id constant.
- patches.drivers/USB3-0151-USB-goku_udc-make-PCI-device-id-constant.patch:
  USB goku_udc: make PCI device id constant.
- patches.drivers/USB3-0152-USB-serial-option.c-Add-chipset-information-for-4G-W14.patch:
  USB: serial: option.c: Add chipset information for 4G W14.
- patches.drivers/USB3-0153-USB-serial-option.c-Add-blacklisting-infrastructure-for-spec.patch:
  USB: serial: option.c: Add blacklisting infrastructure for
  special device handling.
- patches.drivers/USB3-0154-USB-serial-option.c-Add-4G-W14-stick-to-blacklist-for-option.patch:
  USB: serial: option.c: Add 4G W14 stick to blacklist for
  option_send_setup.
- patches.drivers/USB3-0155-USB-atm-Use-FIELD_SIZEOF-trivial-cleanup.patch:
  USB: atm: Use FIELD_SIZEOF, trivial cleanup.
- patches.drivers/USB3-0156-USB-Remove-BKL-from-poll.patch: USB:
  Remove BKL from poll().
- patches.drivers/USB3-0157-USB-Remove-BKL-from-usbdev_open.patch:
  USB: Remove BKL from usbdev_open().
- patches.drivers/USB3-0158-USB-Remove-BKL-from-lseek-implementations.patch:
  USB: Remove BKL from lseek implementations.
- patches.drivers/USB3-0159-USB-Push-BKL-on-open-down-into-the-drivers.patch:
  USB: Push BKL on open down into the drivers.
- patches.drivers/USB3-0161-USB-isight-firmware-declare-MODULE_FIRMWARE.patch:
  USB: isight-firmware: declare MODULE_FIRMWARE.
- patches.drivers/USB3-0162-usb-BKL-removal-usblp.patch: usb:
  BKL removal: usblp.
- patches.drivers/USB3-0163-USB-BKL-removal-usb-skeleton.patch:
  USB: BKL removal: usb-skeleton.
- patches.drivers/USB3-0164-USB-BKL-removal-usbtmc.patch: USB:
  BKL removal: usbtmc.
- patches.drivers/USB3-0165-USB-BKL-removal-cdc-wdm.patch: USB:
  BKL removal: cdc-wdm.
- patches.drivers/USB3-0166-USB-BKL-removal-mdc800.patch: USB:
  BKL removal: mdc800.
- patches.drivers/USB3-0167-USB-BKL-removal-rio500.patch: USB:
  BKL removal: rio500.
- patches.drivers/USB3-0168-USB-BKL-removal-idmouse.patch: USB:
  BKL removal: idmouse.
- patches.drivers/USB3-0169-USB-BKL-removal-adutux.patch: USB:
  BKL removal: adutux.
- patches.drivers/USB3-0170-USB-BKL-removal-ftdi-elan.patch:
  USB: BKL removal: ftdi-elan.
- patches.drivers/USB3-0171-USB-BKL-removal-ldusb.patch: USB:
  BKL removal: ldusb.
- patches.drivers/USB3-0172-USB-BKL-removal-legousbtower.patch:
  USB: BKL removal: legousbtower.
- patches.drivers/USB3-0173-USB-BKL-removal-vstusb.patch: USB:
  BKL removal: vstusb.
- patches.drivers/USB3-0177-USB-serial-Eliminate-useless-code.patch:
  USB: serial: Eliminate useless code.
- patches.drivers/USB3-0178-USB-ftdi_sio-correct-spelling-in-header-files.patch:
  USB: ftdi_sio: correct spelling in header files.
- patches.drivers/USB3-0179-USB-ftdi_sio-correct-spelling-in-implementation-file.patch:
  USB: ftdi_sio: correct spelling in implementation file.
- patches.drivers/USB3-0180-USB-trivial-missing-newline-in-usb-core-warning-message.patch:
  USB: trivial: missing newline in usb core warning message.
- patches.drivers/USB3-0182-USB-usbfs_snoop-add-data-logging-back-in.patch:
  USB: usbfs_snoop: add data logging back in.
- patches.drivers/USB3-0192-USB-io_edgeport-eliminate-get_string.patch:
  USB: io_edgeport: eliminate get_string().
- patches.drivers/USB3-0193-USB-serial-add-support-for-serial-port-on-the-moschip-7715.patch:
  USB: serial: add support for serial port on the moschip 7715.
- patches.drivers/USB3-0200-USB-ftdi_sio-Replace-BKL-with-a-mutex.patch:
  USB: ftdi_sio: Replace BKL with a mutex.
- patches.drivers/USB3-0205-USB-cdc-acm-fix-possible-deadlock-with-multiple-openers.patch:
  USB: cdc-acm: fix possible deadlock with multiple openers.
- patches.drivers/USB3-0209-USB-serial-Add-support-for-ViVOtech-ViVOpay-devices.patch:
  USB: serial: Add support for ViVOtech ViVOpay devices.
- patches.drivers/USB3-0210-USB-ehci-dbgp-split-PID-register-updates-for-IN-and-OUT-pipe.patch:
  USB: ehci-dbgp: split PID register updates for IN and OUT pipes.
- patches.drivers/USB3-0211-USB-serial-Remove-unnecessary-n-s-from-dbg-uses.patch:
  USB: serial: Remove unnecessary \n's from dbg uses.
- patches.drivers/USB3-0212-USB-Convert-concatenated-__FILE__-to-s-__FILE__.patch:
  USB: Convert concatenated __FILE__ to %%s, __FILE__.
- patches.drivers/USB3-0213-USB-Extend-and-neaten-dbg-macros.patch:
  USB: Extend and neaten dbg macros.
- patches.drivers/USB3-0215-tty-Fix-various-bogus-WARN-checks-in-the-usb-serial-layer.patch:
  tty: Fix various bogus WARN checks in the usb serial layer.
- patches.drivers/USB3-0218-USB-serial-sierra-driver-adding-reset_resume-function.patch:
  USB: serial: sierra driver adding reset_resume function.
- patches.drivers/USB3-0224-usb-storage-use-max_hw_sectors-instead-of-max_sectors.patch:
  usb-storage: use max_hw_sectors instead of max_sectors.
- patches.drivers/USB3-0227-USB-storage-fix-misplaced-parenthesis.patch:
  USB: storage: fix misplaced parenthesis.
- patches.drivers/USB3-0228-USB-tty-sort-out-the-request_room-handling-for-whiteheat.patch:
  USB: tty: sort out the request_room handling for whiteheat.
- patches.drivers/USB3-0229-USB-tty-kill-request_room-for-USB-ACM-class.patch:
  USB: tty: kill request_room for USB ACM class.
- patches.drivers/USB3-0230-USB-don-t-read-past-config-interface-if-usb_control_msg-fail.patch:
  USB: don't read past config->interface if usb_control_msg()
  fails in usb_reset_configuration().
- patches.drivers/USB3-0231-USB-tty-Prune-uses-of-tty_request_room-in-the-USB-layer.patch:
  USB: tty: Prune uses of tty_request_room in the USB layer.
- patches.drivers/USB3-0234-USB-storage-onetouch-unnecessary-GFP_ATOMIC.patch:
  USB: storage: onetouch: unnecessary GFP_ATOMIC.
- patches.drivers/USB3-0235-USB-sisusbvga-no-unnecessary-GFP_ATOMIC.patch:
  USB: sisusbvga: no unnecessary GFP_ATOMIC.
- patches.drivers/USB3-0236-USB-usbmon-mask-seconds-properly-in-text-API.patch:
  USB: usbmon: mask seconds properly in text API.
- patches.drivers/USB3-0238-USB-option-add-Longcheer-Longsung-vendor-ID.patch:
  USB: option: add Longcheer/Longsung vendor ID.
- patches.drivers/USB3-0239-USB-pl2303-initial-TIOCGSERIAL-support.patch:
  USB: pl2303: initial TIOCGSERIAL support.
- patches.drivers/USB3-0240-USB-qcaux-driver-for-auxiliary-serial-ports-on-Qualcomm-devi.patch:
  USB: qcaux: driver for auxiliary serial ports on Qualcomm
  devices.
- patches.drivers/USB3-0241-USB-ftdi_sio-remove-unused-tx_bytes-counter.patch:
  USB: ftdi_sio: remove unused tx_bytes counter.
- patches.drivers/USB3-0242-USB-ftdi_sio-remove-obsolete-check-in-unthrottle.patch:
  USB: ftdi_sio: remove obsolete check in unthrottle.
- patches.drivers/USB3-0243-USB-pl2303-remove-unnecessary-reset-of-usb_device-in-urbs.patch:
  USB: pl2303: remove unnecessary reset of usb_device in urbs.
- patches.drivers/USB3-0244-USB-backlight-appledisplay-fix-incomplete-registration-failu.patch:
  USB: backlight, appledisplay: fix incomplete registration
  failure handling.
- patches.drivers/USB3-0247-usbfs-fix-deadlock-on-usbfs_mutex-clean-up-poll.patch:
  usbfs: fix deadlock on 'usbfs_mutex', clean up poll.
- patches.drivers/USB3-0248-USB-remove-unused-defintion-of-struct-usb_device_status.patch:
  USB: remove unused defintion of struct usb_device_status.
- patches.drivers/USB3-0249-USB-Fix-s3c-hsotg-build-following-Samsung-platform-header-mo.patch:
  USB: Fix s3c-hsotg build following Samsung platform header
  moves.
- patches.drivers/USB3-0250-another-pegasus-usb-net-device.patch:
  another pegasus usb net device.
- patches.drivers/USB3-0253-obsolete-config-in-kernel-source-HSO_AUTOPM.patch:
  obsolete config in kernel source: HSO_AUTOPM.
- patches.drivers/USB3-0255-smsc75xx-SMSC-LAN75xx-USB-gigabit-ethernet-adapter-driver.patch:
  smsc75xx: SMSC LAN75xx USB gigabit ethernet adapter driver.
- patches.drivers/USB3-0256-smsc95xx-wait-for-PHY-to-complete-reset-during-init.patch:
  smsc95xx: wait for PHY to complete reset during init.
- patches.drivers/USB3-0257-smsc95xx-Fix-tx-checksum-offload-for-small-packets.patch:
  smsc95xx: Fix tx checksum offload for small packets.
- patches.drivers/USB3-0258-tty_port-usb-console-Fix-usb-serial-console-open-close-regre.patch:
  tty_port,usb-console: Fix usb serial console open/close
  regression.
- patches.drivers/USB3-0260-USB-serial-fix-error-message-on-close-in-generic-driver.patch:
  USB: serial: fix error message on close in generic driver.
- patches.drivers/USB3-0261-USB-serial-fix-softint-not-being-called-on-errors.patch:
  USB: serial: fix softint not being called on errors.
- patches.drivers/USB3-0262-USB-serial-use-port-endpoint-size-to-determine-if-ep-is-avai.patch:
  USB: serial: use port endpoint size to determine if ep is
  available.
- patches.drivers/USB3-0263-USB-unusual_devs.h-Fix-capacity-for-SL11R-IDE-2.6c.patch:
  USB: unusual_devs.h: Fix capacity for SL11R-IDE 2.6c.
- patches.drivers/USB3-0264-USB-Option-Add-support-for-a-variant-of-DLink-DWM-652-U5.patch:
  USB: Option: Add support for a variant of DLink DWM 652 U5.
- patches.drivers/USB3-0270-USB-xhci-rename-driver-to-xhci_hcd.patch:
  USB: xhci: rename driver to xhci_hcd.
- patches.drivers/USB3-0281-usb-cdc-wdm-Fix-race-between-write-and-disconnect.patch:
  usb: cdc-wdm: Fix race between write and disconnect.
- patches.drivers/USB3-0282-usb-cdc-wdm-Fix-race-between-autosuspend-and-reading-from-th.patch:
  usb: cdc-wdm: Fix race between autosuspend and reading from
  the device.
- patches.drivers/USB3-0283-usb-cdc-wdm-Fix-race-between-disconnect-and-debug-messages.patch:
  usb: cdc-wdm: Fix race between disconnect and debug messages.
- patches.drivers/USB3-0284-usb-cdc-wdm-Fix-submission-of-URB-after-suspension.patch:
  usb: cdc-wdm: Fix submission of URB after suspension.
- patches.drivers/USB3-0285-usb-cdc-wdm-Fix-loss-of-data-due-to-autosuspend.patch:
  usb: cdc-wdm:Fix loss of data due to autosuspend.
- patches.drivers/USB3-0286-usb-cdc-wdm-Fix-order-in-disconnect-and-fix-locking.patch:
  usb: cdc-wdm: Fix order in disconnect and fix locking.
- patches.drivers/USB3-0287-usb-cdc-wdm-Fix-deadlock-between-write-and-resume.patch:
  usb: cdc-wdm: Fix deadlock between write and resume.
- patches.drivers/USB3-0288-USB-serial-Fix-module-name-typo-for-qcaux-Kconfig-entry.patch:
  USB: serial: Fix module name typo for qcaux Kconfig entry.
- patches.drivers/USB3-0295-USB-ftdi_sio-Fix-locking-for-change_speed-function.patch:
  USB: ftdi_sio: Fix locking for change_speed() function.
- patches.drivers/USB3-0298-USB-cp210x-Remove-double-usb_control_msg-from-cp210x_set_con.patch:
  USB: cp210x: Remove double usb_control_msg from
  cp210x_set_config.
- patches.drivers/USB3-0299-USB-Fix-usb_fill_int_urb-for-SuperSpeed-devices.patch:
  USB: Fix usb_fill_int_urb for SuperSpeed devices.
- patches.drivers/USB3-0306-drivers-net-usb-Add-new-driver-ipheth.patch:
  drivers/net/usb: Add new driver ipheth.
- patches.drivers/USB3-0307-USB-ti_usb_3410_5052-adding-multitech-dialup-fax-modem-devic.patch:
  USB: ti_usb_3410_5052: adding multitech dialup fax/modem
  devices.
- patches.drivers/USB3-0308-USB-fixed-bug-in-usbsevseg-using-USB-autosuspend-incorrectly.patch:
  USB: fixed bug in usbsevseg using USB autosuspend incorrectly.
- patches.drivers/USB3-0310-usb-wusb-don-t-overflow-the-Keep-Alive-IE-buffer.patch:
  usb: wusb: don't overflow the Keep Alive IE buffer.
- patches.drivers/USB3-0311-USB-qcaux-add-LG-Rumor-and-Sanyo-Katana-LX-device-IDs.patch:
  USB: qcaux: add LG Rumor and Sanyo Katana LX device IDs.
- patches.drivers/USB3-0314-USB-pl2303-add-AdLink-ND-6530-USB-IDs.patch:
  USB: pl2303: add AdLink ND-6530 USB IDs.
- patches.drivers/USB3-0318-usb-Increase-timeout-value-for-device-reset.patch:
  usb: Increase timeout value for device reset.
- patches.drivers/USB3-0319-drivers-usb-net-kaweth.c-add-device-Allied-Telesyn-AT-USB10-.patch:
  drivers/usb/net/kaweth.c: add device "Allied Telesyn AT-USB10
  USB Ethernet Adapter".
- patches.drivers/USB3-0320-ipheth-potential-null-dereferences-on-error-path.patch:
  ipheth: potential null dereferences on error path.
- patches.drivers/USB3-0322-net-usb-add-sierra_net.c-driver.patch:
  net/usb: add sierra_net.c driver.
- patches.drivers/USB3-0340-USB-option-add-ID-for-ZTE-MF-330.patch:
  USB: option: add ID for ZTE MF 330.
- patches.drivers/USB3-0342-USB-serial-option-ZTEAC8710-Support-with-Device-ID-0xffff.patch:
  USB: serial: option: ZTEAC8710 Support with Device ID 0xffff.
- patches.drivers/USB3-0347-USB-ti_usb-fix-printk-format-warning.patch:
  USB: ti_usb: fix printk format warning.
- patches.drivers/USB3-0348-USB-rename-usb_buffer_alloc-and-usb_buffer_free.patch:
  USB: rename usb_buffer_alloc() and usb_buffer_free().
- patches.drivers/USB3-0351-net-usb-remove-default-in-Kconfig-for-sierra_net-driver.patch:
  net/usb: remove default in Kconfig for sierra_net driver.
- patches.drivers/USB3-0352-net-usb-initiate-sync-sequence-in-sierra_net.c-driver.patch:
  net/usb: initiate sync sequence in sierra_net.c driver.
- patches.suse/kdb-common: Refresh.
- patches.suse/usb-storage-disable-delay.patch: Delete.
* Thu Jun 30 2011 dsterba@suse.cz
- patches.suse/btrfs-fix-dio-locking.patch: Refresh.
* Thu Jun 30 2011 duwe@suse.de
- drop in code for IBM powerpc features as base for discussion:
  + bnc#700391 fate 311563 Update ipr driver for enabling the
    SAS VRAID functions (Power7/P7)
  + bnc#699265 fate#311643 Power7/P7: export data from new
    hcall H_BEST_ENERGY
  + bnc#700777 fate#311648: CPU dynamic affinity (performance)
  + bnc#699534 fate#311649: DLPAR Memory Remove for
    Shared Memory Partitions
  + bnc#700514 fate#311650: Power Virtual Ethernet
    performance enhancements (ibmveth driver)
  + bnc#699990 fate#311669: NPIV Support for 8GB Quad Port
    PCIe Gen 2 Fibre Channel adapter (ibmvfc driver update)
  + bnc#699703 fate#311672: Page Coalescing (kernel changes)
  + bnc#699701 fate#311674: Power7/P7 thread combinations
  + bnc#701198 fate#311687: Capture oops/panic reports to NVRAM
  + bnc#698548 fate#312285: Update the driver support for enabling
    the Bell2 (with PLX chip) 2-port adapter on POWER7/P7
- Update config files for bnc#699265 #311643.
* Thu Jun 30 2011 dsterba@suse.cz
- patches.suse/btrfs-fix-dio-locking.patch: Refresh.
* Thu Jun 30 2011 dsterba@suse.cz
- patches.suse/btrfs-fix-dio-locking.patch: Btrfs: fix DIO
  locking type (FATE#306586).
* Thu Jun 30 2011 jankit@suse.de
- patches.fixes/ses-requesting-a-fault-indication: [SCSI] ses:
  requesting a fault indication (FATE #311531).
* Thu Jun 30 2011 hare@suse.de
- patches.drivers/fnic-1.5.0.1-update: fnic: Update to 1.5.0.1
  (bnc#679301,FATE#311271,FATE#311071).
* Thu Jun 30 2011 hare@suse.de
- patches.fixes/fcoe-update-to-mainline: Fixup call to
  fcoe_transport_show().
* Thu Jun 30 2011 jankit@suse.de
- patches.fixes/dm-mpath-flush-workqueues-before-suspend-completes:
  Don't change the interface version number, revert earlier change.
  Update references (bnc#668483, bnc#703013).
* Thu Jun 30 2011 gregkh@suse.de
- patches.drivers/USB3-0144-wimax-i2400m-usb-remove-unnecessary-power-management.patch:
  wimax/i2400m/usb: remove unnecessary power management primitive
  in i2400m.
* Thu Jun 30 2011 gregkh@suse.de
- add my signed-off-by: to a few patches I missed:
- patches.drivers/USB3-0004-convert-kaweth-to-use-usb_reset_configuration.patch:
  Refresh.
- patches.drivers/USB3-0006-usbnet-Set-link-down-initially-for-drivers-that-update-link-.patch:
  Refresh.
- patches.drivers/USB3-0012-cdc-ether-Implement-reset_resume.patch:
  Refresh.
- patches.drivers/USB3-0013-usbnet-cdc-ether-Autosuspend-for-online-devices.patch:
  Refresh.
- patches.drivers/USB3-0143-usb-remove-rare-pm-primitive-for-conversion-to-new-API.patch:
  Refresh.
- patches.drivers/USB3-0149-const-constify-remaining-dev_pm_ops.patch:
  Refresh.
- patches.drivers/USB3-0185-usbnet-test-off-by-one.patch: Refresh.
- patches.drivers/USB3-0186-hso-Add-Vendor-Product-ID-s-for-new-devices.patch:
  Refresh.
- patches.drivers/USB3-0187-hso-Fix-for-endian-issues-on-big-endian-machines.patch:
  Refresh.
- patches.drivers/USB3-0188-hso-don-t-change-the-state-of-a-closed-port.patch:
  Refresh.
- patches.drivers/USB3-0189-hso-Attempt-to-recover-from-usb-bus-errors.patch:
  Refresh.
- patches.drivers/USB3-0190-hso-Fix-for-5-sec-timeouts-with-v2.x-firmware.patch:
  Refresh.
- patches.drivers/USB3-0191-hso-fixed-missing-newlines.patch:
  Refresh.
- patches.drivers/USB3-0206-cdc_ether-Partially-revert-usbnet-Set-link-down-initially.patch:
  Refresh.
* Thu Jun 30 2011 gregkh@suse.de
- USB 3.0 update for SLE11 SP2.  .32->.33 update, which consists of
  all of the following patches:
- patches.drivers/USB3-0004-convert-kaweth-to-use-usb_reset_configuration.patch:
  convert kaweth to use usb_reset_configuration().
- patches.drivers/USB3-0006-usbnet-Set-link-down-initially-for-drivers-that-update-link-.patch:
  usbnet: Set link down initially for drivers that update
  link state.
- patches.drivers/USB3-0011-drivers-net-Move-and-to-end-of-previous-line.patch:
  drivers/net: Move && and || to end of previous line.
- patches.drivers/USB3-0012-cdc-ether-Implement-reset_resume.patch:
  cdc-ether: Implement reset_resume().
- patches.drivers/USB3-0013-usbnet-cdc-ether-Autosuspend-for-online-devices.patch:
  usbnet & cdc-ether: Autosuspend for online devices.
- patches.drivers/USB3-0014-ehci-hcd-Fix-typo-in-an-error-message.patch:
  ehci-hcd: Fix typo in an error message.
- patches.drivers/USB3-0015-tree-wide-fix-assorted-typos-all-over-the-place.patch:
  tree-wide: fix assorted typos all over the place.
- patches.drivers/USB3-0019-firmware_class-make-request_firmware_nowait-more-useful.patch:
  firmware_class: make request_firmware_nowait more useful.
- patches.drivers/USB3-0020-USB-serial-ftdi_sio-add-space-mark-parity.patch:
  USB: serial: ftdi_sio: add space/mark parity.
- patches.drivers/USB3-0021-USB-ehci-hub-Remove-redundant-ehci-debug-check.patch:
  USB: ehci-hub: Remove redundant ehci->debug check.
- patches.drivers/USB3-0022-USB-Convert-a-dev_info-to-a-dev_dbg.patch:
  USB: Convert a dev_info to a dev_dbg.
- patches.drivers/USB3-0023-USB-usb-storage-Associate-the-name-of-the-interface-with-the.patch:
  USB: usb-storage: Associate the name of the interface with
  the scsi host.
- patches.drivers/USB3-0024-USB-Storage-Make-driver-less-chatty-when-it-finds-a-new-devi.patch:
  USB Storage: Make driver less chatty when it finds a new device.
- patches.drivers/USB3-0026-USB-Add-missing-static-markers-to-ohci-pnx4008.patch:
  USB: Add missing static markers to ohci-pnx4008.
- patches.drivers/USB3-0027-USB-make-urb-scatter-gather-support-more-generic.patch:
  USB: make urb scatter-gather support more generic.
- patches.drivers/USB3-0028-USB-whci-hcd-support-urbs-with-scatter-gather-lists.patch:
  USB: whci-hcd: support urbs with scatter-gather lists.
- patches.drivers/USB3-0029-USB-allow-interrupt-transfers-to-WUSB-devices.patch:
  USB: allow interrupt transfers to WUSB devices.
- patches.drivers/USB3-0030-USB-whci-hcd-fix-type-and-format-warnings-in-sg-code.patch:
  USB: whci-hcd: fix type and format warnings in sg code.
- patches.drivers/USB3-0035-USB-usbtmc-minor-formatting-cleanups.patch:
  USB: usbtmc: minor formatting cleanups.
- patches.drivers/USB3-0036-usb-whci-hcd-decode-more-QHead-fields-in-the-debug-files.patch:
  usb: whci-hcd: decode more QHead fields in the debug files.
- patches.drivers/USB3-0037-USB-wusb-add-wusb_phy_rate-sysfs-file-to-host-controllers.patch:
  USB: wusb: add wusb_phy_rate sysfs file to host controllers.
- patches.drivers/USB3-0041-USB-improved-error-handling-in-usb_port_suspend.patch:
  USB: improved error handling in usb_port_suspend().
- patches.drivers/USB3-0042-USB-xhci-Handle-URB-cancel-complete-and-resubmit-race.patch:
  USB: xhci: Handle URB cancel, complete and resubmit race.
- patches.drivers/USB3-0043-USB-xhci-Re-purpose-xhci_quiesce.patch:
  USB: xhci: Re-purpose xhci_quiesce().
- patches.drivers/USB3-0044-USB-xhci-Add-watchdog-timer-for-URB-cancellation.patch:
  USB: xhci: Add watchdog timer for URB cancellation.
- patches.drivers/USB3-0045-USB-xhci-Remove-unused-HCD-statistics-code.patch:
  USB: xhci: Remove unused HCD statistics code.
- patches.drivers/USB3-0046-USB-ehci-Minor-constant-fix-for-SCHEDULE_SLOP.patch:
  USB: ehci: Minor constant fix for SCHEDULE_SLOP.
- patches.drivers/USB3-0047-USB-ehci-Respect-IST-when-scheduling-new-split-iTDs.patch:
  USB: ehci: Respect IST when scheduling new split iTDs.
- patches.drivers/USB3-0048-USB-don-t-use-a-fixed-DMA-mapping-for-hub-status-URBs.patch:
  USB: don't use a fixed DMA mapping for hub status URBs.
- patches.drivers/USB3-0049-USB-add-a-remove-hardware-sysfs-attribute.patch:
  USB: add a "remove hardware" sysfs attribute.
- patches.drivers/USB3-0050-USB-fix-a-bug-in-the-scatter-gather-library.patch:
  USB: fix a bug in the scatter-gather library.
- patches.drivers/USB3-0061-USB-Interface-Association-Descriptors-added-to-CDC-RNDIS.patch:
  USB: Interface Association Descriptors added to CDC & RNDIS.
- patches.drivers/USB3-0062-USB-serial-sierra-driver-memory-reduction.patch:
  USB: serial: sierra driver memory reduction.
- patches.drivers/USB3-0063-USB-EHCI-add-native-scatter-gather-support.patch:
  USB: EHCI: add native scatter-gather support.
- patches.drivers/USB3-0064-USB-add-scatter-gather-support-to-usbmon.patch:
  USB: add scatter-gather support to usbmon.
- patches.drivers/USB3-0066-USB-Check-results-of-dma_map_single.patch:
  USB: Check results of dma_map_single.
- patches.drivers/USB3-0070-USB-ark3116-Setup-some-basic-infrastructure-for-new-ark3116-.patch:
  USB: ark3116: Setup some basic infrastructure for new ark3116
  driver.
- patches.drivers/USB3-0071-USB-ark3116-Make-existing-functions-16450-aware-and-add-clos.patch:
  USB: ark3116: Make existing functions 16450-aware and add
  close and release functions.
- patches.drivers/USB3-0072-USB-ark3116-Replace-cmget.patch:
  USB: ark3116: Replace cmget.
- patches.drivers/USB3-0073-USB-ark3116-Add-cmset-and-break.patch:
  USB: ark3116: Add cmset and break.
- patches.drivers/USB3-0074-USB-ark3116-Callbacks-for-interrupt-and-bulk-read.patch:
  USB: ark3116: Callbacks for interrupt and bulk read.
- patches.drivers/USB3-0075-USB-ark3116-Cleanup-of-now-unneeded-functions.patch:
  USB: ark3116: Cleanup of now unneeded functions.
- patches.drivers/USB3-0077-USB-hcd.c-quiet-NULL-pointer-sparse-noise.patch:
  USB: hcd.c: quiet NULL pointer sparse noise.
- patches.drivers/USB3-0078-USB-remove-the-auto_pm-flag.patch:
  USB: remove the auto_pm flag.
- patches.drivers/USB3-0080-USB-fix-possible-null-deref-in-init_usb_class.patch:
  USB: fix possible null deref in init_usb_class().
- patches.drivers/USB3-0081-usbtest-make-module-param-pattern-writeable.patch:
  usbtest: make module param pattern writeable.
- patches.drivers/USB3-0082-USB-xhci-Add-tests-for-TRB-address-translation.patch:
  USB: xhci: Add tests for TRB address translation.
- patches.drivers/USB3-0088-USB-composite-usb_composite_unregister-no-longer-__exit.patch:
  USB: composite: usb_composite_unregister() no longer __exit.
- patches.drivers/USB3-0091-USB-xhci-Set-transfer-descriptor-size-field-correctly.patch:
  USB: xhci: Set transfer descriptor size field correctly.
- patches.drivers/USB3-0092-USB-xhci-Return-EPROTO-on-a-split-transaction-error.patch:
  USB: xhci: Return -EPROTO on a split transaction error.
- patches.drivers/USB3-0093-USB-xhci-Return-success-for-vendor-specific-info-codes.patch:
  USB: xhci: Return success for vendor-specific info codes.
- patches.drivers/USB3-0094-USB-xhci-Handle-errors-that-cause-endpoint-halts.patch:
  USB: xhci: Handle errors that cause endpoint halts.
- patches.drivers/USB3-0113-USB-add-devpath-sysfs-attribute.patch:
  USB: add devpath sysfs attribute.
- patches.drivers/USB3-0114-USB-prepare-for-changover-to-Runtime-PM-framework.patch:
  USB: prepare for changover to Runtime PM framework.
- patches.drivers/USB3-0117-USB-whci-hcd-correctly-handle-sg-lists-longer-than-QTD_MAX_X.patch:
  USB: whci-hcd: correctly handle sg lists longer than
  QTD_MAX_XFER_SIZE.
- patches.drivers/USB3-0118-USB-wusb-don-t-leak-urb-in-certain-error-cases.patch:
  USB: wusb: don't leak urb in certain error cases.
- patches.drivers/USB3-0119-USB-wusb-correctly-check-size-of-security-descriptor.patch:
  USB: wusb: correctly check size of security descriptor.
- patches.drivers/USB3-0122-USB-add-remove_id-sysfs-attr-for-usb-drivers.patch:
  USB: add remove_id sysfs attr for usb drivers.
- patches.drivers/USB3-0123-USB-xhci-mem.c-introduce-missing-kfree.patch:
  USB: xhci-mem.c: introduce missing kfree.
- patches.drivers/USB3-0125-USB-usbtmc-Use-usb_clear_halt-instead-of-custom-code.patch:
  USB: usbtmc: Use usb_clear_halt() instead of custom code.
- patches.drivers/USB3-0126-USB-xhci-Make-reverting-an-alt-setting-unfailable.patch:
  USB: xhci: Make reverting an alt setting "unfailable".
- patches.drivers/USB3-0127-USB-xhci-Fix-command-completion-after-a-drop-endpoint.patch:
  USB: xhci: Fix command completion after a drop endpoint.
- patches.drivers/USB3-0128-USB-Refactor-code-to-find-alternate-interface-settings.patch:
  USB: Refactor code to find alternate interface settings.
- patches.drivers/USB3-0129-USB-Check-bandwidth-when-switching-alt-settings.patch:
  USB: Check bandwidth when switching alt settings.
- patches.drivers/USB3-0131-USB-core-fix-sparse-warning-for-static-function.patch:
  USB: core: fix sparse warning for static function.
- patches.drivers/USB3-0132-USB-core-hub-fix-sparse-warning.patch:
  USB: core: hub: fix sparse warning.
- patches.drivers/USB3-0133-USB-core-message-fix-sparse-warning.patch:
  USB: core: message: fix sparse warning.
- patches.drivers/USB3-0139-tty_port-add-tty_port_open-helper.patch:
  tty_port: add "tty_port_open" helper.
- patches.drivers/USB3-0140-usb_serial-Use-the-shutdown-operation.patch:
  usb_serial: Use the shutdown() operation.
- patches.drivers/USB3-0141-usb_serial-Kill-port-mutex.patch:
  usb_serial: Kill port mutex.
- patches.drivers/USB3-0142-opticon-Fix-resume-logic.patch:
  opticon: Fix resume logic.
- patches.drivers/USB3-0143-usb-remove-rare-pm-primitive-for-conversion-to-new-API.patch:
  usb: remove rare pm primitive for conversion to new API.
- patches.drivers/USB3-0149-const-constify-remaining-dev_pm_ops.patch:
  const: constify remaining dev_pm_ops.
- patches.drivers/USB3-0163-USB-fix-section-mismatch-in-early-ehci-dbgp.patch:
  USB: fix section mismatch in early ehci dbgp.
- patches.drivers/USB3-0164-USB-add-device-ID-for-Apple-Cinema-Display-23in-2007.patch:
  USB: add device ID for Apple Cinema Display 23in 2007.
- patches.drivers/USB3-0165-USB-core-fix-recent-kernel-doc-warnings.patch:
  USB core: fix recent kernel-doc warnings.
- patches.drivers/USB3-0185-usbnet-test-off-by-one.patch: usbnet:
  test off by one.
- patches.drivers/USB3-0186-hso-Add-Vendor-Product-ID-s-for-new-devices.patch:
  hso: Add Vendor/Product ID's for new devices.
- patches.drivers/USB3-0187-hso-Fix-for-endian-issues-on-big-endian-machines.patch:
  hso: Fix for endian issues on big endian machines.
- patches.drivers/USB3-0188-hso-don-t-change-the-state-of-a-closed-port.patch:
  hso: don't change the state of a closed port.
- patches.drivers/USB3-0189-hso-Attempt-to-recover-from-usb-bus-errors.patch:
  hso: Attempt to recover from usb bus errors.
- patches.drivers/USB3-0190-hso-Fix-for-5-sec-timeouts-with-v2.x-firmware.patch:
  hso: Fix for 5 sec timeouts with v2.x firmware.
- patches.drivers/USB3-0191-hso-fixed-missing-newlines.patch:
  hso: fixed missing newlines.
- patches.drivers/USB3-0200-USB-Fix-duplicate-sysfs-problem-after-device-reset.patch:
  USB: Fix duplicate sysfs problem after device reset.
- patches.drivers/USB3-0206-cdc_ether-Partially-revert-usbnet-Set-link-down-initially.patch:
  cdc_ether: Partially revert "usbnet: Set link down initially
  ...".
- patches.drivers/USB3-0213-USB-storage-Remove-unneeded-SC-PR-from-unusual_devs.h.patch:
  USB: storage: Remove unneeded SC/PR from unusual_devs.h.
- patches.drivers/USB3-0217-USB-ehci-phy-low-power-mode-bug-fixing.patch:
  USB: ehci: phy low power mode bug fixing.
- patches.drivers/USB3-0219-USB-serial-add-usbid-for-dell-wwan-card-to-sierra.c.patch:
  USB: serial: add usbid for dell wwan card to sierra.c.
- patches.suse/kdb-common: Refresh.
* Wed Jun 29 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-118-Add-a-fix-up-for-HP-RP5800-laptop:
  ALSA: hda - Add a fix-up for HP RP5800 laptop (bnc#701622).
* Wed Jun 29 2011 trenn@suse.de
- Update config files:
  - CONFIG_PSTORE=y (for i386, x86_64 and Xen x86_64)
  - # CONFIG_PSTORE is not set (for all the rest)
  - > pstore is used by APEI only enable it on relevant archs.
- patches.drivers/002-apei_pstore.patch: new error reporting
  interface with APEI (fate#311705).
* Wed Jun 29 2011 hare@suse.de
- Update config files:
  - CONFIG_ISCSI_BOOT_SYSFS=m
* Wed Jun 29 2011 jslaby@suse.de
- patches.fixes/tty-ldisc-do-not-close-until-there-are-readers.patch:
  TTY: ldisc, do not close until there are readers (bnc#698247
  bnc#693374).
* Wed Jun 29 2011 jankit@suse.de
- patches.fixes/fcoe-update-to-mainline: Sync fcoe stack with
  mainline (FATE#311954, bnc#687065).
* Wed Jun 29 2011 trenn@suse.de
- Update config files:
    For all i386/x86_64 and XEN (only x86_64):
  - CONFIG_ACPI_HED=m
  - CONFIG_ACPI_APEI=y
  - CONFIG_ACPI_APEI_GHES=m
  - CONFIG_ACPI_APEI_EINJ=m
  - CONFIG_ACPI_APEI_ERST_DEBUG=m
    For ia64:
  - # CONFIG_ACPI_HED is not set
- supported.conf:
  - kernel/drivers/acpi/apei/einj
  - kernel/drivers/acpi/apei/ghes
  - kernel/drivers/acpi/apei/erst-dbg
  - kernel/drivers/acpi/apei/hed
- patches.drivers/001-apei_infrastructure.patch:
  APEI infrastructure support
  (fate#311701,fate#311703,fate#311704,fate#311771,fate#311706,fate#311772,bnc#697859).
- patches.xen/xen-x86-ioremap_xen.patch: XEN:
  Implement ioremap_page_range for XEN used by APEI
  (fate#311701,fate#311703,fate#311704,fate#311771,fate#311706,fate#311772,bnc#697859).
- patches.xen/xen3-auto-common.diff: Refresh.
- patches.xen/xen3-auto-xen-kconfig.diff: Refresh.
- patches.xen/xen3-patch-2.6.19: Refresh.
- patches.xen/xen3-patch-2.6.30: Refresh.
- patches.xen/xen3-patch-2.6.31: Refresh.
* Wed Jun 29 2011 rw@suse.de
- patches.suse/dm-raid45-26-Nov-2009.patch:
  Refresh and reenable.
- Update config files.
* Wed Jun 29 2011 mmarek@suse.cz
- Refresh patches to apply cleanly:
  patches.drivers/cxgb3i-change-cxgb3i-to-use-libcxgbi.patch
  patches.drivers/cxgb4i-v5-iscsi-driver.patch
  patches.suse/iscsi-boot-mv-iscsi_boot_sysfs-to-drivers-sc.patch
* Wed Jun 29 2011 hare@suse.de
- patches.drivers/mptfusion-Update-to-4.28.00.00suse.patch:
  Fixup merge error.
- patches.suse/iscsi-boot-mv-iscsi_boot_sysfs-to-drivers-sc.patch:
  iscsi boot: mv iscsi_boot_sysfs to drivers/scsi
  (FATE#311488,bnc#702736).
* Wed Jun 29 2011 hare@suse.de
- Update config files.
- patches.drivers/3w-sas-mainline.patch: 3w-sas: Add new driver
  from mainline (bnc#702832).
- patches.drivers/pm8001-mainline.patch: pm8001: Add new driver
  from mainline (bnc#702838).
- supported.conf: Update to include 3w-sas and pm8001.
* Wed Jun 29 2011 jbeulich@novell.com
- patches.xen/xen3-x86-Introduce-pci_map_biosrom.patch: Fix build
  of unprivileged configurations.
* Tue Jun 28 2011 jack@suse.cz
- patches.suse/cfq-iosched-Always-provide-group-isolation.patch:
  cfq-iosched: Always provide group isolation (fate#312039).
- patches.suse/cfq-iosched-Don-t-update-group-weights-when-on-servi.patch:
  Refresh.
* Tue Jun 28 2011 ptesarik@suse.cz
- patches.fixes/initialize-call_single_queue-before-enabling-interrupt:
  smp: add missing init.h include.
* Tue Jun 28 2011 jbeulich@novell.com
- Update Xen patches to 2.6.32.42 and c/s 1095.
- patches.xen/xen-x86-EFI: support booting Xen from EFI
  (fate#311376, fate#311529, bnc#578927, bnc#628554).
- patches.xen/xen3-0011-x86-Export-k8-physical-topology.patch:
  x86: Export k8 physical topology (fate#311968 fate#309727).
- patches.xen/xen3-0018-x86-k8-Rename-k8.-ch-to-amd_nb.-ch-and.patch:
  and (fate#311968).
- patches.xen/xen3-0022-x86-amd-Extract-compute-unit-information-for-AMD-CPU.patch:
  x86, amd: Extract compute unit information for AMD CPUs
  (fate#309723).
- patches.xen/xen3-0027-x86-amd-nb-Complete-the-rename-of-AMD-NB-and.patch:
  x86, amd-nb: Complete the rename of AMD NB and (fate#311968).
- patches.xen/xen3-004-ACPI__allow_a_native_cpuidle_driver_to_displace_ACPI.patch:
  ACPI: allow a native cpuidle driver to displace ACPI
  (fate#311818,fate#311942).
- patches.xen/xen3-0124-x86-amd-Support-L3-Cache-Partitioning-on-AMD-family-.patch:
  x86, amd: Support L3 Cache Partitioning on AMD family 0x15 CPUs
  (fate#309727).
- patches.xen/xen3-VMware-Balloon-driver-2.6.32.28.patch: Refresh.
- patches.xen/xen3-dev_mem-read-write-beyond-EOF.patch: Return
  EOF on out-of-bounds read from /dev/mem (FATE#310031).
- patches.xen/xen3-dev_mem-read-write-phys_addr_t.patch: Allow
  reading/writing all memory through /dev/mem (FATE#310031).
- patches.xen/xen3-kvm-x86-Export-FPU-API-for-KVM-use.patch:
  x86: Export FPU API for KVM use (FATE#311768).
- patches.xen/xen3-printk-Allocate-kernel-log-buffer-earlier.patch:
  printk: Allocate kernel log buffer earlier v1 (bnc#700445).
- patches.xen/xen3-repmovs-06-fix-cpuid-leaf-7-feature-detection.patch:
  x86, cpufeature: Fix cpuid leaf 7 feature detection (FATE#311936
  bnc#698793).
- patches.xen/xen3-scsi-host-lock-push-down.patch: SCSI host
  lock push-down (FATE#311826).
- patches.xen/xen3-x86-Eliminate-TS_XSAVE.patch: x86: Eliminate
  TS_XSAVE (FATE#311768).
- patches.xen/xen3-x86-Introduce-pci_map_biosrom.patch: x86:
  Introduce pci_map_biosrom() (FATE#311808).
- patches.xen/xen3-x86-Introduce-struct-fpu-and-related-API.patch:
  x86: Introduce 'struct fpu' and related API (FATE#311768).
- patches.xen/xen3-x86-enable-smep.patch: Enable SMEP
  (FATE#311999).
- patches.xen/xen3-x86-features-flags-in-new-CPUID-leaf.patch:
  x86, cpu: Support the features flags in new CPUID leaf 7
  (bnc#698779 fate#311965).
- patches.xen/xen3-x86-ioremap-fix-pae.patch: x86, ioremap: Fix
  incorrect physical address handling in PAE mode (FATE#310031).
- patches.xen/xen3-xlate_dev_mem_ptr-use-phys_addr_t.patch:
  (un)xlate_dev_mem_ptr: use phys_addr_t for the @phys parameter
  (FATE#310031).
- patches.xen/xen3-xsaveopt-06-use-xsaveopt-in-context-switch-path.patch:
  x86, xsave: Use xsaveopt in context-switch path when supported
  (bnc#698779 fate#311965).
- Refresh other Xen patches.
- Update Xen config files.
- supported.conf: Mark rtc-efi supported.
* Tue Jun 28 2011 hare@suse.de
- supported.conf: Mark cxgb3i and cxbg4i as supported.
* Tue Jun 28 2011 mhocko@suse.de
- patches.fixes/vm-fix-vm_pgoff-wrap-in-upward-expansion.patch:
  Refresh.
* Tue Jun 28 2011 hare@suse.de
- patches.drivers/enic-2.1.1.20-1-update: enic: Update driver
  to 2.1.1.20-1 (FATE#311271,bnc#699687).
* Tue Jun 28 2011 mhocko@suse.cz
- patches.fixes/vm-fix-vm_pgoff-wrap-in-stack-expansion.patch:
  vm: fix vm_pgoff wrap in stack expansion (bnc#702285,
  CVE-2011-2496).
- patches.fixes/vm-fix-vm_pgoff-wrap-in-upward-expansion.patch:
  vm: fix vm_pgoff wrap in upward expansion (bnc#702285,
  CVE-2011-2496).
* Tue Jun 28 2011 ptesarik@suse.cz
- patches.fixes/initialize-call_single_queue-before-enabling-interrupt:
  generic-ipi: Fix kexec boot crash by initializing
  call_single_queue before enabling interrupts (bnc#699946).
* Tue Jun 28 2011 hare@suse.de
- Update cxgb3i and cxgb4i driver (FATE#311932):
  * patches.drivers/cxgb3-Added-private-MAC-address-and-provisioning-pa.patch:
    cxgb3: Added private MAC address and provisioning packet
    handler for iSCSI (FATE#311932,bnc#694963).
  * patches.drivers/cxgb3i-change-cxgb3i-to-use-libcxgbi.patch:
    cxgb3i: change cxgb3i to use libcxgbi
    (FATE#311932,bnc#694963).
  * patches.drivers/cxgb3i-fixed-connection-over-vlan.patch: [SCSI]
    cxgb3i: fixed connection over vlan (FATE#311932,bnc#694963).
  * patches.drivers/cxgb3i-fixed-connection-problem-with-iscsi-p.patch:
    cxgb3i: fixed connection problem with iscsi private ip
    (FATE#311932,bnc#694963).
  * patches.drivers/cxgb4i-connection-and-ddp-setting-update.patch:
    cxgb4i: connection and ddp setting update
    (FATE#311932,bnc#694963).
  * patches.drivers/cxgb4i-ignore-informational-act-open-rpl-mes.patch:
    cxgb4i: ignore informational act-open-rpl message
    (FATE#311932,bnc#694963).
  * patches.drivers/cxgb4i-v5-iscsi-driver.patch: cxgb4i v5:
    iscsi driver (FATE#311932,bnc#694963).
  * patches.drivers/cxgbi-convert-to-use-iscsi_conn_get_addr_par.patch:
    cxgbi: convert to use iscsi_conn_get_addr_param
    (FATE#311932,bnc#694963).
  * patches.drivers/cxgbi-enable-TEXT-PDU-support.patch:
    cxgbi: enable TEXT PDU support (FATE#311932,bnc#694963).
  * patches.drivers/cxgbi-get-rid-of-gl_skb-in-cxgbi_ddp_info.patch:
    cxgbi: get rid of gl_skb in cxgbi_ddp_info
    (FATE#311932,bnc#694963).
  * patches.drivers/cxgbi-rename-alloc_cpl-to-alloc_wr.patch:
    cxgbi: rename alloc_cpl to alloc_wr (FATE#311932,bnc#694963).
  * patches.drivers/cxgbi-set-ulpmode-only-if-digest-is-on.patch:
    cxgbi: set ulpmode only if digest is on
    (FATE#311932,bnc#694963).
  * patches.drivers/libcxgbi-common-library-for-cxgb3i-and-cxgb4.patch:
    libcxgbi: common library for cxgb3i and cxgb4i
    (FATE#311932,bnc#694963).
  * patches.drivers/libcxgbi-pdu-read-fixes.patch: libcxgbi:
    pdu read fixes (FATE#311932,bnc#694963).
* Tue Jun 28 2011 trenn@suse.de
- patches.arch/0001-x86-cpu-Add-AMD-core-boosting-feature-flag-to-proc-c.patch:
  Refresh.
- patches.arch/x2apic_opt_out.patch: x86, vt-d: enable x2apic
  opt out (disabling x2apic through BIOS flag) (bnc#701183,
  fate#311989).
- patches.arch/x86_intel_set_default_energy_perf_bias.patch: x86
  intel: Set perf BIAS MSR to default value on boot (bnc#702604).
- patches.arch/x86_intel_show_ebp_cpuinfo_flag.patch: x86:
  Look for IA32_ENERGY_PERF_BIAS support (bnc#702604).
- patches.drivers/hwmon-coretemp-add-pkgtemp-support.patch:
  Refresh.
* Tue Jun 28 2011 hare@suse.de
- patches.drivers/bfa-2.3.2.3-update: bfa: Update to version
  2.3.2.3 (FATE#311450,bnc#689227).
* Tue Jun 28 2011 hare@suse.de
- patches.drivers/mpt2sas-09.102.00.00-update: mpt2sas: Update
  to version 09.102.00.00 (FATE#311801,bnc#680809).
* Tue Jun 28 2011 mhocko@suse.cz
- patches.fixes/NLM-Don-t-hang-forever-on-NLM-unlock-requests-fix.patch:
  Hide new tk_rebind_retry from kABI checker (bnc#702013).
- patches.fixes/NLM-Don-t-hang-forever-on-NLM-unlock-requests.patch:
  NLM: Don't hang forever on NLM unlock requests (bnc#702013
  CVE-2011-2491).
* Tue Jun 28 2011 hare@suse.de
- patches.suse/block-use-struct-parsed_partitions-state-universal.patch:
  Fix crash in ibm_partition (bnc#702470).
* Tue Jun 28 2011 hare@suse.de
- patches.drivers/qla4xxx-5.02.10.00.11.2-k0-update: qla4xxx:
  Update to 5.02.10.00.11.2-k0 (FATE#311466,bnc#689435).
* Tue Jun 28 2011 hare@suse.de
- patches.drivers/qla2xxx-8.03.07.05.11.2-k-update: qla2xxx:
  Update to 8.03.07.05.11.2-k (FATE#311465,bnc#690082).
* Mon Jun 27 2011 jeffm@suse.com
- Updated patch-mainline to reflect upstream status of:
  - patches.drivers/cnic-give-a-chance-for-the-uio-device-to-be-opened
  - patches.drivers/0009-cnic-Revert-cnic-Give-a-chance-for-the-uio-device-to.patch
* Mon Jun 27 2011 jeffm@suse.com
- patches.drivers/0152-bnx2x-fix-possible-deadlock-in-HC-hw-block.patch:
  bnx2x: fix possible deadlock in HC hw block (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0153-bnx2x-prevent-false-parity-error-in-MSI-X-memory-of-.patch:
  bnx2x: prevent false parity error in MSI-X memory of HC block
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0154-bnx2x-update-version-to-1.60.00-3.patch:
  bnx2x: update version to 1.60.00-3 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0155-bnx2-Increase-max-rx-ring-size-from-1K-to-2K.patch:
  bnx2: Increase max rx ring size from 1K to 2K (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0156-bnx2x-make-local-function-static-and-remove-dead-cod.patch:
  bnx2x: make local function static and remove dead code
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0157-bnx2x-Restore-appropriate-delay-during-BMAC-reset.patch:
  bnx2x: Restore appropriate delay during BMAC reset (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0158-bnx2x-Fix-waiting-for-reset-complete-on-BCM848x3-PHY.patch:
  bnx2x: Fix waiting for reset complete on BCM848x3 PHYs
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0159-bnx2x-Fix-port-selection-in-case-of-E2.patch:
  bnx2x: Fix port selection in case of E2 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0160-bnx2x-Clear-latch-indication-on-link-reset.patch:
  bnx2x: Clear latch indication on link reset (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0161-bnx2x-Fix-resetting-BCM8726-PHY-during-common-init.patch:
  bnx2x: Fix resetting BCM8726 PHY during common init (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0162-bnx2x-Do-not-enable-CL37-BAM-unless-it-is-explicitly.patch:
  bnx2x: Do not enable CL37 BAM unless it is explicitly enabled
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0163-bnx2x-Reset-8073-phy-during-common-init.patch:
  bnx2x: Reset 8073 phy during common init (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0164-bnx2x-Update-version-number.patch: bnx2x:
  Update version number (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0165-tree-wide-fix-comment-printk-typos.patch:
  tree-wide: fix comment/printk typos (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0166-bnx2x-Look-inside-vlan-when-determining-checksum-pro.patch:
  bnx2x: Look inside vlan when determining checksum proto
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0167-drivers-net-bnx2x-Remove-unnecessary-semicolons.patch:
  drivers/net/bnx2x: Remove unnecessary semicolons (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0168-drivers-net-cnic.c-Remove-unnecessary-semicolons.patch:
  drivers/net/cnic.c: Remove unnecessary semicolons (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0169-net-bnx2x-fix-error-value-sign.patch:
  net: bnx2x: fix error value sign (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0170-bnx2x-Disable-local-BHes-to-prevent-a-dead-lock-situ.patch:
  bnx2x: Disable local BHes to prevent a dead-lock situation
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0171-bnx2x-Do-interrupt-mode-initialization-and-NAPIs-add.patch:
  bnx2x: Do interrupt mode initialization and NAPIs adding
  before register_netdev() (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0172-bnx2-Fix-reset-bug-on-5709.patch: bnx2:
  Fix reset bug on 5709 (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0173-bnx2-Remove-config-access-to-non-standard-registers.patch:
  bnx2: Remove config access to non-standard registers
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0174-bnx2x-Use-helpers-instead-of-direct-access-to-the-sh.patch:
  bnx2x: Use helpers instead of direct access to the shinfo(skb)
  fields (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0175-bnx2x-Add-Nic-partitioning-mode-57712-devices.patch:
  bnx2x: Add Nic partitioning mode (57712 devices) (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0176-net-Fix-too-optimistic-NETIF_F_HW_CSUM-features.patch:
  net: Fix too optimistic NETIF_F_HW_CSUM features (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0177-bnx2x-LSO-code-was-broken-on-BE-platforms.patch:
  bnx2x: LSO code was broken on BE platforms (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0178-bnx2x-Use-dma_alloc_coherent-semantics-for-ILT-memor.patch:
  bnx2x: Use dma_alloc_coherent() semantics for ILT memory
  allocation (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0179-bnx2x-Fixed-a-compilation-warning.patch:
  bnx2x: Fixed a compilation warning (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0180-bnx2x-Update-version-number-and-a-date.patch:
  bnx2x: Update version number and a date (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0181-drivers-net-don-t-use-flush_scheduled_work.patch:
  drivers/net: don't use flush_scheduled_work() (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0182-bnx2x-Take-the-distribution-range-definition-out-of-.patch:
  bnx2x: Take the distribution range definition out of
  skb_tx_hash() (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0183-bnx2x-add-FCoE-ring.patch: bnx2x: add
  FCoE ring (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0184-bnx2x-add-a-select-queue-callback.patch:
  bnx2x: add a select queue callback (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0185-bnx2x-add-DCB-support.patch: bnx2x: add
  DCB support (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0186-bnx2x-Add-DCB-PFC-support-link-layer.patch:
  bnx2x: Add DCB/PFC support - link layer (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0187-bnx2x-add-FW-6.2.5-files.patch: bnx2x:
  add FW 6.2.5 files (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0188-bnx2x-replace-FW-to-6.2.5.patch: bnx2x:
  replace FW to 6.2.5 (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0189-bnx2x-remove-old-FW-files.patch: bnx2x:
  remove old FW files (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0190-bnx2x-update-version-to-1.62.00-2.patch:
  bnx2x: update version to 1.62.00-2 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0191-drivers-net-.c-Use-static-const.patch:
  drivers/net/*.c: Use static const (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0192-drivers-net-Use-static-const.patch:
  drivers/net/*/: Use static const (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0193-bnx2i-Fixed-bugs-in-the-handling-of-unsolicited-NOP-.patch:
  bnx2i: Fixed bugs in the handling of unsolicited NOP-Ins
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0194-bnx2i-Added-fix-for-NOP-Out-response-panic-from-unso.patch:
  bnx2i: Added fix for NOP-Out response panic from unsolicited
  NOP-In (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0195-bnx2i-Fixed-the-endian-bug-in-the-TMF-LUN-cmd-send.patch:
  bnx2i: Fixed the endian bug in the TMF LUN cmd send (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0196-bnx2i-Fixed-a-cid-leak-issue-for-5771X-10g.patch:
  bnx2i: Fixed a cid leak issue for 5771X (10g) (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0197-bnx2i-Fixed-the-remote-TCP-RST-handling-for-the-570X.patch:
  bnx2i: Fixed the remote TCP RST handling for the 570X (1g)
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0198-bnx2i-Allow-to-abort-the-connection-if-connect-reque.patch:
  bnx2i: Allow to abort the connection if connect request
  times out (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0199-bnx2i-Added-mutex-lock-protection-to-conn_get_param.patch:
  bnx2i: Added mutex lock protection to conn_get_param
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0200-bnx2i-Removed-the-dynamic-registration-of-CNIC.patch:
  bnx2i: Removed the dynamic registration of CNIC (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0201-bnx2i-Modified-the-bnx2i-stop-path-to-compensate-for.patch:
  bnx2i: Modified the bnx2i stop path to compensate for in
  progress ops (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0202-bnx2i-Added-return-code-check-for-chip-kwqe-submissi.patch:
  bnx2i: Added return code check for chip kwqe submission request
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0203-bnx2i-Cleaned-up-various-error-conditions-in-ep_conn.patch:
  bnx2i: Cleaned up various error conditions in
  ep_connect/disconnect (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0204-bnx2i-Updated-copyright-and-maintainer-info.patch:
  bnx2i: Updated copyright and maintainer info (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0205-bnx2i-Updated-version-to-2.6.2.2.patch:
  bnx2i: Updated version to 2.6.2.2 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0206-bnx2x-remove-bogus-check.patch: bnx2x:
  remove bogus check (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0207-bnx2-remove-cancel_work_sync-from-remove_one.patch:
  bnx2: remove cancel_work_sync() from remove_one (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0208-cnic-Fix-iSCSI-TCP-port-endian-order.patch:
  cnic: Fix iSCSI TCP port endian order (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0209-cnic-Prevent-scheduling-while-atomic-when-calling-cn.patch:
  cnic: Prevent "scheduling while atomic" when calling
  - >cnic_init() (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0210-cnic-Improve-iscsi_nl_msg_send.patch:
  cnic: Improve ->iscsi_nl_msg_send() (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0211-cnic-Use-proper-client-and-connection-IDs-on-iSCSI-r.patch:
  cnic: Use proper client and connection IDs on iSCSI ring
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0212-cnic-Support-NIC-Partition-mode.patch:
  cnic: Support NIC Partition mode (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0213-cnic-Check-device-state-before-reading-the-kcq-point.patch:
  cnic: Check device state before reading the kcq pointer in IRQ
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0214-cnic-Call-cm_connect_complete-immediately-on-error.patch:
  cnic: Call cm_connect_complete() immediately on error
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0215-cnic-Add-kcq2-support-on-57712.patch:
  cnic: Add kcq2 support on 57712 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0216-cnic-Add-FCoE-support-on-57712.patch:
  cnic: Add FCoE support on 57712 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0217-bnx2-Free-IRQ-before-freeing-status-block-memory.patch:
  bnx2: Free IRQ before freeing status block memory (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0218-bnx2-Update-firmware-and-version.patch:
  bnx2: Update firmware and version (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0219-Broadcom-CNIC-core-network-driver-fix-mem-leak-on-al.patch:
  Broadcom CNIC core network driver: fix mem leak on allocation
  failures in cnic_alloc_uio_rings() (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0220-cnic-Do-not-allow-iSCSI-and-FCoE-on-bnx2x-multi-func.patch:
  cnic: Do not allow iSCSI and FCoE on bnx2x multi-function mode
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0221-cnic-Do-not-call-bnx2i-when-bnx2i-is-calling-cnic_un.patch:
  cnic: Do not call bnx2i when bnx2i is calling
  cnic_unregister_driver() (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0222-cnic-Fix-the-type-field-in-SPQ-messages.patch:
  cnic: Fix the type field in SPQ messages (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0223-bnx2x-Don-t-prevent-RSS-configuration-in-INT-x-and-M.patch:
  bnx2x: Don't prevent RSS configuration in INT#x and MSI
  interrupt modes (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0224-bnx2x-registers-dump-fixes.patch: bnx2x:
  registers dump fixes (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0225-bnx2x-Move-to-D0-before-clearing-MSI-MSI-X-configura.patch:
  bnx2x: Move to D0 before clearing MSI/MSI-X configuration
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0226-bnx2x-Fix-the-race-on-bp-stats_pending.patch:
  bnx2x: Fix the race on bp->stats_pending (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0227-bnx2x-Swap-BCM8073-PHY-polarity-if-required.patch:
  bnx2x: Swap BCM8073 PHY polarity if required (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0228-bnx2x-Common-init-will-be-executed-only-once-after-P.patch:
  bnx2x: Common init will be executed only once after POR
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0229-bnx2x-LED-fix-for-BCM8727-over-BCM57712.patch:
  bnx2x: LED fix for BCM8727 over BCM57712 (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0230-bnx2x-Fix-BCM8073-BCM8727-microcode-loading.patch:
  bnx2x: Fix BCM8073/BCM8727 microcode loading (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0231-bnx2x-Mark-full-duplex-on-some-external-PHYs.patch:
  bnx2x: Mark full duplex on some external PHYs (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0232-bnx2x-Fix-BCM84823-LED-behavior.patch:
  bnx2x: Fix BCM84823 LED behavior (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0233-bnx2x-Fix-AER-setting-for-BCM57712.patch:
  bnx2x: Fix AER setting for BCM57712 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0234-bnx2x-Update-bnx2x-version-to-1.62.00-4.patch:
  bnx2x: Update bnx2x version to 1.62.00-4 (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0235-bnx2i-Added-reconnect-fix-connecting-against-Lefthan.patch:
  bnx2i: Added reconnect fix connecting against Lefthand targets
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0236-bnx2-Eliminate-AER-error-messages-on-systems-not-sup.patch:
  bnx2: Eliminate AER error messages on systems not supporting it
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0237-drivers-net-remove-some-rcu-sparse-warnings.patch:
  drivers/net: remove some rcu sparse warnings (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0238-bnx2x-Remove-setting-XAUI-low-power-for-BCM8073.patch:
  bnx2x: Remove setting XAUI low-power for BCM8073 (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0239-bnx2x-Fix-LED-blink-rate-on-BCM84823.patch:
  bnx2x: Fix LED blink rate on BCM84823 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0240-bnx2x-Fix-port-swap-for-BCM8073.patch:
  bnx2x: Fix port swap for BCM8073 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0241-bnx2x-Fix-potential-link-loss-in-multi-function-mode.patch:
  bnx2x: Fix potential link loss in multi-function mode
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0242-bnx2x-Update-bnx2x-version-to-1.62.00-5.patch:
  bnx2x: Update bnx2x version to 1.62.00-5 (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0243-bnx2x-Fix-line-indentation.patch: bnx2x:
  Fix line indentation (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0244-bnx2x-Rename-CL45-macro.patch: bnx2x:
  Rename CL45 macro (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0245-bnx2x-Set-comments-according-to-preferred-Linux-styl.patch:
  bnx2x: Set comments according to preferred Linux style
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0246-bnx2x-Fix-compilation-warning-messages.patch:
  bnx2x: Fix compilation warning messages (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0247-bnx2x-Add-and-change-some-net_dev-messages.patch:
  bnx2x: Add and change some net_dev messages (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0248-bnx2x-Enhance-SFP-module-control.patch:
  bnx2x: Enhance SFP+ module control (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0249-bnx2x-Add-support-for-new-PHY-BCM84833.patch:
  bnx2x: Add support for new PHY BCM84833 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0250-bnx2x-Add-CMS-functionality-for-848x3.patch:
  bnx2x: Add CMS functionality for 848x3 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0251-bnx2x-Remove-support-for-emulation-FPGA.patch:
  bnx2x: Remove support for emulation/FPGA (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0252-bnx2x-Update-bnx2x-version-to-1.62.11-0.patch:
  bnx2x: Update bnx2x version to 1.62.11-0 (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0253-bnx2x-cnic-Consolidate-iSCSI-FCoE-shared-mem-logic-i.patch:
  bnx2x, cnic: Consolidate iSCSI/FCoE shared mem logic in bnx2x
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0254-bnx2x-multicasts-in-NPAR-mode.patch: bnx2x:
  multicasts in NPAR mode (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0255-bnx2x-MTU-for-FCoE-L2-ring.patch: bnx2x:
  MTU for FCoE L2 ring (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0256-bnx2x-Duplication-in-promisc-mode.patch:
  bnx2x: Duplication in promisc mode (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0257-bnx2x-Proper-netdev-ndo_set_rx_mode-implementation.patch:
  bnx2x: Proper netdev->ndo_set_rx_mode() implementation
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0258-bnx2i-Allow-ep-CONNECT_FAILED-condition-to-go-throug.patch:
  bnx2i: Allow ep CONNECT_FAILED condition to go through proper
  cleanup (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0259-bnx2i-Fixed-the-32-bit-swapping-of-the-LUN-field-for.patch:
  bnx2i: Fixed the 32-bit swapping of the LUN field for nopouts
  for 5771X (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0260-bnx2i-Added-handling-for-unsupported-iSCSI-offload-h.patch:
  bnx2i: Added handling for unsupported iSCSI offload hba
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0261-bnx2i-Added-support-for-the-57712-E-devices.patch:
  bnx2i: Added support for the 57712(E) devices (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0262-bnx2i-Added-jumbo-MTU-support-for-the-no-shost-case.patch:
  bnx2i: Added jumbo MTU support for the no shost case
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0263-bnx2i-Added-iSCSI-text-pdu-support-for-iSCSI-offload.patch:
  bnx2i: Added iSCSI text pdu support for iSCSI offload
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0264-bnx2i-Updated-to-version-2.6.2.3.patch:
  bnx2i: Updated to version 2.6.2.3 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0265-bnx2x-Add-a-missing-bit-for-PXP-parity-register-of-5.patch:
  bnx2x: Add a missing bit for PXP parity register of 57712
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0266-bnx2x-NPAR-mode-Fix-FW-initialization.patch:
  bnx2x: (NPAR mode) Fix FW initialization (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0267-bnx2x-Fix-nvram-test-for-single-port-devices.patch:
  bnx2x: Fix nvram test for single port devices (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0268-bnx2x-Fix-ethtool-t-link-test-for-MF-non-pmf-devices.patch:
  bnx2x: Fix ethtool -t link test for MF (non-pmf) devices
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0269-bnx2x-properly-configure-coefficients-for-MinBW-algo.patch:
  bnx2x: properly configure coefficients for MinBW algorithm
  (NPAR mode) (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0270-bnx2x-perform-statistics-action-before-state-transit.patch:
  bnx2x: perform statistics "action" before state transition
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0271-bnx2x-properly-calculate-lro_mss.patch:
  bnx2x: properly calculate lro_mss (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
* Mon Jun 27 2011 ohering@suse.de
- patches.suse/fs-proc-vmcorec-add-hook-to-read_from_oldmem-to-check-for-non-ram-pages.patch:
  fs/proc/vmcore.c: add hook to read_from_oldmem() to check for
  non-ram pages (bnc#684297).
* Mon Jun 27 2011 trenn@suse.de
  Fate#311164,bnc#697859:
- patches.drivers/001-cpufreq_ondemand_count_iowait_as_busy:
  sched: Add a comment to get_cpu_idle_time_us()
  (fate#311164,bnc#698774).
- patches.drivers/002-cpufreq_ondemand_count_iowait_as_busy:
  sched: Introduce a function to update the idle statistics
  (fate#311164,bnc#698774).
- patches.drivers/003-cpufreq_ondemand_count_iowait_as_busy:
  sched: Update the idle statistics in get_cpu_idle_time_us()
  (fate#311164,bnc#698774).
- patches.drivers/004-cpufreq_ondemand_count_iowait_as_busy:
  sched: Fold updating of the last_update_time_info into
  update_ts_time_stats() (fate#311164,bnc#698774).
- patches.drivers/005-cpufreq_ondemand_count_iowait_as_busy:
  sched: Eliminate the ts->idle_lastupdate field
  (fate#311164,bnc#698774).
- patches.drivers/006-cpufreq_ondemand_count_iowait_as_busy:
  sched: Intoduce get_cpu_iowait_time_us()
  (fate#311164,bnc#698774).
- patches.drivers/007-cpufreq_ondemand_count_iowait_as_busy:
  ondemand: Solve a big performance issue by counting IOWAIT
  time as busy (fate#311164,bnc#698774).
* Mon Jun 27 2011 hare@suse.de
- patches.drivers/megaraid-sas-05.38-update: megaraid_sas:
  Update to 00.00.05.38-SL1 (FATE#311453,bnc#697777).
* Mon Jun 27 2011 hare@suse.de
- be2iscsi update (FATE#311449):
  * patches.drivers/0001-be2iscsi-fix-lock-imbalance.patch:
    be2iscsi: fix lock imbalance (FATE#311449,bnc#690073).
  * patches.drivers/0002-be2iscsi-correct-return-value-in-mgmt_invali.patch:
    be2iscsi: correct return value in mgmt_invalidate_icds()
    (FATE#311449,bnc#690073).
  * patches.drivers/0003-be2iscsi-fix-disconnection-cleanup.patch:
    be2iscsi: fix disconnection cleanup
    (FATE#311449,bnc#690073).
  * patches.drivers/0004-be2iscsi-fix-memory-leak-on-error-path.patch:
    be2iscsi: fix memory leak on error path
    (FATE#311449,bnc#690073).
  * patches.drivers/0005-be2iscsi-fix-null-dereference-on-error-path.patch:
    be2iscsi: fix null dereference on error path
    (FATE#311449,bnc#690073).
  * patches.drivers/0006-be2iscsi-Fix-warnings-from-new-checkpatch.pl.patch:
    be2iscsi: Fix warnings from new checkpatch.pl
    (FATE#311449,bnc#690073).
  * patches.drivers/0007-be2iscsi-Fixing-return-values.patch:
    be2iscsi: Fixing return values (FATE#311449,bnc#690073).
  * patches.drivers/0008-be2iscsi-Fixing-the-return-type-of-functions.patch:
    be2iscsi: Fixing the return type of functions
    (FATE#311449,bnc#690073).
  * patches.drivers/0009-be2iscsi-pass-the-return-from-beiscsi_open_c.patch:
    be2iscsi: pass the return from beiscsi_open_conn
    (FATE#311449,bnc#690073).
  * patches.drivers/0010-be2iscsi-Fix-for-freeing-cid.patch:
    be2iscsi: Fix for freeing cid (FATE#311449,bnc#690073).
  * patches.drivers/0011-be2iscsi-No-return-value-for-hwi_enable_intr.patch:
    be2iscsi: No return value for hwi_enable_intr
    (FATE#311449,bnc#690073).
  * patches.drivers/0012-be2iscsi-Fix-to-handle-request_irq-failure.patch:
    be2iscsi: Fix to handle request_irq failure
    (FATE#311449,bnc#690073).
  * patches.drivers/0013-be2iscsi-Free-tags-allocated.patch:
    be2iscsi: Free tags allocated (FATE#311449,bnc#690073).
  * patches.drivers/0014-be2iscsi-Adding-crashdump-support.patch:
    be2iscsi: Adding crashdump support
    (FATE#311449,bnc#690073).
  * patches.drivers/0015-be2iscsi-Maintain-same-ITT-across-login.patch:
    be2iscsi: Maintain same ITT across login
    (FATE#311449,bnc#690073).
  * patches.drivers/0016-be2iscsi-Limit-max_xmit_length.patch:
    be2iscsi: Limit max_xmit_length (FATE#311449,bnc#690073).
  * patches.drivers/0017-be2iscsi-Remove-debug-print-in-IO-path.patch:
    be2iscsi: Remove debug print in IO path
    (FATE#311449,bnc#690073).
  * patches.drivers/0018-be2iscsi-Fix-for-premature-buffer-free.patch:
    be2iscsi: Fix for premature buffer free
    (FATE#311449,bnc#690073).
  * patches.drivers/0019-be2iscsi-The-extended-shift-must-be-16.patch:
    be2iscsi: The extended shift must be 16
    (FATE#311449,bnc#690073).
  * patches.drivers/0020-scsi-add-Kconfig-dependency-on-NET.patch:
    scsi: add Kconfig dependency on NET
    (FATE#311449,bnc#690073).
  * patches.drivers/0021-be2iscsi-Add-support-for-iscsi-boot.patch:
    be2iscsi: Add support for iscsi boot
    (FATE#311449,bnc#690073).
  * patches.drivers/0022-be2iscsi-Increase-max-sector.patch:
    be2iscsi: Increase max sector (FATE#311449,bnc#690073).
  * patches.drivers/0023-be2iscsi-Driver-Version-change-to-2.0.549.0.patch:
    be2iscsi: Driver Version change to 2.0.549.0
    (FATE#311449,bnc#690073).
  * patches.drivers/0024-be2iscsi-Fix-for-Login-failure.patch:
    be2iscsi: Fix for Login failure (FATE#311449,bnc#690073).
  * patches.drivers/0025-be2iscsi-More-time-for-FW.patch: [SCSI]
    be2iscsi: More time for FW (FATE#311449,bnc#690073).
  * patches.drivers/0026-be2iscsi-Remove-premature-free-of-cid.patch:
    be2iscsi: Remove premature free of cid
    (FATE#311449,bnc#690073).
  * patches.drivers/0027-be2iscsi-SGE-Len-64K.patch: [SCSI]
    be2iscsi: SGE Len == 64K (FATE#311449,bnc#690073).
  * patches.drivers/0028-be2iscsi-fix-gfp-use-in-alloc_pdu.patch:
    be2iscsi: fix gfp use in alloc_pdu
    (FATE#311449,bnc#690073).
  * patches.drivers/0029-be2iscsi-fix-null-ptr-when-accessing-task-hd.patch:
    be2iscsi: fix null ptr when accessing task hdr
    (FATE#311449,bnc#690073).
  * patches.drivers/0030-be2iscsi-fix-null-ptr-ref-in-conn-get-param.patch:
    be2iscsi: fix null ptr ref in conn get param
    (FATE#311449,bnc#690073).
  * patches.drivers/0031-be2iscsi-Fix-common-misspellings.patch:
    Fix common misspellings (FATE#311449,bnc#690073).
  * patches.drivers/0032-be2iscsi-remove-extra-semicolons.patch:
    treewide: remove extra semicolons (FATE#311449,bnc#690073).
  * patches.drivers/0033-be2iscsi-change-in-copyright-notice.patch:
    be2iscsi: change in copyright notice
    (FATE#311449,bnc#690073).
  * patches.drivers/0034-be2iscsi-Modifying-Maintainer-s-emailid.patch:
    be2iscsi: Modifying Maintainer's emailid
    (FATE#311449,bnc#690073).
  * patches.drivers/0035-be2iscsi-Set-a-timeout-to-FW.patch:
    be2iscsi: Set a timeout to FW (FATE#311449,bnc#690073).
  * patches.drivers/0036-be2iscsi-Fix-for-proper-setting-of-FW.patch:
    be2iscsi: Fix for proper setting of FW
    (FATE#311449,bnc#690073).
  * patches.drivers/0037-be2iscsi-fix-boot-hang-due-to-interrupts-not.patch:
    be2iscsi: fix boot hang due to interrupts not getting
    rearmed (FATE#311449,bnc#690073).
  * patches.drivers/0038-be2iscsi-fix-chip-cleanup.patch: [SCSI]
    be2iscsi: fix chip cleanup (FATE#311449,bnc#690073).
  * patches.drivers/0039-be2iscsi-update-version.patch: [SCSI]
    be2iscsi: update version (FATE#311449,bnc#690073).
  * patches.drivers/0040-be2iscsi-Fix-MSI-X-Interrupt-Names.patch:
    be2iscsi: Fix MSI-X Interrupt Names (FATE#311449,bnc#690073).
- Update iSCSI stack with latest fixes:
  * patches.suse/iscsi-add-module-alias.patch: [SCSI] iscsi:
    add module alias (FATE#311449,bnc#690073).
  * patches.suse/iscsi-class-add-callout-to-get-iscsi_endpoin.patch:
    iscsi class: add callout to get iscsi_endpoint values
    (FATE#311449,bnc#690073).
  * patches.suse/iscsi-class-remove-unused-active-variable.patch:
    iscsi class: remove unused active variable
    (FATE#311449,bnc#690073).
  * patches.suse/iscsi-fix-iscsi_endpoint-leak.patch: [SCSI] iscsi:
    fix iscsi_endpoint leak (FATE#311449,bnc#690073).
  * patches.suse/iscsi_tcp-use-iscsi_conn_get_addr_param-libi.patch:
    iscsi_tcp: use iscsi_conn_get_addr_param libiscsi
    function (FATE#311449,bnc#690073).
  * patches.suse/iscsi_transport-added-new-iscsi_param-to-dis.patch:
    iscsi_transport: added new iscsi_param to display target
    alias in sysfs (FATE#311449,bnc#690073).
  * patches.suse/libiscsi-add-helper-to-convert-addr-to-strin.patch:
    libiscsi: add helper to convert addr to string
    (FATE#311449,bnc#690073).
  * patches.suse/libiscsi-add-more-informative-failure-messag.patch:
    libiscsi: add more informative failure message during
    iscsi scsi eh (FATE#311449,bnc#690073).
  * patches.suse/libiscsi-do-not-take-host-lock-in-queuecomma.patch:
    libiscsi: do not take host lock in queuecommand
    (FATE#311449,bnc#690073).
  * patches.suse/libiscsi-use-bh-locking-instead-of-irq-with.patch:
    libiscsi: use bh locking instead of irq with session lock
    (FATE#311449,bnc#690073).
  * patches.suse/libiscsi_tcp-use-kmap-in-xmit-path.patch: [SCSI]
    libiscsi_tcp: use kmap in xmit path (FATE#311449,bnc#690073).
  * patches.suse/scsi_transport_iscsi-make-priv_sess-file-wri.patch:
    scsi_transport_iscsi: make priv_sess file writeable
    only by root (FATE#311449,bnc#690073).
* Mon Jun 27 2011 sjayaraman@suse.de
- patches.suse/sata-enable-non-queueable-flush-flag.patch:
  Fix misplacement of an hunk by quilt refresh that caused build error.
* Mon Jun 27 2011 sjayaraman@suse.de
- patches.suse/block-Stop-using-byte-offsets.patch: Fix "unused variable"
  warning.
* Mon Jun 27 2011 sjayaraman@suse.de
- Add missing block layer fixes (FATE#312039).
- patches.suse/block-add-a-non-queueable-flush-flag.patch: block:
  add a non-queueable flush flag (FATE#312039).
- patches.suse/block-add-force_kblockd-to-__blk_run_queue.patch:
  block: add @force_kblockd to __blk_run_queue() (FATE#312039).
- patches.suse/block-blk-flush-shouldn-t-call-directly-into-q-request_fn-__blk_run_queue.patch:
  block: blk-flush shouldn't call directly into q->request_fn()
  __blk_run_queue() (FATE#312039).
- patches.suse/block-dump-request-state-on-seeing-a-corrupted-request-completion.patch:
  block: dump request state on seeing a corrupted request
  completion (FATE#312039).
- patches.suse/block-hold-queue-if-flush-is-running-for-non-queueable-flush-drive.patch:
  block: hold queue if flush is running for non-queueable flush
  drive (FATE#312039).
- patches.suse/block-make-the-flush-insertion-use-the-tail-of-the-dispatch-list.patch:
  block: make the flush insertion use the tail of the dispatch
  list (FATE#312039).
- patches.suse/block-remove-the-extra-check-in-queue_requests_store.patch:
  block: Remove the extra check in queue_requests_store
  (FATE#312039).
- patches.suse/sata-enable-non-queueable-flush-flag.patch: SATA:
  enable non-queueable flush flag (FATE#312039).
* Mon Jun 27 2011 hare@suse.de
- patches.drivers/lpfc-8.3.5.45-update: lpfc: Update to 8.3.5.45
  (FATE#311447,bnc#686702).
* Mon Jun 27 2011 hare@suse.de
- patches.drivers/mptfusion-Fix-Incorrect-return-value-in-mpts.patch:
  mptfusion: Fix Incorrect return value in mptscsih_dev_reset
  (FATE#311454,bnc#680814).
- patches.drivers/mptfusion-Fix-memory-leak-in-mptctl_getiocin.patch:
  mptfusion: Fix memory leak in mptctl_getiocinfo()
  (FATE#311454,bnc#680814).
- patches.drivers/mptfusion-Remove-debug-print-from-mptscsih_q.patch:
  mptfusion: Remove debug print from mptscsih_qcmd()
  (FATE#311454,bnc#680814).
- patches.drivers/mptfusion-Update-to-4.28.00.00suse.patch:
  mptfusion: Update to 4.28.00.00suse (FATE#311454,bnc#680814).
- patches.drivers/mptfusion-release-resources-in-error-return.patch:
  mptfusion: release resources in error return path
  (FATE#311454,bnc#680814).
* Mon Jun 27 2011 dsterba@suse.cz
- add patches.fixes/xfs-pass-private-data-to-formatter-in-xfs_bulkstat to
  series.conf (bnc#691536)
* Mon Jun 27 2011 jdelvare@suse.de
- patches.suse/mm-check-any-page-in-pageblock-reserved.patch,
  patches.suse/mm-compaction-use-async-migration-__GFP_NO_KSWAPD.patch,
  patches.suse/mm-migrate-move-inc_zone_page_state-isolated.patch:
  Commit-ID -> Git-commit.
- patches.suse/mm-thp-add-pmd-mangling-x86.patch,
  patches.xen/xen3-mm-thp-add-pmd-mangling-x86.patch:
  Commit-ID -> Git-commit + fix commit ID.
* Mon Jun 27 2011 hare@suse.de
- patches.arch/005-intel_idle__native_hardware_cpuidle_driver_for_latest_Intel_processors.patch:
  Correct file mode.
- patches.drivers/0142-tg3-implement-ethtool-set_phys_id.patch:
  Fixup patch for series2git.
* Sat Jun 25 2011 brogers@suse.com
- supported.conf: Mark vhost_net as supported (FATE#311977)
* Sat Jun 25 2011 brogers@suse.com
- Update config files.
- patches.drivers/vhost-Fix-host-panic-if-ioctl-called-with-wrong-ind.patch:
  vhost: Fix host panic if ioctl called with wrong index
  (FATE#311977).
- patches.drivers/vhost-add-__rcu-annotations.patch: vhost:
  add __rcu annotations (FATE#311977).
- patches.drivers/vhost-add-unlikely-annotations-to-error-path.patch:
  vhost: add unlikely annotations to error path (FATE#311977).
- patches.drivers/vhost-apply-cgroup-to-vhost-workers.patch:
  vhost: apply cgroup to vhost workers (FATE#311977).
- patches.drivers/vhost-avoid-pr_err-on-condition-guest-can-trigger.patch:
  vhost: avoid pr_err on condition guest can trigger
  (FATE#311977).
- patches.drivers/vhost-better-variable-name-in-logging.patch:
  vhost: better variable name in logging (FATE#311977).
- patches.drivers/vhost-break-out-of-polling-loop-on-error.patch:
  vhost: break out of polling loop on error (FATE#311977).
- patches.drivers/vhost-cgroups-Add-an-API-to-attach-a-task-to-current-task.patch:
  cgroups: Add an API to attach a task to current task's cgroup
  (FATE#311977).
- patches.drivers/vhost-copy_to_user-__copy_to_user.patch: vhost:
  copy_to_user -> __copy_to_user (FATE#311977).
- patches.drivers/vhost-correctly-set-bits-of-dirty-pages.patch:
  vhost: correctly set bits of dirty pages (FATE#311977).
- patches.drivers/vhost-error-handling-fix.patch: vhost: error
  handling fix (FATE#311977).
- patches.drivers/vhost-export-tun_get_socket.patch: tun: export
  underlying socket (FATE#311977).
- patches.drivers/vhost-final-cleanup.patch: vhost backport
  final cleanup (FATE#311977).
- patches.drivers/vhost-fix-attach-to-cgroups-regression.patch:
  vhost: fix attach to cgroups regression (FATE#311977).
- patches.drivers/vhost-fix-barrier-pairing.patch: vhost: fix
  barrier pairing (FATE#311977).
- patches.drivers/vhost-fix-error-handling-in-vring-ioctls.patch:
  vhost: fix error handling in vring ioctls (FATE#311977).
- patches.drivers/vhost-fix-error-path-in-vhost_net_set_backend.patch:
  vhost: fix error path in vhost_net_set_backend (FATE#311977).
- patches.drivers/vhost-fix-get_user_pages_fast-error-handling.patch:
  vhost: fix get_user_pages_fast error handling (FATE#311977).
- patches.drivers/vhost-fix-interrupt-mitigation-with-raw-sockets.patch:
  vhost: fix interrupt mitigation with raw sockets (FATE#311977).
- patches.drivers/vhost-fix-log-ctx-signalling.patch: vhost:
  fix log ctx signalling (FATE#311977).
- patches.drivers/vhost-fix-return-code-for-log_access_ok.patch:
  vhost: fix return code for log_access_ok() (FATE#311977).
- patches.drivers/vhost-fix-signed-unsigned-comparison.patch:
  vhost: fix signed/unsigned comparison (FATE#311977).
- patches.drivers/vhost-fix-sparse-warnings.patch: vhost: fix
  sparse warnings (FATE#311977).
- patches.drivers/vhost-fix-the-memory-leak-which-will-happen-when-me.patch:
  vhost: fix the memory leak which will happen when
  memory_access_ok fails (FATE#311977).
- patches.drivers/vhost-fix-to-check-the-return-value-of-copy_to-from.patch:
  vhost: fix to check the return value of copy_to/from_user()
  correctly (FATE#311977).
- patches.drivers/vhost-fix-typos-in-comment.patch: vhost:
  fix typos in comment (FATE#311977).
- patches.drivers/vhost-get-put_user-__get-__put_user.patch:
  vhost: get/put_user -> __get/__put_user (FATE#311977).
- patches.drivers/vhost-include-cleanup-Update-gfp.h-and-slab.h-includes-to.patch:
  include cleanup: Update gfp.h and slab.h includes to prepare for
  breaking implicit slab.h inclusion from percpu.h (FATE#311977).
- patches.drivers/vhost-initialize-log-eventfd-context-pointer.patch:
  vhost: initialize log eventfd context pointer (FATE#311977).
- patches.drivers/vhost-kernel-wide-replace-USHORT_MAX-SHORT_MAX-and-SHORT.patch:
  kernel-wide: replace USHORT_MAX, SHORT_MAX and SHORT_MIN with
  USHRT_MAX, SHRT_MAX and SHRT_MIN (FATE#311977).
- patches.drivers/vhost-logging-thinko-fix.patch: vhost: logging
  thinko fix (FATE#311977).
- patches.drivers/vhost-max-s-g-to-match-qemu.patch: vhost:
  max s/g to match qemu (FATE#311977).
- patches.drivers/vhost-misc-Fix-allocation-borrowed-by-vhost_net.patch:
  misc: Fix allocation 'borrowed' by vhost_net (FATE#311977).
- patches.drivers/vhost-mm-export-use_mm-unuse_mm-to-modules.patch:
  mm: export use_mm/unuse_mm to modules (FATE#311977).
- patches.drivers/vhost-net-avoid-flush-under-lock.patch:
  vhost-net: avoid flush under lock (FATE#311977).
- patches.drivers/vhost-net-batch-use-unuse-mm.patch: vhost-net:
  batch use/unuse mm (FATE#311977).
- patches.drivers/vhost-net-fix-range-checking-in-mrg-bufs-case.patch:
  vhost-net: fix range checking in mrg bufs case (FATE#311977).
- patches.drivers/vhost-net-fix-rcu-check-usage.patch: vhost/net:
  fix rcu check usage (FATE#311977).
- patches.drivers/vhost-net-fix-to-check-the-return-value-of-copy_to.patch:
  vhost-net: fix to check the return value of copy_to/from_user()
  correctly (FATE#311977).
- patches.drivers/vhost-net-fix-vq_memory_access_ok-error-checking.patch:
  vhost-net: fix vq_memory_access_ok error checking (FATE#311977).
- patches.drivers/vhost-net-mergeable-buffers-support.patch:
  vhost-net: mergeable buffers support (FATE#311977).
- patches.drivers/vhost-net-reorganize-some-code.patch: vhost net:
  reorganize some code (FATE#311977).
- patches.drivers/vhost-net-restart-tx-poll-on-sk_sndbuf-full.patch:
  vhost-net: restart tx poll on sk_sndbuf full (FATE#311977).
- patches.drivers/vhost-net-switch-to-smp-barriers.patch:
  vhost-net: switch to smp barriers (FATE#311977).
- patches.drivers/vhost-put-mm-after-thread-stop.patch: vhost:
  put mm after thread stop (FATE#311977).
- patches.drivers/vhost-rcu-annotation-fixup.patch: vhost:
  rcu annotation fixup (FATE#311977).
- patches.drivers/vhost-remove-unused-include.patch: vhost:
  remove unused include (FATE#311977).
- patches.drivers/vhost-replace-vhost_workqueue-with-per-vhost-kthrea.patch:
  vhost: replace vhost_workqueue with per-vhost kthread
  (FATE#311977).
- patches.drivers/vhost-stop-worker-only-if-created.patch: vhost:
  stop worker only if created (FATE#311977).
- patches.drivers/vhost-tun-add-ioctl-to-modify-vnet-header-size.patch:
  tun: add ioctl to modify vnet header size (FATE#311977).
- patches.drivers/vhost-vhost-Cleanup-vhost.c-and-net.c.patch:
  vhost: Cleanup vhost.c and net.c (FATE#311977).
- patches.drivers/vhost-vhost-lock-receive-queue-not-the-socket.patch:
  vhost: lock receive queue, not the socket (FATE#311977).
- patches.drivers/vhost-vhost-net-Unify-the-code-of-mergeable-and-big-buffe.patch:
  vhost-net: Unify the code of mergeable and big buffer handling
  (FATE#311977).
- patches.drivers/vhost-vhost-net-check-the-support-of-mergeable-buffer-out.patch:
  vhost-net: check the support of mergeable buffer outside the
  receive loop (FATE#311977).
- patches.drivers/vhost-vhost-net-remove-unlocked-use-of-receive_queue.patch:
  vhost-net: remove unlocked use of receive_queue (FATE#311977).
- patches.drivers/vhost-vhost-support-event-index.patch: vhost:
  support event index (FATE#311977).
- patches.drivers/vhost-vhost.c-delete-double-assignment.patch:
  drivers/vhost/vhost.c: delete double assignment (FATE#311977).
- patches.drivers/vhost-virtio-event-index-interface.patch:
  virtio: event index interface (FATE#311977).
- patches.drivers/vhost-virtio-ring-inline-function-to-check-for-events.patch:
  virtio ring: inline function to check for events (FATE#311977).
- patches.drivers/vhost-virtio_ring-support-event-idx-feature.patch:
  virtio_ring: support event idx feature (FATE#311977).
- patches.drivers/vhost-whitespace-fix.patch: vhost: whitespace
  fix (FATE#311977).
- patches.drivers/vhost_net-a-kernel-level-virtio-server.patch:
  vhost_net: a kernel-level virtio server (FATE#311977).
* Fri Jun 24 2011 mhocko@suse.cz
- patches.suse/memcg-unify-charge-uncharge-quantities-to-units-of-pages.patch:
  Refresh - added missing upstream commit id.
* Fri Jun 24 2011 jslaby@suse.de
  Add Git-commit tags.
- patches.kernel.org/patch-2.6.32.1: Refresh.
- patches.kernel.org/patch-2.6.32.1-2: Refresh.
- patches.kernel.org/patch-2.6.32.10-11: Refresh.
- patches.kernel.org/patch-2.6.32.11-12: Refresh.
- patches.kernel.org/patch-2.6.32.12-13: Refresh.
- patches.kernel.org/patch-2.6.32.13-14: Refresh.
- patches.kernel.org/patch-2.6.32.15-16: Refresh.
- patches.kernel.org/patch-2.6.32.16-17: Refresh.
- patches.kernel.org/patch-2.6.32.17-18: Refresh.
- patches.kernel.org/patch-2.6.32.18-19: Refresh.
- patches.kernel.org/patch-2.6.32.19-20: Refresh.
- patches.kernel.org/patch-2.6.32.2-3: Refresh.
- patches.kernel.org/patch-2.6.32.20-21: Refresh.
- patches.kernel.org/patch-2.6.32.21-22: Refresh.
- patches.kernel.org/patch-2.6.32.22-23: Refresh.
- patches.kernel.org/patch-2.6.32.24-25: Refresh.
- patches.kernel.org/patch-2.6.32.25-26: Refresh.
- patches.kernel.org/patch-2.6.32.26-27: Refresh.
- patches.kernel.org/patch-2.6.32.27-28: Refresh.
- patches.kernel.org/patch-2.6.32.28-29: Refresh.
- patches.kernel.org/patch-2.6.32.29-30: Refresh.
- patches.kernel.org/patch-2.6.32.3-4: Refresh.
- patches.kernel.org/patch-2.6.32.31-32: Refresh.
- patches.kernel.org/patch-2.6.32.32-33: Refresh.
- patches.kernel.org/patch-2.6.32.33-34: Refresh.
- patches.kernel.org/patch-2.6.32.35-36: Refresh.
- patches.kernel.org/patch-2.6.32.36-37: Refresh.
- patches.kernel.org/patch-2.6.32.38-39: Refresh.
- patches.kernel.org/patch-2.6.32.39-40: Refresh.
- patches.kernel.org/patch-2.6.32.4-5: Refresh.
- patches.kernel.org/patch-2.6.32.40-41: Refresh.
- patches.kernel.org/patch-2.6.32.41-42: Refresh.
- patches.kernel.org/patch-2.6.32.5-6: Refresh.
- patches.kernel.org/patch-2.6.32.6-7: Refresh.
- patches.kernel.org/patch-2.6.32.7-8: Refresh.
- patches.kernel.org/patch-2.6.32.8-9: Refresh.
- patches.kernel.org/patch-2.6.32.9-10: Refresh.
* Fri Jun 24 2011 jslaby@suse.de
- Update to 2.6.32.42
- patches.arch/acpi_handle_root_level_devices.patch: Delete.
- patches.fixes/Fix-for-buffer-overflow-in-ldm_frag_add-not-sufficie.patch:
  Delete.
- patches.fixes/PCI-Set-PCIE-maxpayload-for-card-during-hotplug-inse.patch:
  Delete.
- patches.fixes/block-Add-proper-guards-to-__elv_next_request:
  Delete.
- patches.fixes/block-Export-blk_get_queue-and-blk_put_queue:
  Delete.
- patches.fixes/scsi-Fix-oops-caused-by-queue-refcounting-failure:
  Delete.
- patches.suse/SoN-09-global-ALLOC_NO_WATERMARKS.patch: Refresh.
- patches.suse/SoN-27-nfs-swap_ops.patch: Refresh.
- patches.xen/xen3-patch-2.6.27: Refresh.
* Fri Jun 24 2011 jeffm@suse.com
- patches.drivers/0188-qlcnic-fix-checks-for-auto_fw_reset.patch:
  qlcnic: fix checks for auto_fw_reset (bnc#698272, FATE#311468).
* Fri Jun 24 2011 jeffm@suse.com
- patches.drivers/0002-tg3-Add-tg3_compat.h.patch: tg3: Add
  tg3_compat.h (bnc#697783, FATE#311457).
- patches.drivers/0003-net-use-netdev_mc_count-and-netdev_mc_empty-when-app.patch:
  net: use netdev_mc_count and netdev_mc_empty when appropriate
  (bnc#697783, FATE#311457).
- patches.drivers/0004-tg3-Reset-phy-during-bringup-when-using-phylib.patch:
  tg3: Reset phy during bringup when using phylib (bnc#697783,
  FATE#311457).
- patches.drivers/0005-tg3-Allow-phylib-flowctrl-changes-anytime.patch:
  tg3: Allow phylib flowctrl changes anytime (bnc#697783,
  FATE#311457).
- patches.drivers/0006-tg3-Rename-TG3_FLG3_RGMII_STD_IBND_DISABLE.patch:
  tg3: Rename TG3_FLG3_RGMII_STD_IBND_DISABLE (bnc#697783,
  FATE#311457).
- patches.drivers/0007-tg3-Reduce-indent-level-of-tg3_rx_prodring_alloc.patch:
  tg3: Reduce indent level of tg3_rx_prodring_alloc (bnc#697783,
  FATE#311457).
- patches.drivers/0008-tg3-Discover-phy-address-once.patch: tg3:
  Discover phy address once (bnc#697783, FATE#311457).
- patches.drivers/0009-tg3-Reformat-SSID-to-phy-ID-table.patch:
  tg3: Reformat SSID to phy ID table (bnc#697783, FATE#311457).
- patches.drivers/0010-tg3-Rename-tg3-phy-ID-preprocessor-definitions.patch:
  tg3: Rename tg3 phy ID preprocessor definitions (bnc#697783,
  FATE#311457).
- patches.drivers/0011-tg3-Push-phylib-definitions-to-phylib.patch:
  tg3: Push phylib definitions to phylib (bnc#697783,
  FATE#311457).
- patches.drivers/0012-drivers-net-tg3.c-Use-pr-netdev-_-level-macro-helper.patch:
  drivers/net/tg3.c: Use (pr|netdev)_<level> macro helpers
  (bnc#697783, FATE#311457).
- patches.drivers/0013-net-convert-multiple-drivers-to-use-netdev_for_each_.patch:
  net: convert multiple drivers to use netdev_for_each_mc_addr,
  part6 (bnc#697783, FATE#311457).
- patches.drivers/0014-pci-Add-PCI-LRDT-tag-size-and-section-size.patch:
  pci: Add PCI LRDT tag size and section size (bnc#697783,
  FATE#311457).
- patches.drivers/0015-pci-Add-large-and-small-resource-data-type-code.patch:
  pci: Add large and small resource data type code (bnc#697783,
  FATE#311457).
- patches.drivers/0016-pci-Add-helper-to-find-a-VPD-resource-data-type.patch:
  pci: Add helper to find a VPD resource data type (bnc#697783,
  FATE#311457).
- patches.drivers/0017-pci-Add-VPD-information-field-helper-functions.patch:
  pci: Add VPD information field helper functions (bnc#697783,
  FATE#311457).
- patches.drivers/0018-pci-Add-helper-to-search-for-VPD-keywords.patch:
  pci: Add helper to search for VPD keywords (bnc#697783,
  FATE#311457).
- patches.drivers/0019-tg3-Remove-now-useless-VPD-code.patch:
  tg3: Remove now useless VPD code (bnc#697783, FATE#311457).
- patches.drivers/0020-tg3-Restore-likely-check-in-tg3_poll_msix.patch:
  tg3: Restore likely() check in tg3_poll_msix() (bnc#697783,
  FATE#311457).
- patches.drivers/0021-tg3-Replace-pr_err-with-sensible-alternatives.patch:
  tg3: Replace pr_err with sensible alternatives (bnc#697783,
  FATE#311457).
- patches.drivers/0022-tg3-netdev_err-dev_err.patch: tg3:
  netdev_err() => dev_err() (bnc#697783, FATE#311457).
- patches.drivers/0023-tg3-Fix-message-80-char-violations.patch:
  tg3: Fix message 80 char violations (bnc#697783, FATE#311457).
- patches.drivers/0024-tg3-Prepare-FW-version-code-for-VPD-versioning.patch:
  tg3: Prepare FW version code for VPD versioning (bnc#697783,
  FATE#311457).
- patches.drivers/0025-tg3-Use-VPD-fw-version-when-present.patch:
  tg3: Use VPD fw version when present (bnc#697783, FATE#311457).
- patches.drivers/0026-tg3-Whitespace-constant-and-comment-updates.patch:
  tg3: Whitespace, constant, and comment updates (bnc#697783,
  FATE#311457).
- patches.drivers/0027-tg3-The-case-of-switches.patch: tg3:
  The case of switches (bnc#697783, FATE#311457).
- patches.drivers/0028-tg3-Cleanup-if-codestyle.patch: tg3:
  Cleanup if codestyle (bnc#697783, FATE#311457).
- patches.drivers/0029-tg3-Remove-tg3_dump_state.patch: tg3:
  Remove tg3_dump_state() (bnc#697783, FATE#311457).
- patches.drivers/0030-tg3-Optimize-rx-double-copy-test.patch:
  tg3: Optimize rx double copy test (bnc#697783, FATE#311457).
- patches.drivers/0031-tg3-Re-inline-VLAN-tags-when-appropriate.patch:
  tg3: Re-inline VLAN tags when appropriate (bnc#697783,
  FATE#311457).
- patches.drivers/0032-tg3-Unify-max-pkt-size-preprocessor-constants.patch:
  tg3: Unify max pkt size preprocessor constants (bnc#697783,
  FATE#311457).
- patches.drivers/0033-tg3-Remove-function-errors-flagged-by-checkpatch.patch:
  tg3: Remove function errors flagged by checkpatch (bnc#697783,
  FATE#311457).
- patches.drivers/0034-tg3-use-the-DMA-state-API-instead-of-the-pci-equival.patch:
  tg3: use the DMA state API instead of the pci equivalents
  (bnc#697783, FATE#311457).
- patches.drivers/0035-tg3-Enable-GRO-by-default.patch: tg3:
  Enable GRO by default (bnc#697783, FATE#311457).
- patches.drivers/0036-tg3-Off-by-one-error-in-RSS-setup.patch:
  tg3: Off-by-one error in RSS setup (bnc#697783, FATE#311457).
- patches.drivers/0037-tg3-Allow-single-MSI-X-vector-allocations.patch:
  tg3: Allow single MSI-X vector allocations (bnc#697783,
  FATE#311457).
- patches.drivers/0038-tg3-5717-Allow-serdes-link-via-parallel-detect.patch:
  tg3: 5717: Allow serdes link via parallel detect (bnc#697783,
  FATE#311457).
- patches.drivers/0039-tg3-Use-devfn-to-determine-function-number.patch:
  tg3: Use devfn to determine function number (bnc#697783,
  FATE#311457).
- patches.drivers/0040-tg3-Add-5719-ASIC-rev.patch: tg3: Add
  5719 ASIC rev (bnc#697783, FATE#311457).
- patches.drivers/0041-tg3-Add-5719-PCI-device-and-phy-IDs.patch:
  tg3: Add 5719 PCI device and phy IDs (bnc#697783, FATE#311457).
- patches.drivers/0042-tg3-64-bit-stats-on-all-arches.patch:
  tg3: 64 bit stats on all arches (bnc#697783, FATE#311457).
- patches.drivers/0043-tg3-allow-TSO-on-vlan-devices.patch: tg3:
  allow TSO on vlan devices (bnc#697783, FATE#311457).
- patches.drivers/0044-tg3-Revert-RSS-indir-tbl-setup-change.patch:
  tg3: Revert RSS indir tbl setup change (bnc#697783,
  FATE#311457).
- patches.drivers/0045-tg3-Fix-single-MSI-X-vector-coalescing.patch:
  tg3: Fix single MSI-X vector coalescing (bnc#697783,
  FATE#311457).
- patches.drivers/0046-tg3-Relax-5717-serdes-restriction.patch:
  tg3: Relax 5717 serdes restriction (bnc#697783, FATE#311457).
- patches.drivers/0047-tg3-Report-driver-version-to-firmware.patch:
  tg3: Report driver version to firmware (bnc#697783,
  FATE#311457).
- patches.drivers/0048-tg3-Revert-PCIe-tx-glitch-fix.patch: tg3:
  Revert PCIe tx glitch fix (bnc#697783, FATE#311457).
- patches.drivers/0049-tg3-Fix-some-checkpatch-errors.patch:
  tg3: Fix some checkpatch errors (bnc#697783, FATE#311457).
- patches.drivers/0050-tg3-Add-5784-ASIC-rev-to-earlier-PCIe-MPS-fix.patch:
  tg3: Add 5784 ASIC rev to earlier PCIe MPS fix (bnc#697783,
  FATE#311457).
- patches.drivers/0051-tg3-Disable-TSS-also-during-tg3_close.patch:
  tg3: Disable TSS also during tg3_close() (bnc#697783,
  FATE#311457).
- patches.drivers/0052-tg3-Create-TG3_FLG3_5717_PLUS-flag.patch:
  tg3: Create TG3_FLG3_5717_PLUS flag (bnc#697783, FATE#311457).
- patches.drivers/0053-tg3-Don-t-access-phy-test-ctrl-reg-for-5717.patch:
  tg3: Don't access phy test ctrl reg for 5717+ (bnc#697783,
  FATE#311457).
- patches.drivers/0054-tg3-Manage-gphy-power-for-CPMU-less-devs-only.patch:
  tg3: Manage gphy power for CPMU-less devs only (bnc#697783,
  FATE#311457).
- patches.drivers/0055-tg3-Restrict-ASPM-workaround-devlist.patch:
  tg3: Restrict ASPM workaround devlist (bnc#697783, FATE#311457).
- patches.drivers/0056-tg3-Detect-APE-firmware-types.patch: tg3:
  Detect APE firmware types (bnc#697783, FATE#311457).
- patches.drivers/0057-tg3-Remove-5720-5750-and-5750M.patch:
  tg3: Remove 5720, 5750, and 5750M (bnc#697783, FATE#311457).
- patches.drivers/0058-tg3-Improve-small-packet-performance.patch:
  tg3: Improve small packet performance (bnc#697783, FATE#311457).
- patches.drivers/0059-tg3-Add-error-reporting-to-tg3_phydsp_write.patch:
  tg3: Add error reporting to tg3_phydsp_write() (bnc#697783,
  FATE#311457).
- patches.drivers/0060-tg3-Add-phy-related-preprocessor-constants.patch:
  tg3: Add phy-related preprocessor constants (bnc#697783,
  FATE#311457).
- patches.drivers/0061-tg3-Create-phy_flags-and-migrate-phy_is_low_power.patch:
  tg3: Create phy_flags and migrate phy_is_low_power (bnc#697783,
  FATE#311457).
- patches.drivers/0062-tg3-Migrate-tg3_flags-to-phy_flags.patch:
  tg3: Migrate tg3_flags to phy_flags (bnc#697783, FATE#311457).
- patches.drivers/0063-drivers-net-avoid-some-skb-ip_summed-initializations.patch:
  drivers/net: avoid some skb->ip_summed initializations
  (bnc#697783, FATE#311457).
- patches.drivers/0064-tg3-Fix-read-DMA-FIFO-overruns-on-recent-devices.patch:
  tg3: Fix read DMA FIFO overruns on recent devices (bnc#697783,
  FATE#311457).
- patches.drivers/0065-tg3-Disable-TSS.patch: tg3: Disable TSS
  (bnc#697783, FATE#311457).
- patches.drivers/0066-tg3-Don-t-send-APE-events-for-NCSI-firmware.patch:
  tg3: Don't send APE events for NCSI firmware (bnc#697783,
  FATE#311457).
- patches.drivers/0067-tg3-Unlock-5717-B0-support.patch: tg3:
  Unlock 5717 B0+ support (bnc#697783, FATE#311457).
- patches.drivers/0068-tg3-Clarify-semantics-of-TG3_IRQ_MAX_VECS.patch:
  tg3: Clarify semantics of TG3_IRQ_MAX_VECS (bnc#697783,
  FATE#311457).
- patches.drivers/0069-tg3-Move-producer-ring-struct-to-tg3_napi.patch:
  tg3: Move producer ring struct to tg3_napi (bnc#697783,
  FATE#311457).
- patches.drivers/0070-tg3-Use-skb_is_gso_v6.patch: tg3: Use
  skb_is_gso_v6() (bnc#697783, FATE#311457).
- patches.drivers/0071-tg3-Dynamically-allocate-VPD-data-memory.patch:
  tg3: Dynamically allocate VPD data memory (bnc#697783,
  FATE#311457).
- patches.drivers/0072-tg3-phy-tmp-variable-roundup.patch: tg3:
  phy tmp variable roundup (bnc#697783, FATE#311457).
- patches.drivers/0073-drivers-net-return-operator-cleanup.patch:
  drivers/net: return operator cleanup (bnc#697783, FATE#311457).
- patches.drivers/0074-tg3-Use-netif_set_real_num_-rx-tx-_queues.patch:
  tg3: Use netif_set_real_num_{rx,tx}_queues() (bnc#697783,
  FATE#311457).
- patches.drivers/0075-tg3-Fix-potential-netpoll-crash.patch:
  tg3: Fix potential netpoll crash (bnc#697783, FATE#311457).
- patches.drivers/0076-tg3-5719-Prevent-tx-data-corruption.patch:
  tg3: 5719: Prevent tx data corruption (bnc#697783, FATE#311457).
- patches.drivers/0077-tg3-Remove-5724-device-ID.patch: tg3:
  Remove 5724 device ID (bnc#697783, FATE#311457).
- patches.drivers/0078-tg3-Cleanup-missing-VPD-partno-section.patch:
  tg3: Cleanup missing VPD partno section (bnc#697783,
  FATE#311457).
- patches.drivers/0079-tg3-Futureproof-the-loopback-test.patch:
  tg3: Futureproof the loopback test (bnc#697783, FATE#311457).
- patches.drivers/0080-tg3-Prepare-for-larger-rx-ring-sizes.patch:
  tg3: Prepare for larger rx ring sizes (bnc#697783, FATE#311457).
- patches.drivers/0081-tg3-Add-extend-rx-ring-sizes-for-5717-and-5719.patch:
  tg3: Add extend rx ring sizes for 5717 and 5719 (bnc#697783,
  FATE#311457).
- patches.drivers/0082-tg3-Set-real_num_rx_queues-for-non-multiq-devs.patch:
  tg3: Set real_num_rx_queues for non-multiq devs (bnc#697783,
  FATE#311457).
- patches.drivers/0083-net-tg3-simplify-conditional.patch:
  net/tg3: simplify conditional (bnc#697783, FATE#311457).
- patches.drivers/0084-tg3-restore-rx_dropped-accounting.patch:
  tg3: restore rx_dropped accounting (bnc#697783, FATE#311457).
- patches.drivers/0085-tg3-Add-support-for-selfboot-format-1-v6.patch:
  tg3: Add support for selfboot format 1 v6 (bnc#697783,
  FATE#311457).
- patches.drivers/0086-tg3-Disable-unused-transmit-rings.patch:
  tg3: Disable unused transmit rings (bnc#697783, FATE#311457).
- patches.drivers/0087-tg3-Add-clause-45-register-accessor-methods.patch:
  tg3: Add clause 45 register accessor methods (bnc#697783,
  FATE#311457).
- patches.drivers/0088-tg3-Add-EEE-support.patch: tg3: Add EEE
  support (bnc#697783, FATE#311457).
- patches.drivers/0089-tg3-Cleanup-tg3_alloc_rx_skb.patch: tg3:
  Cleanup tg3_alloc_rx_skb() (bnc#697783, FATE#311457).
- patches.drivers/0090-tg3-Don-t-allocate-jumbo-ring-for-5780-class-devs.patch:
  tg3: Don't allocate jumbo ring for 5780 class devs (bnc#697783,
  FATE#311457).
- patches.drivers/0091-tg3-Report-invalid-link-from-tg3_get_settings.patch:
  tg3: Report invalid link from tg3_get_settings() (bnc#697783,
  FATE#311457).
- patches.drivers/0092-vlan-Don-t-check-for-vlan-group-before-vlan_tx_tag_p.patch:
  vlan: Don't check for vlan group before vlan_tx_tag_present
  (bnc#697783, FATE#311457).
- patches.drivers/0093-tg3-Do-not-call-device_set_wakeup_enable-under-spin_.patch:
  tg3: Do not call device_set_wakeup_enable() under spin_lock_bh
  (bnc#697783, FATE#311457).
- patches.drivers/0094-tg3-Apply-10Mbps-fix-to-all-57765-revisions.patch:
  tg3: Apply 10Mbps fix to all 57765 revisions (bnc#697783,
  FATE#311457).
- patches.drivers/0095-tg3-Assign-correct-tx-margin-for-5719.patch:
  tg3: Assign correct tx margin for 5719 (bnc#697783,
  FATE#311457).
- patches.drivers/0096-tg3-Always-turn-on-APE-features-in-mac_mode-reg.patch:
  tg3: Always turn on APE features in mac_mode reg (bnc#697783,
  FATE#311457).
- patches.drivers/0097-tg3-Fix-5719-internal-FIFO-overflow-problem.patch:
  tg3: Fix 5719 internal FIFO overflow problem (bnc#697783,
  FATE#311457).
- patches.drivers/0098-tg3-Enable-mult-rd-DMA-engine-on-5719.patch:
  tg3: Enable mult rd DMA engine on 5719 (bnc#697783,
  FATE#311457).
- patches.drivers/0099-tg3-Reenable-TSS-for-5719.patch: tg3:
  Reenable TSS for 5719 (bnc#697783, FATE#311457).
- patches.drivers/0100-tg3-use-dma_alloc_coherent-instead-of-pci_alloc_cons.patch:
  tg3: use dma_alloc_coherent() instead of pci_alloc_consistent()
  (bnc#697783, FATE#311457).
- patches.drivers/0101-tg3-Enable-phy-APD-for-5717-and-later-asic-revs.patch:
  tg3: Enable phy APD for 5717 and later asic revs (bnc#697783,
  FATE#311457).
- patches.drivers/0102-tg3-Raise-the-jumbo-frame-BD-flag-threshold.patch:
  tg3: Raise the jumbo frame BD flag threshold (bnc#697783,
  FATE#311457).
- patches.drivers/0103-tg3-Move-EEE-definitions-into-mdio.h.patch:
  tg3: Move EEE definitions into mdio.h (bnc#697783, FATE#311457).
- patches.drivers/0104-tg3-Fix-57765-EEE-support.patch: tg3:
  Fix 57765 EEE support (bnc#697783, FATE#311457).
- patches.drivers/0105-tg3-Minor-EEE-code-tweaks.patch: tg3:
  Minor EEE code tweaks (bnc#697783, FATE#311457).
- patches.drivers/0106-tg3-Relax-EEE-thresholds.patch: tg3:
  Relax EEE thresholds (bnc#697783, FATE#311457).
- patches.drivers/0107-tg3-Use-DEFINE_PCI_DEVICE_TABLE.patch:
  tg3: Use DEFINE_PCI_DEVICE_TABLE (bnc#697783, FATE#311457).
- patches.drivers/0108-tg3-Do-not-use-legacy-PCI-power-management.patch:
  tg3: Do not use legacy PCI power management (bnc#697783,
  FATE#311457).
- patches.drivers/0109-tg3-fix-return-value-check-in-tg3_read_vpd.patch:
  tg3: fix return value check in tg3_read_vpd() (bnc#697783,
  FATE#311457).
- patches.drivers/0110-tg3-fix-warnings.patch: tg3: fix warnings
  MIME-Version: 1.0 Content-Type: text/plain; charset=UTF-8
  Content-Transfer-Encoding: 8bit (bnc#697783, FATE#311457).
- patches.drivers/0111-tg3-Revise-5719-internal-FIFO-overflow-solution.patch:
  tg3: Revise 5719 internal FIFO overflow solution (bnc#697783,
  FATE#311457).
- patches.drivers/0112-tg3-Fix-5719-A0-tx-completion-bug.patch:
  tg3: Fix 5719 A0 tx completion bug (bnc#697783, FATE#311457).
- patches.drivers/0113-tg3-Use-new-VLAN-code.patch: tg3: Use
  new VLAN code (bnc#697783, FATE#311457).
- patches.drivers/0114-tg3-Disable-multivec-mode-for-1-MSIX-vector.patch:
  tg3: Disable multivec mode for 1 MSIX vector (bnc#697783,
  FATE#311457).
- patches.drivers/0115-tg3-Restrict-phy-ioctl-access.patch: tg3:
  Restrict phy ioctl access (bnc#697783, FATE#311457).
- patches.drivers/0116-tg3-Fix-loopback-tests.patch: tg3: Fix
  loopback tests (bnc#697783, FATE#311457).
- patches.drivers/0117-tg3-Disable-MAC-loopback-test-for-CPMU-devices.patch:
  tg3: Disable MAC loopback test for CPMU devices (bnc#697783,
  FATE#311457).
- patches.drivers/0118-tg3-Disable-EEE-during-loopback-tests.patch:
  tg3: Disable EEE during loopback tests (bnc#697783,
  FATE#311457).
- patches.drivers/0119-tg3-Fix-EEE-interoperability-issue.patch:
  tg3: Fix EEE interoperability issue (bnc#697783, FATE#311457).
- patches.drivers/0120-tg3-Fix-eee-preprocessor-naming.patch:
  tg3: Fix eee preprocessor naming (bnc#697783, FATE#311457).
- patches.drivers/0121-tg3-Expand-5719-workaround.patch: tg3:
  Expand 5719 workaround (bnc#697783, FATE#311457).
- patches.drivers/0122-tg3-Avoid-setting-power.can_wakeup-for-devices-that-.patch:
  tg3: Avoid setting power.can_wakeup for devices that cannot
  wake up (bnc#697783, FATE#311457).
- patches.drivers/0123-tg3-Add-missed-5719-workaround-change.patch:
  tg3: Add missed 5719 workaround change (bnc#697783,
  FATE#311457).
- patches.drivers/0124-tg3-Fix-NVRAM-selftest.patch: tg3: Fix
  NVRAM selftest (bnc#697783, FATE#311457).
- patches.drivers/0125-tg3-Add-code-to-verify-RODATA-checksum-of-VPD.patch:
  tg3: Add code to verify RODATA checksum of VPD (bnc#697783,
  FATE#311457).
- patches.drivers/0126-tg3-cleanup-pci-device-table-vars.patch:
  tg3: cleanup pci device table vars (bnc#697783, FATE#311457).
- patches.drivers/0127-tg3-Refine-VAux-decision-process.patch:
  tg3: Refine VAux decision process (bnc#697783, FATE#311457).
- patches.drivers/0128-tg3-Move-tg3_init_link_config-to-tg3_phy_probe.patch:
  tg3: Move tg3_init_link_config to tg3_phy_probe (bnc#697783,
  FATE#311457).
- patches.drivers/0129-tg3-Remove-5750-PCI-code.patch: tg3:
  Remove 5750 PCI code (bnc#697783, FATE#311457).
- patches.drivers/0130-tg3-use-linux-io.h-and-linux-uaccess.h-instead-asm-i.patch:
  tg3: use <linux/io.h> and <linux/uaccess.h> instead <asm/io.h>
  and <asm/uaccess.h> (bnc#697783, FATE#311457).
- patches.drivers/0131-tg3-Fix-inline-keyword-usage.patch: tg3:
  Fix inline keyword usage (bnc#697783, FATE#311457).
- patches.drivers/0132-Fix-common-misspellings.patch: Fix common
  misspellings (bnc#697783, FATE#311457).
- patches.drivers/0133-tg3-Cleanup-extended-rx-ring-size-code.patch:
  tg3: Cleanup extended rx ring size code (bnc#697783,
  FATE#311457).
- patches.drivers/0134-tg3-5717_PLUS-57765_PLUS.patch: tg3:
  5717_PLUS => 57765_PLUS (bnc#697783, FATE#311457).
- patches.drivers/0135-tg3-Reintroduce-5717_PLUS.patch: tg3:
  Reintroduce 5717_PLUS (bnc#697783, FATE#311457).
- patches.drivers/0136-tg3-Add-5720-ASIC-rev.patch: tg3: Add
  5720 ASIC rev (bnc#697783, FATE#311457).
- patches.drivers/0137-tg3-Add-5720-NVRAM-decoding.patch: tg3:
  Add 5720 NVRAM decoding (bnc#697783, FATE#311457).
- patches.drivers/0138-tg3-Add-5720-H2BMC-support.patch: tg3:
  Add 5720 H2BMC support (bnc#697783, FATE#311457).
- patches.drivers/0139-tg3-Add-5720-PHY-ID.patch: tg3: Add 5720
  PHY ID (bnc#697783, FATE#311457).
- patches.drivers/0140-tg3-Enable-5720-support.patch: tg3:
  Enable 5720 support (bnc#697783, FATE#311457).
- patches.drivers/0141-tg3-Support-4mb-flash-sizes-for-5717-and-5719.patch:
  tg3: Support 4mb flash sizes for 5717 and 5719 (bnc#697783,
  FATE#311457).
- patches.drivers/0142-tg3-implement-ethtool-set_phys_id.patch:
  tg3: implement ethtool set_phys_id (bnc#697783, FATE#311457).
- patches.drivers/0143-net-tg3-convert-to-hw_features.patch: net:
  tg3: convert to hw_features MIME-Version: 1.0 Content-Type:
  text/plain; charset=UTF-8 Content-Transfer-Encoding: 8bit
  (bnc#697783, FATE#311457).
- patches.drivers/0144-tg3-Provide-full-regdump-on-tx-timeout.patch:
  tg3: Provide full regdump on tx timeout (bnc#697783,
  FATE#311457).
- patches.drivers/0145-tg3-Dump-registers-when-status-block-shows-errors.patch:
  tg3: Dump registers when status block shows errors (bnc#697783,
  FATE#311457).
- patches.drivers/0146-tg3-Automatically-size-stat-test-string-arrays.patch:
  tg3: Automatically size stat/test string arrays (bnc#697783,
  FATE#311457).
- patches.drivers/0147-tg3-Add-jumbo-frame-loopback-tests-to-selftest.patch:
  tg3: Add jumbo frame loopback tests to selftest (bnc#697783,
  FATE#311457).
- patches.drivers/0148-tg3-Add-support-for-extended-VPD-blocks.patch:
  tg3: Add support for extended VPD blocks (bnc#697783,
  FATE#311457).
- patches.drivers/0149-tg3-Workaround-rx_discards-stat-bug.patch:
  tg3: Workaround rx_discards stat bug (bnc#697783, FATE#311457).
- patches.drivers/0150-tg3-Adjust-rx-prod-ring-bd-replenish-thresholds.patch:
  tg3: Adjust rx prod ring bd replenish thresholds (bnc#697783,
  FATE#311457).
- patches.drivers/0151-tg3-Nullify-RSS-for-loopback-test.patch:
  tg3: Nullify RSS for loopback test (bnc#697783, FATE#311457).
- patches.drivers/0152-tg3-Only-allow-phy-ioctls-while-netif_running.patch:
  tg3: Only allow phy ioctls while netif_running (bnc#697783,
  FATE#311457).
- patches.drivers/0153-tg3-Move-phy-accessor-functions-higher.patch:
  tg3: Move phy accessor functions higher (bnc#697783,
  FATE#311457).
- patches.drivers/0154-tg3-Add-read-accessor-for-AUX-CTRL-phy-reg.patch:
  tg3: Add read accessor for AUX CTRL phy reg (bnc#697783,
  FATE#311457).
- patches.drivers/0155-tg3-Add-write-accessor-for-AUX-CTRL-phy-reg.patch:
  tg3: Add write accessor for AUX CTRL phy reg (bnc#697783,
  FATE#311457).
- patches.drivers/0156-tg3-Add-macro-for-SMDSP-toggling.patch:
  tg3: Add macro for SMDSP toggling (bnc#697783, FATE#311457).
- patches.drivers/0157-tg3-Add-additional-EEE-messaging.patch:
  tg3: Add additional EEE messaging (bnc#697783, FATE#311457).
- patches.drivers/0158-tg3-Fix-int-generation-hw-bug-for-5719-5720.patch:
  tg3: Fix int generation hw bug for 5719 / 5720 (bnc#697783,
  FATE#311457).
- patches.drivers/0159-tg3-Organize-loopback-test-failure-flags.patch:
  tg3: Organize loopback test failure flags (bnc#697783,
  FATE#311457).
- patches.drivers/0160-tg3-Add-TSO-loopback-test.patch: tg3:
  Add TSO loopback test (bnc#697783, FATE#311457).
- patches.drivers/0161-tg3-Add-EEH-support.patch: tg3: Add EEH
  support (bnc#697783, FATE#311457).
- patches.drivers/0162-tg3-Whitespace-cleanups.patch: tg3:
  Whitespace cleanups (bnc#697783, FATE#311457).
- patches.drivers/0163-tg3-Convert-u32-flag-flg2-flg3-uses-to-bitmap.patch:
  tg3: Convert u32 flag,flg2,flg3 uses to bitmap (bnc#697783,
  FATE#311457).
- patches.drivers/0164-ethtool-Use-full-32-bit-speed-range-in-ethtool-s-set.patch:
  ethtool: Use full 32 bit speed range in ethtool's set_settings
  (bnc#697783, FATE#311457).
- patches.drivers/0165-ethtool-cosmetic-Use-ethtool-ethtool_cmd_speed-API.patch:
  ethtool: cosmetic: Use ethtool ethtool_cmd_speed API
  (bnc#697783, FATE#311457).
- patches.drivers/0166-tg3-Set-tx-bug-flags-for-more-devices.patch:
  tg3: Set tx bug flags for more devices (bnc#697783,
  FATE#311457).
- patches.drivers/0167-tg3-Cleanup-transmit-error-path.patch:
  tg3: Cleanup transmit error path (bnc#697783, FATE#311457).
- patches.drivers/0168-tg3-Fix-57765-B0-data-corruption.patch:
  tg3: Fix 57765 B0 data corruption (bnc#697783, FATE#311457).
- patches.drivers/0169-tg3-Fix-IPv6-TCP-problems-for-5719.patch:
  tg3: Fix IPv6 TCP problems for 5719 (bnc#697783, FATE#311457).
- patches.drivers/0170-tg3-Fix-EEE-interoperability-workaround.patch:
  tg3: Fix EEE interoperability workaround (bnc#697783,
  FATE#311457).
- patches.drivers/0171-tg3-Consolidate-autoneg-advertisement-setup-code.patch:
  tg3: Consolidate autoneg advertisement setup code (bnc#697783,
  FATE#311457).
- patches.drivers/0172-tg3-Fix-TSO-loopback-test.patch: tg3:
  Fix TSO loopback test (bnc#697783, FATE#311457).
- patches.drivers/0173-tg3-Fix-stats-for-5704-and-later-devices.patch:
  tg3: Fix stats for 5704 and later devices (bnc#697783,
  FATE#311457).
- patches.drivers/0174-tg3-Move-TSO_CAPABLE-assignment.patch:
  tg3: Move TSO_CAPABLE assignment (bnc#697783, FATE#311457).
- patches.drivers/0175-tg3-Consolidate-all-netdev-feature-assignments.patch:
  tg3: Consolidate all netdev feature assignments (bnc#697783,
  FATE#311457).
- patches.drivers/0176-tg3-Remove-excessive-parenthesis.patch:
  tg3: Remove excessive parenthesis (bnc#697783, FATE#311457).
- patches.drivers/0177-tg3-Apply-rx_discards-fix-to-5719-5720.patch:
  tg3: Apply rx_discards fix to 5719/5720 (bnc#697783,
  FATE#311457).
- patches.drivers/0178-tg3-Add-braces-around-5906-workaround.patch:
  tg3: Add braces around 5906 workaround (bnc#697783,
  FATE#311457).
- patches.drivers/0179-Add-Fujitsu-1000base-SX-PCI-ID-to-tg3.patch:
  Add Fujitsu 1000base-SX PCI ID to tg3 (bnc#697783, FATE#311457).
- patches.drivers/0180-tg3-Fix-tg3_skb_error_unmap.patch: tg3:
  Fix tg3_skb_error_unmap() (bnc#697783, FATE#311457).
- patches.drivers/0181-net-remove-interrupt.h-inclusion-from-netdevice.h.patch:
  net: remove interrupt.h inclusion from netdevice.h (bnc#697783,
  FATE#311457).
- patches.drivers/0182-tg3-enable-transmit-time-stamping.patch:
  tg3: enable transmit time stamping (bnc#697783, FATE#311457).
- patches.drivers/0183-tg3-Workaround-tagged-status-update-bug.patch:
  tg3: Workaround tagged status update bug (bnc#697783,
  FATE#311457).
- patches.drivers/0184-tg3-Remove-40BIT_DMA_LIMIT_BUG.patch:
  tg3: Remove 40BIT_DMA_LIMIT_BUG (bnc#697783, FATE#311457).
- patches.drivers/0185-tg3-Remove-4G_DMA_BNDRY_BUG-flag.patch:
  tg3: Remove 4G_DMA_BNDRY_BUG flag (bnc#697783, FATE#311457).
- patches.drivers/0186-tg3-Add-more-selfboot-formats-to-NVRAM-selftest.patch:
  tg3: Add more selfboot formats to NVRAM selftest (bnc#697783,
  FATE#311457).
- patches.drivers/0187-tg3-Show-flowctrl-settings-through-get_settings.patch:
  tg3: Show flowctrl settings through get_settings() (bnc#697783,
  FATE#311457).
- patches.drivers/0188-tg3-Migrate-phy-preprocessor-defs-to-system-defs.patch:
  tg3: Migrate phy preprocessor defs to system defs (bnc#697783,
  FATE#311457).
- patches.drivers/0189-tg3-Create-funcs-for-power-source-switching.patch:
  tg3: Create funcs for power source switching (bnc#697783,
  FATE#311457).
- patches.drivers/0190-tg3-Fix-EEE-debounce-timer-values.patch:
  tg3: Fix EEE debounce timer values (bnc#697783, FATE#311457).
- patches.drivers/0191-tg3-Remove-tg3_config_info-definition.patch:
  tg3: Remove tg3_config_info definition (bnc#697783,
  FATE#311457).
- patches.drivers/0192-tg3-Reorg-tg3_napi-members.patch: tg3:
  Reorg tg3_napi members (bnc#697783, FATE#311457).
- patches.drivers/0193-tg3-Fix-MII_TG3_DSP_EXP8-offset.patch:
  tg3: Fix MII_TG3_DSP_EXP8 offset (bnc#697783, FATE#311457).
- patches.drivers/0194-tg3-Update-version-and-copyright.patch:
  tg3: Update version and copyright (bnc#697783, FATE#311457).
- patches.drivers/tg3-entropy-source.patch: Refresh.
* Fri Jun 24 2011 jeffm@suse.com
- patches.drivers/0001-mdio-Advertise-pause-flow-control-settings-even-if-a.patch:
  mdio: Advertise pause (flow control) settings even if autoneg
  is off (bnc#698572, FATE#311724).
- patches.drivers/0001-netdevice.h-Add-netdev_printk-helpers-like-dev_print.patch:
  netdevice.h: Add netdev_printk helpers like dev_printk
  (bnc#698572, FATE#311724).
- patches.drivers/0001-sfc-10Xpress-Initialise-pause-advertising-flags.patch:
  sfc: 10Xpress: Initialise pause advertising flags (bnc#698572,
  FATE#311724).
- patches.drivers/0002-include-linux-netdevice.h-Add-netif_printk-helpers.patch:
  include/linux/netdevice.h: Add netif_printk helpers (bnc#698572,
  FATE#311724).
- patches.drivers/0002-mdio-Expose-pause-frame-advertising-flags-to-ethtool.patch:
  mdio: Expose pause frame advertising flags to ethtool
  (bnc#698572, FATE#311724).
- patches.drivers/0002-sfc-10Xpress-Report-support-for-pause-frames.patch:
  sfc: 10Xpress: Report support for pause frames (bnc#698572,
  FATE#311724).
- patches.drivers/0003-net-Fix-definition-of-netif_vdbg-when-VERBOSE_DEBUG-.patch:
  net: Fix definition of netif_vdbg() when VERBOSE_DEBUG is not
  defined (bnc#698572, FATE#311724).
- patches.drivers/0003-sfc-Remove-redundant-header-gmii.h.patch:
  sfc: Remove redundant header gmii.h (bnc#698572, FATE#311724).
- patches.drivers/0004-net-Fix-definition-of-netif_vdbg-when-VERBOSE_DEBUG-.patch:
  net: Fix definition of netif_vdbg() when VERBOSE_DEBUG is
  defined (bnc#698572, FATE#311724).
- patches.drivers/0004-sfc-Remove-redundant-hardware-initialisation.patch:
  sfc: Remove redundant hardware initialisation (bnc#698572,
  FATE#311724).
- patches.drivers/0005-sfc-Rename-Falcon-specific-board-code-and-types.patch:
  sfc: Rename Falcon-specific board code and types (bnc#698572,
  FATE#311724).
- patches.drivers/0006-sfc-Merge-sfe4001.c-into-falcon_boards.c.patch:
  sfc: Merge sfe4001.c into falcon_boards.c (bnc#698572,
  FATE#311724).
- patches.drivers/0007-sfc-Remove-boards.h-moving-last-remaining-declaratio.patch:
  sfc: Remove boards.h, moving last remaining declaration to
  falcon.h (bnc#698572, FATE#311724).
- patches.drivers/0008-sfc-Remove-versioned-bitfield-macros.patch:
  sfc: Remove versioned bitfield macros (bnc#698572, FATE#311724).
- patches.drivers/0009-sfc-Move-RX-data-FIFO-thresholds-out-of-struct-efx_n.patch:
  sfc: Move RX data FIFO thresholds out of struct efx_nic_type
  (bnc#698572, FATE#311724).
- patches.drivers/0010-sfc-Update-hardware-definitions-for-Siena.patch:
  sfc: Update hardware definitions for Siena (bnc#698572,
  FATE#311724).
- patches.drivers/0011-sfc-Rename-register-I-O-header-and-functions-used-by.patch:
  sfc: Rename register I/O header and functions used by both
  Falcon and Siena (bnc#698572, FATE#311724).
- patches.drivers/0012-sfc-Eliminate-indirect-lookups-of-queue-size-constan.patch:
  sfc: Eliminate indirect lookups of queue size constants
  (bnc#698572, FATE#311724).
- patches.drivers/0013-sfc-Define-DMA-address-mask-explicitly-in-terms-of-d.patch:
  sfc: Define DMA address mask explicitly in terms of descriptor
  field width (bnc#698572, FATE#311724).
- patches.drivers/0014-sfc-Move-all-TX-DMA-length-limiting-into-tx.c.patch:
  sfc: Move all TX DMA length limiting into tx.c (bnc#698572,
  FATE#311724).
- patches.drivers/0015-sfc-Merge-struct-efx_blinker-into-struct-efx_board.patch:
  sfc: Merge struct efx_blinker into struct efx_board (bnc#698572,
  FATE#311724).
- patches.drivers/0016-sfc-Change-order-of-device-removal-to-reverse-of-pro.patch:
  sfc: Change order of device removal to reverse of probe order
  (bnc#698572, FATE#311724).
- patches.drivers/0017-sfc-Remove-declarations-of-nonexistent-functions.patch:
  sfc: Remove declarations of nonexistent functions (bnc#698572,
  FATE#311724).
- patches.drivers/0018-sfc-Move-efx_xmit_done-declaration-into-correct-stan.patch:
  sfc: Move efx_xmit_done() declaration into correct stanza
  (bnc#698572, FATE#311724).
- patches.drivers/0019-sfc-Move-shared-members-of-struct-falcon_nic_data-in.patch:
  sfc: Move shared members of struct falcon_nic_data into struct
  efx_nic (bnc#698572, FATE#311724).
- patches.drivers/0020-sfc-Maintain-interrupt-moderation-values-in-ticks-no.patch:
  sfc: Maintain interrupt moderation values in ticks, not
  microseconds (bnc#698572, FATE#311724).
- patches.drivers/0021-sfc-Removed-kernel-doc-for-nonexistent-member-of-efx.patch:
  sfc: Removed kernel-doc for nonexistent member of
  efx_phy_operations (bnc#698572, FATE#311724).
- patches.drivers/0022-sfc-Remove-pointless-abstraction-of-memory-BAR-numbe.patch:
  sfc: Remove pointless abstraction of memory BAR number
  (bnc#698572, FATE#311724).
- patches.drivers/0023-sfc-Merge-falcon_probe_phy-into-falcon_probe_port.patch:
  sfc: Merge falcon_probe_phy() into falcon_probe_port()
  (bnc#698572, FATE#311724).
- patches.drivers/0024-sfc-Remove-incorrect-assertion-from-efx_pci_remove_m.patch:
  sfc: Remove incorrect assertion from efx_pci_remove_main()
  (bnc#698572, FATE#311724).
- patches.drivers/0025-sfc-Remove-unnecessary-tests-of-efx-membase.patch:
  sfc: Remove unnecessary tests of efx->membase (bnc#698572,
  FATE#311724).
- patches.drivers/0026-sfc-Move-MTD-probe-after-netdev-registration-and-nam.patch:
  sfc: Move MTD probe after netdev registration and name
  allocation (bnc#698572, FATE#311724).
- patches.drivers/0027-sfc-Merge-efx_fc_resolve-into-efx_mdio_get_pause.patch:
  sfc: Merge efx_fc_resolve() into efx_mdio_get_pause()
  (bnc#698572, FATE#311724).
- patches.drivers/0028-sfc-Remove-unused-code-for-non-autoneg-speed-duplex-.patch:
  sfc: Remove unused code for non-autoneg speed/duplex switching
  (bnc#698572, FATE#311724).
- patches.drivers/0029-sfc-Rename-xfp-file-and-functions-to-reflect-reality.patch:
  sfc: Rename 'xfp' file and functions to reflect reality
  (bnc#698572, FATE#311724).
- patches.drivers/0030-sfc-Really-allow-RX-checksum-offload-to-be-disabled.patch:
  sfc: Really allow RX checksum offload to be disabled
  (bnc#698572, FATE#311724).
- patches.drivers/0033-sfc-Remove-pointless-abstraction-of-memory-BAR-numbe.patch:
  sfc: Remove pointless abstraction of memory BAR number (2)
  (bnc#698572, FATE#311724).
- patches.drivers/0034-sfc-Remove-redundant-gotos-from-__efx_rx_packet.patch:
  sfc: Remove redundant gotos from __efx_rx_packet() (bnc#698572,
  FATE#311724).
- patches.drivers/0035-sfc-Remove-ridiculously-paranoid-assertions.patch:
  sfc: Remove ridiculously paranoid assertions (bnc#698572,
  FATE#311724).
- patches.drivers/0036-sfc-Move-assertions-and-buffer-cleanup-earlier-in-ef.patch:
  sfc: Move assertions and buffer cleanup earlier in
  efx_rx_packet_lro() (bnc#698572, FATE#311724).
- patches.drivers/0037-sfc-Record-RX-queue-number-on-GRO-path.patch:
  sfc: Record RX queue number on GRO path (bnc#698572,
  FATE#311724).
- patches.drivers/0038-sfc-SFT9001-Reset-LED-configuration-correctly-after-.patch:
  sfc: SFT9001: Reset LED configuration correctly after blinking
  (bnc#698572, FATE#311724).
- patches.drivers/0039-sfc-Use-a-single-blink-implementation.patch:
  sfc: Use a single blink implementation (bnc#698572,
  FATE#311724).
- patches.drivers/0040-sfc-Rename-efx_board-init_leds-to-init_phy-and-use-f.patch:
  sfc: Rename efx_board::init_leds to init_phy and use for
  SFN4111T (bnc#698572, FATE#311724).
- patches.drivers/0041-sfc-Make-board-information-explicitly-Falcon-specifi.patch:
  sfc: Make board information explicitly Falcon-specific
  (bnc#698572, FATE#311724).
- patches.drivers/0042-sfc-Move-definition-of-struct-falcon_nic_data-into-f.patch:
  sfc: Move definition of struct falcon_nic_data into falcon.h
  (bnc#698572, FATE#311724).
- patches.drivers/0043-sfc-Move-struct-falcon_board-into-struct-falcon_nic_.patch:
  sfc: Move struct falcon_board into struct falcon_nic_data
  (bnc#698572, FATE#311724).
- patches.drivers/0044-sfc-Move-all-I2C-stuff-into-struct-falcon_board.patch:
  sfc: Move all I2C stuff into struct falcon_board (bnc#698572,
  FATE#311724).
- patches.drivers/0045-sfc-Gather-link-state-fields-in-struct-efx_nic-into-.patch:
  sfc: Gather link state fields in struct efx_nic into new struct
  efx_link_state (bnc#698572, FATE#311724).
- patches.drivers/0046-sfc-Remove-unnecessary-casts-to-struct-sk_buff.patch:
  sfc: Remove unnecessary casts to struct sk_buff * (bnc#698572,
  FATE#311724).
- patches.drivers/0047-sfc-Remove-redundant-efx_xmit-function.patch:
  sfc: Remove redundant efx_xmit() function (bnc#698572,
  FATE#311724).
- patches.drivers/0048-sfc-Combine-high-level-header-files.patch:
  sfc: Combine high-level header files (bnc#698572, FATE#311724).
- patches.drivers/0049-sfc-Log-interrupt-and-reset-type-names-not-numbers.patch:
  sfc: Log interrupt and reset type names, not numbers
  (bnc#698572, FATE#311724).
- patches.drivers/0050-sfc-Fix-descriptor-cache-sizes.patch:
  sfc: Fix descriptor cache sizes (bnc#698572, FATE#311724).
- patches.drivers/0051-sfc-Treat-all-MAC-registers-as-128-bit.patch:
  sfc: Treat all MAC registers as 128-bit (bnc#698572,
  FATE#311724).
- patches.drivers/0052-sfc-Strengthen-EFX_ASSERT_RESET_SERIALISED.patch:
  sfc: Strengthen EFX_ASSERT_RESET_SERIALISED (bnc#698572,
  FATE#311724).
- patches.drivers/0053-sfc-Comment-corrections.patch: sfc:
  Comment corrections (bnc#698572, FATE#311724).
- patches.drivers/0054-sfc-Remove-unused-constant.patch: sfc:
  Remove unused constant (bnc#698572, FATE#311724).
- patches.drivers/0055-sfc-Clean-up-struct-falcon_board-and-struct-falcon_b.patch:
  sfc: Clean up struct falcon_board and struct falcon_board_data
  (bnc#698572, FATE#311724).
- patches.drivers/0056-sfc-Fix-bugs-in-RX-queue-flushing.patch:
  sfc: Fix bugs in RX queue flushing (bnc#698572, FATE#311724).
- patches.drivers/0057-sfc-Remove-unused-function-efx_flush_queues.patch:
  sfc: Remove unused function efx_flush_queues() (bnc#698572,
  FATE#311724).
- patches.drivers/0058-sfc-Only-switch-Falcon-MAC-clocks-as-necessary.patch:
  sfc: Only switch Falcon MAC clocks as necessary (bnc#698572,
  FATE#311724).
- patches.drivers/0059-sfc-Hold-MAC-lock-for-longer-in-efx_init_port.patch:
  sfc: Hold MAC lock for longer in efx_init_port() (bnc#698572,
  FATE#311724).
- patches.drivers/0060-sfc-Split-MAC-stats-DMA-initiation-and-completion.patch:
  sfc: Split MAC stats DMA initiation and completion (bnc#698572,
  FATE#311724).
- patches.drivers/0061-sfc-Move-Falcon-board-PHY-MAC-monitoring-code-to-fal.patch:
  sfc: Move Falcon board/PHY/MAC monitoring code to falcon.c
  (bnc#698572, FATE#311724).
- patches.drivers/0062-sfc-Simplify-XMAC-link-polling.patch:
  sfc: Simplify XMAC link polling (bnc#698572, FATE#311724).
- patches.drivers/0063-sfc-Change-MAC-promiscuity-and-multicast-hash-at-the.patch:
  sfc: Change MAC promiscuity and multicast hash at the same time
  (bnc#698572, FATE#311724).
- patches.drivers/0064-sfc-Move-inline-comment-into-kernel-doc.patch:
  sfc: Move inline comment into kernel-doc (bnc#698572,
  FATE#311724).
- patches.drivers/0065-sfc-Do-not-set-net_device-trans_start-in-self-test.patch:
  sfc: Do not set net_device::trans_start in self-test
  (bnc#698572, FATE#311724).
- patches.drivers/0066-sfc-Simplify-PHY-polling.patch: sfc:
  Simplify PHY polling (bnc#698572, FATE#311724).
- patches.drivers/0067-sfc-QT202x-Reset-before-reading-PHY-id.patch:
  sfc: QT202x: Reset before reading PHY id (bnc#698572,
  FATE#311724).
- patches.drivers/0068-sfc-Replace-MDIO-spinlock-with-mutex.patch:
  sfc: Replace MDIO spinlock with mutex (bnc#698572, FATE#311724).
- patches.drivers/0069-sfc-Always-start-Falcon-using-the-XMAC.patch:
  sfc: Always start Falcon using the XMAC (bnc#698572,
  FATE#311724).
- patches.drivers/0070-sfc-Limit-some-hardware-workarounds-to-Falcon.patch:
  sfc: Limit some hardware workarounds to Falcon (bnc#698572,
  FATE#311724).
- patches.drivers/0071-sfc-Remove-EFX_WORKAROUND_9141-macro.patch:
  sfc: Remove EFX_WORKAROUND_9141 macro (bnc#698572, FATE#311724).
- patches.drivers/0072-sfc-Remove-another-unused-workaround-macro.patch:
  sfc: Remove another unused workaround macro (bnc#698572,
  FATE#311724).
- patches.drivers/0073-sfc-Remove-some-redundant-whitespace.patch:
  sfc: Remove some redundant whitespace (bnc#698572, FATE#311724).
- patches.drivers/0074-sfc-Decouple-NIC-revision-number-from-Falcon-PCI-rev.patch:
  sfc: Decouple NIC revision number from Falcon PCI revision
  number (bnc#698572, FATE#311724).
- patches.drivers/0075-sfc-Move-descriptor-cache-base-addresses-to-struct-e.patch:
  sfc: Move descriptor cache base addresses to struct efx_nic_type
  (bnc#698572, FATE#311724).
- patches.drivers/0076-sfc-Clean-up-RX-event-handling.patch:
  sfc: Clean up RX event handling (bnc#698572, FATE#311724).
- patches.drivers/0077-sfc-Remove-redundant-writes-to-INT_ADR_KER.patch:
  sfc: Remove redundant writes to INT_ADR_KER (bnc#698572,
  FATE#311724).
- patches.drivers/0078-sfc-Remove-duplicate-hardware-structure-definitions.patch:
  sfc: Remove duplicate hardware structure definitions
  (bnc#698572, FATE#311724).
- patches.drivers/0079-sfc-Turn-pause-frame-generation-on-and-off-at-the-MA.patch:
  sfc: Turn pause frame generation on and off at the MAC, not
  the RX FIFO (bnc#698572, FATE#311724).
- patches.drivers/0080-sfc-Move-Falcon-NIC-operations-to-efx_nic_type.patch:
  sfc: Move Falcon NIC operations to efx_nic_type (bnc#698572,
  FATE#311724).
- patches.drivers/0081-sfc-Refactor-link-configuration.patch:
  sfc: Refactor link configuration (bnc#698572, FATE#311724).
- patches.drivers/0082-sfc-Generalise-link-state-monitoring.patch:
  sfc: Generalise link state monitoring (bnc#698572, FATE#311724).
- patches.drivers/0083-sfc-Add-power-management-and-wake-on-LAN-support.patch:
  sfc: Add power-management and wake-on-LAN support (bnc#698572,
  FATE#311724).
- patches.drivers/0084-sfc-Implement-ethtool-reset-operation.patch:
  sfc: Implement ethtool reset operation (bnc#698572,
  FATE#311724).
- patches.drivers/0085-sfc-Add-efx_nic_type-operation-for-register-self-tes.patch:
  sfc: Add efx_nic_type operation for register self-test
  (bnc#698572, FATE#311724).
- patches.drivers/0086-sfc-Add-efx_nic_type-operation-for-NVRAM-self-test.patch:
  sfc: Add efx_nic_type operation for NVRAM self-test (bnc#698572,
  FATE#311724).
- patches.drivers/0087-sfc-Add-efx_nic_type-operation-for-identity-LED-cont.patch:
  sfc: Add efx_nic_type operation for identity LED control
  (bnc#698572, FATE#311724).
- patches.drivers/0088-sfc-Separate-shared-NIC-code-from-Falcon-specific-an.patch:
  sfc: Separate shared NIC code from Falcon-specific and rename
  accordingly (bnc#698572, FATE#311724).
- patches.drivers/0089-sfc-Fold-falcon_probe_nic_variant-into-falcon_probe_.patch:
  sfc: Fold falcon_probe_nic_variant() into falcon_probe_nic()
  (bnc#698572, FATE#311724).
- patches.drivers/0090-sfc-Extend-loopback-mode-enumeration.patch:
  sfc: Extend loopback mode enumeration (bnc#698572, FATE#311724).
- patches.drivers/0091-sfc-Remove-static-PHY-data-and-enumerations.patch:
  sfc: Remove static PHY data and enumerations (bnc#698572,
  FATE#311724).
- patches.drivers/0092-sfc-Extend-MTD-driver-for-use-with-new-NICs.patch:
  sfc: Extend MTD driver for use with new NICs (bnc#698572,
  FATE#311724).
- patches.drivers/0093-sfc-Allow-for-additional-checksum-offload-features.patch:
  sfc: Allow for additional checksum offload features (bnc#698572,
  FATE#311724).
- patches.drivers/0094-sfc-Rename-falcon.h-to-nic.h.patch: sfc:
  Rename falcon.h to nic.h (bnc#698572, FATE#311724).
- patches.drivers/0095-sfc-Move-shared-NIC-code-from-falcon.c-to-new-source.patch:
  sfc: Move shared NIC code from falcon.c to new source file nic.c
  (bnc#698572, FATE#311724).
- patches.drivers/0096-sfc-Add-firmware-protocol-definitions-MCDI.patch:
  sfc: Add firmware protocol definitions (MCDI) (bnc#698572,
  FATE#311724).
- patches.drivers/0097-sfc-Add-support-for-SFC9000-family-1.patch:
  sfc: Add support for SFC9000 family (1) (bnc#698572,
  FATE#311724).
- patches.drivers/0098-sfc-Add-support-for-SFC9000-family-2.patch:
  sfc: Add support for SFC9000 family (2) (bnc#698572,
  FATE#311724).
- patches.drivers/0099-sfc-Implement-TSO-for-TCP-IPv6.patch:
  sfc: Implement TSO for TCP/IPv6 (bnc#698572, FATE#311724).
- patches.drivers/0100-sfc-Update-version-copyright-dates-authors.patch:
  sfc: Update version, copyright dates, authors (bnc#698572,
  FATE#311724).
- patches.drivers/0101-drivers-net-sfc-Correct-code-taking-the-size-of-a-po.patch:
  drivers/net/sfc: Correct code taking the size of a pointer
  (bnc#698572, FATE#311724).
- patches.drivers/0102-sfc-Move-PHY-software-state-initialisation-from-init.patch:
  sfc: Move PHY software state initialisation from init() into
  probe() (bnc#698572, FATE#311724).
- patches.drivers/0103-sfc-Include-XGXS-in-XMAC-link-status-check-except-in.patch:
  sfc: Include XGXS in XMAC link status check except in XGMII
  loopback (bnc#698572, FATE#311724).
- patches.drivers/0105-sfc-QT2025C-Work-around-PHY-bug.patch:
  sfc: QT2025C: Work around PHY bug (bnc#698572, FATE#311724).
- patches.drivers/0106-sfc-QT2025C-Switch-into-self-configure-mode-when-not.patch:
  sfc: QT2025C: Switch into self-configure mode when not in
  loopback (bnc#698572, FATE#311724).
- patches.drivers/0107-sfc-QT2025C-Work-around-PHY-firmware-initialisation-.patch:
  sfc: QT2025C: Work around PHY firmware initialisation bug
  (bnc#698572, FATE#311724).
- patches.drivers/0108-sfc-QT2025C-Add-error-message-for-suspected-bad-SFP-.patch:
  sfc: QT2025C: Add error message for suspected bad SFP+ cables
  (bnc#698572, FATE#311724).
- patches.drivers/0109-sfc-Disable-TX-descriptor-prefetch-watchdog.patch:
  sfc: Disable TX descriptor prefetch watchdog (bnc#698572,
  FATE#311724).
- patches.drivers/0111-sfc-Fix-polling-for-slow-MCDI-operations.patch:
  sfc: Fix polling for slow MCDI operations (bnc#698572,
  FATE#311724).
- patches.drivers/0112-sfc-Fix-conditions-for-MDIO-self-test.patch:
  sfc: Fix conditions for MDIO self-test (bnc#698572,
  FATE#311724).
- patches.drivers/0113-sfc-QT202x-Remove-unreliable-MMD-check-at-initialisa.patch:
  sfc: QT202x: Remove unreliable MMD check at initialisation
  (bnc#698572, FATE#311724).
- patches.drivers/0114-sfc-Add-workspace-for-GMAC-bug-workaround-to-MCDI-MA.patch:
  sfc: Add workspace for GMAC bug workaround to MCDI MAC_STATS
  buffer (bnc#698572, FATE#311724).
- patches.drivers/0115-sfc-Use-fixed-size-buffers-for-MCDI-NVRAM-requests.patch:
  sfc: Use fixed-size buffers for MCDI NVRAM requests (bnc#698572,
  FATE#311724).
- patches.drivers/0116-sfc-Update-MCDI-protocol-definitions.patch:
  sfc: Update MCDI protocol definitions (bnc#698572, FATE#311724).
- patches.drivers/0117-sfc-Handle-firmware-assertion-failure-while-resettin.patch:
  sfc: Handle firmware assertion failure while resetting
  (bnc#698572, FATE#311724).
- patches.drivers/0118-sfc-Enable-autonegotiated-flow-control-by-default-if.patch:
  sfc: Enable autonegotiated flow-control by default if supported
  (bnc#698572, FATE#311724).
- patches.drivers/0119-sfc-Replace-PHY-MDIO-test-with-an-alive-test.patch:
  sfc: Replace PHY MDIO test with an 'alive' test (bnc#698572,
  FATE#311724).
- patches.drivers/0120-sfc-Implement-NVRAM-selftest-for-SFC9000-family.patch:
  sfc: Implement NVRAM selftest for SFC9000 family (bnc#698572,
  FATE#311724).
- patches.drivers/0121-sfc-Survive-ISR0-0-bug-in-the-shared-IRQ-case.patch:
  sfc: Survive ISR0=0 bug in the shared IRQ case (bnc#698572,
  FATE#311724).
- patches.drivers/0122-sfc-Add-some-missing-bits-to-register-self-test-mask.patch:
  sfc: Add some missing bits to register self-test masks
  (bnc#698572, FATE#311724).
- patches.drivers/0123-sfc-Remove-declarations-of-nonexistent-functions.patch:
  sfc: Remove declarations of nonexistent functions (bnc#698572,
  FATE#311724).
- patches.drivers/0124-sfc-Fix-some-incorrect-or-redundant-comments.patch:
  sfc: Fix some incorrect or redundant comments (bnc#698572,
  FATE#311724).
- patches.drivers/0125-sfc-Do-not-include-unneeded-headers.patch:
  sfc: Do not include unneeded headers (bnc#698572, FATE#311724).
- patches.drivers/0128-sfc-Fix-SFE4002-initialisation.patch:
  sfc: Fix SFE4002 initialisation (bnc#698572, FATE#311724).
- patches.drivers/0130-sfc-Fix-sign-of-efx_mcdi_poll_reboot-error-in-efx_mc.patch:
  sfc: Fix sign of efx_mcdi_poll_reboot() error in efx_mcdi_poll()
  (bnc#698572, FATE#311724).
- patches.drivers/0131-sfc-SFE4002-SFN4112F-Widen-temperature-and-voltage-t.patch:
  sfc: SFE4002/SFN4112F: Widen temperature and voltage tolerances
  (bnc#698572, FATE#311724).
- patches.drivers/0134-sfc-Wait-at-most-10ms-for-the-MC-to-finish-reading-o.patch:
  sfc: Wait at most 10ms for the MC to finish reading out MAC
  statistics (bnc#698572, FATE#311724).
- patches.drivers/0135-sfc-Always-close-net-device-at-the-end-of-a-disablin.patch:
  sfc: Always close net device at the end of a disabling reset
  (bnc#698572, FATE#311724).
- patches.drivers/0136-sfc-Change-falcon_probe_board-to-fail-for-unsupporte.patch:
  sfc: Change falcon_probe_board() to fail for unsupported boards
  (bnc#698572, FATE#311724).
- patches.drivers/0137-sfc-Ignore-parity-errors-in-the-other-port-s-SRAM.patch:
  sfc: Ignore parity errors in the other port's SRAM (bnc#698572,
  FATE#311724).
- patches.drivers/0138-sfc-Consistently-report-short-MCDI-responses-as-EIO.patch:
  sfc: Consistently report short MCDI responses as EIO
  (bnc#698572, FATE#311724).
- patches.drivers/0139-sfc-Handle-serious-errors-in-exactly-one-interrupt-h.patch:
  sfc: Handle serious errors in exactly one interrupt handler
  (bnc#698572, FATE#311724).
- patches.drivers/0140-sfc-Stop-masking-out-XGMII-faults-over-reconfigures.patch:
  sfc: Stop masking out XGMII faults over reconfigures
  (bnc#698572, FATE#311724).
- patches.drivers/0141-sfc-Reconfigure-the-XAUI-serdes-after-an-EM-reset.patch:
  sfc: Reconfigure the XAUI serdes after an EM reset (bnc#698572,
  FATE#311724).
- patches.drivers/0142-sfc-Extend-the-legacy-interrupt-workarounds.patch:
  sfc: Extend the legacy interrupt workarounds (bnc#698572,
  FATE#311724).
- patches.drivers/0143-sfc-Log-specific-message-for-failure-of-NVRAM-self-t.patch:
  sfc: Log specific message for failure of NVRAM self-test
  (bnc#698572, FATE#311724).
- patches.drivers/0144-sfc-Read-MEM_STAT-for-SRM_PERR-as-well-as-MEM_PERR-e.patch:
  sfc: Read MEM_STAT for SRM_PERR as well as MEM_PERR errors
  (bnc#698572, FATE#311724).
- patches.drivers/0145-sfc-Enable-IPv6-RSS-using-random-key-for-Toeplitz-ha.patch:
  sfc: Enable IPv6 RSS using random key for Toeplitz hash
  (bnc#698572, FATE#311724).
- patches.drivers/0146-sfc-Update-MCDI-protocol-definitions.patch:
  sfc: Update MCDI protocol definitions (bnc#698572, FATE#311724).
- patches.drivers/0147-sfc-Set-PERIODIC_NOEVENT-flag-for-MC_CMD_MAC_STATS.patch:
  sfc: Set PERIODIC_NOEVENT flag for MC_CMD_MAC_STATS (bnc#698572,
  FATE#311724).
- patches.drivers/0148-sfc-Break-NAPI-processing-after-one-ring-full-of-TX-.patch:
  sfc: Break NAPI processing after one ring-full of TX completions
  (bnc#698572, FATE#311724).
- patches.drivers/0149-sfc-Add-necessary-parentheses-to-macro-definitions-i.patch:
  sfc: Add necessary parentheses to macro definitions in
  net_driver.h (bnc#698572, FATE#311724).
- patches.drivers/0150-sfc-Clean-up-efx_nic-irq_zero_count.patch:
  sfc: Clean up efx_nic::irq_zero_count (bnc#698572, FATE#311724).
- patches.drivers/0151-sfc-Add-Siena-PHY-BIST-and-cable-diagnostic-support.patch:
  sfc: Add Siena PHY BIST and cable diagnostic support
  (bnc#698572, FATE#311724).
- patches.drivers/0152-sfc-Test-only-the-first-pair-of-TX-queues.patch:
  sfc: Test only the first pair of TX queues (bnc#698572,
  FATE#311724).
- patches.drivers/0153-sfc-Create-multiple-TX-queues.patch: sfc:
  Create multiple TX queues (bnc#698572, FATE#311724).
- patches.drivers/0154-sfc-Rename-struct-efx_mcdi_phy_cfg-to-efx_mcdi_phy_d.patch:
  sfc: Rename struct efx_mcdi_phy_cfg to efx_mcdi_phy_data
  (bnc#698572, FATE#311724).
- patches.drivers/0155-sfc-Reschedule-any-resets-scheduled-inside-efx_pm_fr.patch:
  sfc: Reschedule any resets scheduled inside efx_pm_freeze()
  (bnc#698572, FATE#311724).
- patches.drivers/0156-sfc-Workaround-flush-failures-on-Falcon-B0.patch:
  sfc: Workaround flush failures on Falcon B0 (bnc#698572,
  FATE#311724).
- patches.drivers/0157-sfc-Synchronise-link_advertising-and-wanted_fc-on-Si.patch:
  sfc: Synchronise link_advertising and wanted_fc on Siena
  (bnc#698572, FATE#311724).
- patches.drivers/0158-sfc-Wait-for-the-link-to-stay-up-before-running-loop.patch:
  sfc: Wait for the link to stay up before running loopback
  selftest (bnc#698572, FATE#311724).
- patches.drivers/0159-sfc-Allow-DRV_GEN-events-to-be-used-outside-of-selft.patch:
  sfc: Allow DRV_GEN events to be used outside of selftests
  (bnc#698572, FATE#311724).
- patches.drivers/0160-sfc-Remove-efx_rx_queue-add_lock.patch:
  sfc: Remove efx_rx_queue::add_lock (bnc#698572, FATE#311724).
- patches.drivers/0161-sfc-Support-only-two-rx-buffers-per-page.patch:
  sfc: Support only two rx buffers per page (bnc#698572,
  FATE#311724).
- patches.drivers/0162-sfc-Recycle-discarded-rx-buffers-back-onto-the-queue.patch:
  sfc: Recycle discarded rx buffers back onto the queue
  (bnc#698572, FATE#311724).
- patches.drivers/0163-sfc-Allow-shared-pages-to-be-recycled.patch:
  sfc: Allow shared pages to be recycled (bnc#698572,
  FATE#311724).
- patches.drivers/0164-sfc-Only-count-bad-packets-in-rx_errors.patch:
  sfc: Only count bad packets in rx_errors (bnc#698572,
  FATE#311724).
- patches.drivers/0165-sfc-Get-port-number-from-CS_PORT_NUM-not-PCI-functio.patch:
  sfc: Get port number from CS_PORT_NUM, not PCI function number
  (bnc#698572, FATE#311724).
- patches.drivers/0168-sfc-Store-port-number-in-net_device-dev_id.patch:
  sfc: Store port number in net_device::dev_id (bnc#698572,
  FATE#311724).
- patches.drivers/0170-sfc-Implement-ethtool-register-dump-operation.patch:
  sfc: Implement ethtool register dump operation (bnc#698572,
  FATE#311724).
- patches.drivers/0171-sfc-Log-MTD-errors-using-partition-name-not-just-net.patch:
  sfc: Log MTD errors using partition name, not just net device
  name (bnc#698572, FATE#311724).
- patches.drivers/0172-sfc-Implement-message-level-control.patch:
  sfc: Implement message level control (bnc#698572, FATE#311724).
- patches.drivers/0173-sfc-Replace-EFX_DRIVER_NAME-with-KBUILD_MODNAME.patch:
  sfc: Replace EFX_DRIVER_NAME with KBUILD_MODNAME (bnc#698572,
  FATE#311724).
- patches.drivers/0174-sfc-Disable-setting-feature-flags-that-are-not-imple.patch:
  sfc: Disable setting feature flags that are not implemented
  (bnc#698572, FATE#311724).
- patches.drivers/0177-sfc-Move-siena_nic_data-ipv6_rss_key-to-efx_nic-rx_h.patch:
  sfc: Move siena_nic_data::ipv6_rss_key to efx_nic::rx_hash_key
  (bnc#698572, FATE#311724).
- patches.drivers/0179-sfc-Log-clearer-error-messages-for-hardware-monitor.patch:
  sfc: Log clearer error messages for hardware monitor
  (bnc#698572, FATE#311724).
- patches.drivers/0185-sfc-Use-MCDI-RX_BAD_FCS_PKTS-count-as-MAC-rx_bad-cou.patch:
  sfc: Use MCDI RX_BAD_FCS_PKTS count as MAC rx_bad count
  (bnc#698572, FATE#311724).
- patches.drivers/0186-sfc-Accumulate-RX_NODESC_DROP-count-in-rx_dropped-no.patch:
  sfc: Accumulate RX_NODESC_DROP count in rx_dropped, not
  rx_over_errors (bnc#698572, FATE#311724).
- patches.drivers/0187-sfc-Remove-declarations-of-functions-that-no-longer-.patch:
  sfc: Remove declarations of functions that no longer exist
  (bnc#698572, FATE#311724).
- patches.drivers/0188-sfc-Fix-failure-paths-in-efx_probe_port.patch:
  sfc: Fix failure paths in efx_probe_port() (bnc#698572,
  FATE#311724).
- patches.drivers/0189-sfc-Allocate-DMA-and-event-rings-using-GFP_KERNEL.patch:
  sfc: Allocate DMA and event rings using GFP_KERNEL (bnc#698572,
  FATE#311724).
- patches.drivers/0190-sfc-Abstract-channel-and-index-lookup-for-RX-queues.patch:
  sfc: Abstract channel and index lookup for RX queues
  (bnc#698572, FATE#311724).
- patches.drivers/0191-sfc-Refactor-channel-and-queue-lookup-and-iteration.patch:
  sfc: Refactor channel and queue lookup and iteration
  (bnc#698572, FATE#311724).
- patches.drivers/0192-sfc-Allocate-each-channel-separately-along-with-its-.patch:
  sfc: Allocate each channel separately, along with its RX and
  TX queues (bnc#698572, FATE#311724).
- patches.drivers/0193-sfc-Make-the-dmaq-size-a-run-time-setting-rather-tha.patch:
  sfc: Make the dmaq size a run-time setting (rather than
  compile-time) (bnc#698572, FATE#311724).
- patches.drivers/0194-sfc-Allow-changing-the-DMA-ring-sizes-dynamically-vi.patch:
  sfc: Allow changing the DMA ring sizes dynamically via ethtool
  (bnc#698572, FATE#311724).
- patches.drivers/0195-sfc-Fix-order-of-channel_name-array-dimensions.patch:
  sfc: Fix order of channel_name array dimensions (bnc#698572,
  FATE#311724).
- patches.drivers/0199-sfc-Clean-up-and-correct-comments-on-efx_monitor.patch:
  sfc: Clean up and correct comments on efx_monitor() (bnc#698572,
  FATE#311724).
- patches.drivers/0201-sfc-Remove-support-for-SFN4111T-SFT9001-and-Falcon-G.patch:
  sfc: Remove support for SFN4111T, SFT9001 and Falcon GMAC
  (bnc#698572, FATE#311724).
- patches.drivers/0202-sfc-Add-support-for-SFE4003-board-and-TXC43128-PHY.patch:
  sfc: Add support for SFE4003 board and TXC43128 PHY (bnc#698572,
  FATE#311724).
- patches.drivers/0208-sfc-Reduce-log-level-for-MCDI-error-response-in-efx_.patch:
  sfc: Reduce log level for MCDI error response in efx_mcdi_rpc()
  (bnc#698572, FATE#311724).
- patches.drivers/0209-sfc-Fix-condition-for-no-op-in-set_phy_flash_cfg.patch:
  sfc: Fix condition for no-op in set_phy_flash_cfg() (bnc#698572,
  FATE#311724).
- patches.drivers/0210-sfc-Distinguish-critical-and-non-critical-over-tempe.patch:
  sfc: Distinguish critical and non-critical over-temperature
  conditions (bnc#698572, FATE#311724).
- patches.drivers/0211-sfc-Read-to-clear-LM87-alarm-interrupt-status-at-sta.patch:
  sfc: Read-to-clear LM87 alarm/interrupt status at start of day
  (bnc#698572, FATE#311724).
- patches.drivers/0212-sfc-Clear-RXIN_SEL-when-soft-resetting-QT2025C.patch:
  sfc: Clear RXIN_SEL when soft-resetting QT2025C (bnc#698572,
  FATE#311724).
- patches.drivers/0213-sfc-Fix-event-based-MCDI-completion-and-MC-REBOOT-CM.patch:
  sfc: Fix event based MCDI completion and MC REBOOT/CMDDONE
  ordering issue (bnc#698572, FATE#311724).
- patches.drivers/0214-sfc-Remove-broken-automatic-fallback-for-invalid-Fal.patch:
  sfc: Remove broken automatic fallback for invalid Falcon
  chip/board config (bnc#698572, FATE#311724).
- patches.drivers/0215-sfc-Expose-Falcon-BootROM-config-through-MTD-not-eth.patch:
  sfc: Expose Falcon BootROM config through MTD, not ethtool
  (bnc#698572, FATE#311724).
- patches.drivers/0216-sfc-Remove-unnecessary-inclusion-of-various-private-.patch:
  sfc: Remove unnecessary inclusion of various private header
  files (bnc#698572, FATE#311724).
- patches.drivers/0217-sfc-Move-SPI-state-to-struct-falcon_nic_data.patch:
  sfc: Move SPI state to struct falcon_nic_data (bnc#698572,
  FATE#311724).
- patches.drivers/0218-sfc-Move-mdio_lock-to-struct-falcon_nic_data.patch:
  sfc: Move mdio_lock to struct falcon_nic_data (bnc#698572,
  FATE#311724).
- patches.drivers/0219-sfc-Move-Falcon-global-event-handling-to-falcon.c.patch:
  sfc: Move Falcon global event handling to falcon.c (bnc#698572,
  FATE#311724).
- patches.drivers/0220-sfc-Move-xmac_poll_required-into-struct-falcon_nic_d.patch:
  sfc: Move xmac_poll_required into struct falcon_nic_data
  (bnc#698572, FATE#311724).
- patches.drivers/0221-sfc-Update-kernel-doc-to-match-earlier-move-of-Toepl.patch:
  sfc: Update kernel-doc to match earlier move of Toeplitz hash
  key (bnc#698572, FATE#311724).
- patches.drivers/0222-sfc-When-waking-a-stopped-tx_queue-only-lock-that-tx.patch:
  sfc: When waking a stopped tx_queue, only lock that tx_queue
  (bnc#698572, FATE#311724).
- patches.drivers/0223-sfc-Use-current-MAC-address-not-NVRAM-MAC-address-fo.patch:
  sfc: Use current MAC address, not NVRAM MAC address,  for WoL
  filter (bnc#698572, FATE#311724).
- patches.drivers/0224-sfc-Store-MAC-address-from-NVRAM-in-net_device-perm_.patch:
  sfc: Store MAC address from NVRAM in net_device::perm_addr
  (bnc#698572, FATE#311724).
- patches.drivers/0225-sfc-Reorder-struct-efx_nic-to-separate-fields-by-vol.patch:
  sfc: Reorder struct efx_nic to separate fields by volatility
  (bnc#698572, FATE#311724).
- patches.drivers/0226-sfc-Use-ACCESS_ONCE-when-copying-efx_tx_queue-read_c.patch:
  sfc: Use ACCESS_ONCE when copying efx_tx_queue::read_count
  (bnc#698572, FATE#311724).
- patches.drivers/0227-sfc-Expand-correct-comments-on-collector-behaviour-a.patch:
  sfc: Expand/correct comments on collector behaviour and function
  usage (bnc#698572, FATE#311724).
- patches.drivers/0228-sfc-Remove-redundant-memory-barriers-between-MMIOs.patch:
  sfc: Remove redundant memory barriers between MMIOs (bnc#698572,
  FATE#311724).
- patches.drivers/0229-sfc-Add-compile-time-checks-for-correctness-of-paged.patch:
  sfc: Add compile-time checks for correctness of paged register
  writes (bnc#698572, FATE#311724).
- patches.drivers/0230-sfc-Remove-locking-from-implementation-of-efx_writeo.patch:
  sfc: Remove locking from implementation of efx_writeo_paged()
  (bnc#698572, FATE#311724).
- patches.drivers/0231-sfc-Use-TX-push-whenever-adding-descriptors-to-an-em.patch:
  sfc: Use TX push whenever adding descriptors to an empty queue
  (bnc#698572, FATE#311724).
- patches.drivers/0232-sfc-Log-start-and-end-of-ethtool-self-test-at-INFO-l.patch:
  sfc: Log start and end of ethtool self-test at INFO level
  (bnc#698572, FATE#311724).
- patches.drivers/0235-sfc-Fix-crash-in-legacy-onterrupt-handler-during-rin.patch:
  sfc: Fix crash in legacy onterrupt handler during ring
  reallocation (bnc#698572, FATE#311724).
- patches.drivers/0236-sfc-Fix-NAPI-list-corruption-during-ring-reallocatio.patch:
  sfc: Fix NAPI list corruption during ring reallocation
  (bnc#698572, FATE#311724).
- patches.drivers/0237-sfc-Remove-unused-field-and-comment-on-a-previously-.patch:
  sfc: Remove unused field and comment on a previously removed
  field (bnc#698572, FATE#311724).
- patches.drivers/0238-sfc-Remove-ancient-support-for-nesting-of-TX-stop.patch:
  sfc: Remove ancient support for nesting of TX stop (bnc#698572,
  FATE#311724).
- patches.drivers/0239-sfc-convert-references-to-LRO-to-GRO.patch:
  sfc: convert references to LRO to GRO (bnc#698572, FATE#311724).
- patches.drivers/0240-netdev-Use-default-implementation-of-ethtool_ops-get.patch:
  sfc: Report link-dwn while interface is down (bnc#698572,
  FATE#311724).
- patches.drivers/0242-sfc-Make-efx_get_tx_queue-an-inline-function.patch:
  sfc: Make efx_get_tx_queue() an inline function (bnc#698572,
  FATE#311724).
- patches.drivers/0243-sfc-Restore-the-effect-of-the-rss_cpus-module-parame.patch:
  sfc: Restore the effect of the rss_cpus module parameter
  (bnc#698572, FATE#311724).
- patches.drivers/0245-sfc-Move-TX-queue-core-queue-mapping-into-tx.c.patch:
  sfc: Move TX queue core queue mapping into tx.c (bnc#698572,
  FATE#311724).
- patches.drivers/0246-sfc-Distinguish-queue-lookup-from-test-for-queue-exi.patch:
  sfc: Distinguish queue lookup from test for queue existence
  (bnc#698572, FATE#311724).
- patches.drivers/0250-sfc-lower-stack-usage-in-efx_ethtool_self_test.patch:
  sfc: lower stack usage in efx_ethtool_self_test (bnc#698572,
  FATE#311724).
- patches.drivers/0251-sfc-Reduce-size-of-efx_rx_buffer-by-unionising-skb-a.patch:
  sfc: Reduce size of efx_rx_buffer by unionising skb and page
  (bnc#698572, FATE#311724).
- patches.drivers/0252-sfc-Reduce-size-of-efx_rx_buffer-further-by-removing.patch:
  sfc: Reduce size of efx_rx_buffer further by removing data
  member (bnc#698572, FATE#311724).
- patches.drivers/0253-sfc-Read-MC-firmware-version-when-requested-through-.patch:
  sfc: Read MC firmware version when requested through ethtool
  (bnc#698572, FATE#311724).
- patches.drivers/0254-sfc-Do-not-read-STAT1.FAULT-in-efx_mdio_check_mmd.patch:
  sfc: Do not read STAT1.FAULT in efx_mdio_check_mmd()
  (bnc#698572, FATE#311724).
- patches.drivers/0255-sfc-Update-copyright-dates.patch: sfc:
  Update copyright dates (bnc#698572, FATE#311724).
- patches.drivers/0256-sfc-Expose-TX-push-and-TSO-counters-through-ethtool-.patch:
  sfc: Expose TX push and TSO counters through ethtool statistics
  (bnc#698572, FATE#311724).
- patches.drivers/0257-sfc-Remove-configurable-FIFO-thresholds-for-pause-fr.patch:
  sfc: Remove configurable FIFO thresholds for pause frame
  generation (bnc#698572, FATE#311724).
- patches.drivers/0258-sfc-Bump-version-to-3.1.patch: sfc:
  Bump version to 3.1 (bnc#698572, FATE#311724).
- patches.drivers/0259-sfc-Use-write-combining-to-reduce-TX-latency.patch:
  sfc: Use write-combining to reduce TX latency (bnc#698572,
  FATE#311724).
- patches.drivers/0260-sfc-Siena-Disable-write-combining-when-SR-IOV-is-ena.patch:
  sfc: Siena: Disable write-combining when SR-IOV is enabled
  (bnc#698572, FATE#311724).
- patches.drivers/0262-sfc-Stop-the-TX-queues-during-loopback-self-tests.patch:
  sfc: Stop the TX queues during loopback self-tests (bnc#698572,
  FATE#311724).
- patches.drivers/0263-sfc-Do-not-use-efx_process_channel_now-in-online-sel.patch:
  sfc: Do not use efx_process_channel_now() in online self-test
  (bnc#698572, FATE#311724).
- patches.drivers/0264-sfc-Use-rmb-to-ensure-reads-occur-in-order.patch:
  sfc: Use rmb() to ensure reads occur in order (bnc#698572,
  FATE#311724).
- patches.drivers/0265-sfc-Always-map-MCDI-shared-memory-as-uncacheable.patch:
  sfc: Always map MCDI shared memory as uncacheable (bnc#698572,
  FATE#311724).
- patches.drivers/0266-sfc-Fix-oops-in-register-dump-after-mapping-change.patch:
  sfc: Fix oops in register dump after mapping change (bnc#698572,
  FATE#311724).
- Remove sfc_netback support:
  - patches.xen/xen3-auto-xen-drivers.diff: Refresh.
  - patches.xen/xen3-fixup-xen: Refresh.
  - patches.xen/xen3-patch-2.6.19: Refresh.
  - patches.xen/xen3-patch-2.6.22: Refresh.
  - patches.xen/xen3-patch-2.6.23: Refresh.
  - patches.xen/xen3-patch-2.6.24: Refresh.
  - patches.xen/xen3-patch-2.6.27: Refresh.
  - patches.xen/xen3-patch-2.6.31: Refresh.
  - patches.xen/xen3-patch-2.6.32: Refresh.
  - patches.xen/sfc-driverlink: Delete.
  - patches.xen/sfc-driverlink-conditional: Delete.
  - patches.xen/sfc-endianness: Delete.
  - patches.xen/sfc-external-sram: Delete.
  - patches.xen/sfc-kzalloc: Delete.
  - patches.xen/sfc-resource-driver: Delete.
  - patches.xen/sfc-set-arch: Delete.
  - patches.xen/sfc-update-to-kfifo-api: Delete.
* Fri Jun 24 2011 dsterba@suse.cz
- patches.suse/btrfs-add-helper-for-fs_info-closing.patch: btrfs:
  add helper for fs_info->closing (FATE#306586).
- patches.suse/btrfs-add-initial-tracepoint-support-for-btrfs.patch:
  Refresh.
- patches.suse/btrfs-add-missing-btrfs_free_path.patch: fs/btrfs:
  Add missing btrfs_free_path (FATE#306586).
- patches.suse/btrfs-add-missing-spin_unlock-to-a-rare-exit-path.patch:
  Refresh.
- patches.suse/btrfs-add-mount-o-auto_defrag.patch: Btrfs:
  add mount -o auto_defrag (FATE#306586).
- patches.suse/btrfs-add-mount-o-inode_cache.patch: Btrfs:
  add mount -o inode_cache (FATE#306586).
- patches.suse/btrfs-add-readonly-flag.patch: btrfs: add readonly
  flag (FATE#306586).
- patches.suse/btrfs-allocate-extent-state-and-check-the-result-pro.patch:
  Btrfs: allocate extent state and check the result properly
  (FATE#306586).
- patches.suse/btrfs-always-use-64bit-inode-number.patch: Btrfs:
  Always use 64bit inode number (FATE#306586).
- patches.suse/btrfs-avoid-delayed-metadata-items-during-commits.patch:
  Btrfs: avoid delayed metadata items during commits
  (FATE#306586).
- patches.suse/btrfs-avoid-stack-bloat-in-btrfs_ioctl_fs_info.patch:
  Btrfs: avoid stack bloat in btrfs_ioctl_fs_info() (FATE#306586).
- patches.suse/btrfs-avoid-taking-the-chunk_mutex-in-do_chunk_alloc.patch:
  Refresh.
- patches.suse/btrfs-avoid-taking-the-trans_mutex-in-btrfs_end_tran.patch:
  Refresh.
- patches.suse/btrfs-bug_on-is-deleted-from-the-caller-of-btrfs_tru.patch:
  Btrfs: BUG_ON is deleted from the caller of btrfs_truncate_item
  & btrfs_extend_item (FATE#306586).
- patches.suse/btrfs-cache-bitmaps-when-searching-for-a-cluster.patch:
  Btrfs: cache bitmaps when searching for a cluster (FATE#306586).
- patches.suse/btrfs-cache-free-inode-numbers-in-memory.patch:
  Btrfs: Cache free inode numbers in memory (FATE#306586).
- patches.suse/btrfs-check-for-duplicate-entries-in-the-free-space-.patch:
  Btrfs: check for duplicate entries in the free space cache
  (FATE#306586).
- patches.suse/btrfs-check-return-value-of-btrfs_inc_extent_ref.patch:
  Btrfs: check return value of btrfs_inc_extent_ref()
  (FATE#306586).
- patches.suse/btrfs-check-return-value-of-kmalloc.patch: Refresh.
- patches.suse/btrfs-check-the-return-value-from-set_anon_super.patch:
  Btrfs: check the return value from set_anon_super (FATE#306586).
- patches.suse/btrfs-cleanup-warnings-from-gcc-4.6-nonbugs.patch:
  Refresh.
- patches.suse/btrfs-clear-current-journal_info-on-async-transactio.patch:
  Btrfs: clear current->journal_info on async transaction commit
  (FATE#306586).
- patches.suse/btrfs-close_bdev_exclusive-should-use-the-same-flags.patch:
  Refresh.
- patches.suse/btrfs-create-special-free-space-cache-inode.patch:
  Refresh.
- patches.suse/btrfs-delete-unused-version.sh-script.patch:
  btrfs: Delete unused version.sh script (FATE#306586).
- patches.suse/btrfs-discard-flags-update: Refresh.
- patches.suse/btrfs-do-not-flush-csum-items-of-unchanged-file-data.patch:
  Btrfs: do not flush csum items of unchanged file data during
  treelog (FATE#306586).
- patches.suse/btrfs-document-a-mutex-lock-unlock-sequence.patch:
  btrfs: Document a mutex lock/unlock sequence (FATE#306586).
- patches.suse/btrfs-don-t-always-do-readahead.patch: Btrfs:
  don't always do readahead (FATE#306586).
- patches.suse/btrfs-don-t-commit-the-transaction-if-we-dont-have-e.patch:
  Btrfs: don't commit the transaction if we dont have enough
  pinned bytes (FATE#306586).
- patches.suse/btrfs-don-t-force-chunk-allocation-in-find_free_exte.patch:
  Refresh.
- patches.suse/btrfs-don-t-look-at-the-extent-buffer-level-3-times-.patch:
  Btrfs: don't look at the extent buffer level 3 times in a row
  (FATE#306586).
- patches.suse/btrfs-don-t-map-extent-buffer-if-path-skip_locking-i.patch:
  Btrfs: don't map extent buffer if path->skip_locking is set
  (FATE#306586).
- patches.suse/btrfs-don-t-save-the-inode-cache-if-we-are-deleting-.patch:
  Btrfs: don't save the inode cache if we are deleting this root
  (FATE#306586).
- patches.suse/btrfs-don-t-save-the-inode-cache-in-non-fs-roots.patch:
  Btrfs: don't save the inode cache in non-FS roots (FATE#306586).
- patches.suse/btrfs-don-t-try-to-allocate-from-a-block-group-that-.patch:
  Btrfs: don't try to allocate from a block group that doesn't
  have enough space (FATE#306586).
- patches.suse/btrfs-drop-gfp-parameter-from-alloc_extent_buffer.patch:
  btrfs: drop gfp parameter from alloc_extent_buffer
  (FATE#306586).
- patches.suse/btrfs-drop-gfp-parameter-from-alloc_extent_map.patch:
  btrfs: drop gfp parameter from alloc_extent_map (FATE#306586).
- patches.suse/btrfs-drop-gfp-parameter-from-find_extent_buffer.patch:
  btrfs: drop gfp parameter from find_extent_buffer (FATE#306586).
- patches.suse/btrfs-drop-unnecessary-device-lock.patch: Btrfs:
  drop unnecessary device lock (FATE#306586).
- patches.suse/btrfs-drop-unused-argument-from-extent_io_tree_init.patch:
  btrfs: drop unused argument from extent_io_tree_init
  (FATE#306586).
- patches.suse/btrfs-drop-unused-parameter-from-btrfs_release_path.patch:
  btrfs: drop unused parameter from btrfs_release_path
  (FATE#306586).
- patches.suse/btrfs-drop-unused-parameter-from-extent_map_tree_ini.patch:
  btrfs: drop unused parameter from extent_map_tree_init
  (FATE#306586).
- patches.suse/btrfs-ensure-the-tree-search-ioctl-returns-the-right.patch:
  btrfs: Ensure the tree search ioctl returns the right number
  of records (FATE#306586).
- patches.suse/btrfs-false-bug_on-when-degraded.patch: btrfs:
  false BUG_ON when degraded (FATE#306586).
- patches.suse/btrfs-fix-FS_IOC_GETFLAGS-ioctl.patch: Refresh.
- patches.suse/btrfs-fix-FS_IOC_SETFLAGS-ioctl.patch: Refresh.
- patches.suse/btrfs-fix-__btrfs_map_block-on-32-bit-machines.patch:
  Refresh.
- patches.suse/btrfs-fix-bh-leak-on-__btrfs_open_devices-path.patch:
  Btrfs: fix bh leak on __btrfs_open_devices path (FATE#306586).
- patches.suse/btrfs-fix-bitmap-regression.patch: Btrfs: fix
  bitmap regression (FATE#306586).
- patches.suse/btrfs-fix-dereference-before-check.patch: btrfs:
  fix dereference before check (FATE#306586).
- patches.suse/btrfs-fix-dereference-of-err_ptr-value.patch:
  btrfs: fix dereference of ERR_PTR value (FATE#306586).
- patches.suse/btrfs-fix-duplicate-checking-logic.patch: Btrfs:
  fix duplicate checking logic (FATE#306586).
- patches.suse/btrfs-fix-easily-get-into-enospc-in-mixed-case.patch:
  Refresh.
- patches.suse/btrfs-fix-extent-state-leak-on-failed-nodatasum-read.patch:
  Btrfs: fix extent state leak on failed nodatasum reads
  (FATE#306586).
- patches.suse/btrfs-fix-how-we-do-space-reservation-for-truncate.patch:
  Btrfs: fix how we do space reservation for truncate
  (FATE#306586).
- patches.suse/btrfs-fix-memory-leak-at-umount.patch: Refresh.
- patches.suse/btrfs-fix-memory-leak-in-btrfs_init_new_device.patch:
  Refresh.
- patches.suse/btrfs-fix-memory-leak-of-empty-filesystem-after-bala.patch:
  Refresh.
- patches.suse/btrfs-fix-oops-of-empty-filesystem-after-balance.patch:
  Refresh.
- patches.suse/btrfs-fix-path-leakage-on-subvol-deletion.patch:
  Btrfs: fix path leakage on subvol deletion (FATE#306586).
- patches.suse/btrfs-fix-raid-code-for-removing-missing-drives.patch:
  Refresh.
- patches.suse/btrfs-fix-relocation-races.patch: Btrfs: fix
  relocation races (FATE#306586).
- patches.suse/btrfs-fix-return-value-check-of-btrfs_join_transacti.patch:
  Refresh.
- patches.suse/btrfs-fix-the-allocator-loop-logic.patch: Btrfs:
  fix the allocator loop logic (FATE#306586).
- patches.suse/btrfs-fix-the-race-between-reading-and-updating-devi.patch:
  Btrfs: fix the race between reading and updating devices
  (FATE#306586).
- patches.suse/btrfs-fix-the-race-between-remove-dev-and-alloc-chun.patch:
  Btrfs: fix the race between remove dev and alloc chunk
  (FATE#306586).
- patches.suse/btrfs-fix-uncheck-memory-allocations.patch:
  Refresh.
- patches.suse/btrfs-fix-uninit-variable-in-the-delayed-inode-code.patch:
  Btrfs: fix uninit variable in the delayed inode code
  (FATE#306586).
- patches.suse/btrfs-fix-uninitialized-return-value.patch: btrfs:
  fix uninitialized return value (FATE#306586).
- patches.suse/btrfs-fix-uninitialized-variable-warning.patch:
  btrfs: fix uninitialized variable warning (FATE#306586).
- patches.suse/btrfs-fix-unlocked-access-of-delalloc_inodes.patch:
  btrfs: fix unlocked access of delalloc_inodes (FATE#306586).
- patches.suse/btrfs-fix-unsafe-usage-of-merge_state.patch:
  Btrfs: fix unsafe usage of merge_state (FATE#306586).
- patches.suse/btrfs-fix-wrong-calculation-of-stripe-size.patch:
  Refresh.
- patches.suse/btrfs-fix-wrong-free-space-information-of-btrfs.patch:
  Refresh.
- patches.suse/btrfs-fix-wrong-reservation-when-doing-delayed-inode.patch:
  btrfs: fix wrong reservation when doing delayed inode operations
  (FATE#306586).
- patches.suse/btrfs-forced-readonly-mounts-on-errors.patch:
  Refresh.
- patches.suse/btrfs-handle-errors-in-btrfs_orphan_cleanup.patch:
  Refresh.
- patches.suse/btrfs-heed-alloc_start.patch: btrfs: heed
  alloc_start (FATE#306586).
- patches.suse/btrfs-if-we-ve-already-started-a-trans-handle-use-th.patch:
  Btrfs: if we've already started a trans handle, use that one
  (FATE#306586).
- patches.suse/btrfs-implement-delayed-inode-items-operation.patch:
  btrfs: implement delayed inode items operation (FATE#306586).
- patches.suse/btrfs-kill-btrfs_i-inode-block_group.patch: Btrfs:
  kill BTRFS_I(inode)->block_group (FATE#306586).
- patches.suse/btrfs-kill-trans_mutex.patch: Btrfs: kill
  trans_mutex (FATE#306586).
- patches.suse/btrfs-leave-spinning-on-lookup-and-map-the-leaf.patch:
  Btrfs: leave spinning on lookup and map the leaf (FATE#306586).
- patches.suse/btrfs-make-btrfs_map_block-return-entire-free-extent.patch:
  Refresh.
- patches.suse/btrfs-make-btrfs_rm_device-fail-gracefully.patch:
  Refresh.
- patches.suse/btrfs-make-free-space-cache-code-generic.patch:
  Btrfs: Make free space cache code generic (FATE#306586).
- patches.suse/btrfs-make-functions-static-when-possible.patch:
  btrfs: make functions static when possible (FATE#306586).
- patches.suse/btrfs-make-sure-to-recheck-for-bitmaps-in-clusters.patch:
  Btrfs: make sure to recheck for bitmaps in clusters
  (FATE#306586).
- patches.suse/btrfs-make-sure-to-use-the-delalloc-reserve-when-fil.patch:
  Btrfs: make sure to use the delalloc reserve when filling
  delalloc (FATE#306586).
- patches.suse/btrfs-make-sure-we-don-t-overflow-the-free-space-cac.patch:
  Btrfs: make sure we don't overflow the free space cache crc page
  (FATE#306586).
- patches.suse/btrfs-make-the-chunk-allocator-utilize-the-devices-b.patch:
  Refresh.
- patches.suse/btrfs-make-the-code-for-reading-writing-free-space-c.patch:
  Btrfs: Make the code for reading/writing free space cache
  generic (FATE#306586).
- patches.suse/btrfs-map-the-node-block-when-looking-for-readahead-.patch:
  Btrfs: map the node block when looking for readahead targets
  (FATE#306586).
- patches.suse/btrfs-mount-failure-return-value-fix.patch:
  Refresh.
- patches.suse/btrfs-move-btrfs_cmp_device_free_bytes-to-super.c.patch:
  btrfs: move btrfs_cmp_device_free_bytes to super.c
  (FATE#306586).
- patches.suse/btrfs-new-ioctls-for-scrub.patch: btrfs: new
  ioctls for scrub (FATE#306586).
- patches.suse/btrfs-noinline-the-cluster-searching-functions.patch:
  Btrfs: noinline the cluster searching functions (FATE#306586).
- patches.suse/btrfs-per-file-directory-controls-for-cow-and-compre.patch:
  Refresh.
- patches.suse/btrfs-prevent-oopsing-in-posix_acl_valid.patch:
  Refresh.
- patches.suse/btrfs-protect-the-pending_snapshots-list-with-trans_.patch:
  Btrfs: protect the pending_snapshots list with trans_lock
  (FATE#306586).
- patches.suse/btrfs-quasi-round-robin-for-chunk-allocation.patch:
  btrfs: quasi-round-robin for chunk allocation (FATE#306586).
- patches.suse/btrfs-reinitialize-scrub-workers.patch: btrfs:
  reinitialize scrub workers (FATE#306586).
- patches.suse/btrfs-remove-64bit-alignment-padding-to-allow-extent.patch:
  btrfs: remove 64bit alignment padding to allow extent_buffer
  to fit into one fewer cacheline (FATE#306586).
- patches.suse/btrfs-remove-BLKDEV_IFL_WAIT.patch: Refresh.
- patches.suse/btrfs-remove-all-unused-functions.patch: btrfs:
  remove all unused functions (FATE#306586).
- patches.suse/btrfs-remove-nested-duplicate-variable-declarations.patch:
  btrfs: remove nested duplicate variable declarations
  (FATE#306586).
- patches.suse/btrfs-remove-old-unused-commented-out-code.patch:
  btrfs: remove old unused commented out code (FATE#306586).
- patches.suse/btrfs-remove-unneeded-includes-from-scrub.c.patch:
  btrfs: remove unneeded includes from scrub.c (FATE#306586).
- patches.suse/btrfs-remove-unused-btrfs_block_group_free_space.patch:
  Btrfs: Remove unused btrfs_block_group_free_space()
  (FATE#306586).
- patches.suse/btrfs-remove-unused-function-prototypes.patch:
  btrfs: remove unused function prototypes (FATE#306586).
- patches.suse/btrfs-remove-unused-node_lock.patch: BTRFS:
  Remove unused node_lock (FATE#306586).
- patches.suse/btrfs-remove-unused-sysfs-code.patch: btrfs:
  Remove unused sysfs code (FATE#306586).
- patches.suse/btrfs-rename-variables-clashing-with-global-function.patch:
  btrfs: rename variables clashing with global function names
  (FATE#306586).
- patches.suse/btrfs-replace-barriers-with-explicit-flush-FUA-us.patch:
  Refresh.
- patches.suse/btrfs-restructure-find_free_dev_extent.patch:
  Refresh.
- patches.suse/btrfs-return-enomem-in-clear_extent_bit.patch:
  Btrfs: return -ENOMEM in clear_extent_bit (FATE#306586).
- patches.suse/btrfs-return-error-code-to-caller-when-btrfs_del_ite.patch:
  Btrfs: return error code to caller when btrfs_del_item fails
  (FATE#306586).
- patches.suse/btrfs-return-error-code-to-caller-when-btrfs_previou.patch:
  Btrfs: return error code to caller when btrfs_previous_item
  fails (FATE#306586).
- patches.suse/btrfs-return-error-to-caller-if-read_one_inode-fails.patch:
  Btrfs: return error to caller if read_one_inode() fails
  (FATE#306586).
- patches.suse/btrfs-sanitize-linux-prefetch.h-usage.patch:
  sanitize <linux/prefetch.h> usage (FATE#306586).
- patches.suse/btrfs-scrub-don-t-coalesce-pages-that-are-logically-.patch:
  btrfs scrub: don't coalesce pages that are logically
  discontiguous (FATE#306586).
- patches.suse/btrfs-scrub-don-t-reuse-bios-and-pages.patch:
  btrfs: scrub: don't reuse bios and pages (FATE#306586).
- patches.suse/btrfs-scrub-errors-in-tree-enumeration.patch:
  btrfs: scrub: errors in tree enumeration (FATE#306586).
- patches.suse/btrfs-scrub-make-fixups-sync.patch: btrfs scrub:
  make fixups sync (FATE#306586).
- patches.suse/btrfs-scrub.patch: btrfs: scrub (FATE#306586).
- patches.suse/btrfs-set-fmode_excl-in-btrfs_device-mode.patch:
  Refresh.
- patches.suse/btrfs-set-no_trans_join-after-trying-to-expand-the-t.patch:
  Btrfs: set no_trans_join after trying to expand the transaction
  (FATE#306586).
- patches.suse/btrfs-set-range_start-to-the-right-start-in-count_ra.patch:
  Btrfs: set range_start to the right start in count_range_bits
  (FATE#306586).
- patches.suse/btrfs-setup-free-ino-caching-in-a-more-asynchronous-.patch:
  Btrfs: setup free ino caching in a more asynchronous way
  (FATE#306586).
- patches.suse/btrfs-support-reading-writing-on-disk-free-ino-cache.patch:
  Btrfs: Support reading/writing on disk free ino cache
  (FATE#306586).
- patches.suse/btrfs-take-away-the-num_items-argument-from-btrfs_jo.patch:
  Btrfs: take away the num_items argument from
  btrfs_join_transaction (FATE#306586).
- patches.suse/btrfs-try-not-to-sleep-as-much-when-doing-slow-cachi.patch:
  Btrfs: try not to sleep as much when doing slow caching
  (FATE#306586).
- patches.suse/btrfs-typo-btrfs-btrfs.patch: btrfs: typo:
  'btrfS' -> 'btrfs' (FATE#306586).
- patches.suse/btrfs-unify-checking-of-is_err-and-null.patch:
  btrfs: unify checking of IS_ERR and null (FATE#306586).
- patches.suse/btrfs-unify-flags-for-struct-bio-and-struct-request.patch:
  Refresh.
- patches.suse/btrfs-unlock-the-trans-lock-properly.patch: Btrfs:
  unlock the trans lock properly (FATE#306586).
- patches.suse/btrfs-update-the-delayed-inode-code-to-use-the-btrfs.patch:
  Btrfs: update the delayed inode code to use the btrfs_ino helper
  (FATE#306586).
- patches.suse/btrfs-use-bitmap_set-clear.patch: Btrfs: Use
  bitmap_set/clear() (FATE#306586).
- patches.suse/btrfs-use-btrfs_ino-to-access-inode-number.patch:
  btrfs: use btrfs_ino to access inode number (FATE#306586).
- patches.suse/btrfs-use-join_transaction-in-btrfs_evict_inode.patch:
  Btrfs: use join_transaction in btrfs_evict_inode()
  (FATE#306586).
- patches.suse/btrfs-use-printk_ratelimited-instead-of-printk_ratel.patch:
  btrfs: use printk_ratelimited instead of printk_ratelimit
  (FATE#306586).
- patches.suse/btrfs-use-the-device_list_mutex-during-write_dev_sup.patch:
  Btrfs: use the device_list_mutex during write_dev_supers
  (FATE#306586).
- patches.suse/btrfs-use-unsigned-type-for-single-bit-bitfield.patch:
  btrfs: use unsigned type for single bit bitfield (FATE#306586).
- patches.suse/btrfs-using-rcu-lock-in-the-reader-side-of-devices-l.patch:
  Btrfs: using rcu lock in the reader side of devices list
  (FATE#306586).
- patches.suse/btrfs-write-out-free-space-cache.patch: Refresh.
- patches.suse/direct-io-add-a-hook-for-the-fs-to-provide-its-own-s.patch:
  Refresh.
- patches.suse/fs-add-fitrim-ioctl.patch: Refresh.
- patches.suse/fs-remove-FS_COW_FL.patch: Refresh.
- patches.xen/tmem: Refresh.
* Thu Jun 23 2011 jack@suse.cz
- patches.fixes/ocfs2-readpage-livelock.patch: ocfs2: Avoid
  livelock in ocfs2_readpage() (bnc#682076).
* Thu Jun 23 2011 jeffm@suse.com
- patches.drivers/0001-bnx2-Refine-statistics-code.patch: bnx2:
  Refine statistics code (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0002-bnx2-Save-statistics-during-reset.patch:
  bnx2: Save statistics during reset (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0003-bnx2-Check-BNX2_FLAG_USING_MSIX-flag-when-setting-up.patch:
  bnx2: Check BNX2_FLAG_USING_MSIX flag when setting up MSIX
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0004-bnx2-Allow-user-specified-multiple-advertisement-spe.patch:
  bnx2: Allow user-specified multiple advertisement speed values
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0005-bnx2-Fix-bug-when-saving-statistics.patch:
  bnx2: Fix bug when saving statistics (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0008-drivers-net-bnx2.c-Use-pr-netdev-netif-_-level-macro.patch:
  drivers/net/bnx2.c: Use (pr|netdev|netif)_<level> macro helpers
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0009-cnic-Revert-cnic-Give-a-chance-for-the-uio-device-to.patch:
  cnic: Revert "cnic: Give a chance for the uio device to be
  opened" (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0010-drivers-net-cnic.c-Use-pr-netdev-_-level-macro-helpe.patch:
  drivers/net/cnic.c: Use (pr|netdev)_<level> macro helpers
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0011-cnic-Simplify-route-checking-during-iSCSI-connection.patch:
  cnic: Simplify route checking during iSCSI connection
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0012-bnx2-Prevent-scheduling-while-atomic-warning-with-cn.patch:
  bnx2: Prevent "scheduling while atomic" warning with cnic,
  bonding and vlan (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0013-bnx2-Update-version-to-2.0.9.patch: bnx2:
  Update version to 2.0.9 (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0014-bnx2-Add-GRO-support.patch: bnx2: Add
  GRO support (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0015-bnx2-Add-prefetches-to-rx-path.patch:
  bnx2: Add prefetches to rx path (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0016-drivers-net-Remove-unnecessary-returns-from-void-fun.patch:
  drivers/net: Remove unnecessary returns from void function()s
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0017-bnx2x-use-smp_mb-to-keep-ordering-of-read-write-oper.patch:
  bnx2x: use smp_mb() to keep ordering of read write operations
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0018-bnx2x-remove-not-necessary-compiler-barrier.patch:
  bnx2x: remove not necessary compiler barrier (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0019-bnx2x-change-smp_mb-comment-to-conform-the-true.patch:
  bnx2x: change smp_mb() comment to conform the true (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0020-bnx2x-Added-GRO-support.patch: bnx2x: Added
  GRO support (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0021-bnx2x-Parity-errors-handling-for-57710-and-57711.patch:
  bnx2x: Parity errors handling for 57710 and 57711 (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0022-bnx2x-Increase-DMAE-max-write-size-for-57711.patch:
  bnx2x: Increase DMAE max write size for 57711 (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0023-bnx2x-Protect-code-with-NOMCP.patch: bnx2x:
  Protect code with NOMCP (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0024-bnx2x-White-spaces.patch: bnx2x: White
  spaces (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0025-bnx2x-Added-new-statistics.patch: bnx2x:
  Added new statistics (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0026-bnx2x-Fixed-MSI-X-enabling-flow.patch:
  bnx2x: Fixed MSI-X enabling flow (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0027-bnx2x-use-mask-in-test_registers-to-avoid-parity-err.patch:
  bnx2x: use mask in test_registers() to avoid parity error
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0028-bnx2x-Rework-power-state-handling-code.patch:
  bnx2x: Rework power state handling code (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0029-bnx2x-Don-t-report-link-down-if-has-been-already-dow.patch:
  bnx2x: Don't report link down if has been already down
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0030-bnx2x-Date-and-version.patch: bnx2x: Date
  and version (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0031-bnx2x-Remove-two-prefetch.patch: bnx2x:
  Remove two prefetch() (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0032-bnx2-Fix-register-printouts-during-NETEV_WATCHDOG.patch:
  bnx2: Fix register printouts during NETEV_WATCHDOG (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0033-bnx2-Update-5709-MIPS-firmware-and-version-to-2.0.15.patch:
  bnx2: Update 5709 MIPS firmware and version to 2.0.15
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0034-bnx2-Use-netif_carrier_off-to-prevent-timeout.patch:
  bnx2: Use netif_carrier_off() to prevent timeout (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0035-bnx2x-avoid-TX-timeout-when-stopping-device.patch:
  bnx2x: avoid TX timeout when stopping device (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0036-bnx2-Fix-compiler-warning-in-bnx2_disable_forced_2g5.patch:
  bnx2: Fix compiler warning in bnx2_disable_forced_2g5()
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0037-bnx2x-Fix-link-problem-with-some-DACs.patch:
  bnx2x: Fix link problem with some DACs (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0038-cnic-Return-error-code-in-cnic_cm_close-if-unsuccess.patch:
  cnic: Return error code in cnic_cm_close() if unsuccessful
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0039-cnic-Refactor-code-in-cnic_cm_process_kcqe.patch:
  cnic: Refactor code in cnic_cm_process_kcqe() (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0040-cnic-Refactor-and-fix-cnic_ready_to_close.patch:
  cnic: Refactor and fix cnic_ready_to_close() (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0041-cnic-Fix-cnic_cm_abort-error-handling.patch:
  cnic: Fix cnic_cm_abort() error handling (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0042-bnx2-fix-dma_get_ops-compilation-breakage.patch:
  bnx2: fix dma_get_ops compilation breakage (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0043-cnic-Fine-tune-CID-memory-space-calculation.patch:
  cnic: Fine-tune CID memory space calculation (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0044-cnic-Unify-IRQ-code-for-all-hardware-types.patch:
  cnic: Unify IRQ code for all hardware types (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0045-cnic-Unify-kcq-allocation-for-all-devices.patch:
  cnic: Unify kcq allocation for all devices (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0046-cnic-Restructure-kcq-processing.patch:
  cnic: Restructure kcq processing (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0047-cnic-Further-unify-kcq-handling-code.patch:
  cnic: Further unify kcq handling code (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0048-cnic-Update-version-to-2.1.3.patch: cnic:
  Update version to 2.1.3 (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0049-bnx2x-fail-when-try-to-setup-unsupported-features.patch:
  bnx2x: fail when try to setup unsupported features (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0050-bnx2-Always-enable-MSI-X-on-5709.patch:
  bnx2: Always enable MSI-X on 5709 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0051-bnx2-Dump-some-config-space-registers-during-TX-time.patch:
  bnx2: Dump some config space registers during TX timeout
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0052-bnx2-Update-version-to-2.0.16.patch: bnx2:
  Update version to 2.0.16 (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0053-bnx2-allocate-with-GFP_KERNEL-flag-on-RX-path-init.patch:
  bnx2: allocate with GFP_KERNEL flag on RX path init (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0054-bnx2-use-device-model-DMA-API.patch: bnx2:
  use device model DMA API (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0055-bnx2-Use-proper-counter-for-net_device_stats-multica.patch:
  bnx2: Use proper counter for net_device_stats->multicast
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0056-bnx2-Call-pci_enable_msix-with-actual-number-of-vect.patch:
  bnx2: Call pci_enable_msix() with actual number of vectors
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0057-bnx2-Remove-some-unnecessary-smp_mb-in-tx-fast-path.patch:
  bnx2: Remove some unnecessary smp_mb() in tx fast path
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0058-bnx2-Update-version-to-2.0.17.patch: bnx2:
  Update version to 2.0.17 (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0066-bnx2x-Protect-a-SM-state-change.patch:
  bnx2x: Protect a SM state change (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0067-bnx2x-Protect-statistics-ramrod-and-sequence-number.patch:
  bnx2x: Protect statistics ramrod and sequence number
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0068-bnx2x-Advance-a-module-version.patch:
  bnx2x: Advance a module version (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0069-bnx2x-Create-separate-folder-for-bnx2x-driver.patch:
  bnx2x: Create separate folder for bnx2x driver (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0070-bnx2x-store-module-parameters-in-driver-main-structu.patch:
  bnx2x: store module parameters in driver main structure
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0071-bnx2x-move-global-variable-load_count-to-bnx2x.h.patch:
  bnx2x: move global variable load_count to bnx2x.h (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0072-bnx2x-Create-bnx2x_cmn.-files.patch: bnx2x:
  Create bnx2x_cmn.* files (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0073-bnx2x-Create-separate-file-for-ethtool-routines.patch:
  bnx2x: Create separate file for ethtool routines (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0074-bnx2x-Move-statistics-handling-code-to-bnx2x_stats.patch:
  bnx2x: Move statistics handling code to bnx2x_stats.*
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0075-bnx2x-update-driver-version-to-1.52.53-3.patch:
  bnx2x: update driver version to 1.52.53-3 (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0076-bnx2x-Update-MAINTAINERS-according-to-new-location.patch:
  bnx2x: Update MAINTAINERS according to new location (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0077-net-bnx2x_cmn.c-needs-net-ip6_checksum.h-for-csum_ip.patch:
  net: bnx2x_cmn.c needs net/ip6_checksum.h for csum_ipv6_magic
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0078-scsi-fix-bnx2i-build-errors.patch: scsi:
  fix bnx2i build errors (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0079-bnx2x-Load-firmware-in-open-instead-of-probe.patch:
  bnx2x: Load firmware in open() instead of probe() (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0080-drivers-net-bnx2x-Adjust-confusing-if-indentation.patch:
  drivers/net/bnx2x: Adjust confusing if indentation (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0081-drivers-net-Convert-unbounded-kzalloc-calls-to-kcall.patch:
  drivers/net: Convert unbounded kzalloc calls to kcalloc
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0082-bnx2x-Fix-PHY-locking-problem.patch: bnx2x:
  Fix PHY locking problem (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0083-bnx2x-Update-bnx2x-version-to-1.52.53-4.patch:
  bnx2x: Update bnx2x version to 1.52.53-4 (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0084-bnx2-Add-PCI-Advanced-Error-Reporting-support.patch:
  bnx2: Add PCI Advanced Error Reporting support (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0085-bnx2x-small-fix-in-stats-handling.patch:
  bnx2x: small fix in stats handling (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0086-bnx2x-fix-wrong-return-from-bnx2x_trylock_hw_lock.patch:
  bnx2x: fix wrong return from bnx2x_trylock_hw_lock (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0087-bnx2x-Fix-potential-link-issue-of-BCM8073-BCM8727.patch:
  bnx2x: Fix potential link issue of BCM8073/BCM8727 (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0088-bnx2x-Fix-potential-link-issue-In-BCM8727-based-boar.patch:
  bnx2x: Fix potential link issue In BCM8727 based boards
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0089-bnx2x-Reset-link-before-any-new-link-settings.patch:
  bnx2x: Reset link before any new link settings (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0090-bnx2x-Change-BCM848xx-configuration-according-to-IEE.patch:
  bnx2x: Change BCM848xx configuration according to IEEE
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0091-bnx2x-Remove-unneeded-setting-of-XAUI-low-power-to-B.patch:
  bnx2x: Remove unneeded setting of XAUI low power to BCM8727
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0092-bnx2x-Change-BCM848xx-LED-configuration.patch:
  bnx2x: Change BCM848xx LED configuration (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0093-bnx2x-Add-BCM84823-to-the-supported-PHYs.patch:
  bnx2x: Add BCM84823 to the supported PHYs (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0094-bnx2x-Update-version-to-1.52.53-5.patch:
  bnx2x: Update version to 1.52.53-5 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0095-bnx2i-Fixed-a-protocol-violation-on-nopout-responses.patch:
  bnx2i: Fixed a protocol violation on nopout responses
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0096-bxn2i-Added-support-for-other-TMFs-besides-ABORT_TAS.patch:
  bxn2i: Added support for other TMFs besides ABORT_TASK
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0097-bnx2i-Recouple-the-CFC-delete-cleanup-with-cm_abort-.patch:
  bnx2i: Recouple the CFC delete cleanup with cm_abort/close
  completion (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0098-bnx2i-Added-chip-cleanup-for-the-remove-module-path.patch:
  bnx2i: Added chip cleanup for the remove module path
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0099-bnx2i-Updated-version-to-bnx2i-2.1.3.patch:
  bnx2i: Updated version to bnx2i-2.1.3 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0100-bnx2x-Unify-PHY-attributes.patch: bnx2x:
  Unify PHY attributes (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0101-bnx2x-Split-PHY-functions.patch: bnx2x:
  Split PHY functions (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0102-bnx2x-Adjust-alignment-of-split-PHY-functions.patch:
  bnx2x: Adjust alignment of split PHY functions (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0103-bnx2x-Adjust-flow-control-with-the-new-scheme.patch:
  bnx2x: Adjust flow-control with the new scheme (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0104-bnx2x-Move-common-function-into-aggregated-function.patch:
  bnx2x: Move common function into aggregated function
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0105-bnx2x-Apply-logic-changes-for-the-new-scheme.patch:
  bnx2x: Apply logic changes for the new scheme (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0106-bnx2x-Organize-PHY-functions.patch: bnx2x:
  Organize PHY functions (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0107-bnx2x-Add-dual-media-changes.patch: bnx2x:
  Add dual-media changes (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0108-bnx2x-Change-LED-scheme-for-dual-media.patch:
  bnx2x: Change LED scheme for dual-media (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0109-bnx2x-Update-bnx2x-version-to-1.52.53-6.patch:
  bnx2x: Update bnx2x version to 1.52.53-6 (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0110-drivers-net-bnx2x-use-ARRAY_SIZE-macro-in-bnx2x_main.patch:
  drivers/net/bnx2x: use ARRAY_SIZE macro in bnx2x_main.c
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0111-bnx2x-Spread-rx-buffers-between-allocated-queues.patch:
  bnx2x: Spread rx buffers between allocated queues (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0112-drivers-net-return-operator-cleanup.patch:
  drivers/net: return operator cleanup (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0113-bnx2-Use-netif_set_real_num_-rx-tx-_queues.patch:
  bnx2: Use netif_set_real_num_{rx,tx}_queues() (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0114-bnx2x-Use-netif_set_real_num_-rx-tx-_queues.patch:
  bnx2x: Use netif_set_real_num_{rx,tx}_queues() (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0115-bnx2x-Moved-enabling-of-MSI-to-the-bnx2x_set_num_que.patch:
  bnx2x: Moved enabling of MSI to the bnx2x_set_num_queues()
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0116-cnic-Pass-cp-pointer-to-BNX2X_HW_CID.patch:
  cnic: Pass cp pointer to BNX2X_HW_CID (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0117-cnic-Use-pfid-for-internal-memory-offsets.patch:
  cnic: Use pfid for internal memory offsets (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0118-cnic-Fine-tune-ring-init-code.patch: cnic:
  Fine-tune ring init code (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0119-bnx2x-create-folder-for-bnx2x-firmware-files.patch:
  bnx2x: create folder for bnx2x firmware files (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0120-bnx2x-add-6.0.34-fw-files.patch: bnx2x:
  add 6.0.34 fw files (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0121-bnx2x-cnic-bnx2i-use-new-FW-HSI.patch:
  bnx2x, cnic, bnx2i: use new FW/HSI (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0122-bnx2x-remove-old-FW-files.patch: bnx2x:
  remove old FW files (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0123-bnx2x-rename-MF-related-fields.patch:
  bnx2x: rename MF related fields (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0124-bnx2x-change-type-of-spq_left-to-atomic.patch:
  bnx2x: change type of spq_left to atomic (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0125-bnx2x-Add-57712-support.patch: bnx2x: Add
  57712 support (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0126-bnx2x-remove-unused-parameter-in-reuse_rx_skb.patch:
  bnx2x: remove unused parameter in reuse_rx_skb() (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0127-bnx2x-remove-unused-fields-in-main-driver-structure.patch:
  bnx2x: remove unused fields in main driver structure
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0128-bnx2x-use-proper-constants-for-dma_unmap-calls.patch:
  bnx2x: use proper constants for dma_unmap* calls (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0129-bnx2x-use-L1_CACHE_BYTES-instead-of-magic-number.patch:
  bnx2x: use L1_CACHE_BYTES instead of magic number (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0130-bnx2x-move-msix-table-initialization-to-probe.patch:
  bnx2x: move msix table initialization to probe() (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0131-bnx2x-cnic-Fix-SPQ-return-credit.patch:
  bnx2x, cnic: Fix SPQ return credit (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0132-bnx2x-code-beautify.patch: bnx2x: code
  beautify (FATE#311458 FATE#311459 FATE#311460 FATE#311461
  FATE#311462 bnc#698050).
- patches.drivers/0133-bnx2x-properly-initialize-FW-stats.patch:
  bnx2x: properly initialize FW stats (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0134-bnx2x-update-version-to-1.60.00-1.patch:
  bnx2x: update version to 1.60.00-1 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0135-bnx2-Update-firmware-to-6.0.x.patch: bnx2:
  Update firmware to 6.0.x (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0136-bnx2-Enable-AER-on-PCIE-devices-only.patch:
  bnx2: Enable AER on PCIE devices only (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0137-bnx2x-Fixing-a-typo-added-a-missing-RSS-enablement.patch:
  bnx2x: Fixing a typo: added a missing RSS enablement
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0138-cnic-Add-common-cnic_request_irq.patch:
  cnic: Add common cnic_request_irq() (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0139-cnic-Convert-ctx_flags-to-bit-fields.patch:
  cnic: Convert ctx_flags to bit fields (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0140-cnic-Add-cnic_bnx2x_destroy_ramrod.patch:
  cnic: Add cnic_bnx2x_destroy_ramrod() (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0141-cnic-Defer-iscsi-connection-cleanup.patch:
  cnic: Defer iscsi connection cleanup (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0142-cnic-Add-cnic_free_uio.patch: cnic:
  Add cnic_free_uio() (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0143-cnic-Add-cnic_uio_dev-struct.patch: cnic:
  Add cnic_uio_dev struct (FATE#311458 FATE#311459 FATE#311460
  FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0144-cnic-Decouple-uio-close-from-cnic-shutdown.patch:
  cnic: Decouple uio close from cnic shutdown (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0145-cnic-Add-support-for-57712-device.patch:
  cnic: Add support for 57712 device (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0146-bnx2x-Optimized-the-branching-in-the-bnx2x_rx_int.patch:
  bnx2x: Optimized the branching in the bnx2x_rx_int()
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0147-bnx2x-remove-redundant-commands-during-error-handlin.patch:
  bnx2x: remove redundant commands during error handling
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0148-bnx2x-do-not-deal-with-power-if-no-capability.patch:
  bnx2x: do not deal with power if no capability (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0149-bnx2x-Use-correct-FW-constant-for-header-padding.patch:
  bnx2x: Use correct FW constant for header padding (FATE#311458
  FATE#311459 FATE#311460 FATE#311461 FATE#311462 bnc#698050).
- patches.drivers/0150-bnx2x-remove-unnecessary-FUNC_FLG_RSS-flag-and-relat.patch:
  bnx2x: remove unnecessary FUNC_FLG_RSS flag and related
  (FATE#311458 FATE#311459 FATE#311460 FATE#311461 FATE#311462
  bnc#698050).
- patches.drivers/0151-bnx2x-update-version-to-1.60.00-2.patch:
  bnx2x: update version to 1.60.00-2 (FATE#311458 FATE#311459
  FATE#311460 FATE#311461 FATE#311462 bnc#698050).
* Thu Jun 23 2011 jeffm@suse.com
- patches.drivers/0000-be2net-remove-use-of-skb_dma_map-unmap.patch:
  be2net: remove use of skb_dma_map/unmap (FATE#311448,
  bnc#697255).
- patches.drivers/0001-be2net-implement-pci-shutdown-handler.patch:
  be2net: implement pci shutdown handler (FATE#311448,
  bnc#697255).
- patches.drivers/0002-be2net-free-tx-buffers-when-completions-never-arriv.patch:
  be2net: free tx buffers when completions never arrive
  (FATE#311448, bnc#697255).
- patches.drivers/0003-be2net-update-copyright-dates.patch:
  be2net: update copyright dates (FATE#311448, bnc#697255).
- patches.drivers/0004-be2net-remove-usage-of-be_pci_func.patch:
  be2net: remove usage of be_pci_func (FATE#311448, bnc#697255).
- patches.drivers/0005-be2net-remove-unused-code-in-be_load_fw.patch:
  be2net: remove unused code in be_load_fw (FATE#311448,
  bnc#697255).
- patches.drivers/0006-be2net-handle-dma-mapping-errors-in-Tx-path.patch:
  be2net: handle dma mapping errors in Tx path (FATE#311448,
  bnc#697255).
- patches.drivers/0007-be2net-fix-unmap_single-page-called-incorrectly-i.patch:
  be2net: fix unmap_single/page() called incorrectly in Tx compl
  processing (FATE#311448, bnc#697255).
- patches.drivers/0008-net-various-remove-trailing-space-in-messages.patch:
  net/various: remove trailing space in messages (FATE#311448,
  bnc#697255).
- patches.drivers/0009-benet-Fix-compile-warnnings-in-drivers-net-benet-be.patch:
  benet: Fix compile warnnings in drivers/net/benet/be_ethtool.c
  (FATE#311448, bnc#697255).
- patches.drivers/0010-include-cleanup-Update-gfp.h-and-slab.h-includes-to.patch:
  include cleanup: Update gfp.h and slab.h includes to prepare for
  breaking implicit slab.h inclusion from percpu.h (FATE#311448,
  bnc#697255).
- patches.drivers/0011-net-remove-redundant-code.patch: net:
  remove redundant code (FATE#311448, bnc#697255).
- patches.drivers/0012-be2net-fix-a-bug-in-flashing-the-redboot-section.patch:
  be2net: fix a bug in flashing the redboot section (FATE#311448,
  bnc#697255).
- patches.drivers/0013-be2net-fix-flashing-on-big-endian-architectures.patch:
  be2net: fix flashing on big endian architectures (FATE#311448,
  bnc#697255).
- patches.drivers/0014-be2net-Adding-PCI-SRIOV-support.patch:
  be2net: Adding PCI SRIOV support (FATE#311448, bnc#697255).
- patches.drivers/0015-benet-use-the-dma-state-API-instead-of-the-pci-equi.patch:
  benet: use the dma state API instead of the pci equivalents
  (FATE#311448, bnc#697255).
- patches.drivers/0016-benet-fix-the-misusage-of-zero-dma-address.patch:
  benet: fix the misusage of zero dma address (FATE#311448,
  bnc#697255).
- patches.drivers/0017-be2net-clarify-promiscuous-cmd-with-a-comment.patch:
  be2net: clarify promiscuous cmd with a comment (FATE#311448,
  bnc#697255).
- patches.drivers/0018-drivers-net-use-skb_headlen.patch: drivers:
  net: use skb_headlen() (FATE#311448, bnc#697255).
- patches.drivers/0019-drivers-net-Remove-unnecessary-returns-from-void-fu.patch:
  drivers/net: Remove unnecessary returns from void function()s
  (FATE#311448, bnc#697255).
- patches.drivers/0020-be2net-Bug-fix-in-init-code-in-probe.patch:
  be2net: Bug fix in init code in probe (FATE#311448, bnc#697255).
- patches.drivers/0021-be2net-Bug-fix-to-avoid-disabling-bottom-half-durin.patch:
  be2net: Bug fix to avoid disabling bottom half during firmware
  upgrade (FATE#311448, bnc#697255).
- patches.drivers/0022-be2net-increase-POST-timeout-for-EEH-recovery.patch:
  be2net: increase POST timeout for EEH recovery (FATE#311448,
  bnc#697255).
- patches.drivers/0023-be2net-Patch-removes-redundant-while-statement-in-l.patch:
  be2net: Patch removes redundant while statement in loop
  (FATE#311448, bnc#697255).
- patches.drivers/0024-be2net-add-unlock-on-error-path.patch:
  be2net: add unlock on error path (FATE#311448, bnc#697255).
- patches.drivers/0025-be2net-remove-superfluous-externs.patch:
  be2net: remove superfluous externs (FATE#311448, bnc#697255).
- patches.drivers/0026-be2net-cleanup-in-case-of-error-in-be_open.patch:
  be2net: cleanup in case of error in be_open() (FATE#311448,
  bnc#697255).
- patches.drivers/0027-be2net-replace-udelay-with-schedule_timeout-in.patch:
  be2net: replace udelay() with schedule_timeout() in mbox polling
  (FATE#311448, bnc#697255).
- patches.drivers/0028-be2net-convert-hdr.timeout-in-be_cmd_loopback_test.patch:
  be2net: convert hdr.timeout in be_cmd_loopback_test() to le32
  (FATE#311448, bnc#697255).
- patches.drivers/0029-fix-typos-concerning-management.patch:
  fix typos concerning "management" (FATE#311448, bnc#697255).
- patches.drivers/0030-be2net-enable-ipv6-tso-support.patch:
  be2net: enable ipv6 tso support (FATE#311448, bnc#697255).
- patches.drivers/0031-be2net-memory-barrier-fixes-on-IBM-p7-platform.patch:
  be2net: memory barrier fixes on IBM p7 platform (FATE#311448,
  bnc#697255).
- patches.drivers/0032-be2net-changes-to-properly-provide-phy-details.patch:
  be2net: changes to properly provide phy details (FATE#311448,
  bnc#697255).
- patches.drivers/0033-be2net-Patch-to-determine-if-function-is-VF-while-r.patch:
  be2net: Patch to determine if function is VF while running in
  guest OS (FATE#311448, bnc#697255).
- patches.drivers/0034-be2net-supress-printing-error-when-mac-query-fails.patch:
  be2net: supress printing error when mac query fails for VF
  (FATE#311448, bnc#697255).
- patches.drivers/0035-be2net-variable-name-changes.patch:
  be2net: variable name change (FATE#311448, bnc#697255).
- patches.drivers/0036-be2net-fix-to-correctly-know-if-driver-needs-to-run.patch:
  be2net: fix to correctly know if driver needs to run for a VF
  or a PF (FATE#311448, bnc#697255).
- patches.drivers/0037-be2net-add-code-to-dump-registers-for-debug.patch:
  be2net: add code to dump registers for debug (FATE#311448,
  bnc#697255).
- patches.drivers/0038-be2net-change-to-show-correct-physical-link-status.patch:
  be2net: change to show correct physical link status
  (FATE#311448, bnc#697255).
- patches.drivers/0039-be2net-fix-to-avoid-sending-get_stats-request-if-on.patch:
  be2net: fix to avoid sending get_stats request if one is
  already being processed (FATE#311448, bnc#697255).
- patches.drivers/0040-be2net-get-rid-of-be_get_stats.patch:
  be2net: get rid of be_get_stats() (FATE#311448, bnc#697255).
- patches.drivers/0041-be2net-fix-to-dynamically-generate-MAC-Address-for.patch:
  be2net: fix to dynamically generate MAC Address for VFs
  (FATE#311448, bnc#697255).
- patches.drivers/0042-be2net-stats-for-packets-received-due-to-internal-s.patch:
  be2net: stats for packets received due to internal switching
  in ASIC (FATE#311448, bnc#697255).
- patches.drivers/0043-drivers-net-avoid-some-skb-ip_summed-initializatio.patch:
  drivers/net: avoid some skb->ip_summed initializations
  (FATE#311448, bnc#697255).
- patches.drivers/0044-be2net-fix-net-snmp-error-because-of-wrong-packet-s.patch:
  be2net: fix net-snmp error because of wrong packet stats
  (FATE#311448, bnc#697255).
- patches.drivers/0045-be2net-fix-a-bug-in-UE-detection-logic.patch:
  be2net: fix a bug in UE detection logic (FATE#311448,
  bnc#697255).
- patches.drivers/0046-be2net-remove-a-BUG_ON-in-be_cmds.c.patch:
  be2net: remove a BUG_ON in be_cmds.c (FATE#311448, bnc#697255).
- patches.drivers/0047-drivers-net-return-operator-cleanup.patch:
  drivers/net: return operator cleanup (FATE#311448, bnc#697255).
- patches.drivers/0048-be2net-add-multiple-RX-queue-support.patch:
  be2net: add multiple RX queue support (FATE#311448, bnc#697255).
- patches.drivers/0049-vlan-Don-t-check-for-vlan-group-before-vlan_tx_tag_.patch:
  vlan: Don't check for vlan group before vlan_tx_tag_present
  (FATE#311448, bnc#697255).
- patches.drivers/0050-be2net-Changes-to-use-only-priority-codes-allowed-b.patch:
  be2net: Changes to use only priority codes allowed by f/w
  (FATE#311448, bnc#697255).
- patches.drivers/0051-benet-remove-dead-code.patch: benet:
  remove dead code (FATE#311448, bnc#697255).
- patches.drivers/0052-benet-make-be_poll_rx-local.patch: benet:
  make be_poll_rx local (FATE#311448, bnc#697255).
- patches.drivers/0053-be2net-Call-netif_carier_off-after-register_netde.patch:
  be2net: Call netif_carier_off() after register_netdev()
  (FATE#311448, bnc#697255).
- patches.drivers/0054-be2net-Fix-CSO-for-UDP-packets.patch:
  be2net: Fix CSO for UDP packets (FATE#311448, bnc#697255).
- patches.drivers/0055-be2net-Schedule-Destroy-worker-thread-in-probe-re.patch:
  be2net: Schedule/Destroy worker thread in probe()/remove()
  rather than open()/close() (FATE#311448, bnc#697255).
- patches.drivers/0056-be2net-Fix-to-avoid-firmware-update-when-interface.patch:
  be2net: Fix to avoid firmware update when interface is not open
  (FATE#311448, bnc#697255).
- patches.drivers/0057-be2net-adding-support-for-Lancer-family-of-CNAs.patch:
  be2net: adding support for Lancer family of CNAs (FATE#311448,
  bnc#697255).
- patches.drivers/0058-net-Fix-too-optimistic-NETIF_F_HW_CSUM-features.patch:
  net: Fix too optimistic NETIF_F_HW_CSUM features (FATE#311448,
  bnc#697255).
- patches.drivers/0059-be2net-Fix-be_dev_family_check-return-value-check.patch:
  be2net: Fix be_dev_family_check() return value check
  (FATE#311448, bnc#697255).
- patches.drivers/0060-be2net-FW-init-cmd-fix-for-lancer.patch:
  be2net: FW init cmd fix for lancer (FATE#311448, bnc#697255).
- patches.drivers/0061-be2net-Handle-out-of-buffer-completions-for-lancer.patch:
  be2net: Handle out of buffer completions for lancer
  (FATE#311448, bnc#697255).
- patches.drivers/0063-be2net-use-mutex-instead-of-spin-lock-for-mbox_lock.patch:
  be2net: use mutex instead of spin lock for mbox_lock
  (FATE#311448, bnc#697255).
- patches.drivers/0064-drivers-net-Use-static-const.patch:
  drivers/net/*/: Use static const (FATE#311448, bnc#697255).
- patches.drivers/0065-be2net-fix-a-crash-seen-during-insmod-rmmod-test.patch:
  be2net: fix a crash seen during insmod/rmmod test (FATE#311448,
  bnc#697255).
- patches.drivers/0066-be2net-remove-netif_stop_queue-being-called-before.patch:
  be2net: remove netif_stop_queue being called before
  register_netdev (FATE#311448, bnc#697255).
- patches.drivers/0067-be2net-use-device-model-DMA-API.patch:
  be2net: use device model DMA API (FATE#311448, bnc#697255).
- patches.drivers/0068-benet-Avoid-potential-null-deref-in-be_cmd_get_seep.patch:
  benet: Avoid potential null deref in be_cmd_get_seeprom_data()
  (FATE#311448, bnc#697255).
- patches.drivers/0070-be2net-Use-domain-id-when-be_cmd_if_destroy-is-call.patch:
  be2net: Use domain id when be_cmd_if_destroy is called
  (FATE#311448, bnc#697255).
- patches.drivers/0071-be2net-Initialize-and-cleanup-sriov-resources-only.patch:
  be2net: Initialize and cleanup sriov resources only if
  pci_enable_sriov has succeeded (FATE#311448, bnc#697255).
- patches.drivers/0072-be2net-Cleanup-the-VF-interface-handles.patch:
  be2net: Cleanup the VF interface handles (FATE#311448,
  bnc#697255).
- patches.drivers/0073-be2net-For-the-VF-MAC-use-the-OUI-from-current-MAC.patch:
  be2net: For the VF MAC, use the OUI from current MAC address
  (FATE#311448, bnc#697255).
- patches.drivers/0074-be2net-pass-domain-numbers-for-pmac_add-del-functio.patch:
  be2net: pass domain numbers for pmac_add/del functions
  (FATE#311448, bnc#697255).
- patches.drivers/0075-be2net-Allow-VFs-to-call-be_cmd_reset_function.patch:
  be2net: Allow VFs to call be_cmd_reset_function (FATE#311448,
  bnc#697255).
- patches.drivers/0076-be2net-Fix-broken-priority-setting-when-vlan-taggin.patch:
  be2net: Fix broken priority setting when vlan tagging is enabled
  (FATE#311448, bnc#697255).
- patches.drivers/0077-be2net-pass-proper-hdr_size-while-flashing-redboot.patch:
  be2net: pass proper hdr_size while flashing redboot
  (FATE#311448, bnc#697255).
- patches.drivers/0078-be2net-fix-be_suspend-resume-shutdown.patch:
  be2net: fix be_suspend/resume/shutdown (FATE#311448,
  bnc#697255).
- patches.drivers/0079-be2net-gracefully-handle-situations-when-UE-is-dete.patch:
  be2net: gracefully handle situations when UE is detected
  (FATE#311448, bnc#697255).
- patches.drivers/0080-be2net-detect-a-UE-even-when-a-interface-is-down.patch:
  be2net: detect a UE even when a interface is down (FATE#311448,
  bnc#697255).
- patches.drivers/0081-be2net-restrict-WOL-to-PFs-only.patch:
  be2net: restrict WOL to PFs only (FATE#311448, bnc#697255).
- patches.drivers/0082-be2net-add-new-counters-to-display-via-ethtool-stat.patch:
  be2net: add new counters to display via ethtool stats
  (FATE#311448, bnc#697255).
- patches.drivers/0083-be2net-fixes-in-ethtool-selftest.patch:
  be2net: fixes in ethtool selftest (FATE#311448, bnc#697255).
- patches.drivers/0084-be2net-variable-name-change.patch: be2net:
  variable name change (FATE#311448, bnc#697255).
- patches.drivers/0085-be2net-fix-to-ignore-transparent-vlan-ids-wrongly-i.patch:
  be2net: fix to ignore transparent vlan ids wrongly indicated
  by NIC (FATE#311448, bnc#697255).
- patches.drivers/0086-be2net-add-code-to-display-temperature-of-ASIC.patch:
  be2net: add code to display temperature of ASIC (FATE#311448,
  bnc#697255).
- patches.drivers/0087-be2net-use-hba_port_num-instead-of-port_num.patch:
  be2net: use hba_port_num instead of port_num (FATE#311448,
  bnc#697255).
- patches.drivers/0088-benet-use-GFP_KERNEL-allocations-when-possible.patch:
  benet: use GFP_KERNEL allocations when possible (FATE#311448,
  bnc#697255).
- patches.drivers/0089-be2net-Remove-ERR-compl-workaround-for-Lancer.patch:
  be2net: Remove ERR compl workaround for Lancer (FATE#311448,
  bnc#697255).
- patches.drivers/0090-be2net-Checksum-field-valid-only-for-TCP-UDP.patch:
  be2net: Checksum field valid only for TCP/UDP (FATE#311448,
  bnc#697255).
- patches.drivers/0091-be2net-Add-error-recovery-during-load-for-Lancer.patch:
  be2net: Add error recovery during load for Lancer (FATE#311448,
  bnc#697255).
- patches.drivers/0092-be2net-Change-f-w-command-versions-for-Lancer.patch:
  be2net: Change f/w command versions for Lancer (FATE#311448,
  bnc#697255).
- patches.drivers/0093-be2net-Remove-TX-Queue-stop-in-close.patch:
  be2net: Remove TX Queue stop in close (FATE#311448, bnc#697255).
- patches.drivers/0094-be2net-Disarm-CQ-and-EQ-to-disable-interrupt-in-Lan.patch:
  be2net: Disarm CQ and EQ to disable interrupt in Lancer
  (FATE#311448, bnc#697255).
- patches.drivers/0095-be2net-Add-multicast-filter-capability-for-Lancer.patch:
  be2net: Add multicast filter capability for Lancer (FATE#311448,
  bnc#697255).
- patches.drivers/0096-be2net-changes-for-BE3-native-mode-support.patch:
  be2net: changes for BE3 native mode support (FATE#311448,
  bnc#697255).
- patches.drivers/0097-be2net-Fix-UDP-packet-detected-status-in-RX-compl.patch:
  be2net: Fix UDP packet detected status in RX compl (FATE#311448,
  bnc#697255).
- patches.drivers/0098-be2net-Copyright-notice-change.-Update-to-Emulex-in.patch:
  be2net: Copyright notice change. Update to Emulex instead of
  ServerEngines (FATE#311448, bnc#697255).
- patches.drivers/0099-be2net-Support-for-FAT-dump-retrieval-using-ethtool.patch:
  be2net: Support for FAT dump retrieval using ethtool
  - -register-dump option (FATE#311448, bnc#697255).
- patches.drivers/0100-be2net-refactor-code-that-decides-adapter-num_rx_q.patch:
  be2net: refactor code that decides adapter->num_rx_queues
  (FATE#311448, bnc#697255).
- patches.drivers/0101-be2net-parse-vid-and-vtm-fields-of-rx-compl-only-if.patch:
  be2net: parse vid and vtm fields of rx-compl only if vlanf
  bit is set (FATE#311448, bnc#697255).
- patches.drivers/0102-be2net-remove-redundant-code-in-be_worker.patch:
  be2net: remove redundant code in be_worker() (FATE#311448,
  bnc#697255).
- patches.drivers/0103-be2net-cancel-be_worker-in-be_shutdown-even-when.patch:
  be2net: cancel be_worker in be_shutdown() even when i/f is down
  (FATE#311448, bnc#697255).
- patches.drivers/0104-be2net-remove-one-useless-line.patch:
  be2net: remove one useless line (FATE#311448, bnc#697255).
- patches.drivers/0105-Fix-common-misspellings.patch: Fix common
  misspellings (FATE#311448, bnc#697255).
- patches.drivers/0106-be2net-Fix-a-potential-crash-during-shutdown.patch:
  be2net: Fix a potential crash during shutdown (FATE#311448,
  bnc#697255).
- patches.drivers/0107-be2net-Rename-some-struct-members-for-clarity.patch:
  be2net: Rename some struct members for clarity (FATE#311448,
  bnc#697255).
- patches.drivers/0108-be2net-Fix-suspend-resume-operation.patch:
  be2net: Fix suspend/resume operation (FATE#311448, bnc#697255).
- patches.drivers/0109-be2net-use-common-method-to-check-for-sriov-functio.patch:
  be2net: use common method to check for sriov function type
  (FATE#311448, bnc#697255).
- patches.drivers/0110-be2net-fix-to-get-max-VFs-supported-from-adapter.patch:
  be2net: fix to get max VFs supported from adapter (FATE#311448,
  bnc#697255).
- patches.drivers/0111-be2net-dynamically-allocate-adapter-vf_cfg.patch:
  be2net: dynamically allocate adapter->vf_cfg (FATE#311448,
  bnc#697255).
- patches.drivers/0112-be2net-call-FLR-after-setup-wol-in-be_shutdown.patch:
  be2net: call FLR after setup wol in be_shutdown (FATE#311448,
  bnc#697255).
- patches.drivers/0113-net-benet-convert-to-hw_features.patch:
  net: benet: convert to hw_features (FATE#311448, bnc#697255).
- patches.drivers/0114-net-benet-convert-to-hw_features-fixup.patch:
  net: benet: convert to hw_features - fixup (FATE#311448,
  bnc#697255).
- patches.drivers/0115-ethtool-allow-custom-interval-for-physical-identifi.patch:
  ethtool: allow custom interval for physical identification
  (FATE#311448, bnc#697255).
- patches.drivers/0116-be2net-Fix-unused-but-set-variables.patch:
  be2net: Fix unused-but-set variables (FATE#311448, bnc#697255).
- patches.drivers/0118-be2net-allow-register-dump-only-for-PFs.patch:
  be2net: allow register dump only for PFs (FATE#311448,
  bnc#697255).
- patches.drivers/0119-be2net-Add-code-to-display-nic-speeds-other-than-1G.patch:
  be2net: Add code to display nic speeds other than 1Gbps/10Gbps
  (FATE#311448, bnc#697255).
- patches.drivers/0120-be2net-fix-be_mcc_compl_process-to-identify-eth_get.patch:
  be2net: fix be_mcc_compl_process to identify eth_get_stat
  command (FATE#311448, bnc#697255).
- patches.drivers/0121-be2net-pass-domain-id-to-be_cmd_link_status_query.patch:
  be2net: pass domain id to be_cmd_link_status_query (FATE#311448,
  bnc#697255).
- patches.drivers/0122-be2net-add-code-to-display-default-value-of-tx-rate.patch:
  be2net: add code to display default value of tx rate for VFs
  (FATE#311448, bnc#697255).
- patches.drivers/0123-be2net-increment-work_counter-in-be_worker.patch:
  be2net: increment work_counter in be_worker (FATE#311448,
  bnc#697255).
- patches.drivers/0124-be2net-Fixed-a-bug-in-be_cmd_get_regs.patch:
  be2net: Fixed a bug in be_cmd_get_regs() (FATE#311448,
  bnc#697255).
- patches.drivers/0125-be2net-Fixed-bugs-related-to-PVID.patch:
  be2net: Fixed bugs related to PVID (FATE#311448, bnc#697255).
- patches.drivers/0126-be2net-Handle-error-completion-in-Lancer.patch:
  be2net: Handle error completion in Lancer (FATE#311448,
  bnc#697255).
- patches.drivers/0127-be2net-Disable-coalesce-water-mark-mode-of-CQ-for-L.patch:
  be2net: Disable coalesce water mark mode of CQ for Lancer
  (FATE#311448, bnc#697255).
- patches.drivers/0128-be2net-In-case-of-UE-do-not-dump-registers-for-Lan.patch:
  be2net: In case of UE, do not dump registers for Lancer
  (FATE#311448, bnc#697255).
- patches.drivers/0129-be2net-Use-NTWK_RX_FILTER-command-for-promiscous-mo.patch:
  be2net: Use NTWK_RX_FILTER command for promiscous mode
  (FATE#311448, bnc#697255).
- patches.drivers/0130-be2net-Fix-to-prevent-flooding-of-TX-queue.patch:
  be2net: Fix to prevent flooding of TX queue (FATE#311448,
  bnc#697255).
- patches.drivers/0131-be2net-handle-signal-reception-while-waiting-for-PO.patch:
  be2net: handle signal reception while waiting for POST
  (FATE#311448, bnc#697255).
- patches.drivers/0132-be2net-fix-mbox-polling-for-signal-reception.patch:
  be2net: fix mbox polling for signal reception (FATE#311448,
  bnc#697255).
- patches.drivers/0133-be2net-Support-for-version-1-of-stats-for-BE3.patch:
  be2net: Support for version 1 of stats for BE3 (FATE#311448,
  bnc#697255).
- patches.drivers/0134-be2net-Stats-for-Lancer.patch: be2net:
  Stats for Lancer (FATE#311448, bnc#697255).
- patches.drivers/0135-be2net-FW-download-for-Lancer.patch:
  be2net: FW download for Lancer (FATE#311448, bnc#697255).
- patches.drivers/0136-be2net-Enable-SR-IOV-for-Lancer.patch:
  be2net: Enable SR-IOV for Lancer (FATE#311448, bnc#697255).
- patches.drivers/0137-be2net-Kill-set-but-unused-variable-req-in-lancer.patch:
  be2net: Kill set but unused variable 'req' in
  lancer_fw_download() (FATE#311448, bnc#697255).
- patches.drivers/0138-Add-appropriate-linux-prefetch.h-include-for-prefe.patch:
  Add appropriate <linux/prefetch.h> include for prefetch users
  (FATE#311448, bnc#697255).
- patches.drivers/0139-be2net-hash-key-for-rss-config-cmd-not-set.patch:
  be2net: hash key for rss-config cmd not set (FATE#311448,
  bnc#697255).
- patches.drivers/0140-be2net-Fallback-to-the-older-opcode-if-MCC_CREATE_E.patch:
  be2net: Fallback to the older opcode if MCC_CREATE_EXT opcode
  is not supported on...  (FATE#311448, bnc#697255).
- patches.drivers/0141-be2net-Fix-Rx-pause-counter-for-lancer.patch:
  be2net: Fix Rx pause counter for lancer (FATE#311448,
  bnc#697255).
- patches.drivers/0142-be2net-Enable-NETIF_F_TSO6-for-VLAN-traffic-for-BE.patch:
  be2net: Enable NETIF_F_TSO6 for VLAN traffic for BE
  (FATE#311448, bnc#697255).
- patches.drivers/0143-be2net-support-multiple-TX-queues.patch:
  be2net: support multiple TX queues (FATE#311448, bnc#697255).
- patches.drivers/0144-be2net-fix-sles11sp2-backporting-issues.patch:
  be2net: Fix sles11sp2 backporting issues (FATE#311448,
  bnc#697255).
* Thu Jun 23 2011 brogers@suse.com
- patches.suse/kvm-0002-KVM-SVM-Add-clean-bit-for-intercetps-tsc-offset-a.patch:
  Update references (FATE#309760).
* Thu Jun 23 2011 brogers@suse.com
- patches.suse/kvm-0001-KVM-SVM-Add-clean-bits-infrastructure-code.patch:
  KVM: SVM: Add clean-bits infrastructure code (FATE#309760).
- patches.suse/kvm-0001-KVM-SVM-Implement-infrastructure-for-TSC_RATE_MSR.patch:
  KVM: SVM: Implement infrastructure for TSC_RATE_MSR
  (FATE#309762).
- patches.suse/kvm-0001-KVM-SVM-implement-NEXTRIPsave-SVM-feature.patch:
  KVM: SVM: implement NEXTRIPsave SVM feature (FATE#309761).
- patches.suse/kvm-0002-KVM-SVM-Add-clean-bit-for-intercetps-tsc-offset-a.patch:
  KVM: SVM: Add clean-bit for intercepts, tsc-offset and pause
  filter count (FATE:309760).
- patches.suse/kvm-0002-KVM-X86-Let-kvm-clock-report-the-right-tsc-frequency.patch:
  KVM: X86: Let kvm-clock report the right tsc frequency
  (FATE#309762).
- patches.suse/kvm-0002-KVM-x86-fix-CR8-handling.patch: KVM:
  x86: fix CR8 handling (FATE#309761).
- patches.suse/kvm-0003-KVM-SVM-Add-clean-bit-for-IOPM_BASE-and-MSRPM_BASE.patch:
  KVM: SVM: Add clean-bit for IOPM_BASE and MSRPM_BASE
  (FATE#309760).
- patches.suse/kvm-0003-KVM-SVM-Make-tsc_delta-calculation-a-function-of-gue.patch:
  KVM: SVM: Make tsc_delta calculation a function of guest tsc
  (FATE#309762).
- patches.suse/kvm-0003-KVM-cleanup-emulate_instruction.patch:
  KVM: cleanup emulate_instruction (FATE#309761).
- patches.suse/kvm-0004-KVM-SVM-Add-clean-bit-for-the-ASID.patch:
  KVM: SVM: Add clean-bit for the ASID (FATE#309760).
- patches.suse/kvm-0004-KVM-SVM-add-new-SVM-feature-bit-names.patch:
  KVM: SVM: add Decode Assist SVM feature bit name (FATE#309761).
- patches.suse/kvm-0004-KVM-X86-Implement-call-back-to-propagate-virtual_tsc.patch:
  KVM: X86: Implement call-back to propagate virtual_tsc_khz
  (FATE#309762).
- patches.suse/kvm-0005-KVM-SVM-Add-clean-bit-for-interrupt-state.patch:
  KVM: SVM: Add clean-bit for interrupt state (FATE#309760).
- patches.suse/kvm-0005-KVM-SVM-enhance-MOV-CR-intercept-handler.patch:
  KVM: SVM: enhance MOV CR intercept handler (FATE#309761).
- patches.suse/kvm-0005-KVM-X86-Implement-userspace-interface-to-set-virtual.patch:
  KVM: X86: Implement userspace interface to set virtual_tsc_khz
  (FATE#309762).
- patches.suse/kvm-0006-KVM-SVM-Add-clean-bit-for-NPT-state.patch:
  KVM: SVM: Add clean-bit for NPT state (FATE#309760).
- patches.suse/kvm-0006-KVM-SVM-enhance-mov-DR-intercept-handler.patch:
  KVM: SVM: enhance mov DR intercept handler (FATE#309761).
- patches.suse/kvm-0007-KVM-SVM-Add-clean-bit-for-control-registers.patch:
  KVM: SVM: Add clean-bit for control registers (FATE#309760).
- patches.suse/kvm-0007-KVM-SVM-implement-enhanced-INVLPG-intercept.patch:
  KVM: SVM: implement enhanced INVLPG intercept (FATE#309761).
- patches.suse/kvm-0008-KVM-SVM-Add-clean-bit-for-DR6-and-DR7.patch:
  KVM: SVM: Add clean-bit for DR6 and DR7 (FATE#309760).
- patches.suse/kvm-0008-KVM-SVM-copy-instruction-bytes-from-VMCB.patch:
  KVM: SVM: copy instruction bytes from VMCB (FATE#309761).
- patches.suse/kvm-0009-KVM-SVM-Add-clean-bit-for-GDT-and-IDT.patch:
  KVM: SVM: Add clean-bit for GDT and IDT (FATE#309760).
- patches.suse/kvm-0010-KVM-SVM-Add-clean-bit-for-Segements-and-CPL.patch:
  KVM: SVM: Add clean-bit for Segements and CPL (FATE#309760).
- patches.suse/kvm-0011-KVM-SVM-Add-clean-bit-for-CR2-register.patch:
  KVM: SVM: Add clean-bit for CR2 register (FATE#309760).
- patches.suse/kvm-0012-KVM-SVM-Add-clean-bit-for-LBR-state.patch:
  KVM: SVM: Add clean-bit for LBR state (FATE#309760).
* Thu Jun 23 2011 jbohac@suse.cz
- patches.suse/net-rfc3069-private-vlan-proxy-arp-support.patch:
  Refresh to fix broken sysctl check table.
* Thu Jun 23 2011 mhocko@suse.cz
- patches.suse/mm-memcg-fix-USED-bit-handling-for-THP.patch:
  Refresh - commit id fixed.
* Thu Jun 23 2011 mmarek@suse.cz
- patches.fixes/Fix-over-zealous-flush_disk-when-changing-device-siz.patch:
  Refresh to apply in SP2.
* Thu Jun 23 2011 nfbrown@suse.de
- patches.fixes/Fix-over-zealous-flush_disk-when-changing-device-siz.patch:
  Don't flush dirty filesystem buffers when a device changes size.
* Wed Jun 22 2011 jslaby@suse.de
- patches.drivers/pcie-gen3-01-PCI-cache-PCIe-capability-offset.patch:
  PCI: cache PCIe capability offset (FATE#311840 FATE#311841
  FATE#311842 FATE#311843 bnc#700632 bnc#700637 bnc#700638).
- patches.drivers/pcie-gen3-02-introduce-pci_pcie_cap.patch: PCI:
  introduce pci_pcie_cap() (FATE#311840 FATE#311841 FATE#311842
  FATE#311843 bnc#700632 bnc#700637 bnc#700638).
- patches.drivers/pcie-gen3-03-introduce-pci_is_pcie.patch: PCI:
  introduce pci_is_pcie() (FATE#311840 FATE#311841 FATE#311842
  FATE#311843 bnc#700632 bnc#700637 bnc#700638).
- patches.drivers/pcie-gen3-04-add-ID-based-ordering-enable-disable-support.patch:
  PCI: add ID-based ordering enable/disable support (FATE#311840
  FATE#311841 FATE#311842 FATE#311843 bnc#700632 bnc#700637
  bnc#700638).
- patches.drivers/pcie-gen3-05-add-OBFF-enable-disable-support.patch:
  PCI: add OBFF enable/disable support (FATE#311840 FATE#311841
  FATE#311842 FATE#311843 bnc#700632 bnc#700637 bnc#700638).
- patches.drivers/pcie-gen3-06-add-latency-tolerance-reporting.patch:
  PCI: add latency tolerance reporting enable/disable support
  (FATE#311840 FATE#311841 FATE#311842 FATE#311843 bnc#700632
  bnc#700637 bnc#700638).
- patches.xen/pci-guestdev: Refresh.
* Wed Jun 22 2011 jslaby@suse.de
- patches.arch/repmovs-01-x86-alternatives-check-replacementlen-instrlen.patch:
  x86/alternatives: Check replacementlen <= instrlen at build time
  (FATE#311936 bnc#698793).
- patches.arch/repmovs-02-modify-memcpy-memset.patch: x86-64:
  Modify memcpy()/memset() alternatives mechanism (FATE#311936
  bnc#698793).
- patches.arch/repmovs-03-modify-copy_user_generic.patch:
  x86-64: Modify copy_user_generic() alternatives mechanism
  (FATE#311936 bnc#698793).
- patches.arch/repmovs-04-use-16-bit-numbers-for-cpufeature-idx.patch:
  x86, alternatives: Use 16-bit numbers for cpufeature index
  (FATE#311936 bnc#698793).
- patches.arch/repmovs-05-convert-memmove-to-assembly-file.patch:
  x86-64, mem: Convert memmove() to assembly file and fix return
  value bug (FATE#311936 bnc#698793).
- patches.arch/repmovs-06-fix-cpuid-leaf-7-feature-detection.patch:
  x86, cpufeature: Fix cpuid leaf 7 feature detection (FATE#311936
  bnc#698793).
- patches.arch/repmovs-07-add-CPU-feature-bit.patch: x86,
  cpufeature: Add CPU feature bit for enhanced REP MOVSB/STOSB
  (FATE#311936 bnc#698793).
- patches.arch/repmovs-08-initialize-Enhanced-REP-MOVSB-STOSB.patch:
  x86, mem, intel: Initialize Enhanced REP MOVSB/STOSB
  (FATE#311936 bnc#698793).
- patches.arch/repmovs-09-add-comment.patch: x86, alternative,
  doc: Add comment for applying alternatives order (FATE#311936
  bnc#698793).
- patches.arch/repmovs-10-add-altinstruction_entry-macro.patch:
  x86, alternative: Add altinstruction_entry macro (FATE#311936
  bnc#698793).
- patches.arch/repmovs-11-support-clear_page.patch: x86, mem:
  clear_page_64.S: Support clear_page() with enhanced REP
  MOVSB/STOSB (FATE#311936 bnc#698793).
- patches.arch/repmovs-12-support-copy_to-from_user.patch: x86,
  mem: copy_user_64.S: Support copy_to/from_user by enhanced
  REP MOVSB/STOSB (FATE#311936 bnc#698793).
- patches.arch/repmovs-13-optimize-memcpy.patch: x86, mem:
  memcpy_64.S: Optimize memcpy by enhanced REP MOVSB/STOSB
  (FATE#311936 bnc#698793).
- patches.arch/repmovs-14-optimize-memmove.patch: x86, mem:
  memmove_64.S: Optimize memmove by enhanced REP MOVSB/STOSB
  (FATE#311936 bnc#698793).
- patches.arch/repmovs-15-optimize-memset.patch: x86, mem:
  memset_64.S: Optimize memset by enhanced REP MOVSB/STOSB
  (FATE#311936 bnc#698793).
- patches.arch/x86-cpufeature-add-SMEP-flag.patch: Refresh.
* Wed Jun 22 2011 jbohac@suse.cz
- patches.drivers/bonding-change-test-for-presence-of-vlans.patch:
  bonding: change test for presence of VLANs (bnc#654501,
  fate#311754).
- patches.drivers/bonding-fix-bond_inet6addr_event.patch: bonding:
  fix bond_inet6addr_event() (bnc#654501, fate#311754).
- patches.fixes/bonding-allow-arp_ip_targers-on-separate-vlans-to-use-arp-validation.patch:
  Refresh.
- patches.suse/vlan-0-should-be-treated-as-no-vlan-tag.patch:
  VLAN 0 should be treated as "no vlan tag" (802.1p packet)
  (bnc#654501, fate#311754).
- patches.suse/vlan-allow-null-vlan-id-to-be-used.patch: vlan:
  allow null VLAN ID to be used (fate#311754).
* Wed Jun 22 2011 jbohac@suse.cz
- patches.suse/net-rfc3069-private-vlan-proxy-arp-support.patch:
  Refresh.
* Wed Jun 22 2011 jbohac@suse.cz
- patches.suse/ipv4-add-sysctl-to-accept-packets-with-local-source-address.patch:
  ipv4: add sysctl to accept packets with local source addresses
  (fate#310840).
- patches.suse/net-fib_rules-add-oif-classification.patch: net:
  fib_rules: add oif classification (fate#310840).
- patches.suse/net-fib_rules-allow-to-delete-local-rule.patch:
  net: fib_rules: allow to delete local rule (fate#310840).
- patches.suse/net-fib_rules-rearrange-struct-fib_rule.patch:
  net: fib_rules: rearrange struct fib_rule (fate#310840).
- patches.suse/net-fib_rules-rename-ifindex-ifname-FRA_IFNAME.patch:
  net: fib_rules: rearrange struct fib_rule
  net: fib_rules: rename ifindex/ifname/FRA_IFNAME to
  iifindex/iifname/FRA_IIFNAME (fate#310840).
* Wed Jun 22 2011 jankit@suse.de
- patches.fixes/scsi_transport_spi-export-host-width-and-HBA-id:
  scsi_transport_spi: Export host width and HBA id (bnc #697181).
* Wed Jun 22 2011 jbohac@suse.cz
- patches.suse/net-rfc3069-private-vlan-proxy-arp-support.patch:
  net: RFC3069, private VLAN proxy arp support (fate#310827).
* Wed Jun 22 2011 jbohac@suse.cz
- patches.drivers/macvlan-export-macvlan-mode-through-netlink.patch:
  macvlan: export macvlan mode through netlink (fate#311478).
- patches.drivers/macvlan-implement-bridge-VEPA-and-private-mode.patch:
  macvlan: implement bridge, VEPA and private mode (fate#311478).
- patches.suse/net-implement-dev_forward_skb.patch: net: implement
  dev_forward_skb() (fate#311478).
* Tue Jun 21 2011 jack@suse.cz
- patches.suse/cfq-iosched-Don-t-update-group-weights-when-on-servi.patch:
  Fix memory corruption caused by buggy backport.
* Tue Jun 21 2011 jbohac@suse.cz
- Update config files.
- patches.drivers/dcb-data-center-bridging-ops-s: Refresh.
- patches.drivers/ixgbe-net-decreasing-real_num_tx_queues-needs-to-flush-qdi.patch:
  Refresh.
- patches.suse/ixgbe-net-decreasing-real_num_tx_queues-needs-to-flush-qdi-generic.patch:
  net: decreasing real_num_tx_queues needs to flush qdisc
  (bnc#625674).
- patches.suse/net-implement-mechanism-for-HW-based-QOS.patch:
  net: implement mechanism for HW based QOS  (fate#11835,
  bnc#687046).
- patches.suse/net_sched-implement-a-root-container-qdisc-sch_mqprio.patch:
  net_sched: implement a root container qdisc sch_mqprio
  (fate#11835, bnc#687046).
* Tue Jun 21 2011 duwe@suse.de
- patches.suse/introduce-find_memory_block_hinted: driver core:
  Introduce find_memory_block_hinted (bnc#700512, FATE#311655).
- patches.suse/introduce-kset_find_obj_hinted: kobject: Introduce
  kset_find_obj_hinted (bnc#700512, FATE#311655).
* Tue Jun 21 2011 jslaby@suse.de
- patches.arch/x86-cpufeature-add-SMEP-flag.patch: x86,
  cpufeature: Add cpufeature flag for SMEP (fate#311999).
- patches.arch/x86-enable-smep.patch: Refresh.
- patches.arch/x86-features-flags-in-new-CPUID-leaf.patch:
  x86, cpu: Support the features flags in new CPUID leaf 7
  (bnc#698779 fate#311965).
- patches.arch/xsaveopt-01-init_scattered_cpuid_features-subleaves.patch:
  x86, cpu: Make init_scattered_cpuid_features() consider cpuid
  subleaves (bnc#698779 fate#311965).
- patches.arch/xsaveopt-02-add-xsaveopt-cpufeature.patch: x86,
  cpu: Add xsaveopt cpufeature (bnc#698779 fate#311965).
- patches.arch/xsaveopt-03-enumerate-xsaveopt.patch: x86, cpu:
  Enumerate xsaveopt (bnc#698779 fate#311965).
- patches.arch/xsaveopt-04-track-attrs-in-xsave-layout.patch:
  x86, xsave: Track the offset, size of state in the xsave layout
  (bnc#698779 fate#311965).
- patches.arch/xsaveopt-05-sync-xsave-memory-layout.patch:
  x86, xsave: Sync xsave memory layout with its header for user
  handling (bnc#698779 fate#311965).
- patches.arch/xsaveopt-06-use-xsaveopt-in-context-switch-path.patch:
  x86, xsave: Use xsaveopt in context-switch path when supported
  (bnc#698779 fate#311965).
- patches.drivers/hwmon-coretemp-add-pkgtemp-support.patch:
  Refresh.
- patches.suse/kvm-x86-Introduce-struct-fpu-and-related-API.patch:
  Refresh.
- patches.arch/0001-x86-cpu-Add-AMD-core-boosting-feature-flag-to-proc-c.patch:
  Refresh.
- patches.arch/xsaveopt-02-add-xsaveopt-cpufeature.patch: Refresh.
- patches.drivers/hwmon-coretemp-add-pkgtemp-support.patch:
  Refresh.
* Tue Jun 21 2011 jslaby@suse.de
- patches.arch/x86-Eliminate-TS_XSAVE.patch: x86: Eliminate
  TS_XSAVE (FATE#311768).
- patches.arch/x86-Introduce-struct-fpu-and-related-API.patch:
  x86: Introduce 'struct fpu' and related API (FATE#311768).
- patches.arch/x86-fpu-Unbreak-FPU-emulation.patch: x86, fpu:
  Unbreak FPU emulation (FATE#311768).
- patches.suse/kvm-x86-Eliminate-TS_XSAVE.patch: Delete.
- patches.suse/kvm-x86-Introduce-struct-fpu-and-related-API.patch:
  Delete.
- patches.suse/kvm-x86-fpu-Unbreak-FPU-emulation.patch: Delete.
  Move the stuff around as a preparation for the next patches.
* Tue Jun 21 2011 rjw@suse.de
- patches.arch/printk-Allocate-kernel-log-buffer-earlier.patch:
  Refresh.
* Tue Jun 21 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-116-Reorganize-controller-quriks-with-bit-flags:
  Refresh.  Fixed the cherry-picking errors.
* Tue Jun 21 2011 jbohac@suse.cz
- patches.suse/procps_bitmap_support.patch: fix a porting bug.
* Tue Jun 21 2011 hare@suse.de
- patches.suse/libata-Add-ATA-transport-class.patch:
  Fixup merge error.
- patches.suse/libata-Fix-section-mismatch-ata_sff_exit.patch:
  [libata] Fix section mismatch: ata_sff_exit (FATE#311826).
* Mon Jun 20 2011 mhocko@suse.cz
- patches.fixes/cgroups-fix-race-between-userspace-and-kernelspace.patch:
  cgroups: fix race between userspace and kernelspace
  (bnc#700084).
* Mon Jun 20 2011 mgorman@suse.de
- patches.fixes/ksm-fix-null-pointer-dereference-in-scan_get_next_rmap_item.patch
  ksm: fix NULL pointer dereference in scan_get_next_rmap_item
  (bnc#697901, CVE-2011-2183)
* Mon Jun 20 2011 trenn@suse.de
  Remove my own patch which missed an i386 case and add the stub which
  already was in the repo (with a slight change to prefer acpi over amd
  HW info).
- patches.xen/xen3-2009-10-12-0003-x86-Export-k8-physical-topology.patch:
  Refresh.
- patches.xen/xen-initmem_init_4_args.patch: Delete.
* Mon Jun 20 2011 jack@suse.cz
- patches.fixes/ext4-avoid-uninitialized-memory-references-in-ext4_h.patch:
  ext4: avoid uninitialized memory references in
  ext4_htree_next_block() (bnc#692454).
* Mon Jun 20 2011 hare@suse.de
- patches.fixes/scsi_dh_rdac-add-new-array-ids: scsi_dh_rdac:
  Add new array ids (bnc#688912).
* Mon Jun 20 2011 jkosina@suse.cz
- patches.arch/x86-enable-smep.patch: Enable SMEP (FATE#311999).
* Mon Jun 20 2011 hare@suse.de
- patches.fixes/scsi_dh_rdac-Add-definitions-for-different.patch:
  [SCSI] scsi_dh_rdac : Add definitions for different RDAC
  operating modes (bnc#688912).
- patches.fixes/scsi_dh_rdac-Detect-the-different-RDAC-oper.patch:
  [SCSI] scsi_dh_rdac : Detect the different RDAC operating modes
  (bnc#688912).
- patches.fixes/scsi_dh_rdac-decide-whether-to-send-mode-se.patch:
  [SCSI] scsi_dh_rdac : decide whether to send mode select based
  on operating mode (bnc#688912).
* Mon Jun 20 2011 hare@suse.de
- supported.conf: Mark IDE drivers as unsupported (bnc#700332)
* Mon Jun 20 2011 jkosina@suse.cz
- patches.arch/x86-tboot-Add-support-for-S3-memory-integrity-prot.patch:
  x86, tboot: Add support for S3 memory integrity protection
  (FATE#311962).
* Mon Jun 20 2011 jkosina@suse.cz
- patches.drivers/mmc-sd-01-add-support-for-signal-voltage-switch-procedure.patch:
  mmc: sd: add support for signal voltage switch procedure
  (FATE#311119).
- patches.drivers/mmc-sd-02-query-function-modes-for-uhs-cards.patch:
  mmc: sd: query function modes for uhs cards (FATE#311119).
- patches.drivers/mmc-sd-03-add-support-for-driver-type-selection.patch:
  mmc: sd: add support for driver type selection (FATE#311119).
- patches.drivers/mmc-sd-05-add-support-for-uhs-bus-speed-mode-selection.patch:
  mmc: sd: add support for uhs bus speed mode selection
  (FATE#311119).
- patches.drivers/mmc-sd-06-set-current-limit-for-uhs-cards.patch:
  mmc: sd: set current limit for uhs cards (FATE#311119).
- patches.drivers/mmc-sd-07-add-support-for-tuning-during-uhs-initialization.patch:
  mmc: sd: add support for tuning during uhs initialization
  (FATE#311119).
- patches.drivers/mmc-sd-08-report-correct-speed-and-capacity-of-uhs-card.patch:
  mmc: sd: report correct speed and capacity of uhs cards
  (FATE#311119).
- patches.drivers/mmc-sdhci-04-reset-sdclk-before-setting-high-speed-enable.patch:
  mmc: sdhci: reset sdclk before setting high speed enable
  (FATE#311119).
- patches.drivers/mmc-sdhci-09-enable-preset-value-after-uhs-initialization.patch:
  mmc: sdhci: enable preset value after uhs initialization
  (FATE#311119).
- patches.drivers/mmc-sdhci-10-add-support-for-programmable-clock-mode.patch:
  mmc: sdhci: add support for programmable clock mode
  (FATE#311119).
- patches.drivers/mmc-sdhci-11-add-support-for-retuning-mode-1.patch:
  mmc: sdhci: add support for retuning mode 1 (FATE#311119).
* Mon Jun 20 2011 mmarek@suse.cz
- supported.conf: Mark btrfs as supported (fate#306585).
- rpm/kernel-binary.spec.in: Obsolete the tech preview btrfs-kmp.
* Mon Jun 20 2011 trenn@suse.de
- Update config files.
  - Rename CONFIG_K8_NB -> CONFIG_AMD_NB
  - Rename CONFIG_K8_NUMA -> CONFIG_AMD_NUMA
  - Adding CONFIG_EDAC_MCE_INJ=m
- supported.conf:
  - add mperf as supported -> got splitted out to get used by
    powernow-k8 and acpi-cpufreq
  - add i7core_edac
- patches.arch/0001-x86-cpu-Add-AMD-core-boosting-feature-flag-to-proc-c.patch:
  x86, cpu: Add AMD core boosting feature flag to /proc/cpuinfo
  (fate#309725).
- patches.arch/0002-powernow-k8-Add-core-performance-boost-support.patch:
  powernow-k8: Add core performance boost support (fate#309725).
- patches.arch/0003-x86-Unify-APERF-MPERF-support.patch: x86:
  Unify APERF/MPERF support (fate#309726).
- patches.arch/0004-x86-cpufreq-Add-APERF-MPERF-support-for-AMD-processo.patch:
  x86, cpufreq: Add APERF/MPERF support for AMD processors
  (fate#309726).
- patches.arch/0005-x86-cacheinfo-Unify-AMD-L3-cache-index-disable-check.patch:
  x86, cacheinfo: Unify AMD L3 cache index disable checking
  (fate#311580 fate#309727).
- patches.arch/0006-x86-cacheinfo-Reorganize-AMD-L3-cache-structure.patch:
  x86, cacheinfo: Reorganize AMD L3 cache structure (fate#311580
  fate#309727).
- patches.arch/0007-x86-cacheinfo-Make-L3-cache-info-per-node.patch:
  x86, cacheinfo: Make L3 cache info per node (fate#311580
  fate#309727).
- patches.arch/0008-x86-cacheinfo-Disable-index-in-all-four-subcaches.patch:
  x86, cacheinfo: Disable index in all four subcaches (fate#311580
  fate#309727).
- patches.arch/0009-x86-cacheinfo-Carve-out-L3-cache-slot-accessors.patch:
  x86, cacheinfo: Carve out L3 cache slot accessors (fate#311580
  fate#309727).
- patches.arch/0010-x86-cacheinfo-Fix-dependency-of-AMD-L3-CID.patch:
  x86, cacheinfo: Fix dependency of AMD L3 CID (fate#311580
  fate#309727).
- patches.arch/0011-x86-Export-k8-physical-topology.patch: x86:
  Export k8 physical topology (fate#311968 fate#309727).
- patches.arch/0015-MCE-AMD-Limit-MCE-decoding-to-current-families-for.patch:
  MCE, AMD: Limit MCE decoding to current families for
  (fate#311968).
- patches.arch/0017-x86-k8-gart-Decouple-handling-of-garts-and.patch:
  x86, k8-gart: Decouple handling of garts and (fate#311968).
- patches.arch/0018-x86-k8-Rename-k8.-ch-to-amd_nb.-ch-and.patch:
  and (fate#311968).
- patches.arch/0019-x86-nmi-Support-NMI-watchdog-on-newer-AMD-CPU-famili.patch:
  x86, nmi: Support NMI watchdog on newer AMD CPU families
  (fate#309722).
- patches.arch/0020-x86-cpu-Update-AMD-CPUID-feature-bits.patch:
  x86, cpu: Update AMD CPUID feature bits (fate#309722).
- patches.arch/0021-x86-amd-Add-support-for-CPUID-topology-extension-of-.patch:
  x86, amd: Add support for CPUID topology extension of AMD CPUs
  (fate#309723).
- patches.arch/0022-x86-amd-Extract-compute-unit-information-for-AMD-CPU.patch:
  x86, amd: Extract compute unit information for AMD CPUs
  (fate#309723).
- patches.arch/0023-x86-amd-Use-compute-unit-information-to-determine-th.patch:
  x86, amd: Use compute unit information to determine thread
  siblings (fate#309723).
- patches.arch/0024-x86-amd_nb-Enable-GART-support-for-AMD-family-0x15-C.patch:
  x86, amd_nb: Enable GART support for AMD family 0x15 CPUs
  (fate#309763).
- patches.arch/0025-x86-AMD-Extend-support-to-future-families.patch:
  x86, AMD: Extend support to future families (fate#309722).
- patches.arch/0026-x86-mcheck-Avoid-duplicate-sysfs-links-files-for-thr.patch:
  x86, mcheck: Avoid duplicate sysfs links/files for thresholding
  banks (fate#309722).
- patches.arch/0027-x86-amd-nb-Complete-the-rename-of-AMD-NB-and.patch:
  x86, amd-nb: Complete the rename of AMD NB and (fate#311968).
- patches.arch/0028-x86-amd-nb-Cleanup-AMD-northbridge-caching-code.patch:
  x86, amd-nb: Cleanup AMD northbridge caching code (fate#311968).
- patches.arch/0029-x86-Use-PCI-method-for-enabling-AMD-extended-config-.patch:
  x86: Use PCI method for enabling AMD extended config space
  before MSR method (fate#309722).
- patches.arch/0120-x86-cacheinfo-Cleanup-L3-cache-index-disable-support.patch:
  x86, cacheinfo: Cleanup L3 cache index disable support
  (fate#309727).
- patches.arch/0121-x86-amd-Normalize-compute-unit-IDs-on-multi-node-pro.patch:
  x86, amd: Normalize compute unit IDs on multi-node processors
  (fate#309723).
- patches.arch/0122-x86-amd-Enable-L3-cache-index-disable-on-family-0x15.patch:
  x86, amd: Enable L3 cache index disable on family 0x15
  (fate#309727).
- patches.arch/0123-x86-amd-Extend-AMD-northbridge-caching-code-to-suppo.patch:
  x86, amd: Extend AMD northbridge caching code to support
  "Link Control" devices (fate#309727).
- patches.arch/0124-x86-amd-Support-L3-Cache-Partitioning-on-AMD-family-.patch:
  x86, amd: Support L3 Cache Partitioning on AMD family 0x15 CPUs
  (fate#309727).
- patches.arch/0125-x86-Adjust-section-placement-in-AMD-northbridge-rela.patch:
  x86: Adjust section placement in AMD northbridge related code
  (fate#309727).
- patches.arch/0126-x86-amd-Initialize-variable-properly.patch:
  x86, amd: Initialize variable properly (fate#309723).
- patches.arch/0127-x86-amd-nb-Misc-cleanliness-fixes.patch:
  x86, amd-nb: Misc cleanliness fixes (fate#309727).
- patches.arch/0128-x86-AMD-cacheinfo-Fix-L3-cache-index-disable-checks.patch:
  x86, AMD, cacheinfo: Fix L3 cache index disable checks
  (fate#309727).
- patches.arch/0129-x86-mce-Drop-the-default-decoding-notifier.patch:
  x86, mce: Drop the default decoding notifier (fate#311581).
- patches.arch/x86_amd_fix_missing_i386_pci-direct_include.patch:
  x86 backport fixup: Add missing include (fate#309722,
  fate#309723, fate#309780, fate#309781).
- patches.drivers/0012-amd64_edac-Remove-polling-mechanism.patch:
  amd64_edac: Remove polling mechanism (fate#309907).
- patches.drivers/0013-amd64_edac-Fix-operator-precendence-error.patch:
  amd64_edac: Fix operator precendence error (fate#309907).
- patches.drivers/0014-amd64_edac-Minor-formatting-fix.patch:
  amd64_edac: Minor formatting fix (fate#309907).
- patches.drivers/0016-amd64_edac-Do-not-report-error-overflow-as-a.patch:
  amd64_edac: Do not report error overflow as a (fate#309907).
- patches.drivers/0030-EDAC-MCE-Add-HW_ERR-prefix.patch: EDAC,
  MCE: Add HW_ERR prefix (fate#311581).
- patches.drivers/0031-EDAC-MCE-Remove-unused-function-parameter.patch:
  EDAC, MCE: Remove unused function parameter (fate#311581).
- patches.drivers/0032-EDAC-MCE-Sanitize-error-codes.patch:
  EDAC, MCE: Sanitize error codes (fate#311581).
- patches.drivers/0033-EDAC-MCE-Pass-complete-MCE-info-to-decoders.patch:
  EDAC, MCE: Pass complete MCE info to decoders (fate#311581).
- patches.drivers/0034-EDAC-MCE-Rework-MCE-injection.patch:
  EDAC, MCE: Rework MCE injection (fate#311581).
- patches.drivers/0035-EDAC-MCE-Rename-files.patch: EDAC, MCE:
  Rename files (fate#311581).
- patches.drivers/0036-EDAC-MCE-Adjust-DC-decoders-to-F14h.patch:
  EDAC, MCE: Adjust DC decoders to F14h (fate#311581).
- patches.drivers/0037-EDAC-MCE-Adjust-IC-decoders-to-F14h.patch:
  EDAC, MCE: Adjust IC decoders to F14h (fate#311581).
- patches.drivers/0038-EDAC-MCE-Warn-about-LS-MCEs-on-F14h.patch:
  EDAC, MCE: Warn about LS MCEs on F14h (fate#311581).
- patches.drivers/0039-EDAC-MCE-Complete-NB-MCE-decoders.patch:
  EDAC, MCE: Complete NB MCE decoders (fate#311581).
- patches.drivers/0040-EDAC-MCE-Fix-FR-MCEs-decoding.patch:
  EDAC, MCE: Fix FR MCEs decoding (fate#311581).
- patches.drivers/0041-EDAC-MCE-Enable-MCE-decoding-on-F14h.patch:
  EDAC, MCE: Enable MCE decoding on F14h (fate#311581).
- patches.drivers/0042-EDAC-MCE-Add-support-for-F11h-MCEs.patch:
  EDAC, MCE: Add support for F11h MCEs (fate#311581).
- patches.drivers/0043-EDAC-MCE-Add-F12h-DC-MCE-decoder.patch:
  EDAC, MCE: Add F12h DC MCE decoder (fate#311581).
- patches.drivers/0044-EDAC-MCE-Add-F12h-IC-MCE-decoder.patch:
  EDAC, MCE: Add F12h IC MCE decoder (fate#311581).
- patches.drivers/0045-EDAC-MCE-Add-F12h-NB-MCE-decoder.patch:
  EDAC, MCE: Add F12h NB MCE decoder (fate#311581).
- patches.drivers/0046-EDAC-MCE-Enable-MCE-decoding-on-F12h.patch:
  EDAC, MCE: Enable MCE decoding on F12h (fate#311581).
- patches.drivers/0047-EDAC-MCE-Add-a-BIT_64-macro.patch: EDAC,
  MCE: Add a BIT_64() macro (fate#311581).
- patches.drivers/0048-EDAC-MCE-Fix-shift-warning-on-32-bit.patch:
  EDAC, MCE: Fix shift warning on 32-bit (fate#311581).
- patches.drivers/0049-EDAC-MCE-Fix-edac_init_mce_inject-error-handling.patch:
  EDAC, MCE: Fix edac_init_mce_inject error handling
  (fate#311581).
- patches.drivers/0050-amd64_edac-Remove-F11h-support.patch:
  amd64_edac: Remove F11h support (fate#309907).
- patches.drivers/0051-amd64_edac-Use-cached-extended-CPU-model.patch:
  amd64_edac: Use cached extended CPU model (fate#309907).
- patches.drivers/0052-amd64_edac-Add-per-family-init-function.patch:
  amd64_edac: Add per-family init function (fate#309907).
- patches.drivers/0053-amd64_edac-Simplify-CPU-family-detection.patch:
  amd64_edac: Simplify CPU family detection (fate#309907).
- patches.drivers/0054-amd64_edac-Cleanup-the-CPU-PCI-device-reservation.patch:
  amd64_edac: Cleanup the CPU PCI device reservation
  (fate#309907).
- patches.drivers/0055-amd64_edac-Concentrate-per-family-init-even-more.patch:
  amd64_edac: Concentrate per-family init even more (fate#309907).
- patches.drivers/0056-amd64_edac-Rename-CPU-PCI-devices.patch:
  amd64_edac: Rename CPU PCI devices (fate#309907).
- patches.drivers/0057-amd64_edac-Rework-printk-macros.patch:
  amd64_edac: Rework printk macros (fate#309907).
- patches.drivers/0058-amd64_edac-Allocate-driver-instances-dynamically.patch:
  amd64_edac: Allocate driver instances dynamically (fate#309907).
- patches.drivers/0059-amd64_edac-Remove-PCI-ECS-enabling-functions.patch:
  amd64_edac: Remove PCI ECS enabling functions (fate#309907).
- patches.drivers/0060-amd64_edac-Carve-out-ECC-related-hw-settings.patch:
  amd64_edac: Carve out ECC-related hw settings (fate#309907).
- patches.drivers/0061-amd64_edac-Check-ECC-capabilities-initially.patch:
  amd64_edac: Check ECC capabilities initially (fate#309907).
- patches.drivers/0062-amd64_edac-Remove-two-stage-initialization.patch:
  amd64_edac: Remove two-stage initialization (fate#309907).
- patches.drivers/0063-amd64_edac-Disable-DRAM-ECC-injection-on-K8.patch:
  amd64_edac: Disable DRAM ECC injection on K8 (fate#309907).
- patches.drivers/0064-EDAC-MCE-Select-extended-error-code-mask.patch:
  EDAC, MCE: Select extended error code mask (fate#311581).
- patches.drivers/0065-EDAC-MCE-Add-F15h-DC-MCE-decoder.patch:
  EDAC, MCE: Add F15h DC MCE decoder (fate#311581).
- patches.drivers/0066-EDAC-MCE-Add-F15h-IC-MCE-decoder.patch:
  EDAC, MCE: Add F15h IC MCE decoder (fate#311581).
- patches.drivers/0067-EDAC-MCE-Add-F15h-CU-MCE-decoder.patch:
  EDAC, MCE: Add F15h CU MCE decoder (fate#311581).
- patches.drivers/0068-EDAC-MCE-No-F15h-LS-MCE-decoder.patch:
  EDAC, MCE: No F15h LS MCE decoder (fate#311581).
- patches.drivers/0069-EDAC-MCE-Add-an-F15h-NB-MCE-decoder.patch:
  EDAC, MCE: Add an F15h NB MCE decoder (fate#311581).
- patches.drivers/0070-EDAC-MCE-Add-F15-EX-MCE-decoder.patch:
  EDAC, MCE: Add F15 EX MCE decoder (fate#311581).
- patches.drivers/0071-EDAC-MCE-Add-F15h-FP-MCE-decoder.patch:
  EDAC, MCE: Add F15h FP MCE decoder (fate#311581).
- patches.drivers/0072-EDAC-MCE-Overhaul-error-fields-extraction-macros.patch:
  EDAC, MCE: Overhaul error fields extraction macros
  (fate#311581).
- patches.drivers/0073-EDAC-MCE-Shorten-error-report-formatting.patch:
  EDAC, MCE: Shorten error report formatting (fate#311581).
- patches.drivers/0074-EDAC-MCE-Allow-F15h-bank-6-MCE-injection.patch:
  EDAC, MCE: Allow F15h bank 6 MCE injection (fate#311581).
- patches.drivers/0075-EDAC-MCE-Enable-MCE-decoding-on-F15h.patch:
  EDAC, MCE: Enable MCE decoding on F15h (fate#311581).
- patches.drivers/0076-EDAC-MCE-Use-BIT_64-to-eliminate-warnings-on.patch:
  EDAC, MCE: Use BIT_64() to eliminate warnings on (fate#311581).
- patches.drivers/0077-EDAC-MCE-Fix-NB-error-formatting.patch:
  EDAC, MCE: Fix NB error formatting (fate#311581).
- patches.drivers/0078-amd64_edac-Fix-DIMMs-per-DCTs-output.patch:
  amd64_edac: Fix DIMMs per DCTs output (fate#309907).
- patches.drivers/0079-amd64_edac-Add-support-for-F15h-DCT-PCI-config.patch:
  amd64_edac: Add support for F15h DCT PCI config (fate#309907).
- patches.drivers/0080-amd64_edac-Remove-DRAM-base-limit-subfields-caching.patch:
  amd64_edac: Remove DRAM base/limit subfields caching
  (fate#309907).
- patches.drivers/0081-amd64_edac-Cleanup-DHAR-handling.patch:
  amd64_edac: Cleanup DHAR handling (fate#309907).
- patches.drivers/0082-amd64_edac-Cleanup-chipselect-handling.patch:
  amd64_edac: Cleanup chipselect handling (fate#309907).
- patches.drivers/0083-amd64_edac-Sanitize-channel-extraction.patch:
  amd64_edac: Sanitize channel extraction (fate#309907).
- patches.drivers/0084-amd64_edac-Sanitize-f10_get_base_addr_offset.patch:
  amd64_edac: Sanitize f10_get_base_addr_offset (fate#309907).
- patches.drivers/0085-amd64_edac-Replace-huge-bitmasks-with-a-macro.patch:
  amd64_edac: Replace huge bitmasks with a macro (fate#309907).
- patches.drivers/0086-amd64_edac-Cleanup-DBAM-handling.patch:
  amd64_edac: Cleanup DBAM handling (fate#309907).
- patches.drivers/0087-amd64_edac-Cleanup-Dram-Configuration-registers.patch:
  amd64_edac: Cleanup Dram Configuration registers (fate#309907).
- patches.drivers/0088-amd64_edac-Cleanup-DCT-Select-Low-High-code.patch:
  amd64_edac: Cleanup DCT Select Low/High code (fate#309907).
- patches.drivers/0089-amd64_edac-Cleanup-NBCTL-code.patch:
  amd64_edac: Cleanup NBCTL code (fate#309907).
- patches.drivers/0090-amd64_edac-Cleanup-NBCFG-handling.patch:
  amd64_edac: Cleanup NBCFG handling (fate#309907).
- patches.drivers/0091-amd64_edac-Cleanup-NBSH-cruft.patch:
  amd64_edac: Cleanup NBSH cruft (fate#309907).
- patches.drivers/0092-amd64_edac-Cleanup-old-defines-cruft.patch:
  amd64_edac: Cleanup old defines cruft (fate#309907).
- patches.drivers/0093-amd64_edac-Adjust-channel-counting-to-F15h.patch:
  amd64_edac: Adjust channel counting to F15h (fate#309907).
- patches.drivers/0094-amd64_edac-Simplify-decoding-path.patch:
  amd64_edac: Simplify decoding path (fate#309907).
- patches.drivers/0095-amd64_edac-Unify-get_error_address.patch:
  amd64_edac: Unify get_error_address (fate#309907).
- patches.drivers/0096-amd64_edac-Add-support-for-interleaved-region.patch:
  amd64_edac: Add support for interleaved region (fate#309907).
- patches.drivers/0097-amd64_edac-Correct-node-interleaving-removal.patch:
  amd64_edac: Correct node interleaving removal (fate#309907).
- patches.drivers/0098-amd64_edac-Fix-channel-interleave-removal.patch:
  amd64_edac: Fix channel interleave removal (fate#309907).
- patches.drivers/0099-amd64_edac-Revamp-online-spare-handling.patch:
  amd64_edac: Revamp online spare handling (fate#309907).
- patches.drivers/0100-amd64_edac-Beef-up-early-exit-reporting.patch:
  amd64_edac: Beef up early exit reporting (fate#309907).
- patches.drivers/0101-amd64_edac-Adjust-sys_addr-to-chip-select.patch:
  amd64_edac: Adjust sys_addr to chip select (fate#309907).
- patches.drivers/0102-amd64_edac-Sanitize-read_dram_ctl_register.patch:
  amd64_edac: Sanitize ->read_dram_ctl_register (fate#309907).
- patches.drivers/0103-amd64_edac-Improve-DRAM-address-mapping.patch:
  amd64_edac: Improve DRAM address mapping (fate#309907).
- patches.drivers/0104-amd64_edac-Simplify-scrubrate-setting.patch:
  amd64_edac: Simplify scrubrate setting (fate#309907).
- patches.drivers/0105-amd64_edac-Adjust-ECC-symbol-size-to-F15h.patch:
  amd64_edac: Adjust ECC symbol size to F15h (fate#309907).
- patches.drivers/0106-amd64_edac-Enable-driver-on-F15h.patch:
  amd64_edac: Enable driver on F15h (fate#309907).
- patches.drivers/0107-amd64_edac-Drop-redundant-declarations.patch:
  amd64_edac: Drop redundant declarations (fate#309907).
- patches.drivers/0108-amd64_edac-Fix-node-id-signedness.patch:
  amd64_edac: Fix node id signedness (fate#309907).
- patches.drivers/0109-amd64_edac-Fix-DRAM-base-macros.patch:
  amd64_edac: Fix DRAM base macros (fate#309907).
- patches.drivers/0110-amd64_edac-Fix-PCI-config-addressing-types.patch:
  amd64_edac: Fix PCI config addressing types (fate#309907).
- patches.drivers/0111-amd64_edac-Drop-local-variable.patch:
  amd64_edac: Drop local variable (fate#309907).
- patches.drivers/0112-amd64_edac-Fix-ranges-signedness.patch:
  amd64_edac: Fix ranges signedness (fate#309907).
- patches.drivers/0113-amd64_edac-Fix-DCT-argument-type.patch:
  amd64_edac: Fix DCT argument type (fate#309907).
- patches.drivers/0114-amd64_edac-Fix-decode_syndrome-types.patch:
  amd64_edac: Fix decode_syndrome types (fate#309907).
- patches.drivers/0115-amd64_edac-Fix-potential-memleak.patch:
  amd64_edac: Fix potential memleak (fate#309907).
- patches.drivers/0116-EDAC-Remove-debugging-output-in-scrub-rate-handling.patch:
  EDAC: Remove debugging output in scrub rate handling
  (fate#311581).
- patches.drivers/0117-amd64_edac-Remove-node-interleave-warning.patch:
  amd64_edac: Remove node interleave warning (fate#309907).
- patches.drivers/0118-amd64_edac-Factor-in-CC6-save-area.patch:
  amd64_edac: Factor in CC6 save area (fate#309907).
- patches.drivers/0119-amd64_edac-Erratum-637-workaround.patch:
  amd64_edac: Erratum #637 workaround (fate#309907).
- patches.xen/xen-compute_unit.patch: x86 backport fixup:
  compute_unit_id does not exist in Xen (fate#309722, fate#309723,
  fate#309780, fate#309781).
- patches.xen/xen-initmem_init_4_args.patch: xen amd numa:
  Adjust initmem_init to take 4 params (fate#311968 fate#309727).
- patches.xen/xen-unpriv-build: Refresh.
- patches.xen/xen-unxlate_dev_mem_ptr_adjusting.patch: xen
  ioremap: Adjust unxlate_dev_mem_ptr (FATE#310031).
- patches.xen/xen3-auto-arch-x86.diff: Refresh.
- patches.xen/xen3-auto-xen-kconfig.diff: Refresh.
- patches.xen/xen3-patch-2.6.27: Refresh.
- patches.xen/xen3-patch-2.6.31: Refresh.
- patches.xen/xen3-patch-2.6.32: Refresh.
- patches.xen/xen3-patch-2.6.32.11-12: Refresh.
- patches.xen/xen-amd-ecs: Delete.
* Sun Jun 19 2011 jdelvare@suse.de
- patches.drivers/hwmon-coretemp-add-pkgtemp-support.patch:
  Add package level thermal control in coretemp (FATE#311941,
  bnc#698797).
* Sun Jun 19 2011 dsterba@suse.cz
- patches.suse/btrfs-fix-FS_IOC_GETFLAGS-ioctl.patch: Btrfs:
  fix FS_IOC_GETFLAGS ioctl (FATE#306586).
- patches.suse/btrfs-fix-FS_IOC_SETFLAGS-ioctl.patch: Btrfs:
  fix FS_IOC_SETFLAGS ioctl (FATE#306586).
- patches.suse/btrfs-fix-easily-get-into-enospc-in-mixed-case.patch:
  Btrfs: fix easily get into ENOSPC in mixed case (FATE#306586).
- patches.suse/btrfs-prevent-oopsing-in-posix_acl_valid.patch:
  Prevent oopsing in posix_acl_valid() (FATE#306586).
- patches.suse/fs-remove-FS_COW_FL.patch: fs: remove FS_COW_FL
  (FATE#306586).
* Sun Jun 19 2011 brogers@suse.com
- patches.suse/kvm-x86-Eliminate-TS_XSAVE.patch: Refresh.
- patches.xen/xen-fpu.patch: x86: fpu and xsave changes
  (FATE#311768).
* Sat Jun 18 2011 brogers@suse.com
- patches.drivers/virtio-Add-ability-to-detach-unused-buffers-from-vr.patch:
  virtio: Add ability to detach unused buffers from vrings
  (FATE#311632).
- patches.drivers/virtio_net-Defer-skb-allocation-in-receive-path-Dat.patch:
  virtio_net: Defer skb allocation in receive path (FATE#311632).
* Sat Jun 18 2011 brogers@suse.com
- patches.suse/kvm-KVM-VMX-Inform-user-about-INTEL_TXT-dependency.patch:
  KVM: VMX: Inform user about INTEL_TXT dependency (FATE#311961).
* Sat Jun 18 2011 brogers@suse.com
- patches.suse/kvm-KVM-Activate-fpu-on-clts.patch: KVM: Activate
  fpu on clts (FATE#311768).
- patches.suse/kvm-KVM-Fix-xsave-and-xcr-save-restore-memory-leak.patch:
  KVM: Fix xsave and xcr save/restore memory leak (FATE#311768).
- patches.suse/kvm-KVM-Lazify-fpu-activation-and-deactivation.patch:
  KVM: Lazify fpu activation and deactivation (FATE#311768).
- patches.suse/kvm-KVM-VMX-Enable-XSAVE-XRSTOR-for-guest.patch:
  KVM: VMX: Enable XSAVE/XRSTOR for guest (FATE#311768).
- patches.suse/kvm-KVM-VMX-Move-some-cr-04-related-constants-to-vmx.patch:
  KVM: VMX: Move some cr[04] related constants to vmx.c
  (FATE#311768).
- patches.suse/kvm-KVM-x86-Enable-AVX-for-guest.patch: KVM: x86:
  Enable AVX for guest (FATE#311768).
- patches.suse/kvm-KVM-x86-Use-FPU-API.patch: KVM: x86: Use FPU
  API (FATE#311768).
- patches.suse/kvm-KVM-x86-Use-unlazy_fpu-for-host-FPU.patch:
  KVM: x86: Use unlazy_fpu() for host FPU (FATE#311768).
- patches.suse/kvm-KVM-x86-XSAVE-XRSTOR-live-migration-support.patch:
  KVM: x86: XSAVE/XRSTOR live migration support (FATE#311768).
- patches.suse/kvm-x86-Eliminate-TS_XSAVE.patch: x86: Eliminate
  TS_XSAVE (FATE#311768).
- patches.suse/kvm-x86-Export-FPU-API-for-KVM-use.patch: x86:
  Export FPU API for KVM use (FATE#311768).
- patches.suse/kvm-x86-Introduce-struct-fpu-and-related-API.patch:
  x86: Introduce 'struct fpu' and related API (FATE#311768).
- patches.suse/kvm-x86-fpu-Unbreak-FPU-emulation.patch: x86,
  fpu: Unbreak FPU emulation (FATE#311768).
* Sat Jun 18 2011 mgalbraith@suse.de
- bnc#692460, move misplaced return in /0 diag hack.
- patches.fixes/sched-divide-by-zero-workaround-and-diag.diff:
  Refresh.
* Fri Jun 17 2011 jbohac@suse.cz
- patches.suse/ip_local_reserved_ports.patch: net: reserve ports
  for applications using fixed port numbers (fate#310019).
- patches.suse/procps_bitmap_support.patch: sysctl: add
  proc_do_large_bitmap (fate#310019).
* Fri Jun 17 2011 rjw@suse.de
- patches.arch/printk-Allocate-kernel-log-buffer-earlier.patch:
  printk: Allocate kernel log buffer earlier v1 (bnc#700445).
* Fri Jun 17 2011 jbohac@suse.cz
- patches.suse/add-rtnetlink-init_rcvwnd.patch: Add rtnetlink
  init_rcvwnd to set the TCP initial receive window (fate#310871).
- patches.suse/tcp-bug-fix-in-initialization-of-receive-window.patch:
  tcp: Bug fix in initialization of receive window (fate#310871).
- patches.suse/tcp-increase-default-initial-receive-window.patch:
  TCP: increase default initial receive window (fate#310871).
* Fri Jun 17 2011 mmarek@novell.com
- rpm/post.sh: Touch /boot/do_purge_kernels on package install
  (fate#312018).
- rpm/postun.sh: Remove it again if it still exists on package
  uninstall.
* Fri Jun 17 2011 ptesarik@suse.cz
- patches.suse/valid_phys_addr_range-use-phys_addr_t.patch:
  valid_phys_addr_range: use phys_addr_t for the @addr parameter
  (FATE#310031).
* Fri Jun 17 2011 ptesarik@suse.cz
- patches.arch/x86-ioremap-fix-pae.patch: x86, ioremap: Fix
  incorrect physical address handling in PAE mode (FATE#310031).
- patches.fixes/dev_mem-read-write-beyond-EOF.patch: Return EOF
  on out-of-bounds read from /dev/mem (FATE#310031).
- patches.suse/dev_mem-read-write-phys_addr_t.patch: Allow
  reading/writing all memory through /dev/mem (FATE#310031).
- patches.suse/xlate_dev_mem_ptr-use-phys_addr_t.patch:
  (un)xlate_dev_mem_ptr: use phys_addr_t for the @phys parameter
  (FATE#310031).
* Fri Jun 17 2011 mgalbraith@suse.de
- Pick up missed mountpoint patch
- patches.suse/cgroupfs-create-sys-fs-cgroup-to-mount-cgroupfs-on:
  cgroupfs: create /sys/fs/cgroup to mount cgroupfs on.
* Fri Jun 17 2011 mszeredi@suse.cz
- patches.suse/shmem-put_super-must-percpu_counter_destroy.patch:
  shmem: put_super must percpu_counter_destroy (FATE#311806).
- patches.suse/tmpfs-add-accurate-compare-function-to-percpu_counte.patch:
  tmpfs: add accurate compare function to percpu_counter library
  (FATE#311806).
- patches.suse/tmpfs-make-tmpfs-scalable-with-percpu_counter-for-us.patch:
  tmpfs: make tmpfs scalable with percpu_counter for used blocks
  (FATE#311806).
* Fri Jun 17 2011 jack@suse.cz
- patches.xfs/xfs-dmapi-send_correct_flags_for_preunmount_event.patch:
  xfs: Do not always ignore preunmount events (bnc#691538).
* Thu Jun 16 2011 jack@suse.cz
  blk-cgroup & CFQ fixes since 2.6.36:
- patches.suse/blk-cgroup-Initialize-ioc-cgroup_changed-at-ioc-crea.patch:
  blk-cgroup: Initialize ioc->cgroup_changed at ioc creation time
  (fate#312039).
- patches.suse/blk-cgroup-Kill-the-header-printed-at-the-start-of-b.patch:
  blk-cgroup: Kill the header printed at the start of
  blkio.weight_device file (fate#312039).
- patches.suse/blk-cgroup-Lower-minimum-weight-from-100-to-10.patch:
  blk-cgroup: Lower minimum weight from 100 to 10 (fate#312039).
- patches.suse/blk-throttle-Use-task_subsys_state-to-determine-a-ta.patch:
  blk-cgroup: Use task_subsys_state() to determine a task's
  blkio_cgroup (fate#312039).
- patches.suse/block-cfq-compensate-preempted-queue-even-if-it-has-.patch:
  block cfq: compensate preempted queue even if it has no slice
  assigned (fate#312039).
- patches.suse/block-cfq-make-queue-preempt-work-for-queues-from-di.patch:
  block cfq: make queue preempt work for queues from different
  workload (fate#312039).
- patches.suse/block-cfq-select-new-workload-if-priority-changed.patch:
  block cfq: select new workload if priority changed
  (fate#312039).
- patches.suse/cfq-Avoid-calling-blkiocg_lookup_group-for-root-grou.patch:
  cfq: Avoid calling blkiocg_lookup_group() for root group
  (fate#312039).
- patches.suse/cfq-iosched-Don-t-update-group-weights-when-on-servi.patch:
  cfq-iosched: Don't update group weights when on service tree
  (fate#312039).
- patches.suse/cfq-iosched-Don-t-wait-if-queue-already-has-requests.patch:
  cfq-iosched: Don't wait if queue already has requests
  (fate#312039).
- patches.suse/cfq-iosched-Fix-a-possible-race-with-cfq-cgroup-remo.patch:
  cfq-iosched: Fix a possible race with cfq cgroup removal code
  (fate#312039).
- patches.suse/cfq-iosched-algebraic-simplification-in-cfq_prio_to_.patch:
  cfq-iosched: algebraic simplification in cfq_prio_to_maxrq()
  (fate#312039).
- patches.suse/cfq-iosched-don-t-schedule-a-dispatch-for-a-non-idle.patch:
  cfq-iosched: don't schedule a dispatch for a non-idle queue
  (fate#312039).
- patches.suse/cfq-iosched-free-cic_index-if-cfqd-allocation-fails.patch:
  cfq-iosched: free cic_index if cfqd allocation fails
  (fate#312039).
- patches.suse/cfq-iosched-give-busy-sync-queue-no-dispatch-limit.patch:
  cfq-iosched: give busy sync queue no dispatch limit
  (fate#312039).
- patches.suse/cfq-iosched-read_lock-does-not-always-imply-rcu_read.patch:
  cfq-iosched: read_lock() does not always imply rcu_read_lock()
  (fate#312039).
- patches.suse/cfq-iosched-schedule-dispatch-for-noidle-queue.patch:
  cfq-iosched: schedule dispatch for noidle queue (fate#312039).
- patches.suse/cfq-iosched-free-cic_index-if-cfqd-allocation-fails.patch:
  cfq-iosched: free cic_index if cfqd allocation fails (fate#312039).
* Thu Jun 16 2011 garloff@suse.de
- patches.suse/list-prefetch-optimization.diff: Do list prefetching
  and list prefetching of potential NULL ptrs depending on CPU.
* Thu Jun 16 2011 jeffm@suse.com
- patches.apparmor/apparmor-fix-null-deref-in-apparmor_bprm_set_creds:
  apparmor: Fix NULL deref in apparmor_bprm_set_creds
  (bnc#692459).
* Thu Jun 16 2011 rjw@suse.de
- patches.arch/x86-UV-BAU-fix-for-non-consecutive-nasids.patch:
  x86, UV: BAU fix for non-consecutive nasids (bnc#700401,
  fate#311784).
- patches.arch/x86-UV-correct-UV2-BAU-destination-timeout.patch:
  x86, UV: correct UV2 BAU destination timeout (bnc#699842,
  fate#311784).
- patches.arch/x86-UV-correct-reset_with_ipi.patch: x86, UV:
  correct reset_with_ipi() (bnc#700401, fate#311784).
- patches.arch/x86-UV-inline-header-file-functions.patch: x86,
  UV: inline header file functions (bnc#700401, fate#311784).
- patches.arch/x86-UV-remove-cpumask_t-from-the-stack.patch: x86,
  UV: remove cpumask_t from the stack (bnc#700401, fate#311784).
- patches.arch/x86-UV-rename-hubmask-to-pnmask.patch: x86, UV:
  rename hubmask to pnmask (bnc#700401, fate#311784).
- patches.arch/x86-UV-smp_processor_id-in-a-preemptable-region.patch:
  x86, UV: smp_processor_id in a preemptable region (bnc#700401,
  fate#311784).
- patches.arch/x86-UV-uv_tlb_c-cleanup.patch: x86, UV: uv_tlb.c
  cleanup (bnc#700401, fate#311784).
* Thu Jun 16 2011 jeffm@suse.com
- patches.drivers/0001-qlge-Eliminate-firmware-dependency-for-MPI-coredump.patch:
  qlge: Eliminate firmware dependency for MPI coredump.
- patches.drivers/0002-qlge-Changing-cpu_to_be16-to-htons-for-udp-checksum.patch:
  qlge: Changing cpu_to_be16 to htons for udp checksum.
- patches.drivers/0003-qlge-Restoring-the-promiscuous-setting-in-ql_adapter.patch:
  qlge: Restoring the promiscuous setting in ql_adapter_up.
- patches.drivers/0004-qlge-Remove-all-error-packet-flags-and-enable-tcp-ud.patch:
  qlge: Remove all error packet flags and enable tcp/udp and ip
  csum error.
- patches.drivers/0005-qlge-New-release-P24-on-Aug-18-2010-with-below-chang.patch:
  qlge: New release P24 on Aug 18 2010 with below.
- patches.drivers/0006-qlge-fix-a-eeh-handler-to-not-add-a-pending-timer.patch:
  qlge: fix a eeh handler to not add a pending timer.
- patches.drivers/0007-qlge-New-release-P25-on-Aug-17-2010-with-below-chang.patch:
- patches.drivers/0008-qlge-Restoring-the-vlan-setting-during-ql_adapter_up.patch:
  qlge: Restoring the vlan setting during ql_adapter_up.
- patches.drivers/0009-qlge-reset-the-chip-before-freeing-the-buffers.patch:
  qlge: reset the chip before freeing the buffers.
- patches.drivers/0010-qlge-Fix-a-deadlock-when-the-interface-is-going-down.patch:
  qlge: Fix a deadlock when the interface is going down.
- patches.drivers/0011-qlge-pull-NULL-check-ahead-of-dereference.patch:
  qlge: pull NULL check ahead of dereference.
- patches.drivers/0012-qlge-Generate-the-coredump-to-ethtool-user-buffer.patch:
  qlge:Generate the coredump to ethtool user buffer.
- patches.drivers/0013-qlge-New-release-P27-on-Oct-15-2010-with-below-chang.patch:
  qlge: New release P27 on Oct 15 2010 with below.
- patches.drivers/0014-qlge-Fix-deadlock-when-cancelling-worker.patch:
  qlge: Fix deadlock when cancelling worker.
* Thu Jun 16 2011 jack@suse.cz
- patches.suse/Consolidate-min-not-zero.patch: Fix malformed patch.
* Thu Jun 16 2011 trenn@suse.de
- patches.drivers/001-acpi_pad_mainline_fixes.patch: acpi_pad:
  squish warning (fate#311793).
- patches.drivers/002-acpi_pad_mainline_fixes.patch: acpi_pad:
  fix error checks (fate#311793).
- patches.drivers/003-acpi_pad_mainline_fixes.patch: acpi_pad:
  "processor_aggregator" name too long (fate#311793).
- patches.drivers/004-acpi_pad_mainline_fixes.patch: acpi_pad:
  uses MONITOR/MWAIT, so it doesn't need to clear TS_POLLING
  (fate#311793).
- patches.drivers/005-acpi_pad_mainline_fixes.patch: ACPI:
  Don't let acpi_pad needlessly mark TSC unstable (fate#311793).
- patches.drivers/006-acpi_pad_mainline_fixes.patch: ACPI:
  acpi_pad: Don't needlessly mark LAPIC unstable (fate#311793).
- patches.drivers/007-acpi_pad_mainline_fixes.patch: ACPI:
  make acpi_pad /sys output more readable (fate#311793).
* Thu Jun 16 2011 jeffm@suse.com
- patches.drivers/0001-netxen-fix-endianness-read-mac-address.patch:
  netxen: fix endianness read mac address (bnc#698269, FATE#311464).
- patches.drivers/0002-netxen-fix-endianness-intr-coalesce.patch:
  netxen: fix endianness intr coalesce (bnc#698269, FATE#311464).
- patches.drivers/0003-netxen-fix-license-header.patch: netxen:
  fix license header (bnc#698269, FATE#311464).
- patches.drivers/0004-netxen-fix-sparse-warning.patch: netxen:
  fix sparse warning (bnc#698269, FATE#311464).
- patches.drivers/0005-netxen-fix-tx-timeout-recovery-for-NX2031-chip.patch:
  netxen: fix tx timeout recovery for NX2031 chip (bnc#698269, FATE#311464).
- patches.drivers/0006-netxen-protect-resource-cleanup-by-rtnl-lock.patch:
  netxen: protect resource cleanup by rtnl lock (bnc#698269, FATE#311464).
- patches.drivers/0007-net-use-netdev_mc_count-and-netdev_mc_empty-when-app.patch:
  net: use netdev_mc_count and netdev_mc_empty when appropriate (bnc#698269, FATE#311464).
- patches.drivers/0008-net-convert-multiple-drivers-to-use-netdev_for_each_.patch:
  net: convert multiple drivers to use netdev_for_each_mc_addr,
  part5 V2 (bnc#698269, FATE#311464).
- patches.drivers/0009-netxen-The-driver-doesn-t-work-on-NX_P3_B1-so-cause-.patch:
  netxen: The driver doesn't work on NX_P3_B1 so cause probe
  to fail (bnc#698269, FATE#311464).
- patches.drivers/0010-netxen-fix-bios-version-calculation.patch:
  netxen: fix bios version calculation (bnc#698269, FATE#311464).
- patches.drivers/0011-netxen-fix-warning-in-ioaddr-for-NX3031-chip.patch:
  netxen: fix warning in ioaddr for NX3031 chip (bnc#698269, FATE#311464).
- patches.drivers/0012-netxen-added-sanity-check-for-pci-map.patch:
  netxen: added sanity check for pci map (bnc#698269, FATE#311464).
- patches.drivers/0013-netxen-fix-tx-csum-status.patch: netxen:
  fix tx csum status (bnc#698269, FATE#311464).
- patches.drivers/0014-netxen-update-version-to-4.0.73.patch:
  netxen: update version to 4.0.73 (bnc#698269, FATE#311464).
- patches.drivers/0015-netxen-fix-corner-cases-of-firmware-recovery.patch:
  netxen: fix corner cases of firmware recovery (bnc#698269, FATE#311464).
- patches.drivers/0016-netxen-validate-unified-romimage.patch:
  netxen: validate unified romimage (bnc#698269, FATE#311464).
- patches.drivers/0017-netxen-fix-fw-load-from-file.patch:
  netxen: fix fw load from file (bnc#698269, FATE#311464).
- patches.drivers/0018-netxen-fix-interrupt-for-NX2031.patch:
  netxen: fix interrupt for NX2031 (bnc#698269, FATE#311464).
- patches.drivers/0019-netxen-fix-register-usage.patch: netxen:
  fix register usage (bnc#698269, FATE#311464).
- patches.drivers/0020-netxen-remove-unnecessary-size-checks.patch:
  netxen: remove unnecessary size checks (bnc#698269, FATE#311464).
- patches.drivers/0021-netxen-to-fix-onchip-memory-access.patch:
  netxen: to fix onchip memory access (bnc#698269, FATE#311464).
- patches.drivers/0022-netxen-handle-queue-manager-access.patch:
  netxen: handle queue manager access (bnc#698269, FATE#311464).
- patches.drivers/0023-drivers-net-Remove-unnecessary-returns-from-void-fun.patch:
  drivers/net: Remove unnecessary returns from void function()s (bnc#698269, FATE#311464).
- patches.drivers/0024-netxen-fix-memory-leaks-in-error-path.patch:
  netxen: fix memory leaks in error path (bnc#698269, FATE#311464).
- patches.drivers/0025-netxen-fix-rcv-buffer-leak.patch: netxen:
  fix rcv buffer leak (bnc#698269, FATE#311464).
- patches.drivers/0026-netxen-fix-caching-window-register.patch:
  netxen: fix caching window register (bnc#698269, FATE#311464).
- patches.drivers/0027-netxen-fail-when-try-to-setup-unsupported-features.patch:
  netxen: fail when try to setup unsupported features (bnc#698269, FATE#311464).
- patches.drivers/0028-netdev-Make-ethtool_ops-set_flags-return-EINVAL-for-.patch:
  netdev: Make ethtool_ops::set_flags() return -EINVAL for
  unsupported flags (bnc#698269, FATE#311464).
- patches.drivers/0029-netxen-fix-for-kdump.patch: netxen:
  fix for kdump (bnc#698269, FATE#311464).
- patches.drivers/0030-netxen-protect-tx-timeout-recovery-by-rtnl-lock.patch:
  netxen: protect tx timeout recovery by rtnl lock (bnc#698269, FATE#311464).
- patches.drivers/0031-netxen-fix-inconsistent-lock-state.patch:
  netxen: fix inconsistent lock state (bnc#698269, FATE#311464).
- patches.drivers/0032-netxen-update-version-4.0.74.patch:
  netxen: update version 4.0.74 (bnc#698269, FATE#311464).
- patches.drivers/0033-netxen-fix-a-race-in-netxen_nic_get_stats.patch:
  netxen: fix a race in netxen_nic_get_stats() (bnc#698269, FATE#311464).
- patches.drivers/0034-netxen-fix-poll-implementation.patch:
  netxen: fix poll implementation (bnc#698269, FATE#311464).
- patches.drivers/0036-drivers-net-return-operator-cleanup.patch:
  drivers/net: return operator cleanup (bnc#698269, FATE#311464).
- patches.drivers/0037-netxen-fix-race-in-tx-stop-queue.patch:
  netxen: fix race in tx stop queue (bnc#698269, FATE#311464).
- patches.drivers/0038-netxen-mask-correctable-error.patch:
  netxen: mask correctable error (bnc#698269, FATE#311464).
- patches.drivers/0039-netxen-make-local-function-static.patch:
  netxen: make local function static (bnc#698269, FATE#311464).
- patches.drivers/0040-netxen-fix-kdump.patch: netxen: fix kdump (bnc#698269, FATE#311464).
- patches.drivers/0041-netxen_nic-Fix-the-tx-queue-manipulation-bug-in-netx.patch:
  netxen_nic: Fix the tx queue manipulation bug in
  netxen_nic_probe (bnc#698269, FATE#311464).
- patches.drivers/0042-netxen-remove-unused-firmware-exports.patch:
  netxen: remove unused firmware exports (bnc#698269, FATE#311464).
- patches.drivers/0043-netxen-avoid-using-reset_devices-as-it-may-become-ob.patch:
  netxen: avoid using reset_devices as it may become obsolete (bnc#698269, FATE#311464).
- patches.drivers/0044-drivers-net-Use-static-const.patch:
  drivers/net/*/: Use static const (bnc#698269, FATE#311464).
- patches.drivers/0045-netxen-update-module-description.patch:
  netxen: update module description (bnc#698269, FATE#311464).
- patches.drivers/0046-netxen-enable-LRO-based-on-NETIF_F_LRO.patch:
  netxen: enable LRO based on NETIF_F_LRO (bnc#698269, FATE#311464).
- patches.drivers/0047-netxen-update-driver-version-4.0.75.patch:
  netxen: update driver version 4.0.75 (bnc#698269, FATE#311464).
- patches.drivers/0048-netxen-Notify-firmware-of-Flex-10-interface-down.patch:
  netxen: Notify firmware of Flex-10 interface down (bnc#698269, FATE#311464).
- patches.drivers/0049-netxen-support-for-GbE-port-settings.patch:
  netxen: support for GbE port settings (bnc#698269, FATE#311464).
- patches.drivers/0050-net-fix-ethtool-set_flags-not-intended-EINVAL-return.patch:
  net: fix ethtool->set_flags not intended -EINVAL return value (bnc#698269, FATE#311464).
- patches.drivers/0051-drivers-net-Remove-IRQF_SAMPLE_RANDOM-flag-from-netw.patch:
  drivers/net: Remove IRQF_SAMPLE_RANDOM flag from network
  drivers (bnc#698269, FATE#311464).
- patches.drivers/0052-netxen-limit-skb-frags-for-non-tso-packet.patch:
  netxen: limit skb frags for non tso packet (bnc#698269, FATE#311464).
- patches.drivers/0053-netxen-Add-support-for-VLAN-RX-HW-acceleration.patch:
  netxen: Add support for VLAN RX HW acceleration (bnc#698269, FATE#311464).
- patches.drivers/0054-ethtool-Use-full-32-bit-speed-range-in-ethtool-s-set.patch:
  ethtool: Use full 32 bit speed range in ethtool's set_settings (bnc#698269, FATE#311464).
- patches.drivers/0055-ethtool-cosmetic-Use-ethtool-ethtool_cmd_speed-API.patch:
  ethtool: cosmetic: Use ethtool ethtool_cmd_speed API (bnc#698269, FATE#311464).
- patches.drivers/0056-netxen-suppress-false-lro-warning-messages.patch:
  netxen: suppress false lro warning messages (bnc#698269, FATE#311464).
- patches.drivers/revert-netxen-remove-references-to-unified-firmware-file:
  REVERT: netxen: Remove references to unified firmware file.
- patches.drivers/netxen-fix-for-kdump.patch: Delete.
- patches.drivers/netxen-fix-register-usage.patch: Delete.
* Thu Jun 16 2011 jjolly@suse.de
- Update config file s390/vanilla: switches from bnc#700080 not needed.
- patches.arch/s390-s11sp2-aslr.patch: kernel: add support for
  address space layout randomization (bnc#700080).
* Thu Jun 16 2011 rjw@suse.de
- patches.arch/x86-UV-Add-support-for-SGI-UV2-hub-chip.patch: x86,
  UV: Add support for SGI UV2 hub chip (bnc#699842, fate#311784).
- patches.arch/x86-UV-Enable-64-bit-ACPI-MFCG-support-for-SGI-UV2-platform-x86_uv.patch:
  x86, UV: Enable 64-bit ACPI MFCG support for SGI UV2 platform
  x86/uv (bnc#699842, fate#311784).
- patches.arch/x86-UV-Update-node-controller-MMRs.patch: x86,
  UV: Update node controller MMRs (bnc#699842, fate#311784).
* Thu Jun 16 2011 jslaby@suse.de
- patches.arch/s390-fate311851-breaking-event-addres.patch:
  Refresh.
- patches.arch/x86-ptrace-xstate-support.patch: x86, ptrace:
  regset extensions to support xstate (bnc#698803 fate#311964).
* Thu Jun 16 2011 jslaby@suse.de
- patches.arch/x86-ptrace-xstate-support.patch: x86, ptrace:
  regset extensions to support xstate (bnc#698803 fate#311964).
* Thu Jun 16 2011 jack@suse.cz
- patches.suse/ext4-rw-unsupported.patch: Fix typo in config option
* Thu Jun 16 2011 trenn@suse.de
- Update config files.
- patches.arch/001-cpuidle__fail_to_register_if_CONFIG_CPU_IDLE.patch:
  cpuidle: fail to register if !CONFIG_CPU_IDLE
  (fate#311818,fate#311942).
- patches.arch/002-cpuidle__add_cpuidle_unregister_driver_error_check.patch:
  cpuidle: add cpuidle_unregister_driver() error check
  (fate#311818,fate#311942).
- patches.arch/003-cpuidle__make_cpuidle_curr_driver_static.patch:
  cpuidle: make cpuidle_curr_driver static
  (fate#311818,fate#311942).
- patches.arch/004-ACPI__allow_a_native_cpuidle_driver_to_displace_ACPI.patch:
  ACPI: allow a native cpuidle driver to displace ACPI
  (fate#311818,fate#311942).
- patches.arch/005-intel_idle__native_hardware_cpuidle_driver_for_latest_Intel_processors.patch:
  intel_idle: native hardware cpuidle driver for latest Intel
  processors (fate#311818,fate#311942).
- patches.arch/006-intel_idle__delete_substates_DEBUG_modparam.patch:
  intel_idle: delete substates DEBUG modparam
  (fate#311818,fate#311942).
- patches.arch/007-intel_idle__delete_power_policy_modparam__and_choose_substate_functions.patch:
  intel_idle: delete power_policy modparam, and choose substate
  functions (fate#311818,fate#311942).
- patches.arch/008-intel_idle__add_support_for_Westmere-EX.patch:
  intel_idle: add support for Westmere-EX
  (fate#311818,fate#311942).
- patches.arch/009-intel_idle__disable_module_support.patch:
  intel_idle: disable module support (fate#311818,fate#311942).
- patches.arch/010-intel_idle__no_longer_EXPERIMENTAL.patch:
  intel_idle: no longer EXPERIMENTAL (fate#311818,fate#311942).
- patches.arch/011-intel_idle__recognize_Lincroft_Atom_Processor.patch:
  intel_idle: recognize Lincroft Atom Processor
  (fate#311818,fate#311942).
- patches.arch/012-intel_idle__Change_mode_755__644.patch:
  intel_idle: Change mode 755 => 644 (fate#311818,fate#311942).
- patches.arch/013-cpuidle__extend_cpuidle_and_menu_governor_to_handle_dynamic_states.patch:
  cpuidle: extend cpuidle and menu governor to handle dynamic
  states (fate#311818,fate#311942).
- patches.arch/014-intel_idle__Voluntary_leave_mm_before_entering_deeper.patch:
  intel_idle: Voluntary leave_mm before entering deeper
  (fate#311818,fate#311942).
- patches.arch/015-intel_idle__enable_Atom_C6.patch: intel_idle:
  enable Atom C6 (fate#311818,fate#311942).
- patches.arch/016-x86__mwait__Move_mwait_constants_to_a_common_header_file.patch:
  x86, mwait: Move mwait constants to a common header file
  (fate#311818,fate#311942).
- patches.arch/017-intel_idle__simplify_test_for_leave_mm.patch:
  intel_idle: simplify test for leave_mm()
  (fate#311818,fate#311942).
- patches.arch/018-intel_idle__delete_bogus_data_from_cpuidle_state_power_usage.patch:
  intel_idle: delete bogus data from cpuidle_state.power_usage
  (fate#311818,fate#311942).
- patches.arch/019-intel_idle__add_initial_Sandy_Bridge_support.patch:
  intel_idle: add initial Sandy Bridge support
  (fate#311818,fate#311942).
- patches.arch/020-intel_idle__do_not_use_the_LAPIC_timer_for_ATOM_C2.patch:
  intel_idle: do not use the LAPIC timer for ATOM C2
  (fate#311818,fate#311942).
- patches.arch/cpuidle_hotplug_use_C1_not_mwait_amd_cpu_unplug.patch:
  x86, hotplug: Fix powersavings with offlined cores on AMD
  (fate#311958).
- patches.arch/cpuidle_repeating_pattern_detector_for_menu_governor.patch:
  cpuidle: add a repeating pattern detector to the menu governor
  (fate#311789,bnc#698776).
- patches.xen/xen3-auto-common.diff: Refresh.
- patches.xen/xen3-patch-2.6.28: Refresh.
* Thu Jun 16 2011 jankit@suse.de
- patches.fixes/ses-add-subenclosure-support: ses: add
  subenclosure support (FATE# 310852).
* Thu Jun 16 2011 mmarek@novell.com
- rpm/mkspec: Fix perl warning.
* Thu Jun 16 2011 hare@suse.de
- patches.arch/x86-Introduce-pci_map_biosrom.patch: x86: Introduce
  pci_map_biosrom() (FATE#311808).
- patches.drivers/isci-add-isci_compat.h.patch: isci: add
  isci_compat.h (FATE#311808).
- patches.drivers/scsi-Include-Intel-SAS-controller-unit-SCU-driver.patch:
  Include Intel SAS controller unit (SCU) driver (FATE#311808).
- patches.xen/xen3-patch-2.6.27: Refresh.
* Thu Jun 16 2011 hare@suse.de
- libata new eh backport (FATE#311826):
  * patches.suse/ata_piix-implement-LPM-support.patch: ata_piix:
    implement LPM support (FATE#311826).
  * patches.suse/ata_piix-remove-SIDPR-locking.patch: ata_piix:
    remove SIDPR locking (FATE#311826).
  * patches.suse/libata-Add-ATA-transport-class.patch: [libata]
    Add ATA transport class (FATE#311826).
  * patches.suse/libata-add-ap-to-ata_wait_register-and-introduce.patch:
    libata: add @ap to ata_wait_register() and introduce
    ata_msleep() (FATE#311826).
  * patches.suse/libata-avoid-needlessly-passing-around-ptr-to-SCSI.patch:
    [libata] avoid needlessly passing around ptr to SCSI completion
    func (FATE#311826).
  * patches.suse/libata-clean-up-lpm-related-symbols-and-sysfs-show.patch:
    libata: clean up lpm related symbols and sysfs show/store
    functions (FATE#311826).
  * patches.suse/libata-fix-eh-locking.patch: libata: fix eh locking
    (FATE#311826).
  * patches.suse/libata-fix-hotplug-for-drivers-which-don-t-implemen.patch:
    libata: fix hotplug for drivers which don't implement LPM
    (FATE#311826).
  * patches.suse/libata-fix-locking-for-sas-paths.patch: libata:
    fix locking for sas paths (FATE#311826).
  * patches.suse/libata-host-lock-push-down.patch: SCSI host lock
    push-down (FATE#311826).
  * patches.suse/libata-implement-LPM-support-for-port-multipliers.patch:
    libata: implement LPM support for port multipliers
    (FATE#311826).
  * patches.suse/libata-implement-cross-port-EH-exclusion.patch:
    libata: implement cross-port EH exclusion (FATE#311826).
  * patches.suse/libata-implement-sata_link_scr_lpm-and-make-ata_d.patch:
    libata: implement sata_link_scr_lpm() and make
    ata_dev_set_feature() global (FATE#311826).
  * patches.suse/libata-issue-DIPM-enable-commands-with-LPM-state-up.patch:
    libata: issue DIPM enable commands with LPM state updated
    (FATE#311826).
  * patches.suse/libata-plumb-sas-port-scan-into-standard-libata-pat.patch:
    libata: plumb sas port scan into standard libata paths
    (FATE#311826).
  * patches.suse/libata-reimplement-link-power-management.patch:
    libata: reimplement link power management (FATE#311826).
  * patches.suse/libata-remove-SCSI-host-lock-and-serial-number-usa.patch:
    [libata] remove SCSI host lock and serial number usage from
    ata_scsi_queuecmd (FATE#311826).
  * patches.suse/libata-reorder-ata_queued_cmd-to-remove-alignment-p.patch:
    libata: reorder ata_queued_cmd to remove alignment padding on
    64 bit builds (FATE#311826).
  * patches.suse/libata-separate-error-handler-into-usable-component.patch:
    libata: separate error handler into usable components
    (FATE#311826).
  * patches.suse/libata-support-for-512-byte-sectors-e.g.-4K-Nat.patch:
    [libata] support for > 512 byte sectors (e.g. 4K Native)
    (FATE#311826).
- Backport libsas fixes (FATE#311826):
  * patches.suse/libsas-Add-option-for-SATA-soft-reset.patch:
    [SCSI] libsas: Add option for SATA soft reset (FATE#311826).
  * patches.suse/libsas-check-dev-gone-before-submitting-sat.patch:
    libsas: check dev->gone before submitting sata i/o
    (FATE#311826).
  * patches.suse/libsas-convert-to-libata-new-error-handler.patch:
    libsas: convert to libata new error handler
    (FATE#311826).
  * patches.suse/libsas-fix-ATAPI-check-condition-termination.patch:
    libsas: fix ATAPI check condition termination
    (FATE#311826).
  * patches.suse/libsas-fix-SATA-NCQ-error.patch: [SCSI] libsas:
    fix SATA NCQ error (FATE#311826).
  * patches.suse/libsas-fix-amend-device-gone-notification-in.patch:
    libsas: fix/amend device gone notification in
    sas_deform_port() (FATE#311826).
  * patches.suse/libsas-fix-ata-list-corruption-issue.patch:
    libsas: fix ata list corruption issue (FATE#311826).
  * patches.suse/libsas-fix-loopback-topology-bug-during-disc.patch:
    libsas: fix loopback topology bug during discovery
    (FATE#311826).
  * patches.suse/libsas-remove-spurious-sata-control-register.patch:
    libsas: remove spurious sata control register read/write
    (FATE#311826).
- patches.suse/modify-change_queue_depth-to-take-in-reason-why-it-is-being-called.patch:
  Refresh.
- patches.suse/scsi-host-lock-push-down.patch: Refresh.
* Thu Jun 16 2011 hare@suse.de
- patches.suse/Consolidate-min-not-zero.patch: Consolidate
  min_not_zero (FATE#311755).
- patches.suse/staging-hv-update-to-3.0.patch: Refresh.
* Thu Jun 16 2011 hare@suse.de
- Update DIX/DIF and Discard handling (FATE#311755):
  * patches.suse/blkdev-Do-not-return-EOPNOTSUPP-if-discard-is-supp.patch:
    blkdev: Do not return -EOPNOTSUPP if discard is supported
    (FATE#311755).
  * patches.suse/blkdev-Simple-cleanup-in-blkdev_issue_zeroout.patch:
    blkdev: Simple cleanup in blkdev_issue_zeroout() (FATE#311755).
  * patches.suse/blkdev-Submit-discard-bio-in-batches-in-blkdev_issu.patch:
    blkdev: Submit discard bio in batches in blkdev_issue_discard()
    (FATE#311755).
  * patches.suse/block-Add-sysfs-documentation-for-the-discard-topol.patch:
    block: Add sysfs documentation for the discard topology
    parameters (FATE#311755).
  * patches.suse/block-Fix-discard-topology-stacking-and-reporting.patch:
    block: Fix discard topology stacking and reporting
    (FATE#311755).
  * patches.suse/block-Fix-double-free-in-blk_integrity_unregister.patch:
    block: Fix double free in blk_integrity_unregister
    (FATE#311755).
  * patches.suse/block-Make-the-integrity-mapped-property-a-bio-flag.patch:
    block: Make the integrity mapped property a bio flag
    (FATE#311755).
  * patches.suse/block-Provide-a-limit-on-the-number-of-integri.patch:
    block: Provide a limit on the number of integrity segments
    (FATE#311755).
  * patches.suse/block-Remove-extra-discard_alignment-from-hd_struct.patch:
    block: Remove extra discard_alignment from hd_struct
    (FATE#311755).
  * patches.suse/block-Require-subsystems-to-explicitly-allocate-bio.patch:
    block: Require subsystems to explicitly allocate bio_set
    integrity mempool (FATE#311755).
  * patches.suse/block-biovec_slab-vs.-CONFIG_BLK_DEV_INTEGRITY.patch:
    block: biovec_slab vs. CONFIG_BLK_DEV_INTEGRITY (FATE#311755).
  * patches.suse/block-fix-mis-synchronisation-in-blkdev_issue_zeroo.patch:
    block: fix mis-synchronisation in blkdev_issue_zeroout()
    (FATE#311755).
  * patches.suse/block-remove-obsolete-comments-for-blkdev_issue_zer.patch:
    block: remove obsolete comments for blkdev_issue_zeroout
    (FATE#311755).
  * patches.suse/dm-Require-subsystems-to-explicitly-allocate-bio.patch:
    block: Require subsystems to explicitly allocate bio_set
    integrity mempool (FATE#311755).
  * patches.suse/dm-improve-block-integrity-support.patch: dm:
    improve block integrity support (FATE#311755).
  * patches.suse/dm-mpath-do-not-fail-paths-after-integrity-errors.patch:
    dm mpath: do not fail paths after integrity errors
    (FATE#311755).
  * patches.suse/fs-fixup-warning-part_discard_alignment_show.patch:
    fs: fixup warning part_discard_alignment_show() (FATE#311755).
  * patches.suse/libata-Signal-that-our-SATL-supports-WRITE-SAME-16.patch:
    libata: Signal that our SATL supports WRITE SAME(16) with UNMAP
    (FATE#311755).
  * patches.suse/libata-Use-Maximum-Write-Same-Length-to-report-disc.patch:
    libata: Use Maximum Write Same Length to report discard size
    limit (FATE#311755).
  * patches.suse/md-Fix-integrity-registration-error-when-no-devices.patch:
    md: Fix integrity registration error when no devices are capable
    (FATE#311755).
  * patches.suse/md-Require-subsystems-to-explicitly-allocate-bio.patch:
    md: Explicitly allocate bio_set integrity mempool (FATE#311755).
  * patches.suse/scsi-Provide-a-limit-on-the-number-of-integri.patch:
    scsi: Provide a limit on the number of integrity segments
    (FATE#311755).
  * patches.suse/scsi_debug-Convert-to-use-root_device_regist.patch:
    scsi_debug: Convert to use root_device_register()
    and root_device_unregister() (FATE#311755).
  * patches.suse/scsi_debug-Fix-32-bit-overflow-in-do_device_.patch:
    scsi_debug: Fix 32-bit overflow in do_device_access
    causing memory corruption (FATE#311755).
  * patches.suse/scsi_debug-Logical-Block-Provisioning-SBC3r.patch:
    scsi_debug: Logical Block Provisioning (SBC3r26)
    (FATE#311755).
  * patches.suse/scsi_debug-Update-thin-provisioning-support.patch:
    scsi_debug: Update thin provisioning support
    (FATE#311755).
  * patches.suse/scsi_debug-add-consecutive-medium-errors.patch:
    scsi_debug: add consecutive medium errors (FATE#311755).
  * patches.suse/scsi_debug-set-resid-to-indicate-no-data-in.patch:
    scsi_debug: set resid to indicate no data-in when medium
    error (FATE#311755).
  * patches.suse/sd-Export-effective-protection-mode-in-sysfs.patch:
    sd: Export effective protection mode in sysfs
    (FATE#311755).
  * patches.suse/sd-Fail-discard-requests-when-logical-block-provisi.patch:
    sd: Fail discard requests when logical block provisioning has
    been disabled (FATE#311755).
  * patches.suse/sd-Fix-overflow-with-big-physical-blocks.patch:
    sd: Fix overflow with big physical blocks (FATE#311755).
  * patches.suse/sd-Logical-Block-Provisioning-update.patch:
    sd: Logical Block Provisioning update (FATE#311755).
  * patches.suse/sd-Unmap-discard-alignment-needs-to-be-conve.patch:
    sd: Unmap discard alignment needs to be converted to
    bytes (FATE#311755).
  * patches.suse/sd-Update-thin-provisioning-support.patch:
    sd: Update thin provisioning support (FATE#311755).
  * patches.suse/sg-fix-a-warning-in-blk_rq_aligned-call.patch:
    sg: fix a warning in blk_rq_aligned() call (FATE#311755).
* Thu Jun 16 2011 jjolly@suse.de
- Update s390 and s390x config files.
  - Added CONFIG_CRYPTO_GHASH_S390=m
  - Added CONFIG_SMSGIUCV_EVENT=m
  - Switch HAVE_DEFAULT_NO_SPIN_MUTEXES for HAVE_ARCH_MUTEX_CPU_RELAX
- patches.arch/s390-fate311759-dasd-improve-error-recovery-for-internal-IO.patch:
  dasd: improve error recovery for internal I/O
  (bnc#700080,LTC#69437,FATE#311759).
- patches.arch/s390-fate311760-dasd-dynamic-pav-toleration.patch:
  dasd: add dynamic PAV toleration
  (bnc#700080,LTC#69441,FATE#311760).
- patches.arch/s390-fate311761-spp.patch: kernel: virtualization
  aware cpu measurement (bnc#700080,LTC#69436,FATE#311761).
- patches.arch/s390-fate311764-hypfs-bin-attrs.patch: s390_hypfs:
  Add new binary attributes (bnc#700080,LTC#69444,FATE#311764).
- patches.arch/s390-fate311850-cio_settle.patch: cio: introduce
  cio_settle (bnc#700080,LTC#69442,FATE#311850).
- patches.arch/s390-fate311851-breaking-event-addres.patch:
  kernel: Breaking-event-address for user space programs
  (bnc#700080,LTC#69457,FATE#311851).
- patches.arch/s390-fate311853-qdio-per_dev_perf_stats.patch:
  qdio: convert global statistics to per-device stats
  (bnc#700080,LTC#69447,FATE#311853).
- patches.arch/s390-fate311854-performance-indicator.patch:
  kernel: display capacity adjustment indicator in /proc/sysinfo
  (bnc#700080,LTC#69454,FATE#311854).
- patches.arch/s390-fate311855-smsgiucv-uevent.patch:
  smsgiucv_app: deliver z/VM CP special messages as uevents
  (bnc#700080,LTC#69456,FATE#311855).
- patches.arch/s390-fate311870-01-cio_chp_desc_format1.patch:
  cio: obtain mdc value per channel path
  (bnc#700080,LTC#69460,FATE#311870).
- patches.arch/s390-fate311870-02-cio-reduce-itcw-memory-consumption.patch:
  cio: reduce memory consumption of itcw structures
  (bnc#700080,LTC#69460,FATE#311870).
- patches.arch/s390-fate311870-03-dasd-zHPF-multi-track.patch:
  dasd: add High Performance FICON multitrack support
  (bnc#700080,LTC#69460,FATE#311870).
- patches.arch/s390-fate311871-qeth-hw-tx-checksum.patch: qeth:
  exploit HW TX checksumming (bnc#700080,LTC#69471,FATE#311871).
- patches.arch/s390-fate311873-dasd-raw-track-access.patch:
  dasd: Add support for raw ECKD access
  (bnc#700080,LTC#69504,FATE#311873).
- patches.arch/s390-fate311874-01-cio_unit_check_handling.patch:
  cio: unit check handling during internal I/O
  (bnc#700080,LTC#69464,FATE#311874).
- patches.arch/s390-fate311874-02-dasd_unit_check_handling.patch:
  dasd: Add dasd part of cio internal unit check handling
  (bnc#700080,LTC#69464,FATE#311874).
- patches.arch/s390-fate311875-01-cio_add_siosl_support.patch:
  cio: add CHSC SIOSL Support (bnc#700080,LTC#69461,FATE#311875).
- patches.arch/s390-fate311875-02-zfcp_add_siosl_support.patch:
  zfcp: Trigger logging in FCP channel on qdio error conditions
  (bnc#700080,LTC#69461,FATE#311875).
- patches.arch/s390-fate311876-cio_improve_resume_handling.patch:
  cio: improve resume handling (bnc#700080,LTC#69463,FATE#311876).
- patches.arch/s390-fate311878-dasd-automatic-recognition-of-read-only-device.patch:
  dasd: automatic recognition of read-only devices
  (bnc#700080,LTC#69465,FATE#311878).
- patches.arch/s390-fate311880-dasd-tunable-mih.patch: dasd:
  Add tunable default grace period for missing interrupts
  (bnc#700080,LTC#69466,FATE#311880).
- patches.arch/s390-fate311890-01-qdio-napi.patch: qdio: extend
  API to allow polling (bnc#700080,LTC#69474,FATE#311890).
- patches.arch/s390-fate311890-02-qeth-napi.patch:
  qeth: NAPI support for l2 and l3 discipline
  (bnc#700080,LTC#69474,FATE#311890).
- patches.arch/s390-fate311892-qeth-olm-message.patch:
  qeth (new function): tolerate OLM-limitation
  (bnc#700080,LTC#69475,FATE#311892).
- patches.arch/s390-fate311897-zfcpdump-mkdump-prefix.patch:
  zfcpdump: Add prefix registers to dump header
  (bnc#700080,LTC#69493,FATE#311897).
- patches.arch/s390-fate311899-qeth-vlan-null.patch:
  qeth: support for priority tags and VLAN-ID 0 tags
  (bnc#700080,LTC#69476,FATE#311899).
- patches.arch/s390-fate311901-01-zcrypt-check-4k-support.patch:
  zcrypt: Introduce check for 4096 bit support
  (bnc#700080,LTC#69502,FATE#311901).
- patches.arch/s390-fate311901-02-cex3-4096-bit-keys-cex3a.patch:
  zcrypt: support for 4096 bit keys for cex3a
  (bnc#700080,LTC#69502,FATE#311901).
- patches.arch/s390-fate311901-03-cex3-4096-bit-keys-cex3c.patch:
  zcrypt: support for 4096 bit keys for cex3c
  (bnc#700080,LTC#69502,FATE#311901).
- patches.arch/s390-fate311901-04-cex3-cca-restriction.patch:
  zcrypt: cope with cca restriction of cex3
  (bnc#700080,LTC#69502,FATE#311901).
- patches.arch/s390-fate311901-05-zcrypt-4k-crt.patch:
  zcrypt: handling of 4096 bit RSA keys in CRT format
  (bnc#700080,LTC#69502,FATE#311901).
- patches.arch/s390-fate311905-dasd-provide-a-Sense-Path-Group-ID-ioctl.patch:
  dasd: provide a Sense Path Group ID ioctl
  (bnc#700080,LTC#69468,FATE#311905).
- patches.arch/s390-fate311906-dasd-handle-steal-lock-unit-check.patch:
  dasd: Improve handling of stolen DASD reservation
  (bnc#700080,LTC#69470,FATE#311906).
- patches.arch/s390-fate311911-cio-dasd-chpid-reconfig-handling.patch:
  cio, dasd: notify drivers of channel path events
  (bnc#700080,LTC#69675,FATE#311911).
- patches.arch/s390-fate311913-chsc_process_chp_availability_information.patch:
  chsc: process channel-path-availability information
  (bnc#700080,LTC#69685,FATE#311913).
- patches.arch/s390-fate311917-qeth-defaults.patch: qeth: change
  some configurations defaults (bnc#700080,LTC#69687,FATE#311917).
- patches.arch/s390-fate311920-get-cpc-name.patch: kernel:
  Get CPC name (bnc#700080,LTC#69688,FATE#311920).
- patches.arch/s390-fate311922-qeth-qetharp-ipv6.patch:
  qeth: support ipv6 for query arp cache for HiperSockets
  (bnc#700080,LTC#69677,FATE#311922).
- patches.arch/s390-fate311924-crypto-z196.patch: crypto:
  Exploit z196 hardware accelerated crypto algorithms
  (bnc#700080,LTC#69682,FATE#311924).
- patches.arch/s390-fate312075-mutex_spin.patch: mutex: Introduce
  arch_mutex_cpu_relax() (bnc#700080,LTC#70031,FATE#312075).
- Patches refreshed due to changes made by s390 patches:
  - patches.fixes/Fix-various-typos-of-valid-in-comments.patch:
  - patches.suse/block-Consolidate-phys_segment-and-hw_segment-limit.patch:
  - patches.suse/block-Rename-blk_queue_max_sectors-to-blk_queue_max.patch:
  - patches.suse/perf-0001-Single-patch-that-merges-f4c4176-into-sles11.patch:
  - patches.xen/xen3-patch-2.6.30: Refresh.
* Thu Jun 16 2011 hare@suse.de
- Set PCI_LABEL=y in all config files.
* Thu Jun 16 2011 mgalbraith@suse.de
- patches.suse/topology-s390-Set-SCHED_BOOK-Y-in-defconfig:
  [S390] topology: Set CONFIG_SCHED_BOOK=y in arch/s390/defconfig (FATE#311860, bnc#698524).
* Thu Jun 16 2011 hare@suse.de
- SCSI host lock push-down (FATE#311826):
  * patches.suse/libfc-host-lock-push-down.patch
  * patches.suse/libiscsi-host-lock-push-down.patch
  * patches.suse/scsi-host-lock-push-down.patch
  * patches.suse/staging-hv-host-lock-push-down.patch
  * patches.suse/xen-host-lock-push-down.patch
* Thu Jun 16 2011 hare@suse.de
- Backport detailed I/O errors:
  * patches.suse/block-improve-detail-in-I-O-error-messages.patch:
    block: improve detail in I/O error messages (FATE#311692).
  * patches.suse/dm-mpath-propagate-target-errors-immediately.patch:
    dm mpath: propagate target errors immediately (FATE#311692).
  * patches.suse/scsi-Add-detailed-SCSI-I-O-errors.patch: Add
    detailed SCSI I/O errors (FATE#311692).
  * patches.suse/dm-mpath-evaluate-request-result-and-sense: Delete.
* Wed Jun 15 2011 rjw@suse.de
- patches.drivers/PCI-Export-ACPI_DSM-provided-firmware-instance-number-and-string-name-to-sysfs.patch:
  PCI: Export ACPI _DSM provided firmware instance number and
  string name to sysfs (bnc#697944, fate#311158).
- patches.drivers/PCI-label-Fix-compilation-error-when-CONFIG_ACPI-is-unset.patch:
  PCI: label: Fix compilation error when CONFIG_ACPI is unset
  (bnc#697944, fate#311158).
- patches.drivers/PCI-label-remove-include-of-ACPI-header-to-avoid-warnings.patch:
  PCI: label: remove #include of ACPI header to avoid warnings
  (bnc#697944, fate#311158).
- patches.drivers/PCI-pci-label-Fix-build-failure-when-CONFIG_NLS-is-set-to-m-by-allmodconfig.patch:
  PCI: pci-label: Fix build failure when CONFIG_NLS is set to
  'm' by allmodconfig (bnc#697944, fate#311158).
* Wed Jun 15 2011 rjw@suse.de
- patches.arch/x86_PCI-Preserve-existing-pci_bfsort-whitelist-for-Dell-systems.patch:
  x86/PCI: Preserve existing pci=bfsort whitelist for Dell systems
  (bnc#697942, fate#311159).
* Wed Jun 15 2011 jack@suse.cz
- patches.suse/ext4-rw-unsupported.patch: Make ext4 mounts
  read-only unless proper config option is specified
  (fate#311111).
- supported.conf: Make restricted ext4 module supported
* Wed Jun 15 2011 ohering@suse.de
- patches.suse/staging-hv-update-to-3.0.patch
  Update hyperv drivers to current mainline state (bnc#662432).
- patches.xen/xen3-patch-2.6.32: Refresh.
* Wed Jun 15 2011 dsterba@suse.cz
- series.conf: move btrfs patches to the proper section
- patches.fixes/writeback-fix-sb-locking.diff: Refresh.
- patches.suse/writeback-add-new-functions-for-triggering-inode-writeback.patch:
  Refresh.
* Wed Jun 15 2011 jack@suse.cz
- patches.fixes/novfs-minsize-fixes: "Unable to save Login Script"
  appears when trying to save a user login script (bnc#638985).
* Wed Jun 15 2011 jack@suse.cz
- patches.fixes/novfs-copy_user-fixes.diff: fs: novfs: Limit
  check for datacopy between user and kernel space.
* Wed Jun 15 2011 hare@suse.de
- Reshuffle block layer patches:
  * patches.suse/Fix-regression-in-direct-writes-performance-due-to-W.patch
  * patches.suse/blkdev-generalize-flags-for-blkdev_issue_fn-functio.patch
  * patches.suse/block-get-rid-of-the-WRITE_ODIRECT-flag.patch
  * patches.suse/block-unify-flags-for-struct-bio-and-struct-request.patch
  * patches.suse/gfs2-replace-barriers-with-explicit-flush-FUA-usa.patch
  * patches.xfs/xfs-improve-metadata-I-O-merging-in-the-elevator.patch
- Split off hunks to apply cleanly:
  * patches.suse/btrfs-unify-flags-for-struct-bio-and-struct-request.patch
  * patches.suse/ocfs2-generalize-flags-for-blkdev_issue_fn-functio.patch
- Block layer fixes and improvements from mainline (FATE#311692):
  * patches.suse/blktrace-Remove-blk_fill_rwbs_rq.patch: blktrace:
    Remove blk_fill_rwbs_rq (FATE#311692).
  * patches.suse/block-Fix-race-during-disk-initialization.patch:
    block: Fix race during disk initialization (FATE#311692).
  * patches.suse/block-add-REQ_FLUSH_SEQ.patch: block: add
    REQ_FLUSH_SEQ (FATE#311692).
  * patches.suse/block-block_dump-Add-number-of-sectors-to-debug-ou.patch:
    block: block_dump: Add number of sectors to debug output
    (FATE#311692).
  * patches.suse/block-fix-an-address-space-warning-in-blk-map.c.patch:
    block: fix an address space warning in blk-map.c (FATE#311692).
  * patches.suse/block-improve-flush-bio-completion.patch: block:
    improve flush bio completion (FATE#311692).
  * patches.suse/block-max-hardware-sectors-limit-wrapper.patch:
    block: max hardware sectors limit wrapper (FATE#311692).
  * patches.suse/block-reimplement-FLUSH-FUA-to-support-merge.patch:
    block: reimplement FLUSH/FUA to support merge (FATE#311692).
  * patches.suse/block-remove-BLKDEV_IFL_WAIT.patch: block: remove
    BLKDEV_IFL_WAIT (FATE#311488).
  * patches.suse/block-share-request-flush-fields-with-elevator_pri.patch:
    block: share request flush fields with  elevator_private
    (FATE#311692).
  * patches.suse/block-skip-elevator-data-initialization-for-flush-r.patch:
    block: skip elevator data initialization for flush requests
    (FATE#311692).
  * patches.suse/btrfs-remove-BLKDEV_IFL_WAIT.patch: block: remove
    BLKDEV_IFL_WAIT (FATE#311488).
  * patches.suse/ext4-remove-BLKDEV_IFL_WAIT.patch: block: remove
    BLKDEV_IFL_WAIT (FATE#311488).
  * patches.suse/ocfs2-remove-BLKDEV_IFL_WAIT.patch: block: remove
    BLKDEV_IFL_WAIT (FATE#311488).
  * patches.suse/swapfile-remove-BLKDEV_IFL_WAIT.patch: block:
    remove BLKDEV_IFL_WAIT (FATE#311488).
* Wed Jun 15 2011 jbeulich@novell.com
- Update i386/xen config file (disable IPMI and EDAC).
* Wed Jun 15 2011 mhocko@suse.cz
- patches.fixes/memcg-skip-charging-if-fatal-signal-is-pending-fix.patch:
  memcg: Put controller reference when bypassing charging due
  to fatal signal (bnc#700009).
* Wed Jun 15 2011 jbeulich@novell.com
- Update Xen patches to c/s 1092.
- patches.xen/xen3-2009-10-12-0003-x86-Export-k8-physical-topology.patch:
  x86: Export k8 physical topology (fate#311968, disabled).
- patches.xen/xen3-block-deprecate-barrier-and-replace-blk_queue_order.patch:
  block: deprecate barrier and replace blk_queue_ordered()
  with blk_queue_flush() (FATE#311692).
- patches.xen/xen3-block-remove-REQ_HARDBARRIER.patch: block:
  remove REQ_HARDBARRIER (FATE#311692).
- patches.xen/xen3-block-remove-q-prepare_flush_fn-completely.patch:
  block: remove q->prepare_flush_fn completely (FATE#311692).
- patches.xen/xen3-block-remove-the-WRITE_BARRIER-flag.patch:
  block: remove the WRITE_BARRIER flag (FATE#311692).
- patches.xen/xen3-block-remove-wrappers-for-request-type-flags.patch:
  block: remove wrappers for request type/flags (FATE#311692).
- patches.xen/xen3-block-unify-flags-for-struct-bio-and-struct-request.patch:
  block: unify flags for struct bio and struct request
  (FATE#311692).
- patches.xen/xen3-ibft-x86-Change-reserve_ibft_region-to-find_ibft.patch:
  ibft, x86: Change reserve_ibft_region() to find_ibft_region()
  (FATE#311488).
- patches.xen/xen3-perf-0001-Single-patch-that-merges-f4c4176-into-sles11.patch:
  Single patch that merges f4c4176 into sles11 (FATE#311392,
  BNC#685313).
- patches.xen/xen-blkback-bimodal-suse: Delete.
- patches.xen/xen-change-reserve_ibft_region-to-find_ibft.patch:
  Delete.
- patches.xen/xen-deprecate-barrier-fixup: Delete.
- patches.xen/xen-perf-2.6.33.patch: Delete.
* Wed Jun 15 2011 trenn@suse.de
- patches.arch/x86_apic_use_apic_printk_for_spurious_error_interrupts.patch:
  x86, apic: Print verbose error interrupt reason on apic=debug
  (bnc#698949,fate#311990).
* Wed Jun 15 2011 trenn@suse.de
  Remove 2 unrelated/unneeded patches from EDAC series and fix
  i7core EDAC driver to work with XEN:
- patches.drivers/edac_i7core_phys_proc_id_use_socketid.patch:
  EDAC i7core: Use mce socketid for better compatibility
  (fate#311968).
- patches.xen/xen3-patch-2.6.24: Refresh.
* Wed Jun 15 2011 jack@suse.cz
- patches.suse/laptop-mode-Make-flushes-per-device.patch: Refresh.
* Tue Jun 14 2011 jack@suse.cz
- patches.suse/writeback-add-new-functions-for-triggering-inode-writeback.patch:
  Refresh.
* Tue Jun 14 2011 mmarek@suse.cz
- patches.fixes/0001-genksyms-properly-consider-EXPORT_UNUSED_SYMBOL-_GPL.patch:
  genksyms: properly consider  EXPORT_UNUSED_SYMBOL{,_GPL}().
- patches.fixes/0002-genksyms-close-ref_file-after-use.patch:
  genksyms: close ref_file after use.
- patches.fixes/0003-scripts-genksyms-fix-header-usage.patch:
  scripts/genksyms: fix header usage.
- patches.fixes/0004-genksyms-Do-not-paste-the-bison-header-file-to-lex.c.patch:
  genksyms: Do not paste the bison header file to lex.c.
- patches.fixes/0005-genksyms-Simplify-lexer.patch: genksyms:
  Simplify lexer.
- patches.fixes/0006-genksyms-Simplify-printing-of-symbol-types.patch:
  genksyms: Simplify printing of symbol types.
- patches.fixes/0007-genksyms-Add-helpers-for-building-string-lists.patch:
  genksyms: Add helpers for building string lists.
- patches.fixes/0008-genksyms-simplify-usage-of-find_symbol.patch:
  genksyms: simplify usage of find_symbol().
- patches.fixes/0009-genksyms-Track-changes-to-enum-constants.patch:
  genksyms: Track changes to enum constants.
- patches.fixes/0010-genksyms-Regenerate-lexer-and-parser.patch:
  genksyms: Regenerate lexer and parser.
* Tue Jun 14 2011 jeffm@suse.com
- Update config files: Enable QLCNIC.
- patches.drivers/0001-qlcnic-Qlogic-ethernet-driver-for-CNA-devices.patch:
  qlcnic: Qlogic ethernet driver for CNA devices (bnc#698272, FATE#311468).
- patches.drivers/0002-qlcnic-use-DEFINE_PCI_DEVICE_TABLE.patch:
  qlcnic: use DEFINE_PCI_DEVICE_TABLE (bnc#698272, FATE#311468).
- patches.drivers/0003-qlcnic-add-ethernet-identifier-in-board-info.patch:
  qlcnic: add ethernet identifier in board info (bnc#698272, FATE#311468).
- patches.drivers/0004-qlcnic-clear-device-reset-state-after-fw-recovery.patch:
  qlcnic: clear device reset state after fw recovery (bnc#698272, FATE#311468).
- patches.drivers/0005-qlcnic-protect-resoruce-cleanup-by-rtnl-lock.patch:
  qlcnic: protect resoruce cleanup by rtnl lock (bnc#698272, FATE#311468).
- patches.drivers/0006-qlcnic-support-LED-blink-for-device-identification.patch:
  qlcnic: support LED blink for device identification (bnc#698272, FATE#311468).
- patches.drivers/0007-qlcnic-add-interrupt-diagnostic-test.patch:
  qlcnic: add interrupt diagnostic test (bnc#698272, FATE#311468).
- patches.drivers/0008-qlcnic-add-loopback-diagnostic-test.patch:
  qlcnic: add loopback diagnostic test (bnc#698272, FATE#311468).
- patches.drivers/0009-net-use-netdev_mc_count-and-netdev_mc_empty-when-app.patch:
  net: use netdev_mc_count and netdev_mc_empty when appropriate (bnc#698272, FATE#311468).
- patches.drivers/0010-net-convert-multiple-drivers-to-use-netdev_for_each_.patch:
  net: convert multiple drivers to use netdev_for_each_mc_addr,
  part5 V2 (bnc#698272, FATE#311468).
- patches.drivers/0011-qlcnic-fix-tx-csum-status.patch: qlcnic:
  fix tx csum status (bnc#698272, FATE#311468).
- patches.drivers/0012-qlcnic-additional-driver-statistics.patch:
  qlcnic: additional driver statistics (bnc#698272, FATE#311468).
- patches.drivers/0013-qlcnic-fix-multicast-handling.patch:
  qlcnic: fix multicast handling (bnc#698272, FATE#311468).
- patches.drivers/0014-qlcnic-validate-unified-fw-image.patch:
  qlcnic: validate unified fw image (bnc#698272, FATE#311468).
- patches.drivers/0015-qlcnic-fix-bios-version-check.patch:
  qlcnic: fix bios version check (bnc#698272, FATE#311468).
- patches.drivers/0016-qlcnic-remove-extra-space-from-board-names.patch:
  qlcnic: remove extra space from board names (bnc#698272, FATE#311468).
- patches.drivers/0017-qlcnic-fix-fw-load-from-file.patch:
  qlcnic: fix fw load from file (bnc#698272, FATE#311468).
- patches.drivers/0018-qlcnic-handle-queue-manager-access.patch:
  qlcnic: handle queue manager access (bnc#698272, FATE#311468).
- patches.drivers/0019-qlcnic-update-oncard-memory-size-check.patch:
  qlcnic: update oncard memory size check (bnc#698272, FATE#311468).
- patches.drivers/0020-qlcnic-fix-onchip-memory-access.patch:
  qlcnic: fix onchip memory access (bnc#698272, FATE#311468).
- patches.drivers/0021-qlcnic-use-IDC-defined-timeout-value.patch:
  qlcnic: use IDC defined timeout value (bnc#698272, FATE#311468).
- patches.drivers/0022-qlcnic-add-driver-debug-support.patch:
  qlcnic: add driver debug support (bnc#698272, FATE#311468).
- patches.drivers/0023-qlcnic-fix-interface-attach-sequence.patch:
  qlcnic: fix interface attach sequence (bnc#698272, FATE#311468).
- patches.drivers/0024-qlcnic-fix-endianness-in-fw-validation.patch:
  qlcnic: fix endianness in fw validation (bnc#698272, FATE#311468).
- patches.drivers/0025-qlcnic-update-version-to-5.0.1.patch:
  qlcnic: update version to 5.0.1 (bnc#698272, FATE#311468).
- patches.drivers/0026-qlcnic-fix-set-mac-addr.patch: qlcnic:
  fix set mac addr (bnc#698272, FATE#311468).
- patches.drivers/0027-qlcnic-additional-driver-statistics.patch:
  qlcnic: additional driver statistics (bnc#698272, FATE#311468).
- patches.drivers/0028-qlcnic-fix-defines-as-per-IDC-document.patch:
  qlcnic: fix defines as per IDC document (bnc#698272, FATE#311468).
- patches.drivers/0029-qlcnic-fix-fw-initialization-responsibility.patch:
  qlcnic: fix fw initialization responsibility (bnc#698272, FATE#311468).
- patches.drivers/0030-qlcnic-define-macro-for-driver-state.patch:
  qlcnic: define macro for driver state (bnc#698272, FATE#311468).
- patches.drivers/0031-qlcnic-fix-pci-semaphore-checks.patch:
  qlcnic: fix pci semaphore checks (bnc#698272, FATE#311468).
- patches.drivers/0032-qlcnic-fix-rcv-buffer-leak.patch: qlcnic:
  fix rcv buffer leak (bnc#698272, FATE#311468).
- patches.drivers/0033-qlcnic-protect-resource-access.patch:
  qlcnic: protect resource access (bnc#698272, FATE#311468).
- patches.drivers/0034-qlcnic-update-version-5.0.2.patch: qlcnic:
  update version 5.0.2 (bnc#698272, FATE#311468).
- patches.drivers/0035-drivers-net-Remove-unnecessary-returns-from-void-fun.patch:
  drivers/net: Remove unnecessary returns from void function()s (bnc#698272, FATE#311468).
- patches.drivers/0036-qlcnic-fix-context-cleanup.patch: qlcnic:
  fix context cleanup (bnc#698272, FATE#311468).
- patches.drivers/0037-qlcnic-remove-obsolete-register.patch:
  qlcnic: remove obsolete register (bnc#698272, FATE#311468).
- patches.drivers/0038-qlcnic-fix-caching-window-register.patch:
  qlcnic: fix caching window register (bnc#698272, FATE#311468).
- patches.drivers/0039-qlcnic-cleanup-dma-mask-setting.patch:
  qlcnic: cleanup dma mask setting (bnc#698272, FATE#311468).
- patches.drivers/0040-qlcnic-cleanup-unused-code.patch: qlcnic:
  cleanup unused code (bnc#698272, FATE#311468).
- patches.drivers/0041-qlcnic-check-IDC-version.patch: qlcnic:
  check IDC version (bnc#698272, FATE#311468).
- patches.drivers/0042-qlcnic-check-device-class.patch: qlcnic:
  check device class (bnc#698272, FATE#311468).
- patches.drivers/0043-qlcnic-support-quisce-mode.patch: qlcnic:
  support quisce mode (bnc#698272, FATE#311468).
- patches.drivers/0044-qlcnic-add-idc-debug-registers.patch:
  qlcnic: add idc debug registers (bnc#698272, FATE#311468).
- patches.drivers/0045-qlcnic-fix-memory-leaks.patch: qlcnic:
  fix memory leaks (bnc#698272, FATE#311468).
- patches.drivers/0046-qlcnic-change-adapter-name-display.patch:
  qlcnic: change adapter name display (bnc#698272, FATE#311468).
- patches.drivers/0047-qlcnic-fix-rx-bytes-statistics.patch:
  qlcnic: fix rx bytes statistics (bnc#698272, FATE#311468).
- patches.drivers/0048-qlcnic-module-param-for-firmware-load-option.patch:
  qlcnic: module param for firmware load option (bnc#698272, FATE#311468).
- patches.drivers/0049-qlcnic-fix-internal-loopback-test.patch:
  qlcnic: fix internal loopback test (bnc#698272, FATE#311468).
- patches.drivers/0050-qlcnic-remove-unused-register.patch:
  qlcnic: remove unused register (bnc#698272, FATE#311468).
- patches.drivers/0051-qlcnic-mark-device-state-fail.patch:
  qlcnic: mark device state fail (bnc#698272, FATE#311468).
- patches.drivers/0052-qlcnic-NIC-Partitioning-Add-basic-infrastructure-sup.patch:
  qlcnic: NIC Partitioning - Add basic infrastructure support (bnc#698272, FATE#311468).
- patches.drivers/0053-qlcnic-NIC-Partitioning-Add-non-privileged-mode-supp.patch:
  qlcnic: NIC Partitioning - Add non privileged mode support (bnc#698272, FATE#311468).
- patches.drivers/0054-qlcnic-Fix-Compilation-Issue-when-CONFIG_INET-was-no.patch:
  qlcnic: Fix Compilation Issue when CONFIG_INET was not set (bnc#698272, FATE#311468).
- patches.drivers/0055-qlcnic-Fix-a-bug-in-setting-up-NIC-partitioning-mode.patch:
  qlcnic: Fix a bug in setting up NIC partitioning mode (bnc#698272, FATE#311468).
- patches.drivers/0056-qlcnic-Bumped-up-version-number.patch:
  qlcnic: Bumped up version number (bnc#698272, FATE#311468).
- patches.drivers/0057-qlcnic-fix-device-soft-reset.patch:
  qlcnic: fix device soft reset (bnc#698272, FATE#311468).
- patches.drivers/0058-qlcnic-change-driver-description.patch:
  qlcnic: change driver description (bnc#698272, FATE#311468).
- patches.drivers/0059-qlcnic-seperate-interrupt-for-TX.patch:
  qlcnic: seperate interrupt for TX (bnc#698272, FATE#311468).
- patches.drivers/0060-qlcnic-fix-race-in-tx-stop-queue.patch:
  qlcnic: fix race in tx stop queue (bnc#698272, FATE#311468).
- patches.drivers/0061-qlcnic-fix-register-access.patch: qlcnic:
  fix register access (bnc#698272, FATE#311468).
- patches.drivers/0062-qlcnic-cleanup-skb-allocation.patch:
  qlcnic: cleanup skb allocation (bnc#698272, FATE#311468).
- patches.drivers/0063-qlcnic-handshake-with-card-after-fw-load.patch:
  qlcnic: handshake with card after fw load (bnc#698272, FATE#311468).
- patches.drivers/0064-qlcnic-fix-mac-address-mgmt.patch: qlcnic:
  fix mac address mgmt (bnc#698272, FATE#311468).
- patches.drivers/0065-qlcnic-release-device-resources-during-interface-dow.patch:
  qlcnic: release device resources during interface down (bnc#698272, FATE#311468).
- patches.drivers/0066-qlcnic-dont-free-host-resources-during-fw-recovery.patch:
  qlcnic: dont free host resources during fw recovery (bnc#698272, FATE#311468).
- patches.drivers/0067-qlcnic-offload-tx-timeout-recovery.patch:
  qlcnic: offload tx timeout recovery (bnc#698272, FATE#311468).
- patches.drivers/0068-qlcnic-mark-context-state-freed-after-destroy.patch:
  qlcnic: mark context state freed after destroy (bnc#698272, FATE#311468).
- patches.drivers/0069-qlcnic-update-version-to-5.0.6.patch:
  qlcnic: update version to 5.0.6 (bnc#698272, FATE#311468).
- patches.drivers/0070-qlcnic-fail-when-try-to-setup-unsupported-features.patch:
  qlcnic: fail when try to setup unsupported features (bnc#698272, FATE#311468).
- patches.drivers/0071-qlcnic-Remove-obsolete-code.patch: qlcnic:
  Remove obsolete code (bnc#698272, FATE#311468).
- patches.drivers/0072-qlcnic-Add-support-for-configuring-eswitch-and-npars.patch:
  qlcnic: Add support for configuring eswitch and npars (bnc#698272, FATE#311468).
- patches.drivers/0073-netdev-Make-ethtool_ops-set_flags-return-EINVAL-for-.patch:
  netdev: Make ethtool_ops::set_flags() return -EINVAL for
  unsupported flags (bnc#698272, FATE#311468).
- patches.drivers/0074-qlcnic-Check-FW-capability-for-TSO.patch:
  qlcnic: Check FW capability for TSO (bnc#698272, FATE#311468).
- patches.drivers/0075-qlcnic-Disable-admin-tools-interface-for-VF-driver-m.patch:
  qlcnic: Disable admin tools interface for VF driver mode (bnc#698272, FATE#311468).
- patches.drivers/0076-qlcnic-fix-pause-params-setting.patch:
  qlcnic: fix pause params setting (bnc#698272, FATE#311468).
- patches.drivers/0077-qlcnic-disable-tx-timeout-recovery.patch:
  qlcnic: disable tx timeout recovery (bnc#698272, FATE#311468).
- patches.drivers/0078-qlcnic-fix-netdev-notifier-in-error-path.patch:
  qlcnic: fix netdev notifier in error path (bnc#698272, FATE#311468).
- patches.drivers/0079-qlcnic-aer-support.patch: qlcnic:
  aer support (bnc#698272, FATE#311468).
- patches.drivers/0080-qlcnic-restore-NPAR-config-data-after-recovery.patch:
  qlcnic: restore NPAR config data after recovery (bnc#698272, FATE#311468).
- patches.drivers/0081-qlcnic-fix-pci-resource-leak.patch:
  qlcnic: fix pci resource leak (bnc#698272, FATE#311468).
- patches.drivers/0082-qlcnic-fix-copyright-for-pci-searching-function.patch:
  qlcnic: fix copyright for pci searching function (bnc#698272, FATE#311468).
- patches.drivers/0083-qlcnic-fix-bandwidth-check.patch: qlcnic:
  fix bandwidth check (bnc#698272, FATE#311468).
- patches.drivers/0084-qlcnic-fix-loopback-test.patch: qlcnic:
  fix loopback test (bnc#698272, FATE#311468).
- patches.drivers/0085-qlcnic-fix-diag-resource-allocation.patch:
  qlcnic: fix diag resource allocation (bnc#698272, FATE#311468).
- patches.drivers/0086-qlcnic-clean-up-qlcnic_init_pci_info.patch:
  qlcnic: clean up qlcnic_init_pci_info() (bnc#698272, FATE#311468).
- patches.drivers/0087-qlcnic-using-too-much-stack.patch: qlcnic:
  using too much stack (bnc#698272, FATE#311468).
- patches.drivers/0088-qlcnic-fix-aer-for-virtual-func.patch:
  qlcnic: fix aer for virtual func (bnc#698272, FATE#311468).
- patches.drivers/0089-qlcnic-device-state-management-fixes-for-virtual-fun.patch:
  qlcnic: device state management fixes for virtual func (bnc#698272, FATE#311468).
- patches.drivers/0090-qlcnic-fix-for-setting-function-modes.patch:
  qlcnic: fix for setting function modes (bnc#698272, FATE#311468).
- patches.drivers/0091-qlcnic-add-eswitch-statistics-support.patch:
  qlcnic: add eswitch statistics support (bnc#698272, FATE#311468).
- patches.drivers/0092-qlcnic-fix-link-status-message.patch:
  qlcnic: fix link status message (bnc#698272, FATE#311468).
- patches.drivers/0093-qlcnic-fix-link-diag-test.patch: qlcnic:
  fix link diag test (bnc#698272, FATE#311468).
- patches.drivers/0094-qlcnic-turn-off-lro-when-rxcsum-is-disabled.patch:
  qlcnic: turn off lro when rxcsum is disabled (bnc#698272, FATE#311468).
- patches.drivers/0095-drivers-net-qlcnic-Use-available-error-codes.patch:
  drivers/net/qlcnic: Use available error codes (bnc#698272, FATE#311468).
- patches.drivers/0096-qlcnic-fix-inconsistent-lock-state.patch:
  qlcnic: fix inconsistent lock state (bnc#698272, FATE#311468).
- patches.drivers/0097-qlcnic-remove-unused-code.patch: qlcnic:
  remove unused code (bnc#698272, FATE#311468).
- patches.drivers/0098-qlcnic-replace-magic-numbers-with-defines.patch:
  qlcnic: replace magic numbers with defines (bnc#698272, FATE#311468).
- patches.drivers/0099-qlcnic-configure-port-on-eswitch.patch:
  qlcnic: configure port on eswitch (bnc#698272, FATE#311468).
- patches.drivers/0100-qlcnic-configure-offload-setting-on-eswitch.patch:
  qlcnic: configure offload setting on eswitch (bnc#698272, FATE#311468).
- patches.drivers/0101-qlcnic-support-anti-mac-spoofing.patch:
  qlcnic: support anti mac spoofing (bnc#698272, FATE#311468).
- patches.drivers/0102-qlcnic-fix-npar-state.patch: qlcnic:
  fix npar state (bnc#698272, FATE#311468).
- patches.drivers/0103-qlcnic-mark-device-state-as-failed.patch:
  qlcnic: mark device state as failed (bnc#698272, FATE#311468).
- patches.drivers/0104-qlcnic-fix-endiness-in-eswitch-statistics.patch:
  qlcnic: fix endiness in eswitch statistics (bnc#698272, FATE#311468).
- patches.drivers/0105-qlcnic-firmware-initialization-update.patch:
  qlcnic: firmware initialization update (bnc#698272, FATE#311468).
- patches.drivers/0106-qlcnic-rom-lock-recovery.patch: qlcnic:
  rom lock recovery (bnc#698272, FATE#311468).
- patches.drivers/0107-qlcnic-update-version-5.0.8.patch: qlcnic:
  update version 5.0.8 (bnc#698272, FATE#311468).
- patches.drivers/0108-qlcnic-eswitch-config-fixes.patch: qlcnic:
  eswitch config fixes (bnc#698272, FATE#311468).
- patches.drivers/0109-qlcnic-support-port-vlan-id.patch: qlcnic:
  support port vlan id (bnc#698272, FATE#311468).
- patches.drivers/0110-qlcnic-fix-fw-recovery-for-PF.patch:
  qlcnic: fix fw recovery for PF (bnc#698272, FATE#311468).
- patches.drivers/0111-qlcnic-change-reg-name.patch: qlcnic:
  change reg name (bnc#698272, FATE#311468).
- patches.drivers/0112-qlcnic-Fix-missing-error-codes.patch:
  qlcnic: Fix missing error codes (bnc#698272, FATE#311468).
- patches.drivers/0113-qlcnic-Fix-driver-load-issue-in-FW-hang.patch:
  qlcnic: Fix driver load issue in FW hang (bnc#698272, FATE#311468).
- patches.drivers/0114-qlcnic-PCI-ID-addition.patch: qlcnic:
  PCI ID addition (bnc#698272, FATE#311468).
- patches.drivers/0115-qlnic-fix-a-race-in-qlcnic_get_stats.patch:
  qlnic: fix a race in qlcnic_get_stats() (bnc#698272, FATE#311468).
- patches.drivers/0116-qlcnic-fix-poll-implementation.patch:
  qlcnic: fix poll implementation (bnc#698272, FATE#311468).
- patches.drivers/0117-qlcnic-backout-firmware-initialization-update.patch:
  qlcnic: backout firmware initialization update (bnc#698272, FATE#311468).
- patches.drivers/0118-qlcnic-add-api-version-in-reg-dump.patch:
  qlcnic: add api version in reg dump (bnc#698272, FATE#311468).
- patches.drivers/0119-qlcnic-fix-mac-addr-read.patch: qlcnic:
  fix mac addr read (bnc#698272, FATE#311468).
- patches.drivers/0120-qlcnic-fix-for-setting-default-eswitch-config.patch:
  qlcnic: fix for setting default eswitch config (bnc#698272, FATE#311468).
- patches.drivers/0121-qlcnic-fix-mac-anti-spoof-policy.patch:
  qlcnic: fix mac anti spoof policy (bnc#698272, FATE#311468).
- patches.drivers/0122-qlcnic-fix-panic-while-using-eth_hdr.patch:
  qlcnic: fix panic while using eth_hdr (bnc#698272, FATE#311468).
- patches.drivers/0123-qlcnic-fix-mac-override-capability.patch:
  qlcnic: fix mac override capability (bnc#698272, FATE#311468).
- patches.drivers/0124-qlcnic-support-mac-learning.patch: qlcnic:
  support mac learning (bnc#698272, FATE#311468).
- patches.drivers/0125-qlcnic-mac-vlan-learning-support.patch:
  qlcnic: mac vlan learning support (bnc#698272, FATE#311468).
- patches.drivers/0126-qlcnic-add-cksum-flag.patch: qlcnic:
  add cksum flag (bnc#698272, FATE#311468).
- patches.drivers/0127-qlcnic-support-vlan-rx-accleration.patch:
  qlcnic: support vlan rx accleration (bnc#698272, FATE#311468).
- patches.drivers/0128-qlcnic-vlan-gro-support.patch: qlcnic:
  vlan gro support (bnc#698272, FATE#311468).
- patches.drivers/0129-qlcnic-vlan-lro-support.patch: qlcnic:
  vlan lro support (bnc#698272, FATE#311468).
- patches.drivers/0130-qlcnic-remove-fw-version-check.patch:
  qlcnic: remove fw version check (bnc#698272, FATE#311468).
- patches.drivers/0131-qlcnic-update-version-5.0.10.patch:
  qlcnic: update version 5.0.10 (bnc#698272, FATE#311468).
- patches.drivers/0132-qlcnic-dont-assume-NET_IP_ALIGN-is-2.patch:
  qlcnic: dont assume NET_IP_ALIGN is 2 (bnc#698272, FATE#311468).
- patches.drivers/0133-qlcnic-dont-set-skb-truesize.patch:
  qlcnic: dont set skb->truesize (bnc#698272, FATE#311468).
- patches.drivers/0134-drivers-net-return-operator-cleanup.patch:
  drivers/net: return operator cleanup (bnc#698272, FATE#311468).
- patches.drivers/0135-qlcnic-fix-internal-loopback-test.patch:
  qlcnic: fix internal loopback test (bnc#698272, FATE#311468).
- patches.drivers/0136-qlcnic-fix-eswitch-stats.patch: qlcnic:
  fix eswitch stats (bnc#698272, FATE#311468).
- patches.drivers/0137-qlcnic-fix-diag-register.patch: qlcnic:
  fix diag register (bnc#698272, FATE#311468).
- patches.drivers/0138-qlcnic-fix-endianess-for-lro.patch:
  qlcnic: fix endianess for lro (bnc#698272, FATE#311468).
- patches.drivers/0139-qlcnic-fix-vlan-TSO-on-big-endian-machine.patch:
  qlcnic: fix vlan TSO on big endian machine (bnc#698272, FATE#311468).
- patches.drivers/0140-qlcnic-sparse-warning-fixes.patch: qlcnic:
  sparse warning fixes (bnc#698272, FATE#311468).
- patches.drivers/0141-qlcnic-cleanup-port-mode-setting.patch:
  qlcnic: cleanup port mode setting (bnc#698272, FATE#311468).
- patches.drivers/0142-qlcnic-set-mtu-lower-limit.patch: qlcnic:
  set mtu lower limit (bnc#698272, FATE#311468).
- patches.drivers/0143-qlcnic-remove-dead-code.patch: qlcnic:
  remove dead code (bnc#698272, FATE#311468).
- patches.drivers/0144-qlcnic-driver-private-workqueue.patch:
  qlcnic: driver private workqueue (bnc#698272, FATE#311468).
- patches.drivers/0145-qlcnic-support-quiescent-mode.patch:
  qlcnic: support quiescent mode (bnc#698272, FATE#311468).
- patches.drivers/0146-qlcnic-remove-private-LRO-flag.patch:
  qlcnic: remove private LRO flag (bnc#698272, FATE#311468).
- patches.drivers/0147-qlcnic-fix-board-description.patch:
  qlcnic: fix board description (bnc#698272, FATE#311468).
- patches.drivers/0148-qlcnic-fix-promiscous-mode-for-VF.patch:
  qlcnic: fix promiscous mode for VF (bnc#698272, FATE#311468).
- patches.drivers/0149-qlcnic-change-all-P3-references-to-P3P.patch:
  qlcnic: change all P3 references to P3P (bnc#698272, FATE#311468).
- patches.drivers/0150-qlcnic-update-driver-version-5.0.11.patch:
  qlcnic: update driver version 5.0.11 (bnc#698272, FATE#311468).
- patches.drivers/0151-qlcnic-update-ethtool-stats.patch: qlcnic:
  update ethtool stats (bnc#698272, FATE#311468).
- patches.drivers/0152-qlcnic-fix-mac-learning.patch: qlcnic:
  fix mac learning (bnc#698272, FATE#311468).
- patches.drivers/0153-qlcnic-reduce-rx-ring-size.patch: qlcnic:
  reduce rx ring size (bnc#698272, FATE#311468).
- patches.drivers/0154-qlcnic-define-valid-vlan-id-range.patch:
  qlcnic: define valid vlan id range (bnc#698272, FATE#311468).
- patches.drivers/0155-qlcnic-Allow-minimum-bandwidth-of-zero.patch:
  qlcnic: Allow minimum bandwidth of zero (bnc#698272, FATE#311468).
- patches.drivers/0156-qlcnic-Fix-for-kdump.patch: qlcnic:
  Fix for kdump (bnc#698272, FATE#311468).
- patches.drivers/0157-qlcnic-Add-description-for-CN1000Q-adapter.patch:
  qlcnic: Add description for CN1000Q adapter (bnc#698272, FATE#311468).
- patches.drivers/0158-qlcnic-lro-off-message-log-from-set-rx-checsum.patch:
  qlcnic: lro off message log from set rx checsum (bnc#698272, FATE#311468).
- patches.drivers/0159-qlcnic-fix-panic-on-load.patch: qlcnic:
  fix panic on load (bnc#698272, FATE#311468).
- patches.drivers/0160-qlcnic-Bumped-up-driver-version-to-5.0.12.patch:
  qlcnic: Bumped up driver version to 5.0.12 (bnc#698272, FATE#311468).
- patches.drivers/0161-qlcnic-avoid-using-reset_devices-as-it-may-become-ob.patch:
  qlcnic: avoid using reset_devices as it may become obsolete (bnc#698272, FATE#311468).
- patches.drivers/0162-qlcnic-Disable-loopback-support.patch:
  qlcnic: Disable loopback support (bnc#698272, FATE#311468).
- patches.drivers/0163-qlcnic-validate-eswitch-config-values-for-PF.patch:
  qlcnic: validate eswitch config values for PF (bnc#698272, FATE#311468).
- patches.drivers/0164-qlcnic-LICENSE-file-for-qlcnic.patch:
  qlcnic: LICENSE file for qlcnic (bnc#698272, FATE#311468).
- patches.drivers/0165-qlcnic-Updated-driver-version-to-5.0.13.patch:
  qlcnic: Updated driver version to 5.0.13 (bnc#698272, FATE#311468).
- patches.drivers/0166-qlcnic-fix-LED-test-when-interface-is-down.patch:
  qlcnic: fix LED test when interface is down (bnc#698272, FATE#311468).
- patches.drivers/0167-qlcnic-fix-ocm-window-register-offset-calculation.patch:
  qlcnic: fix ocm window register offset calculation (bnc#698272, FATE#311468).
- patches.drivers/0168-qlcnic-reset-pci-function-unconditionally-during-pro.patch:
  qlcnic: reset pci function unconditionally during probe (bnc#698272, FATE#311468).
- patches.drivers/0169-drivers-net-Use-static-const.patch:
  drivers/net/*/: Use static const (bnc#698272, FATE#311468).
- patches.drivers/0170-qlcnic-fix-flash-fw-version-read.patch:
  qlcnic: fix flash fw version read (bnc#698272, FATE#311468).
- patches.drivers/0171-qlcnic-fix-ethtool-diagnostics-test.patch:
  qlcnic: fix ethtool diagnostics test (bnc#698272, FATE#311468).
- patches.drivers/0172-qlcnic-change-module-parameter-permissions.patch:
  qlcnic: change module parameter permissions (bnc#698272, FATE#311468).
- patches.drivers/0173-qlcnic-Update-version-to-5.0.15.1.patch:
  qlcnic: Update version to 5.0.15.1 (bnc#698272, FATE#311468).
- patches.drivers/0174-qlcnic-Remove-validation-for-max-tx-and-max-rx-queue.patch:
  qlcnic: Remove validation for max tx and max rx queues (bnc#698272, FATE#311468).
- patches.drivers/0175-qlcnic-update-driver-version-to-5.0.15.2.patch:
  qlcnic: update driver version to 5.0.15.2 (bnc#698272, FATE#311468).
- patches.drivers/0176-net-fix-ethtool-set_flags-not-intended-EINVAL-return.patch:
  net: fix ethtool->set_flags not intended -EINVAL return value (bnc#698272, FATE#311468).
- patches.drivers/0177-qlcnic-Make-PCI-info-available-in-all-modes.patch:
  qlcnic: Make PCI info available in all modes (bnc#698272, FATE#311468).
- patches.drivers/0178-qlcnic-Memory-leak-fix.patch: qlcnic:
  Memory leak fix (bnc#698272, FATE#311468).
- patches.drivers/0179-qlcnic-Cleanup-patch.patch: qlcnic:
  Cleanup patch (bnc#698272, FATE#311468).
- patches.drivers/0180-qlcnic-Code-optimization-patch.patch:
  qlcnic: Code optimization patch (bnc#698272, FATE#311468).
- patches.drivers/0181-qlcnic-Remove-unused-code.patch: qlcnic:
  Remove unused code (bnc#698272, FATE#311468).
- patches.drivers/0182-qlcnic-Use-flt-method-to-determine-flash-fw-region.patch:
  qlcnic: Use flt method to determine flash fw region (bnc#698272, FATE#311468).
- patches.drivers/0183-qlcnic-Fix-LRO-disable.patch: qlcnic:
  Fix LRO disable (bnc#698272, FATE#311468).
- patches.drivers/0184-qlcnic-Update-version-number-to-5.0.16.patch:
  qlcnic: Update version number to 5.0.16 (bnc#698272, FATE#311468).
- patches.drivers/0185-qlcnic-limit-skb-frags-for-non-tso-packet.patch:
  qlcnic: limit skb frags for non tso packet (bnc#698272, FATE#311468).
- patches.drivers/0186-qlcnic-configure-number-of-RSS-rings-using-sysfs.patch:
  qlcnic: configure number of RSS rings using sysfs (bnc#698272, FATE#311468).
- patches.drivers/0187-qlcnic-Support-for-GBE-port-settings.patch:
  qlcnic: Support for GBE port settings (bnc#698272, FATE#311468).
- patches.drivers/net-add-qlogic-ethernet-driver-for-cna-devices:
  NET: Add Qlogic ethernet driver for CNA devices (bnc#698272, FATE#311468).
* Tue Jun 14 2011 jack@suse.cz
- patches.fixes/vfs-Leave-superblocks-on-s_list-until-the-end.patch:
  Leave superblocks on s_list until the end (bnc#649000,
  fate#312304).
- patches.fixes/vfs-get-rid-of-restarts-in-sync_filesystems.patch:
  get rid of restarts in sync_filesystems() (bnc#649000,
  fate#312304).
- patches.fixes/writeback-avoid-WB_SYNC_ALL-livelock.diff:
  writeback: avoid livelocking WB_SYNC_ALL writeback (bnc#649000).
- patches.fixes/writeback-avoid-new-file-livelock.diff: mm: avoid
  resetting wb_start after each writeback round (bnc#649000).
- patches.fixes/writeback-check-background-flush-after-work.diff:
  writeback: integrated background writeback work (bnc#649000).
- patches.fixes/writeback-fix-sb-locking.diff: Fix superblock
  locking when doing writeback (bnc#649000 bnc#617437).
- patches.fixes/writeback-stop-background-for-other-work.diff:
  writeback: stop background/kupdate works from livelocking
  other works (bnc#649000).
* Tue Jun 14 2011 jeffm@suse.com
- Update config files: Sync configs.
* Tue Jun 14 2011 mhocko@suse.cz
- patches.suse/cgroup-implement-eventfd-based-generic-API-for-notif.patch:
  cgroup: implement eventfd-based generic API for notifications
  (fate#312042).
- patches.suse/memcg-fix-oom-kill-behavior.patch: memcg: fix
  oom kill behavior (fate#312042).
- patches.suse/memcg-oom-kill-disable-and-oom-status.patch:
  memcg: oom kill disable and oom status (fate#312042).
- patches.suse/memcg-oom-notifier.patch: memcg: oom notifier
  (fate#312042).
- patches.suse/memcg-oom-wakeup-filter.patch: memcg: oom wakeup
  filter (fate#312042).
- patches.suse/memcg-skip-charging-if-fatal-signal-is-pending.patch:
  memcg: Do not charge if current is going to die (fate#312042).
* Tue Jun 14 2011 trenn@suse.de
- fate#311968: EDAC i7core driver with additional AMD EDAC fixes:
- Update config files.
- patches.drivers/2009-10-12-0001-mce-edac-Use-an-atomic-notifier-for-MCEs-decoding.patch:
  mce, edac: Use an atomic notifier for MCEs decoding
  (fate#311968).
- patches.drivers/2009-10-12-0002-x86-Clean-up-and-add-missing-log-levels-for-k8.patch:
  x86: Clean up and add missing log levels for k8 (fate#311968).
- patches.drivers/2009-10-12-0003-x86-Export-k8-physical-topology.patch:
  x86: Export k8 physical topology (fate#311968).
- patches.drivers/2009-11-08-0001-x86-k8.h-Add-struct-bootnode.patch:
  x86: k8.h: Add struct bootnode (fate#311968).
- patches.drivers/2009-12-07-0001-amd64_edac-clarify-DRAM-CTL-debug-reporting.patch:
  amd64_edac: clarify DRAM CTL debug reporting (fate#311968).
- patches.drivers/2009-12-07-0002-amd64_edac-make-DRAM-regions-output-more-human-read.patch:
  amd64_edac: make DRAM regions output more human-readable
  (fate#311968).
- patches.drivers/2009-12-07-0005-amd64_edac-wrap-up-pci-config-read-error-handling.patch:
  amd64_edac: wrap-up pci config read error handling
  (fate#311968).
- patches.drivers/2009-12-07-0006-amd64_edac-cleanup-DRAM-cfg-low-debug-output.patch:
  amd64_edac: cleanup DRAM cfg low debug output (fate#311968).
- patches.drivers/2009-12-07-0007-amd64_edac-cleanup-rest-of-amd64_dump_misc_regs.patch:
  amd64_edac: cleanup rest of amd64_dump_misc_regs (fate#311968).
- patches.drivers/2009-12-07-0008-amd64_edac-dump-DIMM-sizes-on-K8-too.patch:
  amd64_edac: dump DIMM sizes on K8 too (fate#311968).
- patches.drivers/2009-12-07-0009-amd64_edac-cleanup-f10_early_channel_count.patch:
  amd64_edac: cleanup f10_early_channel_count (fate#311968).
- patches.drivers/2009-12-07-0010-amd64_edac-enhance-address-to-DRAM-bank-mapping.patch:
  amd64_edac: enhance address to DRAM bank mapping (fate#311968).
- patches.drivers/2009-12-07-0011-amd64_edac-remove-superfluous-dbg-printk.patch:
  amd64_edac: remove superfluous dbg printk (fate#311968).
- patches.drivers/2009-12-07-0012-amd64_edac-rename-StinkyIdentifier.patch:
  amd64_edac: rename StinkyIdentifier (fate#311968).
- patches.drivers/2009-12-07-0013-amd64_edac-remove-unneeded-extract_error_address-wr.patch:
  amd64_edac: remove unneeded extract_error_address wrapper
  (fate#311968).
- patches.drivers/2009-12-07-0014-edac-mce-update-AMD-F10h-revD-check.patch:
  edac, mce: update AMD F10h revD check (fate#311968).
- patches.drivers/2009-12-07-0015-edac-add-memory-types-strings-for-debugging.patch:
  edac: add memory types strings for debugging (fate#311968).
- patches.drivers/2009-12-07-0016-amd64_edac-detect-DDR3-memory-type.patch:
  amd64_edac: detect DDR3 memory type (fate#311968).
- patches.drivers/2009-12-07-0017-amd64_edac-remove-early-hw-support-check.patch:
  amd64_edac: remove early hw support check (fate#311968).
- patches.drivers/2009-12-08-0001-amd64_edac-add-a-leaner-syndrome-decoding-algorithm.patch:
  amd64_edac: add a leaner syndrome decoding algorithm
  (fate#311968).
- patches.drivers/2009-12-08-0002-amd64_edac-correct-sys-address-to-chip-select-mappi.patch:
  amd64_edac: correct sys address to chip select mapping
  (fate#311968).
- patches.drivers/2009-12-08-0003-amd64_edac-fix-use-uninitialised-bug.patch:
  amd64_edac: fix use-uninitialised bug (fate#311968).
- patches.drivers/2009-12-08-0004-amd64_edac-bump-driver-version.patch:
  amd64_edac: bump driver version (fate#311968).
- patches.drivers/2009-12-15-0002-kernel.h-add-printk_ratelimited-and-pr_-level-_rl.patch:
  kernel.h: add printk_ratelimited and pr_<level>_rl
  (fate#311968).
- patches.drivers/2009-12-16-0001-edac-i5100-clean-controller-to-channel-terms.patch:
  edac: i5100 clean controller to channel terms (fate#311968).
- patches.drivers/2009-12-16-0002-edac-i5100-add-scrubbing.patch:
  edac: i5100 add scrubbing (fate#311968).
- patches.drivers/2009-12-16-0003-edac-i5100-add-6-ranks-per-channel.patch:
  edac: i5100 add 6 ranks per channel (fate#311968).
- patches.drivers/2009-12-16-0004-edac-mce-amd-silence-GART-TLB-errors.patch:
  edac, mce, amd: silence GART TLB errors (fate#311968).
- patches.drivers/2009-12-24-0001-amd64_edac-fix-K8-chip-select-reporting.patch:
  amd64_edac: fix K8 chip select reporting (fate#311968).
- patches.drivers/2009-12-24-0005-amd64_edac-restrict-PCI-config-space-access.patch:
  amd64_edac: restrict PCI config space access (fate#311968).
- patches.drivers/2009-12-24-0006-edac-pci-remove-pesky-debug-printk.patch:
  edac, pci: remove pesky debug printk (fate#311968).
- patches.drivers/2010-01-15-0001-amd64_edac-Ensure-index-stays-within-bounds-in-amd6.patch:
  amd64_edac: Ensure index stays within bounds in
  amd64_get_scrub_rate (fate#311968).
- patches.drivers/2010-03-01-0001-amd64_edac-Simplify-ECC-override-handling.patch:
  amd64_edac: Simplify ECC override handling (fate#311968).
- patches.drivers/2010-03-12-0001-edac-e752x-fsb-ecc.patch:
  edac: e752x fsb ecc (fate#311968).
- patches.drivers/2010-03-12-0002-edac-e752x-add-dram-scrubbing-support.patch:
  edac: e752x: add dram scrubbing support (fate#311968).
- patches.drivers/2010-04-07-0001-kernel.h-fix-wrong-usage-of-__ratelimit.patch:
  kernel.h: fix wrong usage of __ratelimit() (fate#311968).
- patches.drivers/2010-05-10-0001-i7core_edac-Add-an-EDAC-memory-controller-driver-fo.patch:
  i7core_edac: Add an EDAC memory controller driver for Nehalem
  chipsets (fate#311968).
- patches.drivers/2010-05-10-0002-i7core_edac-Add-error-insertion-code-for-Nehalem.patch:
  i7core_edac: Add error insertion code for Nehalem (fate#311968).
- patches.drivers/2010-05-10-0003-i7core_edac-Add-more-status-functions-to-EDAC-drive.patch:
  i7core_edac: Add more status functions to EDAC driver
  (fate#311968).
- patches.drivers/2010-05-10-0004-i7core_edac-Registers-all-supported-MC-functions.patch:
  i7core_edac: Registers all supported MC functions (fate#311968).
- patches.drivers/2010-05-10-0005-i7core_edac-Show-read-write-virtual-physical-channe.patch:
  i7core_edac: Show read/write virtual/physical channel
  association (fate#311968).
- patches.drivers/2010-05-10-0006-i7core_edac-A-few-fixes-at-error-injection-code.patch:
  i7core_edac: A few fixes at error injection code (fate#311968).
- patches.drivers/2010-05-10-0007-i7core_edac-need-mci-edac_check-otherwise-module.patch:
  i7core_edac: need mci->edac_check, otherwise module removal
  doesn't work (fate#311968).
- patches.drivers/2010-05-10-0008-i7core_edac-Add-a-memory-check-routine-based-on-de.patch:
  i7core_edac: Add a memory check routine, based on device 3
  function 4 (fate#311968).
- patches.drivers/2010-05-10-0009-i7core_edac-Add-additional-tests-for-error-detectio.patch:
  i7core_edac: Add additional tests for error detection
  (fate#311968).
- patches.drivers/2010-05-10-0010-i7core_edac-Properly-fill-struct-csrow_info.patch:
  i7core_edac: Properly fill struct csrow_info (fate#311968).
- patches.drivers/2010-05-10-0011-i7core_edac-Improve-error-handling.patch:
  i7core_edac: Improve error handling (fate#311968).
- patches.drivers/2010-05-10-0012-i7core_edac-Add-more-information-about-each-active.patch:
  i7core_edac: Add more information about each active dimm
  (fate#311968).
- patches.drivers/2010-05-10-0013-i7core_edac-Get-more-info-about-the-memory-DIMMs.patch:
  i7core_edac: Get more info about the memory DIMMs (fate#311968).
- patches.drivers/2010-05-10-0014-i7core_edac-Memory-info-fixes-and-preparation-for-p.patch:
  i7core_edac: Memory info fixes and preparation for properly
  filling cswrow data (fate#311968).
- patches.drivers/2010-05-10-0015-i7core_edac-fill-csrows-edac-sysfs-info.patch:
  i7core_edac: fill csrows edac sysfs info (fate#311968).
- patches.drivers/2010-05-10-0016-i7core_edac-CodingStyle-fixes.patch:
  i7core_edac: CodingStyle fixes (fate#311968).
- patches.drivers/2010-05-10-0017-edac_mce-Add-an-interface-driver-to-report-mce-erro.patch:
  edac_mce: Add an interface driver to report mce errors via edac
  (fate#311968).
- patches.drivers/2010-05-10-0018-edac-Kconfig-edac_mce-can-t-be-module.patch:
  edac/Kconfig: edac_mce can't be module (fate#311968).
- patches.drivers/2010-05-10-0019-pci-Add-a-probing-code-that-seeks-for-an-specific-b.patch:
  pci: Add a probing code that seeks for an specific bus
  (fate#311968).
- patches.drivers/2010-05-10-0020-i7core_edac-Add-edac_mce-glue.patch:
  i7core_edac: Add edac_mce glue (fate#311968).
- patches.drivers/2010-05-10-0021-i7core_edac-Adds-write-unlock-to-MC-registers.patch:
  i7core_edac: Adds write unlock to MC registers (fate#311968).
- patches.drivers/2010-05-10-0022-i7core_edac-Add-a-code-to-probe-Xeon-55xx-bus.patch:
  i7core_edac: Add a code to probe Xeon 55xx bus (fate#311968).
- patches.drivers/2010-05-10-0023-i7core_edac-add-support-for-more-than-one-MC-socket.patch:
  i7core_edac: add support for more than one MC socket
  (fate#311968).
- patches.drivers/2010-05-10-0024-i7core_edac-maps-all-sockets-as-if-ther-are-one-MC.patch:
  i7core_edac: maps all sockets as if ther are one MC controller
  (fate#311968).
- patches.drivers/2010-05-10-0025-i7core_edac-decode-mcelog-error-and-send-it-via-eda.patch:
  i7core_edac: decode mcelog error and send it via edac interface
  (fate#311968).
- patches.drivers/2010-05-10-0026-i7core_edac-some-fixes-at-memory-error-parser.patch:
  i7core_edac: some fixes at memory error parser (fate#311968).
- patches.drivers/2010-05-10-0027-i7core-fix-probing-on-Xeon55xx.patch:
  i7core: fix probing on Xeon55xx (fate#311968).
- patches.drivers/2010-05-10-0028-i7core-check-if-the-memory-error-is-fatal-or-non-fa.patch:
  i7core: check if the memory error is fatal or non-fatal
  (fate#311968).
- patches.drivers/2010-05-10-0029-i7core-enrich-error-information-based-on-memory-tra.patch:
  i7core: enrich error information based on memory transaction
  type (fate#311968).
- patches.drivers/2010-05-10-0030-i7core-fix-get_devices-routine-for-Xeon55xx.patch:
  i7core: fix get_devices routine for Xeon55xx (fate#311968).
- patches.drivers/2010-05-10-0031-i7core-better-document-i7core_get_active_channels.patch:
  i7core: better document i7core_get_active_channels()
  (fate#311968).
- patches.drivers/2010-05-10-0032-i7core-add-socket-info-at-the-debug-msg.patch:
  i7core: add socket info at the debug msg (fate#311968).
- patches.drivers/2010-05-10-0033-i7core-remove-some-uneeded-noisy-debug-messages.patch:
  i7core: remove some uneeded noisy debug messages (fate#311968).
- patches.drivers/2010-05-10-0034-i7core_edac-Some-cleanups-at-displayed-info.patch:
  i7core_edac: Some cleanups at displayed info (fate#311968).
- patches.drivers/2010-05-10-0035-i7core_edac-some-fixes-at-error-injection-code.patch:
  i7core_edac: some fixes at error injection code (fate#311968).
- patches.drivers/2010-05-10-0036-i7core_edac-fix-error-codes-for-sysfs-error-injecti.patch:
  i7core_edac: fix error codes for sysfs error injection interface
  (fate#311968).
- patches.drivers/2010-05-10-0037-i7core_edac-fix-error-injection.patch:
  i7core_edac: fix error injection (fate#311968).
- patches.drivers/2010-05-10-0038-i7core_edac-CodingSyle-fixes-cleanups.patch:
  i7core_edac: CodingSyle fixes/cleanups (fate#311968).
- patches.drivers/2010-05-10-0039-i7core_edac-Print-an-error-message-if-pci-register.patch:
  i7core_edac: Print an error message if pci register fails
  (fate#311968).
- patches.drivers/2010-05-10-0040-i7core_edac-Fix-ecc-enable-shift.patch:
  i7core_edac: Fix ecc enable shift (fate#311968).
- patches.drivers/2010-05-10-0041-i7core_edac-Use-Device-3-function-2-to-report-error.patch:
  i7core_edac: Use Device 3 function 2 to report errors with
  RDIMM's (fate#311968).
- patches.drivers/2010-05-10-0042-i7core-Use-registered-memories-per-processor.patch:
  i7core: Use registered memories per processor (fate#311968).
- patches.drivers/2010-05-10-0043-i7core_edac-Probe-on-Xeons-eariler.patch:
  i7core_edac: Probe on Xeons eariler (fate#311968).
- patches.drivers/2010-05-10-0044-i7core_edac-Improve-corrected_error_counts-output-f.patch:
  i7core_edac: Improve corrected_error_counts output for RDIMM
  (fate#311968).
- patches.drivers/2010-05-10-0046-Dynamically-allocate-memory-for-PCI-devices.patch:
  Dynamically allocate memory for PCI devices (fate#311968).
- patches.drivers/2010-05-10-0047-i7core_edac-create-one-mc-per-socket-QPI.patch:
  i7core_edac: create one mc per socket/QPI (fate#311968).
- patches.drivers/2010-05-10-0048-i7core_edac-sanity-check-print-a-warning-if-a-mcel.patch:
  i7core_edac: sanity check: print a warning if a mcelog is
  ignored (fate#311968).
- patches.drivers/2010-05-10-0049-i7core_edac-a-few-fixes-for-multiple-mc-s.patch:
  i7core_edac: a few fixes for multiple mc's (fate#311968).
- patches.drivers/2010-05-10-0050-i7core_edac-Fix-a-bug-when-printing-error-counts-wi.patch:
  i7core_edac: Fix a bug when printing error counts with RDIMMs
  (fate#311968).
- patches.drivers/2010-05-10-0051-i7core_edac-at-remove-don-t-remove-all-pci-devices.patch:
  i7core_edac: at remove, don't remove all pci devices at once
  (fate#311968).
- patches.drivers/2010-05-10-0052-i7core_edac-remove-static-counter-for-max-sockets.patch:
  i7core_edac: remove static counter for max sockets
  (fate#311968).
- patches.drivers/2010-05-10-0053-i7core_edac-change-remove-module-strategy.patch:
  i7core_edac: change remove module strategy (fate#311968).
- patches.drivers/2010-05-10-0054-i7core_edac-We-need-to-use-list_for_each_entry_safe.patch:
  i7core_edac: We need to use list_for_each_entry_safe to avoid
  errors (fate#311968).
- patches.drivers/2010-05-10-0055-i7core_edac-Avoid-printing-a-warning-when-debug-is.patch:
  i7core_edac: Avoid printing a warning when debug is disabled
  (fate#311968).
- patches.drivers/2010-05-10-0056-edac_core-Allow-the-creation-of-sysfs-groups.patch:
  edac_core: Allow the creation of sysfs groups (fate#311968).
- patches.drivers/2010-05-10-0057-i7core_edac-Add-support-for-sysfs-addrmatch-group.patch:
  i7core_edac: Add support for sysfs addrmatch group
  (fate#311968).
- patches.drivers/2010-05-10-0058-edac-store-show-methods-for-device-groups-weren-t-w.patch:
  edac: store/show methods for device groups weren't working
  (fate#311968).
- patches.drivers/2010-05-10-0059-edac-Don-t-create-csrow-entries-on-instance-groups.patch:
  edac: Don't create csrow entries on instance groups
  (fate#311968).
- patches.drivers/2010-05-10-0060-i7core_edac-Convert-UDIMM-error-counters-into-a-pro.patch:
  i7core_edac: Convert UDIMM error counters into a proper sysfs
  group (fate#311968).
- patches.drivers/2010-05-10-0061-edac-Create-an-unique-instance-for-each-kobj.patch:
  edac: Create an unique instance for each kobj (fate#311968).
- patches.drivers/2010-05-10-0062-i7core_edac-Use-a-lockless-ringbuffer.patch:
  i7core_edac: Use a lockless ringbuffer (fate#311968).
- patches.drivers/2010-05-10-0063-i7core_edac-Better-parse-any-addrmask.patch:
  i7core_edac: Better parse "any" addrmask (fate#311968).
- patches.drivers/2010-05-10-0064-i7core_edac-First-store-then-increment.patch:
  i7core_edac: First store, then increment (fate#311968).
- patches.drivers/2010-05-10-0065-i7core_edac-Fix-ringbuffer-maxsize.patch:
  i7core_edac: Fix ringbuffer maxsize (fate#311968).
- patches.drivers/2010-05-10-0066-i7core_edac-PCI-device-is-called-NONCORE-instead-o.patch:
  i7core_edac: PCI device is called NONCORE, instead of NOCORE
  (fate#311968).
- patches.drivers/2010-05-10-0067-i7core_edac-Use-a-more-generic-approach-for-probing.patch:
  i7core_edac: Use a more generic approach for probing PCI devices
  (fate#311968).
- patches.drivers/2010-05-10-0068-edac-i7core_edac-produces-undefined-behaviour-on-32.patch:
  edac: i7core_edac produces undefined behaviour on 32bit
  (fate#311968).
- patches.drivers/2010-05-10-0069-edac-fix-i7core-build.patch:
  edac: fix i7core build (fate#311968).
- patches.drivers/2010-05-10-0070-i7core_edac-do-not-export-static-functions.patch:
  i7core_edac: do not export static functions (fate#311968).
- patches.drivers/2010-05-10-0071-i7core_edac-Add-initial-support-for-Lynnfield.patch:
  i7core_edac: Add initial support for Lynnfield (fate#311968).
- patches.drivers/2010-05-10-0072-i7core-add-support-for-Lynnfield-alternate-address.patch:
  i7core: add support for Lynnfield alternate address
  (fate#311968).
- patches.drivers/2010-05-10-0073-i7core_edac-Fix-wrong-device-id-for-channel-1-devic.patch:
  i7core_edac: Fix wrong device id for channel 1 devices
  (fate#311968).
- patches.drivers/2010-05-18-0001-EDAC-add-__init-to-i7core_xeon_pci_fixup.patch:
  EDAC: add __init to i7core_xeon_pci_fixup (fate#311968).
- patches.drivers/2010-05-18-0002-i7core_edac-fix-memory-leak-of-i7core_dev.patch:
  i7core_edac: fix memory leak of i7core_dev (fate#311968).
- patches.drivers/2010-05-18-0003-Always-call-i7core_-ur-dimm_check_mc_ecc_err.patch:
  Always call i7core_dimm_check_mc_ecc_err (fate#311968).
- patches.drivers/2010-05-18-0004-i7core_edac-Add-support-for-X5670.patch:
  i7core_edac: Add support for X5670 (fate#311968).
- patches.drivers/2010-05-18-0005-i7core_edac-don-t-free-on-success.patch:
  i7core_edac: don't free on success (fate#311968).
- patches.drivers/2010-05-18-0006-PCI-fix-typos-pci_device_dis-enable-to-pci_dis-enab.patch:
  PCI: fix typos pci_device_dis/enable to pci_dis/enable_device
  in comments (fate#311968).
- patches.drivers/2010-05-18-0007-Add-support-for-Westmere-to-i7core_edac-driver.patch:
  Add support for Westmere to i7core_edac driver (fate#311968).
- patches.drivers/2010-05-18-0008-i7core_edac-Better-describe-the-supported-devices.patch:
  i7core_edac: Better describe the supported devices
  (fate#311968).
- patches.drivers/2010-06-11-0001-x86-mce-Add-HW_ERR-printk-prefix-for-hardware-erro.patch:
  x86, mce: Add HW_ERR printk prefix for hardware error logging
  (fate#311968).
- patches.drivers/2010-07-02-0001-amd64_edac-Fix-syndrome-calculation-on-K8.patch:
  amd64_edac: Fix syndrome calculation on K8 (fate#311968).
- patches.drivers/2010-07-02-0002-i7core_edac-Properly-discover-the-first-QPI-device.patch:
  i7core_edac: Properly discover the first QPI device
  (fate#311968).
- patches.drivers/2010-07-02-0003-i7core_edac-Avoid-doing-multiple-probes-for-the-sam.patch:
  i7core_edac: Avoid doing multiple probes for the same card
  (fate#311968).
- patches.drivers/2010-07-20-0001-edac-mpc85xx-fix-MPC85xx-dependency.patch:
  edac: mpc85xx: fix MPC85xx dependency (fate#311968).
- patches.drivers/2010-07-26-0001-quiesce-EDAC-initialisation-on-desktop-mobile-i7.patch:
  quiesce EDAC initialisation on desktop/mobile i7 (fate#311968).
- patches.drivers/2010-07-30-0001-x86-PCI-pci-fix-section-mismatch.patch:
  x86/PCI: pci, fix section mismatch (fate#311968).
- patches.drivers/2010-08-03-0001-amd64_edac-Sanitize-syndrome-extraction.patch:
  amd64_edac: Sanitize syndrome extraction (fate#311968).
- patches.drivers/2010-08-03-0002-edac-Remove-EDAC_DEBUG_VERBOSE.patch:
  edac: Remove EDAC_DEBUG_VERBOSE (fate#311968).
- patches.drivers/2010-08-03-0003-amd64_edac-Remove-unneeded-defines.patch:
  amd64_edac: Remove unneeded defines (fate#311968).
- patches.drivers/2010-08-03-0007-edac-mc-Improve-scrub-rate-handling.patch:
  edac, mc: Improve scrub rate handling (fate#311968).
- patches.drivers/2010-10-01-0001-i7core_edac-fix-panic-in-udimm-sysfs-attributes-reg.patch:
  i7core_edac: fix panic in udimm sysfs attributes registration
  (fate#311968).
- patches.drivers/2010-10-21-0001-EDAC-Fix-error-return.patch:
  EDAC: Fix error return (fate#311968).
- patches.drivers/2010-10-21-0006-EDAC-Export-edac-sysfs-class-to-users.patch:
  EDAC: Export edac sysfs class to users (fate#311968).
- patches.drivers/2010-10-24-0001-i7core_edac-Be-sure-that-the-edac-pci-handler-will.patch:
  i7core_edac: Be sure that the edac pci handler will be properly
  released (fate#311968).
- patches.drivers/2010-10-24-0002-i7core_edac-move-static-vars-to-the-beginning-of-th.patch:
  i7core_edac: move static vars to the beginning of the file
  (fate#311968).
- patches.drivers/2010-10-24-0003-i7core_edac-Properly-mark-const-static-vars-as-such.patch:
  i7core_edac: Properly mark const static vars as such
  (fate#311968).
- patches.drivers/2010-10-24-0004-i7core_edac-move-if-PAGE_SHIFT-to-edac_core.h.patch:
  i7core_edac: move #if PAGE_SHIFT to edac_core.h (fate#311968).
- patches.drivers/2010-10-24-0005-i7core_edac-Improve-debug-to-seek-for-register-remo.patch:
  i7core_edac: Improve debug to seek for register/remove errors
  (fate#311968).
- patches.drivers/2010-10-24-0006-i7core_edac-Initialize-all-priv-vars-before-start-p.patch:
  i7core_edac: Initialize all priv vars before start polling
  (fate#311968).
- patches.drivers/2010-10-24-0007-i7core_edac-MCE-NMI-handling-should-stop-first.patch:
  i7core_edac: MCE NMI handling should stop first (fate#311968).
- patches.drivers/2010-10-24-0008-i7core_edac-explicitly-remove-PCI-devices-from-the.patch:
  i7core_edac: explicitly remove PCI devices from the devices list
  (fate#311968).
- patches.drivers/2010-10-24-0009-edac_core-Do-a-better-job-with-node-removal.patch:
  edac_core: Do a better job with node removal (fate#311968).
- patches.drivers/2010-10-24-0010-edac_core-Don-t-let-free-mci-happen-while-using-it.patch:
  edac_core: Don't let free(mci) happen while using it
  (fate#311968).
- patches.drivers/2010-10-24-0011-edac_core-Print-debug-messages-at-release-calls.patch:
  edac_core: Print debug messages at release calls (fate#311968).
- patches.drivers/2010-10-24-0012-i7core_edac-don-t-use-a-freed-mci-struct.patch:
  i7core_edac: don't use a freed mci struct (fate#311968).
- patches.drivers/2010-10-24-0013-i7core_edac-Don-t-do-the-legacy-PCI-probe-by-defaul.patch:
  i7core_edac: Don't do the legacy PCI probe by default
  (fate#311968).
- patches.drivers/2010-10-24-0014-i7core_edac-Fix-the-logic-in-i7core_remove.patch:
  i7core_edac: Fix the logic in i7core_remove() (fate#311968).
- patches.drivers/2010-10-24-0015-i7core_edac-Reduce-args-of-i7core_get_onedevice.patch:
  i7core_edac: Reduce args of i7core_get_onedevice (fate#311968).
- patches.drivers/2010-10-24-0016-i7core_edac-Introduce-alloc_i7core_dev.patch:
  i7core_edac: Introduce alloc_i7core_dev (fate#311968).
- patches.drivers/2010-10-24-0017-i7core_edac-Introduce-free_i7core_dev.patch:
  i7core_edac: Introduce free_i7core_dev (fate#311968).
- patches.drivers/2010-10-24-0018-i7core_edac-Introduce-i7core_pci_ctl_create-release.patch:
  i7core_edac: Introduce i7core_pci_ctl_create/release
  (fate#311968).
- patches.drivers/2010-10-24-0019-i7core_edac-Always-do-get-put-for-all-devices.patch:
  i7core_edac: Always do get/put for all devices (fate#311968).
- patches.drivers/2010-10-24-0020-i7core_edac-Fix-order-of-lines-in-i7core_register_m.patch:
  i7core_edac: Fix order of lines in i7core_register_mci
  (fate#311968).
- patches.drivers/2010-10-24-0021-i7core_edac-Fix-error-path-of-i7core_register_mci.patch:
  i7core_edac: Fix error path of i7core_register_mci
  (fate#311968).
- patches.drivers/2010-10-24-0022-i7core_edac-Call-pci_dev_put-when-alloc_i7core_de.patch:
  i7core_edac: Call pci_dev_put() when alloc_i7core_dev()  failed
  (fate#311968).
- patches.drivers/2010-10-24-0023-i7core_edac-Check-probe-counter-in-i7core_remove.patch:
  i7core_edac: Check probe counter in i7core_remove (fate#311968).
- patches.drivers/2010-10-24-0024-i7core_edac-Use-saved-pointers.patch:
  i7core_edac: Use saved pointers (fate#311968).
- patches.drivers/2010-10-24-0025-i7core_edac-Introduce-i7core_unregister_mci.patch:
  i7core_edac: Introduce i7core_unregister_mci (fate#311968).
- patches.drivers/2010-10-24-0026-i7core_edac-Reduce-args-of-i7core_register_mci.patch:
  i7core_edac: Reduce args of i7core_register_mci (fate#311968).
- patches.drivers/2010-10-24-0027-i7core_edac-Remove-unused-arg-csrow-from-get_dimm_c.patch:
  i7core_edac: Remove unused arg csrow from get_dimm_config
  (fate#311968).
- patches.drivers/2010-10-24-0028-i7core_edac-Remove-unused-member-channels-in-i7core.patch:
  i7core_edac: Remove unused member channels in i7core_pvt
  (fate#311968).
- patches.drivers/2010-10-24-0029-i7core_edac-Fix-an-oops-at-i7core-probe.patch:
  i7core_edac: Fix an oops at i7core probe (fate#311968).
- patches.drivers/2010-10-24-0030-i7core_edac-it-is-safe-to-i7core_unregister_mci-w.patch:
  i7core_edac: it is safe to i7core_unregister_mci() when mci=NULL
  (fate#311968).
- patches.drivers/2010-10-24-0031-i7core_edac-Fix-refcount-error-at-PCI-devices.patch:
  i7core_edac: Fix refcount error at PCI devices (fate#311968).
- patches.drivers/2010-10-24-0032-i7core_edac-Avoid-PCI-refcount-to-reach-zero-on-suc.patch:
  i7core_edac: Avoid PCI refcount to reach zero on successive
  load/reload (fate#311968).
- patches.drivers/2010-10-24-0033-i7core_edac-properly-terminate-pci_dev_table.patch:
  i7core_edac: properly terminate pci_dev_table (fate#311968).
- patches.drivers/2010-10-24-0034-i7core_edac-return-ENODEV-when-devices-were-alread.patch:
  i7core_edac: return -ENODEV when devices were already probed
  (fate#311968).
- patches.drivers/2010-12-08-0001-EDAC-Fix-workqueue-related-crashes.patch:
  EDAC: Fix workqueue-related crashes (fate#311968).
- patches.drivers/2010-12-08-0002-EDAC-Correct-MiB_TO_PAGES-macro.patch:
  EDAC: Correct MiB_TO_PAGES() macro (fate#311968).
- patches.drivers/2010-12-28-0001-i7core_edac-fix-typos-in-comments.patch:
  i7core_edac: fix typos in comments (fate#311968).
- patches.drivers/2011-03-17-0001-EDAC-Shut-up-sysfs-registration-debug-code.patch:
  EDAC: Shut up sysfs registration debug code (fate#311968).
- patches.drivers/Modified-2010-03-08-0001-Driver-core-Constify-struct-sysfs_ops-in-struct-kob.patch:
  Driver core: Constify struct sysfs_ops in struct kobj_type
  (fate#311968).
- patches.drivers/Modified-2010-03-30-0001-include-cleanup-Update-gfp.h-and-slab.h-includes-to.patch:
  include cleanup: Update gfp.h and slab.h includes to prepare for
  breaking implicit slab.h inclusion from percpu.h (fate#311968).
- patches.drivers/Modified-2010-05-25-0001-kernel.h-add-pr_warn-for-symmetry-to-dev_warn-netd.patch:
  kernel.h: add pr_warn for symmetry to dev_warn, netdev_warn
  (fate#311968).
- patches.drivers/Modified-2011-01-07-0015-EDAC-Fixup-scrubrate-manipulation.patch:
  EDAC: Fixup scrubrate manipulation (fate#311968).
- patches.xen/xen-amd-ecs: Refresh.
- patches.xen/xen3-patch-2.6.24: Refresh.
* Tue Jun 14 2011 hare@suse.de
- Disable PS3 specific options from PPC config.
* Tue Jun 14 2011 hare@suse.de
- Re-enable and update FLUSH/FUA update patches (FATE#311692):
  * patches.suse/block-drop-barrier-ordering-by-queue-draining.patch
  * patches.suse/block-misc-cleanups-in-barrier-code.patch
  * patches.suse/btrfs-adjust-btrfs_discard_extent-return-errors-and-.patch
  * patches.suse/btrfs-discard-flags-update
  * patches.suse/btrfs-replace-barriers-with-explicit-flush-FUA-us.patch
  * patches.suse/btrfs-use-gfp_nofs-instead-of-gfp_kernel.patch
  * patches.suse/dm-implement-REQ_FLUSH-FUA-support-for-bio-based-dm.patch
  * patches.suse/gfs2-replace-barriers-with-explicit-flush-FUA-usa.patch
  * patches.suse/ide-deprecate-barrier-and-replace-blk_queue_order.patch
  * patches.suse/ide-stop-using-q-prepare_flush_fn.patch
  * patches.suse/ps3disk-stop-using-q-prepare_flush_fn.patch
* Tue Jun 14 2011 hare@suse.de
- patches.xen/xen-change-reserve_ibft_region-to-find_ibft.patch:
  Change reserve_ibft_region() to find_ibft_region()
  (FATE#311488).
* Tue Jun 14 2011 hare@suse.de
- supported.conf: Add iscsi_boot_sysfs.
* Tue Jun 14 2011 hare@suse.de
- Update config files.
- patches.suse/ibft-For-UEFI-machines-actually-do-scan-ACPI-for-iB.patch:
  ibft: For UEFI machines actually do scan ACPI for iBFT
  (FATE#311488).
- patches.suse/ibft-Kernel-oops-when-rmmoding-iscsi_ibft-with-no-i.patch:
  ibft: Kernel oops when rmmoding iscsi_ibft with no iBFT present
  (FATE#311488).
- patches.suse/ibft-Update-iBFT-handling-for-v1.03-of-the-spec.patch:
  ibft: Update iBFT handling for v1.03 of the spec (FATE#311488).
- patches.suse/ibft-convert-iscsi_ibft-module-to-iscsi-boot-lib.patch:
  ibft: convert iscsi_ibft module to iscsi boot lib (FATE#311488).
- patches.suse/ibft-separate-ibft-parsing-from-sysfs-interface.patch:
  ibft: separate ibft parsing from sysfs interface (FATE#311488).
- patches.suse/ibft-x86-Change-reserve_ibft_region-to-find_ibft.patch:
  ibft, x86: Change reserve_ibft_region() to find_ibft_region()
  (FATE#311488).
- patches.xen/xen3-patch-2.6.26: Refresh.
* Fri Jun 10 2011 mmarek@suse.cz
- rpm/built-in-where: Reimplement the main part in make to speed up
  parallel builds.
* Fri Jun 10 2011 dsterba@suse.cz
- patches.suse/btrfs-account-for-missing-devices-in-raid-allocation.patch:
  Btrfs: account for missing devices in RAID allocation profiles
  (FATE#306586).
- patches.suse/btrfs-add-a-clear_cache-mount-option.patch: Btrfs:
  Add a clear_cache mount option (FATE#306586).
- patches.suse/btrfs-add-a-comment-explaining-what-btrfs_cont_expan.patch:
  Btrfs: add a comment explaining what btrfs_cont_expand does
  (FATE#306586).
- patches.suse/btrfs-add-a-helper-try_merge_free_space.patch:
  btrfs: Add a helper try_merge_free_space() (FATE#306586).
- patches.suse/btrfs-add-basic-dio-read-write-support.patch:
  Btrfs: add basic DIO read/write support (FATE#306586).
- patches.suse/btrfs-add-btrfs_ioc_subvol_getflags-setflags-ioctls.patch:
  Btrfs: Add BTRFS_IOC_SUBVOL_GETFLAGS/SETFLAGS ioctls
  (FATE#306586).
- patches.suse/btrfs-add-checks-to-verify-dir-items-are-correct.patch:
  Btrfs: add checks to verify dir items are correct (FATE#306586).
- patches.suse/btrfs-add-helper-function-free_bitmap.patch:
  btrfs: Add helper function free_bitmap() (FATE#306586).
- patches.suse/btrfs-add-initial-tracepoint-support-for-btrfs.patch:
  Btrfs: add initial tracepoint support for btrfs (FATE#306586).
- patches.suse/btrfs-add-lzo-compression-support.patch: btrfs:
  Add lzo compression support (FATE#306586).
- patches.suse/btrfs-add-migrate-page-for-metadata-inode.patch:
  Btrfs: add migrate page for metadata inode (FATE#306586).
- patches.suse/btrfs-add-missing-spin_unlock-to-a-rare-exit-path.patch:
  btrfs: add missing spin_unlock to a rare exit path
  (FATE#306586).
- patches.suse/btrfs-add-readonly-snapshots-support.patch: Btrfs:
  Add readonly snapshots support (FATE#306586).
- patches.suse/btrfs-add-snap_create_async-ioctl.patch: Btrfs:
  add SNAP_CREATE_ASYNC ioctl (FATE#306586).
- patches.suse/btrfs-add-start_sync-wait_sync-ioctls.patch:
  Btrfs: add START_SYNC, WAIT_SYNC ioctls (FATE#306586).
- patches.suse/btrfs-add-support-for-mixed-data-metadata-block-grou.patch:
  Btrfs: add support for mixed data+metadata block groups
  (FATE#306586).
- patches.suse/btrfs-adjust-btrfs_discard_extent-return-errors-and-.patch:
  Btrfs: adjust btrfs_discard_extent() return errors and trimmed
  bytes (FATE#306586).
- patches.suse/btrfs-allow-balance-to-explicitly-allocate-chunks-as.patch:
  Btrfs: allow balance to explicitly allocate chunks as it
  relocates (FATE#306586).
- patches.suse/btrfs-allow-subvol-deletion-by-unprivileged-user-wit.patch:
  Btrfs: allow subvol deletion by unprivileged user with -o
  user_subvol_rm_allowed (FATE#306586).
- patches.suse/btrfs-allow-to-add-new-compression-algorithm.patch:
  btrfs: Allow to add new compression algorithm (FATE#306586).
- patches.suse/btrfs-allow-to-specify-compress-method-when-defrag.patch:
  btrfs: Allow to specify compress method when defrag
  (FATE#306586).
- patches.suse/btrfs-allow-unaligned-dio.patch: Btrfs: allow
  unaligned DIO (FATE#306586).
- patches.suse/btrfs-async-transaction-commit.patch: Btrfs:
  async transaction commit (FATE#306586).
- patches.suse/btrfs-avoid-accessing-unmapped-kernel-address.patch:
  Btrfs: Avoid accessing unmapped kernel address (FATE#306586).
- patches.suse/btrfs-avoid-null-pointer-deref-in-try_release_extent.patch:
  Btrfs: avoid NULL pointer deref in try_release_extent_buffer
  (FATE#306586).
- patches.suse/btrfs-avoid-taking-the-chunk_mutex-in-do_chunk_alloc.patch:
  Btrfs: avoid taking the chunk_mutex in do_chunk_alloc
  (FATE#306586).
- patches.suse/btrfs-avoid-taking-the-trans_mutex-in-btrfs_end_tran.patch:
  Btrfs: avoid taking the trans_mutex in btrfs_end_transaction
  (FATE#306586).
- patches.suse/btrfs-avoid-uninit-variable-warnings-in-ordered-data.patch:
  Btrfs: avoid uninit variable warnings in ordered-data.c
  (FATE#306586).
- patches.suse/btrfs-break-out-of-shrink_delalloc-earlier.patch:
  Btrfs: break out of shrink_delalloc earlier (FATE#306586).
- patches.suse/btrfs-catch-errors-from-btrfs_sync_log.patch:
  Btrfs: catch errors from btrfs_sync_log (FATE#306586).
- patches.suse/btrfs-change-reserved_extents-to-an-atomic_t.patch:
  Btrfs: change reserved_extents to an atomic_t (FATE#306586).
- patches.suse/btrfs-check-cache-caching_ctl-before-returning-if-ca.patch:
  Btrfs: check cache->caching_ctl before returning if caching
  has started (FATE#306586).
- patches.suse/btrfs-check-for-duplicate-iov_base-s-when-doing-dio-.patch:
  Btrfs: check for duplicate iov_base's when doing dio reads
  (FATE#306586).
- patches.suse/btrfs-check-free-space-in-block-group-before-searchi.patch:
  Btrfs: check free space in block group before searching for
  a cluster (FATE#306586).
- patches.suse/btrfs-check-if-btrfs_next_leaf-returns-error-in-btrfs_listxattr.patch:
  Btrfs: Check if btrfs_next_leaf() returns error in
  btrfs_listxattr() (FATE#306586).
- patches.suse/btrfs-check-if-btrfs_next_leaf-returns-error-in-btrfs_real_readdir.patch:
  Btrfs: Check if btrfs_next_leaf() returns error in
  btrfs_real_readdir() (FATE#306586).
- patches.suse/btrfs-check-if-dest_offset-is-block-size-aligned-bef.patch:
  btrfs: Check if dest_offset is block-size aligned before
  cloning file (FATE#306586).
- patches.suse/btrfs-check-items-for-correctness-as-we-search.patch:
  Btrfs: check items for correctness as we search (FATE#306586).
- patches.suse/btrfs-check-link-counter-overflow-in-link-2.patch:
  btrfs: check link counter overflow in link(2) (FATE#306586).
- patches.suse/btrfs-check-mergeable-free-space-when-removing-a-clu.patch:
  btrfs: Check mergeable free space when removing a cluster
  (FATE#306586).
- patches.suse/btrfs-check-null-or-not.patch: btrfs: check NULL
  or not (FATE#306586).
- patches.suse/btrfs-check-return-value-of-alloc_extent_map.patch:
  Btrfs: check return value of alloc_extent_map() (FATE#306586).
- patches.suse/btrfs-check-return-value-of-btrfs_alloc_path.patch:
  Btrfs: check return value of btrfs_alloc_path() (FATE#306586).
- patches.suse/btrfs-check-return-value-of-btrfs_search_slot-proper.patch:
  Btrfs: check return value of btrfs_search_slot properly
  (FATE#306586).
- patches.suse/btrfs-check-return-value-of-btrfs_start_ioctl_transa.patch:
  btrfs: check return value of btrfs_start_ioctl_transaction()
  properly (FATE#306586).
- patches.suse/btrfs-check-return-value-of-kmalloc.patch: Btrfs:
  check return value of kmalloc() (FATE#306586).
- patches.suse/btrfs-check-return-value-of-read_tree_block.patch:
  Btrfs: check return value of read_tree_block() (FATE#306586).
- patches.suse/btrfs-check-validity-before-setting-an-acl.patch:
  Btrfs: Check validity before setting an acl (FATE#306586).
- patches.suse/btrfs-checking-null-or-not-in-some-functions.patch:
  btrfs: checking NULL or not in some functions (FATE#306586).
- patches.suse/btrfs-cleanup-duplicate-bio-allocating-functions.patch:
  btrfs: cleanup duplicate bio allocating functions (FATE#306586).
- patches.suse/btrfs-cleanup-error-handling-in-btrfs_unlink_inode.patch:
  btrfs: cleanup error handling in btrfs_unlink_inode()
  (FATE#306586).
- patches.suse/btrfs-cleanup-error-handling-in-inode.c.patch:
  Btrfs: cleanup error handling in inode.c (FATE#306586).
- patches.suse/btrfs-cleanup-error-handling-in-the-truncate-path.patch:
  Btrfs: cleanup error handling in the truncate path
  (FATE#306586).
- patches.suse/btrfs-cleanup-how-we-setup-free-space-clusters.patch:
  Btrfs: cleanup how we setup free space clusters (FATE#306586).
- patches.suse/btrfs-cleanup-some-bug_on.patch: Btrfs: cleanup
  some BUG_ON() (FATE#306586).
- patches.suse/btrfs-cleanup-warnings-from-gcc-4.6-nonbugs.patch:
  Btrfs: cleanup warnings from gcc 4.6 (nonbugs) (FATE#306586).
- patches.suse/btrfs-clear-__gfp_fs-flag-in-the-space-cache-inode.patch:
  btrfs: clear __GFP_FS flag in the space cache inode
  (FATE#306586).
- patches.suse/btrfs-close_bdev_exclusive-should-use-the-same-flags.patch:
  btrfs: close_bdev_exclusive() should use the same @flags as
  the matching open_bdev_exclusive() (FATE#306586).
- patches.suse/btrfs-constify-xattr_handler.patch: btrfs:
  constify xattr_handler (FATE#306586).
- patches.suse/btrfs-create-special-free-space-cache-inode.patch:
  Btrfs: create special free space cache inode (FATE#306586).
- patches.suse/btrfs-deal-with-dio-bios-that-span-more-than-one-ord.patch:
  Btrfs: deal with DIO bios that span more than one ordered extent
  (FATE#306586).
- patches.suse/btrfs-deal-with-errors-from-updating-the-tree-log.patch:
  Btrfs: deal with errors from updating the tree log
  (FATE#306586).
- patches.suse/btrfs-deal-with-min_bytes-appropriately-when-looking.patch:
  Btrfs: deal with min_bytes appropriately when looking for a
  cluster (FATE#306586).
- patches.suse/btrfs-deal-with-short-returns-from-copy_from_user.patch:
  Btrfs: deal with short returns from copy_from_user
  (FATE#306586).
- patches.suse/btrfs-deal-with-space-cache-errors-better.patch:
  Btrfs: deal with space cache errors better (FATE#306586).
- patches.suse/btrfs-deal-with-the-case-that-we-run-out-of-space-in.patch:
  Btrfs: deal with the case that we run out of space in the cache
  (FATE#306586).
- patches.suse/btrfs-do-aio_write-instead-of-write.patch: Btrfs:
  do aio_write instead of write (FATE#306586).
- patches.suse/btrfs-do-error-checking-in-btrfs_del_csums.patch:
  Btrfs: do error checking in btrfs_del_csums (FATE#306586).
- patches.suse/btrfs-do-not-bug-if-we-fail-to-remove-the-orphan-ite.patch:
  Btrfs: do not BUG if we fail to remove the orphan item for
  dead snapshots (FATE#306586).
- patches.suse/btrfs-do-not-call-btrfs_update_inode-in-endio-if-not.patch:
  Btrfs: do not call btrfs_update_inode in endio if nothing
  changed (FATE#306586).
- patches.suse/btrfs-do-not-do-fast-caching-if-we-are-allocating-bl.patch:
  Btrfs: do not do fast caching if we are allocating blocks for
  tree_root (FATE#306586).
- patches.suse/btrfs-do-not-release-more-reserved-bytes-to-the-glob.patch:
  Btrfs: do not release more reserved bytes to the
  global_block_rsv than we need (FATE#306586).
- patches.suse/btrfs-do-not-use-async-submit-for-small-dio-io-s.patch:
  Btrfs: do not use async submit for small DIO io's (FATE#306586).
- patches.suse/btrfs-don-t-allocate-chunks-as-aggressively.patch:
  Btrfs: don't allocate chunks as aggressively (FATE#306586).
- patches.suse/btrfs-don-t-allocate-dip-csums-when-doing-writes.patch:
  Btrfs: don't allocate dip->csums when doing writes
  (FATE#306586).
- patches.suse/btrfs-don-t-be-as-aggressive-about-using-bitmaps.patch:
  Btrfs: don't be as aggressive about using bitmaps (FATE#306586).
- patches.suse/btrfs-don-t-force-chunk-allocation-in-find_free_exte.patch:
  Btrfs: don't force chunk allocation in find_free_extent
  (FATE#306586).
- patches.suse/btrfs-don-t-loop-forever-on-bad-btree-blocks.patch:
  Btrfs: don't loop forever on bad btree blocks (FATE#306586).
- patches.suse/btrfs-don-t-mess-with-i_nlink-of-unlocked-inode-in-r.patch:
  btrfs: don't mess with i_nlink of unlocked inode in rename()
  (FATE#306586).
- patches.suse/btrfs-don-t-pass-null-ptr-to-func-that-may-deref-it.patch:
  btrfs: Don't pass NULL ptr to func that may deref it
  (FATE#306586).
- patches.suse/btrfs-don-t-release-pages-when-we-can-t-clear-the-up.patch:
  Btrfs: don't release pages when we can't clear the uptodate bits
  (FATE#306586).
- patches.suse/btrfs-don-t-return-acl-info-when-mounting-with-noacl.patch:
  Btrfs: Don't return acl info when mounting with noacl option
  (FATE#306586).
- patches.suse/btrfs-don-t-split-dio-bios-if-we-don-t-have-to.patch:
  Btrfs: don't split dio bios if we don't have to (FATE#306586).
- patches.suse/btrfs-don-t-use-migrate-page-without-config_migratio.patch:
  Btrfs: don't use migrate page without CONFIG_MIGRATION
  (FATE#306586).
- patches.suse/btrfs-don-t-warn-if-we-get-enospc-in-btrfs_block_rsv.patch:
  Btrfs: don't warn if we get ENOSPC in btrfs_block_rsv_check
  (FATE#306586).
- patches.suse/btrfs-don-t-warn-in-btrfs_add_orphan.patch: Btrfs:
  don't warn in btrfs_add_orphan (FATE#306586).
- patches.suse/btrfs-drop-__exit-attribute-on-btrfs_exit_compress.patch:
  btrfs: Drop __exit attribute on btrfs_exit_compress
  (FATE#306586).
- patches.suse/btrfs-drop-unused-variable-in-block_alloc_rsv.patch:
  Btrfs: drop unused variable in block_alloc_rsv (FATE#306586).
- patches.suse/btrfs-eio-when-we-fail-to-read-tree-roots.patch:
  Btrfs: EIO when we fail to read tree roots (FATE#306586).
- patches.suse/btrfs-end_bio_extent_readpage-should-look-for-locked.patch:
  Btrfs end_bio_extent_readpage should look for locked bits
  (FATE#306586).
- patches.suse/btrfs-exclude-super-blocks-when-we-read-in-block-gro.patch:
  Btrfs: exclude super blocks when we read in block groups
  (FATE#306586).
- patches.suse/btrfs-extract-duplicate-decompress-code.patch:
  btrfs: Extract duplicate decompress code (FATE#306586).
- patches.suse/btrfs-fail-if-we-try-to-use-hole-punch.patch:
  Btrfs: fail if we try to use hole punch (FATE#306586).
- patches.suse/btrfs-fix-__btrfs_map_block-on-32-bit-machines.patch:
  Btrfs: fix __btrfs_map_block on 32 bit machines (FATE#306586).
- patches.suse/btrfs-fix-a-crash-when-mounting-a-subvolume.patch:
  Btrfs: Fix a crash when mounting a subvolume (FATE#306586).
- patches.suse/btrfs-fix-balance-panic.patch: Btrfs: Fix balance
  panic (FATE#306586).
- patches.suse/btrfs-fix-btrfs-b0rkage.patch: Fix btrfs b0rkage
  (FATE#306586).
- patches.suse/btrfs-fix-btrfs_ioc_subvol_setflags-ioctl.patch:
  Btrfs: Fix BTRFS_IOC_SUBVOL_SETFLAGS ioctl (FATE#306586).
- patches.suse/btrfs-fix-bugs-in-zlib-workspace.patch: btrfs:
  Fix bugs in zlib workspace (FATE#306586).
- patches.suse/btrfs-fix-build-of-ctree.patch: fs/btrfs: Fix
  build of ctree (FATE#306586).
- patches.suse/btrfs-fix-check_path_shared-so-it-returns-the-right-.patch:
  Btrfs: fix check_path_shared so it returns the right value
  (FATE#306586).
- patches.suse/btrfs-fix-clone-ioctl-destination-file-size-expansio.patch:
  Btrfs: fix CLONE ioctl destination file size expansion to
  block boundary (FATE#306586).
- patches.suse/btrfs-fix-clone-ioctl-where-range-is-adjacent-to-ext.patch:
  Btrfs: fix clone ioctl where range is adjacent to extent
  (FATE#306586).
- patches.suse/btrfs-fix-compiler-warning-in-file.c.patch: Btrfs:
  fix compiler warning in file.c (FATE#306586).
- patches.suse/btrfs-fix-compiler-warnings.patch: Btrfs: fix
  compiler warnings (FATE#306586).
- patches.suse/btrfs-fix-deadlock-in-btrfs_commit_transaction.patch:
  Btrfs: fix deadlock in btrfs_commit_transaction (FATE#306586).
- patches.suse/btrfs-fix-delalloc-checks-in-clone-ioctl.patch:
  Btrfs: fix delalloc checks in clone ioctl (FATE#306586).
- patches.suse/btrfs-fix-df-regression.patch: Btrfs: fix df
  regression (FATE#306586).
- patches.suse/btrfs-fix-dip-leak.patch: btrfs: fix dip leak
  (FATE#306586).
- patches.suse/btrfs-fix-early-enospc-because-unused-calculated-wit.patch:
  btrfs: Fix early enospc because 'unused' calculated with wrong
  sign (FATE#306586).
- patches.suse/btrfs-fix-error-handling-in-btrfs_get_sb.patch:
  Btrfs: fix error handling in btrfs_get_sb (FATE#306586).
- patches.suse/btrfs-fix-error-handling-in-zlib.patch: btrfs:
  Fix error handling in zlib (FATE#306586).
- patches.suse/btrfs-fix-fiemap-bugs-with-delalloc.patch: Btrfs:
  fix fiemap bugs with delalloc (FATE#306586).
- patches.suse/btrfs-fix-fiemap.patch: Btrfs: fix fiemap
  (FATE#306586).
- patches.suse/btrfs-fix-file-clone-when-source-offset-is-not-0.patch:
  Btrfs: Fix file clone when source offset is not 0 (FATE#306586).
- patches.suse/btrfs-fix-formatting-in-file.c.patch: Btrfs:
  fix formatting in file.c (FATE#306586).
- patches.suse/btrfs-fix-free-dip-and-dip-csums-twice.patch:
  btrfs: fix free dip and dip->csums twice (FATE#306586).
- patches.suse/btrfs-fix-free-space-cache-leak.patch: Btrfs:
  fix free space cache leak (FATE#306586).
- patches.suse/btrfs-fix-free-space-cache-when-there-are-pinned-ext.patch:
  Btrfs: fix free space cache when there are pinned extents and
  clusters V2 (FATE#306586).
- patches.suse/btrfs-fix-how-we-deal-with-the-pages-array-in-the-wr.patch:
  Btrfs: fix how we deal with the pages array in the write path
  (FATE#306586).
- patches.suse/btrfs-fix-incorrect-inode-nlink-in-btrfs_link.patch:
  Btrfs: Fix incorrect inode nlink in btrfs_link() (FATE#306586).
- patches.suse/btrfs-fix-lockdep-warning-on-clone-ioctl.patch:
  Btrfs: fix lockdep warning on clone ioctl (FATE#306586).
- patches.suse/btrfs-fix-memory-leak-at-umount.patch: Btrfs:
  Fix memory leak at umount (FATE#306586).
- patches.suse/btrfs-fix-memory-leak-in-btrfs_init_new_device.patch:
  Btrfs - Fix memory leak in btrfs_init_new_device()
  (FATE#306586).
- patches.suse/btrfs-fix-memory-leak-in-btrfs_ioctl_start_sync.patch:
  Btrfs: fix memory leak in btrfs_ioctl_start_sync()
  (FATE#306586).
- patches.suse/btrfs-fix-memory-leak-in-btrfs_read_fs_root_no_radix.patch:
  btrfs: Fix memory leak in btrfs_read_fs_root_no_radix()
  (FATE#306586).
- patches.suse/btrfs-fix-memory-leak-in-start_transaction.patch:
  Btrfs: fix memory leak in start_transaction() (FATE#306586).
- patches.suse/btrfs-fix-memory-leak-in-writepage-fixup-work.patch:
  Btrfs: Fix memory leak in writepage fixup work (FATE#306586).
- patches.suse/btrfs-fix-memory-leak-of-empty-filesystem-after-bala.patch:
  Btrfs: fix memory leak of empty filesystem after balance
  (FATE#306586).
- patches.suse/btrfs-fix-memory-leak-on-finding-existing-super.patch:
  Btrfs: Fix memory leak on finding existing super (FATE#306586).
- patches.suse/btrfs-fix-memory-leaks-in-btrfs_new_inode.patch:
  Btrfs: fix memory leaks in btrfs_new_inode() (FATE#306586).
- patches.suse/btrfs-fix-missing-break-in-switch-phrase.patch:
  btrfs: fix missing break in switch phrase (FATE#306586).
- patches.suse/btrfs-fix-missing-mutex_unlock-in-btrfs_del_dir_entr.patch:
  Btrfs: fix missing mutex_unlock in
  btrfs_del_dir_entries_in_log() (FATE#306586).
- patches.suse/btrfs-fix-more-estale-problems-with-nfs.patch:
  Btrfs: fix more ESTALE problems with NFS (FATE#306586).
- patches.suse/btrfs-fix-not-enough-reserved-space.patch: btrfs:
  fix not enough reserved space (FATE#306586).
- patches.suse/btrfs-fix-off-by-one-while-setting-block-groups-read.patch:
  Btrfs: fix off by one while setting block groups readonly
  (FATE#306586).
- patches.suse/btrfs-fix-oops-for-defrag-with-compression-turned-on.patch:
  Btrfs: Fix oops for defrag with compression turned on
  (FATE#306586).
- patches.suse/btrfs-fix-oops-of-empty-filesystem-after-balance.patch:
  Btrfs: fix OOPS of empty filesystem after balance (FATE#306586).
- patches.suse/btrfs-fix-page-count-calculation.patch: Btrfs:
  Fix page count calculation (FATE#306586).
- patches.suse/btrfs-fix-page-leak-in-compressed-writeback-path.patch:
  Btrfs: Fix page leak in compressed writeback path (FATE#306586).
- patches.suse/btrfs-fix-page-private-races.patch: Btrfs: fix
  page->private races (FATE#306586).
- patches.suse/btrfs-fix-panic-caused-by-direct-io.patch: btrfs:
  fix panic caused by direct IO (FATE#306586).
- patches.suse/btrfs-fix-possible-deadlock-by-clearing-__gfp_fs-fla.patch:
  btrfs: fix possible deadlock by clearing __GFP_FS flag
  (FATE#306586).
- patches.suse/btrfs-fix-preallocation-and-nodatacow-checks-in-o_di.patch:
  Btrfs: fix preallocation and nodatacow checks in O_DIRECT
  (FATE#306586).
- patches.suse/btrfs-fix-proc-mounts-info.patch: Btrfs: fix
  /proc/mounts info (FATE#306586).
- patches.suse/btrfs-fix-race-between-btrfs_get_sb-and-umount.patch:
  Btrfs - fix race between btrfs_get_sb() and umount
  (FATE#306586).
- patches.suse/btrfs-fix-raid-code-for-removing-missing-drives.patch:
  Btrfs: fix raid code for removing missing drives (FATE#306586).
- patches.suse/btrfs-fix-regressions-in-copy_from_user-handling.patch:
  Btrfs: fix regressions in copy_from_user handling (FATE#306586).
- patches.suse/btrfs-fix-reservation-code-for-mixed-block-groups.patch:
  Btrfs: fix reservation code for mixed block groups
  (FATE#306586).
- patches.suse/btrfs-fix-return-value-check-of-btrfs_join_transacti.patch:
  btrfs: fix return value check of btrfs_join_transaction()
  (FATE#306586).
- patches.suse/btrfs-fix-return-value-check-of-btrfs_start_transact.patch:
  btrfs: fix return value check of btrfs_start_transaction()
  (FATE#306586).
- patches.suse/btrfs-fix-return-value-of-setflags-ioctl.patch:
  Btrfs: fix return value of setflags ioctl (FATE#306586).
- patches.suse/btrfs-fix-several-uncheck-memory-allocations.patch:
  btrfs: fix several uncheck memory allocations (FATE#306586).
- patches.suse/btrfs-fix-split_leaf-double-split-corner-case.patch:
  Btrfs: fix split_leaf double split corner case (FATE#306586).
- patches.suse/btrfs-fix-subvol_sem-leak-in-btrfs_rename.patch:
  Btrfs: fix subvol_sem leak in btrfs_rename() (FATE#306586).
- patches.suse/btrfs-fix-subvolume-mount-by-name-problem-when-defau.patch:
  Btrfs: fix subvolume mount by name problem when default mount
  subvolume is set (FATE#306586).
- patches.suse/btrfs-fix-sync-subvol-snapshot-creation.patch:
  Btrfs: fix sync subvol/snapshot creation (FATE#306586).
- patches.suse/btrfs-fix-the-df-ioctl-to-report-raid-types.patch:
  Btrfs: fix the df ioctl to report raid types (FATE#306586).
- patches.suse/btrfs-fix-threshold-calculation-for-block-groups-sma.patch:
  btrfs: Fix threshold calculation for block groups smaller than
  1GB (FATE#306586).
- patches.suse/btrfs-fix-typo-in-fallocate-to-make-it-honor-actual-.patch:
  Btrfs: fix typo in fallocate to make it honor actual size
  (FATE#306586).
- patches.suse/btrfs-fix-uncheck-memory-allocation-in-btrfs_submit_.patch:
  btrfs: fix uncheck memory allocation in
  btrfs_submit_compressed_read (FATE#306586).
- patches.suse/btrfs-fix-uncheck-memory-allocations.patch: Btrfs:
  fix uncheck memory allocations (FATE#306586).
- patches.suse/btrfs-fix-use-after-free-in-o_direct.patch: Btrfs:
  fix use after free in O_DIRECT (FATE#306586).
- patches.suse/btrfs-fix-user-annotation-in-ioctl.c.patch:
  fix user annotation in ioctl.c (FATE#306586).
- patches.suse/btrfs-fix-variables-set-but-not-read-bugs-found-by-g.patch:
  Btrfs: Fix variables set but not read (bugs found by gcc 4.6)
  (FATE#306586).
- patches.suse/btrfs-fix-wrong-allocating-flag-when-reading-page.patch:
  btrfs: fix wrong allocating flag when reading page
  (FATE#306586).
- patches.suse/btrfs-fix-wrong-calculation-of-stripe-size.patch:
  btrfs: fix wrong calculation of stripe size (FATE#306586).
- patches.suse/btrfs-fix-wrong-data-space-statistics.patch:
  btrfs: fix wrong data space statistics (FATE#306586).
- patches.suse/btrfs-fix-wrong-free-space-information-of-btrfs.patch:
  btrfs: fix wrong free space information of btrfs (FATE#306586).
- patches.suse/btrfs-fixup-return-code-for-btrfs_del_orphan_item.patch:
  Btrfs: fixup return code for btrfs_del_orphan_item
  (FATE#306586).
- patches.suse/btrfs-forced-readonly-mounts-on-errors.patch:
  Btrfs: forced readonly mounts on errors (FATE#306586).
- patches.suse/btrfs-free-bitmaps-properly-when-evicting-the-cache.patch:
  Btrfs: free bitmaps properly when evicting the cache
  (FATE#306586).
- patches.suse/btrfs-free-correct-pointer-after-using-strsep.patch:
  Btrfs: Free correct pointer after using strsep (FATE#306586).
- patches.suse/btrfs-free-fully-occupied-bitmap-in-cluster.patch:
  btrfs: Free fully occupied bitmap in cluster (FATE#306586).
- patches.suse/btrfs-handle-errors-in-btrfs_orphan_cleanup.patch:
  Btrfs: handle errors in btrfs_orphan_cleanup (FATE#306586).
- patches.suse/btrfs-handle-nfs-lookups-properly.patch: Btrfs:
  handle NFS lookups properly (FATE#306586).
- patches.suse/btrfs-handle-no-memory-properly-in-prepare_pages.patch:
  Btrfs: handle no memory properly in prepare_pages (FATE#306586).
- patches.suse/btrfs-handle-the-space_cache-option-properly.patch:
  Btrfs: handle the space_cache option properly (FATE#306586).
- patches.suse/btrfs-hold-i_mutex-when-calling-btrfs_log_dentry_saf.patch:
  Btrfs: hold i_mutex when calling btrfs_log_dentry_safe
  (FATE#306586).
- patches.suse/btrfs-inode.c-add-missing-is_err-test.patch:
  fs/btrfs/inode.c: Add missing IS_ERR test (FATE#306586).
- patches.suse/btrfs-let-the-user-know-space-caching-is-enabled.patch:
  Btrfs: let the user know space caching is enabled (FATE#306586).
- patches.suse/btrfs-load-free-space-cache-if-it-exists.patch:
  Btrfs: load free space cache if it exists (FATE#306586).
- patches.suse/btrfs-make-1-bit-signed-fileds-unsigned.patch:
  btrfs: make 1-bit signed fileds unsigned (FATE#306586).
- patches.suse/btrfs-make-async-snapshot-ioctl-more-generic.patch:
  Btrfs: Make async snapshot ioctl more generic (FATE#306586).
- patches.suse/btrfs-make-btrfs_add_nondir-take-parent-inode-as-an-.patch:
  Btrfs: make btrfs_add_nondir take parent inode as an argument
  (FATE#306586).
- patches.suse/btrfs-make-btrfs_map_block-return-entire-free-extent.patch:
  Btrfs: make btrfs_map_block() return entire free extent for
  each device of RAID0/1/10/DUP (FATE#306586).
- patches.suse/btrfs-make-btrfs_rm_device-fail-gracefully.patch:
  Btrfs: make btrfs_rm_device() fail gracefully (FATE#306586).
- patches.suse/btrfs-make-inode-ref-log-recovery-faster.patch:
  btrfs: make inode ref log recovery faster (FATE#306586).
- patches.suse/btrfs-make-shrink_delalloc-a-little-friendlier.patch:
  Btrfs: make shrink_delalloc a little friendlier (FATE#306586).
- patches.suse/btrfs-make-snap_destroy-async.patch: Btrfs:
  make SNAP_DESTROY async (FATE#306586).
- patches.suse/btrfs-make-sure-new-inode-size-is-ok-in-fallocate.patch:
  Btrfs: make sure new inode size is ok in fallocate
  (FATE#306586).
- patches.suse/btrfs-make-sure-not-to-return-overlapping-extents-to.patch:
  Btrfs: make sure not to return overlapping extents to fiemap
  (FATE#306586).
- patches.suse/btrfs-make-sure-search_bitmap-finds-something-in-rem.patch:
  Btrfs: make sure search_bitmap finds something in
  remove_from_bitmap (FATE#306586).
- patches.suse/btrfs-make-sure-to-remove-the-orphan-item-from-the-i.patch:
  Btrfs: make sure to remove the orphan item from the in-memory
  list (FATE#306586).
- patches.suse/btrfs-make-the-chunk-allocator-utilize-the-devices-b.patch:
  btrfs: make the chunk allocator utilize the devices better
  (FATE#306586).
- patches.suse/btrfs-make-the-feature-checks-in-fallocate-future-proof.patch:
  make the feature checks in ->fallocate future proof
  (FATE#306586).
- patches.suse/btrfs-make-uncache_state-unconditional.patch:
  Btrfs: make uncache_state unconditional (FATE#306586).
- patches.suse/btrfs-make-update_reserved_bytes-public.patch:
  Btrfs: make update_reserved_bytes() public (FATE#306586).
- patches.suse/btrfs-map-the-inode-item-when-doing-fill_inode_item.patch:
  Btrfs: map the inode item when doing fill_inode_item
  (FATE#306586).
- patches.suse/btrfs-mark-the-bio-with-an-error-if-we-have-a-failur.patch:
  Btrfs: mark the bio with an error if we have a failure in dio
  (FATE#306586).
- patches.suse/btrfs-mem-leak-in-btrfs_get_acl.patch: btrfs:
  Mem leak in btrfs_get_acl() (FATE#306586).
- patches.suse/btrfs-mount-failure-return-value-fix.patch: btrfs:
  mount failure return value fix (FATE#306586).
- patches.suse/btrfs-move-o_direct-space-reservation-to-btrfs_direc.patch:
  Btrfs: move O_DIRECT space reservation to btrfs_direct_IO
  (FATE#306586).
- patches.suse/btrfs-only-add-orphan-items-when-truncating.patch:
  Btrfs: only add orphan items when truncating (FATE#306586).
- patches.suse/btrfs-only-retry-transaction-reservation-once.patch:
  Btrfs: only retry transaction reservation once (FATE#306586).
- patches.suse/btrfs-per-file-directory-controls-for-cow-and-compre.patch:
  Btrfs: Per file/directory controls for COW and compression
  (FATE#306586).
- patches.suse/btrfs-prevent-heap-corruption-in-btrfs_ioctl_space_i.patch:
  btrfs: prevent heap corruption in btrfs_ioctl_space_info()
  (FATE#306586).
- patches.suse/btrfs-prevent-raid-level-downgrades-when-space-is-lo.patch:
  Btrfs: prevent RAID level downgrades when space is low
  (FATE#306586).
- patches.suse/btrfs-properly-access-unaligned-checksum-buffer.patch:
  btrfs: properly access unaligned checksum buffer (FATE#306586).
- patches.suse/btrfs-properly-handle-overlapping-areas-in-memmove_e.patch:
  btrfs: properly handle overlapping areas in
  memmove_extent_buffer (FATE#306586).
- patches.suse/btrfs-put-enospc-debugging-under-a-mount-option.patch:
  Btrfs: put ENOSPC debugging under a mount option (FATE#306586).
- patches.suse/btrfs-put-the-right-bio-if-we-have-an-error.patch:
  Btrfs: put the right bio if we have an error (FATE#306586).
- patches.suse/btrfs-pwrite-blocked-when-writing-from-the-mmaped-bu.patch:
  Btrfs: pwrite blocked when writing from the mmaped buffer of
  the same page (FATE#306586).
- patches.suse/btrfs-re-work-delalloc-flushing.patch: Btrfs:
  re-work delalloc flushing (FATE#306586).
- patches.suse/btrfs-refactor-btrfs_ioctl_snap_create.patch:
  Btrfs: Refactor btrfs_ioctl_snap_create() (FATE#306586).
- patches.suse/btrfs-remove-warn_on-from-use_block_rsv.patch:
  Btrfs: remove warn_on from use_block_rsv (FATE#306586).
- patches.suse/btrfs-restructure-find_free_dev_extent.patch:
  btrfs: restructure find_free_dev_extent() (FATE#306586).
- patches.suse/btrfs-restructure-try_release_extent_buffer.patch:
  Btrfs: restructure try_release_extent_buffer() (FATE#306586).
- patches.suse/btrfs-return-error-if-the-range-we-want-to-map-is-bo.patch:
  Btrfs: return error if the range we want to map is bogus
  (FATE#306586).
- patches.suse/btrfs-reuse-the-extent_map-we-found-when-calling-btr.patch:
  Btrfs: reuse the extent_map we found when calling
  btrfs_get_extent (FATE#306586).
- patches.suse/btrfs-rework-how-we-reserve-metadata-bytes.patch:
  Btrfs: rework how we reserve metadata bytes (FATE#306586).
- patches.suse/btrfs-rework-o_direct-enospc-handling.patch:
  Btrfs: rework O_DIRECT enospc handling (FATE#306586).
- patches.suse/btrfs-set-file-size-correctly-in-file-clone.patch:
  btrfs: Set file size correctly in file clone (FATE#306586).
- patches.suse/btrfs-set-fmode_excl-in-btrfs_device-mode.patch:
  Btrfs: set FMODE_EXCL in btrfs_device->mode (FATE#306586).
- patches.suse/btrfs-set-trans-to-null-in-reserve_metadata_bytes-if.patch:
  Btrfs: set trans to null in reserve_metadata_bytes if we commit
  the transaction (FATE#306586).
- patches.suse/btrfs-setup-blank-root-and-fs_info-for-mount-time.patch:
  Btrfs: setup blank root and fs_info for mount time
  (FATE#306586).
- patches.suse/btrfs-show-device-attr-correctly-for-symlinks.patch:
  btrfs: Show device attr correctly for symlinks (FATE#306586).
- patches.suse/btrfs-simplify-our-write-path.patch: Btrfs:
  simplify our write path (FATE#306586).
- patches.suse/btrfs-stop-trying-to-shrink-delalloc-if-there-are-no.patch:
  Btrfs: stop trying to shrink delalloc if there are no inodes
  to reclaim (FATE#306586).
- patches.suse/btrfs-switch-the-extent-buffer-rbtree-into-a-radix-t.patch:
  Btrfs: Switch the extent buffer rbtree into a radix tree
  (FATE#306586).
- patches.suse/btrfs-the-file-argument-for-fsync-is-never-null.patch:
  Btrfs: The file argument for fsync() is never null
  (FATE#306586).
- patches.suse/btrfs-try-to-reclaim-some-space-when-chunk-allocatio.patch:
  btrfs: try to reclaim some space when chunk allocation fails
  (FATE#306586).
- patches.suse/btrfs-tune-the-chunk-allocation-to-5-of-the-fs-as-me.patch:
  Btrfs: tune the chunk allocation to 5%% of the FS as metadata
  (FATE#306586).
- patches.suse/btrfs-update-inode-ctime-when-using-links.patch:
  Btrfs: update inode ctime when using links (FATE#306586).
- patches.suse/btrfs-update-stats-when-allocating-from-a-cluster.patch:
  btrfs: Update stats when allocating from a cluster
  (FATE#306586).
- patches.suse/btrfs-use-a-slab-for-the-free-space-entries.patch:
  Btrfs: use a slab for the free space entries (FATE#306586).
- patches.suse/btrfs-use-async-helpers-for-dio-write-checksumming.patch:
  Btrfs: use async helpers for DIO write checksumming
  (FATE#306586).
- patches.suse/btrfs-use-dget_parent-where-we-can-updated.patch:
  Btrfs: use dget_parent where we can UPDATED (FATE#306586).
- patches.suse/btrfs-use-err_cast-helpers.patch: Btrfs: Use
  ERR_CAST helpers (FATE#306586).
- patches.suse/btrfs-use-gfp_nofs-instead-of-gfp_kernel.patch:
  btrfs: use GFP_NOFS instead of GFP_KERNEL (FATE#306586).
- patches.suse/btrfs-use-mark_inode_dirty-when-expanding-the-file.patch:
  Btrfs: use mark_inode_dirty when expanding the file
  (FATE#306586).
- patches.suse/btrfs-use-memdup_user-helpers.patch: Btrfs:
  use memdup_user helpers (FATE#306586).
- patches.suse/btrfs-use-rcu-instead-of-a-spinlock-to-protect-the-r.patch:
  Btrfs: use RCU instead of a spinlock to protect the root node
  (FATE#306586).
- patches.suse/btrfs-use-the-flusher-threads-for-delalloc-throttlin.patch:
  Btrfs: use the flusher threads for delalloc throttling
  (FATE#306586).
- patches.suse/btrfs-use-the-global-block-reserve-if-we-cannot-rese.patch:
  Btrfs: use the global block reserve if we cannot reserve space
  (FATE#306586).
- patches.suse/btrfs-using-cached-extent_state-in-set-unlock-combin.patch:
  btrfs: using cached extent_state in set/unlock combinations
  (FATE#306586).
- patches.suse/btrfs-write-out-free-space-cache.patch: Btrfs:
  write out free space cache (FATE#306586).
- patches.suse/direct-io-add-a-hook-for-the-fs-to-provide-its-own-s.patch:
  direct-io: add a hook for the fs to provide its own submit_bio
  function (FATE#306586).
- patches.suse/exportfs-return-the-minimum-required-handle-size.patch:
  exportfs: Return the minimum required handle size (FATE#306586).
- patches.suse/fs-add-fitrim-ioctl.patch: fs: Add FITRIM ioctl
  (FATE#306586).
- patches.suse/writeback-add-new-functions-for-triggering-inode-writeback.patch:
  Add new functions for triggering inode writeback (FATE#306586).
- patches.xen/tmem: Refresh.
* Fri Jun 10 2011 trenn@suse.de
- patches.arch/acpi_handle_root_level_devices.patch: ACPI:
  use _HID when supplied by root-level devices (bnc#684852).
* Fri Jun 10 2011 hare@suse.de
- Add missing fixes from 2.6.36:
  * patches.suse/blkio-Fix-return-code-for-mkdir-calls.patch:
    blkio: Fix return code for mkdir calls (FATE#311692).
  * patches.suse/block-fix-blk_rq_map_kern-bio-direction-flag.patch:
    block: fix blk_rq_map_kern bio direction flag (FATE#311692).
  * patches.suse/block-make-sure-that-REQ_-types-are-seen-even-with.patch:
    block: make sure that REQ_* types are seen even with
    CONFIG_BLOCK=n (FATE#311692).
  * patches.suse/cfq-iosched-Do-group-share-accounting-in-IOPS-when.patch:
    cfq-iosched: Do group share accounting in IOPS when slice_idle=0
    (FATE#311692).
  * patches.suse/cfq-iosched-Documentation-help-for-new-tunables.patch:
    cfq-iosched: Documentation help for new tunables (FATE#311692).
  * patches.suse/cfq-iosched-Implement-tunable-group_idle.patch:
    cfq-iosched: Implement tunable group_idle (FATE#311692).
  * patches.suse/cfq-iosched-blktrace-print-per-slice-sector-stats.patch:
    cfq-iosched: blktrace print per slice sector stats
    (FATE#311692).
  * patches.suse/cfq-iosched-fix-a-kernel-OOPs-when-usb-key-is-inser.patch:
    cfq-iosched: fix a kernel OOPs when usb key is inserted
    (FATE#311692).
  * patches.suse/sd-remove-q-prepare_flush_fn-completely.patch:
    block: remove q->prepare_flush_fn completely (FATE#311692).
- Rediff patches to apply:
  * patches.suse/block-add-secure-discard.patch
  * patches.suse/block-implement-an-unprep-function-corresponding-di.patch
  * patches.suse/block-remove-q-prepare_flush_fn-completely.patch
  * patches.suse/block-remove-wrappers-for-request-type-flags.patch
  * patches.suse/block-unify-flags-for-struct-bio-and-struct-request.patch
  * patches.suse/dm-do-not-initialise-full-request-queue-when-bio-ba.patch
  * patches.suse/dm-stop-using-q-prepare_flush_fn.patch
  * patches.suse/scsi-remove-wrappers-from-request-type-flags.patch
  * patches.suse/scsi-stop-using-q-prepare_flush_fn.patch
- series.conf: Re-enable fixes from 2.6.36
* Fri Jun 10 2011 mhocko@suse.cz
- patches.suse/cgroups-Add-WARN_ON-on-empty-subsystems.patch:
  Delete - no more needed after fixed
  patches.suse/cgroups-revamp-subsys-array.patch.
* Fri Jun 10 2011 mhocko@suse.cz
- patches.suse/cgroups-revamp-subsys-array.patch: Refresh - added
  forgotten part of the patch
* Thu Jun  9 2011 mhocko@suse.cz
- patches.fixes/oom-filter-tasks-not-sharing-the-same-cpuset.patch:
  oom: filter tasks not sharing the same cpuset (bnc#693636).
* Thu Jun  9 2011 hare@suse.de
- patches.suse/cgroups-Add-WARN_ON-on-empty-subsystems.patch:
  cgroups: Add WARN_ON on empty subsystems (FATE#311054).
- patches.suse/sched-cgroup-Fix-cgroup_subsys-exit-callback:
  Revert to original patch.
- series.conf: Disable patches.xen/xen-deprecate-barrier-fixup
  to make Xen build again.
* Thu Jun  9 2011 hare@suse.de
- Revert block backport to v2.6.35 level and disabling patches
- Add correct mainline version:
  * patches.suse/Revert-block-improve-queue_should_plug-by-lookin.patch
  * patches.suse/bio-fs-separate-out-bio_types.h-and-define-READ-WR.patch
  * patches.suse/bio-fs-update-RWA_MASK-READA-and-SWRITE-to-match.patch
  * patches.suse/bio-integrity.c-remove-dependency-on-__GFP_NOFAIL.patch
  * patches.suse/blk-cgroup-Fix-an-RCU-warning-in-blkiocg_create.patch
  * patches.suse/blkdev-add-blkdev_issue_zeroout-helper-function.patch:
  * patches.suse/blkdev-allow-async-blkdev_issue_flush-requests.patch:
  * patches.suse/blkdev-check-for-valid-request-queue-before-issuing.patch:
  * patches.suse/blkdev-fix-blkdev_issue_zeroout-return-value.patch:
  * patches.suse/blkdev-flush-disk-cache-on-fsync.patch: Refresh.
  * patches.suse/blkdev-generalize-flags-for-blkdev_issue_fn-functio.patch:
  * patches.suse/blkdev-move-blkdev_issue-helper-functions-to-separa.patch:
  * patches.suse/blkio-Add-io-controller-stats-like.patch
  * patches.suse/blkio-Increment-the-blkio-cgroup-stats-for-real-now.patch:
  * patches.suse/blkio-Remove-per-cfqq-nr_sectors-as-we-ll-be-passin.patch:
  * patches.suse/block-Adjust-elv_iosched_show-to-return-none-for.patch:
  * patches.suse/block-BARRIER-request-should-imply-SYNC.patch:
  * patches.suse/block-Don-t-count_vm_events-for-discard-bio-in-subm.patch:
  * patches.suse/block-Range-check-cpu-in-blk_cpu_to_group.patch:
  * patches.suse/block-add-function-call-to-switch-the-IO-scheduler.patch:
  * patches.suse/block-add-helpers-for-the-trivial-queue-flag-sysfs.patch:
  * patches.suse/block-add-secure-discard.patch: Refresh.
  * patches.suse/block-add-sysfs-knob-for-turning-off-disk-entropy-c.patch:
  * patches.suse/block-allow-initialization-of-previously-allocated.patch:
  * patches.suse/block-avoid-unconditionally-freeing-previously-allo.patch:
  * patches.suse/block-bd_start_claiming-cleanup.patch: Refresh.
  * patches.suse/block-bd_start_claiming-fix-module-refcount.patch:
  * patches.suse/block-disallow-FS-recursion-from-sb_issue_discard-a.patch:
  * patches.suse/block-don-t-allocate-a-payload-for-discard-request.patch:
  * patches.suse/block-factor-out-bd_may_claim.patch: Refresh.
  * patches.suse/block-fix-DISCARD_BARRIER-requests.patch: Refresh.
  * patches.suse/block-fix-bad-use-of-min-on-different-types.patch:
  * patches.suse/block-fix-bio.bi_rw-handling.patch: Refresh.
  * patches.suse/block-fix-missing-export-of-blk_types.h.patch:
  * patches.suse/block-fix-problem-with-sending-down-discard-that-is.patch:
  * patches.suse/block-fix-some-more-cmd_type-cleanup-fallout.patch:
  * patches.suse/block-ide-simplify-bdops-set_capacity-to-unloc.patch:
  * patches.suse/block-implement-an-unprep-function-corresponding-di.patch:
  * patches.suse/block-implement-bd_claiming-and-claiming-block.patch:
  * patches.suse/block-improve-automatic-native-capacity-unlocking.patch:
  * patches.suse/block-introduce-REQ_FLUSH-flag.patch: Refresh.
  * patches.suse/block-kill-ISA_DMA_THRESHOLD-usage.patch: Refresh.
  * patches.suse/block-make-blk_init_free_list-and-elevator_init-ide.patch:
  * patches.suse/block-permit-PREFLUSH-and-POSTFLUSH-without-prepare.patch:
  * patches.suse/block-prevent-merges-of-discard-and-write-requests.patch:
  * patches.suse/block-put-dev-kobj-in-blk_register_queue-fail-path.patch:
  * patches.suse/block-remove-all-rcu-head-initializations.patch:
  * patches.suse/block-remove-duplicate-BUG_ON-in-bd_finish_claimi.patch:
  * patches.suse/block-remove-q-prepare_flush_fn-completely.patch:
  * patches.suse/block-remove-unused-REQ_TYPE_LINUX_BLOCK.patch:
  * patches.suse/block-remove-wrappers-for-request-type-flags.patch:
  * patches.suse/block-restart-partition-scan-after-resizing-a-devic.patch:
  * patches.suse/block-set-REQ_TYPE_FS-on-flush-requests.patch:
  * patches.suse/block-set-up-rq-rq_disk-properly-for-flush-request.patch:
  * patches.suse/block-unify-flags-for-struct-bio-and-struct-request.patch:
  * patches.suse/block-update-request-stacking-methods-to-support-di.patch:
  * patches.suse/block-use-struct-parsed_partitions-state-universal.patch:
  * patches.suse/buffer-make-invalidate_bdev-drain-all-percpu-LRU.patch:
  * patches.suse/cfq-Don-t-allow-queue-merges-for-queues-that-have-n.patch:
  * patches.suse/cfq-iosched-Do-not-idle-if-slice_idle-0.patch:
  * patches.suse/cfq-iosched-compact-io_context-radix_tree.patch:
  * patches.suse/cfq-iosched-fix-an-oops-caused-by-slab-leak.patch:
  * patches.suse/cfq-iosched-remove-dead_key-from-cfq_io_context.patch:
  * patches.suse/coda-fixup-clash-with-block-layer-REQ_-defines.patch:
  * patches.suse/elevator-fix-oops-on-early-call-to-elevator_change.patch:
  * patches.suse/fs-bio-integrity.c-return-ENOMEM-on-kmalloc-failur.patch:
  * patches.suse/gcc-4.6-block-fix-unused-but-set-variables-in-blk.patch:
  * patches.suse/gfs2-replace-barriers-with-explicit-flush-FUA-usa.patch:
  * patches.suse/jbd2-Modify-ASYNC_COMMIT-code-to-not-rely-on-queue.patch:
  * patches.suse/kill-BH_Ordered-flag.patch: Refresh.
  * patches.suse/laptop-mode-Make-flushes-per-device.patch: Refresh.
  * patches.suse/perf-0001-Single-patch-that-merges-f4c4176-into-sles11.patch:
  * patches.suse/scatterlist-prevent-invalid-free-when-alloc-fails.patch:
  * patches.suse/sched-cgroup-Fix-cgroup_subsys-exit-callback:
  * patches.suse/vfs-don-t-hold-s_umount-over-close_bdev_exclusive.patch:
  * patches.suse/vfs-rename-block_fsync-to-blkdev_fsync.patch:
- Add missing patches from v2.6.35:
  * patches.suse/blk-cgroup-config-options-re-arrangement.patch:
    blk-cgroup: config options re-arrangement (FATE#311054).
  * patches.suse/blkio-Add-io_merged-stat.patch: blkio: Add
    io_merged stat (FATE#311054).
  * patches.suse/blkio-Add-io_queued-and-avg_queue_size-stats.patch:
    blkio: Add io_queued and avg_queue_size stats (FATE#311692).
  * patches.suse/blkio-Add-more-debug-only-per-cgroup-stats.patch:
    blkio: Add more debug-only per-cgroup stats (FATE#311692).
  * patches.suse/blkio-Changes-to-IO-controller-additional-stats-pat.patch:
    blkio: Changes to IO controller additional stats patches
    (FATE#311692).
  * patches.suse/blkio-Fix-another-BUG_ON-crash-due-to-cfqq-moveme.patch:
    blkio: Fix another BUG_ON() crash due to cfqq movement across
    groups (FATE#311692).
  * patches.suse/blkio-Fix-blkio-crash-during-rq-stat-update.patch:
    blkio: Fix blkio crash during rq stat update (FATE#311692).
  * patches.suse/blkio-Initialize-blkg-stats_lock-for-the-root-cfqg.patch:
    blkio: Initialize blkg->stats_lock for the root cfqg too
    (FATE#311692).
  * patches.suse/blkio-fix-compile-errors.patch: blkio: Fix compile
    errors (FATE#311692).
  * patches.suse/blkio-fix-for-modular-blk-cgroup-build.patch:
    blkio: fix for modular blk-cgroup build (FATE#311692).
  * patches.suse/block-Update-to-io-controller-stats.patch: block:
    Update to io-controller stats (FATE#311692).
  * patches.suse/block-blk_rq_err_sectors-cleanup.patch: block:
    blk_rq_err_sectors cleanup (FATE#311692).
  * patches.suse/block-disable-preemption-before-using-sched_clock.patch:
    Update references (FATE#311693).
  * patches.suse/block-kill-some-useless-goto-s-in-blk-cgroup.c.patch:
    block: kill some useless goto's in blk-cgroup.c (FATE#311692).
  * patches.suse/btrfs-discard-flags-update: blkdev: generalize
    flags for blkdev_issue_fn functions (FATE#311692).
  * patches.suse/cfq-fix-recursive-call-in-cfq_blkiocg_update_c.patch:
    cfq: fix recursive call in cfq_blkiocg_update_completion_stats()
    (FATE#311692).
  * patches.suse/cfq-iosched-Fixed-boot-warning-with-BLK_CGROUP.patch:
    cfq-iosched: Fixed boot warning with BLK_CGROUP=y and
    CFQ_GROUP_IOSCHED=n (FATE#311692).
  * patches.suse/cfq-iosched-fix-broken-cfq_ref_get_cfqf-for-CONFI.patch:
    cfq-iosched: fix broken cfq_ref_get_cfqf() for
    CONFIG_BLK_CGROUP=y && CFQ_GROUP_IOSCHED=n (FATE#311692).
  * patches.suse/cgroups-blkio-subsystem-as-module.patch: cgroups:
    blkio subsystem as module (FATE#311692).
  * patches.suse/cgroups-fix-CONTENTS-in-cgroups-documentation.patch:
    cgroups: fix CONTENTS in cgroups documentation (FATE#311692).
  * patches.suse/cgroups-revamp-subsys-array.patch: cgroups:
    revamp subsys array (FATE#311692).
  * patches.suse/cgroups-subsystem-module-loading-interface.patch:
    cgroups: subsystem module loading interface (FATE#311692).
  * patches.suse/cgroups-subsystem-module-unloading.patch: cgroups:
    subsystem module unloading (FATE#311692).
  * patches.suse/gfs2-generalize-flags-for-blkdev_issue_fn-functio.patch:
    blkdev: generalize flags for blkdev_issue_fn functions
    (FATE#311054).
  * patches.suse/io-controller-Add-a-new-interface-weight_device-f.patch:
    io-controller: Add a new interface "weight_device" for
    IO-Controller (FATE#311692).
  * patches.suse/io-controller-Document-for-blkio.weight_device-f.patch:
    io-controller: Document for blkio.weight_device (FATE#311692).
* Thu Jun  9 2011 trenn@suse.de
  moved patches down which allows compilation of partly applied
  series.conf (does not fix all cases, but a large part will
  compile again now):
- patches.suse/kvm-mm-thp-mmu-notifier-test_young.patch: thp:
  mmu_notifier_test_young (THP core (fate #311931)).
- patches.suse/mm-thp-mmu-notifier-test_young.patch: Delete.
* Thu Jun  9 2011 jbeulich@novell.com
- patches.xen/1089-blkback-barrier-check.patch: xen/blkback: don't fail
  empty barrier requests.
- patches.xen/1090-blktap-locking.patch: xen/blktap: fix locking
  (bnc#685276).
- patches.xen/1091-xenbus-dev-no-BUG.patch: xenbus: don't BUG() on user
  mode induced conditions (bnc#696107).
- Refresh other Xen patches.
* Thu Jun  9 2011 mhocko@suse.cz
- patches.fixes/Fix-for-buffer-overflow-in-ldm_frag_add-not-sufficie.patch:
  Fix for buffer overflow in ldm_frag_add not sufficient
  (bnc#698221, CVE-2011-1017, CVE-2011-2182).
* Wed Jun  8 2011 mgalbraith@suse.de
- Update config files.
- (oops)
* Wed Jun  8 2011 mgalbraith@suse.de
- Add remaining FATE#311860 patches, and refresh/enable the rest.
- patches.suse/arch-s390-kernel-Add-missing-unlock:
  arch/s390/kernel: Add missing unlock (FATE#311860).
- patches.suse/s390-Move-__cpu_logical_map-to-smp-dot-c:
  Move __cpu_logical_map to smp.c (FATE#311860).
- patches.suse/s390-smp-Remove-volatile-type-quilifier-from-__cpu_logical_map:
  smp: remove volatile type quilifier from __cpu_logical_map (FATE#311860).
- patches.suse/sched-Add-book-scheduling-domain:
  Update references (FATE#311860).
- patches.suse/sched-Create-special-class-for-stop-and-migrate-work:
  Refresh.
- patches.suse/topology-s390-Add-z11-cpu-topology-support:
  Update references (FATE#311860).
- patches.suse/topology-s390-change-default:
  topology: change default (FATE#311860).
- patches.suse/topology-s390-expose-core-identifier:
  Update references (FATE#311860).
- patches.suse/topology-s390-fix-cpu-masks-for-topology-off-case:
  topology: fix cpu masks for topology=off case (FATE#311860).
- patches.suse/topology-s390-sched-fix-cpu_coregroup_mask-cpu_book_mask-definitions:
  topology,sched: fix cpu_coregroup_mask/cpu_book_mask definitions (FATE#311860).
- patches.suse/topology-s390-use-default-MC-domain-initializer:
  topology: use default MC domain initializer (FATE#311860).
- patches.suse/topology-sysfs-Provide-book-id-and-siblings-attributes:
  Update references (FATE#311860).
* Wed Jun  8 2011 mhocko@suse.cz
- patches.suse/memcg-convert-uncharge-batching-from-bytes-to-page-g.patch:
  memcg: convert uncharge batching from bytes to page granularity
  (fate#311931, bnc#697913).
- patches.suse/memcg-unify-charge-uncharge-quantities-to-units-of-pages.patch:
  memcg: unify charge/uncharge quantities to units of pages
  (fate#311931, bnc#697913).
- patches.suse/perfmon2.patch: Refresh.
* Wed Jun  8 2011 tonyj@suse.de
- patches.fixes/perf-enable-on-exec.patch: perf record: Enable
  the enable_on_exec flag if record forks the target (FATE#312124,
  BNC#665999).
- patches.fixes/perf-ppc64-symbol-resolution.patch: perf symbols:
  Function descriptor symbol lookup (FATE#312124, BNC#665999).
* Wed Jun  8 2011 trenn@suse.de
- patches.arch/x86_powernow_k8_remove_zero_latency_warning.patch:
  cpufreq powernow-k8: Remove firmware warning in zero transition
  latency case (bnc#698604).
* Wed Jun  8 2011 mgalbraith@suse.de
- Apply fixes for stable 3b4b7c75 mainline 86cbfb56 induced explosions
- patches.fixes/block-Export-blk_get_queue-and-blk_put_queue:
  block: export blk_{get,put}_queue().
- patches.fixes/block-add-proper-guards-to-elv_queue_empty:
  block: add proper state guards to elv_queue_empty()
  (https://lkml.org/lkml/2011/6/3/33).
- patches.fixes/scsi-Fix-oops-caused-by-queue-refcounting-failure:
  Fix oops caused by queue refcounting failure.
* Wed Jun  8 2011 tonyj@suse.de
- Update config files.
- patches.suse/perf-0001-Single-patch-that-merges-f4c4176-into-sles11.patch:
  Refresh.
- patches.xen/xen-perf-2.6.33.patch: Xen fixes for AMD perf update
  (FATE#311392, BNC#685313).
* Wed Jun  8 2011 jjolly@suse.de
- patches.drivers/rdma_cm-01-lock.patch: rdma/addr:
  use appropriate locking with for_each_netdev
  (FATE#311652,bnc#695605).
- patches.drivers/rdma_cm-02-mc0.patch: RDMA CM: Correct detection
  of SA Created MGID (FATE#311652,bnc#695605).
- patches.drivers/rdma_cm-03-mc1.patch: RDMA CM: Fix AF_INET6
  support in multicast joining (FATE#311652,bnc#695605).
- patches.drivers/rdma_cm-04-ifindex.patch: rdma/cm: replace
  net_device pointer with index (FATE#311652,bnc#695605).
- patches.drivers/rdma_cm-05-addr_chk.patch: ib/addr:
  verify source and destination address families match
  (FATE#311652,bnc#695605).
- patches.drivers/rdma_cm-06-dev_type.patch: ib/addr: store
  net_device type instead of translating to RDMA transport
  (FATE#311652,bnc#695605).
- patches.drivers/rdma_cm-07-resolve_loopback.patch: rdma/cm:
  fix loopback address support (FATE#311652,bnc#695605).
- patches.drivers/rdma_cm-08-resolve_ip4.patch: ib/addr: simplify
  resolving IPv4 addresses (FATE#311652,bnc#695605).
- patches.drivers/rdma_cm-09-resolve_ip6.patch: ib/addr: fix
  ipv6 routing lookup (FATE#311652,bnc#695605).
- patches.drivers/rdma_cm-10-revert.patch: rdma/cm: revert
  associating an RDMA device when binding to loopback
  (FATE#311652,bnc#695605).
* Tue Jun  7 2011 duwe@suse.de
- patches.arch/ppc-dynamic-dmawin: powerpc/pseries: Add support
  for dynamic dma windows (FATE#311558, bnc#695066).
- patches.arch/ppc-dynamic-dmawin-kexec+iommu-fixes: powerpc:
  various fixes for dynamic DMA windows (FATE#311558, bnc#695066).
- patches.arch/ppc-memory_hotplug_max: powerpc: Add
  memory_hotplug_max() (FATE#311558, bnc#695066).
- patches.arch/ppc-platform-override-dma_set_mask: powerpc/dma:
  Add optional platform override of dma_set_mask() (FATE#311558,
  bnc#695066).
- patches.arch/ppc-tune-rtas_busy_delay: powerpc/rtas: Only sleep
  in rtas_busy_delay if we have useful work to do (FATE#311558,
  bnc#695066).
* Tue Jun  7 2011 tonyj@suse.de
- Added patches.suse/perf-{0001-0279}*.patch (FATE#311392, BNC#685313)
- patches.xen/kexec-move-segment-code-i386.patch: Refresh.
- patches.xen/xen3-auto-arch-i386.diff: Refresh.
- patches.xen/xen3-auto-arch-x86.diff: Refresh.
- patches.xen/xen3-auto-arch-x86_64.diff: Refresh.
- patches.xen/xen3-patch-2.6.25: Refresh.
- patches.xen/xen3-patch-2.6.27: Refresh.
- patches.xen/xen3-patch-2.6.28: Refresh.
- patches.xen/xen3-patch-2.6.30: Refresh.
- patches.xen/xen3-patch-2.6.31: Refresh.
- patches.xen/xen3-patch-2.6.32.11-12: Refresh.
- Xen sequences but does not build.
* Tue Jun  7 2011 hare@suse.de
- patches.suse/block-drop-barrier-ordering-by-queue-draining.patch:
  Rediff to have it applied.
* Tue Jun  7 2011 hare@suse.de
- patches.suse/block-drop-barrier-ordering-by-queue-draining.patch:
  Fixup merge error.
- patches.suse/block-remove-wrappers-for-request-type-flags.patch:
  Refresh.
* Tue Jun  7 2011 hare@suse.de
- patches.xen/xen-deprecate-barrier-fixup: Fixup Xen drivers
  after FLUSH/FUA conversion (FATE#311692).
* Tue Jun  7 2011 hare@suse.de
- patches.suse/block-remove-wrappers-for-request-type-flags.patch:
  Fix copy and paste error: Use blk_rq_bytes() instead of blk_rq_sectors().
* Tue Jun  7 2011 hare@suse.de
- supported.conf: Mark libahci as supported.
* Mon Jun  6 2011 duwe@suse.de
- patches.arch/ppc-detect-form1-affinity-using-ibm,architecture-vec-5:
  powerpc/numa: Use ibm,architecture-vec-5 to detect form 1
  affinity (FATE#311725, bnc#695067).
- patches.arch/ppc-form1-affinity-node-distance: dito.
- patches.arch/ppc-smaller-reclaim_distance:
  Set a smaller value for RECLAIM_DISTANCE to enable
  zone reclaim (FATE#311725, bnc#695067)
- open series.conf section for m68k arch
  (for whatever reason Hannes or T-Systems need that ;-)
* Mon Jun  6 2011 mhocko@suse.cz
- patches.fixes/mm-memcg-modify-accounting-for-THP-fix.patch:
  Handle file type for mem_cgroup_charge_statistics correctly
  (bnc#697913).
- patches.fixes/mm-memcg-modify-accounting-for-THP-fix2.patch:
  Fix page in/out accounting (bnc#697913).
- patches.fixes/mm-thp-memcg-compound-reimplementation-fix.patch:
  Fix cmem_cgroup_cancel_carge units (bnc#697913).
- patches.suse/mm-memcg-fix-USED-bit-handling-for-THP.patch:
  Refresh.
- patches.suse/mm-memcg-fix-event-counting-with-THP.patch:
  Refresh.
- patches.suse/mm-memcg-fix-rmdir-with-THP.patch: Refresh.
- patches.suse/mm-thp-compound_trans_order.patch: Refresh.
* Mon Jun  6 2011 hare@suse.de
- Fixup patches for series2git:
- patches.rpmify/gdth-section-conflict: Refresh.
- patches.suse/brd-unify-flags-for-struct-bio-and-struct-request.patch:
  Refresh.
- patches.suse/dm-mpath-leastpending-path-update: Refresh.
- patches.suse/dm-remove-wrappers-for-request-type-flags.patch:
  Refresh.
- patches.suse/dm-unify-flags-for-struct-bio-and-struct-request.patch:
  Refresh.
- patches.suse/ide-deprecate-barrier-and-replace-blk_queue_order.patch:
  Refresh.
- patches.suse/md-unify-flags-for-struct-bio-and-struct-request.patch:
  Refresh.
- patches.suse/scsi-deprecate-barrier-and-replace-blk_queue_order.patch:
  Refresh.
- patches.suse/scsi-netlink-ml: Refresh.
- patches.suse/virtio-blk-kill-QUEUE_ORDERED_BY_TAG.patch:
  Refresh.
- patches.xen/sfc-driverlink: Refresh.
* Mon Jun  6 2011 hare@suse.de
- patches.suse/block-unify-flags-for-struct-bio-and-struct-request.patch:
  Fixup broken patch.
* Mon Jun  6 2011 hare@suse.de
- Backport fixes from 2.6.36 and turn HARDBARRIER into a
  Flush/FUA sequence (FATE#311692):
- Update config files.
- patches.suse/NCR5380-bit-MR_DMA_MODE-set-twice-in-NCR5380_transf.patch:
  NCR5380: bit MR_DMA_MODE set twice in NCR5380_transfer_dma()
  (FATE#311692).
- patches.suse/aacraid-Do-not-set-DMA-mask-to-32-bit-first.patch:
  [SCSI] aacraid: Do not set DMA mask to 32 bit first if adapter
  only supports 31 (FATE#311692).
- patches.suse/aacraid-add-an-ifdef-d-device-delete-case-in.patch:
  [SCSI] aacraid: add an ifdef'd device delete case instead of
  taking the device offline (FATE#311692).
- patches.suse/aacraid-add-support-for-handling-ATA-pass-th.patch:
  [SCSI] aacraid: add support for handling ATA pass-through
  commands (FATE#311692).
- patches.suse/aacraid-expose-physical-devices-for-models-w.patch:
  [SCSI] aacraid: expose physical devices for models with newer
  firmware (FATE#311692).
- patches.suse/aacraid-prohibit-access-to-array-container-s.patch:
  [SCSI] aacraid: prohibit access to array container space
  (FATE#311692).
- patches.suse/aacraid-respond-automatically-to-volumes-add.patch:
  [SCSI] aacraid: respond automatically to volumes added by
  config tool (FATE#311692).
- patches.suse/aha1532-remove-ISA_DMA_THRESHOLD-usage.patch:
  aha1532: remove ISA_DMA_THRESHOLD usage (FATE#311692).
- patches.suse/ahci-Add-platform-driver.patch: ahci: Add platform
  driver (FATE#311692).
- patches.suse/ahci-EM-message-type-auto-detect.patch: ahci:
  EM message type auto detect (FATE#311692).
- patches.suse/ahci-Factor-out-PCI-specifics-from-ahci_init_contro.patch:
  ahci: Factor out PCI specifics from ahci_init_controller()
  (FATE#311692).
- patches.suse/ahci-Factor-out-PCI-specifics-from-ahci_print_info.patch:
  ahci: Factor out PCI specifics from ahci_print_info()
  (FATE#311692).
- patches.suse/ahci-Factor-out-PCI-specifics-from-ahci_reset_contr.patch:
  ahci: Factor out PCI specifics from ahci_reset_controller()
  (FATE#311692).
- patches.suse/ahci-Factor-out-PCI-specifics-from-ahci_save_initia.patch:
  ahci: Factor out PCI specifics from ahci_save_initial_config()
  (FATE#311692).
- patches.suse/ahci-Fix-warning-comparison-between-enum.patch:
  [libata] ahci: Fix warning: comparison between 'enum
  <anonymous>' and 'enum <anonymous>' (FATE#311692).
- patches.suse/ahci-Get-rid-of-host-iomap-usage.patch: ahci:
  Get rid of host->iomap usage (FATE#311692).
- patches.suse/ahci-Get-rid-of-pci_dev-argument-in-ahci_port_init.patch:
  ahci: Get rid of pci_dev argument in ahci_port_init()
  (FATE#311692).
- patches.suse/ahci-Get-rid-of-pci_dev-argument-in-ahci_save_initi.patch:
  ahci: Get rid of pci_dev argument in ahci_save_initial_config()
  (FATE#311692).
- patches.suse/ahci-Implement-SATA-AHCI-FIS-based-switching-suppor.patch:
  ahci: Implement SATA AHCI FIS-based switching support
  (FATE#311692).
- patches.suse/ahci-Introduce-ahci_set_em_messages.patch: ahci:
  Introduce ahci_set_em_messages() (FATE#311692).
- patches.suse/ahci-Move-generic-code-into-libahci.patch: ahci:
  Move generic code into libahci (FATE#311692).
- patches.suse/ahci-Turn-off-DMA-engines-when-there-s-no-device-at.patch:
  ahci: Turn off DMA engines when there's no device attached
  (FATE#311692).
- patches.suse/ahci-add-HFLAG_YES_FBS-and-apply-it-to-88SE9128.patch:
  ahci: add HFLAG_YES_FBS and apply it to 88SE9128 (FATE#311692).
- patches.suse/ahci-add-em_buffer-attribute-for-AHCI-hosts.patch:
  ahci: add "em_buffer" attribute for AHCI hosts (FATE#311692).
- patches.suse/ahci-add-missing-nv-IDs.patch: ahci: add missing
  nv IDs (FATE#311692).
- patches.suse/ahci-clean-up-board-IDs.patch: ahci: clean up
  board IDs (FATE#311692).
- patches.suse/ahci-fix-hang-on-failed-softreset.patch: ahci:
  fix hang on failed softreset (FATE#311692).
- patches.suse/ahci-fix-module-refcount-breakage-introduced-by-lib.patch:
  ahci: fix module refcount breakage introduced by libahci split
  (FATE#311692).
- patches.suse/ahci-implement-AHCI_HFLAG_NO_FPDMA_AA-and-update-NV.patch:
  ahci: implement AHCI_HFLAG_NO_FPDMA_AA and update NV quirks
  (FATE#311692).
- patches.suse/ahci-pp-active_link-is-not-reliable-when-FBS-is-en.patch:
  ahci: pp->active_link is not reliable when FBS is enabled
  (FATE#311692).
- patches.suse/ahci-redo-stopping-DMA-engines-on-empty-ports.patch:
  ahci: redo stopping DMA engines on empty ports (FATE#311692).
- patches.suse/ahci_platform-Provide-for-vendor-specific-init.patch:
  ahci_platform: Provide for vendor specific init (FATE#311692).
- patches.suse/ahci_platform-Remove-unneeded-ahci_driver.probe-ass.patch:
  ahci_platform: Remove unneeded ahci_driver.probe assignment
  (FATE#311692).
- patches.suse/ahci_platform-properly-set-up-EM-messaging.patch:
  ahci_platform: properly set up EM messaging (FATE#311692).
- patches.suse/aic94xx-aic94xx_init.c-correct-the-siz.patch:
  drivers/scsi/aic94xx/aic94xx_init.c: correct the size argument
  to kmalloc (FATE#311692).
- patches.suse/arcmsr-Support-1024-scatter-gather-list-entr.patch:
  [SCSI] arcmsr: Support 1024 scatter-gather list entries and
  improve AP while FW trapped and behaviors of EHs (FATE#311692).
- patches.suse/arcmsr-Support-HW-reset-for-EH-and-polling-s.patch:
  [SCSI] arcmsr: Support HW reset for EH and polling scheme for
  scsi device (FATE#311692).
- patches.suse/ata-Convert-pci_table-entries-to-PCI_VDEVICE-if-PC.patch:
  ata: Convert pci_table entries to PCI_VDEVICE (if PCI_ANY_ID
  is used) (FATE#311692).
- patches.suse/ata-Detect-Delkin-Devices-compact-flash.patch:
  ata: Detect Delkin Devices compact flash (FATE#311692).
- patches.suse/ata_generic-drop-hard-coded-DMA-force-logic-for-CEN.patch:
  ata_generic: drop hard coded DMA force logic for CENATEK
  (FATE#311692).
- patches.suse/ataflop-Killl-warning-about-unused-variable-flags.patch:
  Refresh.
- patches.suse/bio-fs-separate-out-bio_types.h-and-define-READ-WR.patch:
  bio, fs: separate out bio_types.h and define READ/WRITE
  constants in terms of BIO_RW_* flags (FATE#311692).
- patches.suse/bio-fs-update-RWA_MASK-READA-and-SWRITE-to-match.patch:
  bio, fs: update RWA_MASK, READA and SWRITE to match the
  corresponding BIO_RW_* bits (FATE#311692).
- patches.suse/bio-integrity.c-remove-dependency-on-__GFP_NOFAIL.patch:
  bio-integrity.c: remove dependency on __GFP_NOFAIL
  (FATE#311692).
- patches.suse/blkdev-add-blkdev_issue_zeroout-helper-function.patch:
  blkdev: add blkdev_issue_zeroout helper function (FATE#311692).
- patches.suse/blkdev-allow-async-blkdev_issue_flush-requests.patch:
  blkdev: allow async blkdev_issue_flush requests (FATE#311692).
- patches.suse/blkdev-check-for-valid-request-queue-before-issuing.patch:
  blkdev: check for valid request queue before issuing flush
  (FATE#311692).
- patches.suse/blkdev-fix-blkdev_issue_zeroout-return-value.patch:
  blkdev: fix blkdev_issue_zeroout return value (FATE#311692).
- patches.suse/blkdev-flush-disk-cache-on-fsync.patch: blkdev:
  flush disk cache on ->fsync (FATE#311692).
- patches.suse/blkdev-generalize-flags-for-blkdev_issue_fn-functio.patch:
  blkdev: generalize flags for blkdev_issue_fn functions
  (FATE#311692).
- patches.suse/blkdev-move-blkdev_issue-helper-functions-to-separa.patch:
  blkdev: move blkdev_issue helper functions to separate file
  (FATE#311692).
- patches.suse/block-Adjust-elv_iosched_show-to-return-none-for.patch:
  block: Adjust elv_iosched_show to return "none" for bio-based DM
  (FATE#311692).
- patches.suse/block-BARRIER-request-should-imply-SYNC.patch:
  block: BARRIER request should imply SYNC (FATE#311692).
- patches.suse/block-Don-t-count_vm_events-for-discard-bio-in-subm.patch:
  block: Don't count_vm_events for discard bio in submit_bio
  (FATE#311692).
- patches.suse/block-Range-check-cpu-in-blk_cpu_to_group.patch:
  block: Range check cpu in blk_cpu_to_group (FATE#311692).
- patches.suse/block-add-function-call-to-switch-the-IO-scheduler.patch:
  block: add function call to switch the IO scheduler from a
  driver (FATE#311692).
- patches.suse/block-add-helpers-for-the-trivial-queue-flag-sysfs.patch:
  block: add helpers for the trivial queue flag sysfs show/store
  entries (FATE#311692).
- patches.suse/block-add-secure-discard.patch: block: add secure
  discard (FATE#311692).
- patches.suse/block-add-sysfs-knob-for-turning-off-disk-entropy-c.patch:
  block: add sysfs knob for turning off disk entropy contributions
  (FATE#311692).
- patches.suse/block-allow-initialization-of-previously-allocated.patch:
  block: allow initialization of previously allocated
  request_queue (FATE#311692).
- patches.suse/block-avoid-unconditionally-freeing-previously-allo.patch:
  block: avoid unconditionally freeing previously allocated
  request_queue (FATE#311692).
- patches.suse/block-bd_start_claiming-cleanup.patch: block:
  bd_start_claiming cleanup (FATE#311692).
- patches.suse/block-bd_start_claiming-fix-module-refcount.patch:
  block: bd_start_claiming fix module refcount (FATE#311692).
- patches.suse/block-deprecate-barrier-and-replace-blk_queue_order.patch:
  block: deprecate barrier and replace blk_queue_ordered()
  with blk_queue_flush() (FATE#311692).
- patches.suse/block-disable-preemption-before-using-sched_clock.patch:
  block: disable preemption before using sched_clock()
  (FATE#311692).
- patches.suse/block-disallow-FS-recursion-from-sb_issue_discard-a.patch:
  block: disallow FS recursion from sb_issue_discard allocation
  (FATE#311692).
- patches.suse/block-don-t-allocate-a-payload-for-discard-request.patch:
  block: don't allocate a payload for discard request
  (FATE#311692).
- patches.suse/block-drop-barrier-ordering-by-queue-draining.patch:
  block: drop barrier ordering by queue draining (FATE#311692).
- patches.suse/block-expose-the-statistics-in-blkio.time-and-blkio.patch:
  Refresh.
- patches.suse/block-factor-out-bd_may_claim.patch: block:
  factor out bd_may_claim() (FATE#311692).
- patches.suse/block-filter-flush-bio-s-in-__generic_make_request.patch:
  block: filter flush bio's in __generic_make_request()
  (FATE#311692).
- patches.suse/block-fix-DISCARD_BARRIER-requests.patch: block:
  fix DISCARD_BARRIER requests (FATE#311692).
- patches.suse/block-fix-bad-use-of-min-on-different-types.patch:
  block: fix bad use of min() on different types (FATE#311692).
- patches.suse/block-fix-bio.bi_rw-handling.patch: BLOCK: fix
  bio.bi_rw handling (FATE#311692).
- patches.suse/block-fix-missing-export-of-blk_types.h.patch:
  block: fix missing export of blk_types.h (FATE#311692).
- patches.suse/block-fix-problem-with-sending-down-discard-that-is.patch:
  block: fix problem with sending down discard that isn't of
  correct granularity (FATE#311692).
- patches.suse/block-fix-some-more-cmd_type-cleanup-fallout.patch:
  block: fix some more cmd_type cleanup fallout (FATE#311692).
- patches.suse/block-ide-simplify-bdops-set_capacity-to-unloc.patch:
  block,ide: simplify bdops->set_capacity() to
  - >unlock_native_capacity() (FATE#311692).
- patches.suse/block-implement-REQ_FLUSH-FUA-based-interface-for-F.patch:
  block: implement REQ_FLUSH/FUA based interface for FLUSH/FUA
  requests (FATE#311692).
- patches.suse/block-implement-an-unprep-function-corresponding-di.patch:
  block: implement an unprep function corresponding directly to
  prep (FATE#311692).
- patches.suse/block-implement-bd_claiming-and-claiming-block.patch:
  block: implement bd_claiming and claiming block (FATE#311692).
- patches.suse/block-improve-automatic-native-capacity-unlocking.patch:
  block: improve automatic native capacity unlocking
  (FATE#311692).
- patches.suse/block-initialize-flush-request-with-WRITE_FLUSH-ins.patch:
  block: initialize flush request with WRITE_FLUSH instead of
  REQ_FLUSH (FATE#311692).
- patches.suse/block-introduce-REQ_FLUSH-flag.patch: block:
  introduce REQ_FLUSH flag (FATE#311692).
- patches.suse/block-kick-queue-after-sequencing-REQ_FLUSH-FUA.patch:
  block: kick queue after sequencing REQ_FLUSH/FUA (FATE#311692).
- patches.suse/block-kill-ISA_DMA_THRESHOLD-usage.patch: block:
  kill ISA_DMA_THRESHOLD usage (FATE#311692).
- patches.suse/block-kill-QUEUE_ORDERED_BY_TAG.patch: block:
  kill QUEUE_ORDERED_BY_TAG (FATE#311692).
- patches.suse/block-loop-implement-REQ_FLUSH-FUA-support.patch:
  block/loop: implement REQ_FLUSH/FUA support (FATE#311692).
- patches.suse/block-make-__blk_rq_prep_clone-copy-most-command.patch:
  block: make __blk_rq_prep_clone() copy most command flags
  (FATE#311692).
- patches.suse/block-make-blk_init_free_list-and-elevator_init-ide.patch:
  block: make blk_init_free_list and elevator_init idempotent
  (FATE#311692).
- patches.suse/block-make-sure-FSEQ_DATA-request-has-the-same-rq_d.patch:
  block: make sure FSEQ_DATA request has the same rq_disk as
  the original (FATE#311692).
- patches.suse/block-misc-cleanups-in-barrier-code.patch: block:
  misc cleanups in barrier code (FATE#311692).
- patches.suse/block-pass-gfp_mask-and-flags-to-sb_issue_discard.patch:
  block: pass gfp_mask and flags to sb_issue_discard
  (FATE#311692).
- patches.suse/block-permit-PREFLUSH-and-POSTFLUSH-without-prepare.patch:
  block: permit PREFLUSH and POSTFLUSH without prepare_flush_fn
  (FATE#311692).
- patches.suse/block-prevent-merges-of-discard-and-write-requests.patch:
  block: prevent merges of discard and write requests
  (FATE#311692).
- patches.suse/block-put-dev-kobj-in-blk_register_queue-fail-path.patch:
  block: put dev->kobj in blk_register_queue fail path
  (FATE#311692).
- patches.suse/block-remove-REQ_HARDBARRIER.patch: block: remove
  REQ_HARDBARRIER (FATE#311692).
- patches.suse/block-remove-all-rcu-head-initializations.patch:
  block: remove all rcu head initializations (FATE#311692).
- patches.suse/block-remove-duplicate-BUG_ON-in-bd_finish_claimi.patch:
  block: remove duplicate BUG_ON() in bd_finish_claiming()
  (FATE#311692).
- patches.suse/block-remove-q-prepare_flush_fn-completely.patch:
  block: remove q->prepare_flush_fn completely (FATE#311692).
- patches.suse/block-remove-spurious-uses-of-REQ_HARDBARRIER.patch:
  block: remove spurious uses of REQ_HARDBARRIER (FATE#311692).
- patches.suse/block-remove-the-BH_Eopnotsupp-flag.patch: block:
  remove the BH_Eopnotsupp flag (FATE#311692).
- patches.suse/block-remove-the-BLKDEV_IFL_BARRIER-flag.patch:
  block: remove the BLKDEV_IFL_BARRIER flag (FATE#311692).
- patches.suse/block-remove-the-WRITE_BARRIER-flag.patch: block:
  remove the WRITE_BARRIER flag (FATE#311692).
- patches.suse/block-remove-unused-REQ_TYPE_LINUX_BLOCK.patch:
  block: remove unused REQ_TYPE_LINUX_BLOCK (FATE#311692).
- patches.suse/block-remove-wrappers-for-request-type-flags.patch:
  block: remove wrappers for request type/flags (FATE#311692).
- patches.suse/block-rename-barrier-ordered-to-flush.patch:
  block: rename barrier/ordered to flush (FATE#311692).
- patches.suse/block-rename-blk-barrier.c-to-blk-flush.c.patch:
  block: rename blk-barrier.c to blk-flush.c (FATE#311692).
- patches.suse/block-restart-partition-scan-after-resizing-a-devic.patch:
  block: restart partition scan after resizing a device
  (FATE#311692).
- patches.suse/block-set-REQ_TYPE_FS-on-flush-requests.patch:
  block: set REQ_TYPE_FS on flush requests (FATE#311692).
- patches.suse/block-set-up-rq-rq_disk-properly-for-flush-request.patch:
  block: set up rq->rq_disk properly for flush requests
  (FATE#311692).
- patches.suse/block-simplify-queue_next_fseq.patch: block:
  simplify queue_next_fseq (FATE#311692).
- patches.suse/block-switch-s390-tape_block-and-mg_disk-to-elevato.patch:
  block: switch s390 tape_block and mg_disk to elevator_change()
  (FATE#311692).
- patches.suse/block-unify-flags-for-struct-bio-and-struct-request.patch:
  block: unify flags for struct bio and struct request
  (FATE#311692).
- patches.suse/block-update-documentation-for-REQ_FLUSH-REQ_FUA.patch:
  block: update documentation for REQ_FLUSH / REQ_FUA
  (FATE#311692).
- patches.suse/block-update-request-stacking-methods-to-support-di.patch:
  block: update request stacking methods to support discards
  (FATE#311692).
- patches.suse/block-use-REQ_FLUSH-in-blkdev_issue_flush.patch:
  block: use REQ_FLUSH in blkdev_issue_flush() (FATE#311692).
- patches.suse/block-use-struct-parsed_partitions-state-universal.patch:
  block: use struct parsed_partitions *state universally in
  partition check code (FATE#311692).
- patches.suse/block-xd.c-fix-brace-typo.patch: block/xd.c:
  fix brace typo (FATE#311692).
- patches.suse/bnx2i-Added-host-param-ISCSI_HOST_PARAM_IPAD.patch:
  [SCSI] bnx2i: Added host param ISCSI_HOST_PARAM_IPADDRESS
  (FATE#311692).
- patches.suse/bnx2i-Created-an-active-linklist-which-holds.patch:
  [SCSI] bnx2i: Created an active linklist which holds bnx2i
  endpoints (FATE#311692).
- patches.suse/bnx2i-Fine-tuned-conn-destroy-and-context-de.patch:
  [SCSI] bnx2i: Fine tuned conn destroy and context destroy
  timeout values (FATE#311692).
- patches.suse/bnx2i-Fixed-the-TCP-graceful-termination-ini.patch:
  [SCSI] bnx2i: Fixed the TCP graceful termination initiation
  (FATE#311692).
- patches.suse/bnx2i-Optimized-the-bnx2i_stop-connection-cl.patch:
  [SCSI] bnx2i: Optimized the bnx2i_stop connection clean up
  procedure (FATE#311692).
- patches.suse/bnx2i-Separated-the-hardware-s-cleanup-proce.patch:
  [SCSI] bnx2i: Separated the hardware's cleanup procedure from
  ep_disconnect (FATE#311692).
- patches.suse/bnx2i-Updated-version-from-2.1.1-to-2.1.2.patch:
  [SCSI] bnx2i: Updated version from 2.1.1 to 2.1.2 (FATE#311692).
- patches.suse/brd-support-discard.patch: brd: support discard
  (FATE#311692).
- patches.suse/brd-unify-flags-for-struct-bio-and-struct-request.patch:
  block: unify flags for struct bio and struct request
  (FATE#311692).
- patches.suse/btrfs-replace-barriers-with-explicit-flush-FUA-us.patch:
  btrfs: replace barriers with explicit flush / FUA usage
  (FATE#311692).
- patches.suse/buffer-make-invalidate_bdev-drain-all-percpu-LRU.patch:
  buffer: make invalidate_bdev() drain all percpu LRU add caches
  (FATE#311692).
- patches.suse/cdrom-use-pr_-level.patch: drivers/cdrom: use
  pr_<level> (FATE#311692).
- patches.suse/cfq-Don-t-allow-queue-merges-for-queues-that-have-n.patch:
  cfq: Don't allow queue merges for queues that have no process
  references (FATE#311692).
- patches.suse/cfq-iosched-Do-not-idle-if-slice_idle-0.patch:
  cfq-iosched: Do not idle if slice_idle=0 (FATE#311692).
- patches.suse/cfq-iosched-compact-io_context-radix_tree.patch:
  cfq-iosched: compact io_context radix_tree (FATE#311692).
- patches.suse/cfq-iosched-fix-an-oops-caused-by-slab-leak.patch:
  cfq-iosched: fix an oops caused by slab leak (FATE#311692).
- patches.suse/cfq-iosched-remove-dead_key-from-cfq_io_context.patch:
  cfq-iosched: remove dead_key from cfq_io_context (FATE#311692).
- patches.suse/ch-don-t-use-vprintk-as-macro.patch:
  drivers/scsi/ch.c: don't use vprintk as macro (FATE#311692).
- patches.suse/coda-fixup-clash-with-block-layer-REQ_-defines.patch:
  coda: fixup clash with block layer REQ_* defines (FATE#311692).
- patches.suse/cpqarray-check-put_user-result.patch: cpqarray:
  check put_user() result (FATE#311692).
- patches.suse/cpqarray-fix-two-more-wrong-section-type.patch:
  cpqarray: fix two more wrong section type (FATE#311692).
- patches.suse/cpqarray-fix-wrong-__init-type-on-pci-probe-functio.patch:
  cpqarray: fix wrong __init type on pci probe function
  (FATE#311692).
- patches.suse/cxgb3i-Fix-error-path-for-module-init.patch:
  [SCSI] cxgb3i: Fix error path for module init (FATE#311692).
- patches.suse/dc395x-decrease-iteration-for-tag_number-of-max_com.patch:
  dc395x: decrease iteration for tag_number of max_command in
  start_scsi() (FATE#311692).
- patches.suse/dm-convey-that-all-flushes-are-processed-as-empty.patch:
  dm: convey that all flushes are processed as empty
  (FATE#311692).
- patches.suse/dm-crypt-simplify-crypt_config-destruction-logic.patch:
  dm crypt: simplify crypt_config destruction logic (FATE#311692).
- patches.suse/dm-crypt-simplify-crypt_ctr.patch: dm crypt:
  simplify crypt_ctr (FATE#311692).
- patches.suse/dm-crypt-use-kstrdup.patch: dm crypt: use kstrdup
  (FATE#311692).
- patches.suse/dm-delay-support-discard.patch: dm delay: support
  discard (FATE#311692).
- patches.suse/dm-do-not-initialise-full-request-queue-when-bio-ba.patch:
  dm: do not initialise full request queue when bio based
  (FATE#311692).
- patches.suse/dm-error-return-error-for-discards.patch: dm:
  error return error for discards (FATE#311692).
- patches.suse/dm-factor-out-max_io_len_target_boundary.patch:
  dm: factor out max_io_len_target_boundary (FATE#311692).
- patches.suse/dm-fix-locking-context-in-queue_io.patch: dm:
  fix locking context in queue_io() (FATE#311692).
- patches.suse/dm-implement-REQ_FLUSH-FUA-support-for-bio-based-dm.patch:
  dm: implement REQ_FLUSH/FUA support for bio-based dm
  (FATE#311692).
- patches.suse/dm-implement-REQ_FLUSH-FUA-support-for-request-base.patch:
  dm: implement REQ_FLUSH/FUA support for request-based dm
  (FATE#311692).
- patches.suse/dm-ioctl-make-__dev_status-void.patch: dm ioctl:
  make __dev_status void (FATE#311692).
- patches.suse/dm-ioctl-make-bio-or-request-based-device-type-immu.patch:
  dm ioctl: make bio or request based device type immutable
  (FATE#311692).
- patches.suse/dm-ioctl-refactor-dm_table_complete.patch: dm
  ioctl: refactor dm_table_complete (FATE#311692).
- patches.suse/dm-ioctl-remove-__dev_status-from-geometry-and-targ.patch:
  dm ioctl: remove __dev_status from geometry and target message
  (FATE#311692).
- patches.suse/dm-ioctl-return-uevent-flag-after-rename.patch:
  dm ioctl: return uevent flag after rename (FATE#311692).
- patches.suse/dm-ioctl-use-nonseekable_open.patch: dm ioctl:
  use nonseekable_open (FATE#311692).
- patches.suse/dm-linear-support-discard.patch: dm: linear
  support discard (FATE#311692).
- patches.suse/dm-mpath-support-discard.patch: dm mpath: support
  discard (FATE#311692).
- patches.suse/dm-prevent-access-to-md-being-deleted.patch: dm:
  prevent access to md being deleted (FATE#311692).
- patches.suse/dm-relax-ordering-of-bio-based-flush-implementation.patch:
  dm: relax ordering of bio-based flush implementation
  (FATE#311692).
- patches.suse/dm-remove-wrappers-for-request-type-flags.patch:
  block: remove wrappers for request type/flags (FATE#311692).
- patches.suse/dm-rename-map_info-flush_request-to-target_request_.patch:
  dm: rename map_info flush_request to target_request_nr
  (FATE#311692).
- patches.suse/dm-separate-device-deletion-from-dm_put.patch:
  dm: separate device deletion from dm_put (FATE#311692).
- patches.suse/dm-skip-second-flush-on-bio-unsupported-error.patch:
  dm: skip second flush on bio unsupported error (FATE#311692).
- patches.suse/dm-snapshot-implement-merge.patch: dm snapshot:
  implement merge (FATE#311692).
- patches.suse/dm-snapshot-iterate-origin-and-cow-devices.patch:
  dm snapshot: iterate origin and cow devices (FATE#311692).
- patches.suse/dm-snapshot-persistent-use-define-for-disk-header-c.patch:
  dm snapshot: persistent use define for disk header chunk size
  (FATE#311692).
- patches.suse/dm-snapshot-test-chunk-size-against-both-origin-and.patch:
  dm snapshot: test chunk size against both origin and snapshot
  (FATE#311692).
- patches.suse/dm-split-discard-requests-on-target-boundaries.patch:
  dm: split discard requests on target boundaries (FATE#311692).
- patches.suse/dm-stop-using-q-prepare_flush_fn.patch: dm:
  stop using q->prepare_flush_fn (FATE#311692).
- patches.suse/dm-stripe-move-sector-translation-to-a-function.patch:
  dm stripe: move sector translation to a function (FATE#311692).
- patches.suse/dm-stripe-optimize-sector-division.patch: dm
  stripe: optimize sector division (FATE#311692).
- patches.suse/dm-stripe-support-discards.patch: dm stripe:
  support discards (FATE#311692).
- patches.suse/dm-unify-flags-for-struct-bio-and-struct-request.patch:
  block: unify flags for struct bio and struct request
  (FATE#311692).
- patches.suse/dm-use-common-__issue_target_request-for-flush-and.patch:
  dm: use common __issue_target_request for flush and discard
  support (FATE#311692).
- patches.suse/dm-use-dm_target_offset-macro.patch: dm: use
  dm_target_offset macro (FATE#311692).
- patches.suse/dm-zero-silently-drop-discards.patch: dm: zero
  silently drop discards (FATE#311692).
- patches.suse/dpt_i2o-Use-GFP_ATOMIC-when-a-lock-is-held.patch:
  [SCSI] dpt_i2o: Use GFP_ATOMIC when a lock is held
  (FATE#311692).
- patches.suse/dpt_i2o-move-range-check-forward.patch: [SCSI]
  dpt_i2o: move range check forward (FATE#311692).
- patches.suse/drivers-block-use-memdup_user.patch: drivers/block:
  use memdup_user (FATE#311692).
- patches.suse/drivers-scsi-remove-unnecessary-NULL-test.patch:
  drivers/scsi: remove unnecessary NULL test (FATE#311692).
- patches.suse/elevator-fix-oops-on-early-call-to-elevator_change.patch:
  elevator: fix oops on early call to elevator_change()
  (FATE#311692).
- patches.suse/ext4-do-not-send-discards-as-barriers.patch:
  ext4: do not send discards as barriers (FATE#311692).
- patches.suse/floppy-cmos-attribute-should-be-static.patch:
  floppy: cmos attribute should be static (FATE#311692).
- patches.suse/floppy-fix-signed-unsigned-warnings.patch: floppy:
  fix signed/unsigned warnings (FATE#311692).
- patches.suse/floppy-initialize-debug-jiffies-offset.patch:
  floppy: initialize debug jiffies offset (FATE#311692).
- patches.suse/floppy-make-controller-const.patch: floppy:
  make controller const (FATE#311692).
- patches.suse/floppy-remove-unnecessary-inlines.patch: floppy:
  remove unnecessary inlines (FATE#311692).
- patches.suse/floppy-silence-warning-during-disk-test.patch:
  floppy: silence warning during disk test (FATE#311692).
- patches.suse/floppy-use-atomic-type-for-usage_count.patch:
  floppy: use atomic type for usage_count (FATE#311692).
- patches.suse/floppy-use-wait_event_interruptible.patch: floppy:
  use wait_event_interruptible (FATE#311692).
- patches.suse/floppy-use-warning-macros.patch: floppy: use
  warning macros (FATE#311692).
- patches.suse/fs-bio-integrity.c-return-ENOMEM-on-kmalloc-failur.patch:
  fs/bio-integrity.c: return -ENOMEM on kmalloc failure
  (FATE#311692).
- patches.suse/gcc-4.6-block-fix-unused-but-set-variables-in-blk.patch:
  gcc-4.6: block: fix unused but set variables in blk-merge
  (FATE#311692).
- patches.suse/gdth-unmap-ccb_phys-when-scsi_add_host-fails-in-g.patch:
  gdth: unmap ccb_phys when scsi_add_host() fails in
  gdth_eisa_probe_one() (FATE#311692).
- patches.suse/gfs2-replace-barriers-with-explicit-flush-FUA-usa.patch:
  gfs2: replace barriers with explicit flush / FUA usage
  (FATE#311692).
- patches.suse/hptiop-Eliminate-a-NULL-pointer-dereference.patch:
  [SCSI] hptiop: Eliminate a NULL pointer dereference
  (FATE#311692).
- patches.suse/ibmvfc-Add-support-for-fc_block_scsi_eh.patch:
  [SCSI] ibmvfc: Add support for fc_block_scsi_eh (FATE#311692).
- patches.suse/ibmvfc-Driver-version-1.0.8.patch: [SCSI] ibmvfc:
  Driver version 1.0.8 (FATE#311692).
- patches.suse/ibmvfc-Driver-version-1.0.9.patch: [SCSI] ibmvfc:
  Driver version 1.0.9 (FATE#311692).
- patches.suse/ibmvfc-Fix-soft-lockup-on-resume.patch: [SCSI]
  ibmvfc: Fix soft lockup on resume (FATE#311692).
- patches.suse/ibmvfc-Fix-terminate_rport_io.patch: [SCSI]
  ibmvfc: Fix terminate_rport_io (FATE#311692).
- patches.suse/ibmvscsi-Fix-error-path-deadlock.patch: [SCSI]
  ibmvscsi: Fix error path deadlock (FATE#311692).
- patches.suse/ibmvscsi-Fix-oops-when-an-interrupt-is-pendi.patch:
  [SCSI] ibmvscsi: Fix oops when an interrupt is pending during
  probe (FATE#311692).
- patches.suse/ibmvscsi-Fix-possible-request_limit-issue.patch:
  [SCSI] ibmvscsi: Fix possible request_limit issue (FATE#311692).
- patches.suse/ibmvscsi-Fix-softlockup-on-resume.patch: [SCSI]
  ibmvscsi: Fix softlockup on resume (FATE#311692).
- patches.suse/ibmvstgt-add-__init-__exit-macros.patch: [SCSI]
  ibmvstgt: add __init/__exit macros (FATE#311692).
- patches.suse/ide-deprecate-barrier-and-replace-blk_queue_order.patch:
  block: deprecate barrier and replace blk_queue_ordered()
  with blk_queue_flush() (FATE#311692).
- patches.suse/ide-remove-unnecessary-blk_queue_flushing-test-in.patch:
  ide: remove unnecessary blk_queue_flushing() test in
  do_ide_request() (FATE#311692).
- patches.suse/ide-stop-using-q-prepare_flush_fn.patch: ide:
  stop using q->prepare_flush_fn (FATE#311692).
- patches.suse/ipr-add-MMIO-write-to-perform-BIST-for-64-bi.patch:
  [SCSI] ipr: add MMIO write to perform BIST for 64 bit adapters
  (FATE#311692).
- patches.suse/ipr-add-endian-swap-enablement-for-64-bit-ad.patch:
  [SCSI] ipr: add endian swap enablement for 64 bit adapters
  (FATE#311692).
- patches.suse/ipr-add-support-for-new-Obsidian-E-embedded.patch:
  [SCSI] ipr: add support for new Obsidian-E embedded adapter
  (FATE#311692).
- patches.suse/ipr-add-writeq-definition-if-needed.patch: [SCSI]
  ipr: add writeq definition if needed (FATE#311692).
- patches.suse/ipr-change-endian-swap-key-to-match-hardware.patch:
  [SCSI] ipr: change endian swap key to match hardware spec change
  (FATE#311692).
- patches.suse/ipr-fix-a-register-read-to-use-the-correct-a.patch:
  [SCSI] ipr: fix a register read to use the correct address
  for 64 bit adapters (FATE#311692).
- patches.suse/ipr-fix-resource-path-display-and-formatting.patch:
  [SCSI] ipr: fix resource path display and formatting
  (FATE#311692).
- patches.suse/ipr-fix-resource-type-update-and-add-sdev-an.patch:
  [SCSI] ipr: fix resource type update and add sdev and shost
  attributes (FATE#311692).
- patches.suse/ipr-fix-transition-to-operational-for-new-ad.patch:
  [SCSI] ipr: fix transition to operational for new adapters
  (FATE#311692).
- patches.suse/ipr-implement-fixes-for-64-bit-adapter-suppo.patch:
  [SCSI] ipr: implement fixes for 64 bit adapter support
  (FATE#311692).
- patches.suse/ipr-improve-interrupt-service-routine-perfor.patch:
  [SCSI] ipr: improve interrupt service routine performance
  (FATE#311692).
- patches.suse/ipr-include-the-resource-path-in-the-IOA-sta.patch:
  [SCSI] ipr: include the resource path in the IOA status area
  structure (FATE#311692).
- patches.suse/ipr-set-the-data-list-length-in-the-request.patch:
  [SCSI] ipr: set the data list length in the request control
  block (FATE#311692).
- patches.suse/jbd-replace-barriers-with-explicit-flush-FUA-usag.patch:
  jbd: replace barriers with explicit flush / FUA usage
  (FATE#311692).
- patches.suse/jbd2-Modify-ASYNC_COMMIT-code-to-not-rely-on-queue.patch:
  jbd2: Modify ASYNC_COMMIT code to not rely on queue draining
  on barrier (FATE#311692).
- patches.suse/jbd2-replace-barriers-with-explicit-flush-FUA-usa.patch:
  jbd2: replace barriers with explicit flush / FUA usage
  (FATE#311692).
- patches.suse/kill-BH_Ordered-flag.patch: kill BH_Ordered flag
  (FATE#311692).
- patches.suse/laptop-mode-Make-flushes-per-device.patch:
  laptop-mode: Make flushes per-device (FATE#311692).
- patches.suse/lguest-replace-VIRTIO_F_BARRIER-support-with-VIRTIO.patch:
  lguest: replace VIRTIO_F_BARRIER support with VIRTIO_F_FLUSH
  support (FATE#311692).
- patches.suse/libahci-Fix-bug-in-storing-EM-messages.patch:
  libahci: Fix bug in storing EM messages (FATE#311692).
- patches.suse/libata-Allow-pata_legacy-to-be-built-on-non-ISA-but.patch:
  libata: Allow pata_legacy to be built on non-ISA but PCI systems
  (FATE#311692).
- patches.suse/libata-Disable-R_OK-Early-ACK-on-SII-3726-PMP.patch:
  [libata] Disable R_OK (Early ACK) on SII 3726 PMP (FATE#311692).
- patches.suse/libata-Fix-several-inaccuracies-in-developer-s-guid.patch:
  libata: Fix several inaccuracies in developer's guide
  (FATE#311692).
- patches.suse/libata-Pass-host-flags-into-the-pci-helper.patch:
  libata: Pass host flags into the pci helper (FATE#311692).
- patches.suse/libata-Remove-excess-delay-in-the-tf_load-path.patch:
  libata: Remove excess delay in the tf_load path (FATE#311692).
- patches.suse/libata-add-ATA_CMD_DSM-to-ata_get_cmd_descript.patch:
  [libata] add ATA_CMD_DSM to ata_get_cmd_descript (FATE#311692).
- patches.suse/libata-allow-hyphenated-pattern-ranges.patch:
  libata: allow hyphenated pattern ranges (FATE#311692).
- patches.suse/libata-be-less-of-a-drama-queen-on-empty-data-comma.patch:
  libata: be less of a drama queen on empty data commands
  (FATE#311692).
- patches.suse/libata-cleanup-ata_sff_interrupt.patch: libata:
  cleanup ata_sff_interrupt() (FATE#311692).
- patches.suse/libata-don-t-whine-on-spurious-IRQ.patch: libata:
  don't whine on spurious IRQ (FATE#311692).
- patches.suse/libata-fix-CFA-handling-in-ide_timing_compute.patch:
  libata: fix CFA handling in ide_timing_compute() (FATE#311692).
- patches.suse/libata-fix-docs-RE-port-and-device-of-libata.force.patch:
  libata: fix docs, RE port and device of libata.force ID
  separated by point (FATE#311692).
- patches.suse/libata-glob_match-for-ata_device_blacklist-v2.patch:
  libata: glob_match for ata_device_blacklist (v2) (FATE#311692).
- patches.suse/libata-implement-on-demand-HPA-unlocking.patch:
  libata: implement on-demand HPA unlocking (FATE#311692).
- patches.suse/libata-implement-spurious-irq-handling-for-SFF-and.patch:
  libata: implement spurious irq handling for SFF and apply it
  to piix (FATE#311692).
- patches.suse/libata-introduce-sff_set_devctl-method.patch:
  libata: introduce sff_set_devctl() method (FATE#311692).
- patches.suse/libata-kill-ATA_FLAG_DISABLED.patch: libata:
  kill ATA_FLAG_DISABLED (FATE#311692).
- patches.suse/libata-make-functions-variables-static.patch:
  libata: make functions/variables static (FATE#311692).
- patches.suse/libata-make-sff_irq_on-method-optional.patch:
  libata: make sff_irq_on() method optional (FATE#311692).
- patches.suse/libata-more-PCI-IDs-for-jmicron-controllers.patch:
  libata: more PCI IDs for jmicron controllers (FATE#311692).
- patches.suse/libata-pata_via-revert-ata_wait_idle-removal-from.patch:
  libata,pata_via: revert ata_wait_idle() removal from
  ata_sff/via_tf_load() (FATE#311692).
- patches.suse/libata-reduce-blacklist-size-even-more-v2.patch:
  libata: reduce blacklist size even more (v2) (FATE#311692).
- patches.suse/libata-reduce-blacklist-size-v2.patch: libata:
  reduce blacklist size (v2) (FATE#311692).
- patches.suse/libata-sff-Reenable-Port-Multiplier-after-libata-sf.patch:
  libata-sff: Reenable Port Multiplier after libata-sff remodeling
  (FATE#311692).
- patches.suse/libata-sff-ap-last_-ctl-are-SFF-specific.patch:
  libata-sff: ap->[last_]ctl are SFF specific (FATE#311692).
- patches.suse/libata-sff-ata_sff_-dumb_-qc_prep-are-BMDMA-specifi.patch:
  libata-sff: ata_sff_[dumb_]qc_prep are BMDMA specific
  (FATE#311692).
- patches.suse/libata-sff-ata_sff_irq_clear-is-BMDMA-specific.patch:
  libata-sff: ata_sff_irq_clear() is BMDMA specific (FATE#311692).
- patches.suse/libata-sff-clean-up-BMDMA-initialization.patch:
  libata-sff: clean up BMDMA initialization (FATE#311692).
- patches.suse/libata-sff-clean-up-inheritance-in-several-drivers.patch:
  libata-sff: clean up inheritance in several drivers
  (FATE#311692).
- patches.suse/libata-sff-fix-spurious-IRQ-handling.patch:
  libata-sff: fix spurious IRQ handling (FATE#311692).
- patches.suse/libata-sff-introduce-ata_sff_init-exit-and-ata_sf.patch:
  libata-sff: introduce ata_sff_init/exit() and
  ata_sff_port_init() (FATE#311692).
- patches.suse/libata-sff-kill-dummy-BMDMA-ops-from-sata_qstor-and.patch:
  libata-sff: kill dummy BMDMA ops from sata_qstor and
  pata_octeon_cf (FATE#311692).
- patches.suse/libata-sff-kill-unused-ata_bus_reset.patch:
  libata-sff: kill unused ata_bus_reset() (FATE#311692).
- patches.suse/libata-sff-kill-unused-prototype-and-make-ata_dev_s.patch:
  libata-sff: kill unused prototype and make ata_dev_select()
  static (FATE#311692).
- patches.suse/libata-sff-port_task-is-SFF-specific.patch:
  libata-sff: port_task is SFF specific (FATE#311692).
- patches.suse/libata-sff-prd-is-BMDMA-specific.patch: libata-sff:
  prd is BMDMA specific (FATE#311692).
- patches.suse/libata-sff-remove-harmful-BUG_ON-from-ata_bmdma_qc_.patch:
  libata-sff: remove harmful BUG_ON from ata_bmdma_qc_issue
  (FATE#311692).
- patches.suse/libata-sff-rename-ap-ops-drain_fifo-to-sff_drai.patch:
  libata-sff: rename ap->ops->drain_fifo() to sff_drain_fifo()
  (FATE#311692).
- patches.suse/libata-sff-reorder-SFF-BMDMA-functions.patch:
  libata-sff: reorder SFF/BMDMA functions (FATE#311692).
- patches.suse/libata-sff-separate-out-BMDMA-EH.patch: libata-sff:
  separate out BMDMA EH (FATE#311692).
- patches.suse/libata-sff-separate-out-BMDMA-init.patch:
  libata-sff: separate out BMDMA init (FATE#311692).
- patches.suse/libata-sff-separate-out-BMDMA-irq-handler.patch:
  libata-sff: separate out BMDMA irq handler (FATE#311692).
- patches.suse/libata-sff-separate-out-BMDMA-qc_issue.patch:
  libata-sff: separate out BMDMA qc_issue (FATE#311692).
- patches.suse/libata-sff-update-bmdma-host-bus-error-handling.patch:
  libata-sff: update bmdma host bus error handling (FATE#311692).
- patches.suse/libata-unlock-HPA-if-device-shrunk.patch: libata:
  unlock HPA if device shrunk (FATE#311692).
- patches.suse/libata-update-blacklist-for-new-hyphenated-pattern.patch:
  [libata] update blacklist for new hyphenated pattern ranges (v2)
  (FATE#311692).
- patches.suse/libata-update-gfp-slab.h-includes.patch: libata:
  update gfp/slab.h includes (FATE#311692).
- patches.suse/libata-use-__ratelimit.patch: libata: use
  __ratelimit (FATE#311692).
- patches.suse/libata-use-longer-0xff-wait-if-parallel-scan-is-ena.patch:
  libata: use longer 0xff wait if parallel scan is enabled
  (FATE#311692).
- patches.suse/libata-use-the-enlarged-capacity-after-late-HPA-unl.patch:
  libata: use the enlarged capacity after late HPA unlock
  (FATE#311692).
- patches.suse/libsas-fix-deref-before-check-in-commit-70b2.patch:
  [SCSI] libsas: fix deref before check in commit 70b25f890ce
  (FATE#311692).
- patches.suse/md-Call-blk_queue_flush-to-establish-flush-fua-su.patch:
  md: Call blk_queue_flush() to establish flush/fua support
  (FATE#311692).
- patches.suse/md-implment-REQ_FLUSH-FUA-support.patch: md:
  implment REQ_FLUSH/FUA support (FATE#311692).
- patches.suse/md-unify-flags-for-struct-bio-and-struct-request.patch:
  block: unify flags for struct bio and struct request
  (FATE#311692).
- patches.suse/modify-change_queue_depth-to-take-in-reason-why-it-is-being-called.patch:
  Refresh.
- patches.suse/nilfs2-replace-barriers-with-explicit-flush-FUA-u.patch:
  nilfs2: replace barriers with explicit flush / FUA usage
  (FATE#311692).
- patches.suse/no-partition-scan: Refresh.
- patches.suse/osdblk-stop-using-q-prepare_flush_fn.patch:
  osdblk: stop using q->prepare_flush_fn (FATE#311692).
- patches.suse/osst-fix-read-buffer-overflow.patch: osst: fix
  read buffer overflow (FATE#311692).
- patches.suse/pata_ali-documentation-fixes.patch: pata_ali:
  documentation fixes (FATE#311692).
- patches.suse/pata_artop-Fix-device-ID-parity-check.patch:
  pata_artop: Fix device ID parity check (FATE#311692).
- patches.suse/pata_at91-fix-backslash-continued-string.patch:
  [libata] pata_at91: fix backslash-continued string
  (FATE#311692).
- patches.suse/pata_atiixp-add-locking-for-parallel-scann.patch:
  [libata] pata_atiixp: add locking for parallel scanning
  (FATE#311692).
- patches.suse/pata_atiixp-enable-parallel-scan.patch:
  pata_atiixp: enable parallel scan (FATE#311692).
- patches.suse/pata_cmd640-don-t-read-CFR-pointlessly.patch:
  pata_cmd640: don't read CFR pointlessly (FATE#311692).
- patches.suse/pata_cmd64x-cmd648_bmdma_stop-fix.patch:
  pata_cmd64x: cmd648_bmdma_stop() fix (FATE#311692).
- patches.suse/pata_cmd64x-fix-PIO-setup.patch: pata_cmd64x:
  fix PIO setup (FATE#311692).
- patches.suse/pata_cmd64x-fix-handling-of-address-setup-timings.patch:
  pata_cmd64x: fix handling of address setup timings
  (FATE#311692).
- patches.suse/pata_cmd64x-remove-unused-definitions.patch:
  pata_cmd64x: remove unused definitions (FATE#311692).
- patches.suse/pata_cmd64x-revert-commit-d62f5576.patch:
  pata_cmd64x: revert commit d62f5576 (FATE#311692).
- patches.suse/pata_cs5535-use-correct-values-for-PIO1-and-PIO2-da.patch:
  pata_cs5535: use correct values for PIO1 and PIO2 data timings
  (FATE#311692).
- patches.suse/pata_cypress-fix-PIO-timings-underclocking.patch:
  pata_cypress: fix PIO timings underclocking (FATE#311692).
- patches.suse/pata_efar-Enable-parallel-scanning.patch:
  pata_efar: Enable parallel scanning (FATE#311692).
- patches.suse/pata_efar-add-locking-for-parallel-scannin.patch:
  [libata] pata_efar: add locking for parallel scanning
  (FATE#311692).
- patches.suse/pata_efar-fix-secondary-port-support.patch:
  pata_efar: fix secondary port support (FATE#311692).
- patches.suse/pata_hpt-37x-3x2n-improve-timing-register-document.patch:
  pata_hpt{37x|3x2n}: improve timing register documentation
  (FATE#311692).
- patches.suse/pata_hpt-37x-3x2n-unify-mode-programming.patch:
  pata_hpt{37x|3x2n}: unify mode programming (FATE#311692).
- patches.suse/pata_hpt366-remove-irrelevant-TODO.patch:
  pata_hpt366: remove irrelevant TODO (FATE#311692).
- patches.suse/pata_hpt366-remove-redundant-code.patch:
  pata_hpt366: remove redundant code (FATE#311692).
- patches.suse/pata_hpt37x-use-ATA_DMA_-constants.patch:
  pata_hpt37x: use ATA_DMA_* constants (FATE#311692).
- patches.suse/pata_marvell-CONFIG_AHCI-is-really-CONFIG_.patch:
  [libata] pata_marvell: CONFIG_AHCI is really CONFIG_SATA_AHCI
  (FATE#311692).
- patches.suse/pata_mpc52xx-reduce-code-size-by-simple-change-of-c.patch:
  pata_mpc52xx: reduce code size by simple change of constant
  data types (FATE#311692).
- patches.suse/pata_pcmcia-ide-cs-Fix-bad-hashes-for-Transcend-a.patch:
  pata_pcmcia / ide-cs: Fix bad hashes for Transcend and kingston
  IDs (FATE#311692).
- patches.suse/pata_pcmcia-ide-cs-add-IDs-for-transcend-and-kingst.patch:
  pata_pcmcia/ide-cs: add IDs for transcend and kingston cards
  (FATE#311692).
- patches.suse/pata_scc-kill-useless-check-in-scc_postreset.patch:
  pata_scc: kill useless check in scc_postreset() (FATE#311692).
- patches.suse/pata_scc-make-scc_wait_after_reset-static.patch:
  pata_scc: make scc_wait_after_reset() static (FATE#311692).
- patches.suse/pata_sch-use-ata_pci_sff_init_one.patch: pata_sch:
  use ata_pci_sff_init_one() (FATE#311692).
- patches.suse/pata_serverworks-fix-PIO-setup-for-the-second-chann.patch:
  pata_serverworks: fix PIO setup for the second channel
  (FATE#311692).
- patches.suse/pata_serverworks-fix-error-message.patch:
  pata_serverworks: fix error message (FATE#311692).
- patches.suse/pata_sil680-Do-our-own-exec_command-posting.patch:
  pata_sil680: Do our own exec_command posting (FATE#311692).
- patches.suse/pata_via-fix-VT6410-6415-6330-detection-issue.patch:
  pata_via: fix VT6410/6415/6330 detection issue (FATE#311692).
- patches.suse/pata_via-fix-address-setup-timings-underlocking.patch:
  pata_via: fix address setup timings underlocking (FATE#311692).
- patches.suse/pata_via-store-UDMA-masks-in-via_isa_bridges-table.patch:
  pata_via: store UDMA masks in via_isa_bridges table
  (FATE#311692).
- patches.suse/pmcraid-MSI-X-support-and-other-changes.patch:
  [SCSI] pmcraid: MSI-X support and other changes (FATE#311692).
- patches.suse/ps3disk-stop-using-q-prepare_flush_fn.patch:
  ps3disk: stop using q->prepare_flush_fn (FATE#311692).
- patches.suse/reiserfs-replace-barriers-with-explicit-flush-FUA.patch:
  reiserfs: replace barriers with explicit flush / FUA usage
  (FATE#311692).
- patches.suse/sata_inic162x-inic162x-is-not-dependent-on-CONFIG_A.patch:
  sata_inic162x: inic162x is not dependent on CONFIG_ATA_SFF
  (FATE#311692).
- patches.suse/sata_inic162x-kill-PORT_PRD_ADDR-initialization.patch:
  sata_inic162x: kill PORT_PRD_ADDR initialization (FATE#311692).
- patches.suse/sata_mv-drop-unncessary-EH-callback-resetting.patch:
  sata_mv: drop unncessary EH callback resetting (FATE#311692).
- patches.suse/sata_mv-remove-unnecessary-initialization.patch:
  sata_mv: remove unnecessary initialization (FATE#311692).
- patches.suse/sata_sil24-Use-memory-barriers-before-issuing-comma.patch:
  sata_sil24: Use memory barriers before issuing commands
  (FATE#311692).
- patches.suse/sata_sil24-fix-kernel-panic-on-ARM-caused-by-unalig.patch:
  sata_sil24: fix kernel panic on ARM caused by unaligned access
  in sata_sil24 (FATE#311692).
- patches.suse/sata_sil24-memset-overflow.patch: sata_sil24:
  memset() overflow (FATE#311692).
- patches.suse/sata_via-Correctly-setup-PIO-DMA-for-pata-slave-on.patch:
  sata_via: Correctly setup PIO/DMA for pata slave on vt6421
  (FATE#311692).
- patches.suse/sata_via-Delay-on-vt6420-when-starting-ATAPI-DMA-wr.patch:
  sata_via: Delay on vt6420 when starting ATAPI DMA write
  (FATE#311692).
- patches.suse/sata_via-explain-the-magic-fix.patch: sata_via:
  explain the magic fix (FATE#311692).
- patches.suse/scatterlist-prevent-invalid-free-when-alloc-fails.patch:
  scatterlist: prevent invalid free when alloc fails
  (FATE#311692).
- patches.suse/scsi-Fix-VPD-inquiry-page-wrapper.patch: [SCSI]
  Fix VPD inquiry page wrapper (FATE#311692).
- patches.suse/scsi-Fix-warning-zero-length-gnu_printf-format-st.patch:
  [SCSI] Fix warning: zero-length gnu_printf format string
  (FATE#311692).
- patches.suse/scsi-Log-msg-when-getting-Unit-Attention.patch:
  [SCSI] Log msg when getting Unit Attention (FATE#311692).
- patches.suse/scsi-Retry-commands-with-UNIT_ATTENTION-sense-code.patch:
  [SCSI] Retry commands with UNIT_ATTENTION sense codes to fix
  ext3/ext4 I/O error (FATE#311692).
- patches.suse/scsi-SCSI-Support-Type-C-RAID-controller.patch:
  [SCSI] SCSI: Support Type C RAID controller (FATE#311692).
- patches.suse/scsi-Unexport-scsi-scsi.h-from-headers_install.patch:
  [SCSI] Unexport scsi/scsi.h from headers_install (FATE#311692).
- patches.suse/scsi-Unify-SAM_-and-SAM_STAT_-macros.patch:
  [SCSI] Unify SAM_ and SAM_STAT_ macros (FATE#311692).
- patches.suse/scsi-add-sd_unprep_fn-to-free-discard-page.patch:
  scsi: add sd_unprep_fn to free discard page (FATE#311692).
- patches.suse/scsi-convert-discard-to-REQ_TYPE_FS-from-REQ_TYPE_B.patch:
  scsi: convert discard to REQ_TYPE_FS from REQ_TYPE_BLOCK_PC
  (FATE#311692).
- patches.suse/scsi-deprecate-barrier-and-replace-blk_queue_order.patch:
  block: deprecate barrier and replace blk_queue_ordered()
  with blk_queue_flush() (FATE#311692).
- patches.suse/scsi-don-t-allocate-a-payload-for-discard-request.patch:
  block: don't allocate a payload for discard request
  (FATE#311692).
- patches.suse/scsi-fix-bio.bi_rw-handling.patch: [SCSI] fix
  bio.bi_rw handling (FATE#311692).
- patches.suse/scsi-fix-discard-page-leak.patch: scsi: fix
  discard page leak (FATE#311692).
- patches.suse/scsi-fix-race-in-scsi_target_reap.patch: [SCSI]
  fix race in scsi_target_reap (FATE#311692).
- patches.suse/scsi-fix-sdev_rw_attr-macro-for-scsi-device-sysfs.patch:
  [SCSI] fix sdev_rw_attr macro for scsi device sysfs entries
  (FATE#311692).
- patches.suse/scsi-fix-use-after-free-in-scsi_init_io.patch:
  [SCSI] fix use-after-free in scsi_init_io() (FATE#311692).
- patches.suse/scsi-i2o_block-cleanup-ioctl-handling.patch:
  scsi/i2o_block: cleanup ioctl handling (FATE#311692).
- patches.suse/scsi-ipr-update-the-configuration-table-code-for.patch:
  Refresh.
- patches.suse/scsi-libiscsi-reset-cmd-timer-if-cmds-are-making.patch:
  Refresh.
- patches.suse/scsi-make-error-handling-more-robust-in-the-face-o.patch:
  [SCSI] make error handling more robust in the face of
  reservations (FATE#311692).
- patches.suse/scsi-need-to-reset-unprep_rq_fn-in-sd_remove.patch:
  scsi: need to reset unprep_rq_fn in sd_remove (FATE#311692).
- patches.suse/scsi-pass-unit-attention-upwards.patch: Pass unit
  attention code upwards to the SCSI layer (FATE#).
- patches.suse/scsi-pmcraid-Remove-unnecessary-casts-for-void.patch:
  [SCSI] pmcraid : Remove unnecessary casts for void * pointers
  (FATE#311692).
- patches.suse/scsi-remove-superfluous-NULL-pointer-check-from-scs.patch:
  scsi: remove superfluous NULL pointer check from
  scsi_kill_request() (FATE#311692).
- patches.suse/scsi-remove-unused-free-discard-page-in-sd_done.patch:
  scsi: remove unused free discard page in sd_done (FATE#311692).
- patches.suse/scsi-remove-wrappers-from-request-type-flags.patch:
  block: remove wrappers for request type/flags (FATE#311692).
- patches.suse/scsi-scsi-hosts.c-Fix-warning-variable-rval-set.patch:
  [SCSI] scsi:hosts.c Fix warning: variable 'rval' set but not
  used (FATE#311692).
- patches.suse/scsi-scsi_debug-fix-map_region-and-unmap_region-o.patch:
  [SCSI] scsi_debug: fix map_region and unmap_region oops
  (FATE#311692).
- patches.suse/scsi-scsi_dh_rdac-Add-Dell-MD36xxi-controller-int.patch:
  [SCSI] scsi_dh_rdac: Add Dell MD36xxi controller into RDAC
  device list (FATE#311692).
- patches.suse/scsi-sg-fix-bio-leak-with-a-detached-device.patch:
  [SCSI] sg: fix bio leak with a detached device (FATE#311692).
- patches.suse/scsi-stop-using-q-prepare_flush_fn.patch: scsi:
  stop using q->prepare_flush_fn (FATE#311692).
- patches.suse/scsi-tgt-fix-warning.patch: [SCSI] tgt: fix warning
  (FATE#311692).
- patches.suse/scsi-use-REQ_TYPE_FS-for-flush-request.patch:
  scsi: use REQ_TYPE_FS for flush request (FATE#311692).
- patches.suse/sd-implement-sd_unlock_native_capacity.patch:
  SCSI: implement sd_unlock_native_capacity() (FATE#311692).
- patches.suse/sd-quiet-all-sparse-noise.patch: scsi/sd.c:
  quiet all sparse noise (FATE#311692).
- patches.suse/staging-Update-dst-to-handle-FLUSH-FUA.patch:
  staging: Update dst to handle FLUSH/FUA (FATE#311054).
- patches.suse/swap-discard-while-swapping-only-if-SWAP_FLAG_DISCA.patch:
  swap: discard while swapping only if SWAP_FLAG_DISCARD
  (FATE#311692).
- patches.suse/swap-do-not-send-discards-as-barriers.patch:
  swap: do not send discards as barriers (FATE#311692).
- patches.suse/vfs-don-t-hold-s_umount-over-close_bdev_exclusive.patch:
  vfs: don't hold s_umount over close_bdev_exclusive() call
  (FATE#311692).
- patches.suse/vfs-rename-block_fsync-to-blkdev_fsync.patch:
  vfs: rename block_fsync() to blkdev_fsync() (FATE#311692).
- patches.suse/virtio-blk-deprecate-barrier-and-replace-blk_queue_order.patch:
  block: deprecate barrier and replace blk_queue_ordered()
  with blk_queue_flush() (FATE#311692).
- patches.suse/virtio-blk-kill-QUEUE_ORDERED_BY_TAG.patch: block:
  kill QUEUE_ORDERED_BY_TAG (FATE#311692).
- patches.suse/virtio_blk-add-default-case-to-cmd-type-switch.patch:
  virtio_blk: add default case to cmd type switch (FATE#311692).
- patches.suse/virtio_blk-drop-REQ_HARDBARRIER-support.patch:
  virtio_blk: drop REQ_HARDBARRIER support (FATE#311692).
- patches.suse/virtio_blk-stop-using-q-prepare_flush_fn.patch:
  virtio_blk: stop using q->prepare_flush_fn (FATE#311692).
- patches.suse/xen-blkfront-Implement-FUA-with-BLKIF_OP_WRITE_BARR.patch:
  xen/blkfront: Implement FUA with BLKIF_OP_WRITE_BARRIER
  (FATE#311692).
- patches.suse/xen-blkfront-map-REQ_FLUSH-into-a-full-barrier.patch:
  xen/blkfront: map REQ_FLUSH into a full barrier (FATE#311692).
- patches.suse/xfs-replace-barriers-with-explicit-flush-FUA-usag.patch:
  xfs: replace barriers with explicit flush / FUA usage
  (FATE#311692).
- patches.xen/tmem: Refresh.
* Mon Jun  6 2011 oneukum@suse.de
- patches.fixes/bug-691216_hp_accel-resume-warning-fix.diff:
  fix kernel warning upon resumption from S4 due to hw_accel
  (bnc#691216).
* Sun Jun  5 2011 jjolly@suse.de
- patches.arch/s390-30-01-qeth-sysfs-serialize.patch:
  qeth: serialize device removal and config changes
  (bnc#696586,LTC#72239).
- patches.arch/s390-30-02-crypto-prng-seed.patch: crypto: prng
  error in initial seed calculation (bnc#696586,LTC#72362).
* Fri Jun  3 2011 mmarek@suse.cz
- rpm/macros.kernel-source: Add -b option to %%kernel_module_package
  to unconditionally call mkinitrd on kmp install (fate#309400).
- rpm/kernel-module-subpackage: Pass KMP_NEEDS_MKINITRD=1 to
  weak-modules2 if the -b option is used.
* Thu Jun  2 2011 sjayaraman@suse.de
- patches.suse/cifs-enable-signing-flag-in-SMB-header-when-server-h.patch:
  cifs: enable signing flag in SMB header when server has it on
  (bko#28142).
* Thu Jun  2 2011 sjayaraman@suse.de
- patches.suse/cifs-check-for-private_data-before-trying-to-put-it.patch:
  cifs: check for private_data before trying to put it
  (bnc#692497).
* Thu Jun  2 2011 sjayaraman@suse.de
- patches.suse/cifs-127-implement-recurring-workqueue-job-to-prune-old-.patch:
  move prune_tlinks declaration out of #ifdef.
* Thu Jun  2 2011 mhocko@suse.cz
- move patches.fixes/err-h-add-helper-function-to-simplify-pointer-error-checking
  moved closer to the top of series.conf to resolve compilation issues with ksm
  patches which use its functionality as well.
* Wed Jun  1 2011 trenn@suse.de
- move patches.arch/x86-uv-westmere-acpicid-fix.patch still one
  patch further down.
* Wed Jun  1 2011 trenn@suse.de
- move patches.arch/x86-uv-westmere-acpicid-fix.patch further down
  after a patch on which it depends, so that partly applied series.conf
  still compiles
* Wed Jun  1 2011 mmarek@suse.cz
- patches.fixes/fixdep-part1.patch: fixdep: Do not record
  dependency on the source file itself.
- patches.fixes/fixdep-part2.patch: kbuild: Fix computing
  srcversion for modules.
* Wed Jun  1 2011 mgalbraith@suse.de
- fix up header, since it's in mainline.
- patches.fixes/block-Add-proper-guards-to-__elv_next_request:
* Wed Jun  1 2011 mgalbraith@suse.de
- Add fix for NULL dereference in elv_queue_empty() pending the fix
  hitting mainline/stable.
- patches.fixes/block-Add-proper-guards-to-__elv_next_request:
  block: add proper state guards to __elv_next_request
  (http://marc.info/?l=linux-scsi&m=130348673628282).
* Tue May 31 2011 sjayaraman@suse.de
- Update config files: CONFIG_CIFS_ACL=n. Also fix a typo with the previous
  commit.
* Tue May 31 2011 sjayaraman@suse.de
- Bring cifs to 2.6.38 level (cifs internal version 1.70) for FATE#311695
- Update config files.
- patches.suse/cifs-001-Enable-mmap-on-forcedirectio-mounts.patch:
  Enable mmap on forcedirectio mounts (FATE#311695).
- patches.suse/cifs-002-Add-support-for-TCP_NODELAY.patch:
  Add support for TCP_NODELAY (FATE#311695).
- patches.suse/cifs-003-Maximum-username-length-check-in-session-setup-.patch:
  Maximum username length check in session setup does not match
  (FATE#311695).
- patches.suse/cifs-004-Don-t-cache-timestamps-on-utimes-due-to-coarse-.patch:
  Don't cache timestamps on utimes due to coarse granularity
  (FATE#311695).
- patches.suse/cifs-005-fix-dentry-hash-calculation-for-case-insensitiv.patch:
  cifs: fix dentry hash calculation for case-insensitive mounts
  (FATE#311695).
- patches.suse/cifs-006-add-parens-around-smb_var-in-BCC-macros.patch:
  cifs: add parens around smb_var in BCC macros (FATE#311695).
- patches.suse/cifs-007-clean-up-indentation-in-CIFSSMBQAllEAs.patch:
  cifs: clean up indentation in CIFSSMBQAllEAs (FATE#311695).
- patches.suse/cifs-008-rename-name_len-to-list_len-in-CIFSSMBQAllEAs.patch:
  cifs: rename name_len to list_len in CIFSSMBQAllEAs
  (FATE#311695).
- patches.suse/cifs-009-increase-maximum-buffer-size-in-CIFSSMBQAllEAs.patch:
  cifs: increase maximum buffer size in CIFSSMBQAllEAs
  (FATE#311695).
- patches.suse/cifs-010-verify-lengths-of-QueryAllEAs-reply.patch:
  cifs: verify lengths of QueryAllEAs reply (FATE#311695).
- patches.suse/cifs-011-merge-CIFSSMBQueryEA-with-CIFSSMBQAllEAs.patch:
  cifs: merge CIFSSMBQueryEA with CIFSSMBQAllEAs (FATE#311695).
- patches.suse/cifs-012-Minor-cleanup-to-EA-patch.patch: Minor
  cleanup to EA patch (FATE#311695).
- patches.suse/cifs-013-set-server_eof-in-cifs_fattr_to_inode.patch:
  cifs: set server_eof in cifs_fattr_to_inode (FATE#311695).
- patches.suse/cifs-014-Use-unsigned-ea-length-for-clarity.patch:
  Use unsigned ea length for clarity (FATE#311695).
- patches.suse/cifs-015-pSesInfo-sesSem-is-used-as-mutex.-Rename-it-to-.patch:
  pSesInfo->sesSem is used as mutex. Rename it to session_mutex
  and convert it to a real mutex (FATE#311695).
- patches.suse/cifs-016-overhaul-cifs_revalidate-and-rename-to-cifs_rev.patch:
  cifs: overhaul cifs_revalidate and rename to
  cifs_revalidate_dentry (FATE#311695).
- patches.suse/cifs-017-add-a-CIFSSMBQFileInfo-function.patch:
  cifs: add a CIFSSMBQFileInfo function (FATE#311695).
- patches.suse/cifs-018-add-a-CIFSSMBUnixQFileInfo-function.patch:
  cifs: add a CIFSSMBUnixQFileInfo function (FATE#311695).
- patches.suse/cifs-019-add-cifs_revalidate_file.patch: cifs:
  add cifs_revalidate_file (FATE#311695).
- patches.suse/cifs-020-trivial-white-space.patch: cifs: trivial
  white space (FATE#311695).
- patches.suse/cifs-021-Add-mmap-for-direct-nobrl-cifs-mount-types.patch:
  Add mmap for direct, nobrl cifs mount types (FATE#311695).
- patches.suse/cifs-022-overwriting-file_lock-structure-after-GET_LK.patch:
  not overwriting file_lock structure after GET_LK (FATE#311695).
- patches.suse/cifs-023-Neaten-cERROR-and-cFYI-macros-reduce-text-space.patch:
  Neaten cERROR and cFYI macros, reduce text space (FATE#311695).
- patches.suse/cifs-024-Cleanup-various-minor-breakage-in-previous-cFYI.patch:
  Cleanup various minor breakage in previous cFYI cleanup
  (FATE#311695).
- patches.suse/cifs-025-Fix-losing-locks-during-fork.patch:
  Fix losing locks during fork() (FATE#311695).
- patches.suse/cifs-026-track-local_nls-in-volume-info.patch:
  cifs: track local_nls in volume info (FATE#311695).
- patches.suse/cifs-027-move-SMB-session-creation-code-into-separate-fu.patch:
  cifs: move SMB session creation code into separate function
  (FATE#311695).
- patches.suse/cifs-028-move-tcon-find-create-into-separate-function.patch:
  cifs: move tcon find/create into separate function
  (FATE#311695).
- patches.suse/cifs-029-rename-extended_security-to-global_secflags.patch:
  cifs: rename "extended_security" to "global_secflags"
  (FATE#311695).
- patches.suse/cifs-030-fix-typo.patch: cifs: change && to ||
  (FATE#311695).
- patches.suse/cifs-031-save-the-dialect-chosen-by-server.patch:
  cifs: save the dialect chosen by server (FATE#311695).
- patches.suse/cifs-032-Fix-lease-break-for-writes.patch: Fix
  lease break for writes (FATE#311695).
- patches.suse/cifs-033-eliminate-first_time-parm-to-CIFS_SessSetup.patch:
  cifs: eliminate "first_time" parm to CIFS_SessSetup
  (FATE#311695).
- patches.suse/cifs-034-break-negotiate-protocol-calls-out-of-cifs_setu.patch:
  cifs: break negotiate protocol calls out of cifs_setup_session
  (FATE#311695).
- patches.suse/cifs-035-have-decode_negTokenInit-set-flags-in-server-st.patch:
  cifs: have decode_negTokenInit set flags in server struct
  (FATE#311695).
- patches.suse/cifs-036-Remove-unused-cifs_oplock_cachep.patch:
  Remove unused cifs_oplock_cachep (FATE#311695).
- patches.suse/cifs-037-drop-quota-operation-stubs.patch: drop
  quota operation stubs (FATE#311695).
- patches.suse/cifs-038-always-revalidate-hardlinked-inodes-when-using-.patch:
  cifs: always revalidate hardlinked inodes when using noserverino
  (FATE#311695).
- patches.suse/cifs-039-don-t-update-uniqueid-in-cifs_fattr_to_inode.patch:
  cifs: don't update uniqueid in cifs_fattr_to_inode
  (FATE#311695).
- patches.suse/cifs-040-fix-noserverino-handling-when-unix-extensions-a.patch:
  cifs: fix noserverino handling when unix extensions are enabled
  (FATE#311695).
- patches.suse/cifs-041-implement-drop_inode-superblock-op.patch:
  cifs: implement drop_inode superblock op (FATE#311695).
- patches.suse/cifs-042-guard-cifsglob.h-against-multiple-inclusion.patch:
  cifs: guard cifsglob.h against multiple inclusion (FATE#311695).
- patches.suse/cifs-043-remove-an-potentially-confusing-obsolete-commen.patch:
  cifs: remove an potentially confusing, obsolete comment
  (FATE#311695).
- patches.suse/cifs-044-remove-unused-ip_address-field-in-struct-TCP_Se.patch:
  cifs: remove unused ip_address field in struct TCP_Server_Info
  (FATE#311695).
- patches.suse/cifs-045-add-kernel-config-option-for-CIFS-Client-cachin.patch:
  cifs: add kernel config option for CIFS Client caching support
  (FATE#311695).
- patches.suse/cifs-046-cifs-Remove-unnecessary-casts-of-private_data.patch:
  fs/cifs: Remove unnecessary casts of private_data (FATE#311695).
- patches.suse/cifs-047-register-CIFS-for-caching.patch: cifs:
  register CIFS for caching (FATE#311695).
- patches.suse/cifs-048-define-server-level-cache-index-objects-and-reg.patch:
  cifs: define server-level cache index objects and register them
  (FATE#311695).
- patches.suse/cifs-049-set-the-port-in-sockaddr-in-a-more-clearly-defi.patch:
  cifs: set the port in sockaddr in a more clearly defined fashion
  (FATE#311695).
- patches.suse/cifs-050-move-address-comparison-into-separate-function.patch:
  cifs: move address comparison into separate function
  (FATE#311695).
- patches.suse/cifs-051-match-secType-when-searching-for-existing-tcp-s.patch:
  cifs: match secType when searching for existing tcp session
  (FATE#311695).
- patches.suse/cifs-052-clean-up-cifs_find_smb_ses-try-2.patch:
  cifs: clean up cifs_find_smb_ses (try #2)  (FATE#311695).
- patches.suse/cifs-053-remove-unused-cifsUidInfo-struct.patch:
  cifs: remove unused cifsUidInfo struct (FATE#311695).
- patches.suse/cifs-054-define-superblock-level-cache-index-objects-and.patch:
  cifs: define superblock-level cache index objects and register
  them (FATE#311695).
- patches.suse/cifs-055-define-inode-level-cache-object-and-register-th.patch:
  cifs: define inode-level cache object and register them
  (FATE#311695).
- patches.suse/cifs-056-FS-Cache-page-management.patch: cifs:
  FS-Cache page management (FATE#311695).
- patches.suse/cifs-057-store-pages-into-local-cache.patch:
  cifs: store pages into local cache (FATE#311695).
- patches.suse/cifs-058-read-pages-from-FS-Cache.patch: cifs:
  read pages from FS-Cache (FATE#311695).
- patches.suse/cifs-059-add-mount-option-to-enable-local-caching.patch:
  cifs: add mount option to enable local caching (FATE#311695).
- patches.suse/cifs-060-Fix-build-break-when-CONFIG_CIFS_FSCACHE-disabl.patch:
  Fix build break when CONFIG_CIFS_FSCACHE disabled (FATE#311695).
- patches.suse/cifs-061-Missing-line-from-previous-commit.patch:
  Missing line from previous commit (FATE#311695).
- patches.suse/cifs-062-Missing-ifdef.patch: Missing ifdef
  (FATE#311695).
- patches.suse/cifs-063-cifs-check-kmalloc-result.patch: fs:
  cifs: check kmalloc() result (FATE#311695).
- patches.suse/cifs-064-add-separate-cred_uid-field-to-sesInfo.patch:
  cifs: add separate cred_uid field to sesInfo (FATE#311695).
- patches.suse/cifs-065-relinquish-fscache-cookie-before-freeing-CIFSTc.patch:
  relinquish fscache cookie before freeing CIFSTconInfo
  (FATE#311695).
- patches.suse/cifs-066-don-t-allow-cifs_iget-to-match-inodes-of-the-wr.patch:
  cifs: don't allow cifs_iget to match inodes of the wrong type
  (FATE#311695).
- patches.suse/cifs-067-map-NT_STATUS_ERROR_WRITE_PROTECTED-to-EROFS.patch:
  cifs: map NT_STATUS_ERROR_WRITE_PROTECTED to -EROFS
  (FATE#311695).
- patches.suse/cifs-068-ignore-the-mand-nomand-and-_netdev-mount-option.patch:
  cifs: ignore the "mand", "nomand" and "_netdev" mount options
  (FATE#311695).
- patches.suse/cifs-069-remove-redundant-path-walking-in-dfs_do_refmoun.patch:
  remove redundant path walking in dfs_do_refmount (FATE#311695).
- patches.suse/cifs-070-fsc-should-not-default-to-on.patch:
  cifs: fsc should not default to "on" (FATE#311695).
- patches.suse/cifs-071-update-README.patch: cifs: update README
  (FATE#311695).
- patches.suse/cifs-072-show-features-compiled-in-as-part-of-DebugData.patch:
  cifs: show features compiled in as part of DebugData
  (FATE#311695).
- patches.suse/cifs-073-Make-cifs_convert_address-take-a-const-src-poin.patch:
  CIFS: Make cifs_convert_address() take a const src pointer
  and a length (FATE#311695).
- patches.suse/cifs-074-reduce-false-positives-with-inode-aliasing-serv.patch:
  cifs: reduce false positives with inode aliasing serverino
  autodisable (FATE#311695).
- patches.suse/cifs-075-account-for-new-creduid-0x-x-parameter-in-spneg.patch:
  cifs: account for new creduid=0x%%x parameter in spnego upcall
  string (FATE#311695).
- patches.suse/cifs-076-update-README-to-include-details-about-fsc-opti.patch:
  cifs: update README to include details about 'fsc' option
  (FATE#311695).
- patches.suse/cifs-077-clean-up-error-handling-in-cifs_mknod.patch:
  cifs: clean up error handling in cifs_mknod (FATE#311695).
- patches.suse/cifs-078-consolidate-error-handling-in-several-functions.patch:
  cifs: consolidate error handling in several functions
  (FATE#311695).
- patches.suse/cifs-079-missing-prepathlen-oops: cifs: revert
  upstream commit "always do is_path_accessible.
- patches.suse/cifs-080-correction-of-unicode-header-files.patch:
  cifs: correction of unicode header files (FATE#311695).
- patches.suse/cifs-081-Fix-ntlmv2-auth-with-ntlmssp.patch:
  Fix ntlmv2 auth with ntlmssp (FATE#311695).
- patches.suse/cifs-082-changes-during-ntlmv2-ntlmssp-auth-and-sign.patch:
  missing changes during ntlmv2/ntlmssp auth and sign
  (FATE#311695).
- patches.suse/cifs-083-sparse-warning-bad-constant-expression.patch:
  Eliminate sparse warning - bad constant expression
  (FATE#311695).
- patches.suse/cifs-084-Eliminate-unused-variable-warning.patch:
  Eliminate unused variable warning (FATE#311695).
- patches.suse/cifs-085-CIFS-Eliminate-unused-variable-warning.patch:
  Revert " Eliminate unused variable warning" (FATE#311695).
- patches.suse/cifs-086-Eliminate-sparse-warning-bad-constant-express.patch:
  Revert "Eliminate sparse warning - bad constant expression"
  (FATE#311695).
- patches.suse/cifs-087-missing-changes-during-ntlmv2-ntlmssp-auth-an.patch:
  Revert "missing changes during ntlmv2/ntlmssp auth and sign"
  (FATE#311695).
- patches.suse/cifs-088-CIFS-Fix-ntlmv2-auth-with-ntlmssp.patch:
  Revert " Fix ntlmv2 auth with ntlmssp" (FATE#311695).
- patches.suse/cifs-089-eliminate-redundant-xdev-check-in-cifs_rename.patch:
  cifs: eliminate redundant xdev check in cifs_rename
  (FATE#311695).
- patches.suse/cifs-090-ntlmv2-ntlmssp-remove-unused-function-CalcNTLMv.patch:
  ntlmv2/ntlmssp remove-unused-function CalcNTLMv2_partial_mac_key
  (FATE#311695).
- patches.suse/cifs-091-prevent-cifsd-from-exiting-prematurely.patch:
  cifs: prevent cifsd from exiting prematurely (FATE#311695).
- patches.suse/cifs-092-eliminate-some-more-premature-cifsd-exits.patch:
  cifs: eliminate some more premature cifsd exits (FATE#311695).
- patches.suse/cifs-093-prevent-possible-memory-corruption-in-cifs_demu.patch:
  cifs: prevent possible memory corruption in
  cifs_demultiplex_thread (FATE#311695).
- patches.suse/cifs-094-fix-potential-double-put-of-TCP-session-referen.patch:
  cifs: fix potential double put of TCP session reference
  (FATE#311695).
- patches.suse/cifs-095-use-type-__u32-instead-of-int-for-the-oplock-pa.patch:
  cifs: use type __u32 instead of int for the oplock parameter
  (FATE#311695).
- patches.suse/cifs-096-fix-broken-oplock-handling.patch: cifs:
  fix broken oplock handling (FATE#311695).
- patches.suse/cifs-097-NTLMv2-NTLMSSP-Change-variable-name-mac_key-to-.patch:
  cifs NTLMv2/NTLMSSP Change variable name mac_key to session
  key to reflect the key it holds (FATE#311695).
- patches.suse/cifs-098-NTLMv2-NTLMSSP-ntlmv2-within-ntlmssp-autenticat.patch:
  cifs NTLMv2/NTLMSSP ntlmv2 within ntlmssp autentication code
  (FATE#311695).
- patches.suse/cifs-099-Allow-binding-to-local-IP-address.patch:
  cifs: Allow binding to local IP address (FATE#311695).
- patches.suse/cifs-100-implement-CIFSParseMFSymlink.patch:
  cifs: implement CIFSParseMFSymlink() (FATE#311695).
- patches.suse/cifs-101-implement-CIFSCouldBeMFSymlink-and-CIFSCheckMFS.patch:
  cifs: implement CIFSCouldBeMFSymlink() and CIFSCheckMFSymlink()
  (FATE#311695).
- patches.suse/cifs-102-implement-CIFSQueryMFSymLink.patch:
  cifs: implement CIFSQueryMFSymLink() (FATE#311695).
- patches.suse/cifs-103-implement-CIFSFormatMFSymlink.patch:
  cifs: implement CIFSFormatMFSymlink() (FATE#311695).
- patches.suse/cifs-104-implement-CIFSCreateMFSymLink.patch:
  cifs: implement CIFSCreateMFSymLink() (FATE#311695).
- patches.suse/cifs-105-use-Minshall-French-symlink-functions.patch:
  cifs: use Minshall+French symlink functions (FATE#311695).
- patches.suse/cifs-106-add-mfsymlinks-mount-option.patch: cifs:
  add "mfsymlinks" mount option (FATE#311695).
- patches.suse/cifs-107-add-tcon-field-to-cifsFileInfo-struct.patch:
  cifs: add tcon field to cifsFileInfo struct (FATE#311695).
- patches.suse/cifs-108-allow-matching-of-tcp-sessions-in-CifsNew-state.patch:
  cifs: allow matching of tcp sessions in CifsNew state
  (FATE#311695).
- patches.suse/cifs-109-Remove-obsolete-header.patch: Remove
  obsolete header (FATE#311695).
- patches.suse/cifs-110-Fix-ordering-of-cleanup-on-module-init-failure.patch:
  Fix ordering of cleanup on module init failure (FATE#311695).
- patches.suse/cifs-111-make-various-routines-use-the-cifsFileInfo-tcon.patch:
  cifs: make various routines use the cifsFileInfo->tcon pointer
  (FATE#311695).
- patches.suse/cifs-112-add-function-to-get-a-tcon-from-cifs_sb.patch:
  cifs: add function to get a tcon from cifs_sb (FATE#311695).
- patches.suse/cifs-113-temporarily-rename-cifs_sb-tcon-to-ptcon-to-cat.patch:
  cifs: temporarily rename cifs_sb->tcon to ptcon to catch
  stragglers (FATE#311695).
- patches.suse/cifs-114-add-cifs_sb_master_tcon-and-convert-some-caller.patch:
  cifs: add cifs_sb_master_tcon and convert some callers to use it
  (FATE#311695).
- patches.suse/cifs-115-have-cifs_new_fileinfo-take-a-tcon-arg.patch:
  cifs: have cifs_new_fileinfo take a tcon arg (FATE#311695).
- patches.suse/cifs-116-fix-handling-of-signing-with-writepages-try-6.patch:
  cifs: fix handling of signing with writepages (try #6)
  (FATE#311695).
- patches.suse/cifs-117-prevent-infinite-recursion-in-cifs_reconnect_tc.patch:
  cifs: prevent infinite recursion in cifs_reconnect_tcon
  (FATE#311695).
- patches.suse/cifs-118-add-refcounted-and-timestamped-container-for-ho.patch:
  cifs: add refcounted and timestamped container for holding tcons
  (FATE#311695).
- patches.suse/cifs-119-have-cifsFileInfo-hold-a-reference-to-a-tlink-r.patch:
  cifs: have cifsFileInfo hold a reference to a tlink rather
  than tcon pointer (FATE#311695).
- patches.suse/cifs-120-have-find_readable-writable_file-filter-by-fsui.patch:
  cifs: have find_readable/writable_file filter by fsuid
  (FATE#311695).
- patches.suse/cifs-121-fix-cifs_show_options-to-show-username-or-multi.patch:
  cifs: fix cifs_show_options to show "username=" or "multiuser"
  (FATE#311695).
- patches.suse/cifs-122-authentication-and-signing-Correct-response-len.patch:
  ntlm authentication and signing - Correct response length for
  ntlmv2 authentication without extended security (FATE#311695).
- patches.suse/cifs-123-add-routines-to-build-sessions-and-tcons-on-the.patch:
  cifs: add routines to build sessions and tcons on the fly
  (FATE#311695).
- patches.suse/cifs-124-add-multiuser-mount-option.patch: cifs:
  add "multiuser" mount option (FATE#311695).
- patches.suse/cifs-125-Various-small-checkpatch-cleanups.patch:
  Various small checkpatch cleanups (FATE#311695).
- patches.suse/cifs-126-on-multiuser-mount-set-ownership-to-current_fsu.patch:
  cifs: on multiuser mount, set ownership to
  current_fsuid/current_fsgid (try #5) (FATE#311695).
- patches.suse/cifs-127-implement-recurring-workqueue-job-to-prune-old-.patch:
  cifs: implement recurring workqueue job to prune old tcons
  (FATE#311695).
- patches.suse/cifs-128-fix-module-refcount-leak-in-find_domain_name.patch:
  cifs: fix module refcount leak in find_domain_name
  (FATE#311695).
- patches.suse/cifs-129-Remove-build-warning.patch: Remove build
  warning (FATE#311695).
- patches.suse/cifs-130-initialize-tlink_tree_lock-and-tlink_tree.patch:
  cifs: initialize tlink_tree_lock and tlink_tree (FATE#311695).
- patches.suse/cifs-131-ntlm-authentication-and-signing-Build-a-proper-.patch:
  CIFS ntlm authentication and signing - Build a proper av/ti
  pair blob for ntlmv2 without extended security authentication
  (FATE#311695).
- patches.suse/cifs-132-on-multiuser-mount-set-ownership-to-current_fsu.patch:
  cifs: on multiuser mount, set ownership to
  current_fsuid/current_fsgid (try #7) (FATE#311695).
- patches.suse/cifs-133-keep-dentry-reference-in-cifsFileInfo-instead-o.patch:
  cifs: keep dentry reference in cifsFileInfo instead of inode
  reference (FATE#311695).
- patches.suse/cifs-134-don-t-use-vfsmount-to-pin-superblock-for-oplock.patch:
  cifs: don't use vfsmount to pin superblock for oplock breaks
  (FATE#311695).
- patches.suse/cifs-135-authentication-and-signing-Calculate-auth-respo.patch:
  NTLM authentication and signing - Calculate auth response per
  smb session (FATE#311695).
- patches.suse/cifs-136-handle-FindFirst-failure-gracefully.patch:
  cifs: handle FindFirst failure gracefully (FATE#311695).
- patches.suse/cifs-137-eliminate-cifs_posix_open_inode_helper.patch:
  cifs: eliminate cifs_posix_open_inode_helper (FATE#311695).
- patches.suse/cifs-139-fix-flags-handling-in-cifs_posix_open.patch:
  cifs: fix flags handling in cifs_posix_open (FATE#311695).
- patches.suse/cifs-140-eliminate-oflags-option-from-cifs_new_fileinfo.patch:
  cifs: eliminate oflags option from cifs_new_fileinfo
  (FATE#311695).
- patches.suse/cifs-141-eliminate-the-inode-argument-from-cifs_new_file.patch:
  cifs: eliminate the inode argument from cifs_new_fileinfo
  (FATE#311695).
- patches.suse/cifs-142-clean-up-cifs_reopen_file.patch: cifs:
  clean up cifs_reopen_file (FATE#311695).
- patches.suse/cifs-143-cifs_write-argument-change-and-cleanup.patch:
  cifs: cifs_write argument change and cleanup (FATE#311695).
- patches.suse/cifs-144-eliminate-pfile-pointer-from-cifsFileInfo.patch:
  cifs: eliminate pfile pointer from cifsFileInfo (FATE#311695).
- patches.suse/cifs-145-move-cifs_new_fileinfo-to-file.c.patch:
  cifs: move cifs_new_fileinfo to file.c (FATE#311695).
- patches.suse/cifs-146-Fix-minor-checkpatch-warning-and-update-cifs-ve.patch:
  Fix minor checkpatch warning and update cifs version
  (FATE#311695).
- patches.suse/cifs-147-convert-GlobalSMBSeslock-from-a-rwlock-to-regul.patch:
  cifs: convert GlobalSMBSeslock from a rwlock to regular spinlock
  (FATE#311695).
- patches.suse/cifs-148-move-cifsFileInfo_put-to-file.c.patch:
  cifs: move cifsFileInfo_put to file.c (FATE#311695).
- patches.suse/cifs-149-up-two-declarations-of-blob_len.patch:
  Clean up two declarations of blob_len (FATE#311695).
- patches.suse/cifs-150-convert-cifs_tcp_ses_lock-from-a-rwlock-to-a-sp.patch:
  cifs: convert cifs_tcp_ses_lock from a rwlock to a spinlock
  (FATE#311695).
- patches.suse/cifs-151-move-close-processing-from-cifs_close-to-cifsFi.patch:
  move close processing  from cifs_close to cifsFileInfo_put
  (FATE#311695).
- patches.suse/cifs-152-convert-cifsFileInfo-count-to-non-atomic-counte.patch:
  cifs: convert cifsFileInfo->count to non-atomic counter
  (FATE#311695).
- patches.suse/cifs-153-wait-for-writeback-to-complete-in-cifs_flush.patch:
  cifs: wait for writeback to complete in cifs_flush
  (FATE#311695).
- patches.suse/cifs-154-Fix-checkpatch-warnings-and-bump-cifs-version-n.patch:
  Fix checkpatch warnings and bump cifs version number
  (FATE#311695).
- patches.suse/cifs-155-eliminate-cifsInodeInfo-write_behind_rc-try-6.patch:
  cifs: eliminate cifsInodeInfo->write_behind_rc (try #6)
  (FATE#311695).
- patches.suse/cifs-156-update-comments-s-GlobalSMBSesLock-cifs_file_li.patch:
  cifs: update comments -
  [s/GlobalSMBSesLock/cifs_file_list_lock/g] (FATE#311695).
- patches.suse/cifs-157-auth-and-sign-Allocate-session-key-client-respo.patch:
  NTLM auth and sign - Allocate session key/client response
  dynamically (FATE#311695).
- patches.suse/cifs-158-cifs_convert_address-returns-zero-on-error.patch:
  cifs: cifs_convert_address() returns zero on error
  (FATE#311695).
- patches.suse/cifs-159-auth-and-sign-Define-crypto-hash-functions-and-.patch:
  NTLM auth and sign - Define crypto hash functions and create
  and send keys needed for key exchange (FATE#311695).
- patches.suse/cifs-160-auth-and-sign-Use-kernel-crypto-apis-to-calcula.patch:
  NTLM auth and sign - Use kernel crypto apis to calculate hashes
  and smb signatures (FATE#311695).
- patches.suse/cifs-161-auth-and-sign-minor-error-corrections-and-clean.patch:
  NTLM auth and sign - minor error corrections and cleanup
  (FATE#311695).
- patches.suse/cifs-162-add-kfree-on-error-path.patch: cifs:
  add kfree() on error path (FATE#311695).
- patches.suse/cifs-163-auth-and-sign-Use-appropriate-server-challenge.patch:
  NTLM auth and sign - Use appropriate server challenge
  (FATE#311695).
- patches.suse/cifs-164-Cleanup-and-thus-reduce-smb-session-structure-a.patch:
  cifs: Cleanup and thus reduce smb session structure and fields
  used during authentication (FATE#311695).
- patches.suse/cifs-165-cifs-remove-unneeded-NULL-tests.patch:
  FS: cifs, remove unneeded NULL tests (FATE#311695).
- patches.suse/cifs-166-Add-cifs_set_oplock_level.patch: CIFS:
  Add cifs_set_oplock_level (FATE#311695).
- patches.suse/cifs-167-store-pointer-to-master-tlink-in-superblock-try.patch:
  cifs: store pointer to master tlink in superblock (try #2)
  (FATE#311695).
- patches.suse/cifs-168-convert-tlink_tree-to-a-rbtree.patch:
  cifs: convert tlink_tree to a rbtree (FATE#311695).
- patches.suse/cifs-169-Cleanup-unused-variable-build-warning.patch:
  Cleanup unused variable build warning (FATE#311695).
- patches.suse/cifs-170-trivial-comment-fix-tlink_tree-is-now-a-rbtree.patch:
  cifs: trivial comment fix: tlink_tree is now a rbtree
  (FATE#311695).
- patches.suse/cifs-171-dereferencing-first-then-checking.patch:
  cifs: dereferencing first then checking (FATE#311695).
- patches.suse/cifs-172-make-cifs_set_oplock_level-take-a-cifsInodeInfo.patch:
  cifs: make cifs_set_oplock_level() take a cifsInodeInfo pointer
  (FATE#311695).
- patches.suse/cifs-173-make-cifs_ioctl-handle-NULL-filp-private_data-c.patch:
  cifs: make cifs_ioctl handle NULL filp->private_data correctly
  (FATE#311695).
- patches.suse/cifs-174-fix-potential-use-after-free-in-cifs_oplock_bre.patch:
  cifs: fix potential use-after-free in cifs_oplock_break_put
  (FATE#311695).
- patches.suse/cifs-175-Percolate-error-up-to-the-caller-during-get-set.patch:
  cifs: Percolate error up to the caller during get/set acls
  (FATE#311695).
- patches.suse/cifs-176-don-t-take-extra-tlink-reference-in-initiate_ci.patch:
  cifs: don't take extra tlink reference in initiate_cifs_search
  (FATE#311695).
- patches.suse/cifs-177-fs-cifs-Kconfig-CIFS-depends-on-CRYPTO_HMAC.patch:
  fs/cifs/Kconfig: CIFS depends on CRYPTO_HMAC (FATE#311695).
- patches.suse/cifs-178-trivial-comment-fix-for-cifs_invalidate_mapping.patch:
  cifs: trivial comment fix for cifs_invalidate_mapping
  (FATE#311695).
- patches.suse/cifs-179-cleanup-cifsacl-handling.patch: cifs:
  Misc. cleanup in cifsacl handling (FATE#311695).
- patches.suse/cifs-180-Handle-extended-attribute-name-cifs_acl-to-gene.patch:
  cifs: Handle extended attribute name cifs_acl to generate cifs
  acl blob (try #4) (FATE#311695).
- patches.suse/cifs-181-allow-fsc-mount-option-only-if-CONFIG_CIFS_FSCA.patch:
  cifs: allow fsc mount option only if CONFIG_CIFS_FSCACHE is set
  (FATE#311695).
- patches.suse/cifs-182-enable-fscache-iff-fsc-mount-option-is-used-exp.patch:
  cifs: enable fscache iff fsc mount option is used explicitly
  (FATE#311695).
- patches.suse/cifs-183-display-fsc-in-proc-mounts.patch: cifs:
  display fsc in /proc/mounts (FATE#311695).
- patches.suse/cifs-184-add-attribute-cache-timeout-actimeo-tunable.patch:
  cifs: add attribute cache timeout (actimeo) tunable
  (FATE#311695).
- patches.suse/cifs-185-fix-use-of-CONFIG_CIFS_ACL.patch: cifs:
  fix use of CONFIG_CIFS_ACL (FATE#311695).
- patches.suse/cifs-186-remove-Local_System_Name.patch: cifs:
  remove Local_System_Name (FATE#311695).
- patches.suse/cifs-187-fix-check-of-error-return-from-is_path_accessab.patch:
  cifs: fix check of error return from is_path_accessable
  (FATE#311695).
- patches.suse/cifs-188-allow-calling-cifs_build_path_to_root-on-incomp.patch:
  cifs: allow calling cifs_build_path_to_root on incomplete
  cifs_sb (FATE#311695).
- patches.suse/cifs-189-remove-bogus-remapping-of-error-in-cifs_filldir.patch:
  cifs: remove bogus remapping of error in cifs_filldir()
  (FATE#311695).
- patches.suse/cifs-190-Support-NTLM2-session-security-during-NTLMSSP-a.patch:
  cifs: Support NTLM2 session security during NTLMSSP
  authentication (FATE#311695).
- patches.suse/cifs-191-Simplify-ipv-_connect-functions-into-one-try-4.patch:
  CIFS: Simplify ipv*_connect functions into one (try #4)
  (FATE#311695).
- patches.suse/cifs-192-Add-match_port-check-during-looking-for-an-exis.patch:
  CIFS: Add match_port check during looking for an existing
  connection (try #4) (FATE#311695).
- patches.suse/cifs-193-Simplify-non-posix-open-stuff-try-2.patch:
  CIFS: Simplify non-posix open stuff (try #2) (FATE#311695).
- patches.suse/cifs-194-Simplify-cifs_open-code.patch: CIFS:
  Simplify cifs_open code (FATE#311695).
- patches.suse/cifs-195-remove-unnecessary-locking-around-sequence_numb.patch:
  cifs: remove unnecessary locking around sequence_number
  (FATE#311695).
- patches.suse/cifs-196-replace-some-hardcoded-values-with-preprocessor.patch:
  cifs: replace some hardcoded values with preprocessor constants
  (FATE#311695).
- patches.suse/cifs-197-move-ntlmssp-and-local_leases-options-out-of-ex.patch:
  cifs: move "ntlmssp" and "local_leases" options out of
  experimental code (FATE#311695).
- patches.suse/cifs-198-show-acl-in-DebugData-Features-when-it-s-compil.patch:
  cifs: show "acl" in DebugData Features when it's compiled in
  (FATE#311695).
- patches.suse/cifs-199-switch-cifs_open-and-cifs_create-to-use-CIFSSMB.patch:
  cifs: switch cifs_open and cifs_create to use
  CIFSSMBUnixSetFileInfo (FATE#311695).
- patches.suse/cifs-200-use-CreationTime-like-an-i_generation-field.patch:
  cifs: use CreationTime like an i_generation field (FATE#311695).
- patches.suse/cifs-201-cFYI-the-entire-error-code-in-map_smb_to_linux_.patch:
  cifs: cFYI the entire error code in map_smb_to_linux_error
  (FATE#311695).
- patches.suse/cifs-202-add-cruid-mount-option.patch: cifs:
  add cruid= mount option (FATE#311695).
- patches.suse/cifs-203-don-t-fail-writepages-on-EAGAIN-errors.patch:
  cifs: don't fail writepages on -EAGAIN errors (FATE#311695).
- patches.suse/cifs-204-no-need-to-mark-smb_ses_list-as-cifs_demultiple.patch:
  cifs: no need to mark smb_ses_list as cifs_demultiplex_thread
  is exiting (FATE#311695).
- patches.suse/cifs-205-make-wait_for_free_request-take-a-TCP_Server_In.patch:
  cifs: make wait_for_free_request take a TCP_Server_Info pointer
  (FATE#311695).
- patches.suse/cifs-206-clean-up-accesses-to-midCount.patch:
  cifs: clean up accesses to midCount (FATE#311695).
- patches.suse/cifs-207-move-locked-sections-out-of-DeleteMidQEntry-and.patch:
  cifs: move locked sections out of DeleteMidQEntry and
  AllocMidQEntry (FATE#311695).
- patches.suse/cifs-208-move-mid-result-processing-into-common-function.patch:
  cifs: move mid result processing into common function
  (FATE#311695).
- patches.suse/cifs-209-Update-cifs-version-number.patch: Update
  cifs version number (FATE#311695).
- patches.suse/cifs-210-Fix-regression-during-share-level-security-moun.patch:
  cifs: Fix regression during share-level security mounts (Repost)
  (FATE#311695).
- patches.suse/cifs-211-Use-mask-of-ACEs-for-SID-Everyone-to-calculate-.patch:
  cifs: Use mask of ACEs for SID Everyone to calculate all three
  permissions user, group, and other (FATE#311695).
- patches.suse/cifs-212-wait-indefinitely-for-responses.patch:
  cifs: wait indefinitely for responses (FATE#311695).
- patches.suse/cifs-213-don-t-reconnect-server-when-we-don-t-get-a-resp.patch:
  cifs: don't reconnect server when we don't get a response
  (FATE#311695).
- patches.suse/cifs-214-clean-up-sync_mid_result.patch: cifs:
  clean up sync_mid_result (FATE#311695).
- patches.suse/cifs-215-allow-for-different-handling-of-received-respon.patch:
  cifs: allow for different handling of received response
  (FATE#311695).
- patches.suse/cifs-216-add-cifs_call_async.patch: cifs: add
  cifs_call_async (FATE#311695).
- patches.suse/cifs-217-add-ability-to-send-an-echo-request.patch:
  cifs: add ability to send an echo request (FATE#311695).
- patches.suse/cifs-218-set-up-recurring-workqueue-job-to-do-SMB-echo-r.patch:
  cifs: set up recurring workqueue job to do SMB echo requests
  (FATE#311695).
- patches.suse/cifs-219-cifs-reconnect-unresponsive-servers.patch:
  cifs: reconnect unresponsive servers (FATE#311695).
- patches.suse/cifs-220-remove-code-for-setting-timeouts-on-requests.patch:
  cifs: remove code for setting timeouts on requests
  (FATE#311695).
- patches.suse/cifs-221-mangle-existing-header-for-SMB_COM_NT_CANCEL.patch:
  cifs: mangle existing header for SMB_COM_NT_CANCEL
  (FATE#311695).
- patches.suse/cifs-222-TCP_Server_Info-diet.patch: cifs:
  TCP_Server_Info diet (FATE#311695).
- patches.suse/cifs-223-move-time-field-in-cifsInodeInfo.patch:
  cifs: move time field in cifsInodeInfo (FATE#311695).
- patches.suse/cifs-224-use-get-put_unaligned-functions-to-access-ByteC.patch:
  cifs: use get/put_unaligned functions to access ByteCount
  (FATE#311695).
- patches.suse/cifs-225-clean-up-unaligned-accesses-in-validate_t2.patch:
  cifs: clean up unaligned accesses in validate_t2 (FATE#311695).
- patches.suse/cifs-226-fix-unaligned-access-in-check2ndT2-and-coalesce.patch:
  cifs: fix unaligned access in check2ndT2 and coalesce_t2
  (FATE#311695).
- patches.suse/cifs-227-clean-up-unaligned-accesses-in-cifs_unicode.c.patch:
  cifs: clean up unaligned accesses in cifs_unicode.c
  (FATE#311695).
- patches.suse/cifs-228-fix-unaligned-accesses-in-cifsConvertToUCS.patch:
  cifs: fix unaligned accesses in cifsConvertToUCS (FATE#311695).
- patches.suse/cifs-229-fix-up-CIFSSMBEcho-for-unaligned-access.patch:
  cifs: fix up CIFSSMBEcho for unaligned access (FATE#311695).
- patches.suse/cifs-230-handle-cancelled-requests-better.patch:
  cifs: handle cancelled requests better (FATE#311695).
- patches.suse/cifs-231-send-an-NT_CANCEL-request-when-a-process-is-sig.patch:
  cifs: send an NT_CANCEL request when a process is signalled
  (FATE#311695).
- patches.suse/cifs-232-simplify-SMB-header-check-routine.patch:
  cifs: simplify SMB header check routine (FATE#311695).
- patches.suse/cifs-233-don-t-pop-a-printk-when-sending-on-a-socket-is-.patch:
  cifs: don't pop a printk when sending on a socket is interrupted
  (FATE#311695).
- patches.suse/cifs-234-force-a-reconnect-if-there-are-too-many-MIDs-in.patch:
  cifs: force a reconnect if there are too many MIDs in flight
  (FATE#311695).
- patches.suse/cifs-235-make-CIFS-depend-on-CRYPTO_MD4.patch:
  cifs: make CIFS depend on CRYPTO_MD4 (FATE#311695).
- patches.suse/cifs-236-Update-cifs-minor-version.patch: Update
  cifs minor version (FATE#311695).
- patches.suse/trace-open.patch: Refresh.
- patches.suse/vfs-138-fix-f_flags-and-f_fmode.patch: Fix
  f_flags/f_mode in case of lookup_instantiate_filp() from
  open(pathname, 3) (FATE#311695).
* Tue May 31 2011 jbeulich@novell.com
- Update i386/xen config file (drop privileged kernel support).
- rpm/package-descriptions: Adjust description for kernel-xen.
* Tue May 31 2011 jbeulich@novell.com
- Update Xen patches to c/s 1089.
- Update Xen config files.
- patches.xen/xen3-block-Consolidate-phys_segment-and-hw_segment-limit.patch:
  block: Consolidate phys_segment and hw_segment limits
  (FATE#311054).
- patches.xen/xen3-block-Rename-blk_queue_max_sectors-to-blk_queue_max.patch:
  block: Rename blk_queue_max_sectors to blk_queue_max_hw_sectors
  (FATE#311054).
- patches.xen/xen3-mm-pagealloc-free_pages_prepare.patch: mm:
  introduce free_pages_prepare() (Page allocator enhancements
  suitable for THP(fate #311931)).
- patches.xen/xen3-mm-thp-add-pmd-mangling-x86.patch: thp:
  add pmd mangling functions to x86 (THP core (fate #311931)).
- patches.xen/xen3-mm-thp-config.patch: thp:
  CONFIG_TRANSPARENT_HUGEPAGE (THP core (fate #311931)).
- patches.xen/xen3-oprofile-001-percpu-make-percpu-symbols-in-unique.patch:
  percpu: make percpu symbols in oprofile unique (FATE#309728,
  FATE#309730, BNC#686840).
- Refresh other Xen patches.
* Tue May 31 2011 mgalbraith@suse.de
- patches.suse/cpu-Avoid-using-unititialized-error-variable-in-disable_nonboot_cpus:
  CPU: Avoid using unititialized error variable in disable_nonboot_cpus().
- patches.suse/cpu-Remove-unused-variable:
  cpu: Remove unused variable.
- patches.suse/cpuset-Fix-cpuset_cpus_allowed_fallback-dont-update-tsk-rt-nr_cpus_allowed:
  cpuset: Fix cpuset_cpus_allowed_fallback(), don't update tsk->rt.nr_cpus_allowed.
- patches.suse/sched-Fix-min_vruntime-calculation-in-dequeue_entity:
  sched: Fix ->min_vruntime calculation in dequeue_entity().
- patches.suse/01-15-sched-fixlet-dont-update-shares-twice-on-on_rq-parent: Refresh.
- patches.suse/02-15-sched-hierarchical-task-accounting-for-SCHED_OTHER: Refresh.
- patches.suse/03-15-sched-introduce-primitives-to-account-for-CFS-bandwidth-tracking: Refresh.
- patches.suse/04-15-sched-validate-CFS-quota-hierarchies: Refresh.
- patches.suse/04-15-sched-validate-CFS-quota-hierarchies-fix: Refresh.
- patches.suse/05-15-sched-add-a-timer-to-handle-CFS-bandwidth-refresh: Refresh.
- patches.suse/06-15-sched-accumulate-per-cfs_rq-cpu-usage-and-charge-against-bandwidth: Refresh.
- patches.suse/07-15-sched-expire-invalid-runtime: Refresh.
- patches.suse/08-15-sched-throttle-cfs_rq-entities-which-exceed-their-local-runtime: Refresh.
- patches.suse/09-15-sched-unthrottle-cfs_rqs-who-ran-out-of-quota-at-period-refresh: Refresh.
- patches.suse/11-15-sched-prevent-interactions-between-throttled-entities-and-load-balance: Refresh.
- patches.suse/12-15-sched-migrate-throttled-tasks-on-HOTPLUG: Refresh.
- patches.suse/13-15-sched-add-exports-tracking-cfs-bandwidth-control-statistics: Refresh.
- patches.suse/14-15-sched-return-unused-runtime-on-voluntary-sleep: Refresh.
- patches.suse/16-15-sched-fix-hotplug-lockup: Refresh.
- patches.suse/SoN-07-mm-PF_MEMALLOC-softirq.patch: Refresh.
- patches.suse/sched-Simplify-cpu-hot-unplug-task-migration: Refresh.
* Tue May 31 2011 trenn@suse.de
- patches.arch/0001-nodemask-make-NODEMASK_ALLOC-more-general.patch:
  nodemask: make NODEMASK_ALLOC more general (fate#311647
  bnc#691979).
- patches.arch/0002-hugetlb-factor-init_nodemask_of_node.patch:
  hugetlb: factor init_nodemask_of_node() (fate#311647
  bnc#691979).
- patches.arch/0003-hugetlb-rework-hstate_next_node_-functions.patch:
  hugetlb: rework hstate_next_node_* functions (fate#311647
  bnc#691979).
- patches.arch/0004-hugetlb-add-nodemask-arg-to-huge-page-alloc-free-and.patch:
  hugetlb: add nodemask arg to huge page alloc, free and surplus
  adjust functions (fate#311647 bnc#691979).
- patches.arch/0005-hugetlb-derive-huge-pages-nodes-allowed-from-task-me.patch:
  hugetlb: derive huge pages nodes allowed from task mempolicy
  (fate#311647 bnc#691979).
- patches.arch/0006-hugetlb-add-per-node-hstate-attributes.patch:
  hugetlb: add per node hstate attributes (fate#311647
  bnc#691979).
- patches.arch/0007-hugetlb-update-hugetlb-documentation-for-NUMA-contro.patch:
  hugetlb: update hugetlb documentation for NUMA controls
  (fate#311647 bnc#691979).
- patches.arch/0008-hugetlb-handle-memory-hot-plug-events.patch:
  hugetlb: handle memory hot-plug events (fate#311647 bnc#691979).
- patches.arch/0009-hugetlb-use-only-nodes-with-memory-for-huge-pages.patch:
  hugetlb: use only nodes with memory for huge pages (fate#311647
  bnc#691979).
- patches.arch/0010-hugetlb-offload-per-node-attribute-registrations.patch:
  hugetlb: offload per node attribute registrations (fate#311647
  bnc#691979).
- patches.arch/0011-hugetlb-add-generic-definition-of-NUMA_NO_NODE.patch:
  hugetlb: add generic definition of NUMA_NO_NODE (fate#311647
  bnc#691979).
* Tue May 31 2011 jack@suse.cz
- patches.xen/tmem: Added lost chunk from previous refresh.
* Mon May 30 2011 jankit@suse.de
- patches.fixes/dm-mpath-add-mutex-to-synchronize-adding-and-flushing-work:
  dm mpath: add mutex to synchronize adding and flushing work
  (bnc#668483).
- patches.fixes/dm-mpath-flush-workqueues-before-suspend-completes:
  dm mpath: flush workqueues before suspend completes
  (bnc#668483).
- patches.fixes/dm-mpath-hold-io-until-all-pg_inits-complete:
  dm mpath: hold io until all pg_inits completed (bnc#668483).
- patches.fixes/dm-mpath-prevent-io-from-workqueue-while-suspended:
  dm mpath: prevent io from work queue while suspended
  (bnc#668483).
- patches.fixes/dm-mpath-wait-for-pg_init-completion-when-suspending:
  dm mpath: wait for pg_init completion when suspending
  (bnc#668483).
* Mon May 30 2011 mgalbraith@suse.de
- patches.suse/sched-More-sched_domain-iterations-fixes:
  sched: More sched_domain iterations fixes.
- patches.suse/02-15-sched-hierarchical-task-accounting-for-SCHED_OTHER:
  Refresh.
* Mon May 30 2011 hare@suse.de
- patches.suse/scsi-raid_attrs-fix-dependency-problems.patch:
  Delete as it is causing build failures.
* Mon May 30 2011 hare@suse.de
- Backport fixes from 2.6.34 (FATE#311054):
- patches.suse/Block-Fix-block-elevator.c-elevator_get-off-by-on.patch:
  Block: Fix block/elevator.c elevator_get() off-by-one error
  (FATE#311054).
- patches.suse/Documentation-fix-block-biodoc.txt-dma-mapping-desc.patch:
  Documentation: fix block/biodoc.txt dma mapping description
  (FATE#311054).
- patches.suse/Remove-GENHD_FL_DRIVERFS.patch: Remove
  GENHD_FL_DRIVERFS (FATE#311054).
- patches.suse/ataflop-Killl-warning-about-unused-variable-flags.patch:
  ataflop: Killl warning about unused variable flags
  (FATE#311054).
- patches.suse/backing-dev-Handle-class_create-failure.patch:
  backing-dev: Handle class_create() failure (FATE#311054).
- patches.suse/blk-cgroup-Fix-RCU-correctness-warning-in-cfq_init_.patch:
  blk-cgroup: Fix RCU correctness warning in cfq_init_queue()
  (FATE#311054).
- patches.suse/blk-cgroup-Fix-an-RCU-warning-in-blkiocg_create.patch:
  blk-cgroup: Fix an RCU warning in blkiocg_create()
  (FATE#311054).
- patches.suse/blk-core-use-BIO-list-management-functions.patch:
  blk-core: use BIO list management functions (FATE#311054).
- patches.suse/blkdev-fix-merge_bvec_fn-return-value-checks-v2.patch:
  blkdev: fix merge_bvec_fn return value checks v2 (FATE#311054).
- patches.suse/blkdev-fix-merge_bvec_fn-return-value-checks.patch:
  blkdev: fix merge_bvec_fn return value checks (FATE#311054).
- patches.suse/blkio-Add-io-controller-stats-like.patch: blkio:
  Add io controller stats like (FATE#311054).
- patches.suse/blkio-Increment-the-blkio-cgroup-stats-for-real-now.patch:
  blkio: Increment the blkio cgroup stats for real now
  (FATE#311054).
- patches.suse/blkio-Remove-per-cfqq-nr_sectors-as-we-ll-be-passin.patch:
  blkio: Remove per-cfqq nr_sectors as we'll be passing
  (FATE#311054).
- patches.suse/blktrace-perform-cleanup-after-setup-error.patch:
  blktrace: perform cleanup after setup error (FATE#311054).
- patches.suse/block-Add-BLK_-prefix-to-definitions.patch: block:
  Add BLK_ prefix to definitions (FATE#311054).
- patches.suse/block-Consolidate-phys_segment-and-hw_segment-limit.patch:
  block: Consolidate phys_segment and hw_segment limits
  (FATE#311054).
- patches.suse/block-Export-max-number-of-segments-and-max-segment.patch:
  block: Export max number of segments and max segment size in
  sysfs (FATE#311054).
- patches.suse/block-Finalize-conversion-of-block-limits-functions.patch:
  block: Finalize conversion of block limits functions
  (FATE#311054).
- patches.suse/block-Remove-unused-accessor-function.patch:
  block: Remove unused accessor function (FATE#311054).
- patches.suse/block-Rename-blk_queue_max_sectors-to-blk_queue_max.patch:
  block: Rename blk_queue_max_sectors to blk_queue_max_hw_sectors
  (FATE#311054).
- patches.suse/block-Update-blk_queue_max_sectors-and-documentatio.patch:
  block: Update blk_queue_max_sectors and documentation
  (FATE#311054).
- patches.suse/block-don-t-access-jiffies-when-initialising-io_con.patch:
  block: don't access jiffies when initialising io_context
  (FATE#311054).
- patches.suse/block-expose-the-statistics-in-blkio.time-and-blkio.patch:
  block: expose the statistics in blkio.time and blkio.sectors
  for the root cgroup (FATE#311054).
- patches.suse/block-fix-for-Consolidate-phys_segment-and-hw_segm.patch:
  block: fix for "Consolidate phys_segment and hw_segment limits"
  (FATE#311054).
- patches.suse/block-make-CONFIG_BLK_CGROUP-visible.patch: block:
  make CONFIG_BLK_CGROUP visible (FATE#311054).
- patches.suse/block-make-Open-Firmware-device-id-constant.patch:
  block: make Open Firmware device id constant (FATE#311054).
- patches.suse/block-make-PCI-device-id-constant.patch: block:
  make PCI device id constant (FATE#311054).
- patches.suse/block-make-USB-device-id-constant.patch: block:
  make USB device id constant (FATE#311054).
- patches.suse/block-make-virtio-device-id-constant.patch: block:
  make virtio device id constant (FATE#311054).
- patches.suse/block-make-xenbus-device-id-constant.patch: block:
  make xenbus device id constant (FATE#311054).
- patches.suse/block-remove-16-bytes-of-padding-from-struct-reques.patch:
  block: remove 16 bytes of padding from struct request on 64bits
  (FATE#311054).
- patches.suse/block-remove-padding-from-io_context-on-64bit-build.patch:
  block: remove padding from io_context on 64bit builds
  (FATE#311054).
- patches.suse/cfq-Remove-useless-css-reference-get.patch: cfq:
  Remove useless css reference get (FATE#311054).
- patches.suse/cfq-iosched-Add-additional-blktrace-log-messages-in.patch:
  cfq-iosched: Add additional blktrace log messages in CFQ for
  easier debugging (FATE#311054).
- patches.suse/cfq-iosched-Do-not-merge-queues-of-BE-and-IDLE-clas.patch:
  cfq-iosched: Do not merge queues of BE and IDLE classes
  (FATE#311054).
- patches.suse/cfq-iosched-Fix-the-incorrect-timeslice-accounting.patch:
  cfq-iosched: Fix the incorrect timeslice accounting with
  forced_dispatch (FATE#311054).
- patches.suse/cfq-iosched-fix-a-kbuild-regression.patch:
  cfq-iosched: fix a kbuild regression (FATE#311054).
- patches.suse/cfq-iosched-quantum-check-tweak.patch: cfq-iosched:
  quantum check tweak (FATE#311054).
- patches.suse/cfq-iosched-requests-in-flight-vs-in-driver-cla.patch:
  cfq-iosched: requests "in flight" vs "in driver" clarification
  (FATE#311054).
- patches.suse/cfq-iosched-rethink-seeky-detection-for-SSDs.patch:
  cfq-iosched: rethink seeky detection for SSDs (FATE#311054).
- patches.suse/cfq-iosched-rework-seeky-detection.patch:
  cfq-iosched: rework seeky detection (FATE#311054).
- patches.suse/cfq-remove-8-bytes-of-padding-from-cfq_rb_root-on-6.patch:
  cfq: remove 8 bytes of padding from cfq_rb_root on 64 bit builds
  (FATE#311054).
- patches.suse/dm-document-when-snapshot-has-finished-merging.patch:
  dm: document when snapshot has finished merging (FATE#311054).
- patches.suse/dm-eliminate-some-holes-data-structures.patch:
  dm: eliminate some holes data structures (FATE#311054).
- patches.suse/dm-free-dm_io-before-bio_endio-not-after.patch:
  dm: free dm_io before bio_endio not after (FATE#311054).
- patches.suse/dm-ioctl-introduce-flag-indicating-uevent-was-gener.patch:
  dm ioctl: introduce flag indicating uevent was generated
  (FATE#311054).
- patches.suse/dm-ioctl-only-issue-uevent-on-resume-if-state-chang.patch:
  dm ioctl: only issue uevent on resume if state changed
  (FATE#311054).
- patches.suse/dm-mpath-avoid-storing-private-suspended-state.patch:
  dm mpath: avoid storing private suspended state (FATE#311054).
- patches.suse/dm-mpath-hold-io-until-all-pg_inits-completed.patch:
  dm mpath: hold io until all pg_inits completed (FATE#311054).
- patches.suse/dm-mpath-pass-struct-pgpath-to-pg-init-done.patch:
  dm mpath: pass struct pgpath to pg init done (FATE#311054).
- patches.suse/dm-mpath-refactor-pg_init.patch: dm mpath:
  refactor pg_init (FATE#311054).
- patches.suse/dm-mpath-wait-for-pg_init-completion-when-suspendin.patch:
  dm mpath: wait for pg_init completion when suspending
  (FATE#311054).
- patches.suse/dm-raid1-always-return-error-if-all-legs-fail.patch:
  dm raid1: always return error if all legs fail (FATE#311054).
- patches.suse/dm-raid1-fix-deadlock-when-suspending-failed-device.patch:
  dm raid1: fix deadlock when suspending failed device
  (FATE#311054).
- patches.suse/dm-table-remove-dm_get-from-dm_table_get_md.patch:
  dm table: remove dm_get from dm_table_get_md (FATE#311054).
- patches.suse/dm-table-remove-unused-dm_get_device-range-paramete.patch:
  dm table: remove unused dm_get_device range parameters
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-DPRINT-neatening.patch:
  drivers/block/floppy.c: DPRINT neatening (FATE#311054).
- patches.suse/drivers-block-floppy.c-add-__func__-to-debugt.patch:
  drivers/block/floppy.c: add __func__ to debugt (FATE#311054).
- patches.suse/drivers-block-floppy.c-add-debug_dcl-.-macro.patch:
  drivers/block/floppy.c: add debug_dcl(...) macro (FATE#311054).
- patches.suse/drivers-block-floppy.c-add-function-is_ready_state.patch:
  drivers/block/floppy.c: add function is_ready_state
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-comment-neatening-and-remove.patch:
  drivers/block/floppy.c: comment neatening and remove naked ;
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-convert-int-1-0-to-bool-true.patch:
  drivers/block/floppy.c: convert int 1/0 to bool true/false
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-convert-int-initialising-to.patch:
  drivers/block/floppy.c: convert int initialising to bool
  initialized (FATE#311054).
- patches.suse/drivers-block-floppy.c-convert-raw_cmd_copyin-from.patch:
  drivers/block/floppy.c: convert raw_cmd_copyin from while(1)
  to label: goto (FATE#311054).
- patches.suse/drivers-block-floppy.c-convert-some-include-asm.patch:
  drivers/block/floppy.c: convert some #include <asm/ to #include
  <linux/ (FATE#311054).
- patches.suse/drivers-block-floppy.c-define-space-and-column-nea.patch:
  drivers/block/floppy.c: #define space and column neatening
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-hoist-assigns-from-if-s-ne.patch:
  drivers/block/floppy.c: hoist assigns from if()s, neatening
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-indent-a-comment.patch:
  drivers/block/floppy.c: indent a comment (FATE#311054).
- patches.suse/drivers-block-floppy.c-move-leading-and-to-pr.patch:
  drivers/block/floppy.c: move leading && and || to preceding line
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-CLEARSTRUCT-macro-us.patch:
  drivers/block/floppy.c: remove CLEARSTRUCT macro, use memset
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-IN-OUT-macros-indent.patch:
  drivers/block/floppy.c: remove IN/OUT macros, indent switch/case
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-LAST_OUT-macro.patch:
  drivers/block/floppy.c: remove LAST_OUT macro (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-REPEAT-macro.patch:
  drivers/block/floppy.c: remove REPEAT macro (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-U-CLEARF-U-SETF-a.patch:
  drivers/block/floppy.c: remove [U]CLEARF, [U]SETF, and [U]TESTF
  macros (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-_-COPYIN-_-COPYOUT.patch:
  drivers/block/floppy.c: remove [_]COPYIN [_]COPYOUT and ECALL
  macros (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-a-few-spaces-from-fun.patch:
  drivers/block/floppy.c: remove a few spaces from function casts
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-define-DEVICE_NAME.patch:
  drivers/block/floppy.c: remove #define DEVICE_NAME "floppy"
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-define-FLOPPY_SANITY.patch:
  drivers/block/floppy.c: remove #define FLOPPY_SANITY_CHECK
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-macro-LOCK_FDC.patch:
  drivers/block/floppy.c: remove macro LOCK_FDC (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-macros-CALL-WAIT-and.patch:
  drivers/block/floppy.c: remove macros CALL, WAIT and IWAIT
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-misleading-used-once.patch:
  drivers/block/floppy.c: remove misleading, used once
  FD_IOCTL_ALLOWED macro (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-most-uses-of-CALL-and.patch:
  drivers/block/floppy.c: remove most uses of CALL and ECALL
  macros (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-obfuscating-CODE2SIZE.patch:
  drivers/block/floppy.c: remove obfuscating CODE2SIZE macro
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-some-unnecessary-cast.patch:
  drivers/block/floppy.c: remove some unnecessary casting
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-unnecessary-argument.patch:
  drivers/block/floppy.c: remove unnecessary argument from
  [__]reschedule_timeout (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-unnecessary-braces.patch:
  drivers/block/floppy.c: remove unnecessary braces (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-unnecessary-casting-i.patch:
  drivers/block/floppy.c: remove unnecessary casting in fd_ioctl
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-unnecessary-return-an.patch:
  drivers/block/floppy.c: remove unnecessary return and braces
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-remove-used-once-CHECK_READY.patch:
  drivers/block/floppy.c: remove used once CHECK_READY macro
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-unclutter-redo_fd_request-lo.patch:
  drivers/block/floppy.c: unclutter redo_fd_request logic
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-use-__func__-where-appropria.patch:
  drivers/block/floppy.c: use __func__ where appropriate
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-use-pf-in-logging-messages.patch:
  drivers/block/floppy.c: use %%pf in logging messages
  (FATE#311054).
- patches.suse/drivers-block-floppy.c-use-pr_-level.patch:
  drivers/block/floppy.c: use pr_<level> (FATE#311054).
- patches.suse/ibmvfc-Add-FC-Passthru-support.patch: Refresh.
- patches.suse/mac68k-cleanup.patch: mac68k: cleanup
  (FATE#311054).
- patches.suse/mac68k-move-mac_esp-platform-device.patch: mac68k:
  move mac_esp platform device (FATE#311054).
- patches.suse/mac68k-rework-SWIM-platform-device.patch: mac68k:
  rework SWIM platform device (FATE#311054).
- patches.suse/md-006-raid1-add-takeover-support-for-raid5-raid1.patch:
  Refresh.
- patches.suse/md-020-Add-support-for-Raid5-Raid0-and-Raid10-Raid0-take.patch:
  Refresh.
- patches.suse/paride-fix-off-by-one-test.patch: paride: fix
  off-by-one test (FATE#311054).
- patches.suse/pktcdvd-improve-BKL-and-compat_ioctl.c-usage.patch:
  pktcdvd: improve BKL and compat_ioctl.c usage (FATE#311054).
- patches.suse/pktcdvd-use-BIO-list-management-functions.patch:
  pktcdvd: use BIO list management functions (FATE#311054).
- patches.suse/platform-drivers-move-probe-to-.devinit.text-in-dri.patch:
  platform-drivers: move probe to .devinit.text in drivers/scsi
  (FATE#311054).
- patches.suse/powerpc-viodasd-Remove-VIOD_KERN_-level-macros-for.patch:
  powerpc/viodasd: Remove VIOD_KERN_<level> macros for printks
  (FATE#311054).
- patches.suse/qlogicpti-Remove-slash-in-QlogicPTI-irq-name.patch:
  qlogicpti: Remove slash in QlogicPTI irq name (FATE#311054).
- patches.suse/scsi-3w-xxxx-3w-9xxx-force-60-second-timeout.patch:
  [SCSI] 3w-xxxx, 3w-9xxx: force 60 second timeout (FATE#311054).
- patches.suse/scsi-3ware-maintainers-update.patch: [SCSI]
  3ware maintainers update (FATE#311054).
- patches.suse/scsi-Add-missing-scsi-command-definitions.patch:
  [SCSI] Add missing scsi command definitions (FATE#311054).
- patches.suse/scsi-Fix-printing-of-failed-32-byte-commands.patch:
  [SCSI] Fix printing of failed 32-byte commands (FATE#311054).
- patches.suse/scsi-Fix-printing-of-variable-length-commands.patch:
  [SCSI] Fix printing of variable length commands (FATE#311054).
- patches.suse/scsi-FlashPoint-fix-off-by-one-tests.patch:
  [SCSI] FlashPoint: fix off by one tests (FATE#311054).
- patches.suse/scsi-add-missing-kernel-doc-notation-for-new-VPD.patch:
  scsi.c: add missing kernel-doc notation for new VPD parameters
  (FATE#311054).
- patches.suse/scsi-advansys-fix-narrow-board-error-path.patch:
  [SCSI] advansys: fix narrow board error path (FATE#311054).
- patches.suse/scsi-advansys-fix-regression-with-request_firmwar.patch:
  [SCSI] advansys: fix regression with request_firmware change
  (FATE#311054).
- patches.suse/scsi-bnx2i-set-change_queue_depth-function.patch:
  [SCSI] bnx2i: set change_queue_depth function (FATE#311054).
- patches.suse/scsi-cxgb3i-bnx2i-remove-uses-of-nipquad-use-pi.patch:
  [SCSI] cxgb3i, bnx2i: remove uses of nipquad use %%pi4
  (FATE#311054).
- patches.suse/scsi-cxgb3i-check-for-setup-netdev.patch: [SCSI]
  cxgb3i: check for setup netdev (FATE#311054).
- patches.suse/scsi-cxgbi3-remove-unnecessary-NULL-test.patch:
  [SCSI] cxgbi3: remove unnecessary NULL test (FATE#311054).
- patches.suse/scsi-don-t-kfree-an-initialized-struct-device.patch:
  [SCSI] don't kfree an initialized struct device (FATE#311054).
- patches.suse/scsi-don-t-reap-targets-upon-device_add-failure.patch:
  [SCSI] don't reap targets upon device_add failure (FATE#311054).
- patches.suse/scsi-dpt_i2o-several-use-after-free-issues.patch:
  [SCSI] dpt_i2o: several use after free issues (FATE#311054).
- patches.suse/scsi-eata-fix-buffer-overflow.patch: [SCSI] eata:
  fix buffer overflow (FATE#311054).
- patches.suse/scsi-fix-duplicate-removal-on-error-path-in-scsi_s.patch:
  [SCSI] fix duplicate removal on error path in
  scsi_sysfs_add_sdev (FATE#311054).
- patches.suse/scsi-fix-memory-leak-in-scsi_report_lun_scan.patch:
  [SCSI] fix memory leak in scsi_report_lun_scan (FATE#311054).
- patches.suse/scsi-fix-refcounting-bug-in-scsi_get_host_dev.patch:
  [SCSI] fix refcounting bug in scsi_get_host_dev (FATE#311054).
- patches.suse/scsi-gdth-Convert-to-use-regular-kernel-types.patch:
  [SCSI] gdth: Convert to use regular kernel types (FATE#311054).
- patches.suse/scsi-gdth-fix-buffer-overflow.patch: [SCSI] gdth:
  fix buffer overflow (FATE#311054).
- patches.suse/scsi-ibmmca-fix-buffer-overflow.patch: [SCSI]
  ibmmca: fix buffer overflow (FATE#311054).
- patches.suse/scsi-ibmvfc-Add-suspend-resume-support.patch:
  [SCSI] ibmvfc: Add suspend/resume support (FATE#311054).
- patches.suse/scsi-ibmvscsi-Add-suspend-resume-support.patch:
  [SCSI] ibmvscsi: Add suspend/resume support (FATE#311054).
- patches.suse/scsi-ibmvscsi-fix-DMA-API-misuse.patch: [SCSI]
  ibmvscsi: fix DMA API misuse (FATE#311054).
- patches.suse/scsi-ibmvscsi-fix-a-typo-in-a-source-code-comment.patch:
  [SCSI] ibmvscsi: fix a typo in a source code comment
  (FATE#311054).
- patches.suse/scsi-ipr-add-error-handling-updates-for-the-next.patch:
  [SCSI] ipr: add error handling updates for the next generation
  chip (FATE#311054).
- patches.suse/scsi-ipr-add-hardware-assisted-smart-dump-functio.patch:
  [SCSI] ipr: add hardware assisted smart dump functionality
  (FATE#311054).
- patches.suse/scsi-ipr-add-support-for-multiple-stages-of-initi.patch:
  [SCSI] ipr: add support for multiple stages of initialization
  (FATE#311054).
- patches.suse/scsi-ipr-add-support-for-new-IOASCs.patch: [SCSI]
  ipr: add support for new IOASCs (FATE#311054).
- patches.suse/scsi-ipr-add-support-for-new-adapter-command-stru.patch:
  [SCSI] ipr: add support for new adapter command structures
  for the next generation chip (FATE#311054).
- patches.suse/scsi-ipr-adds-PCI-ID-definitions-for-new-adapters.patch:
  [SCSI] ipr: adds PCI ID definitions for new adapters
  (FATE#311054).
- patches.suse/scsi-ipr-define-new-offsets-to-registers-for-the.patch:
  [SCSI] ipr: define new offsets to registers for the next
  generation chip (FATE#311054).
- patches.suse/scsi-ipr-implement-shutdown-changes-and-remove-ob.patch:
  [SCSI] ipr: implement shutdown changes and remove obsolete
  write cache parameter (FATE#311054).
- patches.suse/scsi-ipr-rename-blk_queue_max_sectors: ipr:
  Rename blk_queue_max_sectors (FATE#311054).
- patches.suse/scsi-ipr-update-the-configuration-table-code-for.patch:
  [SCSI] ipr: update the configuration table code for the next
  generation chip (FATE#311054).
- patches.suse/scsi-iscsi_tcp-Change-iscsi_sw_tcp_conn_restore_c.patch:
  [SCSI] iscsi_tcp: Change iscsi_sw_tcp_conn_restore_callbacks
  arguments (FATE#311054).
- patches.suse/scsi-iscsi_tcp-Remove-unused-field-iscsi_conn-fro.patch:
  [SCSI] iscsi_tcp: Remove unused field iscsi_conn from struct
  iscsi_sw_tcp_conn (FATE#311054).
- patches.suse/scsi-libiscsi-reset-cmd-timer-if-cmds-are-making.patch:
  [SCSI] libiscsi: reset cmd timer if cmds are making progress
  (FATE#311054).
- patches.suse/scsi-libosd-Fix-unchecked-err-return-found-by-sma.patch:
  [SCSI] libosd: Fix unchecked err return found by smatch
  (FATE#311054).
- patches.suse/scsi-libsrp-fix-bug-in-ADDITIONAL-CDB-LENGTH-inte.patch:
  [SCSI] libsrp: fix bug in ADDITIONAL CDB LENGTH interpretation
  (FATE#311054).
- patches.suse/scsi-libsrp-fix-typo-replace-RDAM-by-RDMA.patch:
  [SCSI] libsrp: fix typo -- replace RDAM by RDMA (FATE#311054).
- patches.suse/scsi-mac_esp-fix-PIO-mode-take-2.patch: [SCSI]
  mac_esp: fix PIO mode, take 2 (FATE#311054).
- patches.suse/scsi-pmcraid-redundant-check-in-pmcraid_check_ioc.patch:
  [SCSI] pmcraid: redundant check in pmcraid_check_ioctl_buffer()
  (FATE#311054).
- patches.suse/scsi-qla4xxx-fix-compile-warning-due-to-invalid-e.patch:
  [SCSI] qla4xxx: fix compile warning due to invalid extHwConfig
  (FATE#311054).
- patches.suse/scsi-raid_attrs-fix-dependency-problems.patch:
  [SCSI] raid_attrs: fix dependency problems (FATE#311054).
- patches.suse/scsi-scsi_debug-Block-Limits-VPD-page-fixes.patch:
  [SCSI] scsi_debug: Block Limits VPD page fixes (FATE#311054).
- patches.suse/scsi-scsi_debug-add-max_queue-no_uld-parameters.patch:
  [SCSI] scsi_debug: add max_queue + no_uld parameters
  (FATE#311054).
- patches.suse/scsi-sd-Combine-DIF-DIX-error-handling.patch:
  [SCSI] sd: Combine DIF/DIX error handling (FATE#311054).
- patches.suse/scsi-sd-Fix-VPD-buffer-allocations.patch: [SCSI]
  sd: Fix VPD buffer allocations (FATE#311054).
- patches.suse/scsi-u14-34f-fix-buffer-overflow.patch: [SCSI]
  u14-34f: fix buffer overflow (FATE#311054).
- patches.suse/scsi-vmw_pvscsi-fix-signedness-warning-with-newer.patch:
  [SCSI] vmw_pvscsi: fix signedness warning with newer compilers
  (FATE#311054).
- patches.suse/scsi-wd7000-fix-reset-handler-typo-spin_unlock_ir.patch:
  [SCSI] wd7000: fix reset handler typo spin_unlock_irq() =>
  spin_lock_irq() (FATE#311054).
- patches.suse/staging-hyper-v-added-all-patches-for-hyper-v-same-as-2.6.35-now.patch:
  Refresh.
- patches.suse/virtio_blk-add-block-topology-support.patch:
  virtio_blk: add block topology support (FATE#311054).
- patches.xen/xen-floppy: Refresh.
* Mon May 30 2011 jack@suse.cz
- patches.fixes/mm-Fix-assertion-mapping-nrpages-0-in-end_writeback.patch:
  mm: Fix assertion mapping->nrpages == 0 in end_writeback()
  (bnc#693013 bnc#666423).
- patches.xen/sfc-external-sram: Refresh.
- patches.xen/tmem: Refresh.
* Mon May 30 2011 hare@suse.de
- patches.suse/block-Stop-using-byte-offsets.patch: Add missing
  commit-id.
* Mon May 30 2011 hare@suse.de
- patches.xen/sfc-update-to-kfifo-api: sfc: Port to new kfifo API
  (FATE#311054).
* Mon May 30 2011 hare@suse.de
- Rename patches starting with '-':
  * patches.suse/libata-MWDMA0-is-unsupported-on-PIIX-like-PATA-con.patch:
  * patches.suse/libata-PATA-Update-experimental-tags.patch:
* Sun May 29 2011 jbohac@suse.cz
- patches.kabi/sock-kabi-fixup-for-adding-sk_backlog.len.patch:
  Fixed an IPv6 socket memory corruption caused by the original version
  of this patch (bnc#655973, bnc#693149).
* Sat May 28 2011 tonyj@suse.de
- Fix Xen build errors from previous oprofile commit.  Build now passes
  with CONFIG_SFC=n
- patches.xen/xen3-patch-2.6.24: Refresh.
- patches.xen/xen3-patch-2.6.29: Refresh.
* Sat May 28 2011 jslaby@suse.de
- patches.drivers/mm-extract-exe_file-handling-from-procfs.patch:
  Refresh. One more build failure on ppc.
* Sat May 28 2011 jslaby@suse.de
- patches.suse/kfifo-move-struct-kfifo-in-place-libsrp-fix.patch:
  libsrp: fix compile failure (fate#311054).
* Sat May 28 2011 jslaby@suse.de
- patches.drivers/core_pattern-fix-truncation-by-core_pattern-handler.patch:
  core_pattern: fix truncation by core_pattern handler with long
  parameters (fate#309473).
- patches.drivers/coredump-add-support-for-exe_file-in-core-name.patch:
  coredump: add support for exe_file in core name (fate#309473).
- patches.drivers/mm-extract-exe_file-handling-from-procfs.patch:
  mm: extract exe_file handling from procfs (fate#309473).
* Sat May 28 2011 mgalbraith@suse.de
- General concensus being that combined patches create more pain than gain,
  remove combined scheduler updates, and insert the individual patches used
  to generate them in their place.
- patches.suse/01-15-sched-fixlet-dont-update-shares-twice-on-on_rq-parent:
  sched: (fixlet) dont update shares twice on on_rq.
- patches.suse/02-15-sched-hierarchical-task-accounting-for-SCHED_OTHER:
  sched: hierarchical task accounting for SCHED_OTHER.
- patches.suse/03-15-sched-introduce-primitives-to-account-for-CFS-bandwidth-tracking:
  sched: introduce primitives to account for CFS.
- patches.suse/03-15-sched-introduce-primitives-to-account-for-CFS-bandwidth-tracking-fix:
  sched: introduce primitives to account for CFS bandwidth tracking UP buildfix.
- patches.suse/04-15-sched-validate-CFS-quota-hierarchies:
  sched: validate CFS quota hierarchies.
- patches.suse/04-15-sched-validate-CFS-quota-hierarchies-fix:
  sched: validate CFS quota hierarchies - bugfix.
- patches.suse/05-15-sched-add-a-timer-to-handle-CFS-bandwidth-refresh:
  sched: add a timer to handle CFS bandwidth refresh.
- patches.suse/06-15-sched-accumulate-per-cfs_rq-cpu-usage-and-charge-against-bandwidth:
  sched: accumulate per-cfs_rq cpu usage and charge.
- patches.suse/07-15-sched-expire-invalid-runtime:
  sched: expire invalid runtime.
- patches.suse/08-15-sched-throttle-cfs_rq-entities-which-exceed-their-local-runtime:
  sched: throttle cfs_rq entities which exceed their local runtime.
- patches.suse/09-15-sched-unthrottle-cfs_rqs-who-ran-out-of-quota-at-period-refresh:
  sched: unthrottle cfs_rq(s) who ran out of quota at period refresh.
- patches.suse/10-15-sched-allow-for-positional-tg_tree-walks:
  sched: allow for positional tg_tree walks.
- patches.suse/11-15-sched-prevent-interactions-between-throttled-entities-and-load-balance:
  sched: prevent interactions between throttled entities and load-balance.
- patches.suse/12-15-sched-migrate-throttled-tasks-on-HOTPLUG:
  sched: migrate throttled tasks on HOTPLUG.
- patches.suse/13-15-sched-add-exports-tracking-cfs-bandwidth-control-statistics:
  sched: add exports tracking cfs bandwidth control statistics.
- patches.suse/14-15-sched-return-unused-runtime-on-voluntary-sleep:
  sched: return unused runtime on voluntary sleep.
- patches.suse/15-15-sched-add-documentation-for-bandwidth-control:
  sched: add documentation for bandwidth control.
- patches.suse/16-15-sched-fix-hotplug-lockup:
  Re: Test for CFS Bandwidth Control V6 ( fix hotplug lockup).
- patches.suse/cpu_stop-add-dummy-implementation-for-UP:
  cpu_stop: add dummy implementation for UP.
- patches.suse/cpu_stop-implement-stop_cpu-and-stop_cpus:
  cpu_stop: implement stop_cpu().
- patches.suse/cpumask-Partition_sched_domains-takes-array-of-cpumask_var_t:
  cpumask: Partition_sched_domains takes array of cpumask_var_t.
- patches.suse/cpumask-Simplify-sched_rt-c:
  cpumask: Simplify sched_rt.c.
- patches.suse/powerpc-Enable-asymmetric-SMT-scheduling-on-POWER7:
  powerpc: Enable asymmetric SMT scheduling on POWER7.
- patches.suse/powerpc-Exclude-arch_sd_sibiling_asym_packing-on-UP:
  powerpc: Exclude arch_sd_sibiling_asym_packing() on UP.
- patches.suse/rcu-need-barrier-in-UP-synchronize_sched_expedited:
  rcu: need barrier() in UP synchronize_sched_expedited().
- patches.suse/sched-Add-asymmetric-group-packing-option-for-sibling-domain:
  sched: Add asymmetric group packing option for sibling domain.
- patches.suse/sched-Add-book-scheduling-domain:
  sched: Add book scheduling domain.
- patches.suse/sched-Add-enqueue-dequeue-flags:
  sched: Add enqueue/dequeue flags.
- patches.suse/sched-Add-sysctl_sched_shares_window:
  sched: Add sysctl_sched_shares_window.
- patches.suse/sched-Allow-SCHED_BATCH-to-preempt-SCHED_IDLE-tasks:
  sched: Allow SCHED_BATCH to preempt SCHED_IDLE tasks.
- patches.suse/sched-Allow-update_cfs_load-to-update-global-load:
  sched: Allow update_cfs_load() to update global load.
- patches.suse/sched-Allow-users-with-sufficient-RLIMIT_NICE-to-change-from-SCHED_IDLE-policy:
  sched: Allow users with sufficient RLIMIT_NICE to change from SCHED_IDLE policy.
- patches.suse/sched-Assume-balance-is-valid:
  sched: Assume *balance is valid.
- patches.suse/sched-Avoid-allocations-in-sched_domain_debug:
  sched: Avoid allocations in sched_domain_debug().
- patches.suse/sched-Avoid-expensive-initial-update_cfs_load:
  sched: Avoid expensive initial update_cfs_load().
- patches.suse/sched-Avoid-expensive-initial-update_cfs_load-on-UP-too:
  sched: Avoid expensive initial update_cfs_load(), on UP too.
- patches.suse/sched-Avoid-going-ahead-if-cpus_allowed-is-not-changed:
  sched: Avoid going ahead if ->cpus_allowed is not changed.
- patches.suse/sched-Avoid-side-effect-of-tickless-idle-on-update_cpu_load:
  sched: Avoid side-effect of tickless idle on update_cpu_load.
- patches.suse/sched-Avoid-using-sd-level:
  sched: Avoid using sd->level.
- patches.suse/sched-Change-NODE-sched_domain-group-creation:
  sched: Change NODE sched_domain group creation.
- patches.suse/sched-Change-nohz-idle-load-balancing-logic-to-push-model:
  sched: Change nohz idle load balancing logic to push model.
- patches.suse/sched-Change-usage-of-rt_rq-rt_se-to-rt_rq-tg-rt_se-cpu:
  sched: Change usage of rt_rq->rt_se to rt_rq->tg->rt_se.
- patches.suse/sched-Clean-up-rebalance_domains-load-balance-interval-calculation:
  sched: Clean up rebalance_domains() load-balance interval calculation.
- patches.suse/sched-Clean-up-remnants-of-sd_idle:
  sched: Clean up remnants of sd_idle.
- patches.suse/sched-Clean-up-some-ALLNODES-code:
  sched: Clean up some ALLNODES code.
- patches.suse/sched-Clean-up-some-f_b_g-comments:
  sched: Clean up some f_b_g() comments.
- patches.suse/sched-Cleanup-set_load_weight:
  sched: Cleanup set_load_weight().
- patches.suse/sched-Create-persistent-sched_domains_tmpmask:
  sched: Create persistent sched_domains_tmpmask.
- patches.suse/sched-Create-proper-cpu_DOM_mask-functions:
  sched: Create proper cpu_$DOM_mask() functions.
- patches.suse/sched-Create-special-class-for-stop-and-migrate-work:
  sched: Create special class for stop/migrate work.
- patches.suse/sched-Cure-load-average-vs-NO_HZ-woes:
  sched: Cure load average vs NO_HZ woes.
- patches.suse/sched-Cure-more-NO_HZ-load-average-woes:
  sched: Cure more NO_HZ load average woes.
- patches.suse/sched-Dont-expose-local-functions:
  sched: Don't expose local functions.
- patches.suse/sched-Drop-all-load-weight-manipulation-for-RT-tasks:
  sched: Drop all load weight manipulation for RT tasks.
- patches.suse/sched-Dynamic-sched_domain-level:
  sched: Dynamic sched_domain::level.
- patches.suse/sched-Dynamically-allocate-sched_domain-sched_group-data-structures:
  sched: Dynamically allocate sched_domain/sched_group data-structures.
- patches.suse/sched-Fix-PROVE_RCU-vs-cpu_cgroup:
  sched: Fix PROVE_RCU vs cpu_cgroup.
- patches.suse/sched-Fix-UP-build-breakage:
  sched: Fix UP build breakage.
- patches.suse/sched-Fix-and-optimise-calculation-of-the-weight-inverse:
  sched: Fix and optimise calculation of the weight-inverse.
- patches.suse/sched-Fix-capacity-calculations-for-SMT4:
  sched: Fix capacity calculations for SMT4.
- patches.suse/sched-Fix-comments-to-make-them-DocBook-happy:
  sched: Fix comments to make them DocBook happy.
- patches.suse/sched-Fix-erroneous-all_pinned-logic:
  sched: Fix erroneous all_pinned logic.
- patches.suse/sched-Fix-fix_small_capacity:
  sched: Fix fix_small_capacity.
- patches.suse/sched-Fix-interactivity-bug-by-charging-unaccounted-run-time-on-entity-re-weight:
  sched: Fix interactivity bug by charging unaccounted run-time on entity re-weight.
- patches.suse/sched-Fix-load-corruption-from-update_cfs_shares:
  sched: Fix load corruption from update_cfs_shares().
- patches.suse/sched-Fix-nohz-balance-kick:
  sched: Fix nohz balance kick.
- patches.suse/sched-Fix-poor-interactivity-on-UP-systems-due-to-group-scheduler-nice-tune-bug:
  sched: Fix poor interactivity on UP systems due to group scheduler nice tune bug.
- patches.suse/sched-Fix-rebalance-interval-calculation:
  sched: Fix rebalance interval calculation.
- patches.suse/sched-Fix-remove-redundant-cfs_rq-checks:
  sched: Fix/remove redundant cfs_rq checks.
- patches.suse/sched-Fix-rt_rq-runtime-leakage-bug:
  sched: Fix rt_rq runtime leakage bug.
- patches.suse/sched-Fix-runnable-condition-for-stoptask:
  sched: Fix runnable condition for stoptask.
- patches.suse/sched-Fix-sched-domain-avg_load-calculation:
  sched: Fix sched-domain avg_load calculation.
- patches.suse/sched-Fix-sched-rt-group-scheduling-when-hierachy-is-enabled:
  sched: Fix sched rt group scheduling when hierachy is enabled.
- patches.suse/sched-Fix-sched_domain-iterations-vs-RCU:
  sched: Fix sched_domain iterations vs. RCU.
- patches.suse/sched-Fix-sign-under-flows-in-wake_affine:
  sched: Fix sign under-flows in wake_affine.
- patches.suse/sched-Fix-spelling-of-sibling:
  sched: Fix spelling of sibling.
- patches.suse/sched-Fix-strncmp-operation:
  sched: Fix strncmp operation.
- patches.suse/sched-Fix-switch_from_fair:
  sched: Fix switch_from_fair().
- patches.suse/sched-Fix-the-group_imb-logic:
  sched: Fix the group_imb logic.
- patches.suse/sched-Fix-the-irqtime-code-for-32bit:
  sched: Fix the irqtime code for 32bit.
- patches.suse/sched-Fix-the-irqtime-code-to-deal-with-u64-wraps:
  sched: Fix the irqtime code to deal with u64 wraps.
- patches.suse/sched-Fix-the-place-where-group-powers-are-updated:
  sched: Fix the place where group powers are updated.
- patches.suse/sched-Fix-unregister_fair_sched_group:
  sched: Fix unregister_fair_sched_group().
- patches.suse/sched-Fix-update_cfs_load-synchronization:
  sched: Fix update_cfs_load() synchronization.
- patches.suse/sched-Fix-update_curr_rt:
  sched: Fix update_curr_rt().
- patches.suse/sched-Implement-demand-based-update_cfs_load:
  sched: Implement demand based update_cfs_load().
- patches.suse/sched-Implement-on-demand-cfs_rq-list:
  sched: Implement on-demand (active) cfs_rq list.
- patches.suse/sched-Increase-SCHED_LOAD_SCALE-resolution:
  sched: Increase SCHED_LOAD_SCALE resolution.
- patches.suse/sched-Introduce-SCHED_POWER_SCALE-to-scale-cpu_power-calculation:
  sched: Introduce SCHED_POWER_SCALE to scale cpu_power calculations.
- patches.suse/sched-Introduce-hierarchal-order-on-shares-update-list:
  sched: Introduce hierarchal order on shares update list.
- patches.suse/sched-Leave-sched_setscheduler-earlier-if-possible-to-not-disturb-SCHED_FIFO-task:
  sched: Leave sched_setscheduler() earlier if possible, do not disturb SCHED_FIFO tasks.
- patches.suse/sched-Limit-the-scope-of-clear_buddies:
  sched: Limit the scope of clear_buddies.
- patches.suse/sched-Make-set_next-last_buddy-work-on-non-task-entities:
  sched: Make set_*_buddy() work on non-task entities.
- patches.suse/sched-Make-sure-timers-have-migrated-before-killing-the-migration_thread:
  sched: Make sure timers have migrated before killing the migration_thread.
- patches.suse/sched-Make-tg_shares_up-walk-on-demand:
  sched: Make tg_shares_up() walk on-demand.
- patches.suse/sched-Merge-cpu_to_core_group-functions:
  sched: Merge cpu_to_core_group functions.
- patches.suse/sched-Move-load-balance-code-into-sched_fair-c:
  sched: Move load balance code into sched_fair.c.
- patches.suse/sched-Move-periodic-share-updates-to-entity_tick:
  sched: Move periodic share updates to entity_tick().
- patches.suse/sched-Move-sched-domain-storage-into-the-topology-list:
  sched: Move sched domain storage into the topology list.
- patches.suse/sched-Next-buddy-hint-on-sleep-and-preempt-path:
  sched: Next buddy hint on sleep and preempt path.
- patches.suse/sched-No-need-for-bootmem-special-cases:
  sched: No need for bootmem special cases.
- patches.suse/sched-Reduce-some-allocation-pressure:
  sched: Reduce some allocation pressure.
- patches.suse/sched-Reduce-update_group_power-calls:
  sched: Reduce update_group_power() calls.
- patches.suse/sched-Remove-from-fwd-decls:
  sched: Remove from fwd decls.
- patches.suse/sched-Remove-load_balance_newidle:
  sched: Remove load_balance_newidle().
- patches.suse/sched-Remove-member-rt_se-from-struct-rt_rq:
  sched: Remove member rt_se from struct rt_rq.
- patches.suse/sched-Remove-nodemask-allocation:
  sched: Remove nodemask allocation.
- patches.suse/sched-Remove-noop-in-alloc_rt_sched_group:
  sched: Remove noop in alloc_rt_sched_group().
- patches.suse/sched-Remove-obsolete-arch_-prefixes:
  sched: Remove obsolete arch_ prefixes.
- patches.suse/sched-Remove-obsolete-comment-from-scheduler_tick:
  sched: Remove obsolete comment from scheduler_tick().
- patches.suse/sched-Remove-rq_iterator-from-move_one_task:
  sched: Remove rq_iterator from move_one_task.
- patches.suse/sched-Remove-rq_iterator-usage-from-load_balance_fair:
  sched: Remove rq_iterator usage from load_balance_fair.
- patches.suse/sched-Remove-some-dead-code:
  sched: Remove some dead code.
- patches.suse/sched-Remove-the-sched_class-load_balance-methods:
  sched: Remove the sched_class load_balance methods.
- patches.suse/sched-Remove-unused-parameters-from-sched_fork-and-wake_up_new_task:
  sched: Remove unused parameters from sched_fork() and wake_up_new_task().
- patches.suse/sched-Remove-unused-this_best_prio-arg-from-balance_tasks:
  sched: Remove unused 'this_best_prio arg' from balance_tasks().
- patches.suse/sched-Remove-unused-update_shares_locked:
  sched: Remove unused update_shares_locked().
- patches.suse/sched-Reverse-the-topology-list:
  sched: Reverse the topology list.
- patches.suse/sched-Rewrite-tg_shares_up:
  sched: Rewrite tg_shares_up().
- patches.suse/sched-Shorten-the-construction-of-the-span-cpu-mask-of-sched-domain:
  sched: Shorten the construction of the span cpu mask of sched domain.
- patches.suse/sched-Simplify-NODE-ALLNODES-domain-creation:
  sched: Simplify NODE/ALLNODES domain creation.
- patches.suse/sched-Simplify-build_sched_groups:
  sched: Simplify build_sched_groups().
- patches.suse/sched-Simplify-cpu-hot-unplug-task-migration:
  sched: Simplify cpu-hot-unplug task migration.
- patches.suse/sched-Simplify-cpu_power-initialization:
  sched: Simplify ->cpu_power initialization.
- patches.suse/sched-Simplify-finding-the-lowest-sched_domain:
  sched: Simplify finding the lowest sched_domain.
- patches.suse/sched-Simplify-sched_group-creation:
  sched: Simplify sched_group creation.
- patches.suse/sched-Simplify-sched_groups_power-initialization:
  sched: Simplify sched_groups_power initialization.
- patches.suse/sched-Simplify-the-free-path-some:
  sched: Simplify the free path some.
- patches.suse/sched-Simplify-the-idle-scheduling-class:
  sched: Simplify the idle scheduling class.
- patches.suse/sched-Simplify-update_cfs_shares-parameters:
  sched: Simplify update_cfs_shares parameters.
- patches.suse/sched-Stuff-the-sched_domain-creation-in-a-data-structure:
  sched: Stuff the sched_domain creation in a data-structure.
- patches.suse/sched-Unify-load_balance-and-load_balance_newidle:
  sched: Unify load_balance{,_newidle}().
- patches.suse/sched-Unify-the-sched_domain-build-functions:
  sched: Unify the sched_domain build functions.
- patches.suse/sched-Update-effective_load-to-use-global-share-weights:
  sched: Update effective_load() to use global share weights.
- patches.suse/sched-Update-rq-clock-for-nohz-balanced-cpus:
  sched: Update rq->clock for nohz balanced cpus.
- patches.suse/sched-Update-shares-on-idle_balance:
  sched: Update shares on idle_balance.
- patches.suse/sched-Update-tg-shares-after-cpu-shares-write:
  sched: Update tg->shares after cpu.shares write.
- patches.suse/sched-Use-for_each_bit:
  sched: Use for_each_bit.
- patches.suse/sched-Use-rq-clock_task-instead-of-rq-clock-for-correctly-maintaining-load-average:
  sched: Use rq->clock_task instead of rq->clock for correctly maintaining load averages.
- patches.suse/sched-Wholesale-removal-of-sd_idle-logic:
  sched: Wholesale removal of sd_idle logic (bnc#588972).
- patches.suse/sched-Wrap-the-cfs_rq-nr_spread_over-field-with-CONFIG_SCHED_DEBUG:
  sched: Wrap the 'cfs_rq->nr_spread_over' field with CONFIG_SCHED_DEBUG.
- patches.suse/sched-cgroup-Fix-cgroup_subsys-exit-callback:
  cgroup: Fix cgroup_subsys::exit callback.
- patches.suse/sched-cgroup-Use-exit-hook-to-avoid-use-after-free-crash:
  sched, cgroup: Use exit hook to avoid use-after-free crash.
- patches.suse/sched-cgroups-if-you-list_empty-a-head-then-dont-list_del-it:
  cgroups: if you list_empty() a head then don't list_del() it.
- patches.suse/sched-correctly-place-paranioa-memory-barriers-in-synchronize_sched_expedited:
  sched: correctly place paranioa memory barriers in synchronize_sched_expedited().
- patches.suse/sched-kill-paranoia-check-in-synchronize_sched_expedited:
  sched: kill paranoia check in synchronize_sched_expedited().
- patches.suse/sched-might_sleep-Make-file-parameter-const-char-pointer:
  sched: might_sleep(): Make file parameter const char *.
- patches.suse/sched-no_hz-Remove-unused-rq-last_tick_seen-field:
  sched, no_hz: Remove unused rq->last_tick_seen field.
- patches.suse/sched-replace-migration_thread-with-cpu_stop:
  sched: replace migration_thread with cpu_stop.
- patches.suse/sched-workqueue-kill-RT-workqueue:
  workqueue: kill RT workqueue.
- patches.suse/stop_machine-Move-local-variable-closer-to-the-usage-site-in-cpu_stop_cpu_callback:
  stop_machine: Move local variable closer to the usage site in cpu_stop_cpu_callback().
- patches.suse/stop_machine-fix-unused-variable-warning:
  kernel/stop_machine.c: fix unused variable warning.
- patches.suse/stop_machine-reimplement-using-cpu_stop:
  stop_machine: reimplement using cpu_stop.
- patches.suse/stop_machine-struct-cpu_stopper-remove-alignment-padding-on-64-bits:
  stop_machine: struct cpu_stopper, remove alignment padding on 64 bits.
- patches.suse/topology-s390-Add-z11-cpu-topology-support:
  topology, s390: Add z11 cpu topology support.
- patches.suse/topology-s390-expose-core-identifier:
  topology: expose core identifier.
- patches.suse/topology-sysfs-Provide-book-id-and-siblings-attributes:
  topology/sysfs: Provide book id and siblings attributes.
- patches.fixes/sched-cfs-hard-limits-V6: Delete.
- patches.fixes/sched-sle11-sp2-fates-scheduler-update: Delete.
- patches.sched/01-15-sched-fixlet-dont-update-shares-twice-on-on_rq-parent:
  Delete.
- patches.sched/02-15-sched-hierarchical-task-accounting-for-SCHED_OTHER:
  Delete.
- patches.sched/03-15-sched-introduce-primitives-to-account-for-CFS-bandwidth-tracking:
  Delete.
- patches.sched/03-15-sched-introduce-primitives-to-account-for-CFS-bandwidth-tracking-fix:
  Delete.
- patches.sched/04-15-sched-validate-CFS-quota-hierarchies:
  Delete.
- patches.sched/04-15-sched-validate-CFS-quota-hierarchies-fix:
  Delete.
- patches.sched/05-15-sched-add-a-timer-to-handle-CFS-bandwidth-refresh:
  Delete.
- patches.sched/06-15-sched-accumulate-per-cfs_rq-cpu-usage-and-charge-against-bandwidth:
  Delete.
- patches.sched/07-15-sched-expire-invalid-runtime: Delete.
- patches.sched/08-15-sched-throttle-cfs_rq-entities-which-exceed-their-local-runtime:
  Delete.
- patches.sched/09-15-sched-unthrottle-cfs_rqs-who-ran-out-of-quota-at-period-refresh:
  Delete.
- patches.sched/10-15-sched-allow-for-positional-tg_tree-walks:
  Delete.
- patches.sched/11-15-sched-prevent-interactions-between-throttled-entities-and-load-balance:
  Delete.
- patches.sched/12-15-sched-migrate-throttled-tasks-on-HOTPLUG:
  Delete.
- patches.sched/13-15-sched-add-exports-tracking-cfs-bandwidth-control-statistics:
  Delete.
- patches.sched/14-15-sched-return-unused-runtime-on-voluntary-sleep:
  Delete.
- patches.sched/15-15-sched-add-documentation-for-bandwidth-control:
  Delete.
- patches.sched/16-15-sched-fix-hotplug-lockup: Delete.
- patches.sched/cpu_stop-add-dummy-implementation-for-UP: Delete.
- patches.sched/cpu_stop-implement-stop_cpu-and-stop_cpus: Delete.
- patches.sched/cpumask-Partition_sched_domains-takes-array-of-cpumask_var_t:
  Delete.
- patches.sched/cpumask-Simplify-sched_rt-c: Delete.
- patches.sched/powerpc-Enable-asymmetric-SMT-scheduling-on-POWER7:
  Delete.
- patches.sched/powerpc-Exclude-arch_sd_sibiling_asym_packing-on-UP:
  Delete.
- patches.sched/rcu-need-barrier-in-UP-synchronize_sched_expedited:
  Delete.
- patches.sched/sched-Add-asymmetric-group-packing-option-for-sibling-domain:
  Delete.
- patches.sched/sched-Add-book-scheduling-domain: Delete.
- patches.sched/sched-Add-enqueue-dequeue-flags: Delete.
- patches.sched/sched-Add-sysctl_sched_shares_window: Delete.
- patches.sched/sched-Allow-SCHED_BATCH-to-preempt-SCHED_IDLE-tasks:
  Delete.
- patches.sched/sched-Allow-update_cfs_load-to-update-global-load:
  Delete.
- patches.sched/sched-Allow-users-with-sufficient-RLIMIT_NICE-to-change-from-SCHED_IDLE-policy:
  Delete.
- patches.sched/sched-Assume-balance-is-valid: Delete.
- patches.sched/sched-Avoid-allocations-in-sched_domain_debug:
  Delete.
- patches.sched/sched-Avoid-expensive-initial-update_cfs_load:
  Delete.
- patches.sched/sched-Avoid-expensive-initial-update_cfs_load-on-UP-too:
  Delete.
- patches.sched/sched-Avoid-going-ahead-if-cpus_allowed-is-not-changed:
  Delete.
- patches.sched/sched-Avoid-side-effect-of-tickless-idle-on-update_cpu_load:
  Delete.
- patches.sched/sched-Avoid-using-sd-level: Delete.
- patches.sched/sched-Change-NODE-sched_domain-group-creation:
  Delete.
- patches.sched/sched-Change-nohz-idle-load-balancing-logic-to-push-model:
  Delete.
- patches.sched/sched-Change-usage-of-rt_rq-rt_se-to-rt_rq-tg-rt_se-cpu:
  Delete.
- patches.sched/sched-Clean-up-rebalance_domains-load-balance-interval-calculation:
  Delete.
- patches.sched/sched-Clean-up-remnants-of-sd_idle: Delete.
- patches.sched/sched-Clean-up-some-ALLNODES-code: Delete.
- patches.sched/sched-Clean-up-some-f_b_g-comments: Delete.
- patches.sched/sched-Cleanup-set_load_weight: Delete.
- patches.sched/sched-Create-persistent-sched_domains_tmpmask:
  Delete.
- patches.sched/sched-Create-proper-cpu_DOM_mask-functions:
  Delete.
- patches.sched/sched-Create-special-class-for-stop-and-migrate-work:
  Delete.
- patches.sched/sched-Cure-load-average-vs-NO_HZ-woes: Delete.
- patches.sched/sched-Cure-more-NO_HZ-load-average-woes: Delete.
- patches.sched/sched-Dont-expose-local-functions: Delete.
- patches.sched/sched-Drop-all-load-weight-manipulation-for-RT-tasks:
  Delete.
- patches.sched/sched-Dynamic-sched_domain-level: Delete.
- patches.sched/sched-Dynamically-allocate-sched_domain-sched_group-data-structures:
  Delete.
- patches.sched/sched-Fix-PROVE_RCU-vs-cpu_cgroup: Delete.
- patches.sched/sched-Fix-UP-build-breakage: Delete.
- patches.sched/sched-Fix-and-optimise-calculation-of-the-weight-inverse:
  Delete.
- patches.sched/sched-Fix-capacity-calculations-for-SMT4: Delete.
- patches.sched/sched-Fix-comments-to-make-them-DocBook-happy:
  Delete.
- patches.sched/sched-Fix-erroneous-all_pinned-logic: Delete.
- patches.sched/sched-Fix-fix_small_capacity: Delete.
- patches.sched/sched-Fix-interactivity-bug-by-charging-unaccounted-run-time-on-entity-re-weight:
  Delete.
- patches.sched/sched-Fix-load-corruption-from-update_cfs_shares:
  Delete.
- patches.sched/sched-Fix-nohz-balance-kick: Delete.
- patches.sched/sched-Fix-poor-interactivity-on-UP-systems-due-to-group-scheduler-nice-tune-bug:
  Delete.
- patches.sched/sched-Fix-rebalance-interval-calculation: Delete.
- patches.sched/sched-Fix-remove-redundant-cfs_rq-checks: Delete.
- patches.sched/sched-Fix-rt_rq-runtime-leakage-bug: Delete.
- patches.sched/sched-Fix-runnable-condition-for-stoptask: Delete.
- patches.sched/sched-Fix-sched-domain-avg_load-calculation:
  Delete.
- patches.sched/sched-Fix-sched-rt-group-scheduling-when-hierachy-is-enabled:
  Delete.
- patches.sched/sched-Fix-sched_domain-iterations-vs-RCU: Delete.
- patches.sched/sched-Fix-sign-under-flows-in-wake_affine: Delete.
- patches.sched/sched-Fix-spelling-of-sibling: Delete.
- patches.sched/sched-Fix-strncmp-operation: Delete.
- patches.sched/sched-Fix-switch_from_fair: Delete.
- patches.sched/sched-Fix-the-group_imb-logic: Delete.
- patches.sched/sched-Fix-the-irqtime-code-for-32bit: Delete.
- patches.sched/sched-Fix-the-irqtime-code-to-deal-with-u64-wraps:
  Delete.
- patches.sched/sched-Fix-the-place-where-group-powers-are-updated:
  Delete.
- patches.sched/sched-Fix-unregister_fair_sched_group: Delete.
- patches.sched/sched-Fix-update_cfs_load-synchronization: Delete.
- patches.sched/sched-Fix-update_curr_rt: Delete.
- patches.sched/sched-Implement-demand-based-update_cfs_load:
  Delete.
- patches.sched/sched-Implement-on-demand-cfs_rq-list: Delete.
- patches.sched/sched-Increase-SCHED_LOAD_SCALE-resolution:
  Delete.
- patches.sched/sched-Introduce-SCHED_POWER_SCALE-to-scale-cpu_power-calculation:
  Delete.
- patches.sched/sched-Introduce-hierarchal-order-on-shares-update-list:
  Delete.
- patches.sched/sched-Leave-sched_setscheduler-earlier-if-possible-to-not-disturb-SCHED_FIFO-task:
  Delete.
- patches.sched/sched-Limit-the-scope-of-clear_buddies: Delete.
- patches.sched/sched-Make-set_next-last_buddy-work-on-non-task-entities:
  Delete.
- patches.sched/sched-Make-sure-timers-have-migrated-before-killing-the-migration_thread:
  Delete.
- patches.sched/sched-Make-tg_shares_up-walk-on-demand: Delete.
- patches.sched/sched-Merge-cpu_to_core_group-functions: Delete.
- patches.sched/sched-Move-load-balance-code-into-sched_fair-c:
  Delete.
- patches.sched/sched-Move-periodic-share-updates-to-entity_tick:
  Delete.
- patches.sched/sched-Move-sched-domain-storage-into-the-topology-list:
  Delete.
- patches.sched/sched-Next-buddy-hint-on-sleep-and-preempt-path:
  Delete.
- patches.sched/sched-No-need-for-bootmem-special-cases: Delete.
- patches.sched/sched-Reduce-some-allocation-pressure: Delete.
- patches.sched/sched-Reduce-update_group_power-calls: Delete.
- patches.sched/sched-Remove-from-fwd-decls: Delete.
- patches.sched/sched-Remove-load_balance_newidle: Delete.
- patches.sched/sched-Remove-member-rt_se-from-struct-rt_rq:
  Delete.
- patches.sched/sched-Remove-nodemask-allocation: Delete.
- patches.sched/sched-Remove-noop-in-alloc_rt_sched_group: Delete.
- patches.sched/sched-Remove-obsolete-arch_-prefixes: Delete.
- patches.sched/sched-Remove-obsolete-comment-from-scheduler_tick:
  Delete.
- patches.sched/sched-Remove-rq_iterator-from-move_one_task:
  Delete.
- patches.sched/sched-Remove-rq_iterator-usage-from-load_balance_fair:
  Delete.
- patches.sched/sched-Remove-some-dead-code: Delete.
- patches.sched/sched-Remove-the-sched_class-load_balance-methods:
  Delete.
- patches.sched/sched-Remove-unused-parameters-from-sched_fork-and-wake_up_new_task:
  Delete.
- patches.sched/sched-Remove-unused-this_best_prio-arg-from-balance_tasks:
  Delete.
- patches.sched/sched-Remove-unused-update_shares_locked: Delete.
- patches.sched/sched-Reverse-the-topology-list: Delete.
- patches.sched/sched-Rewrite-tg_shares_up: Delete.
- patches.sched/sched-Shorten-the-construction-of-the-span-cpu-mask-of-sched-domain:
  Delete.
- patches.sched/sched-Simplify-NODE-ALLNODES-domain-creation:
  Delete.
- patches.sched/sched-Simplify-build_sched_groups: Delete.
- patches.sched/sched-Simplify-cpu-hot-unplug-task-migration:
  Delete.
- patches.sched/sched-Simplify-cpu_power-initialization: Delete.
- patches.sched/sched-Simplify-finding-the-lowest-sched_domain:
  Delete.
- patches.sched/sched-Simplify-sched_group-creation: Delete.
- patches.sched/sched-Simplify-sched_groups_power-initialization:
  Delete.
- patches.sched/sched-Simplify-the-free-path-some: Delete.
- patches.sched/sched-Simplify-the-idle-scheduling-class: Delete.
- patches.sched/sched-Simplify-update_cfs_shares-parameters:
  Delete.
- patches.sched/sched-Stuff-the-sched_domain-creation-in-a-data-structure:
  Delete.
- patches.sched/sched-Unify-load_balance-and-load_balance_newidle:
  Delete.
- patches.sched/sched-Unify-the-sched_domain-build-functions:
  Delete.
- patches.sched/sched-Update-effective_load-to-use-global-share-weights:
  Delete.
- patches.sched/sched-Update-rq-clock-for-nohz-balanced-cpus:
  Delete.
- patches.sched/sched-Update-shares-on-idle_balance: Delete.
- patches.sched/sched-Update-tg-shares-after-cpu-shares-write:
  Delete.
- patches.sched/sched-Use-for_each_bit: Delete.
- patches.sched/sched-Use-rq-clock_task-instead-of-rq-clock-for-correctly-maintaining-load-average:
  Delete.
- patches.sched/sched-Wholesale-removal-of-sd_idle-logic: Delete.
- patches.sched/sched-Wrap-the-cfs_rq-nr_spread_over-field-with-CONFIG_SCHED_DEBUG:
  Delete.
- patches.sched/sched-cgroup-Fix-cgroup_subsys-exit-callback:
  Delete.
- patches.sched/sched-cgroup-Use-exit-hook-to-avoid-use-after-free-crash:
  Delete.
- patches.sched/sched-cgroups-if-you-list_empty-a-head-then-dont-list_del-it:
  Delete.
- patches.sched/sched-correctly-place-paranioa-memory-barriers-in-synchronize_sched_expedited:
  Delete.
- patches.sched/sched-kill-paranoia-check-in-synchronize_sched_expedited:
  Delete.
- patches.sched/sched-might_sleep-Make-file-parameter-const-char-pointer:
  Delete.
- patches.sched/sched-no_hz-Remove-unused-rq-last_tick_seen-field:
  Delete.
- patches.sched/sched-replace-migration_thread-with-cpu_stop:
  Delete.
- patches.sched/sched-workqueue-kill-RT-workqueue: Delete.
- patches.sched/series: Delete.
- patches.sched/stop_machine-Move-local-variable-closer-to-the-usage-site-in-cpu_stop_cpu_callback:
  Delete.
- patches.sched/stop_machine-fix-unused-variable-warning: Delete.
- patches.sched/stop_machine-reimplement-using-cpu_stop: Delete.
- patches.sched/stop_machine-struct-cpu_stopper-remove-alignment-padding-on-64-bits:
  Delete.
- patches.sched/topology-s390-Add-z11-cpu-topology-support:
  Delete.
- patches.sched/topology-s390-expose-core-identifier: Delete.
- patches.sched/topology-sysfs-Provide-book-id-and-siblings-attributes:
  Delete.
* Sat May 28 2011 tiwai@suse.de
- Fix a typo in patches.drivers/alsa-sp1-hda-116-Reorganize-controller-quriks-with-bit-flags
* Fri May 27 2011 tonyj@suse.de
- Added patches.suse/oprofile-{001-050}*.patch (FATE#309728, BNC#686840)
- Dropped patches.fixes/oprofile_bios_ctr.patch (obsoleted)
- patches.xen/xen3-auto-common.diff: Refresh.
- patches.xen/xen3-patch-2.6.24: Refresh.
- patches.xen/xen3-patch-2.6.28: Refresh.
* Fri May 27 2011 hare@suse.de
- Disable dm-raid45; will be enabled with a later snapshot.
- Backport TRIM/DISCARD changes from 2.6.33 (FATE#311054):
- patches.suse/-libata-MWDMA0-is-unsupported-on-PIIX-like-PATA-con.patch:
  [libata] MWDMA0 is unsupported on PIIX-like PATA controllers
  (FATE#311054).
- patches.suse/-libata-PATA-Update-experimental-tags.patch:
  [libata] PATA: Update experimental tags (FATE#311054).
- patches.suse/3w-9xxx-fix-bug-in-sgl-loading.patch: [SCSI]
  3w-9xxx fix bug in sgl loading (FATE#311054).
- patches.suse/ACPI-do-not-select-ACPI_DOCK-from-ATA_ACPI.patch:
  ACPI: do not select ACPI_DOCK from ATA_ACPI (FATE#311054).
- patches.suse/Correctly-handle-thin-provisioning-write-erro.patch:
  [SCSI] Correctly handle thin provisioning write error
  (FATE#311054).
- patches.suse/Do-not-__always_inline-bvec_kmap_irq-and-bvec_kunm.patch:
  Do not __always_inline bvec_kmap_irq() and bvec_kunmap_irq()
  (FATE#311054).
- patches.suse/Fix-a-CFQ-crash-in-for-2.6.33-branch-of-block-tree.patch:
  Fix a CFQ crash in "for-2.6.33" branch of block tree
  (FATE#311054).
- patches.suse/Fix-regression-in-direct-writes-performance-due-to-W.patch:
  Fix regression in direct writes performance due to WRITE_ODIRECT
  flag removal (FATE#311054).
- patches.suse/Revert-block-improve-queue_should_plug-by-lookin.patch:
  Revert "block: improve queue_should_plug() by looking at IO
  depths" (FATE#311054).
- patches.suse/Revert-cfq-Make-use-of-service-count-to-estimate-t.patch:
  Revert "cfq: Make use of service count to estimate the rb_key
  offset" (FATE#311054).
- patches.suse/Revert-pata_cmd64x-implement-serialization-as-per.patch:
  Revert "pata_cmd64x: implement serialization as per notes"
  (FATE#311054).
- patches.suse/Revert-pata_sis-Implement-MWDMA-for-the-UDMA-133-c.patch:
  Revert "pata_sis: Implement MWDMA for the UDMA 133 capable
  chips" (FATE#311054).
- patches.suse/ahci-add-Acer-G725-to-broken-suspend-list.patch:
  ahci: add Acer G725 to broken suspend list (FATE#311054).
- patches.suse/ahci-let-users-know-that-Promise-PDC42819-support-i.patch:
  ahci: let users know that Promise PDC42819 support is limited
  to SATA devices (FATE#311054).
- patches.suse/aio-implement-request-batching.patch: aio:
  implement request batching (FATE#311054).
- patches.suse/aoe-switch-to-the-new-bio_flush_dcache_pages-inte.patch:
  aoe: switch to the new bio_flush_dcache_pages() interface
  (FATE#311054).
- patches.suse/ata-Don-t-require-newlines-for-link_power_managemen.patch:
  ata: Don't require newlines for link_power_management_policy
  (FATE#311054).
- patches.suse/ata-use-pci_dev-revision.patch: ata: use
  pci_dev->revision (FATE#311054).
- patches.suse/ata_piix-enable-32bit-PIO-on-SATA-piix.patch:
  ata_piix: enable 32bit PIO on SATA piix (FATE#311054).
- patches.suse/ataflop-remove-buggy-commented-out-IRQ-disable-from.patch:
  ataflop: remove buggy/commented-out IRQ disable from
  do_fd_request() (FATE#311054).
- patches.suse/blk-cgroup-Fix-potential-deadlock-in-blk-cgroup.patch:
  blk-cgroup: Fix potential deadlock in blk-cgroup (FATE#311054).
- patches.suse/blkio-Allow-CFQ-group-IO-scheduling-even-when-CFQ-i.patch:
  blkio: Allow CFQ group IO scheduling even when CFQ is a module
  (FATE#311054).
- patches.suse/blkio-Determine-async-workload-length-based-on-tota.patch:
  blkio: Determine async workload length based on total number
  of queues (FATE#311054).
- patches.suse/blkio-Documentation.patch: blkio: Documentation
  (FATE#311054).
- patches.suse/blkio-Drop-the-reference-to-queue-once-the-task-cha.patch:
  blkio: Drop the reference to queue once the task changes cgroup
  (FATE#311054).
- patches.suse/blkio-Dynamic-cfq-group-creation-based-on-cgroup-ta.patch:
  blkio: Dynamic cfq group creation based on cgroup tasks belongs
  to (FATE#311054).
- patches.suse/blkio-Export-disk-time-and-sectors-used-by-a-group.patch:
  blkio: Export disk time and sectors used by a group to user
  space (FATE#311054).
- patches.suse/blkio-Export-some-symbols-from-blkio-as-its-user-CF.patch:
  blkio: Export some symbols from blkio as its user CFQ can be
  a module (FATE#311054).
- patches.suse/blkio-Group-time-used-accounting-and-workload-conte.patch:
  blkio: Group time used accounting and workload context save
  restore (FATE#311054).
- patches.suse/blkio-Implement-dynamic-io-controlling-policy-regis.patch:
  blkio: Implement dynamic io controlling policy registration
  (FATE#311054).
- patches.suse/blkio-Implement-group_isolation-tunable.patch:
  blkio: Implement group_isolation tunable (FATE#311054).
- patches.suse/blkio-Implement-macro-to-traverse-each-service-tree.patch:
  blkio: Implement macro to traverse each service tree in group
  (FATE#311054).
- patches.suse/blkio-Implement-per-cfq-group-latency-target-and-bu.patch:
  blkio: Implement per cfq group latency target and busy queue
  avg (FATE#311054).
- patches.suse/blkio-Introduce-blkio-controller-cgroup-interface.patch:
  blkio: Introduce blkio controller cgroup interface
  (FATE#311054).
- patches.suse/blkio-Introduce-per-cfq-group-weights-and-vdisktime.patch:
  blkio: Introduce per cfq group weights and vdisktime
  calculations (FATE#311054).
- patches.suse/blkio-Introduce-the-notion-of-cfq-groups.patch:
  blkio: Introduce the notion of cfq groups (FATE#311054).
- patches.suse/blkio-Introduce-the-root-service-tree-for-cfq-group.patch:
  blkio: Introduce the root service tree for cfq groups
  (FATE#311054).
- patches.suse/blkio-Keep-queue-on-service-tree-until-we-expire-it.patch:
  blkio: Keep queue on service tree until we expire it
  (FATE#311054).
- patches.suse/blkio-Propagate-cgroup-weight-updation-to-cfq-group.patch:
  blkio: Propagate cgroup weight updation to cfq groups
  (FATE#311054).
- patches.suse/blkio-Provide-some-isolation-between-groups.patch:
  blkio: Provide some isolation between groups (FATE#311054).
- patches.suse/blkio-Set-must_dispatch-only-if-we-decided-to-not-d.patch:
  blkio: Set must_dispatch only if we decided to not dispatch
  the request (FATE#311054).
- patches.suse/blkio-Some-debugging-aids-for-CFQ.patch: blkio:
  Some debugging aids for CFQ (FATE#311054).
- patches.suse/blkio-Take-care-of-cgroup-deletion-and-cfq-group-re.patch:
  blkio: Take care of cgroup deletion and cfq group reference
  counting (FATE#311054).
- patches.suse/blkio-Wait-for-cfq-queue-to-get-backlogged-if-group.patch:
  blkio: Wait for cfq queue to get backlogged if group is empty
  (FATE#311054).
- patches.suse/blkio-Wait-on-sync-noidle-queue-even-if-rq_noidle.patch:
  blkio: Wait on sync-noidle queue even if rq_noidle = 1
  (FATE#311054).
- patches.suse/block-Added-in-stricter-no-merge-semantics-for-bloc.patch:
  block: Added in stricter no merge semantics for block I/O
  (FATE#311054).
- patches.suse/block-Allow-devices-to-indicate-whether-discarded-b.patch:
  block: Allow devices to indicate whether discarded blocks are
  zeroed (FATE#311054).
- patches.suse/block-CFQ-is-more-than-a-desktop-scheduler.patch:
  block: CFQ is more than a desktop scheduler (FATE#311054).
- patches.suse/block-Correct-handling-of-bottom-device-misaligment.patch:
  block: Correct handling of bottom device misaligment
  (FATE#311054).
- patches.suse/block-Expose-discard-granularity.patch: block:
  Expose discard granularity (FATE#311054).
- patches.suse/block-Fix-discard-alignment-calculation-and-printin.patch:
  block: Fix discard alignment calculation and printing
  (FATE#311054).
- patches.suse/block-Fix-incorrect-alignment-offset-reporting-and.patch:
  block: Fix incorrect alignment offset reporting and update
  documentation (FATE#311054).
- patches.suse/block-Fix-io_context-leak-after-clone-with-CLONE_IO.patch:
  block: Fix io_context leak after clone with CLONE_IO
  (FATE#311054).
- patches.suse/block-Fix-io_context-leak-after-failure-of-clone-wi.patch:
  block: Fix io_context leak after failure of clone with CLONE_IO
  (FATE#311054).
- patches.suse/block-Fix-topology-stacking-for-data-and-discard-al.patch:
  block: Fix topology stacking for data and discard alignment
  (FATE#311054).
- patches.suse/block-Honor-the-gfp_mask-for-alloc_page-in-blkdev.patch:
  block: Honor the gfp_mask for alloc_page() in
  blkdev_issue_discard() (FATE#311054).
- patches.suse/block-Stop-using-byte-offsets.patch: block:
  Stop using byte offsets (FATE#311054).
- patches.suse/block-add-helpers-to-run-flush_dcache_page-agains.patch:
  block: add helpers to run flush_dcache_page() against a bio
  and a request's pages (FATE#311054).
- patches.suse/block-get-rid-of-the-WRITE_ODIRECT-flag.patch:
  block: get rid of the WRITE_ODIRECT flag (FATE#311054).
- patches.suse/block-include-linux-err.h-to-use-ERR_PTR.patch:
  block: include linux/err.h to use ERR_PTR (FATE#311054).
- patches.suse/block-jiffies-fixes.patch: block: jiffies fixes
  (FATE#311054).
- patches.suse/block-ps3-fix-slow-VRAM-IO.patch: block/ps3:
  fix slow VRAM IO (FATE#311054).
- patches.suse/block-remove-Documentation-block-as-iosched.txt.patch:
  block: remove Documentation/block/as-iosched.txt (FATE#311054).
- patches.suse/block-remove-the-anticipatory-IO-scheduler.patch:
  block: remove the anticipatory IO scheduler (FATE#311054).
- patches.suse/block-removed-unused-as_io_context.patch: block:
  removed unused as_io_context (FATE#311054).
- patches.suse/block-scsi_ioctl.c-quiet-sparse-noise.patch:
  block/scsi_ioctl.c: quiet sparse noise (FATE#311054).
- patches.suse/block-temporarily-disable-discard-granularity.patch:
  block: temporarily disable discard granularity (FATE#311054).
- patches.suse/block-xd-Delay-allocation-of-DMA-buffers-until-devi.patch:
  block,xd: Delay allocation of DMA buffers until device is known
  (FATE#311054).
- patches.suse/cfq-Make-use-of-service-count-to-estimate-the-rb_ke.patch:
  cfq: Make use of service count to estimate the rb_key offset
  (FATE#311054).
- patches.suse/cfq-Optimization-for-close-cooperating-queue-search.patch:
  cfq: Optimization for close cooperating queue searching
  (FATE#311054).
- patches.suse/cfq-Remove-wait_request-flag-when-idle-time-is-bein.patch:
  cfq: Remove wait_request flag when idle time is being deleted
  (FATE#311054).
- patches.suse/cfq-break-apart-merged-cfqqs-if-they-stop-cooperati.patch:
  cfq: break apart merged cfqqs if they stop cooperating
  (FATE#311054).
- patches.suse/cfq-calculate-the-seek_mean-per-cfq_queue-not-per-c.patch:
  cfq: calculate the seek_mean per cfq_queue not per
  cfq_io_context (FATE#311054).
- patches.suse/cfq-change-the-meaning-of-the-cfqq_coop-flag.patch:
  cfq: change the meaning of the cfqq_coop flag (FATE#311054).
- patches.suse/cfq-iosched-Do-not-access-cfqq-after-freeing-it.patch:
  cfq-iosched: Do not access cfqq after freeing it (FATE#311054).
- patches.suse/cfq-iosched-Do-not-idle-on-async-queues.patch:
  cfq-iosched: Do not idle on async queues (FATE#311054).
- patches.suse/cfq-iosched-Get-rid-of-cfqq-wait_busy_done-flag.patch:
  cfq-iosched: Get rid of cfqq wait_busy_done flag (FATE#311054).
- patches.suse/cfq-iosched-Get-rid-of-nr_groups.patch:
  cfq-iosched: Get rid of nr_groups (FATE#311054).
- patches.suse/cfq-iosched-Remove-prio_change-logic-for-workload-s.patch:
  cfq-iosched: Remove prio_change logic for workload selection
  (FATE#311054).
- patches.suse/cfq-iosched-Remove-the-check-for-same-cfq-group-fro.patch:
  cfq-iosched: Remove the check for same cfq group from
  allow_merge (FATE#311054).
- patches.suse/cfq-iosched-Respect-ioprio_class-when-preempting.patch:
  cfq-iosched: Respect ioprio_class when preempting (FATE#311054).
- patches.suse/cfq-iosched-Take-care-of-corner-cases-of-group-losi.patch:
  cfq-iosched: Take care of corner cases of group losing share
  due to deletion (FATE#311054).
- patches.suse/cfq-iosched-adapt-slice-to-number-of-processes-doin.patch:
  cfq-iosched: adapt slice to number of processes doing I/O
  (FATE#311054).
- patches.suse/cfq-iosched-cleanup-unreachable-code.patch:
  cfq-iosched: cleanup unreachable code (FATE#311054).
- patches.suse/cfq-iosched-commenting-non-obvious-initialization.patch:
  cfq-iosched: commenting non-obvious initialization
  (FATE#311054).
- patches.suse/cfq-iosched-don-t-regard-requests-with-long-distanc.patch:
  cfq-iosched: don't regard requests with long distance as close
  (FATE#311054).
- patches.suse/cfq-iosched-enable-idling-for-last-queue-on-priorit.patch:
  cfq-iosched: enable idling for last queue on priority class
  (FATE#311054).
- patches.suse/cfq-iosched-fairness-for-sync-no-idle-queues.patch:
  cfq-iosched: fairness for sync no-idle queues (FATE#311054).
- patches.suse/cfq-iosched-fix-compile-problem-with-CONFIG_CGROUP.patch:
  cfq-iosched: fix compile problem with !CONFIG_CGROUP
  (FATE#311054).
- patches.suse/cfq-iosched-fix-corner-cases-in-idling-logic.patch:
  cfq-iosched: fix corner cases in idling logic (FATE#311054).
- patches.suse/cfq-iosched-fix-ncq-detection-code.patch:
  cfq-iosched: fix ncq detection code (FATE#311054).
- patches.suse/cfq-iosched-fix-next_rq-computation.patch:
  cfq-iosched: fix next_rq computation (FATE#311054).
- patches.suse/cfq-iosched-fix-no-idle-preemption-logic.patch:
  cfq-iosched: fix no-idle preemption logic (FATE#311054).
- patches.suse/cfq-iosched-fix-style-issue-in-cfq_get_avg_queues.patch:
  cfq-iosched: fix style issue in cfq_get_avg_queues()
  (FATE#311054).
- patches.suse/cfq-iosched-idling-on-deep-seeky-sync-queues.patch:
  cfq-iosched: idling on deep seeky sync queues (FATE#311054).
- patches.suse/cfq-iosched-improve-hw_tag-detection.patch:
  cfq-iosched: improve hw_tag detection (FATE#311054).
- patches.suse/cfq-iosched-make-nonrot-check-logic-consistent.patch:
  cfq-iosched: make nonrot check logic consistent (FATE#311054).
- patches.suse/cfq-iosched-move-IO-controller-declerations-to-a-he.patch:
  cfq-iosched: move IO controller declerations to a header file
  (FATE#311054).
- patches.suse/cfq-iosched-no-dispatch-limit-for-single-queue.patch:
  cfq-iosched: no dispatch limit for single queue (FATE#311054).
- patches.suse/cfq-iosched-preparation-to-handle-multiple-service.patch:
  cfq-iosched: preparation to handle multiple service trees
  (FATE#311054).
- patches.suse/cfq-iosched-reduce-write-depth-only-if-sync-was-del.patch:
  cfq-iosched: reduce write depth only if sync was delayed
  (FATE#311054).
- patches.suse/cfq-iosched-reimplement-priorities-using-different.patch:
  cfq-iosched: reimplement priorities using different service
  trees (FATE#311054).
- patches.suse/cfq-iosched-simplify-prio-unboost-code.patch:
  cfq-iosched: simplify prio-unboost code (FATE#311054).
- patches.suse/cfq-iosched-split-seeky-coop-queues-after-one-slice.patch:
  cfq-iosched: split seeky coop queues after one slice
  (FATE#311054).
- patches.suse/cfq-iosched-use-call_rcu-instead-of-doing-grace-p.patch:
  cfq-iosched: use call_rcu() instead of doing grace period
  stall on queue exit (FATE#311054).
- patches.suse/cfq-merge-cooperating-cfq_queues.patch: cfq:
  merge cooperating cfq_queues (FATE#311054).
- patches.suse/cfq-reorder-cfq_queue-removing-padding-on-64bit.patch:
  cfq: reorder cfq_queue removing padding on 64bit (FATE#311054).
- patches.suse/cfq-set-workload-as-expired-if-it-doesn-t-have-any.patch:
  cfq: set workload as expired if it doesn't have any slice left
  (FATE#311054).
- patches.suse/cxgb3i-Fix-a-login-over-vlan-issue.patch: [SCSI]
  cxgb3i: Fix a login over vlan issue (FATE#311054).
- patches.suse/cxgb3i-always-use-negative-errno-in-case-of.patch:
  [SCSI] cxgb3i: always use negative errno in case of error
  (FATE#311054).
- patches.suse/dm-abstract-clone_rq.patch: dm: abstract clone_rq
  (FATE#311054).
- patches.suse/dm-add-dm_deleting_md-function.patch: dm: add
  dm_deleting_md function (FATE#311054).
- patches.suse/dm-add-request-based-barrier-support.patch: dm:
  add request based barrier support (FATE#311054).
- patches.suse/dm-bind-new-table-before-destroying-old.patch:
  dm: bind new table before destroying old (FATE#311054).
- patches.suse/dm-crypt-add-plain64-iv.patch: dm crypt: add
  plain64 iv (FATE#311054).
- patches.suse/dm-crypt-make-wipe-message-also-wipe-tfm-key.patch:
  dm crypt: make wipe message also wipe tfm key (FATE#311054).
- patches.suse/dm-exception-store-add-merge-specific-methods.patch:
  dm exception store: add merge specific methods (FATE#311054).
- patches.suse/dm-export-suspended-state-to-targets.patch: dm:
  export suspended state to targets (FATE#311054).
- patches.suse/dm-io-handle-empty-barriers.patch: dm io: handle
  empty barriers (FATE#311054).
- patches.suse/dm-io-remove-extra-bi_io_vec-region-hack.patch:
  dm io: remove extra bi_io_vec region hack (FATE#311054).
- patches.suse/dm-io-use-slab-for-struct-io.patch: dm io: use
  slab for struct io (FATE#311054).
- patches.suse/dm-ioctl-forbid-messages-to-devices-being-deleted.patch:
  dm ioctl: forbid messages to devices being deleted
  (FATE#311054).
- patches.suse/dm-ioctl-prefer-strlcpy-over-strncpy.patch:
  dm ioctl: prefer strlcpy over strncpy (FATE#311054).
- patches.suse/dm-ioctl-retrieve-status-from-inactive-table.patch:
  dm ioctl: retrieve status from inactive table (FATE#311054).
- patches.suse/dm-kcopyd-accept-zero-size-jobs.patch: dm kcopyd:
  accept zero size jobs (FATE#311054).
- patches.suse/dm-keep-old-table-until-after-resume-succeeded.patch:
  dm: keep old table until after resume succeeded (FATE#311054).
- patches.suse/dm-log-add-flush-callback-fn.patch: dm log:
  add flush callback fn (FATE#311054).
- patches.suse/dm-log-add-flush_header-function.patch: dm log:
  add flush_header function (FATE#311054).
- patches.suse/dm-log-introduce-flush_failed-variable.patch:
  dm log: introduce flush_failed variable (FATE#311054).
- patches.suse/dm-log-use-flush-callback-fn.patch: dm log:
  use flush callback fn (FATE#311054).
- patches.suse/dm-move-dm_end_request.patch: dm: move
  dm_end_request (FATE#311054).
- patches.suse/dm-mpath-add-mutex-to-synchronize-adding-and-flushi.patch:
  dm mpath: add mutex to synchronize adding and flushing work
  (FATE#311054).
- patches.suse/dm-mpath-fix-stall-when-requeueing-io.patch:
  dm mpath: fix stall when requeueing io (FATE#311054).
- patches.suse/dm-mpath-flush-workqueues-before-suspend-completes.patch:
  dm mpath: flush workqueues before suspend completes
  (FATE#311054).
- patches.suse/dm-mpath-prevent-io-from-work-queue-while-suspended.patch:
  dm mpath: prevent io from work queue while suspended
  (FATE#311054).
- patches.suse/dm-mpath-reject-messages-when-device-is-suspended.patch:
  dm mpath: reject messages when device is suspended
  (FATE#311054).
- patches.suse/dm-pass-gfp_mask-to-alloc_rq_tio.patch: dm:
  pass gfp_mask to alloc_rq_tio (FATE#311054).
- patches.suse/dm-raid1-abstract-get_valid_mirror-function.patch:
  dm raid1: abstract get_valid_mirror function (FATE#311054).
- patches.suse/dm-raid1-add-framework-to-hold-bios-during-suspend.patch:
  dm raid1: add framework to hold bios during suspend
  (FATE#311054).
- patches.suse/dm-raid1-explicitly-initialise-bio_lists.patch:
  dm raid1: explicitly initialise bio_lists (FATE#311054).
- patches.suse/dm-raid1-hold-all-write-bios-when-leg-fails.patch:
  dm raid1: hold all write bios when leg fails (FATE#311054).
- patches.suse/dm-raid1-hold-write-bios-when-errors-are-handled.patch:
  dm raid1: hold write bios when errors are handled (FATE#311054).
- patches.suse/dm-raid1-implement-mirror_flush.patch: dm raid1:
  implement mirror_flush (FATE#311054).
- patches.suse/dm-raid1-remove-bio_endio-from-dm_rh_mark_nosync.patch:
  dm raid1: remove bio_endio from dm_rh_mark_nosync (FATE#311054).
- patches.suse/dm-raid1-report-flush-errors-separately-in-status.patch:
  dm raid1: report flush errors separately in status
  (FATE#311054).
- patches.suse/dm-raid1-split-touched-state-into-two.patch:
  dm raid1: split touched state into two (FATE#311054).
- patches.suse/dm-raid1-support-flush.patch: dm raid1: support
  flush (FATE#311054 FATE#311054).
- patches.suse/dm-raid1-use-hold-framework-in-do_failures.patch:
  dm raid1: use hold framework in do_failures (FATE#311054).
- patches.suse/dm-refactor-request-based-completion-functions.patch:
  dm: refactor request based completion functions (FATE#311054).
- patches.suse/dm-rename-dm_get_table-to-dm_get_live_table.patch:
  dm: rename dm_get_table to dm_get_live_table (FATE#311054).
- patches.suse/dm-rename-dm_suspended-to-dm_suspended_md.patch:
  dm: rename dm_suspended to dm_suspended_md (FATE#311054).
- patches.suse/dm-simplify-request-based-suspend.patch: dm:
  simplify request based suspend (FATE#311054).
- patches.suse/dm-snapshot-abstract-minimum_chunk_size-fn.patch:
  dm snapshot: abstract minimum_chunk_size fn (FATE#311054).
- patches.suse/dm-snapshot-add-allocated-metadata-to-snapshot-stat.patch:
  dm snapshot: add allocated metadata to snapshot status
  (FATE#311054).
- patches.suse/dm-snapshot-add-merge-target.patch: dm snapshot:
  add merge target (FATE#311054).
- patches.suse/dm-snapshot-add-merging.patch: dm snapshot:
  add merging (FATE#311054).
- patches.suse/dm-snapshot-allow-live-exception-store-handover-bet.patch:
  dm snapshot: allow live exception store handover between tables
  (FATE#311054).
- patches.suse/dm-snapshot-avoid-allocating-exceptions-in-merge.patch:
  dm snapshot: avoid allocating exceptions in merge (FATE#311054).
- patches.suse/dm-snapshot-avoid-else-clause-in-persistent_read_me.patch:
  dm snapshot: avoid else clause in persistent_read_metadata
  (FATE#311054).
- patches.suse/dm-snapshot-consolidate-insert-exception-functions.patch:
  dm snapshot: consolidate insert exception functions
  (FATE#311054).
- patches.suse/dm-snapshot-create-function-for-chunk_is_tracked-wa.patch:
  dm snapshot: create function for chunk_is_tracked wait
  (FATE#311054).
- patches.suse/dm-snapshot-delay-merging-a-chunk-until-writes-to-i.patch:
  dm snapshot: delay merging a chunk until writes to it complete
  (FATE#311054).
- patches.suse/dm-snapshot-make-bio-optional-in-__origin_write.patch:
  dm snapshot: make bio optional in __origin_write (FATE#311054).
- patches.suse/dm-snapshot-merge-consecutive-chunks-together.patch:
  dm snapshot: merge consecutive chunks together (FATE#311054).
- patches.suse/dm-snapshot-move-cow-ref-from-exception-store-to-sn.patch:
  dm snapshot: move cow ref from exception store to snap core
  (FATE#311054).
- patches.suse/dm-snapshot-permit-only-one-merge-at-once.patch:
  dm snapshot: permit only one merge at once (FATE#311054).
- patches.suse/dm-snapshot-persistent-annotate-work_queue-as-on-st.patch:
  dm snapshot: persistent annotate work_queue as on stack
  (FATE#311054).
- patches.suse/dm-snapshot-queue-writes-to-chunks-being-merged.patch:
  dm snapshot: queue writes to chunks being merged (FATE#311054).
- patches.suse/dm-snapshot-rename-dm_snap_exception-to-dm_exceptio.patch:
  dm snapshot: rename dm_snap_exception to dm_exception
  (FATE#311054).
- patches.suse/dm-snapshot-rename-exception-functions.patch:
  dm snapshot: rename exception functions (FATE#311054).
- patches.suse/dm-snapshot-rename-exception_table-to-dm_exception_.patch:
  dm snapshot: rename exception_table to dm_exception_table
  (FATE#311054).
- patches.suse/dm-snapshot-report-merge-failure-in-status.patch:
  dm snapshot: report merge failure in status (FATE#311054).
- patches.suse/dm-snapshot-rework-writing-to-origin.patch:
  dm snapshot: rework writing to origin (FATE#311054).
- patches.suse/dm-snapshot-support-barriers-in-snapshot-merge-targ.patch:
  dm snapshot: support barriers in snapshot merge target
  (FATE#311054).
- patches.suse/dm-snapshot-track-suspended-state-in-target.patch:
  dm snapshot: track suspended state in target (FATE#311054).
- patches.suse/dm-snapshot-trigger-exceptions-in-remaining-snapsho.patch:
  dm snapshot: trigger exceptions in remaining snapshots during
  merge (FATE#311054).
- patches.suse/dm-snapshot-use-merge-origin-if-snapshot-invalid.patch:
  dm snapshot: use merge origin if snapshot invalid (FATE#311054).
- patches.suse/dm-swap-target-postsuspend-call-and-setting-suspend.patch:
  dm: swap target postsuspend call and setting suspended flag
  (FATE#311054).
- patches.suse/dm-sysfs-add-empty-release-function-to-avoid-debug.patch:
  dm: sysfs add empty release function to avoid debug warning
  (FATE#311054).
- patches.suse/dm-sysfs-revert-add-empty-release-function-to-avoid.patch:
  dm: sysfs revert add empty release function to avoid debug
  warning (FATE#311054).
- patches.suse/dm-trace-request-based-remapping.patch: dm:
  trace request based remapping (FATE#311054).
- patches.suse/dm-use-md-pending-for-in-flight-IO-counting.patch:
  dm: use md pending for in flight IO counting (FATE#311054).
- patches.suse/drivers-block-DAC960.c-use-DAC960_V2_Controller.patch:
  drivers/block/DAC960.c: use DAC960_V2_Controller (FATE#311054).
- patches.suse/drivers-block-mg_disk.c-use-resource_size.patch:
  drivers/block/mg_disk.c: use resource_size() (FATE#311054).
- patches.suse/drivers-scsi-sym53c8xx_2-sym_glue.c-rename-skip_spa.patch:
  drivers/scsi/sym53c8xx_2/sym_glue.c: rename skip_spaces()
  to sym_skip_spaces() (FATE#311054).
- patches.suse/fix-func-names-in-kernel-doc.patch: [SCSI] fix
  func names in kernel-doc (FATE#311054).
- patches.suse/fix-propogation-of-integrity-errors.patch: [SCSI]
  fix propogation of integrity errors (FATE#311054).
- patches.suse/floppy-Add-an-extra-bound-check-on-ioctl-arguments.patch:
  floppy: Add an extra bound check on ioctl arguments
  (FATE#311054).
- patches.suse/fs-bio.c-fix-shadows-sparse-warning.patch:
  fs/bio.c: fix shadows sparse warning (FATE#311054).
- patches.suse/ibmvfc-Add-FC-Passthru-support.patch: [SCSI]
  ibmvfc: Add FC Passthru support (FATE#311054).
- patches.suse/ibmvfc-Driver-version-1.0.7.patch: [SCSI] ibmvfc:
  Driver version 1.0.7 (FATE#311054).
- patches.suse/ibmvfc-Fix-adapter-cancel-flags-for-terminat.patch:
  [SCSI] ibmvfc: Fix adapter cancel flags for terminate_rport_io
  (FATE#311054).
- patches.suse/ibmvfc-Fix-locking-in-ibmvfc_remove.patch: [SCSI]
  ibmvfc: Fix locking in ibmvfc_remove (FATE#311054).
- patches.suse/ibmvfc-Fixup-TMF-response-handling.patch: [SCSI]
  ibmvfc: Fixup TMF response handling (FATE#311054).
- patches.suse/ibmvfc-Remove-unnecessary-parameter-to-ibmvf.patch:
  [SCSI] ibmvfc: Remove unnecessary parameter to ibmvfc_init_host
  (FATE#311054).
- patches.suse/io-controller-quick-fix-for-blk-cgroup-and-modular.patch:
  io controller: quick fix for blk-cgroup and modular CFQ
  (FATE#311054).
- patches.suse/iscsi_tcp-regression-remove-bogus-warn-on-in.patch:
  [SCSI] iscsi_tcp regression: remove bogus warn on in write path
  (FATE#311054).
- patches.suse/libata-Clarify-ata_set_lba_range_entries-function.patch:
  libata: Clarify ata_set_lba_range_entries function
  (FATE#311054).
- patches.suse/libata-Report-zeroed-read-after-TRIM-and-max-discar.patch:
  libata: Report zeroed read after TRIM and max discard size
  (FATE#311054).
- patches.suse/libata-add-comment-documenting-PIO-latency-issues-o.patch:
  libata: add comment documenting PIO latency issues on UP
  (FATE#311054).
- patches.suse/libata-add-private-driver-field-to-struct-ata_devic.patch:
  libata: add private driver field to struct ata_device
  (FATE#311054).
- patches.suse/libata-add-translation-for-SCSI-WRITE-SAME-aka-TRI.patch:
  libata: add translation for SCSI WRITE SAME (aka TRIM support)
  (FATE#311054).
- patches.suse/libata-fix-ata_id_logical_per_physical_sectors.patch:
  libata: fix ata_id_logical_per_physical_sectors (FATE#311054).
- patches.suse/libata-fix-reporting-of-drained-bytes-when-clearing.patch:
  libata: fix reporting of drained bytes when clearing DRQ
  (FATE#311054).
- patches.suse/libata-remove-experimental-tag-on-PATA-drivers.patch:
  libata: remove experimental tag on PATA drivers (FATE#311054).
- patches.suse/libata-retry-failed-FLUSH-if-device-didn-t-fail-it.patch:
  libata: retry failed FLUSH if device didn't fail it
  (FATE#311054).
- patches.suse/libata-sff-Use-ops-bmdma_stop-instead-of-ata_bmdma.patch:
  libata/sff: Use ops->bmdma_stop instead of ata_bmdma_stop()
  (FATE#311054).
- patches.suse/libata-use-the-WRITE_SAME_16-define.patch: libata:
  use the WRITE_SAME_16 define (FATE#311054).
- patches.suse/libiscsi-hook-into-ramp-up-down-handling.patch:
  [SCSI] libiscsi: hook into ramp up/down handling (FATE#311054).
- patches.suse/libosd-Bugfix-of-error-handling-in-attribute.patch:
  [SCSI] libosd: Bugfix of error handling in attributes-list
  decoding (FATE#311054).
- patches.suse/libosd-Error-handling-revamped.patch: [SCSI]
  libosd: Error handling revamped (FATE#311054).
- patches.suse/libosd-Fix-blk_put_request-locking-again.patch:
  [SCSI] libosd: Fix blk_put_request locking again (FATE#311054).
- patches.suse/libosd-bug-in-osd_req_decode_sense_full.patch:
  [SCSI] libosd: bug in osd_req_decode_sense_full() (FATE#311054).
- patches.suse/libosd-osd_dev_info-Unique-Identification-o.patch:
  [SCSI] libosd: osd_dev_info: Unique Identification of an OSD
  device (FATE#311054).
- patches.suse/libosd-osd_dev_is_ver1-Minor-API-cleanup.patch:
  [SCSI] libosd: osd_dev_is_ver1 - Minor API cleanup
  (FATE#311054).
- patches.suse/libosd-osd_sense-OSD_CFO_PERMISSIONS.patch:
  [SCSI] libosd: osd_sense: OSD_CFO_PERMISSIONS (FATE#311054).
- patches.suse/md-make-recovery-started-by-do_md_run-visible-via.patch:
  md: make recovery started by do_md_run() visible via sync_action
  (FATE#311054).
- patches.suse/md-raid5-remove-some-sparse-warnings.patch:
  md/raid5: remove some sparse warnings (FATE#311054).
- patches.suse/md-remove-sparse-warning-symbol-XXX-was-not-declare.patch:
  md: remove sparse warning:symbol XXX was not declared
  (FATE#311054).
- patches.suse/md-remove-unnecessary-code-from-do_md_run.patch:
  md: remove unnecessary code from do_md_run (FATE#311054).
- patches.suse/no-partition-scan: Refresh.
- patches.suse/osduld-Ref-counting-bug-fix.patch: [SCSI] osduld:
  Ref-counting bug fix (FATE#311054).
- patches.suse/osduld-Use-device-release-instead-of-intern.patch:
  [SCSI] osduld: Use device->release instead of internal kref
  (FATE#311054).
- patches.suse/pata-it821x-use-PCI_DEVICE_ID_RDC_D1010-define.patch:
  pata-it821x: use PCI_DEVICE_ID_RDC_D1010 define (FATE#311054).
- patches.suse/pata_bf54x-handle-portmuxing-of-pins-through-GPIO-P.patch:
  pata_bf54x: handle portmuxing of pins through GPIO PORTs
  (FATE#311054).
- patches.suse/pata_cmd64x-implement-serialization-as-per-notes.patch:
  pata_cmd64x: implement serialization as per notes (FATE#311054).
- patches.suse/pata_cs5520-remove-dead-VDMA-support.patch:
  pata_cs5520: remove dead VDMA support (FATE#311054).
- patches.suse/pata_cs5536-use-32-bit-BM-DMA-template-instead-of-1.patch:
  pata_cs5536: use 32-bit BM DMA template instead of 16-bit
  (FATE#311054).
- patches.suse/pata_efar-fix-wrong-MWDMA-timings-being-programmed.patch:
  pata_efar: fix wrong MWDMA timings being programmed
  (FATE#311054).
- patches.suse/pata_efar-fix-wrong-PIO-timings-being-programmed.patch:
  pata_efar: fix wrong PIO timings being programmed (FATE#311054).
- patches.suse/pata_hpt-37x-3x2n-add-debounce-delay-to-cable-dete.patch:
  pata_hpt{37x,3x2n}: add debounce delay to cable detection
  methods (FATE#311054).
- patches.suse/pata_hpt366-fix-timing-register-documentation.patch:
  pata_hpt366: fix timing register documentation (FATE#311054).
- patches.suse/pata_hpt37x-add-proper-cable-detection-methods.patch:
  pata_hpt37x: add proper cable detection methods (FATE#311054).
- patches.suse/pata_hpt37x-unify-pre_reset-methods.patch:
  pata_hpt37x: unify ->pre_reset methods (FATE#311054).
- patches.suse/pata_hpt3x2n-fix-cable-detection.patch:
  pata_hpt3x2n: fix cable detection (FATE#311054).
- patches.suse/pata_hpt3x2n-fix-overclocked-MWDMA0-timing.patch:
  pata_hpt3x2n: fix overclocked MWDMA0 timing (FATE#311054).
- patches.suse/pata_hpt3x3-Power-Management-fix.patch:
  pata_hpt3x3: Power Management fix (FATE#311054).
- patches.suse/pata_it8213-MWDMA0-is-unsupported.patch:
  pata_it8213: MWDMA0 is unsupported (FATE#311054).
- patches.suse/pata_it8213-fix-PIO2-underclocking.patch:
  pata_it8213: fix PIO2 underclocking (FATE#311054).
- patches.suse/pata_it8213-fix-UDMA-handling.patch: pata_it8213:
  fix UDMA handling (FATE#311054).
- patches.suse/pata_it8213-fix-it8213_pre_reset-documentation.patch:
  pata_it8213: fix it8213_pre_reset() documentation (FATE#311054).
- patches.suse/pata_it8213-fix-wrong-MWDMA-timings-being-programme.patch:
  pata_it8213: fix wrong MWDMA timings being programmed
  (FATE#311054).
- patches.suse/pata_it8213-fix-wrong-PIO-timings-being-programmed.patch:
  pata_it8213: fix wrong PIO timings being programmed
  (FATE#311054).
- patches.suse/pata_legacy-add-pointers-to-QDI65x0-documentation.patch:
  pata_legacy: add pointers to QDI65x0 documentation
  (FATE#311054).
- patches.suse/pata_legacy-fix-QDI6580DP-support.patch:
  pata_legacy: fix QDI6580DP support (FATE#311054).
- patches.suse/pata_legacy-fix-access-to-control-register-for-QDI6.patch:
  pata_legacy: fix access to control register for QDI6580
  (FATE#311054).
- patches.suse/pata_marvell-fix-marvell_pre_reset-documentation.patch:
  pata_marvell: fix marvell_pre_reset() documentation
  (FATE#311054).
- patches.suse/pata_ns87415-Power-Management-fix.patch:
  pata_ns87415: Power Management fix (FATE#311054).
- patches.suse/pata_octeon_cf-use-resource_size-to-fix-resource.patch:
  pata_octeon_cf: use resource_size(), to fix resource sizing bug
  (FATE#311054).
- patches.suse/pata_radisys-fix-UDMA-handling.patch: pata_radisys:
  fix UDMA handling (FATE#311054).
- patches.suse/pata_rz1000-Power-Management-fix.patch:
  pata_rz1000: Power Management fix (FATE#311054).
- patches.suse/pata_sis-Implement-MWDMA-for-the-UDMA-133-capable-c.patch:
  pata_sis: Implement MWDMA for the UDMA 133 capable chips
  (FATE#311054).
- patches.suse/pata_sis-Power-Management-fix.patch: pata_sis:
  Power Management fix (FATE#311054).
- patches.suse/pata_via-Blacklist-some-combinations-of-Transcend-F.patch:
  pata_via: Blacklist some combinations of Transcend Flash and
  via (FATE#311054).
- patches.suse/pata_via-clear-UDMA-transfer-mode-bit-for-PIO-and-M.patch:
  pata_via: clear UDMA transfer mode bit for PIO and MWDMA
  (FATE#311054).
- patches.suse/pata_via-fix-double-put-on-isa-bridge.patch:
  pata_via: fix double put on isa bridge (FATE#311054).
- patches.suse/qlogicpti-add-missing-parentheses.patch: [SCSI]
  qlogicpti: add missing parentheses (FATE#311054).
- patches.suse/sata_fsl-Add-asynchronous-notification-support.patch:
  sata_fsl: Add asynchronous notification support (FATE#311054).
- patches.suse/sata_mv-Clean-up-hard-coded-array-size-calculation.patch:
  sata_mv: Clean up hard coded array size calculation
  (FATE#311054).
- patches.suse/sata_mv-add-power-management-support-for-the-PCI-co.patch:
  sata_mv: add power management support for the PCI controllers
  (FATE#311054).
- patches.suse/sata_mv-add-power-management-support-for-the-platfo.patch:
  sata_mv: add power management support for the platform driver
  (FATE#311054).
- patches.suse/sata_mv-increase-PIO-IORDY-timeout.patch: sata_mv:
  increase PIO IORDY timeout (FATE#311054).
- patches.suse/sata_mv-move-the-PCI-bar-description-initialization.patch:
  sata_mv: move the PCI bar description initialization code
  (FATE#311054).
- patches.suse/sata_mv-remove-pointless-NULL-test.patch: sata_mv:
  remove pointless NULL test (FATE#311054).
- patches.suse/sata_mv-store-the-board_idx-into-the-host-private-d.patch:
  sata_mv: store the board_idx into the host private data
  (FATE#311054).
- patches.suse/sata_mv-support-clkdev-framework.patch: sata_mv:
  support clkdev framework (FATE#311054).
- patches.suse/sata_promise-don-t-classify-overruns-as-HSM-errors.patch:
  sata_promise: don't classify overruns as HSM errors
  (FATE#311054).
- patches.suse/sata_sil24-MSI-support-disabled-by-default.patch:
  sata_sil24: MSI support, disabled by default (FATE#311054).
- patches.suse/scsi-Add-missing-command-definitions.patch:
  [SCSI] scsi: Add missing command definitions (FATE#311054).
- patches.suse/scsi_debug-Thin-provisioning-support.patch:
  [SCSI] scsi_debug: Thin provisioning support (FATE#311054).
- patches.suse/scsi_debug-fix-Thin-provisioning-support.patch:
  [SCSI] scsi_debug: fix Thin provisioning support (FATE#311054).
- patches.suse/scsi_lib-fix-potential-NULL-dereference.patch:
  [SCSI] scsi_lib: fix potential NULL dereference (FATE#311054).
- patches.suse/sd-WRITE-SAME-16-UNMAP-support.patch: [SCSI] sd:
  WRITE SAME(16) / UNMAP support (FATE#311054).
- patches.suse/st-fix-test-of-value-range-in-st_set_options.patch:
  [SCSI] st: fix test of value range in st_set_options()
  (FATE#311054).
- patches.suse/stex-fix-scan-of-nonexistent-lun.patch: [SCSI]
  stex: fix scan of nonexistent lun (FATE#311054).
- patches.suse/stex-update-version-to-4.6.0000.4.patch: stex:
  update version to 4.6.0000.4 (FATE#311054).
* Fri May 27 2011 hare@suse.de
- Backport new kfifo API from 2.6.33:
- patches.suse/kfifo-add-DEFINE_KFIFO-and-friends-add-very-tiny-f.patch:
  kfifo: add DEFINE_KFIFO and friends, add very tiny functions
  (FATE#311054).
- patches.suse/kfifo-add-kfifo_skip-kfifo_from_user-and-kfifo_to_.patch:
  kfifo: add kfifo_skip, kfifo_from_user and kfifo_to_user
  (FATE#311054).
- patches.suse/kfifo-add-record-handling-functions.patch: kfifo:
  add record handling functions (FATE#311054).
- patches.suse/kfifo-cleanup-namespace.patch: kfifo: cleanup
  namespace (FATE#311054).
- patches.suse/kfifo-fix-warn_unused_result.patch: kfifo: fix
  warn_unused_result (FATE#311054).
- patches.suse/kfifo-move-out-spinlock.patch: kfifo: move out
  spinlock (FATE#311054).
- patches.suse/kfifo-move-struct-kfifo-in-place.patch: kfifo:
  move struct kfifo in place (FATE#311054).
- patches.suse/kfifo-rename-kfifo_put.-into-kfifo_in.-and-kfif.patch:
  kfifo: rename kfifo_put... into kfifo_in... and
  kfifo_get... into kfifo_out.. (FATE#311054).
- patches.suse/workqueue-Add-debugobjects-support.patch:
  workqueue: Add debugobjects support (FATE#311054).
* Thu May 26 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-117-add-Intel-Panther-Point-HDMI-codec-id:
  ALSA: hda - add Intel Panther Point HDMI codec id (FATE#311774).
* Thu May 26 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-116-Reorganize-controller-quriks-with-bit-flags:
  ALSA: hda - Reorganize controller quriks with bit flags
  (bnc#691269).
* Thu May 26 2011 mgalbraith@suse.de
- Initial commit of scheduler fates 312232, 311946, 312249, 311681, 311679, 311860,
  and 311682 (CFS Hard Limits).
- Two combo patches added to series.conf, one bringing the scheduler core forward
  to accomodate everything _except_ CFS Hard Limits, and one for hard limits, which
  is still in flux.  311860 is incomplete at this time -  waiting for a commit list
  from IBM.  311860 patches that are present are currently disabled.
- Individual patches stored in patches.sched for the moment, as I know I will
  need to re-generate these combo patches, and who knows, something could pop
  up requiring disection.
- Update config files.
- patches.fixes/sched-Implement-group-scheduler-statistics-in-one-struct: Refresh.
- patches.fixes/sched-Limit-the-number-of-scheduler-debug-messages.patch: Refresh.
- patches.fixes/sched-cfs-hard-limits-V6:
  CFS Hard Limits V6 (FATE 311682).
- patches.fixes/sched-make-tunable-scaling-configurable: Refresh.
- patches.fixes/sched-sle11-sp2-fates-scheduler-update:
  SLE11-SP2 FATE scheduler update (FATE 312232, 311946, 312249, 311681, 311679, 311860, bnc#588972).
- patches.fixes/sched-sysctl-for-normalized-tunables: Refresh.
- patches.sched/01-15-sched-fixlet-dont-update-shares-twice-on-on_rq-parent:
  sched: (fixlet) dont update shares twice on on_rq.
- patches.sched/02-15-sched-hierarchical-task-accounting-for-SCHED_OTHER:
  sched: hierarchical task accounting for SCHED_OTHER.
- patches.sched/03-15-sched-introduce-primitives-to-account-for-CFS-bandwidth-tracking:
  sched: introduce primitives to account for CFS.
- patches.sched/03-15-sched-introduce-primitives-to-account-for-CFS-bandwidth-tracking-fix:
  sched: introduce primitives to account for CFS bandwidth tracking UP buildfix.
- patches.sched/04-15-sched-validate-CFS-quota-hierarchies:
  sched: validate CFS quota hierarchies.
- patches.sched/04-15-sched-validate-CFS-quota-hierarchies-fix:
  sched: validate CFS quota hierarchies - bugfix.
- patches.sched/05-15-sched-add-a-timer-to-handle-CFS-bandwidth-refresh:
  sched: add a timer to handle CFS bandwidth refresh.
- patches.sched/06-15-sched-accumulate-per-cfs_rq-cpu-usage-and-charge-against-bandwidth:
  sched: accumulate per-cfs_rq cpu usage and charge.
- patches.sched/07-15-sched-expire-invalid-runtime:
  sched: expire invalid runtime.
- patches.sched/08-15-sched-throttle-cfs_rq-entities-which-exceed-their-local-runtime:
  sched: throttle cfs_rq entities which exceed their local runtime.
- patches.sched/09-15-sched-unthrottle-cfs_rqs-who-ran-out-of-quota-at-period-refresh:
  sched: unthrottle cfs_rq(s) who ran out of quota at period refresh.
- patches.sched/10-15-sched-allow-for-positional-tg_tree-walks:
  sched: allow for positional tg_tree walks.
- patches.sched/11-15-sched-prevent-interactions-between-throttled-entities-and-load-balance:
  sched: prevent interactions between throttled entities and load-balance.
- patches.sched/12-15-sched-migrate-throttled-tasks-on-HOTPLUG:
  sched: migrate throttled tasks on HOTPLUG.
- patches.sched/13-15-sched-add-exports-tracking-cfs-bandwidth-control-statistics:
  sched: add exports tracking cfs bandwidth control statistics.
- patches.sched/14-15-sched-return-unused-runtime-on-voluntary-sleep:
  sched: return unused runtime on voluntary sleep.
- patches.sched/15-15-sched-add-documentation-for-bandwidth-control:
  sched: add documentation for bandwidth control.
- patches.sched/16-15-sched-fix-hotplug-lockup:
  Re: Test for CFS Bandwidth Control V6 ( fix hotplug lockup).
- patches.sched/cpu_stop-add-dummy-implementation-for-UP:
  cpu_stop: add dummy implementation for UP.
- patches.sched/cpu_stop-implement-stop_cpu-and-stop_cpus:
  cpu_stop: implement stop_cpu().
- patches.sched/cpumask-Partition_sched_domains-takes-array-of-cpumask_var_t:
  cpumask: Partition_sched_domains takes array of cpumask_var_t.
- patches.sched/cpumask-Simplify-sched_rt-c:
  cpumask: Simplify sched_rt.c.
- patches.sched/powerpc-Enable-asymmetric-SMT-scheduling-on-POWER7:
  powerpc: Enable asymmetric SMT scheduling on POWER7.
- patches.sched/powerpc-Exclude-arch_sd_sibiling_asym_packing-on-UP:
  powerpc: Exclude arch_sd_sibiling_asym_packing() on UP.
- patches.sched/rcu-need-barrier-in-UP-synchronize_sched_expedited:
  rcu: need barrier() in UP synchronize_sched_expedited().
- patches.sched/sched-Add-asymmetric-group-packing-option-for-sibling-domain:
  sched: Add asymmetric group packing option for sibling domain.
- patches.sched/sched-Add-book-scheduling-domain:
  sched: Add book scheduling domain.
- patches.sched/sched-Add-enqueue-dequeue-flags:
  sched: Add enqueue/dequeue flags.
- patches.sched/sched-Add-sysctl_sched_shares_window:
  sched: Add sysctl_sched_shares_window.
- patches.sched/sched-Allow-SCHED_BATCH-to-preempt-SCHED_IDLE-tasks:
  sched: Allow SCHED_BATCH to preempt SCHED_IDLE tasks.
- patches.sched/sched-Allow-update_cfs_load-to-update-global-load:
  sched: Allow update_cfs_load() to update global load.
- patches.sched/sched-Allow-users-with-sufficient-RLIMIT_NICE-to-change-from-SCHED_IDLE-policy:
  sched: Allow users with sufficient RLIMIT_NICE to change from SCHED_IDLE policy.
- patches.sched/sched-Assume-balance-is-valid:
  sched: Assume *balance is valid.
- patches.sched/sched-Avoid-allocations-in-sched_domain_debug:
  sched: Avoid allocations in sched_domain_debug().
- patches.sched/sched-Avoid-expensive-initial-update_cfs_load:
  sched: Avoid expensive initial update_cfs_load().
- patches.sched/sched-Avoid-expensive-initial-update_cfs_load-on-UP-too:
  sched: Avoid expensive initial update_cfs_load(), on UP too.
- patches.sched/sched-Avoid-going-ahead-if-cpus_allowed-is-not-changed:
  sched: Avoid going ahead if ->cpus_allowed is not changed.
- patches.sched/sched-Avoid-side-effect-of-tickless-idle-on-update_cpu_load:
  sched: Avoid side-effect of tickless idle on update_cpu_load.
- patches.sched/sched-Avoid-using-sd-level:
  sched: Avoid using sd->level.
- patches.sched/sched-Change-NODE-sched_domain-group-creation:
  sched: Change NODE sched_domain group creation.
- patches.sched/sched-Change-nohz-idle-load-balancing-logic-to-push-model:
  sched: Change nohz idle load balancing logic to push model.
- patches.sched/sched-Change-usage-of-rt_rq-rt_se-to-rt_rq-tg-rt_se-cpu:
  sched: Change usage of rt_rq->rt_se to rt_rq->tg->rt_se.
- patches.sched/sched-Clean-up-rebalance_domains-load-balance-interval-calculation:
  sched: Clean up rebalance_domains() load-balance interval calculation.
- patches.sched/sched-Clean-up-remnants-of-sd_idle:
  sched: Clean up remnants of sd_idle.
- patches.sched/sched-Clean-up-some-ALLNODES-code:
  sched: Clean up some ALLNODES code.
- patches.sched/sched-Clean-up-some-f_b_g-comments:
  sched: Clean up some f_b_g() comments.
- patches.sched/sched-Cleanup-set_load_weight:
  sched: Cleanup set_load_weight().
- patches.sched/sched-Create-persistent-sched_domains_tmpmask:
  sched: Create persistent sched_domains_tmpmask.
- patches.sched/sched-Create-proper-cpu_DOM_mask-functions:
  sched: Create proper cpu_$DOM_mask() functions.
- patches.sched/sched-Create-special-class-for-stop-and-migrate-work:
  sched: Create special class for stop/migrate work.
- patches.sched/sched-Cure-load-average-vs-NO_HZ-woes:
  sched: Cure load average vs NO_HZ woes.
- patches.sched/sched-Cure-more-NO_HZ-load-average-woes:
  sched: Cure more NO_HZ load average woes.
- patches.sched/sched-Dont-expose-local-functions:
  sched: Don't expose local functions.
- patches.sched/sched-Drop-all-load-weight-manipulation-for-RT-tasks:
  sched: Drop all load weight manipulation for RT tasks.
- patches.sched/sched-Dynamic-sched_domain-level:
  sched: Dynamic sched_domain::level.
- patches.sched/sched-Dynamically-allocate-sched_domain-sched_group-data-structures:
  sched: Dynamically allocate sched_domain/sched_group data-structures.
- patches.sched/sched-Fix-PROVE_RCU-vs-cpu_cgroup:
  sched: Fix PROVE_RCU vs cpu_cgroup.
- patches.sched/sched-Fix-UP-build-breakage:
  sched: Fix UP build breakage.
- patches.sched/sched-Fix-and-optimise-calculation-of-the-weight-inverse:
  sched: Fix and optimise calculation of the weight-inverse.
- patches.sched/sched-Fix-capacity-calculations-for-SMT4:
  sched: Fix capacity calculations for SMT4.
- patches.sched/sched-Fix-comments-to-make-them-DocBook-happy:
  sched: Fix comments to make them DocBook happy.
- patches.sched/sched-Fix-erroneous-all_pinned-logic:
  sched: Fix erroneous all_pinned logic.
- patches.sched/sched-Fix-fix_small_capacity:
  sched: Fix fix_small_capacity.
- patches.sched/sched-Fix-interactivity-bug-by-charging-unaccounted-run-time-on-entity-re-weight:
  sched: Fix interactivity bug by charging unaccounted run-time on entity re-weight.
- patches.sched/sched-Fix-load-corruption-from-update_cfs_shares:
  sched: Fix load corruption from update_cfs_shares().
- patches.sched/sched-Fix-nohz-balance-kick:
  sched: Fix nohz balance kick.
- patches.sched/sched-Fix-poor-interactivity-on-UP-systems-due-to-group-scheduler-nice-tune-bug:
  sched: Fix poor interactivity on UP systems due to group scheduler nice tune bug.
- patches.sched/sched-Fix-rebalance-interval-calculation:
  sched: Fix rebalance interval calculation.
- patches.sched/sched-Fix-remove-redundant-cfs_rq-checks:
  sched: Fix/remove redundant cfs_rq checks.
- patches.sched/sched-Fix-rt_rq-runtime-leakage-bug:
  sched: Fix rt_rq runtime leakage bug.
- patches.sched/sched-Fix-runnable-condition-for-stoptask:
  sched: Fix runnable condition for stoptask.
- patches.sched/sched-Fix-sched-domain-avg_load-calculation:
  sched: Fix sched-domain avg_load calculation.
- patches.sched/sched-Fix-sched-rt-group-scheduling-when-hierachy-is-enabled:
  sched: Fix sched rt group scheduling when hierachy is enabled.
- patches.sched/sched-Fix-sched_domain-iterations-vs-RCU:
  sched: Fix sched_domain iterations vs. RCU.
- patches.sched/sched-Fix-sign-under-flows-in-wake_affine:
  sched: Fix sign under-flows in wake_affine.
- patches.sched/sched-Fix-spelling-of-sibling:
  sched: Fix spelling of sibling.
- patches.sched/sched-Fix-strncmp-operation: sched:
  Fix strncmp operation.
- patches.sched/sched-Fix-switch_from_fair:
  sched: Fix switch_from_fair().
- patches.sched/sched-Fix-the-group_imb-logic:
  sched: Fix the group_imb logic.
- patches.sched/sched-Fix-the-irqtime-code-for-32bit:
  sched: Fix the irqtime code for 32bit.
- patches.sched/sched-Fix-the-irqtime-code-to-deal-with-u64-wraps:
  sched: Fix the irqtime code to deal with u64 wraps.
- patches.sched/sched-Fix-the-place-where-group-powers-are-updated:
  sched: Fix the place where group powers are updated.
- patches.sched/sched-Fix-unregister_fair_sched_group:
  sched: Fix unregister_fair_sched_group().
- patches.sched/sched-Fix-update_cfs_load-synchronization:
  sched: Fix update_cfs_load() synchronization.
- patches.sched/sched-Fix-update_curr_rt:
  sched: Fix update_curr_rt().
- patches.sched/sched-Implement-demand-based-update_cfs_load:
  sched: Implement demand based update_cfs_load().
- patches.sched/sched-Implement-on-demand-cfs_rq-list:
  sched: Implement on-demand (active) cfs_rq list.
- patches.sched/sched-Increase-SCHED_LOAD_SCALE-resolution:
  sched: Increase SCHED_LOAD_SCALE resolution.
- patches.sched/sched-Introduce-SCHED_POWER_SCALE-to-scale-cpu_power-calculation:
  sched: Introduce SCHED_POWER_SCALE to scale cpu_power calculations.
- patches.sched/sched-Introduce-hierarchal-order-on-shares-update-list:
  sched: Introduce hierarchal order on shares update list.
- patches.sched/sched-Leave-sched_setscheduler-earlier-if-possible-to-not-disturb-SCHED_FIFO-task:
  sched: Leave sched_setscheduler() earlier if possible, do not disturb SCHED_FIFO tasks.
- patches.sched/sched-Limit-the-scope-of-clear_buddies:
  sched: Limit the scope of clear_buddies.
- patches.sched/sched-Make-set_next-last_buddy-work-on-non-task-entities:
  sched: Make set_*_buddy() work on non-task entities.
- patches.sched/sched-Make-sure-timers-have-migrated-before-killing-the-migration_thread:
  sched: Make sure timers have migrated before killing the migration_thread.
- patches.sched/sched-Make-tg_shares_up-walk-on-demand:
  sched: Make tg_shares_up() walk on-demand.
- patches.sched/sched-Merge-cpu_to_core_group-functions:
  sched: Merge cpu_to_core_group functions.
- patches.sched/sched-Move-load-balance-code-into-sched_fair-c:
  sched: Move load balance code into sched_fair.c.
- patches.sched/sched-Move-periodic-share-updates-to-entity_tick:
  sched: Move periodic share updates to entity_tick().
- patches.sched/sched-Move-sched-domain-storage-into-the-topology-list:
  sched: Move sched domain storage into the topology list.
- patches.sched/sched-Next-buddy-hint-on-sleep-and-preempt-path:
  sched: Next buddy hint on sleep and preempt path.
- patches.sched/sched-No-need-for-bootmem-special-cases:
  sched: No need for bootmem special cases.
- patches.sched/sched-Reduce-some-allocation-pressure:
  sched: Reduce some allocation pressure.
- patches.sched/sched-Reduce-update_group_power-calls:
  sched: Reduce update_group_power() calls.
- patches.sched/sched-Remove-from-fwd-decls:
  sched: Remove from fwd decls.
- patches.sched/sched-Remove-load_balance_newidle:
  sched: Remove load_balance_newidle().
- patches.sched/sched-Remove-member-rt_se-from-struct-rt_rq:
  sched: Remove member rt_se from struct rt_rq.
- patches.sched/sched-Remove-nodemask-allocation:
  sched: Remove nodemask allocation.
- patches.sched/sched-Remove-noop-in-alloc_rt_sched_group:
  sched: Remove noop in alloc_rt_sched_group().
- patches.sched/sched-Remove-obsolete-arch_-prefixes:
  sched: Remove obsolete arch_ prefixes.
- patches.sched/sched-Remove-obsolete-comment-from-scheduler_tick:
  sched: Remove obsolete comment from scheduler_tick().
- patches.sched/sched-Remove-rq_iterator-from-move_one_task:
  sched: Remove rq_iterator from move_one_task.
- patches.sched/sched-Remove-rq_iterator-usage-from-load_balance_fair:
  sched: Remove rq_iterator usage from load_balance_fair.
- patches.sched/sched-Remove-some-dead-code:
  sched: Remove some dead code.
- patches.sched/sched-Remove-the-sched_class-load_balance-methods:
  sched: Remove the sched_class load_balance methods.
- patches.sched/sched-Remove-unused-parameters-from-sched_fork-and-wake_up_new_task:
  sched: Remove unused parameters from sched_fork() and wake_up_new_task().
- patches.sched/sched-Remove-unused-this_best_prio-arg-from-balance_tasks:
  sched: Remove unused 'this_best_prio arg' from balance_tasks().
- patches.sched/sched-Remove-unused-update_shares_locked:
  sched: Remove unused update_shares_locked().
- patches.sched/sched-Reverse-the-topology-list:
  sched: Reverse the topology list.
- patches.sched/sched-Rewrite-tg_shares_up:
  sched: Rewrite tg_shares_up().
- patches.sched/sched-Shorten-the-construction-of-the-span-cpu-mask-of-sched-domain:
  sched: Shorten the construction of the span cpu mask of sched domain.
- patches.sched/sched-Simplify-NODE-ALLNODES-domain-creation:
  sched: Simplify NODE/ALLNODES domain creation.
- patches.sched/sched-Simplify-build_sched_groups:
  sched: Simplify build_sched_groups().
- patches.sched/sched-Simplify-cpu-hot-unplug-task-migration:
  sched: Simplify cpu-hot-unplug task migration.
- patches.sched/sched-Simplify-cpu_power-initialization:
  sched: Simplify ->cpu_power initialization.
- patches.sched/sched-Simplify-finding-the-lowest-sched_domain:
  sched: Simplify finding the lowest sched_domain.
- patches.sched/sched-Simplify-sched_group-creation:
  sched: Simplify sched_group creation.
- patches.sched/sched-Simplify-sched_groups_power-initialization:
  sched: Simplify sched_groups_power initialization.
- patches.sched/sched-Simplify-the-free-path-some:
  sched: Simplify the free path some.
- patches.sched/sched-Simplify-the-idle-scheduling-class:
  sched: Simplify the idle scheduling class.
- patches.sched/sched-Simplify-update_cfs_shares-parameters:
  sched: Simplify update_cfs_shares parameters.
- patches.sched/sched-Stuff-the-sched_domain-creation-in-a-data-structure:
  sched: Stuff the sched_domain creation in a data-structure.
- patches.sched/sched-Unify-load_balance-and-load_balance_newidle:
  sched: Unify load_balance{,_newidle}().
- patches.sched/sched-Unify-the-sched_domain-build-functions:
  sched: Unify the sched_domain build functions.
- patches.sched/sched-Update-effective_load-to-use-global-share-weights:
  sched: Update effective_load() to use global share weights.
- patches.sched/sched-Update-rq-clock-for-nohz-balanced-cpus:
  sched: Update rq->clock for nohz balanced cpus.
- patches.sched/sched-Update-shares-on-idle_balance:
  sched: Update shares on idle_balance.
- patches.sched/sched-Update-tg-shares-after-cpu-shares-write:
  sched: Update tg->shares after cpu.shares write.
- patches.sched/sched-Use-for_each_bit: sched: Use for_each_bit.
- patches.sched/sched-Use-rq-clock_task-instead-of-rq-clock-for-correctly-maintaining-load-average:
  sched: Use rq->clock_task instead of rq->clock for correctly maintaining load averages.
- patches.sched/sched-Wholesale-removal-of-sd_idle-logic:
  sched: Wholesale removal of sd_idle logic (bnc#588972).
- patches.sched/sched-Wrap-the-cfs_rq-nr_spread_over-field-with-CONFIG_SCHED_DEBUG:
  sched: Wrap the 'cfs_rq->nr_spread_over' field with CONFIG_SCHED_DEBUG.
- patches.sched/sched-cgroup-Fix-cgroup_subsys-exit-callback:
  cgroup: Fix cgroup_subsys::exit callback.
- patches.sched/sched-cgroup-Use-exit-hook-to-avoid-use-after-free-crash:
  sched, cgroup: Use exit hook to avoid use-after-free crash.
- patches.sched/sched-cgroups-if-you-list_empty-a-head-then-dont-list_del-it:
  cgroups: if you list_empty() a head then don't list_del() it.
- patches.sched/sched-correctly-place-paranioa-memory-barriers-in-synchronize_sched_expedited:
  sched: correctly place paranioa memory barriers in synchronize_sched_expedited().
- patches.sched/sched-kill-paranoia-check-in-synchronize_sched_expedited:
  sched: kill paranoia check in synchronize_sched_expedited().
- patches.sched/sched-might_sleep-Make-file-parameter-const-char-pointer:
  sched: might_sleep(): Make file parameter const char *.
- patches.sched/sched-no_hz-Remove-unused-rq-last_tick_seen-field:
  sched, no_hz: Remove unused rq->last_tick_seen field.
- patches.sched/sched-replace-migration_thread-with-cpu_stop:
  sched: replace migration_thread with cpu_stop.
- patches.sched/sched-workqueue-kill-RT-workqueue:
  workqueue: kill RT workqueue.
- patches.sched/series: make scripts/log happy.
- patches.sched/stop_machine-Move-local-variable-closer-to-the-usage-site-in-cpu_stop_cpu_callback:
  stop_machine: Move local variable closer to the usage site in cpu_stop_cpu_callback().
- patches.sched/stop_machine-fix-unused-variable-warning:
  kernel/stop_machine.c: fix unused variable warning.
- patches.sched/stop_machine-reimplement-using-cpu_stop:
  stop_machine: reimplement using cpu_stop.
- patches.sched/stop_machine-struct-cpu_stopper-remove-alignment-padding-on-64-bits:
  stop_machine: struct cpu_stopper, remove alignment padding on 64 bits.
- patches.sched/topology-s390-Add-z11-cpu-topology-support:
  topology, s390: Add z11 cpu topology support.
- patches.sched/topology-s390-expose-core-identifier:
  topology: expose core identifier.
- patches.sched/topology-sysfs-Provide-book-id-and-siblings-attributes:
  topology/sysfs: Provide book id and siblings attributes.
- patches.trace/utrace-core: Refresh.
* Thu May 26 2011 jbeulich@novell.com
- patches.xen/1080-blkfront-xenbus-gather-format.patch: xen/blkfront:
  fix data size for xenbus_gather in connect().
- patches.xen/1081-blkback-resize-transaction-end.patch: xenbus: fix
  xenbus_transaction_start() hang caused by double xenbus_transaction_end().
- patches.xen/1082-hvmop-get-mem-type.patch: Sync Xen public headers
  (bnc#684297).
- patches.xen/1083-kbdfront-absolute-coordinates.patch: xen-kbdfront -
  advertise either absolute or relative coordinates (bnc#670465).
- Refresh other Xen patches.
* Wed May 25 2011 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.27: Fix broken patch (bad merge).
* Wed May 25 2011 jslaby@suse.de
- patches.fixes/PCI-Set-PCIE-maxpayload-for-card-during-hotplug-inse.patch:
  PCI: Set PCIE maxpayload for card during hotplug insertion
  (bnc#692343 fate#312136).
  The fate is just for reference, this is not a feature, this is a bugfix
  appropriate for SP1 too.
* Tue May 24 2011 nfbrown@suse.de
- patches.fixes/nfs-mmap-sugbus-fix: NFS: Don't SIGBUS
  if nfs_vm_page_mkwrite races with a cache invalidation
  (bnc#690683).
* Mon May 23 2011 jslaby@suse.de
- Update to 2.6.32.41
- patches.drivers/netxen-0017-update-module-info.patch: Refresh.
- patches.xen/xen3-patch-2.6.27: Refresh.
* Fri May 20 2011 jslaby@suse.de
- patches.kernel.org/patch-2.6.32.38-39: Update references
  (bnc#688432 CVE-2011-1593).
* Fri May 20 2011 duwe@suse.de
- patches.arch/ppc-add-pgprot_writecombine: powerpc: Add
  pgprot_writecombine (FATE#311723, bnc#691633).
- patches.arch/ppc-add-power7+-cputableent: powerpc: Add POWER7+
  cputable entry (FATE#311677, bnc#691632).
- patches.fixes/perf-IP-callchain-consistency: perf: Fix
  inconsistency between IP and callchain sampling (FATE#311866,
  bnc#687789).
- patches.fixes/perf-enable-SDAR-in-continous-sample-mode:
  powerpc: perf_event: Enable SDAR in continous sample mode
  (FATE#311866, bnc#687789).
- patches.fixes/perf-frequency-calculation-for-overflowing-counters:
  powerpc: perf: Fix frequency calculation for overflowing
  counters (FATE#311866, bnc#687789).
- patches.fixes/perf-log-invalid-daddr-as-FF: powerpc: perf_event:
  Log invalid data addresses as all 1s (FATE#311866, bnc#687789).
- patches.fixes/perf-power_pmu_disable: powerpc/perf_event:
  Fix for power_pmu_disable() (FATE#311866, bnc#687789).
* Fri May 20 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-113-Use-LPIB-for-ATI-AMD-chipsets-as-default:
  ALSA: hda - Use LPIB for ATI/AMD chipsets as default
  (bnc#691269,bnc#687760).
- patches.drivers/alsa-sp1-hda-113-Use-position_fix-3-as-default-for-AMD:
  Delete.
* Fri May 20 2011 jbohac@suse.cz
- patches.fixes/xfrm-periodic-garbage-collector.patch: xfrm:
  fix garbage collection (bnc#680845, bnc#691693).
* Fri May 20 2011 jankit@suse.de
- patches.fixes/hpsa-fix-lost-command-issue: hpsa: do readl
  after writel in main i/o path to ensure commands don't get lost
  (bnc#683107).
* Thu May 19 2011 jbeulich@novell.com
- supported.conf: blktap2 modules are supported.
* Wed May 18 2011 jankit@suse.de
- patches.suse/aacraid-export-fixed-module-param: aacraid:
  Add module param to export disks as 'fixed' (bnc#667226).
* Tue May 17 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-115-Enable-snoop-bit-for-AMD-controllers:
  ALSA: hda - Enable snoop bit for AMD controllers (bnc#691269).
* Tue May 17 2011 mszeredi@suse.cz
- patches.fixes/radix-tree-fix-rcu-bug.patch: Radix-tree: fix
  RCU bug (bnc#670868).
* Tue May 17 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-114-Handle-dock-line-in-as-auto-detectable:
  ALSA: hda - Handle dock line-in as auto-detectable for IDT
  codecs (bnc#691829).
* Mon May 16 2011 jdelvare@suse.de
- Update config files.
- patches.drivers/hwmon-amd-fam15h-power.patch: hwmon: Add driver
  for AMD family 15h processor power information (FATE#309764).
- supported.conf: Driver hwmon/fam15h_power is supported.
* Mon May 16 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add the commit hash to uname -v, cleanup.
* Mon May 16 2011 mhocko@suse.cz
- patches.fixes/proc-fix-oops-on-invalid-proc-pid-maps-access.patch:
  proc: fix oops on invalid /proc/<pid>/maps access (bnc#693382).
* Mon May 16 2011 jslaby@suse.de
- patches.arch/ppc-kmem-cache-for-DTL-buffers: Refresh.
  It applies cleanly now (kabi patch caused the difference).
* Mon May 16 2011 nfbrown@suse.de
- Update config files.
  Add CONFIG_IPV6_OPTIMISTIC_DAD and CONFIG_IPV6_MROUTE
  to improve support for NFS over IPv6.
  (FATE#311666)
* Fri May 13 2011 dsterba@suse.cz
- patches.fixes/xfs-pass-private-data-to-formatter-in-xfs_bulkstat:
  xfs: pass private_data to formatter in xfs_bulkstat
  (bnc#691536).
* Fri May 13 2011 duwe@suse.de
- patches.arch/ppc-kmem-cache-for-DTL-buffers: powerpc/pseries:
  Use a kmem cache for DTL buffers (bnc#678728).
* Fri May 13 2011 mhocko@suse.cz
- patches.fixes/memcg-allocate-memory-cgroup-structures-in-local-nod.patch:
  memcg: allocate memory cgroup structures in local nodes
  (bnc#692502, bnc#669889).
- patches.fixes/mm-add-alloc_pages_exact_nid.patch: mm: add
  alloc_pages_exact_nid() (bnc#692502, bnc#669889).
* Thu May 12 2011 jslaby@suse.de
- patches.drivers/ata-Intel-IDE-R-support.patch: ata: Intel
  IDE-R support (fate#311817).
* Thu May 12 2011 jdelvare@suse.de
- patches.drivers/i2c-i801-support-multiple-instances.patch:
  i2c-i801: Handle multiple instances instead of keeping global
  state (bnc#650545, bnc#663513, FATE#311947, FATE#311838).
- patches.drivers/intel-patsburg-support-IDF-channels.patch:
  i2c-i801: Add PCI idents for Patsburg 'IDF' SMBus controllers
  (bnc#650545, bnc#663513, FATE#311947, FATE#311838).
- patches.drivers/i2c-i801-no-devices-on-IDF-channels.patch:
  i2c-i801: Don't probe for slaves on IDF channels (bnc#650545,
  bnc#663513, FATE#311947, FATE#311838).
* Thu May 12 2011 nfbrown@suse.de
- Bring md up to 2.6.39 level for FATE 311810
- patches.fixes/md-raid1-throttle: Throttle number of pending
  write requests in md/raid1 (bnc#663678).
- patches.suse/md-001-adjust-resync_min-usefully-when-resync-aborts.patch:
  md: adjust resync_min usefully when resync aborts.
- patches.suse/md-002-don-t-reset-curr_resync_completed-after-an-interr.patch:
  md: don't reset curr_resync_completed after an interrupted
  resync.
- patches.suse/md-003-support-barrier-requests-on-all-personalities.patch:
  md: support barrier requests on all personalities.
- patches.suse/md-004-raid5-don-t-complete-make_request-on-barrier-unti.patch:
  md/raid5: don't complete make_request on barrier until writes
  are scheduled.
- patches.suse/md-005-add-honouring-of-suspend_-lo-hi-to-raid1.patch:
  md: add honouring of suspend_{lo,hi} to raid1.
- patches.suse/md-006-raid1-add-takeover-support-for-raid5-raid1.patch:
  md/raid1: add takeover support for raid5->raid1.
- patches.suse/md-007-bitmap-update-dirty-flag-when-bitmap-bits-are-exp.patch:
  md/bitmap: update dirty flag when bitmap bits are explicitly
  set.
- patches.suse/md-008-raid10-print-more-useful-messages-on-device-failu.patch:
  md/raid10: print more useful messages on device failure.
- patches.suse/md-009-raid-improve-MD-raid10-handling-of-correctable-read-.patch:
  raid: improve MD/raid10 handling of correctable read errors.
- patches.suse/md-010-integrate-spares-into-array-at-earliest-opportuni.patch:
  md: integrate spares into array at earliest opportunity.
- patches.suse/md-011-rcu_read_lock-walk-of-mddev-disks-in-md_do_sync.patch:
  md: rcu_read_lock() walk of mddev->disks in md_do_sync().
- patches.suse/md-012-add-recovery_start-per-device-sysfs-attribute.patch:
  md: add 'recovery_start' per-device sysfs attribute.
- patches.suse/md-013-allow-a-resync-that-is-waiting-for-other-resync-t.patch:
  md: allow a resync that is waiting for other resync to complete,
  to be aborted.
- patches.suse/md-014-fix-some-lockdep-issues-between-md-and-sysfs.patch:
  md: fix some lockdep issues between md and sysfs.
- patches.suse/md-015-linear-avoid-possible-oops-and-array-stop.patch:
  md/linear: avoid possible oops and array stop.
- patches.suse/md-016-remove-unneeded-sysfs-files-more-promptly.patch:
  md: remove unneeded sysfs files more promptly.
- patches.suse/md-017-manage-redundancy-group-in-sysfs-when-changing-le.patch:
  md: manage redundancy group in sysfs when changing level.
- patches.suse/md-018-don-t-use-mddev-raid_disks-in-raid0-or-raid10-whi.patch:
  md: don't use mddev->raid_disks in raid0 or raid10 while array
  is active.
- patches.suse/md-019-Add-support-for-Raid0-Raid5-takeover.patch:
  md:Add support for Raid0->Raid5 takeover.
- patches.suse/md-020-Add-support-for-Raid5-Raid0-and-Raid10-Raid0-take.patch:
  md: Add support for Raid5->Raid0 and Raid10->Raid0 takeover.
- patches.suse/md-021-Add-support-for-Raid0-Raid10-takeover.patch:
  md: Add support for Raid0->Raid10 takeover.
- patches.suse/md-022-Correctly-handle-device-removal-via-sysfs.patch:
  md: Correctly handle device removal via sysfs.
- patches.suse/md-023-Relax-checks-on-max_disks-when-external-metadata-.patch:
  md: Relax checks on ->max_disks when external metadata handling
  is used.
- patches.suse/md-024-notify-level-changes-through-sysfs.patch:
  md: notify level changes through sysfs.
- patches.suse/md-025-add-support-for-raid5-to-raid4-conversion.patch:
  md: add support for raid5 to raid4 conversion.
- patches.suse/md-026-raid1-fix-confusing-redirect-sector-message.patch:
  md/raid1: fix confusing 'redirect sector' message.
- patches.suse/md-027-raid4-permit-raid0-takeover.patch: md/raid4:
  permit raid0 takeover.
- patches.suse/md-028-notify-mdstat-waiters-of-level-change.patch:
  md: notify mdstat waiters of level change.
- patches.suse/md-029-allow-integers-to-be-passed-to-md-level.patch:
  md: allow integers to be passed to md/level.
- patches.suse/md-030-remove-EXPERIMENTAL-designation-from-RAID10.patch:
  md: remove EXPERIMENTAL designation from RAID10.
- patches.suse/md-031-simplify-updating-of-event-count-to-sometimes-avo.patch:
  md: simplify updating of event count to sometimes avoid
  updating spares.
- patches.suse/md-032-don-t-insist-on-valid-event-count-for-spare-devic.patch:
  md: don't insist on valid event count for spare devices.
- patches.suse/md-033-raid10-Fix-null-pointer-dereference-in-fix_read_e.patch:
  md: raid10: Fix null pointer dereference in fix_read_error().
- patches.suse/md-034-fix-handling-of-array-level-takeover-that-re-arra.patch:
  md: fix handling of array level takeover that re-arranges
  devices.
- patches.suse/md-035-fix-raid10-takeover-use-new_layout-for-setup_conf.patch:
  md: fix raid10 takeover: use new_layout for setup_conf.
- patches.suse/md-036-clear-layout-after-raid0-takeover.patch:
  md: clear layout after ->raid0 takeover.
- patches.suse/md-037-enable-raid4-raid0-takeover.patch: md:
  enable raid4->raid0 takeover.
- patches.suse/md-038-raid5-avoid-oops-when-number-of-devices-is-reduce.patch:
  md/raid5: avoid oops when number of devices is reduced then
  increased.
- patches.suse/md-039-Don-t-update-recovery_offset-when-reshaping-an-ar.patch:
  md: Don't update ->recovery_offset when reshaping an array to
  fewer devices.
- patches.suse/md-040-raid5-More-careful-check-for-has-array-failed.patch:
  md/raid5: More careful check for "has array failed".
- patches.suse/md-041-raid5-Allow-recovered-part-of-partially-recovered.patch:
  md/raid5: Allow recovered part of partially recovered devices
  to be in-sync.
- patches.suse/md-042-raid5-add-a-missing-continue-in-a-loop.patch:
  md/raid5: add a missing 'continue' in a loop.
- patches.suse/md-043-raid5-don-t-include-spare-drives-when-reshaping-t.patch:
  md/raid5: don't include 'spare' drives when reshaping to
  fewer devices.
- patches.suse/md-044-be-more-careful-setting-MD_CHANGE_CLEAN.patch:
  md: be more careful setting MD_CHANGE_CLEAN.
- patches.suse/md-045-fix-another-deadlock-with-removing-sysfs-attribut.patch:
  md: fix another deadlock with removing sysfs attributes.
- patches.suse/md-046-Update-recovery_offset-even-when-external-metadata-i.patch:
  Update recovery_offset even when external metadata is used.
- patches.suse/md-047-Notify-sysfs-when-RAID1-5-10-disk-is-In_sync.patch:
  md: Notify sysfs when RAID1/5/10 disk is In_sync.
- patches.suse/md-048-provide-appropriate-return-value-for-spare_active.patch:
  md: provide appropriate return value for spare_active functions.
- patches.suse/md-049-don-t-clear-MD_CHANGE_CLEAN-in-md_update_sb-for-e.patch:
  md: don't clear MD_CHANGE_CLEAN in md_update_sb() for external
  arrays.
- patches.suse/md-050-resolve-confusion-of-MD_CHANGE_CLEAN.patch:
  md: resolve confusion of MD_CHANGE_CLEAN.
- patches.suse/md-051-call-md_update_sb-even-for-external-metadata-arra.patch:
  md: call md_update_sb even for 'external' metadata arrays.
- patches.suse/md-052-fix-v1.x-metadata-update-when-a-disk-is-missing.patch:
  md: fix v1.x metadata update when a disk is missing.
- patches.suse/md-053-raid1-avoid-overflow-in-raid1-resync-when-bitmap-.patch:
  md/raid1:  avoid overflow in raid1 resync when bitmap is in use.
- patches.suse/md-054-raid1-minor-bio-initialisation-improvements.patch:
  md/raid1: minor bio initialisation improvements.
- patches.suse/md-055-check-return-code-of-read_sb_page.patch:
  md: check return code of read_sb_page.
- patches.suse/md-056-Fix-regression-with-raid1-arrays-without-persiste.patch:
  md: Fix regression with raid1 arrays without persistent
  metadata.
- patches.suse/md-057-use-sector_t-in-bitmap_get_counter.patch:
  md: use sector_t in bitmap_get_counter.
- patches.suse/md-058-Fix-possible-deadlock-with-multiple-mempool-alloc.patch:
  md: Fix possible deadlock with multiple mempool allocations.
- patches.suse/md-059-use-bio_kmalloc-rather-than-bio_alloc-when-failur.patch:
  md: use bio_kmalloc rather than bio_alloc when failure is
  acceptable.
- patches.suse/md-060-raid1-perform-mem-allocation-before-disabling-wri.patch:
  md/raid1: perform mem allocation before disabling writes
  during resync.
- patches.suse/md-061-change-type-of-first-arg-to-sync_page_io.patch:
  md: change type of first arg to sync_page_io.
- patches.suse/md-062-use-separate-bio-pool-for-each-md-device.patch:
  md: use separate bio pool for each md device.
- patches.suse/md-063-protect-against-NULL-reference-when-waiting-to-st.patch:
  md: protect against NULL reference when waiting to start
  a raid10.
- patches.suse/md-064-fix-regression-resulting-in-delays-in-clearing-bi.patch:
  md: fix regression resulting in delays in clearing bits in
  a bitmap.
- patches.suse/md-065-Ensure-no-IO-request-to-get-md-device-before-it-i.patch:
  md: Ensure no IO request to get md device before it is properly
  initialised.
- patches.suse/md-066-raid5-use-sysfs_notify_dirent_safe-to-avoid-NULL-.patch:
  md/raid5: use sysfs_notify_dirent_safe to avoid NULL pointer.
- patches.suse/md-067-Be-more-careful-about-clearing-flags-bit-in-recov.patch:
  md: Be more careful about clearing flags bit in ->recovery.
- patches.suse/md-068-Don-t-let-implementation-detail-of-curr_resync-le.patch:
  md: Don't let implementation detail of curr_resync leak out
  through sysfs.
- patches.suse/md-069-allow-suspend_lo-and-suspend_hi-to-decrease-as-we.patch:
  md: allow suspend_lo and suspend_hi to decrease as well as
  increase.
- patches.suse/md-070-fix-sync_completed-reporting-for-very-large-drive.patch:
  md: fix sync_completed reporting for very large drives (>2TB).
- patches.suse/md-071-raid5-handle-manually-added-spares-in-start_resha.patch:
  md/raid5: handle manually-added spares in start_reshape.
- patches.suse/md-072-range-check-slot-number-when-manually-adding-a-sp.patch:
  md: range check slot number when manually adding a spare.
- patches.suse/md-073-Fix-removal-of-extra-drives-when-converting-RAID6.patch:
  md: Fix removal of extra drives when converting RAID6 to RAID5.
- patches.suse/md-074-revert-change-to-raid_disks-on-failure.patch:
  md: revert change to raid_disks on failure.
- patches.suse/md-075-simplify-some-if-conditionals-in-raid5_start_resh.patch:
  md: simplify some 'if' conditionals in raid5_start_reshape.
- patches.suse/md-076-fix-the-test-for-finding-spares-in-raid5_start_re.patch:
  md: fix the test for finding spares in raid5_start_reshape.
- patches.suse/md-077-don-t-abort-checking-spares-as-soon-as-one-cannot.patch:
  md: don't abort checking spares as soon as one cannot be added.
- patches.suse/md-078-Remove-the-AllReserved-flag-for-component-devices.patch:
  md: Remove the AllReserved flag for component devices.
- patches.suse/md-079-Add-raid1-raid0-takeover-support.patch:
  Add raid1->raid0 takeover support.
- patches.suse/md-080-Don-t-use-remove_and_add_spares-to-remove-failed-.patch:
  md: Don't use remove_and_add_spares to remove failed devices
  from a read-only array.
- patches.suse/md-081-don-t-clear-curr_resync_completed-at-end-of-resyn.patch:
  md: don't clear curr_resync_completed at end of resync.
- patches.suse/md-082-Don-t-allow-slot_store-while-resync-recovery-is-h.patch:
  md: Don't allow slot_store while resync/recovery is happening.
- patches.suse/md-083-FIX-md-process-hangs-at-wait_barrier-after-0-10-take.patch:
  FIX: md: process hangs at wait_barrier after 0->10 takeover.
- patches.suse/md-084-Fix-raid1-raid0-takeover.patch: md: Fix
  raid1->raid0 takeover.
- patches.suse/md-085-don-t-set_capacity-before-array-is-active.patch:
  md: don't set_capacity before array is active.
- patches.suse/md-086-Fix-dev_sectors-on-takeover-from-raid0-to-raid4-5.patch:
  md: Fix dev_sectors on takeover from raid0 to raid4/5.
- patches.suse/md-087-Cleanup-after-raid45-raid0-takeover.patch:
  md: Cleanup after raid45->raid0 takeover.
- patches.suse/md-088-raid5-fix-build-error-sector_t-usage.patch:
  raid5: fix build error, sector_t usage.
- patches.suse/md-089-Fix-race-when-creating-a-new-md-device.patch:
  md: Fix race when creating a new md device.
- patches.suse/md-090-reject-a-re-add-request-that-cannot-be-honoured.patch:
  md: reject a re-add request that cannot be honoured.
- patches.suse/md-091-bitmap-fix-saving-of-events_cleared-and-other-sta.patch:
  md/bitmap: fix saving of events_cleared and other state.
- patches.suse/md-092-allow-resync_start-to-be-set-while-an-array-is-ac.patch:
  md: allow resync_start to be set while an array is active.
* Wed May 11 2011 jbeulich@novell.com
- Update Xen patches to 2.6.32.40 and c/s 1079.
- Update Xen config files.
- patches.xen/xen-amd-ecs: x86: Use PCI method for enabling AMD
  extended config space before MSR method.
- patches.xen/xen-blktap2-configurable-nr-devs: blktap2: replace
  hard-coded limit of tap devices with configurable one.
- patches.xen/xen-blktap2-use-after-free: blktap: Fix reference
  to freed struct request.
- patches.xen/xen-setup-gsi: pass trigger mode and polarity
  information to Xen for all interrupts.
- patches.xen/xen-tmem-v1: update tmem interface to v1.
- patches.xen/xen-watchdog: Xen: para-virtual watchdog driver
  (FATE#310308).
- patches.xen/xen-x86_64-unmapped-initrd: eliminate scalability
  issues from initrd handling.
- patches.xen/xen3-VMware-Balloon-driver-2.6.32.28.patch: VMware
  Balloon driver (bnc#669740, fate#311976).
- patches.xen/xen3-auto-blktap2-pvops.diff: pv-ops blktap2.
- patches.xen/xen3-fixup-blktap2-pvops: adjust xen build after
  addition of pv-ops' blktap2.
- patches.xen/xen3-x86-Increase-NR_IRQS-and-nr_irqs.patch: x86:
  Increase NR_IRQS and nr_irqs (bnc#605686 fate#311591).
- supported.conf: Add pci-iomul, evtchn, and xen_wdt. Mark
  netloop unsupported.
* Wed May 11 2011 mmarek@suse.cz
- patches.kabi/struct-rt2x00_ops-guard.patch: Delete, unused.
* Wed May 11 2011 mmarek@suse.cz
- patches.fixes/sunrpc-cache-completion.fix: Refresh.
- patches.fixes/nfsd-09-fix-kabi: Delete.
* Tue May 10 2011 jslaby@suse.de
- patches.fixes/proc-deal-with-races-in-proc-syscall-stack-personality.patch:
  Refresh.
* Tue May 10 2011 mhocko@suse.cz
- patches.suse/mm-devzero-optimisation.patch: Delete (no longer
  needed as we have zero page).
* Tue May 10 2011 jslaby@suse.de
- patches.fixes/proc-auxv-require-the-target-to-be-tracable-or-yourself.patch:
  auxv: require the target to be tracable (or yourself)
  (bnc#674982 CVE-2011-1020).
- patches.fixes/proc-close-race-in-proc-environ.patch: close
  race in /proc/*/environ (bnc#674982 CVE-2011-1020).
- patches.fixes/proc-deal-with-races-in-proc-syscall-stack-personality.patch:
  deal with races in /proc/*/{syscall,stack,personality}
  (bnc#674982 CVE-2011-1020).
- patches.fixes/proc-pagemap-close-races-with-suid-execve.patch:
  pagemap: close races with suid execve (bnc#674982
  CVE-2011-1020).
- patches.fixes/proc-report-errors-in-proc-map-sanely.patch:
  report errors in /proc/*/*map* sanely (bnc#674982
  CVE-2011-1020).
* Tue May 10 2011 jslaby@suse.de
- Update to 2.6.32.40
  - obsoletes:
  - patches.drivers/mmc-fix-hangs-with-sd-at-pm
  - patches.drivers/netxen-0018-module-firmware-hints.patch
  - patches.fixes/af_unix-limit-recursion-level
  - patches.fixes/ldm-fix-oops-on-corrupted-partition-table.patch
  - patches.fixes/nfs-fix-hangs-over-tcp-due-to-packet-loss
  - patches.fixes/nfs4-acl-pages.fix
  - patches.fixes/niu-fix-kernel-buffer-overflow-for-ethtool_grxclsrlall
  - patches.fixes/osf-partition-table-fix.patch
  - patches.fixes/scsi-dh-emc-mode-select-10-size
  - patches.fixes/scsi-dh-emc-rw-mismatch
  - patches.fixes/tehuti-firmware-name
  - patches.fixes/virtio_net-Add-napi-schedule-to-napi_enable-call.patch
- patches.drivers/bnx2x-backports-v2.6.32-to-af901ca.patch:
  Refresh.
- patches.drivers/mpt2sas-04.100.01.02-update: Refresh.
- patches.drivers/netxen-0014-support-for-new-firmware-file-format.patch:
  Refresh.
- patches.drivers/netxen-0017-update-module-info.patch: Refresh.
- patches.drivers/synaptics-hp-clickpad: Refresh.
- patches.drivers/synaptics-hp-new-model.diff: Refresh.
- patches.kabi/kabi-fix-up-struct-mmc_host: Refresh.
- patches.kabi/struct-rt2x00_ops-guard.patch: KABI: struct
  rt2x00_ops guard.
* Mon May  9 2011 mhocko@suse.cz
- Update config files.
* Mon May  9 2011 mhocko@suse.cz
- Update config files - CONFIG_VMWARE_BALLOON enabled (fate#311976)
- patches.drivers/VMware-Balloon-driver-2.6.32.28.patch: VMware
  Balloon driver (bnc#669740, fate#311976).
- supported.conf: module supported externally
* Fri May  6 2011 jjolly@suse.de
- patches.arch/s390-29-01-qdio_input_error.patch: qdio: reset
  error states immediately (bnc#691408,LTC#71781).
- patches.arch/s390-29-02-diag10-64bit.patch: kernel: diagnose
  10 does not release memory above 2GB (bnc#691408,LTC#71847).
* Fri May  6 2011 mgorman@suse.de
- patches.suse/mm-vmswap-*: Backport VmSwap from 2.6.36 (fate#311083)
* Fri May  6 2011 mhocko@suse.cz
- Update config files
  - enable CONFIG_CGROUP_MEM_RES_CTLR_SWAP in all kernel
    flavors(fate#310471)
* Thu May  5 2011 mfasheh@suse.com
- patches.fixes/ocfs2-init-data_ac.patch: ocfs2: Initialize
  data_ac (might be used uninitialized).
* Thu May  5 2011 tiwai@suse.de
- supported.conf: Add snd-asihpi (FATE#310119)
* Thu May  5 2011 bphilips@suse.de
- patches.drivers/ixgbe-Disable-RSC-when-ITR-setting-is-too-high-to-al.patch:
  ixgbe: Disable RSC when ITR setting is too high to allow RSC
  (bnc#686325).
- patches.drivers/ixgbe-add-needs-reset-to-ixgbe_set_flags.patch:
  ixgbe: add needs_reset to ixgbe_set_flags (bnc#686325).
- patches.drivers/ixgbe-enable-extremely-low-latency.patch:
  ixgbe: enable extremely low latency (bnc#686325).
- patches.drivers/ixgbe-fix-automatic-LRO-RSC-settings-for-low-latency.patch:
  ixgbe: fix automatic LRO/RSC settings for low latency
  (bnc#686325).
- patches.drivers/ixgbe-fix-bug-when-EITR-0-causing-no-writebacks.patch:
  ixgbe: fix bug when EITR=0 causing no writebacks (bnc#686325).
* Wed May  4 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-103-Fixes-distorted-recording-on-US15W-chipset:
  ALSA: hda - Fixes distorted recording on US15W chipset
  (bnc#691269,bnc#687760).
- patches.drivers/alsa-sp1-hda-104-Add-position_fix-3-module-option:
  ALSA: HDA: Add position_fix=3 module option, and refactor
  related code (bnc#691269,bnc#687760).
- patches.drivers/alsa-sp1-hda-105-Correctly-apply-position_fix-quirks-for-ATI:
  ALSA: HDA: Correctly apply position_fix quirks for ATI and
  VIA controllers (bnc#691269,bnc#687760).
- patches.drivers/alsa-sp1-hda-106-Enable-sync_write-workaround-for-AMD:
  ALSA: hda - Enable sync_write workaround for AMD generically
  (bnc#691269,bnc#687760).
- patches.drivers/alsa-sp1-hda-107-Prevent-writing-ICH6_PCIREG_TCSEL-on-AMD:
  ALSA: hda: Prevent writing ICH6_PCIREG_TCSEL on AMD systems
  (bnc#691269,bnc#687760).
- patches.drivers/alsa-sp1-hda-108-More-relax-for-pending-period-handling:
  ALSA: hda - More relax for pending period handling
  (bnc#691269,bnc#687760).
- patches.drivers/alsa-sp1-hda-109-use-WALLCLK-register-for-early-irqs:
  [ALSA] snd-hda-intel: use WALLCLK register to check for early
  irqs (bnc#691269,bnc#687760).
- patches.drivers/alsa-sp1-hda-110-Improve-azx_position_ok:
  [ALSA] snd-hda-intel: Improve azx_position_ok()
  (bnc#691269,bnc#687760).
- patches.drivers/alsa-sp1-hda-111-fix-handling-of-non-completion-stream-irqs:
  ALSA: hda_intel: fix handling of non-completion stream
  interrupts (bnc#691269,bnc#687760).
- patches.drivers/alsa-sp1-hda-112-fix-wallclk-variable-update-and-condition:
  ALSA: hda-intel - fix wallclk variable update and condition
  (bnc#691269,bnc#687760).
- patches.drivers/alsa-sp1-hda-113-Use-position_fix-3-as-default-for-AMD:
  ALSA: hda - Use position_fix=3 as default for AMD chipsets
  (bnc#691269,bnc#687760).
* Wed May  4 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete wacom-kmp (bnc#621203).
* Wed May  4 2011 mgalbraith@suse.de
- Remove leftover __GENKSYMS__ kABI guards
- patches.fixes/fcoe-sync-with-upstream-patches: Refresh.
- patches.fixes/ipsec-fix-bogus-bundle-flowi.patch: Refresh.
- patches.fixes/libsas-dont-issue-commands-to-removed-devices: Refresh.
- patches.fixes/libsas-strict-wideport-definition: Refresh.
- patches.fixes/xfs-make-xfsbufd-less-aggressive.patch: Refresh.
- patches.suse/SoN-31-fix-kernel-bug-with-multiple-swapfiles: Refresh.
- patches.suse/libfc-fix-indefinite-rport-restart: Refresh.
* Wed May  4 2011 tiwai@suse.de
- patches.drivers/alsa-sp2-add-asihpi: Add snd-asihpi driver to
  SP2 (FATE#310119).
- Update config files.
* Tue May  3 2011 jslaby@suse.de
- Update config files.
  - move the TRACE configs to proper places
  - set B43 config similar to other configs after kabi patches
    removal
* Tue May  3 2011 jslaby@suse.de
- patches.drivers/watchdog-softdog-soft_panic-param.patch:
  watchdog: softdog.c: enhancement to optionally invoke panic
  instead of reboot on timer expiry (fate#312208).
* Tue May  3 2011 jslaby@suse.de
- patches.fixes/mutex-Improve-the-scalability-of-optimistic-spinning.patch:
  mutex: Improve the scalability of optimistic spinning
  (fate#311833).
* Tue May  3 2011 jslaby@suse.de
- patches.arch/x86-Increase-NR_IRQS-and-nr_irqs.patch: x86:
  Increase NR_IRQS and nr_irqs (bnc#605686 fate#311591).
* Tue May  3 2011 rjw@suse.de
- patches.drivers/PCI-enable-pci-bfsort-by-default-on-future-Dell-systems.patch:
  PCI: Enable pci=bfsort by default on future Dell systems
  (FATE#311159).
* Tue May  3 2011 rjw@suse.de
- patches.drivers/PCI-export-SMBIOS-provided-firmware-instance-and-label-to-sysfs.patch:
  PCI: Export SMBIOS provided firmware instance and label to sysfs
  (FATE#311156).
* Tue May  3 2011 mszeredi@suse.cz
- patches.fixes/ldm-fix-oops-on-corrupted-partition-table.patch:
  fs/partitions/ldm.c: fix oops caused by corrupted partition
  table (CVE-2011-1017 bnc#674648).
* Tue May  3 2011 mmarek@suse.cz
- Delete kabi reference files and patches.kabi/*
- patches.arch/ppc-smt-idle-time-fix: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
- patches.xen/xen3-patch-2.6.32.16-17: Refresh.
* Tue May  3 2011 jack@suse.cz
- Enable CONFIG_BLKDEV_IO_TRACE and necessary config options (fate#311090)
* Tue May  3 2011 jbeulich@novell.com
- patches.suse/stack-unwind: Fix breakage from 2.6.29 merge
  (bnc#588458, bnc#614349).
* Tue May  3 2011 jbeulich@novell.com
- patches.xen/xen3-intel-patsburg-support.patch: Add Patsburg
  PCH support to SLES11 SP1 (bnc#650545, bnc#663513, FATE#311346,
  FATE#311838).
- Refresh other Xen patches.
* Tue May  3 2011 hare@suse.de
- patches.fixes/scsi-dh-alua-attach-to-unavailable: SCSI ALUA
  handler fails to attach to devices reporting UNAVAILABLE AAS
  (bnc#682251).
* Tue May  3 2011 mmarek@suse.cz
- README.BRANCH: This is SLE11-SP2.
* Fri Apr 29 2011 jeffm@suse.com
- rpm/compute-PATCHVERSION.sh: Replace ^+++ with ^\+\+\+ as an
  awk regex. It's technically invalid.
* Thu Apr 28 2011 jack@suse.cz
- patches.fixes/novfs-nwcapi.patch: Fix checking of login id
  (bnc#626119).
* Thu Apr 28 2011 tiwai@suse.de
- patches.drivers/alsa-usb-Don-t-expose-broken-dB-ranges: ALSA:
  usb-audio - Don't expose broken dB ranges (bnc#677563).
* Wed Apr 27 2011 jeffm@suse.com
- Deleted unused patches.suse/osync-error. The issue it resolved
  in earlier releases doesn't exist in this one.
* Tue Apr 26 2011 rgoldwyn@suse.de
- patches.fixes/reiserfs-xattr-crash-fix: fix crash on mount
  if disk is not reiserfs (bnc#686921). Patch modified.
* Tue Apr 26 2011 mgalbraith@suse.de
- patches.fixes/sched-Implement-group-scheduler-statistics-in-one-struct:
  sched: Implement group scheduler statistics in one struct (bnc#689746).
- patches.kabi/sched-sched_entity-kABI-guard.patch:
  sched: sched_entity kABI guard (bnc#689746).
* Tue Apr 26 2011 jkosina@suse.cz
- patches.fixes/hid-noget-quirk-for-symboltec.patch: HID: add
  noget quirk for scanners from Symbol Technologies (bnc#689290).
* Tue Apr 26 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-102-Add-internal-mic-for-IDT-92HD88B:
  ALSA: HDA: Add internal mic for IDT 92HD88B (bnc#689596).
* Sat Apr 23 2011 jslaby@suse.de
- Update to 2.6.32.39
  - obsoletes:
  - patches.fixes/media-video-sn9c102-world-wirtable-sysfs-files
  - patches.fixes/ubifs-restrict-world-writable-debugfs-files
- patches.xen/xen3-patch-2.6.27: Refresh.
- patches.xen/xen3-patch-2.6.32.38-39: Linux 2.6.32.39.
* Fri Apr 22 2011 tiwai@suse.de
- patches.drivers/sdhci-jmb38x-readonly-check: mmc: Fix read-only
  detection with JMicron 388 chip (bnc#686980).
* Thu Apr 21 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-101-Enable-sync_write-for-AMD-chipset-with-IDT:
  ALSA: hda - Enable sync_write for AMD chipset with IDT 92HD8x
  codecs (bnc#688326, bnc#687759).
* Wed Apr 20 2011 jbohac@suse.cz
- patches.fixes/tcp-clear-hints-to-avoid-a-stale-one.patch:
  tcp: clear hints to avoid a stale one (nfs only
  affected?) (bnc#684927).
* Wed Apr 20 2011 hare@suse.de
- patches.suse/dm-mpath-leastpending-status-display-fix:
  dm-leastpending does not work with multipath-tools (bnc#653850).
* Wed Apr 20 2011 duwe@suse.de
- patches.arch/ppc-monotonic-time: powerpc: Rework VDSO
  gettimeofday to prevent time going backwards (bnc#685226).
- patches.arch/ppc-smt-idle-time-fix: powerpc: Account time
  using timebase rather than PURR  (bnc#678728).
- patches.kabi/ppc-smt-idle-time-kabi-fix: avoid
  ppc-smt-idle-time-fix kABI breakage (bnc#678728).
* Tue Apr 19 2011 mfasheh@suse.com
- patches.fixes/ocfs2-dlm-use-negotiated-o2dlm-proto.patch:
  ocfs2/dlm: Use negotiated o2dlm protocol version.
* Tue Apr 19 2011 jbohac@suse.cz
- patches.fixes/bonding-802.3ad-fix-agg_device_up.patch: bonding:
  802.3ad - fix agg_device_up (bnc#682482).
* Tue Apr 19 2011 jjolly@suse.de
- kabi/severities: Added drivers/s390/block as the dasd_mod has changed
  due to patches from IBM.
* Mon Apr 18 2011 mfasheh@suse.com
- patches.fixes/Ocfs2-Journaling-i_flags-and-i_orphaned_slot-when-ad.patch:
  Re-enable.
* Mon Apr 18 2011 mfasheh@suse.com
  Remove unused patches:
- patches.fixes/ocfs2-allow-huge-volumes.patch: Delete.
- patches.fixes/ocfs2-grab_cache_page-recursion-fix: Delete.
* Mon Apr 18 2011 jjolly@suse.de
- patches.arch/s390-28-01-cio-prevent-online-purge.patch:
  cio: prevent purging of CCW devices in the online state
  (bnc#684472,LTC#71139).
- patches.arch/s390-28-02-dasd-fix-open-offline-race.patch:
  dasd: fix race between open and offline (bnc#684472,LTC#71377).
- patches.arch/s390-28-03-dasd-remove-uid-from-devmap.patch:
  dasd: remove uid from devmap (bnc#684472,LTC#64028).
* Mon Apr 18 2011 hare@suse.de
- patches.fixes/scsi-ses-crash-on-lun0: Fixup typo.
* Mon Apr 18 2011 hare@suse.de
- patches.fixes/scsi-dh-rdac-fix-lun-table: scsi_dh_rdac: fix
  for lun_table update for rdac device handler (bnc#686404).
- patches.fixes/scsi-ses-crash-on-lun0: Kernel oops during bootup
  in ses_intf_add() (bnc#670816).
* Sat Apr 16 2011 gregkh@suse.de
- Update to 2.6.32.38
  - bugfix for problem with 2.6.32.37
* Fri Apr 15 2011 jack@suse.cz
- patches.fixes/novfs-sticky-root: novfs: Set the sticky bit
  for the novfs mountpoint (bnc#686412).
* Fri Apr 15 2011 jslaby@suse.de
- Update to 2.6.32.37:
  - obsoletes:
  - patches.drivers/alsa-sp1-hda-101-Fix-SPDIF-out-regression-on-ALC889
  - patches.drivers/gro-Reset-dev-pointer-on-reuse.patch
  - patches.drivers/gro-reset-skb_iif-on-reuse.patch
  - patches.drivers/sound-oss-opl3-validate-voice-and-channel-indexes
  - patches.drivers/sound-oss-remove-offset-from-load_patch-callbacks
  - patches.fixes/ax25-fix-information-leak-to-userland.patch
  - patches.fixes/char-tpm-fix-unitialized-usage-of-data-buffer
  - patches.fixes/drivers-misc-ep93xx_pwm-c-world-writable-sysfs-files
  - patches.fixes/drivers-rtc-rtc-ds1511-c-world-writable-sysfs-nvram-file
  - patches.fixes/econet-fix-crash-in-aun_incoming
  - patches.fixes/exec-make-argv-envp-memory-visible-to-oom-killer
  - patches.fixes/inet_diag-fix-bytecode-validation.patch
  - patches.fixes/irda-prevent-integer-underflow-in-irlmp_enumdevices
  - patches.fixes/irda-validate-peer-name-and-attribute-lengths
  - patches.fixes/mfd-ab3100-world-writable-debugfs-_priv-files
  - patches.fixes/packet-fix-information-leak-to-userland.patch
  - patches.fixes/prevent-rt_sigqueueinfo-from-spoofing-fix.patch
  - patches.fixes/rose-prevent-heap-corruption-with-bad-facilities.patch
  - patches.fixes/sctp-fix-to-calc-the-init-init-ack-chunk-length-correctly-is-set
  - patches.fixes/staging-hv-use-sync_bitops.patch
  - patches.fixes/tipc-fix-information-leak-to-userland.patch
  - patches.fixes/xfs-zero-proper-structure-size-for-geometry-calls.patch
  - patches.fixes/xfs_fs_geometry-fix.patch
  - patches.kernel.org/revert-x86-Cleanup-highmap-after-brk-is-concluded.patch
- patches.fixes/btrfs-add-new-defrag-range-ioctl: Refresh.
- patches.fixes/btrfs-create-snapshot-references-in-same-commit-as-snapshot:
  Refresh.
- patches.fixes/econet-fix-locking: Refresh.
- patches.kabi/exec-make-argv-envp-memory-visible-to-oom-killer:
  Refresh.
- patches.suse/staging-hyper-v-added-all-patches-for-hyper-v-same-as-2.6.35-now.patch:
  Refresh.
* Fri Apr 15 2011 hare@suse.de
- patches.fixes/megaraid-sas-kdump-crash-on-dell: modify patch
  to allow ioctl commands, too (bnc#682319).
* Fri Apr 15 2011 sjayaraman@suse.de
- patches.fixes/cifs-ensure-credentials-match-when-using-existing-session:
  cifs: Ensure credentials match when trying to use a existing
  session (bnc#683282).
* Fri Apr 15 2011 jeffm@suse.com
- patches.fixes/char-tpm-fix-unitialized-usage-of-data-buffer:
  char/tpm: Fix unitialized usage of data buffer (bnc#680040
  CVE-2011-1160).
* Thu Apr 14 2011 jeffm@suse.com
- patches.fixes/fs-partitions-efi-c-corrupted-guid-partition-tables-can-cause-kernel-oops:
  fs/partitions/efi.c: corrupted GUID partition tables can cause
  kernel oops (bnc#687113 CVE-2011-1577).
* Thu Apr 14 2011 jbohac@suse.cz
- patches.fixes/ipv4-fix-route-deletion-for-IPs-on-many-subnets.patch:
  ipv4: fix route deletion for IPs on many subnets (bnc#668927).
- patches.fixes/ipv4-match-prefsrc-when-deleting-routes.patch:
  ipv4: match prefsrc when deleting routes (bnc#668927).
- patches.fixes/ipv4-remove-the-routes-on-secondary-promotion.patch:
  ipv4: remove the routes on secondary promotion (bnc#668927).
* Thu Apr 14 2011 jeffm@suse.com
- patches.fixes/nat-ftp-fix-broken-conntrack: NAT/FTP: Fix broken
  conntrack (bnc#681639 bnc#466279).
* Thu Apr 14 2011 mhocko@suse.cz
- Following patches deleted because we have
  patches.kabi/vm_area_struct-fix.patch now (bnc#687478)
- patches.kernel.org/revert-guard-page-for-stacks-that-grow-upwards.patch:
  Delete.
- patches.kernel.org/revert-mm-fix-missing-page-table-unmap-for-stack-guard-page-failure-case.patch:
  Delete.
- patches.kernel.org/revert-mm-fix-page-table-unmap-for-stack-guard-page-properly.patch:
  Delete.
- patches.kernel.org/revert-mm-keep-a-guard-page-below-a-grow-down-stack-segment.patch:
  Delete.
- patches.kernel.org/revert-mm-make-stack-guard-page-logic-use-vm_prev-pointer.patch:
  Delete.
- patches.kernel.org/revert-x86-don-t-send-sigbus-for-kernel-page-faults.patch:
  Delete.
- patches.suse/silent-stack-overflow-2.patch: Refreshed due to context
  change
* Thu Apr 14 2011 jeffm@suse.com
- patches.fixes/drivers-misc-ep93xx_pwm-c-world-writable-sysfs-files:
  drivers/misc/ep93xx_pwm.c: world-writable sysfs files
  (bnc#673934).
- patches.fixes/drivers-rtc-rtc-ds1511-c-world-writable-sysfs-nvram-file:
  drivers/rtc/rtc-ds1511.c: world-writable sysfs nvram file
  (bnc#673934).
- patches.fixes/media-video-sn9c102-world-wirtable-sysfs-files:
  video: sn9c102: world-wirtable sysfs files (bnc#673934).
- patches.fixes/mfd-ab3100-world-writable-debugfs-_priv-files:
  mfd: ab3100: world-writable debugfs *_priv files (bnc#673934).
- patches.fixes/scsi-aic94xx-world-writable-sysfs-update_bios-file:
  scsi: aic94xx: world-writable sysfs update_bios file.
- patches.fixes/ubifs-restrict-world-writable-debugfs-files:
  UBIFS: restrict world-writable debugfs files (bnc#673934).
* Wed Apr 13 2011 jeffm@suse.com
- patches.fixes/irda-validate-peer-name-and-attribute-lengths:
  irda: validate peer name and attribute lengths (bnc#681497
  CVE-2011-1180).
* Wed Apr 13 2011 jbeulich@novell.com
- Update EC2 config files (SOFT_WATCHDOG=m, bnc#683569).
* Tue Apr 12 2011 trenn@suse.de
- patches.arch/s390-dasd-force-label.patch: Refresh.
  - > refresh to apply with series2git
* Tue Apr 12 2011 hare@suse.de
- patches.fixes/libsas-dont-issue-commands-to-removed-devices:
  libsas: Don't issue commands to devices that have been
  hot-removed (bnc#668898).
- patches.fixes/libsas-fix-vacant-phy: libsas: fix bug for vacant
  phy (bnc#668895).
- patches.fixes/libsas-strict-wideport-definition: libsas: fix
  definition of wideport, include local sas address (bnc#668896).
* Tue Apr 12 2011 jbeulich@novell.com
- patches.xen/1074-xenbus_conn-type.patch: xenbus: fix type
  inconsistency with xenbus_conn().
- patches.xen/1079-hvm-kdump-reset.patch: kdump pv-on-hvm: reset PV
  devices in crash kernel (bnc#658413).
- patches.xen/xen3-patch-2.6.32.33-34: Linux 2.6.32.34
  (bnc#558740).
- Refresh other Xen patches.
* Mon Apr 11 2011 eich@suse.de
- patches.kabi/drm_device-guard.patch:
  Refresh. The type change to num_crtcs is not required from a secruity point
  of view.
* Mon Apr 11 2011 nfbrown@suse.de
- patches.fixes/nfs-sync-writes: Restore use of stable writes
  for small O_SYNC writes (bnc#667766).
* Sat Apr  9 2011 sjayaraman@suse.de
- patches.suse/SoN-11a-mm-reserve.patch: mm: Add
  mem_reserve_kmem_cache_add helper (bnc#678466).
- patches.suse/SoN-16b-netvm-reserve-inet.patch: netvm: Reduce
  the size of the routing reserves and be careful of dst_alloc()
  (bnc#678466).
- patches.suse/SoN-28a-nfs-alloc-recursions.patch: nfs: Create
  a memory reserve for nfs_page_cache (bnc#678466).
* Fri Apr  8 2011 jdelvare@suse.de
- patches.drivers/intel-patsburg-support.patch: Add Patsburg
  PCH support to SLES11 SP1 (bnc#650545, bnc#663513, FATE#311346,
  FATE#311838).
* Thu Apr  7 2011 mfasheh@suse.com
- patches.fixes/btrfs-return-EXDEV-when-linking-from-different-subvo.patch:
  btrfs: return EXDEV when linking from different subvolumes
  (bnc#679545).
* Thu Apr  7 2011 bphilips@suse.de
- patches.fixes/ipv6-udp-optimise-multicast-reception: ipv6:
  udp: Optimise multicast reception.
- patches.fixes/llc-use-limited-socket-backlog: llc: use limited
  socket backlog (CVE-2010-4251 bnc#655973).
- patches.fixes/net-add-limit-for-socket-backlog: net: add limit
  for socket backlog (CVE-2010-4251 bnc#655973).
- patches.fixes/net-backlog-functions-rename: net: backlog
  functions rename (CVE-2010-4251 bnc#655973).
- patches.fixes/net-sk_add_backlog-take-rmem_alloc-into-account:
  net: sk_add_backlog() take rmem_alloc into account
  (CVE-2010-4251 bnc#655973).
- patches.fixes/sctp-use-limited-socket-backlog: sctp: use
  limited socket backlog (CVE-2010-4251 bnc#655973).
- patches.fixes/tcp-use-limited-socket-backlog: tcp: use limited
  socket backlog (CVE-2010-4251 bnc#655973).
- patches.fixes/tipc-use-limited-socket-backlog: tipc: use
  limited socket backlog (CVE-2010-4251 bnc#655973).
- patches.fixes/udp-multicast-rx-should-increment-snmp-sk_drops-counter-in-allocation-failures:
  udp: multicast RX should increment SNMP/sk_drops counter in
  allocation failures.
- patches.fixes/udp-use-limited-socket-backlog: udp: use limited
  socket backlog (CVE-2010-4251 bnc#655973).
- patches.fixes/x25-use-limited-socket-backlog: x25: use limited
  socket backlog (CVE-2010-4251 bnc#655973).
- patches.kabi/sock-kabi-fixup-for-adding-sk_backlog.len.patch:
  sock: kabi fixup for adding sk_backlog.len (bnc#655973).
- patches.suse/SoN-22-netvm.patch: Refresh from kabi changes above.
* Thu Apr  7 2011 jkosina@suse.cz
- patches.fixes/staging-hv-use-sync_bitops.patch: staging: hv: use
  sync_bitops when interacting with the hypervisor (bnc#675963).
* Wed Apr  6 2011 jslaby@suse.de
- patches.kernel.org/revert-x86-Cleanup-highmap-after-brk-is-concluded.patch:
  Update references (bnc#684248).
* Wed Apr  6 2011 jslaby@suse.de
- patches.kabi/vm_area_struct-fix.patch: Update references
  (bnc#676419).
* Wed Apr  6 2011 jslaby@suse.de
- patches.fixes/acpi-fix-build-when-config_acpi_custom_override_initramfs-is-not-defined:
  Delete.
- patches.fixes/dlm-always-use-GFP_NOFS.patch: Delete.
  They are unreferenced and superseded by a newer patch or
  stable update respectively. There are 3 more OCFS2 patches to
  sort out.
* Wed Apr  6 2011 jslaby@suse.de
- patches.kabi/vm_area_struct-fix.patch: MM: guard struct
  vm_area_struct kABI changes.
- patches.suse/reiser4-set_page_dirty_notag: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
- patches.fixes/fix-guard-page-revert-side-effect.patch: Delete.
- patches.kabi/revert-mm-Move-vma_stack_continue-into-mm.h.patch:
  Delete.
- patches.kabi/revert-mm-make-the-mlock-stack-guard-page-checks-stricter.patch:
  Delete.
- patches.kabi/revert-mm-make-the-vma-list-be-doubly-linked.patch:
  Delete.
* Mon Apr  4 2011 eich@suse.de
- patches.fixes/drm-radeon-kms-check-AA-resolve-registers-on-r300.patch:
  drm/radeon/kms: check AA resolve registers on r300 (bnc#674693).
  (CVE-2011-1016).
* Fri Apr  1 2011 jslaby@suse.de
- patches.kernel.org/revert-x86-Cleanup-highmap-after-brk-is-concluded.patch:
  Revert "x86: Cleanup highmap after brk is concluded".
- patches.suse/memory-hotplug-Define-memory_block_size_bytes-for-x86_64-with-CONFIG_X86_UV.patch:
  Refresh.
* Fri Apr  1 2011 jbohac@suse.cz
- patches.fixes/rose-add-length-checks-to-CALL_REQUEST-parsing.patch:
  rose: Add length checks to CALL_REQUEST parsing (bnc#681175).
- patches.fixes/rose-prevent-heap-corruption-with-bad-facilities.patch:
  ROSE: prevent heap corruption with bad facilities (bnc#681175).
* Fri Apr  1 2011 mmarek@suse.cz
- patches.kabi/kabi-fix-xfs-interfaces-with-bulkstat: Fix one more
  caller.
* Fri Apr  1 2011 mmarek@suse.cz
- Update kabi files for xfs.
* Fri Apr  1 2011 sjayaraman@suse.de
- revert the last commit as it seems to break kABI.
- patches.suse/SoN-11a-mm-reserve.patch: Delete.
- patches.suse/SoN-16b-netvm-reserve-inet.patch: Delete.
- patches.suse/SoN-28a-nfs-alloc-recursions.patch: Delete.
* Fri Apr  1 2011 sjayaraman@suse.de
- patches.suse/SoN-11a-mm-reserve.patch: mm: Add
  mem_reserve_kmem_cache_add helper (bnc#678466).
- patches.suse/SoN-16b-netvm-reserve-inet.patch: netvm: Reduce
  the size of the routing reserves and be careful of dst_alloc()
  (bnc#678466).
- patches.suse/SoN-28a-nfs-alloc-recursions.patch: nfs: Create
  a memory reserve for nfs_page_cache (bnc#678466).
* Thu Mar 31 2011 agraf@suse.de
- patches.arch/s390-dasd-force-label.patch: s390x: Add force
  flag for dasd style partition label detection (bnc#684085).
* Wed Mar 30 2011 tiwai@suse.de
- patches.drivers/alsa-usb-remove-trailing-spaces: ALSA: usb -
  Remove trailing spaces from USB card name strings (bnc#677563).
* Wed Mar 30 2011 jeffm@suse.de
- patches.kabi/kabi-fix-xfs-interfaces-with-bulkstat: KABI:
  Fix XFS interfaces with bulkstat (bnc#632317).
* Wed Mar 30 2011 jbohac@suse.cz
- patches.fixes/ipsec-fix-bogus-bundle-flowi.patch: ipsec:
  Fix bogus bundle flowi (bnc#680845).
- patches.fixes/ipv4-check-rt_genid-in-dst_check.patch: ipv4:
  check rt_genid in dst_check (bnc#680845).
* Wed Mar 30 2011 jslaby@suse.de
- patches.fixes/prevent-rt_sigqueueinfo-from-spoofing-fix.patch:
  Relax si_code check in rt_sigqueueinfo and rt_tgsigqueueinfo
  (bnc#681826).
* Tue Mar 29 2011 bphilips@suse.de
- patches.drivers/gro-reset-skb_iif-on-reuse.patch: gro: reset
  skb_iif on reuse (bnc#682965, CVE-2011-1478).
* Tue Mar 29 2011 knikanth@suse.de
- patches.suse/dm-stripe-implement-merge-method: dm stripe:
  implement merge method (bnc#663313).
* Tue Mar 29 2011 hare@suse.de
- patches.fixes/fcoe-use_vlan_id-parameter: Set default value
  to 0 (bnc#620929).
* Tue Mar 29 2011 knikanth@suse.de
- patches.suse/lock_page_speedup_avoid_sync.patch: __lock_pages()
  speedup (bnc#629170).
* Tue Mar 29 2011 bphilips@suse.de
- patches.drivers/gro-Reset-dev-pointer-on-reuse.patch: gro:
  Reset dev pointer on reuse (bnc#682965, CVE-2011-1478).
* Mon Mar 28 2011 duwe@suse.de
- patches.arch/ppc-correct-ccrbit-for-syscall-error: powerpc:
  Use correct ccr bit for syscall error status (bnc#682940).
- patches.arch/ppc-no_BUG_ON-dumping-exiting-thread:
  powerpc/ptrace: Remove BUG_ON when full register set not
  available (bnc#682941).
* Mon Mar 28 2011 mszeredi@suse.cz
- patches.fixes/osf-partition-table-fix.patch: Fix corrupted
  OSF partition table parsing (bnc#679812).
* Mon Mar 28 2011 jslaby@suse.de
- Update to 2.6.32.36:
  - obsoletes:
  - patches.fixes/dcdbas-smiread.patch
  - patches.fixes/prevent-rt_sigqueueinfo-from-spoofing.patch
- patches.suse/kdb-usb-rework: Refresh.
- patches.suse/memory-hotplug-Define-memory_block_size_bytes-for-x86_64-with-CONFIG_X86_UV.patch:
  Refresh.
* Sun Mar 27 2011 sjayaraman@suse.de
- patches.fixes/knfsd4-fix-share-mode-perms: nfsd4: fix share
  mode permissions (bnc#566768).
* Fri Mar 25 2011 sjayaraman@suse.de
- patches.fixes/nfs-fix-hangs-over-tcp-due-to-packet-loss: SUNRPC:
  fix NFS client over TCP hangs due to packet loss (bnc#669058).
* Fri Mar 25 2011 mhocko@suse.cz
- patches.fixes/page_cgroup-reduce-allocation-overhead.patch:
  page_cgroup: reduce allocation overhead for page_cgroup array
  for CONFIG_SPARSEMEM (bnc#669889).
* Fri Mar 25 2011 jslaby@suse.de
- patches.kernel.org/patch-2.6.32.33-34: Update references
  (bnc#558740).
* Thu Mar 24 2011 bphilips@suse.de
- patches.drivers/ixgbe-work-around-for-DDP-last-buffer-size.patch:
  ixgbe: work around for DDP last buffer size (bnc#682333).
* Thu Mar 24 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-101-Fix-SPDIF-out-regression-on-ALC889:
  ALSA: hda - Fix SPDIF out regression on ALC889 (bnc#679588).
* Thu Mar 24 2011 tonyj@suse.de
- patches.fixes/audit-filter-rules-cred-perf.patch: audit:
  audit_filter_rules direct cred access (bnc#670979).
* Thu Mar 24 2011 jslaby@suse.de
- Update to 2.6.32.35:
  - obsoletes:
  - patches.rpmify/revert-perf-Handle-stopped-state-with-tracepoints.patch
* Thu Mar 24 2011 jslaby@suse.de
- patches.fixes/prevent-rt_sigqueueinfo-from-spoofing.patch:
  Prevent rt_sigqueueinfo and rt_tgsigqueueinfo from spoofing
  the signal code (bnc#681826 CVE-2011-1182).
* Thu Mar 24 2011 tiwai@suse.de
- patches.drivers/sound-oss-opl3-validate-voice-and-channel-indexes:
  sound/oss/opl3: validate voice and channel indexes (bnc#681999).
- patches.drivers/sound-oss-remove-offset-from-load_patch-callbacks:
  sound/oss: remove offset from load_patch callbacks (bnc#681999).
- kabi/severities: Ignore OSS kABI
* Thu Mar 24 2011 jack@suse.cz
- patches.fixes/xfs-zero-proper-structure-size-for-geometry-calls.patch:
  xfs: zero proper structure size for geometry calls (bnc#672505).
* Thu Mar 24 2011 jslaby@suse.de
- Update to 2.6.32.34:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/ppc64-kdump-unrace
  - patches.drivers/PCI-remove-quirk-for-pre-production-systems.patch
  - patches.fixes/isdn-avoid-calling-tty_ldisc_flush.patch
  - patches.fixes/smp-smp_call_function_many-fix-list-delete-vs-add-race
  - patches.fixes/smp-smp_call_function_many-handle-concurrent-clearing-of-mask
- patches.rpmify/revert-perf-Handle-stopped-state-with-tracepoints.patch:
  Revert "perf: Handle stopped state with tracepoints".
- patches.kabi/paca_struct-guard.patch: PPC: guard struct
  paca_struct kABI changes.
* Thu Mar 24 2011 nfbrown@suse.de
- patches.fixes/xfs-force-when-pinned: XFS: force log before
  waiting for a pinned buffer (bnc#649473).
* Thu Mar 24 2011 rjw@suse.de
- patches.arch/x86-uv-Initialize-the-broadcast-assist-unit-base-destination-node-id-properly.patch:
  x86, UV: Initialize the broadcast assist unit base destination
  node id properly (bnc#677783).
* Wed Mar 23 2011 nfbrown@suse.de
- patches.fixes/nfs4-acl-pages.fix: nfs4: Ensure that ACL
  pages sent over NFS were not allocated from the slab (v3)
  (bnc#677286).
* Fri Mar 18 2011 jbohac@suse.cz
- patches.fixes/inet_diag-fix-bytecode-validation.patch:
  inet_diag: Make sure we actually run the same bytecode we
  audited (bnc#651599, CVE-2010-3880).
* Thu Mar 17 2011 jdelvare@suse.de
- patches.fixes/bonding-802.3ad-fix-state-machine-locking.patch:
  bonding 802.3ad: Fix the state machine locking (bnc#672453).
* Thu Mar 17 2011 duwe@suse.de
- patches.arch/ppc-pseries-disable-msi-new-interface:
  powerpc/pseries: Disable MSI using new interface if possible
  (bnc#677398).
* Thu Mar 17 2011 duwe@suse.de
- patches.drivers/eeh-fix-early-boot-oops: powerpc/eeh: Fix oops
  when probing in early boot (bnc#677391).
- patches.drivers/ipr-bluedarter-readd-race-workaround: ipr:
  Fix a race on multiple configuration changes (bnc#675115).
* Thu Mar 17 2011 knikanth@suse.de
- patches.suse/ldm_validate_partition_table-quiet: Silence
  "ldm_validate_partition_table(): Disk read failed" when booting
  with "quiet" (bnc#656219).
* Wed Mar 16 2011 jack@suse.cz
- patches.fixes/direct-io-move-aio_complete-into-end_io:
  direct-io: move aio_complete into ->end_io (bnc#622597).
- patches.kabi/restore-dio_iodone-symbol-type: Hide kABI change
  caused by a change of prototype of dio_iodone_t (bnc#622597).
- patches.xfs/xfs-cleanup-data-end-io-handlers: xfs: cleanup
  data end I/O handlers (bnc#622597).
- patches.xfs/xfs-move-aio-completion-after-unwritten-extent-conversion:
  xfs: move aio completion after unwritten extent conversion
  (bnc#622597).
* Wed Mar 16 2011 hare@suse.de
- patches.fixes/scsi-dh-rdac-add-sun: scsi_dh_rdac : Add new
  SUN controllers (bnc#660507).
* Tue Mar 15 2011 jslaby@suse.de
- Update to 2.6.32.33:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.drivers/ixgbe-fix-for-82599-erratum-on-Header-Splitting.patch
- patches.arch/ppc64-kdump-unrace: Refresh.
* Fri Mar 11 2011 hare@suse.de
- patches.drivers/qla2xxx-use-spinlock_irqsave: qla2xxx: Path
  fails to recover after microcode update (bnc#654169).
* Fri Mar 11 2011 hare@suse.de
- patches.fixes/megaraid-sas-kdump-crash-on-dell: Fixup
  patch to apply.
* Fri Mar 11 2011 hare@suse.de
- patches.fixes/megaraid-sas-kdump-crash-on-dell: Rearrange
  to apply at right position (bnc#622868).
* Thu Mar 10 2011 jbohac@suse.cz
- patches.suse/allow_bonding_with_blacklisted_ipv6.patch: fix KABI
* Thu Mar 10 2011 jbohac@suse.cz
- patches.suse/allow_bonding_with_blacklisted_ipv6.patch: remove
  the semaphore which caused bnc#678531 and was not needed, because
  it only protected against the removal of the ipv6 module; ipv6
  can not be removed anyway once loaded
* Thu Mar 10 2011 jjolly@suse.de
- patches.drivers/ib-core-pre-mra-xmit-lap-state-check.patch:
  IB/cm: Check LAP state before sending an MRA
  (bnc#673516,LTC#69958).
* Thu Mar 10 2011 bphilips@suse.de
- patches.drivers/PCI-remove-quirk-for-pre-production-systems.patch:
  PCI: remove quirk for pre-production systems (bnc#656587).
* Tue Mar  8 2011 jbeulich@novell.com
- Update Xen patches to 2.6.32.31.
- patches.xen/1069-blktap-misc.patch: blktap: a small fix and assorted
  cleanup.
- patches.xen/1070-pciback-reset-msi.patch: pciback: disable MSI/MSI-X
  when resetting device (bnc#670615).
- patches.xen/xen-cxgb3: apply xen specific patch to the Chelsio
  ethernet drivers.
- Refresh other Xen patches.
* Tue Mar  8 2011 jslaby@suse.de
- Update to 2.6.32.32
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.drivers/netxen-8f9b3f-to-c651a8.patch (one hunk)
  - patches.drivers/usb-iowarrior-don-t-trust-report_size-for-buffer-siz.patch
  - patches.fixes/fuse-fix-fuseblk-hang.patch
  - patches.fixes/sctp-fix-oops-when-sending-queued-asconf-chunks
- kabi fixes:
  - patches.kabi/drm_device-guard.patch: DRM: guard struct
    drm_device kABI changes.
* Tue Mar  8 2011 bphilips@suse.de
- patches.drivers/ixgbe-fix-panic-due-to-uninitialised-pointer.patch:
  ixgbe: fix panic due to uninitialised pointer.
* Tue Mar  8 2011 bphilips@suse.de
- patches.drivers/ixgbe-add-1g-PHY-support-for-82599.patch:
  ixgbe: add 1g PHY support for 82599 (bnc#644630).
- patches.drivers/ixgbe-add-support-for-active-DA-cables.patch:
  ixgbe: add support for active DA cables (bnc#644630).
- patches.drivers/ixgbe-cleanup-race-conditions-in-link-setup.patch:
  ixgbe: cleanup race conditions in link setup (bnc644630).
- patches.drivers/ixgbe-fix-for-link-failure-on-SFP-DA-cables.patch:
  ixgbe: fix for link failure on SFP+ DA cables (bnc#644630).
* Fri Mar  4 2011 rjw@suse.de
- patches.arch/ACPI-ACPICA-Fix-global-lock-acquisition.patch:
  ACPI / ACPICA: Fix global lock acquisition (bnc#637377).
* Fri Mar  4 2011 bphilips@suse.de
- patches.drivers/usb-iowarrior-don-t-trust-report_size-for-buffer-siz.patch:
  usb: iowarrior: don't trust report_size for buffer size
  (bnc#666842 CVE-2010-4656).
* Fri Mar  4 2011 mgalbraith@suse.de
- Ensure that max_level is >= 1 when used, as in mainline.
- patches.fixes/af_unix-limit-recursion-level: Refresh.
* Fri Mar  4 2011 jack@suse.cz
- patches.fixes/debugfs_remove_corruption.diff: debugfs: Fix
  filesystem reference counting on debugfs_remove() failure
  (bnc#668101).
* Fri Mar  4 2011 knikanth@suse.de
- patches.suse/memory-hotplug-Define-memory_block_size_bytes-for-x86_64-with-CONFIG_X86_UV.patch:
  Refresh. Add missing chunk (bnc#643266).
* Thu Mar  3 2011 gregkh@suse.de
- Update to 2.6.32.31
  - obsoletes:
  - patches.rpmify/swiotlb-build-fix.patch: Delete.
* Thu Mar  3 2011 hare@suse.de
- patches.drivers/lpfc-8.3.5.8.2p-update: Fix panic in
  lpfc_scsi_cmd_iocb_cmpl (bnc#671943).
* Thu Mar  3 2011 jslaby@suse.de
- Update to 2.6.32.30:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/hpet_do_not_register_if_arat.patch
  - patches.arch/s390-remove-task_show_regs.patch
  - patches.drivers/alsa-01-caiaq-Fix-possible-string-buffer-overflow
  - patches.drivers/ixgbe-add-support-for-82599-ba
  - patches.drivers/ixgbe-prevent-speculative-processing-of-descriptors.patch
  - patches.fixes/cred-fix-get_task_cred-and-task_state-to-not-resurrect-dead-credentials
  - patches.fixes/filter-make-sure-filters-dont-read-uninitialized-memory
  - patches.fixes/fix-pktcdvd-ioctl-dev_minor-range-check
  - patches.fixes/isdn-hisax-replace-access-to-irq-stats.patch
  - patches.fixes/media-v3-media-av7110-check-for-negative-array-offse.patch
  - patches.fixes/ocfs2_connection_find-returns-pointer-to-bad-structu.patch
  - patches.fixes/sctp-fix-bounds-checking-in-sctp_asoc_get_hmac.patch
  - patches.fixes/tcp-increase-tcp_maxseg-socket-option-minimum
  - patches.fixes/xfs-always-use-iget-in-bulkstat
  - patches.fixes/xfs-remove-block-number-from-inode-lookup-code
  - patches.fixes/xfs-rename-xfs_iget_bulkstat-to-xfs_iget_untrusted
  - patches.fixes/xfs-validate-untrusted-inode-numbers-during-lookup
- kabi fixes:
  - patches.kabi/hisax-IsdnCardState-guard.patch
- patches.rpmify/swiotlb-build-fix.patch: Fix compilation error
  introduced in 484d82b6.
- patches.drivers/acer_wmi_hotkey_events_support.patch: Refresh.
- patches.drivers/acer_wmi_launch_manager_mode.patch: Refresh.
- patches.drivers/benet-from-v2.6.32-to-8f47afe0.patch: Refresh.
- patches.drivers/mpt-fusion-4.22.00.00-update: Refresh.
- patches.fixes/epoll-fix-max_user_watches-overflow.patch:
  Refresh.
- patches.fixes/net-optimize-berkeley-packet-filter-bpf-processing:
  Refresh.
- patches.fixes/scsi-add-tgps-setting: Refresh.
- patches.fixes/xfs-always-use-iget-in-bulkstat-dmapi: Refresh.
- patches.suse/xfs-dmapi-xfs-enable: Refresh.
- patches.xen/xen-x86-no-lapic: Refresh.
- patches.xen/xen3-patch-2.6.19: Refresh.
- patches.xfs/xfs-remove-incorrect-sparse-annotation-for-xfs_iget_.patch:
  Refresh.
* Wed Mar  2 2011 mhocko@suse.cz
- patches.fixes/media-v3-media-av7110-check-for-negative-array-offse.patch:
  [media] [v3,media] av7110: check for negative array offset
  (bnc#666836, CVE-2011-0521).
* Wed Mar  2 2011 jkosina@suse.cz
- patches.fixes/dcdbas-smiread.patch: dcdbas: force SMI to happen
  when expected (bnc#669571).
- patches.xen/xen-dcdbas: Refresh.
* Mon Feb 28 2011 bphilips@suse.de
- patches.drivers/cnic-fix-big-endian-bug.patch: cnic: Fix big
  endian bug (bnc#670154).
* Mon Feb 28 2011 jjolly@suse.de
- patches.arch/s390-27-01-qeth-mac-in-message.patch: qeth: wrong
  MAC-address displayed in error message (bnc#671296,LTC#69730).
- patches.arch/s390-27-02-dasd-unresumed-devices-panic.patch:
  dasd: prevent panic with unresumed devices
  (bnc#671296,LTC#69816).
- patches.arch/s390-27-03-qeth-chpath-change.patch: qeth: allow
  channel path changes in suspend state (bnc#671296,LTC#70033).
- patches.arch/s390-27-04-qeth-no-ipa-in-offline.patch: qeth:
  remove needless IPA-commands in offline (bnc#671296,LTC#70055).
- patches.arch/s390-27-05-tape-system-wq-deadlock.patch: tape:
  deadlock on global work queue (bnc#671296,LTC#70202).
* Mon Feb 28 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Add annotations to
  lib/rwsem_64.S.
* Mon Feb 28 2011 hare@suse.de
- patches.fixes/fcoe-fix-broken-fcoe-interface: fcoe: fix broken
  fcoe interface reset (bnc#674549).
- patches.fixes/libfc-dereferencing-err_ptr-in: libfc:
  dereferencing ERR_PTR in fc_tm_done() (bnc#674549).
- patches.fixes/libfc-fixing-a-memory-leak: libfc: Fixing a
  memory leak when destroying an interface (bnc#674549).
- patches.fixes/libfc-fix-exchange-being-deleted-when-the-abort-its:
  Delete (bnc#674549).
* Fri Feb 25 2011 mgalbraith@suse.de
- Fix backport error.
- patches.fixes/af_unix-limit-recursion-level: Refresh.
* Thu Feb 24 2011 tiwai@suse.de
- patches.drivers/alsa-usb-fix-oops-at-disconnection: ALSA:
  usb-audio: fix oops due to cleanup race when disconnecting
  (bnc#674735).
* Thu Feb 24 2011 rjw@suse.de
- patches.arch/x86-uv-early-boot-bitmap-fix.patch: x86 / UV:
  Early boot bitmap fix (bnc#657248).
* Thu Feb 24 2011 knikanth@suse.de
  Enable the following patches for bnc#643266.
- patches.suse/driver-core-Add-mutex-for-adding-removing-memory-blocks.patch:
  Driver core: Add mutex for adding/removing memory blocks
  (bnc#643266).
- patches.suse/driver-core-Add-section-count-to-memory_block-struct.patch:
  Driver core: Add section count to memory_block struct
  (bnc#643266).
- patches.suse/driver-core-Move-find_memory_block-routine.patch:
  Driver core: Move find_memory_block routine (bnc#643266).
- patches.suse/memory-hotplug-Allow-memory-blocks-to-span-multiple-memory-sections.patch:
  memory hotplug: Allow memory blocks to span multiple memory
  sections (bnc#643266).
- patches.suse/memory-hotplug-Define-memory_block_size_bytes-for-powerpc-pseries.patch:
  memory hotplug: Define memory_block_size_bytes for
  powerpc/pseries (bnc#643266).
- patches.suse/memory-hotplug-Define-memory_block_size_bytes-for-x86_64-with-CONFIG_X86_UV.patch:
  memory hotplug: Define memory_block_size_bytes for x86_64 with
  CONFIG_X86_UV (bnc#643266).
- patches.suse/memory-hotplug-Update-phys_index-to-start-end-section_nr.patch:
  memory hotplug: Update phys_index to [start|end]_section_nr
  (bnc#643266).
- patches.suse/memory-hotplug-sysfs-probe-routine-should-add-all-memory-sections.patch:
  memory hotplug: sysfs probe routine should add all memory
  sections (bnc#643266).
* Wed Feb 23 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove unused code.
* Wed Feb 23 2011 jbohac@suse.cz
- patches.fixes/ax25-fix-information-leak-to-userland.patch:
  net: ax25: fix information leak to userland (bnc#650897,
  CVE-2010-3875).
- patches.fixes/packet-fix-information-leak-to-userland.patch:
  net: packet: fix information leak to userland (bnc#650897,
  CVE-2010-3876).
- patches.fixes/tipc-fix-information-leak-to-userland.patch:
  net: tipc: fix information leak to userland (bnc#650897,
  CVE-2010-3877).
* Wed Feb 23 2011 jbohac@suse.cz
- patches.arch/crypto-sha-s390-reset-index-after-processing-partial-block.patch:
  crypto: sha-s390 - Reset index after processing partial block
  (bnc#470671).
* Wed Feb 23 2011 knikanth@suse.de
  Disable the following patches:
- patches.suse/driver-core-Add-mutex-for-adding-removing-memory-blocks.patch:
  Driver core: Add mutex for adding/removing memory blocks
  (bnc#643266).
- patches.suse/driver-core-Add-section-count-to-memory_block-struct.patch:
  Driver core: Add section count to memory_block struct
  (bnc#643266).
- patches.suse/driver-core-Move-find_memory_block-routine.patch:
  Driver core: Move find_memory_block routine (bnc#643266).
- patches.suse/memory-hotplug-Allow-memory-blocks-to-span-multiple-memory-sections.patch:
  memory hotplug: Allow memory blocks to span multiple memory
  sections (bnc#643266).
- patches.suse/memory-hotplug-Define-memory_block_size_bytes-for-powerpc-pseries.patch:
  memory hotplug: Define memory_block_size_bytes for
  powerpc/pseries (bnc#643266).
- patches.suse/memory-hotplug-Define-memory_block_size_bytes-for-x86_64-with-CONFIG_X86_UV.patch:
  memory hotplug: Define memory_block_size_bytes for x86_64 with
  CONFIG_X86_UV (bnc#643266).
- patches.suse/memory-hotplug-Update-phys_index-to-start-end-section_nr.patch:
  memory hotplug: Update phys_index to [start|end]_section_nr
  (bnc#643266).
- patches.suse/memory-hotplug-sysfs-probe-routine-should-add-all-memory-sections.patch:
  memory hotplug: sysfs probe routine should add all memory
  sections (bnc#643266).
* Tue Feb 22 2011 jbohac@suse.cz
- patches.fixes/sctp-fix-bounds-checking-in-sctp_asoc_get_hmac.patch:
  sctp: Fix out-of-bounds reading in sctp_asoc_get_hmac()
  (bnc#643513, CVE-2010-3705).
* Tue Feb 22 2011 knikanth@suse.de
- patches.suse/driver-core-Add-mutex-for-adding-removing-memory-blocks.patch:
  Driver core: Add mutex for adding/removing memory blocks
  (bnc#643266).
- patches.suse/driver-core-Add-section-count-to-memory_block-struct.patch:
  Driver core: Add section count to memory_block struct
  (bnc#643266).
- patches.suse/driver-core-Move-find_memory_block-routine.patch:
  Driver core: Move find_memory_block routine (bnc#643266).
- patches.suse/memory-hotplug-Allow-memory-blocks-to-span-multiple-memory-sections.patch:
  memory hotplug: Allow memory blocks to span multiple memory
  sections (bnc#643266).
- patches.suse/memory-hotplug-Define-memory_block_size_bytes-for-powerpc-pseries.patch:
  memory hotplug: Define memory_block_size_bytes for
  powerpc/pseries (bnc#643266).
- patches.suse/memory-hotplug-Define-memory_block_size_bytes-for-x86_64-with-CONFIG_X86_UV.patch:
  memory hotplug: Define memory_block_size_bytes for x86_64 with
  CONFIG_X86_UV (bnc#643266).
- patches.suse/memory-hotplug-Update-phys_index-to-start-end-section_nr.patch:
  memory hotplug: Update phys_index to [start|end]_section_nr
  (bnc#643266).
- patches.suse/memory-hotplug-sysfs-probe-routine-should-add-all-memory-sections.patch:
  memory hotplug: sysfs probe routine should add all memory
  sections (bnc#643266).
* Tue Feb 22 2011 mszeredi@suse.cz
- patches.fixes/xfs_fs_geometry-fix.patch: xfs: prevent leaking
  uninitialized stack memory in FSGEOMETRY_V1 (CVE-2011-0711
  bnc#672524).
* Tue Feb 22 2011 hare@suse.de
- patches.fixes/megaraid-sas-kdump-crash-on-dell: megaraid_sas:
  kdump hangs on dell 2900 (bnc#622868).
* Tue Feb 22 2011 mgalbraith@suse.de
- Added bnc#670129 cases to hopefully (and seemingly) now obsolete safety net
- patches.fixes/sched-divide-by-zero-workaround-and-diag.diff:
  Refresh.
* Mon Feb 21 2011 mgalbraith@suse.de
- patches.fixes/af_unix-limit-recursion-level:
  af_unix: limit recursion level (bnc#658037).
- patches.fixes/smp-consolidate-writes-in-smp_call_function_interrupt:
  kernel/smp.c: consolidate writes in smp_call_function_interrupt() (bnc#658037, bnc#636435, bnc#665663).
- patches.fixes/smp-generic_smp_call_function_interrupt-additional-memory-order-tightening:
  smp_call_function: additional memory-order tightening (bnc#658037, bnc#636435, bnc#665663).
- patches.fixes/smp-smp_call_function_many-fix-list-delete-vs-add-race:
  call_function_many: fix list delete vs add race (bnc#658037, bnc#636435, bnc#665663).
- patches.fixes/smp-smp_call_function_many-handle-concurrent-clearing-of-mask:
  smp_call_function_many: handle concurrent clearing of mask (bnc#658037, bnc#636435, bnc#665663).
* Mon Feb 21 2011 tiwai@suse.de
- patches.drivers/alsa-01-caiaq-Fix-possible-string-buffer-overflow:
  ALSA: caiaq - Fix possible string-buffer overflow (bnc#672499,
  CVE-2011-0712).
* Sat Feb 19 2011 gregkh@suse.de
- patches.arch/s390-remove-task_show_regs.patch: s390: remove
  task_show_regs - CVE-2011-0710 (bnc#672492).
* Fri Feb 18 2011 mhocko@suse.cz
- patches.fixes/mm-clear-pages_scanned-only-if-draining-a-pcp-adds-p.patch:
  mm: clear pages_scanned only if draining a pcp adds pages to
  the buddy allocator (bnc#672292).
* Fri Feb 18 2011 jslaby@suse.de
- Update to 2.6.32.29:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/s390-08-05-hvc-iucv-alloc-dma.patch
  - patches.arch/s390-09-01-vdso-version.patch
  - patches.arch/x86-mtrr-avoid-MTRR-reprogramming-on-BP-during-boot-on.patch
  - patches.drivers/alsa-sp1-hda-98-Fix-memory-leaks-in-conexant-jack-arrays
  - patches.fixes/calibrate-jiffy-overflow
  - patches.fixes/input-introduce-notimeout-blacklist-for-Dell-Vostro-.patch
  - patches.fixes/sd-set-resid-correctly
  - patches.suse/staging-hv-add-code-to-create-the-device-directory-under-sys-block-hdx.patch
- kabi fixes:
  - patches.kabi/sched_group.patch: sched: guard struct sched_group
    kABI changes.
  - patches.kabi/sched_struct_rq_kABI_guard.patch: Refresh.
- patches.fixes/sched-divide-by-zero-workaround-and-diag.diff:
  Refresh.
- patches.fixes/usb-ehci-amd-periodic-frame-list-table-quirk.patch:
  Refresh.
- patches.kabi/sched_sched_class_kABI_guard.patch: Refresh.
- patches.kernel.org/patch-2.6.32.28-29: Linux 2.6.32.29.
- patches.suse/SoN-07-mm-PF_MEMALLOC-softirq.patch: Refresh.
- patches.suse/dm-mpath-accept-failed-paths: Refresh.
- patches.suse/dm-mpath-disable-abort-queue: Refresh.
- patches.suse/kconfig-automate-kernel-desktop: Refresh.
- patches.suse/rlim-0012-core-use-helpers-for-rlimits.patch:
  Refresh.
- Update config files.
* Fri Feb 18 2011 gregkh@suse.de
- patches.arch/s390-remove-task_show_regs.patch: s390: remove
  task_show_regs.
* Thu Feb 17 2011 jbohac@suse.cz
- patches.fixes/ipv6-implement-any-ip-support.patch: Implement
  Any-IP support for IPv6 (bnc#640850, fate#310839).
* Wed Feb 16 2011 oneukum@suse.de
- patches.fixes/Add_Atheros_AR5BBU12_BT_firmware_supported.patch:
  blacklist another BT device that cannot operate without firmware
  (bnc#670864).
* Mon Feb 14 2011 bphilips@suse.de
- patches.drivers/ixgbe-fix-for-82599-erratum-on-Header-Splitting.patch:
  ixgbe: fix for 82599 erratum on Header Splitting (bnc#671483).
* Sat Feb 12 2011 agraf@suse.de
- patches.arch/s390-kvm-ext-param.patch: S390: take a full byte
  as ext_param indicator (bnc#671274).
- patches.arch/s390-kvm-hotplug.patch: S390: Add virtio hotplug
  add support (bnc#671274).
* Fri Feb 11 2011 oneukum@suse.de
- patches.fixes/0001-btusb-fix-crash-with-quirky-dongles-doing-sound.patch:
  btusb:fix crash with quirky dongles doing sound (bnc#671256).
* Fri Feb 11 2011 hare@suse.de
- patches.fixes/fcoe-use_vlan_id-parameter: Introduce
  'use_vlan_id' to omit using of VLAN ID for WWPN (bnc#620929).
* Fri Feb 11 2011 hare@suse.de
- patches.suse/dm-mpath-fixup-status-output-for-no-paths:
  multipath status output wrong for no priority groups
  (bnc#668545).
* Fri Feb 11 2011 hare@suse.de
- patches.fixes/fcoe-cisco-login-failure: fcoe: drop FCoE LOGO
  in FIP mode (bnc#662800).
* Fri Feb 11 2011 hare@suse.de
- patches.fixes/aacraid-check-scsi_dma_map_return-value: aacraid:
  check for errors in scsi_dma_map() (bnc#663706).
* Thu Feb 10 2011 rgoldwyn@suse.de
- patches.fixes/xfs-make-xfsbufd-less-aggressive.patch: XFS -
  Make xfsbufd less aggressive (bnc#649473).
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add version numbers to SLE11-GA kmp
  obsoletes (bnc#633026).
* Wed Feb  9 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-Fix-missing-CA-initialization-for-HDMI-DP:
  ALSA: hda - Fix missing CA initialization for HDMI/DP
  (bnc#670577).
* Wed Feb  9 2011 hare@suse.de
- patches.fixes/scsi-dh-alua-errorneous-tpg_id-check: Erroneous
  TPG ID check in SCSI ALUA Handler (bnc#665524).
* Wed Feb  9 2011 hare@suse.de
- patches.fixes/sd-set-resid-correctly: fix medium error problems
  which can cause data corruption (bnc#650366).
* Tue Feb  8 2011 bphilips@suse.de
- unmask enic driver update (bnc#638258, fate#311002)
- patches.drivers/enic-Clean-ups.patch: fix bug where pci_enable_device*
  was called twice
* Mon Feb  7 2011 jbohac@suse.cz
- patches.fixes/bonding-allow-arp_ip_targers-on-separate-vlans-to-use-arp-validation.patch:
  Update the patch to fix a regression (bnc#648701, bnc#665480).
* Mon Feb  7 2011 mszeredi@suse.cz
- kabi/severities: Add fuse module to the "PASS" list.  Fuse
  symbols are exclusively exported to cuse, nothing else should ever
  use them.
* Fri Feb  4 2011 mszeredi@suse.cz
- patches.fixes/fuse-fix-fuseblk-hang.patch: Fix hang of single
  threaded fuseblk filesystem (bnc#658337).
* Fri Feb  4 2011 jjolly@suse.de
- patches.arch/s390-26-01-ccwgroup_uevent.patch: ccwgroup:
  udev race condition (bnc#659101,LTC#68723).
- patches.arch/s390-26-02-cio-fix-ccwgroup-use-after-free.patch:
  cio: prevent kernel panic when path to network device is lost
  (bnc#659101,LTC#68729).
- patches.arch/s390-26-03-qdio-siga.patch: qdio: use proper
  QEBSM operand for SIGA-R and SIGA-S (bnc#659101,LTC#68830).
- patches.arch/s390-26-04-nohz-cpu-hotplug.patch: kernel: nohz
  vs cpu hotplug system hang (bnc#659101,LTC#68888).
- patches.arch/s390-26-05-qeth_recovery_wait_in_open.patch:
  qeth: wait for recovery finish in open function
  (bnc#659101,LTC#69037).
- patches.arch/s390-26-06-qeth_osn_online.patch: qeth: fix online
  setting of OSN-devices (bnc#659101,LTC#69071).
- patches.arch/s390-26-07-qdio-shared_ind_race.patch: qdio:
  prevent race for shared indicators (bnc#659101,LTC#69028).
- patches.arch/s390-26-08-uaccess-sacf.patch: uaccess: missing
  sacf in uaccess error handling (bnc#659101,LTC#69124).
* Fri Feb  4 2011 rjw@suse.de
- patches.arch/x86-mtrr-avoid-MTRR-reprogramming-on-BP-during-boot-on.patch:
  x86, mtrr: avoid MTRR reprogramming on BP during boot on
  (bnc#623393).
* Thu Feb  3 2011 mszeredi@suse.cz
- patches.suse/squashfs-3.4.patch: forward port squashfs version 3
  from SLES11 as a new "squashfs3" filesystem (bnc#666893)
- supported.conf: added squashfs3
- Update config files.
* Thu Feb  3 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-100-keep-ABI-for-LSI-modem-driver:
  Keep internal structure of hd-audio for LSI binary-only driver
  (bnc#659394,bnc#655278).
* Thu Feb  3 2011 trenn@suse.de
  Make acpi.ec_delay param writeable
- patches.arch/acpi_ec_delay_param.patch: Refresh.
* Thu Feb  3 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-99-Change-the-AZX_MAX_PCMS-to-10:
  ALSA: hda - Change the AZX_MAX_PCMS to 10
  (bnc#659394,bnc#655278).
* Thu Feb  3 2011 jack@suse.cz
- patches.fixes/ocfs2-mkdir-credits.diff: Correct number of
  credits needed for mkdir (bnc#668633).
* Thu Feb  3 2011 jbohac@suse.cz
- patches.fixes/bonding-minimize-race-window-on-miimon-rearming.patch:
  bonding: minimize race window on miimon rearming (bnc#602969).
* Wed Feb  2 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-98-Fix-memory-leaks-in-conexant-jack-arrays:
  ALSA: hda - Fix memory leaks in conexant jack arrays
  (bnc#668929).
* Wed Feb  2 2011 knikanth@suse.de
- patches.suse/lock_page-speedup.patch: lock_page speedup. Avoid
  atomic bit set, when possible (bnc#629170).
* Wed Feb  2 2011 jbeulich@novell.com
- Update Xen patches to 2.6.32.28.
- Refresh other Xen patches.
* Wed Feb  2 2011 jbeulich@novell.com
- patches.fixes/calibrate-jiffy-overflow: Fix jiffy calculations
  in calibrate_delay_direct to handle overflow.
* Tue Feb  1 2011 jkosina@suse.cz
- patches.suse/kdb-fix-cpumask-usage.patch: KDB: Fix cpumask usage
  (bnc#662360).
* Tue Feb  1 2011 tiwai@suse.de
- patches.drivers/synaptics-hp-new-model.diff: Fix the
  detection of new synaptics touchpad on HP laptops
  (bnc#662212,bnc#663582,bnc#663537,bnc#664463).
* Mon Jan 31 2011 mmarek@suse.de
- Update rest of kabi files for xfs changes.
* Mon Jan 31 2011 jslaby@suse.cz
- Refresh patches.rpmify/cloneconfig.diff.
  scripts/kconfig/conf accepts long parameters only for some time already
* Mon Jan 31 2011 mhocko@suse.de
- patches.fixes/Make-swap-accounting-default-behavior-configurable.patch:
  Make swap accounting default behavior configurable (bnc#650309,
  fate#310471).
* Sat Jan 29 2011 mfasheh@suse.com
- patches.fixes/ocfs2-check-heartbeat-for-kernel-stacks-only.patch:
  ocfs2: Check heartbeat mode for kernel stacks only.
* Fri Jan 28 2011 oneukum@suse.de
- patches.fixes/btusb_ignore_malbec_wo_firmware.patch: Refresh.
  Fixed copy'n'paste error
* Fri Jan 28 2011 jeffm@suse.de
- Update reference module symbol versions: accepted xfs_bulkstat
  (and friends) changes from bnc#632317, CVE-2010-2943.
* Thu Jan 27 2011 mfasheh@suse.com
- patches.suse/ocfs2-kapi-compat.patch: ocfs2: add back ported
  kernel api calls.
* Thu Jan 27 2011 trenn@suse.de
- patches.arch/hpet_do_not_register_if_arat.patch: x86, hpet:
  Disable per-cpu hpet timer if ARAT is supported (bnc#648916).
* Thu Jan 27 2011 rjw@suse.de
- patches.arch/x86-UV-BAU-Extend-for-more-than-16-cpus-per-socket.patch:
  Refresh.
* Thu Jan 27 2011 rjw@suse.de
- patches.arch/x86-UV-Fix-interrupt-targeting-for-GRU-on-westmere.patch:
  x86, UV: Fix interrupt targeting for GRU on Westmere
  (bnc#662340).
* Thu Jan 27 2011 rjw@suse.de
- patches.arch/x86-uv-westmere-acpicid-fix.patch: x86, UV:
  Fix APICID shift for westmere processors (bnc#662335).
* Thu Jan 27 2011 rjw@suse.de
- patches.arch/x86-UV-BAU-Extend-for-more-than-16-cpus-per-socket.patch:
  x86, UV, BAU: Extend for more than 16 cpus per socket.
* Thu Jan 27 2011 mfasheh@suse.com
  Bring in Ocfs2 fixes from 2.6.37
- patches.fixes/Fix-various-typos-of-valid-in-comments.patch:
  Fix various typos of valid in comments.
- patches.fixes/Initialize-max_slots-early.patch: Initialize
  max_slots early.
- patches.fixes/JBD2-Allow-feature-checks-before-journal-recovery.patch:
  JBD2: Allow feature checks before journal recovery.
- patches.fixes/OCFS2-Allow-huge-16-TiB-volumes-to-mount.patch:
  OCFS2: Allow huge (> 16 TiB) volumes to mount.
- patches.fixes/Ocfs2-Add-new-OCFS2_IOC_INFO-ioctl-for-ocfs2-v8.patch:
  Ocfs2: Add new OCFS2_IOC_INFO ioctl for ocfs2 v8.
- patches.fixes/Ocfs2-Stop-tracking-a-negative-dentry-after-dentry_i.patch:
  Ocfs2: Stop tracking a negative dentry after dentry_iput().
- patches.fixes/Ocfs2-Teach-coherency-full-O_DIRECT-writes-to-correc.patch:
  Ocfs2: Teach 'coherency=full' O_DIRECT writes to correctly
  up_read i_alloc_sem.
- patches.fixes/Reorganize-data-elements-to-reduce-struct-sizes.patch:
  Reorganize data elements to reduce struct sizes.
- patches.fixes/Track-negative-entries-v3.patch: Track negative
  entries v3.
- patches.fixes/When-I-tried-to-compile-I-got-the-following-warning.patch:
  When I tried to compile I got the following warning:.
- patches.fixes/fs-ocfs2-dlm-Use-GFP_ATOMIC-under-spin_lock.patch:
  fs/ocfs2/dlm: Use GFP_ATOMIC under spin_lock.
- patches.fixes/ocfs2-Add-a-mount-option-coherency-to-handle-cluster.patch:
  ocfs2: Add a mount option "coherency=*" to handle cluster
  coherency for O_DIRECT writes.
- patches.fixes/ocfs2-Add-an-incompat-feature-flag-OCFS2_FEATURE_INC.patch:
  ocfs2: Add an incompat feature flag
  OCFS2_FEATURE_INCOMPAT_CLUSTERINFO.
- patches.fixes/ocfs2-Add-readahead-support-for-CoW.patch: ocfs2:
  Add readahead support for CoW.
- patches.fixes/ocfs2-Add-readhead-during-CoW.patch: ocfs2:
  Add readhead during CoW.
- patches.fixes/ocfs2-Add-some-trace-log-for-orphan-scan.patch:
  ocfs2: Add some trace log for orphan scan.
- patches.fixes/ocfs2-Add-struct-file-to-ocfs2_refcount_cow.patch:
  ocfs2: Add struct file to ocfs2_refcount_cow.
- patches.fixes/ocfs2-Add-support-for-heartbeat-global-mount-option.patch:
  ocfs2: Add support for heartbeat=global mount option.
- patches.fixes/ocfs2-Adjust-masklog-flag-values.patch: ocfs2:
  Adjust masklog flag values.
- patches.fixes/ocfs2-Avoid-to-evaluate-xattr-block-flags-again.patch:
  ocfs2: Avoid to evaluate xattr block flags again.
- patches.fixes/ocfs2-Cache-system-inodes-of-other-slots.patch:
  ocfs2: Cache system inodes of other slots.
- patches.fixes/ocfs2-Change-some-lock-status-member-in-ocfs2_lock_r.patch:
  ocfs2: Change some lock status member in ocfs2_lock_res to char.
- patches.fixes/ocfs2-Fix-system-inodes-cache-overflow.patch:
  ocfs2: Fix system inodes cache overflow.
- patches.fixes/ocfs2-Hold-ip_lock-when-set-clear-flags-for-indexed-.patch:
  ocfs2: Hold ip_lock when set/clear flags for indexed dir.
- patches.fixes/ocfs2-Initialize-the-bktcnt-variable-properly-and-ca.patch:
  ocfs2: Initialize the bktcnt variable properly, and call
  it bucket_count.
- patches.fixes/ocfs2-Remove-obscure-error-handling-in-direct_write.patch:
  ocfs2: Remove obscure error handling in direct_write.
- patches.fixes/ocfs2-Remove-obsolete-comments-before-ocfs2_start_tr.patch:
  ocfs2: Remove obsolete comments before ocfs2_start_trans.
- patches.fixes/ocfs2-Remove-ocfs2_sync_inode.patch: ocfs2:
  Remove ocfs2_sync_inode().
- patches.fixes/ocfs2-Remove-unused-old_id-in-ocfs2_commit_cache.patch:
  ocfs2: Remove unused old_id in ocfs2_commit_cache.
- patches.fixes/ocfs2-Silence-unused-warning.patch: ocfs2:
  Silence unused warning.
- patches.fixes/ocfs2-char-is-not-always-signed.patch: ocfs2:
  char is not always signed.
- patches.fixes/ocfs2-cluster-Add-heartbeat-mode-configfs-parameter.patch:
  ocfs2/cluster: Add heartbeat mode configfs parameter.
- patches.fixes/ocfs2-cluster-Add-mlogs-for-heartbeat-up-down-events.patch:
  ocfs2/cluster: Add mlogs for heartbeat up/down events.
- patches.fixes/ocfs2-cluster-Bump-up-dlm-protocol-to-version-1.1.patch:
  ocfs2/cluster: Bump up dlm protocol to version 1.1.
- patches.fixes/ocfs2-cluster-Check-slots-for-unconfigured-live-node.patch:
  ocfs2/cluster: Check slots for unconfigured live nodes.
- patches.fixes/ocfs2-cluster-Create-debugfs-dir-files-for-each-regi.patch:
  ocfs2/cluster: Create debugfs dir/files for each region.
- patches.fixes/ocfs2-cluster-Create-debugfs-files-for-live-quorum-a.patch:
  ocfs2/cluster: Create debugfs files for live, quorum and failed
  region bitmaps.
- patches.fixes/ocfs2-cluster-Get-all-heartbeat-regions.patch:
  ocfs2/cluster: Get all heartbeat regions.
- patches.fixes/ocfs2-cluster-Maintain-bitmap-of-failed-regions.patch:
  ocfs2/cluster: Maintain bitmap of failed regions.
- patches.fixes/ocfs2-cluster-Maintain-bitmap-of-quorum-regions.patch:
  ocfs2/cluster: Maintain bitmap of quorum regions.
- patches.fixes/ocfs2-cluster-Maintain-live-node-bitmap-per-heartbea.patch:
  ocfs2/cluster: Maintain live node bitmap per heartbeat region.
- patches.fixes/ocfs2-cluster-Print-messages-when-adding-removing-he.patch:
  ocfs2/cluster: Print messages when adding/removing heartbeat
  regions.
- patches.fixes/ocfs2-cluster-Print-messages-when-adding-removing-no.patch:
  ocfs2/cluster: Print messages when adding/removing nodes.
- patches.fixes/ocfs2-cluster-Release-debugfs-file-elapsed_time_in_m.patch:
  ocfs2/cluster: Release debugfs file elapsed_time_in_ms.
- patches.fixes/ocfs2-cluster-Reorganize-o2hb-debugfs-init.patch:
  ocfs2/cluster: Reorganize o2hb debugfs init.
- patches.fixes/ocfs2-cluster-Show-per-region-heartbeat-elapsed-time.patch:
  ocfs2/cluster: Show per region heartbeat elapsed time.
- patches.fixes/ocfs2-cluster-Track-bitmap-of-live-heartbeat-regions.patch:
  ocfs2/cluster: Track bitmap of live heartbeat regions.
- patches.fixes/ocfs2-cluster-Track-number-of-global-heartbeat-regio.patch:
  ocfs2/cluster: Track number of global heartbeat regions.
- patches.fixes/ocfs2-dlm-Add-message-DLM_QUERY_NODEINFO.patch:
  ocfs2/dlm: Add message DLM_QUERY_NODEINFO.
- patches.fixes/ocfs2-dlm-Add-message-DLM_QUERY_REGION.patch:
  ocfs2/dlm: Add message DLM_QUERY_REGION.
- patches.fixes/ocfs2-dlm-Expose-dlm_protocol-in-dlm_state.patch:
  ocfs2/dlm: Expose dlm_protocol in dlm_state.
- patches.fixes/ocfs2-dlm-Migrate-lockres-with-no-locks-if-it-has-a-.patch:
  ocfs2/dlm: Migrate lockres with no locks if it has a reference.
- patches.fixes/ocfs2-fix-memory-leak.patch: ocfs2: fix memory
  leak.
- patches.fixes/ocfs2-pass-struct-file-to-ocfs2_prepare_inode_for_wr.patch:
  ocfs2: pass struct file* to ocfs2_prepare_inode_for_write.
- patches.fixes/ocfs2-pass-struct-file-to-ocfs2_write_begin_nolock.patch:
  ocfs2: pass struct file* to ocfs2_write_begin_nolock.
- patches.fixes/ocfs2-validate-bg_free_bits_count-after-update.patch:
  ocfs2: validate bg_free_bits_count after update.
- patches.fixes/ocfs2_connection_find-returns-pointer-to-bad-structu.patch:
  ocfs2_connection_find() returns pointer to bad structure.
* Thu Jan 27 2011 mfasheh@suse.com
  Bring in Ocfs2 fixes from 2.6.37
- patches.fixes/Fix-various-typos-of-valid-in-comments.patch:
  Fix various typos of valid in comments.
- patches.fixes/Initialize-max_slots-early.patch: Initialize
  max_slots early.
- patches.fixes/JBD2-Allow-feature-checks-before-journal-recovery.patch:
  JBD2: Allow feature checks before journal recovery.
- patches.fixes/OCFS2-Allow-huge-16-TiB-volumes-to-mount.patch:
  OCFS2: Allow huge (> 16 TiB) volumes to mount.
- patches.fixes/Ocfs2-Add-new-OCFS2_IOC_INFO-ioctl-for-ocfs2-v8.patch:
  Ocfs2: Add new OCFS2_IOC_INFO ioctl for ocfs2 v8.
- patches.fixes/Ocfs2-Stop-tracking-a-negative-dentry-after-dentry_i.patch:
  Ocfs2: Stop tracking a negative dentry after dentry_iput().
- patches.fixes/Ocfs2-Teach-coherency-full-O_DIRECT-writes-to-correc.patch:
  Ocfs2: Teach 'coherency=full' O_DIRECT writes to correctly
  up_read i_alloc_sem.
- patches.fixes/Reorganize-data-elements-to-reduce-struct-sizes.patch:
  Reorganize data elements to reduce struct sizes.
- patches.fixes/Track-negative-entries-v3.patch: Track negative
  entries v3.
- patches.fixes/When-I-tried-to-compile-I-got-the-following-warning.patch:
  When I tried to compile I got the following warning:.
- patches.fixes/fs-ocfs2-dlm-Use-GFP_ATOMIC-under-spin_lock.patch:
  fs/ocfs2/dlm: Use GFP_ATOMIC under spin_lock.
- patches.fixes/ocfs2-Add-a-mount-option-coherency-to-handle-cluster.patch:
  ocfs2: Add a mount option "coherency=*" to handle cluster
  coherency for O_DIRECT writes.
- patches.fixes/ocfs2-Add-an-incompat-feature-flag-OCFS2_FEATURE_INC.patch:
  ocfs2: Add an incompat feature flag
  OCFS2_FEATURE_INCOMPAT_CLUSTERINFO.
- patches.fixes/ocfs2-Add-readahead-support-for-CoW.patch: ocfs2:
  Add readahead support for CoW.
- patches.fixes/ocfs2-Add-readhead-during-CoW.patch: ocfs2:
  Add readhead during CoW.
- patches.fixes/ocfs2-Add-some-trace-log-for-orphan-scan.patch:
  ocfs2: Add some trace log for orphan scan.
- patches.fixes/ocfs2-Add-struct-file-to-ocfs2_refcount_cow.patch:
  ocfs2: Add struct file to ocfs2_refcount_cow.
- patches.fixes/ocfs2-Add-support-for-heartbeat-global-mount-option.patch:
  ocfs2: Add support for heartbeat=global mount option.
- patches.fixes/ocfs2-Adjust-masklog-flag-values.patch: ocfs2:
  Adjust masklog flag values.
- patches.fixes/ocfs2-Avoid-to-evaluate-xattr-block-flags-again.patch:
  ocfs2: Avoid to evaluate xattr block flags again.
- patches.fixes/ocfs2-Cache-system-inodes-of-other-slots.patch:
  ocfs2: Cache system inodes of other slots.
- patches.fixes/ocfs2-Change-some-lock-status-member-in-ocfs2_lock_r.patch:
  ocfs2: Change some lock status member in ocfs2_lock_res to char.
- patches.fixes/ocfs2-Fix-system-inodes-cache-overflow.patch:
  ocfs2: Fix system inodes cache overflow.
- patches.fixes/ocfs2-Hold-ip_lock-when-set-clear-flags-for-indexed-.patch:
  ocfs2: Hold ip_lock when set/clear flags for indexed dir.
- patches.fixes/ocfs2-Initialize-the-bktcnt-variable-properly-and-ca.patch:
  ocfs2: Initialize the bktcnt variable properly, and call
  it bucket_count.
- patches.fixes/ocfs2-Remove-obscure-error-handling-in-direct_write.patch:
  ocfs2: Remove obscure error handling in direct_write.
- patches.fixes/ocfs2-Remove-obsolete-comments-before-ocfs2_start_tr.patch:
  ocfs2: Remove obsolete comments before ocfs2_start_trans.
- patches.fixes/ocfs2-Remove-ocfs2_sync_inode.patch: ocfs2:
  Remove ocfs2_sync_inode().
- patches.fixes/ocfs2-Remove-unused-old_id-in-ocfs2_commit_cache.patch:
  ocfs2: Remove unused old_id in ocfs2_commit_cache.
- patches.fixes/ocfs2-Silence-unused-warning.patch: ocfs2:
  Silence unused warning.
- patches.fixes/ocfs2-char-is-not-always-signed.patch: ocfs2:
  char is not always signed.
- patches.fixes/ocfs2-cluster-Add-heartbeat-mode-configfs-parameter.patch:
  ocfs2/cluster: Add heartbeat mode configfs parameter.
- patches.fixes/ocfs2-cluster-Add-mlogs-for-heartbeat-up-down-events.patch:
  ocfs2/cluster: Add mlogs for heartbeat up/down events.
- patches.fixes/ocfs2-cluster-Bump-up-dlm-protocol-to-version-1.1.patch:
  ocfs2/cluster: Bump up dlm protocol to version 1.1.
- patches.fixes/ocfs2-cluster-Check-slots-for-unconfigured-live-node.patch:
  ocfs2/cluster: Check slots for unconfigured live nodes.
- patches.fixes/ocfs2-cluster-Create-debugfs-dir-files-for-each-regi.patch:
  ocfs2/cluster: Create debugfs dir/files for each region.
- patches.fixes/ocfs2-cluster-Create-debugfs-files-for-live-quorum-a.patch:
  ocfs2/cluster: Create debugfs files for live, quorum and failed
  region bitmaps.
- patches.fixes/ocfs2-cluster-Get-all-heartbeat-regions.patch:
  ocfs2/cluster: Get all heartbeat regions.
- patches.fixes/ocfs2-cluster-Maintain-bitmap-of-failed-regions.patch:
  ocfs2/cluster: Maintain bitmap of failed regions.
- patches.fixes/ocfs2-cluster-Maintain-bitmap-of-quorum-regions.patch:
  ocfs2/cluster: Maintain bitmap of quorum regions.
- patches.fixes/ocfs2-cluster-Maintain-live-node-bitmap-per-heartbea.patch:
  ocfs2/cluster: Maintain live node bitmap per heartbeat region.
- patches.fixes/ocfs2-cluster-Print-messages-when-adding-removing-he.patch:
  ocfs2/cluster: Print messages when adding/removing heartbeat
  regions.
- patches.fixes/ocfs2-cluster-Print-messages-when-adding-removing-no.patch:
  ocfs2/cluster: Print messages when adding/removing nodes.
- patches.fixes/ocfs2-cluster-Release-debugfs-file-elapsed_time_in_m.patch:
  ocfs2/cluster: Release debugfs file elapsed_time_in_ms.
- patches.fixes/ocfs2-cluster-Reorganize-o2hb-debugfs-init.patch:
  ocfs2/cluster: Reorganize o2hb debugfs init.
- patches.fixes/ocfs2-cluster-Show-per-region-heartbeat-elapsed-time.patch:
  ocfs2/cluster: Show per region heartbeat elapsed time.
- patches.fixes/ocfs2-cluster-Track-bitmap-of-live-heartbeat-regions.patch:
  ocfs2/cluster: Track bitmap of live heartbeat regions.
- patches.fixes/ocfs2-cluster-Track-number-of-global-heartbeat-regio.patch:
  ocfs2/cluster: Track number of global heartbeat regions.
- patches.fixes/ocfs2-dlm-Add-message-DLM_QUERY_NODEINFO.patch:
  ocfs2/dlm: Add message DLM_QUERY_NODEINFO.
- patches.fixes/ocfs2-dlm-Add-message-DLM_QUERY_REGION.patch:
  ocfs2/dlm: Add message DLM_QUERY_REGION.
- patches.fixes/ocfs2-dlm-Expose-dlm_protocol-in-dlm_state.patch:
  ocfs2/dlm: Expose dlm_protocol in dlm_state.
- patches.fixes/ocfs2-dlm-Migrate-lockres-with-no-locks-if-it-has-a-.patch:
  ocfs2/dlm: Migrate lockres with no locks if it has a reference.
- patches.fixes/ocfs2-fix-memory-leak.patch: ocfs2: fix memory
  leak.
- patches.fixes/ocfs2-pass-struct-file-to-ocfs2_prepare_inode_for_wr.patch:
  ocfs2: pass struct file* to ocfs2_prepare_inode_for_write.
- patches.fixes/ocfs2-pass-struct-file-to-ocfs2_write_begin_nolock.patch:
  ocfs2: pass struct file* to ocfs2_write_begin_nolock.
- patches.fixes/ocfs2-validate-bg_free_bits_count-after-update.patch:
  ocfs2: validate bg_free_bits_count after update.
- patches.fixes/ocfs2_connection_find-returns-pointer-to-bad-structu.patch:
  ocfs2_connection_find() returns pointer to bad structure.
* Wed Jan 26 2011 oneukum@suse.de
- patches.fixes/btusb_ignore_malbec_wo_firmware.patch: ignore
  BT device before firmware transfer (bnc#658353).
* Tue Jan 25 2011 jeffm@suse.com
- patches.fixes/hfs-avoid-crash-in-hfs_bnode_create: hfs: avoid
  crash in hfs_bnode_create (bnc#552250).
* Tue Jan 25 2011 oneukum@suse.de
- patches.fixes/btusb_atheros3011_ignore.patch: ignore BT device
  before firmware transfer (bnc#658353).
* Mon Jan 24 2011 jeffm@suse.com
- patches.fixes/xfs-always-use-iget-in-bulkstat-dmapi: Build fix on
  - debug flavor.
* Sun Jan 23 2011 jeffm@suse.com
- patches.fixes/netfilter-implement-rfc-1123-for-ftp-conntrack:
  netfilter: Implement RFC 1123 for FTP conntrack (bnc#466279).
* Sat Jan 22 2011 mfasheh@suse.com
- patches.fixes/Ocfs2-Fix-a-regression-bug-from-mainline-commit-6b93.patch:
  Ocfs2: Fix a regression bug from mainline
  commit(6b933c8e6f1a2f3118082c455eef25f9b1ac7b45).
- patches.fixes/Ocfs2-Handle-empty-list-in-lockres_seq_start-for-dlm.patch:
  Ocfs2: Handle empty list in lockres_seq_start() for dlmdebug.c.
- patches.fixes/Ocfs2-Re-access-the-journal-after-ocfs2_insert_exten.patch:
  Ocfs2: Re-access the journal after ocfs2_insert_extent()
  in dxdir codes.
- patches.fixes/o2dlm-force-free-mles-during-dlm-exit.patch:
  o2dlm: force free mles during dlm exit.
- patches.fixes/ocfs2-Fix-lockdep-warning-in-reflink.patch:
  ocfs2: Fix lockdep warning in reflink.
- patches.fixes/ocfs2-Move-wanted-into-parens-of-ocfs2_resmap_resv_b.patch:
  ocfs2: Move 'wanted' into parens of ocfs2_resmap_resv_bits.
- patches.fixes/ocfs2-Sync-inode-flags-with-ext2.patch: ocfs2:
  Sync inode flags with ext2.
- patches.fixes/ocfs2-lockdep-Move-ip_xattr_sem-out-of-ocfs2_xattr_g.patch:
  ocfs2/lockdep: Move ip_xattr_sem out of ocfs2_xattr_get_nolock.
- patches.fixes/ocfs2-net-fix-uninitialized-ret-in-o2net_send_messag.patch:
  ocfs2/net: fix uninitialized ret in o2net_send_message_vec().
- patches.fixes/ocfs2-update-ctime-when-changing-the-file-s-permissi.patch:
  ocfs2: update ctime when changing the file's permission
  by setfacl.
* Fri Jan 21 2011 tiwai@suse.de
- patches.drivers/drm-i915-fix-dpms-at-resume: drm/i915: Fix
  DPMS setups at resume (bnc#664149).
* Thu Jan 20 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-97-fix-initialization-for-hp-bnb-2011:
  ALSA: hda - Fix initialization for HP 2011 notebooks
  (bnc#666012).
* Thu Jan 20 2011 jslaby@suse.de
- patches.fixes/epoll-fix-max_user_watches-overflow.patch: EPOLL:
  fix max_user_watches overflow (bnc#652391).
- patches.fixes/fs-fix-max_files-overflow.patch: FS: fix max_files
  overflow (bnc#652391).
- patches.fixes/mm-alloc_large_system_hash-printk-overflow.patch:
  mm: alloc_large_system_hash() printk overflow on 16TB boot
  (bnc#652391).
* Thu Jan 20 2011 jeffm@suse.com
- patches.fixes/xfs-always-use-iget-in-bulkstat: xfs: always
  use iget in bulkstat (bnc#632317 CVE-2010-2943).
- patches.fixes/xfs-always-use-iget-in-bulkstat-dmapi: xfs:
  always use iget in bulkstat (dmapi).
- patches.fixes/xfs-remove-block-number-from-inode-lookup-code:
  xfs: remove block number from inode lookup code (bnc#632317
  CVE-2010-2943).
- patches.fixes/xfs-remove-block-number-from-inode-lookup-code-dmapi:
  xfs: remove block number from inode lookup code (dmapi).
- patches.fixes/xfs-rename-xfs_iget_bulkstat-to-xfs_iget_untrusted:
  xfs: rename XFS_IGET_BULKSTAT to XFS_IGET_UNTRUSTED (bnc#632317
  CVE-2010-2943).
- patches.fixes/xfs-rename-xfs_iget_bulkstat-to-xfs_iget_untrusted-dmapi:
  xfs: rename XFS_IGET_BULKSTAT to XFS_IGET_UNTRUSTED (dmapi).
- patches.fixes/xfs-validate-untrusted-inode-numbers-during-lookup:
  xfs: validate untrusted inode numbers during lookup (bnc#632317
  CVE-2010-2943).
* Thu Jan 20 2011 jeffm@suse.com
- patches.fixes/serial-fix-reading-uninitialized-stack-memory-issues:
  serial: fix reading uninitialized stack memory issues
  (CVE-2010-4075 CVE-2010-4076 CVE-2010-4077 bnc#642309).
* Thu Jan 20 2011 jeffm@suse.com
- patches.fixes/phonet-some-signedness-bugs: phonet: some
  signedness bugs (bnc#662931).
* Thu Jan 20 2011 hare@suse.de
- patches.fixes/iscsi_tcp-change-to-logical-and.patch: iscsi_tcp:
  change & to && (bnc#658551).
- patches.fixes/iscsi_tcp-fix-relogin-shutdown-hang.patch:
  iscsi_tcp: fix relogin/shutdown hang (bnc#658551).
* Thu Jan 20 2011 hare@suse.de
- patches.fixes/add-POLLPRI-to-sock_def_readable.patch: Fixup
  patch for series2git.
* Wed Jan 19 2011 jeffm@suse.com
- patches.fixes/exec-make-argv-envp-memory-visible-to-oom-killer:
  exec: make argv/envp memory visible to oom-killer (CVE-2010-4243
  bnc#655220).
- patches.kabi/exec-make-argv-envp-memory-visible-to-oom-killer:
  KABI: exec: make argv/envp memory visible to oom-killer.
* Wed Jan 19 2011 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-96-add-quirk-for-hp-z-series:
  ALSA: hda - Add quirk for HP Z-series workstation (bnc#665499).
* Wed Jan 19 2011 jbeulich@novell.com
- patches.arch/ix86-numa-option: ix86: add numa= option to allow
  booting on systems with not understood SRAT (bnc#662673).
* Wed Jan 19 2011 jeffm@suse.com
- patches.fixes/block-check-for-proper-length-of-iov-entries-earlier-in-blk_rq_map_user_iov:
  block: check for proper length of iov entries earlier in
  blk_rq_map_user_iov() (CVE-2010-4668 bnc#662202).
* Tue Jan 18 2011 jeffm@suse.com
- patches.fixes/irda-prevent-integer-underflow-in-irlmp_enumdevices:
  irda: prevent integer underflow in IRLMP_ENUMDEVICES
  (CVE-2010-4529 bnc#662031).
* Tue Jan 18 2011 jeffm@suse.com
- patches.fixes/econet-do-the-correct-cleanup-after-an-unprivileged-siocsifaddr:
  econet: Do the correct cleanup after an unprivileged
  SIOCSIFADDR.
- patches.fixes/econet-fix-crash-in-aun_incoming: econet: Fix
  crash in aun_incoming() (CVE-2010-4342 bnc#658461).
- patches.fixes/econet-fix-locking: econet: fix locking.
* Mon Jan 17 2011 jeffm@suse.com
- patches.fixes/misdn-add-support-for-group-membership-check:
  mISDN: Add support for group membership check (bnc#564423).
* Mon Jan 17 2011 hare@suse.de
- patches.drivers/qla2xxx-clear-local-references-on-dev_loss_tmo:
  qla2xxx: Clear local references of rport on device loss timeout
  notification from FC transport (bnc#651152).
* Fri Jan 14 2011 mgalbraith@suse.de
- Make printks a bit more informative, and close the remote possibility
  that writing a 64 bit value with all low 32 bits zero to the 32 bit
  sched_group->cpu_power could end up setting it to zero.
- patches.fixes/sched-divide-by-zero-workaround-and-diag.diff:
  Refresh.
* Thu Jan 13 2011 jkosina@suse.cz
- patches.fixes/input-introduce-notimeout-blacklist-for-Dell-Vostro-.patch:
  merged upstream, update Patch-mainline tag.
* Wed Jan 12 2011 mgalbraith@suse.de
- Ratelimit debug output.
- patches.fixes/sched-divide-by-zero-workaround-and-diag.diff:
  Refresh.
* Tue Jan 11 2011 gregkh@suse.de
- supported.conf: mark hv_timesource as a supported module (bnc#650748)
* Tue Jan 11 2011 gregkh@suse.de
- patches.suse/staging-hv-add-code-to-create-the-device-directory-under-sys-block-hdx.patch:
  Staging: hv: Add code to create the device directory under
  /sys/block/hdX (bnc#659419).
* Tue Jan 11 2011 jbohac@suse.cz
- patches.fixes/add-POLLPRI-to-sock_def_readable.patch: net:
  add POLLPRI to sock_def_readable() (bnc#660546).
* Tue Jan 11 2011 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.29: Fix a regression.
* Mon Jan 10 2011 jack@suse.cz
- patches.fixes/novfs-fragment-size-fix.patch: novfs: NCP
  Fragments can be upto 64k in size (bnc#625965).
* Mon Jan 10 2011 hare@suse.de
- patches.suse/qla2xxx-add-ql2xtargetreset-parm: Enable patch.
* Mon Jan 10 2011 jslaby@suse.de
- Update to 2.6.32.28:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.fixes/acpi_fix_out_of_method_code.patch: Delete.
  - patches.fixes/hvc_console-fix-race-between-hvc_close-and-hvc_remove:
  - patches.fixes/hvc_console-fix-race-between-hvc_close-and-hvc_remove2:
- kabi fixes:
  - patches.kabi/fuse-protect-linux-compat.h.patch: FUSE: protect
    linux/compat.h.
  - patches.kabi/kabi-fix-for-block-Deprecate-QUEUE_FLAG_CLUSTER-and-use-qu.patch:
    kabi fix for "block: Deprecate QUEUE_FLAG_CLUSTER and use
    queue_limits instead".
- patches.drivers/bfa-2.1.2.1-s11-update: Refresh.
- patches.drivers/igb-add-new-data-structure-for-handling-interrupts-a.patch:
  Refresh.
* Mon Jan 10 2011 ptesarik@suse.cz
- patches.suse/acpi-blacklist-dell-latitude-e6410.patch: ACPI:
  Disable Windows 7 and Vista compatibility for Dell Latitude
  E6410 (bnc#657763).
* Fri Jan  7 2011 mgalbraith@suse.de
- Added a workaround/diag with big fat warning in series.conf
  Hopefully, we'll get some useful info while preventing customer
  machines from exploding after weeks/months of uptime.
- patches.fixes/sched-divide-by-zero-workaround-and-diag.diff:
  sched: debug divide by zero bug in find_busiest_group()
  (bnc#630970, bnc#661605).
* Thu Jan  6 2011 jack@suse.cz
- patches.fixes/bdi-Fix-warnings-in-inode_to_bdi.patch: writeback:
  always use sb->s_bdi for writeback purposes (bnc#658254).
* Thu Jan  6 2011 jslaby@suse.de
- patches.fixes/tty-don-t-allow-reopen-when-ldisc-is-changing.patch:
  TTY: don't allow reopen when ldisc is changing (bnc#662722).
* Thu Jan  6 2011 jack@suse.cz
- patches.suse/ext2-fsync-err: Delete obsolete and unused patch.
* Thu Jan  6 2011 jbeulich@novell.com
- patches.xen/1028-interface.patch: Update Xen public headers.
- patches.xen/1055-backends-thread-leak.patch: blkback/blktap/netback:
  Fix CVE-2010-3699 (CVE-2010-3699 bnc#655964).
- patches.xen/1060-gntdev-range-check.patch: xen/gntdev: add range
  check for IOCTL_GNTDEV_UNMAP_GRANT_REF arguments.
- patches.xen/1061-netback-extend-pull.patch: xen/netback: Always pull
  through PKT_PROT_LEN bytes into the linear part of an skb.
- patches.xen/1062-xenbus-dev-leak.patch: xenbus: Fix memory leak on
  release.
- Refresh other Xen patches.
* Wed Jan  5 2011 nfbrown@suse.de
- patches.fixes/sunrpc-cache-completion.fix: Work around incorrect
  return type for wait_for_completion_interruptible_timeout
  (bnc#650067).
* Tue Jan  4 2011 mmarek@suse.cz
- rpm/config.sh: Set OBS_PROJECT=SUSE:SLE-11:SP1.
* Tue Jan  4 2011 bphilips@suse.de
- patches.drivers/enic-return-err-in-vnic_dev_addr.patch: Delete
  this backport patch which is replaced by
  enic-add-ndo_-set-get-_vf_port-support-for-enic-dynamic-vnics.patch
* Mon Jan  3 2011 jslaby@suse.de
- patches.suse/rlim-0023-core-do-security-check-under-task_lock.patch:
  Delete.
  It's unreferenced and superseded by:
  patches.suse/rlim-0020-rlimits-do-security-check-under-task_lock.patch
* Mon Jan  3 2011 mgalbraith@suse.de
- patches.suse/sysctl-add-affinity_load_balancing: Delete.
* Wed Dec 29 2010 jkosina@suse.cz
- patches.fixes/input-introduce-notimeout-blacklist-for-Dell-Vostro-.patch:
  Input: introduce 'notimeout' blacklist for Dell Vostro V13
  (bnc#641105).
* Wed Dec 29 2010 jbohac@suse.cz
- patches.fixes/xfrm-ipv6-fragment-locally-generated-packets.patch:
  ipv6: Fragment locally generated tunnel-mode IPSec6 packets
  as needed.
* Wed Dec 29 2010 rjw@suse.de
- patches.fixes/isdn-hisax-replace-access-to-irq-stats.patch:
  isdn: hisax: Replace the bogus access to irq stats (bnc#648112).
- patches.fixes/proc-stat-fix-scalability-of-irq-sum-of-all-cpu.patch:
  /proc/stat: fix scalability of irq sum of all cpu (bnc#648112).
- patches.fixes/proc-stat-scalability-fix-backport.patch:
  /proc/stat: scalability of irq num per cpu (bnc#648112).
* Tue Dec 28 2010 rjw@suse.de
- patches.arch/x86-uv-early-read-mmr.patch: x86 / UV: Introduce
  uv_early_read_mmr() (bnc#658829).
- patches.arch/x86-uv-early-set-x2apic_extra_bits.patch: x86 /
  UV: Fix uv_acpi_madt_oem_check() (bnc#658829).
- patches.arch/x86-uv-fix-max_pnode.patch: x86 / UV: Fix max_pnode
  (bnc#658829).
* Tue Dec 28 2010 rjw@suse.de
- patches.arch/x86-uv-Enable-Westmere-support-on-SGI-UV.patch:
  x86 / UV: Enable Westmere support on SGI UV (bnc#659144).
* Tue Dec 28 2010 rjw@suse.de
- patches.arch/x86-UV-hwclock-workaround.patch: x86 / UV:
  Workaround for interrupt-IOPort deadlock (bnc#655027).
* Thu Dec 16 2010 trenn@suse.de
- patches.drivers/acer_wmi_init_rfkill.patch: Initialize
  wlan/bluetooth/wwan rfkill software block state (bnc#652842).
* Wed Dec 15 2010 trenn@suse.de
- patches.fixes/acpi_fix_out_of_method_code.patch: ACPICA:
  Fix Scope() op in module level code (bnc#646542).
* Wed Dec 15 2010 tiwai@suse.de
- patches.drivers/mmc-test-bus-width: Refresh.  Fixed wrong 1-bit
  width check.
* Wed Dec 15 2010 tiwai@suse.de
- patches.drivers/mmc-test-bus-width: Refreshed to v2 patch.
* Mon Dec 13 2010 jeffm@suse.com
- patches.fixes/cred-fix-get_task_cred-and-task_state-to-not-resurrect-dead-credentials:
  CRED: Fix get_task_cred() and task_state() to not resurrect
  dead credentials (bnc#654967).
* Mon Dec 13 2010 jslaby@suse.de
- Really update to 2.6.32.27 -- last time I forgot to add it to
  series.conf
- patches.kabi/revert-physical-block-size-change.patch: Revert
  "block: Ensure physical block size is unsigned int".
- patches.xen/xen3-patch-2.6.32.26-27: Refresh.
* Mon Dec 13 2010 jslaby@suse.de
- patches.xen/xen3-patch-2.6.32.26-27: Linux 2.6.32.27.
  I forgot to add this file during the 2.6.32.27 update. It causes
  some fixes for which patches were dropped.
* Mon Dec 13 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh.
  Fix crash when bootsplash animation is used (bnc#646908)
* Mon Dec 13 2010 nfbrown@suse.de
- patches.kabi/xen3-patch-2.6.27: Refresh.
  Remove some kruft I accidentally added in previous patch.
* Sun Dec 12 2010 nfbrown@suse.de
- patches.fixes/sunrpc_xprt_refcnt.fix: Fix possible crash due
  to refcount problem (bnc#650067).
* Sat Dec 11 2010 jjolly@suse.de
- patches.arch/s390-25-01-nmi-clock.patch: kernel: fix clock
  comparator revalidation (bnc#657415,LTC#68476).
- patches.arch/s390-25-02-qeth_l3_vpassthru.patch: qeth: l3 add
  vlan hdr in passthru frames (bnc#657415,LTC#68532).
- patches.arch/s390-25-03-qeth-offline-vipa-add.patch:
  qeth: enable VIPA add/remove for offline devices
  (bnc#657415,LTC#68589).
- patches.arch/s390-25-04-hvc-iucv-unregister.patch: hvc_iucv:
  do not call iucv_unregister if iucv_register has failed
  (bnc#657415,LTC#67568).
* Fri Dec 10 2010 jbohac@suse.cz
- patches.fixes/bonding-allow-arp_ip_targers-on-separate-vlans-to-use-arp-validation.patch:
  bonding: allow arp_ip_targets on separate vlans to use arp
  validation (bnc#648701).
- patches.fixes/bonding-set-device-in-rlb-arp-packet-handler.patch:
  bonding: set device in RLB ARP packet handler (bnc#648701).
* Fri Dec 10 2010 duwe@suse.de
- patches.arch/ppc64-kdump-unrace: hide paca.kexec_state from
  kABI checker.
* Fri Dec 10 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-95-hdmi-check-pincfg: ALSA: HDA:
  Remove unconnected PCM devices for Intel HDMI (bnc#655278).
* Fri Dec 10 2010 jslaby@suse.de
- Update to 2.6.32.27:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/amd_nb_early_access_oops.patch
  - patches.arch/s390-25-01-nmi-clock.patch
  - patches.arch/x86-UV-Delete-unneeded-boot-messages.patch
  - patches.arch/x86-UV-Fix-initialization-of-max_pnode.patch
  - patches.arch/xpc_first_contact_when_active.patch
  - patches.arch/xpc_fix_xpc_get_fifo_entry_uv.patch
  - patches.arch/xpc_pass_nasid_to_gru_create_message_queue.patch
  - patches.arch/xpc_recv_msg_slots_wrap.patch
  - patches.fixes/bio-take-care-not-overflow-page-count-when-mapping-copying-user-data
  - patches.fixes/block-check-for-proper-length-of-iov-entries-in-blk_rq_map_user_iov
  - patches.fixes/block-limit-vec-count-in-bio_kmalloc-and-bio_alloc_map_data
  - patches.fixes/block-take-care-not-to-overflow-when-calculating-total-iov-length
  - patches.fixes/can-bcm-fix-minor-heap-overflow
  - patches.fixes/do_exit-make-sure-that-we-run-with-get_fs-user_ds
  - patches.fixes/hpet-unmap-unused-I-O-space.patch
  - patches.fixes/ipc-initialize-structure-memory-to-zero-for-compat-functions
  - patches.fixes/ipc-shm-fix-information-leak-to-userland
  - patches.fixes/kvm-x86-fix-information-leak-to-userland
  - patches.fixes/net-Limit-socket-I-O-iovec-total-length.patch
  - patches.fixes/net-clear-heap-allocation-for-ethtool_grxclsrlall
  - patches.fixes/net-sched-fix-some-kernel-memory-leaks
  - patches.fixes/net-truncate-recvfrom-and-sendto-length-to-int_max
  - patches.fixes/perf_events-fix-perf_counter_mmap-hook-in-mprotect
  - patches.fixes/rds-integer-overflow-in-rds-cmsg-handling
  - patches.fixes/sys_semctl-fix-kernel-stack-leakage
  - patches.fixes/tty-restore-tty_ldisc_wait_idle.patch
  - patches.fixes/v4l-dvb-ivtvfb-prevent-reading-uninitialized-stack-memory
  - patches.fixes/x25-prevent-crashing-when-parsing-bad-x-25-facilities
  - patches.xen/xen3-amd_nb_early_access_oops.patch
* Fri Dec 10 2010 tiwai@suse.de
- patches.suse/acpi-video-switch-option: ACPI video: Add
  video_switch_key option (bnc#647567).
* Thu Dec  9 2010 duwe@suse.de
- patches.arch/ppc64-kdump-unrace: comment that kexec_state
  in paca struct occupies space that was padding, and enable
  the patch.
* Thu Dec  9 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-89-idt-automatic-dock-mic: Refresh.
- patches.drivers/alsa-sp1-hda-92-add-idt-92hd89xx-codecs: ALSA:
  hda - Add support for IDT 92HD89XX codecs (bnc#658464).
- patches.drivers/alsa-sp1-hda-93-add-idt-92hd90bxx-codecs: ALSA:
  hda - Adding support for new IDT 92HD90BXX and 92HD91BXX codecs
  (bnc#658464).
- patches.drivers/alsa-sp1-hda-94-enable-dmic-on-idt-92hd87b:
  ALSA: HDA: Enable digital mic on IDT 92HD87B (bnc#658464).
* Thu Dec  9 2010 tiwai@suse.de
- patches.drivers/mmc-fix-hibernation-restore: Refresh.  Don't
  remove PM_POST_HIBERNATION case for kernel-space S4.
* Wed Dec  8 2010 gregkh@suse.de
- patches.fixes/rt3090-fix-unable-to-scan-ap.patch: Fix RT3090
  scan AP function (bnc#656471).
* Wed Dec  8 2010 jeffm@suse.com
- patches.fixes/do_exit-make-sure-that-we-run-with-get_fs-user_ds:
  do_exit(): make sure that we run with get_fs() == USER_DS
  (CVE-2010-4258 bnc#657350).
* Wed Dec  8 2010 tiwai@suse.de
- patches.drivers/mmc-fix-hangs-with-sd-at-pm: mmc: fix all hangs
  related to mmc/sd card insert/removal during suspend/resume
  (bnc#646702).
- patches.drivers/mmc-fix-hibernation-restore: mmc: Fix re-probing
  after hibernation (bnc#646702).
- patches.drivers/mmc-sdio-fix-SDIO-suspend-resume-regression:
  mmc: sdio: fix SDIO suspend/resume regression (bnc#646702).
- patches.kabi/kabi-fix-up-struct-mmc_host: Fix up kABI for
  struct mmc_host (bnc#646702).
* Wed Dec  8 2010 tiwai@suse.de
- patches.drivers/memstick-Fix-setup-for-JMicron-38x-controllers:
  memstick: Fix setup for JMicron 38x controllers (bnc#653148).
- patches.drivers/memstick-add-support-for-JMicron-new-controllers:
  memstick: Add support for JMicron JMB 385 and 390 controllers
  (bnc#653148).
- patches.drivers/memstick-set-PMOS-values-for-JMicron-38x:
  memstick: Set PMOS values propery for JMicron 38x controllers
  (bnc#653148).
* Mon Dec  6 2010 trenn@suse.de
- patches.drivers/hp_wmi_update_to_2_6_37_rc4.patch: Update
  hp-wmi to latest mainline version (bnc#657324).
* Mon Dec  6 2010 mmarek@suse.cz
- kabi/severities: Ignore changes to drivers/xen/core/{domctl,pcpu},
  these are purely internal interfaces.
* Fri Dec  3 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-90-idt-92hd8x-beep: ALSA: hda -
  Enable beep for IDT92HD87 / 88 codecs (bnc#657412).
- patches.drivers/alsa-sp1-hda-91-fix-beep-frequency-on-idt-codecs:
  ALSA: hda - Fix beep frequency on IDT 92HD73xx and 92HD71Bxx
  codecs (bnc#657412).
* Thu Dec  2 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-89-idt-automatic-dock-mic: ALSA:
  hda - Fix automatic MIC switching and include dock MIC for
  IDT codecs (bnc#650185).
* Thu Dec  2 2010 hare@suse.de
- patches.fixes/libfcoe-Use-fka_period-as-periodic-timeouts-to-age:
  libfcoe: Use fka_period as periodic timeouts to age out fcf if
  (bnc#615630).
- patches.fixes/libfcoe-fix-lenient-aging-of-FCF-advertisements:
  libfcoe: fix lenient aging of FCF advertisements (bnc#615630).
- patches.fixes/libfcoe-update-FIP-FCF-D-flag-from-advertisments:
  libfcoe: update FIP FCF D flag from advertisments (bnc#615630).
* Thu Dec  2 2010 hare@suse.de
- patches.fixes/libfc-add-print-of-exchange-id-for-debugging-fc_fcp:
  libfc: add print of exchange id for debugging fc_fcp
  (bnc#654530).
- patches.fixes/libfc-do-not-fc_io_compl-on-fsp-w-o-any-scsi_cmnd-a:
  libfc: do not fc_io_compl on fsp w/o any scsi_cmnd associated
  (bnc#654530).
- patches.fixes/libfc-fix-exchange-being-deleted-when-the-abort-its:
  libfc: fix exchange being deleted when the abort itself is
  timed out (bnc#654530).
- patches.fixes/libfc-fix-fc_tm_done-not-freeing-the-allocated-fsp:
  libfc: fix fc_tm_done not freeing the allocated fsp pkt
  (bnc#654530).
- patches.fixes/libfc-the-timeout-for-the-REC-itself-is-2-R_A_TOV:
  libfc: the timeout for the REC itself is 2 * R_A_TOV_els
  (bnc#654530).
* Thu Dec  2 2010 hare@suse.de
- patches.drivers/ixgbe-disable-tx-engine-before-disabling-tx-laser:
  ixgbe: disable tx engine before disabling tx laser (bnc#654350).
- patches.drivers/ixgbe-fix-wrong-offset-to-fc_frame_header-in-ixgbe_:
  ixgbe: fix wrong offset to fc_frame_header in ixgbe_fcoe_ddp
  (bnc#654350).
- patches.drivers/ixgbe-if-ixgbe_copy_dcb_cfg-is-going-to-fail-learn:
  ixgbe: if ixgbe_copy_dcb_cfg is going to fail learn about it
  early (bnc#654350).
- patches.drivers/ixgbe-ixgbe_down-needs-to-stop-dev_watchdog:
  ixgbe: ixgbe_down needs to stop dev_watchdog (bnc#654350).
- patches.drivers/ixgbe-properly-toggling-netdev-feature-flags-when-d:
  ixgbe: properly toggling netdev feature flags when disabling
  FCoE (bnc#654350).
- patches.drivers/ixgbe-use-GFP_ATOMIC-when-allocating-FCoE-DDP-conte:
  ixgbe: use GFP_ATOMIC when allocating FCoE DDP context
  (bnc#654350).
* Wed Dec  1 2010 gregkh@suse.de
- patches.fixes/usb-ehci-amd-periodic-frame-list-table-quirk.patch:
  USB: EHCI: AMD periodic frame list table quirk (bnc#652293).
* Wed Dec  1 2010 hare@suse.de
- patches.drivers/qla2xxx-drop-reference-before-wait-for-completion:
  Update to version found in mainline.
* Wed Dec  1 2010 rjw@suse.de
- patches.suse/acpi-blacklist-dell-vostro-v13.patch: ACPI:
  Disable Windows 7 and Vista compatibility for Dell Vostro V13
  (bnc#602838).
* Tue Nov 30 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.26.
- patches.xen/1035-gnttab-eagain.patch: Fold in c/s 1052.
- patches.xen/1050-evtchn-cpu-clear.patch: xen/evtchn: clear secondary
  CPUs' cpu_evtchn_mask[] after restore (bnc#651626).
- patches.xen/1053-blktap2-run-queue-sem.patch: blktap2: fix
  synchronization in blktap_device_run_queue().
- patches.xen/xen3-x86-Add-array-variants-for-setting-memory-to-wc:
  arch/x86: Add array variants for setting memory to wc caching
  (bnc#654837).
- Update x86_64/xen config file.
* Mon Nov 29 2010 duwe@suse.de
- disable patches.arch/ppc64-kdump-unrace due to kabi breakage
* Mon Nov 29 2010 duwe@suse.de
- patches.arch/ppc64-kdump-unrace: Fix race in kexec shutdown
  (bnc#654150).
- patches.fixes/scsi-correct-sr_drive_status: sr: fix
  sr_drive_status handling when initialization required
  (bnc#653800).
* Mon Nov 29 2010 tiwai@suse.de
- patches.arch/x86-Add-array-variants-for-setting-memory-to-wc:
  arch/x86: Add array variants for setting memory to wc caching
  (bnc#654837).
* Fri Nov 26 2010 mmarek@suse.cz
- Update reference module symbol versions.
* Fri Nov 26 2010 tiwai@suse.de
- patches.drivers/jmb388-mmc-fix: mmc: Add support for JMicron
  388 SD/MMC controller (bnc#646226).
- patches.drivers/mmc-test-bus-width: mmc: Test bus-width for
  old MMC devices (bnc#646226).
* Wed Nov 24 2010 jslaby@suse.de
- patches.kabi/smp_ops.patch: Revert "x86, kexec: Make sure to
  stop all CPUs before exiting the kernel" kabi changes.
- patches.kabi/revert-x86-kexec-Make-sure-to-stop-all-CPUs-before-e.patch:
  Delete.
* Tue Nov 23 2010 jack@suse.cz
- patches.xfs/xfs-ensure-non-negative-f_ffree.patch: xfs: ensure
  f_ffree returned by statfs() is non-negative (bnc#595215).
* Tue Nov 23 2010 jeffm@suse.com
- patches.fixes/net-truncate-recvfrom-and-sendto-length-to-int_max:
  net: Truncate recvfrom and sendto length to INT_MAX
  (CVE-2010-4160 bnc#652939).
* Tue Nov 23 2010 oneukum@suse.de
- patches.fixes/backport_ricoh_fw_chipset_bug.patch: Fix hang
  at S4 for Ricoh fw chips (bnc#648647).
* Mon Nov 22 2010 jslaby@suse.de
- Update to 2.6.32.26:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/ioremap_flush.patch
  - patches.arch/vmcore_ioremap_cache.patch
  - patches.arch/x86-uv-xpc_disconnect_fix.patch
  - patches.arch/x86_amd_mtrr_fix_fam_12_and_higher.patch
  - patches.fixes/fc_sdev_blocked.patch
  - patches.fixes/kvm-constant_tsc-0001-KVM-SVM-Adjust-tsc_offset-only-if-tsc_unstable.patch
  - patches.fixes/scsi-gdth-integer-overflow-in-ioctl
  - patches.fixes/sd-namespace-exhaustion-check.patch
- patches.kabi/revert-x86-kexec-Make-sure-to-stop-all-CPUs-before-e.patch:
  Revert "x86, kexec: Make sure to stop all CPUs before exiting
  the kernel".
- patches.arch/add_x86_support_for_hpet_msi_intr_remap.patch:
  Refresh.
- patches.suse/block-add-mangle-devt-switch: Refresh.
* Mon Nov 22 2010 jeffm@suse.com
- patches.fixes/scsi-gdth-integer-overflow-in-ioctl: gdth:
  integer overflow in ioctl (CVE-2010-4157 bnc#652940).
* Mon Nov 22 2010 jeffm@suse.com
- patches.fixes/tcp-increase-tcp_maxseg-socket-option-minimum:
  tcp: Increase TCP_MAXSEG socket option minimum (CVE-2010-4165
  bnc#653258).
* Mon Nov 22 2010 jeffm@suse.com
- patches.fixes/x25-prevent-crashing-when-parsing-bad-x-25-facilities:
  x25: Prevent crashing when parsing bad X.25 facilities
  (CVE-2010-4164 bnc#653260).
* Mon Nov 22 2010 jeffm@suse.com
- patches.fixes/rds-integer-overflow-in-rds-cmsg-handling:
  rds: Integer overflow in RDS cmsg handling (CVE-2010-4175
  bnc#654581).
* Mon Nov 22 2010 jeffm@suse.com
- patches.fixes/perf_events-fix-perf_counter_mmap-hook-in-mprotect:
  perf_events: Fix perf_counter_mmap() hook in mprotect()
  (CVE-2010-4169 bnc#653930).
* Fri Nov 19 2010 jjolly@suse.de
- patches.arch/s390-24-01-zfcp-fix-lookup-dequeue.patch: zfcp:
  Cancel gid_pn work when removing port (bnc#653266,LTC#68146).
- patches.arch/s390-24-02-vmlogrdr-purge-after-recording-off.patch:
  vmlogrdr: purge after recording is switched off
  (bnc#653266,LTC#68182).
* Fri Nov 19 2010 bphilips@suse.de
- Add enic fixes and features under the philips-eco symbol. Waiting
  on an ECO to unmask (bnc#638258)
* Fri Nov 19 2010 jeffm@suse.com
- patches.fixes/can-bcm-fix-minor-heap-overflow: can-bcm: fix
  minor heap overflow (CVE-2010-3874 bnc#651218).
* Thu Nov 18 2010 jeffm@suse.com
- patches.fixes/filter-make-sure-filters-dont-read-uninitialized-memory:
  filter: make sure filters dont read uninitialized memory
  (CVE-2010-4158 bnc#652563).
- patches.fixes/net-optimize-berkeley-packet-filter-bpf-processing:
  net: optimize Berkeley Packet Filter (BPF) processing.
* Thu Nov 18 2010 jeffm@suse.com
- patches.fixes/bio-take-care-not-overflow-page-count-when-mapping-copying-user-data:
  bio: take care not overflow page count when mapping/copying
  user data (CVE-2010-4162 bnc#652945).
- patches.fixes/block-check-for-proper-length-of-iov-entries-in-blk_rq_map_user_iov:
  block: check for proper length of iov entries in
  blk_rq_map_user_iov() (CVE-2010-4163 bnc#652945).
- patches.fixes/block-limit-vec-count-in-bio_kmalloc-and-bio_alloc_map_data:
  block: limit vec count in bio_kmalloc() and bio_alloc_map_data()
  (bnc#652945).
- patches.fixes/block-take-care-not-to-overflow-when-calculating-total-iov-length:
  block: take care not to overflow when calculating total iov
  length (bnc#652945).
* Thu Nov 18 2010 jeffm@suse.de
- patches.apparmor/apparmor-fix-handling-of-network-permissions:
  apparmor: Fix handling of network permissions (bnc#654701).
* Thu Nov 18 2010 sjayaraman@suse.de
- patches.fixes/nfs4-add-release-lockowner: NFSv4: Add support
  for the RELEASE_LOCKOWNER operation (bnc#649548).
* Wed Nov 17 2010 duwe@suse.de
- patches.fixes/bounce_pfn-raise-limit-on-mem-add: Block: set the
  bounce_pfn to the actual DMA limit rather than to max memory
  (bnc#637542).
- patches.fixes/ibmvfc-fix-del-race: ibmvfc: Fix rport add/delete
  race resulting in oops (bnc#628180).
* Sat Nov 13 2010 jslaby@suse.de
- patches.fixes/tty-restore-tty_ldisc_wait_idle.patch: TTY:
  restore tty_ldisc_wait_idle (bnc#642043).
* Fri Nov 12 2010 jbeulich@novell.com
- patches.xen/1035-gnttab-eagain.patch: xenpaging: handle GNTST_eagain
  in kernel drivers (FATE#310510).
- patches.xen/1037-x86-pin-vs-vmalloc_sync_all.patch: xen/x86:
  synchronize vmalloc_sync_all() with mm_{,un}pin().
- patches.xen/1038-evtchn-handle-timer-first.patch: xen/evtchn: Handle
  VIRQ_TIMER before any other hardirq in event loop.
- patches.xen/1040-pcifront-rescan-claim.patch: pcifront: claim PCI
  resources also on rescan (bnc#643477).
- patches.xen/1041-pcifront-irq-not-evtchn.patch: pcifront: fix freeing
  of device (bnc#643477).
- patches.xen/1045-netback-sched-list-remove.patch: netback: take
  net_schedule_list_lock when removing entry from net_schedule_list.
- patches.xen/xen-mem-hotplug: xen/acpi: Add memory hotadd to
  pvops dom0 (bnc#651066).
- patches.xen/xen-pcpu-hotplug: xen/acpi: Export host physical
  CPU information to dom0 (bnc#651066).
- patches.xen/xen-x86-msr-on-pcpu: introduce
  {rd,wr}msr_safe_on_pcpu() and add/enable users.
- Update other Xen patches (bnc#652024).
- Update Xen config files.
* Fri Nov 12 2010 oneukum@suse.de
- patches.fixes/0001-USB-sd-sd_start_stop_device-proper-error-codes.patch:
  USB: sd: sd_start_stop_device proper error codes (bnc#639803).
- patches.fixes/0003-SCSI-sd-sd_start_stop_device-error-handling.patch:
  SCSI:sd: sd_start_stop_device() error handling (bnc#639803).
- patches.fixes/SCSI-sd-error-handling-in-sd_sync_cache.patch:
  SCSI:sd:error handling in sd_sync_cache() (bnc#639803).
* Fri Nov 12 2010 oneukum@suse.de
- patches.fixes/0001-USB-sd-sd_start_stop_device-proper-error-codes.patch:
  USB: sd: sd_start_stop_device proper error codes (bnc#639803).
- patches.fixes/0003-SCSI-sd-sd_start_stop_device-error-handling.patch:
  SCSI:sd: sd_start_stop_device() error handling (bnc#639803).
- patches.fixes/SCSI-sd-error-handling-in-sd_sync_cache.patch:
  SCSI:sd:error handling in sd_sync_cache() (bnc#639803).
* Fri Nov 12 2010 knikanth@suse.de
- patches.arch/ioremap_flush.patch: mm, x86: Saving vmcore with
  non-lazy freeing of vmas (bnc#640878).
- patches.arch/vmcore_ioremap_cache.patch: x86, kdump: Change
  copy_oldmem_page() to use cached addressing (bnc#640878).
* Wed Nov 10 2010 agraf@suse.de
- patches.arch/s390-kvm-tlb-fix.patch: [S390] kvm: Fix badness
  at include/asm/mmu_context.h:83 (bnc#652603).
* Wed Nov 10 2010 gregkh@suse.de
- supported.conf: mark hyperv drivers as supported (bnc#650748)
* Tue Nov  9 2010 jeffm@suse.com
- patches.fixes/avoid-pgoff-overflow-in-remap_file_pages: Avoid
  pgoff overflow in remap_file_pages (bnc#645659).
* Tue Nov  9 2010 jeffm@suse.com
- patches.fixes/net-clear-heap-allocation-for-ethtool_grxclsrlall:
  net: clear heap allocation for ETHTOOL_GRXCLSRLALL (bnc#649187
  CVE-2010-3861).
* Tue Nov  9 2010 jeffm@suse.com
- patches.fixes/kvm-x86-fix-information-leak-to-userland:
  KVM: x86: fix information leak to userland (bnc#651596
  CVE-2010-3881).
* Tue Nov  9 2010 jack@suse.cz
- patches.fixes/novfs-unlink-oops: novfs: Fix for the issue of
  kernel dumps core on restart (bnc#641811).
* Tue Nov  9 2010 gregkh@suse.de
- patches.suse/staging-hv-fixed-issue-with-possible-race-condition-on-channel-init.patch:
  Staging: hv: Fixed issue with possible race condition on
  channel init (bnc#650748).
* Tue Nov  9 2010 gregkh@suse.de
- supported.conf: added hv_utils as an unsupported, but listed, kernel module.
* Tue Nov  9 2010 gregkh@suse.de
- patches.suse/staging-hv-added-autoload-of-hv_utils.ko-driver.patch:
  Staging: hv: Added autoload of hv_utils.ko driver (bnc#650487).
* Tue Nov  9 2010 jeffm@suse.com
- patches.fixes/fix-pktcdvd-ioctl-dev_minor-range-check: Fix
  pktcdvd ioctl dev_minor range check (bnc#642486 CVE-2010-3437).
* Mon Nov  8 2010 jeffm@suse.com
- patches.fixes/v4l-dvb-ivtvfb-prevent-reading-uninitialized-stack-memory:
  V4L/DVB: ivtvfb: prevent reading uninitialized stack memory
  (bnc#642313 CVE-2010-4082).
* Mon Nov  8 2010 jeffm@suse.com
- patches.fixes/ipc-initialize-structure-memory-to-zero-for-compat-functions:
  ipc: initialize structure memory to zero for compat functions
  (bnc#642314 CVE-2010-4073).
- patches.fixes/ipc-shm-fix-information-leak-to-userland:
  ipc: shm: fix information leak to userland (bnc#642314
  CVE-2010-4072).
- patches.fixes/sys_semctl-fix-kernel-stack-leakage: sys_semctl:
  fix kernel stack leakage (bnc#642314 CVE-2010-4083).
* Mon Nov  8 2010 trenn@suse.de
- Update config files:
  Enable newly introduced config CONFIG_INPUT_SPARSEKMAP=m
  on i386 and x86_64, keep it disabled on ppc and ia64
- patches.drivers/acer_wmi_3g_rfkill_sysfs_file.patch: Add 3G
  rfkill sysfs file (bnc#636672).
- patches.drivers/acer_wmi_dmi_check_wireless_device_availability.patch:
  Detect the WiFi/Bluetooth/3G devices available (bnc#636672).
- patches.drivers/acer_wmi_hotkey_events_support.patch: Add acer
  wmi hotkey events support (bnc#636672).
- patches.drivers/acer_wmi_launch_manager_mode.patch: Enabled
  Acer Launch Manager mode (bnc#636672).
- patches.drivers/input-add-generic-support-for-sparse-keymaps.patches:
  Input: add generic support for sparse keymaps (bnc#636672).
- supported.conf:
* Mon Nov  8 2010 sjayaraman@suse.de
- patches.suse/SoN-31-fix-kernel-bug-with-multiple-swapfiles:
  fix mess up on swap with multi files from same nfs server
  (FATE#303834). Fix kABI issues as well.
* Mon Nov  1 2010 mfasheh@suse.com
- patches.fixes/ocfs2-use-ocfs2_alloc_dinode_update_counts-instead-o.patch:
  Refresh to fix minor merge error found during testing.
* Sat Oct 30 2010 jslaby@suse.de
- Update to 2.6.32.25:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.fixes/execve-improve-interactivity-with-large-arguments
  - patches.fixes/execve-make-responsive-to-sigkill-with-large-arguments
  - patches.fixes/rds-de-pessimize-rds_page_copy_user.patch
  - patches.fixes/rose-fix-signedness-issues-wrt-digi-count
  - patches.fixes/sched-fix-kill-migration-thread-in-CPU_POST_DEAD-suspend-regression
  - patches.fixes/setup_arg_pages-diagnose-excessive-argument-size
  - patches.fixes/tcp-Fix-4GB-writes-on-64-bit.patch
  - patches.fixes/wext-fix-potential-private-ioctl-memory-content-leak
- patches.arch/acpi-osi-dmi-table-backport.patch: Refresh.
- patches.arch/x86-cpu-mv-display_cacheinfo-cpu_detect_cache_sizes.patch:
  Refresh.
- patches.drivers/v4l-disable-dangerous-buggy-compat-function.patch:
  Refresh.
- patches.kabi/revert-mm-Move-vma_stack_continue-into-mm.h.patch:
  Revert "mm: Move vma_stack_continue into mm.h".
- patches.xen/xen3-patch-2.6.32.24-25: Linux 2.6.32.25.
* Sat Oct 30 2010 jjolly@suse.de
- patches.arch/s390-23-01-zfcp-fix-p2p-refcount.patch:
  zfcp: Fix reference counter for point-to-point port
  (bnc#643173,LTC#67542).
- patches.arch/s390-23-02-dasd-fix-dump_sense_dbf.patch: dasd:
  fix dump_sense_dbf (bnc#643173,LTC#67610).
- patches.arch/s390-23-03-dasd-fix-cc1-handling.patch: dasd:
  fix unsolicited interrupt recognition (bnc#643173,LTC#67886).
- patches.arch/s390-23-04-dasd-fix-unimplemented-diag-function.patch:
  dasd: Fix unimplmentes DIAG function (bnc#643173,LTC#67938).
- patches.arch/s390-23-05-qeth-osxosm.patch: qeth: support for
  OSA CHPID types OSX and OSM (bnc#643173,LTC#66974).
- patches.arch/s390-23-06-cio-fix-cancel-halt-clear.patch:
  cio: prevent kernel panic in I/O cancel function
  (bnc#643173,LTC#67990).
* Fri Oct 29 2010 hare@suse.de
- patches.fixes/fcoe-fix-offload-feature-flag-change: fcoe:
  fix offload feature flag change from netdev (bnc#650116).
- patches.fixes/fcoe-sync-with-upstream-patches: Fix kABI.
- patches.fixes/libfc-call-fc_remote_port_chkready-under-the-host-lock:
  libfc: call fc_remote_port_chkready under the host lock
  (bnc#650116).
- patches.fixes/libfc-do-not-return-error-from-fc_fcp_send_abort:
  libfc: do not return error from fc_fcp_send_abort with null
  seq_ptr (bnc#650113).
- patches.fixes/libfc-fix-NULL-pointer-dereference-bug: libfc: fix
  NULL pointer dereference bug in fc_fcp_pkt_release (bnc#650113).
- patches.fixes/libfc-fix-setting-of-rport-dev-loss: libfc:
  fix setting of rport dev loss (bnc#650116).
* Fri Oct 29 2010 jslaby@suse.de
- patches.fixes/net-Limit-socket-I-O-iovec-total-length.patch:
  net: Limit socket I/O iovec total length to INT_MAX
  (bnc#650128).
- patches.fixes/tcp-Fix-4GB-writes-on-64-bit.patch: tcp: Fix
  >4GB writes on 64-bit (bnc#650128).
* Fri Oct 29 2010 hare@suse.de
- patches.drivers/ixgbe-DDP-fixes: ixgbe: DDP fixes (bnc#650111).
- patches.fixes/fcoe-sync-with-upstream-patches: open-fcoe:
  Sync with upstream patches (bnc#649820).
- patches.fixes/libfc-Fix-incorrect-locking-and-unlocking-in-FCP:
  libfc: Fix incorrect locking and unlocking in FCP (bnc#647775).
- patches.fixes/libfc-fix-codes-returned-to-scsi-ml: libfc:
  fix codes returned to scsi-ml (bnc#650109).
* Thu Oct 28 2010 knikanth@suse.de
- patches.xen/xen-add_efi_memmap-update-e820_saved.patch: Delete.
* Thu Oct 28 2010 knikanth@suse.de
- patches.suse/add_efi_memmap-update-e820_saved.patch: Pass
  add_efi_memmap entries to kexec'd kernel (bnc#603738).
- patches.xen/xen-add_efi_memmap-update-e820_saved.patch: Pass
  add_efi_memmap entries to kexec'd kernel (bnc#603738).
* Wed Oct 27 2010 jslaby@suse.de
- patches.fixes/hpet-unmap-unused-I-O-space.patch: hpet: unmap
  unused I/O space (bnc#629908 bnc#629901).
* Tue Oct 26 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-88-idt-workaround-for-master-mute:
  ALSA: HDA: Sigmatel: work around incorrect master muting
  (bnc#649257).
* Tue Oct 26 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-87-Change-BTL-amp-level-on-some-HP-notebooks:
  ALSA: hda - Change BTL amp level on some HP notebooks
  (bnc#649231).
* Mon Oct 25 2010 hare@suse.de
- patches.fixes/qla2xxx-correct-prli-failed-rsp: PLOGI failure
  message occurs and no LUN is detected (bnc#612729).
* Mon Oct 25 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-86-hdmi-support-infoframe-for-DisplayPort:
  ALSA: hdmi - support infoframe for DisplayPort (bnc#647497).
* Mon Oct 25 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-83-Fix-wrong-SPDIF-NID-for-CA0110:
  ALSA: hda - Fix wrong SPDIF NID assignment for CA0110
  (bnc#564324).
- patches.drivers/alsa-sp1-hda-84-Add-some-workarounds-for-Creative-IBG:
  ALSA: hda - Add some workarounds for Creative IBG (bnc#564324).
- patches.drivers/alsa-sp1-hda-85-Add-workarounds-for-CT-IBG-controllers:
  ALSA: hda - Add workarounds for CT-IBG controllers (bnc#564324).
* Thu Oct 21 2010 jslaby@suse.de
- patches.fixes/rds-de-pessimize-rds_page_copy_user.patch:
  De-pessimize rds_page_copy_user (bnc#647392).
* Thu Oct 21 2010 trenn@suse.de
- patches.arch/x86_amd_mtrr_fix_fam_12_and_higher.patch: x86,
  mtrr: Assume SYS_CFG exists on all future AMD CPUs (bnc#648308).
* Thu Oct 21 2010 trenn@suse.de
- patches.arch/acpi_ec_delay_param.patch: ACPI: Make Embedded
  Controller command timeout delay configurable (bnc#639261).
* Thu Oct 21 2010 sjayaraman@suse.de
- patches.suse/SoN-31-fix-kernel-bug-with-multiple-swapfiles:
  Revert(as it breaks kABI).
* Thu Oct 21 2010 sjayaraman@suse.de
- patches.suse/SoN-31-fix-kernel-bug-with-multiple-swapfiles:
  fix mess up on swap with multi files from same nfs server
  (FATE#303834).
* Thu Oct 21 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-82-acer-quirk-mask: ALSA: hda -
  Apply ideapad quirk to Acer laptops with Cxt5066  (bnc#638860).
* Thu Oct 21 2010 bphilips@suse.de
- patches.drivers/v4l-disable-dangerous-buggy-compat-function.patch:
  v4l: disable dangerous buggy compat function (bnc#646045,
  CVE-2010-2963).
* Wed Oct 20 2010 rw@suse.de
- patches.drivers/sgi-mmtimer-holdoff-fix:
  Eliminate long interval timer holdoffs.  (bnc#644373)
* Wed Oct 20 2010 nfbrown@suse.de
- patches.fixes/md-external-bitmap-unplug: md: Unplug write to
  external bitmap before waiting (bnc#623307).
* Wed Oct 20 2010 rjw@suse.de
- patches.arch/acpi-osi-dmi-table-backport.patch: ACPI: Backport
  missing entries of acpi_osi_dmi_table from upstream.
* Mon Oct 18 2010 knikanth@suse.de
- patches.fixes/sd-namespace-exhaustion-check.patch: sd name
  space exhaustion causes system hang (bnc#643249).
* Mon Oct 18 2010 sjayaraman@suse.de
- patches.fixes/nfs-support-local_lock: nfs: introduce mount
  option '-olocal_lock' to make locks local (bnc#609196).
* Mon Oct 18 2010 nfbrown@suse.de
- patches.fixes/nfs-dont-decode-GETATTR-if-DELEGRETURN-returned-error.patch:
  NFS: don't try to decode GETATTR if DELEGRETURN returned error
  (bnc#624850).
* Mon Oct 11 2010 jslaby@suse.de
- patches.fixes/isdn-avoid-calling-tty_ldisc_flush.patch: isdn:
  avoid calling tty_ldisc_flush() in atomic context (bnc#573330).
* Mon Oct 11 2010 hare@suse.de
- patches.fixes/libfc-possible-race-could-panic-system:
  libfc: possible race could panic system due to NULL fsp->cmd
  (bnc#644350).
* Mon Oct 11 2010 hare@suse.de
- patches.fixes/fcoe-set-fcoe-controller-mode: fcoe: set FCoE
  controller mode as FIP for fcoe.ko (bnc#640278).
* Mon Oct 11 2010 hare@suse.de
- patches.fixes/libfc-IO-errors-on-link-down-due-to-cable-unplug:
  libfc: IO errors on link down due to cable unplug (bnc#644219).
- patches.fixes/libfc-use-DID_TRANSPORT_DISRUPTED: libfc: use
  DID_TRANSPORT_DISRUPTED while lport not ready (bnc#644219).
* Thu Oct  7 2010 knikanth@suse.de
- patches.fixes/proc-pid-smaps-export-amount-of-anonymous-memory-in-a-mapping.patch:
  Export the number of anonymous pages in a mapping via smaps
  (bnc#596646).
* Thu Oct  7 2010 mmarek@suse.de
- Import new s390x kabi files.
* Thu Oct  7 2010 mfasheh@suse.com
- patches.fixes/dlm-allow-dlm-do-recovery-during-shutdown: dlm:
  allow dlm do recovery during shutdown.
- patches.fixes/fix-typos-concerning-initializse: fix typos
  concerning "initiali[zs]e".
- patches.fixes/fs-ocfs2-dlm-add-missing-spin_unlock:
  fs/ocfs2/dlm: Add missing spin_unlock.
- patches.fixes/fs-ocfs2-dlm-drop-memory-allocation-cast:
  fs/ocfs2/dlm: Drop memory allocation cast.
- patches.fixes/fs-ocfs2-dlm-use-kstrdup: fs/ocfs2/dlm: Use
  kstrdup.
- patches.fixes/fs-ocfs2-remove-unnecessary-casts-of-private_data:
  fs/ocfs2: Remove unnecessary casts of private_data.
- patches.fixes/include-cleanup-update-gfp-h-and-slab-h-includes-to-prepare-for-breaking-implicit-slab-h-inclusion-from-percpu-h:
  include cleanup: Update gfp.h and slab.h includes to prepare
  for breaking implicit slab.h inclusion from percpu.h.
- patches.fixes/o2net-disallow-o2net-accept-connection-request-from-itself:
  O2net: Disallow o2net accept connection request from itself.
- patches.fixes/o2net-log-socket-state-changes: o2net: log socket
  state changes.
- patches.fixes/ocfs2-Zero-the-tail-cluster-when-extending-past-i_si.patch:
  Refresh.
- patches.fixes/ocfs2-add-extent-block-stealing-for-ocfs2-v5.patch:
  Refresh.
- patches.fixes/ocfs2-add-parenthesis-to-wrap-the-check-for-o_direct:
  ocfs2: Add parenthesis to wrap the check for O_DIRECT.
- patches.fixes/ocfs2-avoid-a-gcc-warning-in-ocfs2_wipe_inode:
  ocfs2: Avoid a gcc warning in ocfs2_wipe_inode().
- patches.fixes/ocfs2-avoid-unnecessary-block-mapping-when-refreshing-quota-info:
  ocfs2: Avoid unnecessary block mapping when refreshing quota
  info.
- patches.fixes/ocfs2-block-signals-for-mkdir-link-symlink-o_creat:
  ocfs2: Block signals for mkdir/link/symlink/O_CREAT.
- patches.fixes/ocfs2-dlm-avoid-dlm-ast_lock-lockres-spinlock-dependency-break:
  ocfs2:dlm: avoid dlm->ast_lock lockres->spinlock dependency
  break.
- patches.fixes/ocfs2-dlm-don-t-access-beyond-bitmap-size:
  ocfs2/dlm: don't access beyond bitmap size.
- patches.fixes/ocfs2-dlm-increase-o2dlm-lockres-hash-size:
  ocfs2/dlm: Increase o2dlm lockres hash size.
- patches.fixes/ocfs2-dlm-make-o2dlm-domain-join-leave-messages-kern_notice:
  ocfs2/dlm: Make o2dlm domain join/leave messages KERN_NOTICE.
- patches.fixes/ocfs2-dlm-remove-bug_on-from-migration-in-the-rare-case-of-a-down-node:
  ocfs2/dlm: Remove BUG_ON from migration in the rare case of
  a down node.
- patches.fixes/ocfs2-do-not-map-blocks-from-local-quota-file-on-each-write:
  ocfs2: Do not map blocks from local quota file on each write.
- patches.fixes/ocfs2-don-t-duplicate-pages-past-i_size-during-cow:
  ocfs2: Don't duplicate pages past i_size during CoW.
- patches.fixes/ocfs2-don-t-retry-xattr-set-in-case-value-extension-fails:
  ocfs2: Don't retry xattr set in case value extension fails.
- patches.fixes/ocfs2-fix-deadlock-when-allocating-page: ocfs2:
  Fix deadlock when allocating page.
- patches.fixes/ocfs2-fix-estimate-of-credits-needed-for-quota-allocation:
  ocfs2: Fix estimate of credits needed for quota allocation.
- patches.fixes/ocfs2-fix-hole-punching-to-correctly-do-cow-during-cluster-zeroing:
  Ocfs2: Fix hole punching to correctly do CoW during cluster
  zeroing.
- patches.fixes/ocfs2-fix-lock-inversion-in-quotas-during-umount:
  ocfs2: Fix lock inversion in quotas during umount.
- patches.fixes/ocfs2-fix-null-pointer-deref-when-writing-local-dquot:
  ocfs2: Fix NULL pointer deref when writing local dquot.
- patches.fixes/ocfs2-fix-quota-locking: ocfs2: Fix quota locking.
- patches.fixes/ocfs2-fix-use-after-free-on-remount-read-only:
  ocfs2: Fix use after free on remount read-only.
- patches.fixes/ocfs2-flush-drive-s-caches-on-fdatasync: ocfs2:
  Flush drive's caches on fdatasync.
- patches.fixes/ocfs2-make-__ocfs2_page_mkwrite-handle-file-end-properly:
  ocfs2: make __ocfs2_page_mkwrite handle file end properly.
- patches.fixes/ocfs2-make-nointr-a-default-mount-option: ocfs2:
  Make nointr a default mount option.
- patches.fixes/ocfs2-make-ocfs2_adjust_resv_from_alloc-simple:
  ocfs2: make ocfs2_adjust_resv_from_alloc simple.
- patches.fixes/ocfs2-make-ocfs2_extend_trans-really-extend:
  ocfs2: Make ocfs2_extend_trans() really extend.
- patches.fixes/ocfs2-make-ocfs2_find_cpos_for_left_leaf-public:
  Ocfs2: Make ocfs2_find_cpos_for_left_leaf() public.
- patches.fixes/ocfs2-make-ocfs2_journal_dirty-void: ocfs2:
  Make ocfs2_journal_dirty() void.
- patches.fixes/ocfs2-make-xattr-extension-work-with-new-local-alloc-reservation:
  ocfs2: make xattr extension work with new local alloc
  reservation.
- patches.fixes/ocfs2-make-xattr-reflink-work-with-new-local-alloc-reservation:
  ocfs2: Make xattr reflink work with new local alloc reservation.
- patches.fixes/ocfs2-move-orphan-scan-work-to-ocfs2_wq: ocfs2:
  Move orphan scan work to ocfs2_wq.
- patches.fixes/ocfs2-one-more-warning-fix-in-ocfs2_file_aio_write-v2:
  ocfs2: one more warning fix in ocfs2_file_aio_write(), v2
  MIME-Version: 1.0 Content-Type: text/plain; charset=UTF-8
  Content-Transfer-Encoding: 8bit.
- patches.fixes/ocfs2-optimize-ocfs2-truncate-to-use-ocfs2_remove_btree_range-instead:
  Ocfs2: Optimize ocfs2 truncate to use ocfs2_remove_btree_range()
  instead.
- patches.fixes/ocfs2-optimize-punching-hole-code: Ocfs2:
  Optimize punching-hole code.
- patches.fixes/ocfs2-print-node-when-tcp-fails: ocfs2: print
  node # when tcp fails.
- patches.fixes/ocfs2-replace-ushort_max-short_max-and-short_min-with-ushrt_max-shrt_max-and-shrt_min:
  ocfs2: replace USHORT_MAX, SHORT_MAX and SHORT_MIN with
  USHRT_MAX, SHRT_MAX and SHRT_MIN.
- patches.fixes/ocfs2-reset-status-if-we-want-to-restart-file-extension:
  ocfs2: Reset status if we want to restart file extension.
- patches.fixes/ocfs2-reset-xattr-value-size-after-xa_cleanup_value_truncate:
  ocfs2: Reset xattr value size after xa_cleanup_value_truncate().
- patches.fixes/ocfs2-silence-gcc-warning-in-ocfs2_write_zero_page:
  ocfs2: Silence gcc warning in ocfs2_write_zero_page().
- patches.fixes/ocfs2-tighten-up-strlen-checking: ocfs2: tighten
  up strlen() checking.
- patches.fixes/ocfs2-trivial-code-cleanup-for-allocation-reservation:
  ocfs2/trivial: Code cleanup for allocation reservation.
- patches.fixes/ocfs2-update-gfp-slab-h-includes: ocfs2: update
  gfp/slab.h includes.
- patches.fixes/ocfs2-use-ocfs2_alloc_dinode_update_counts-instead-o.patch:
  Refresh.
- patches.fixes/ocfs2-wrap-signal-blocking-in-void-functions:
  ocfs2: Wrap signal blocking in void functions.
- patches.fixes/tree-wide-assorted-spelling-fixes: tree-wide:
  Assorted spelling fixes.
- patches.fixes/tree-wide-fix-typos-offest-offset: tree-wide:
  fix typos "offest" -> "offset" MIME-Version: 1.0 Content-Type:
  text/plain; charset=UTF-8 Content-Transfer-Encoding: 8bit.
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Wed Oct  6 2010 tiwai@suse.de
- patches.drivers/lis3-add-support-for-hp-2011-bnb: Refresh.
  Yet another machine entry.
* Wed Oct  6 2010 tiwai@suse.de
- patches.drivers/lis3-add-support-for-hp-2011-bnb: Refresh.
  Add a DMI entry for another new model.
* Wed Oct  6 2010 hare@suse.de
- patches.fixes/libfc-add-retry-logic-to-lport: libfc: Add retry
  logic to fp_lport (bnc#640276).
- patches.fixes/libfc-adds-flogi-retry: libfc: add flogi retry
  for non-zero DID (bnc#640276).
* Wed Oct  6 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-81-add-support-for-new-idt-codecs:
  ALSA: hda - Adding support for new IDT 92HD87XX codecs
  (bnc#643909, bnc#643922, bnc#643914).
* Tue Oct  5 2010 hare@suse.de
- patches.drivers/qla2xxx-drop-reference-before-wait-for-completion:
  Reshuffle to keep series2git happy.
* Tue Oct  5 2010 jkosina@suse.cz
- patches.fixes/i915-rephrase-pwrite-bounds-checking.patch:
  drm/i915: Rephrase pwrite bounds checking to avoid any potential
  overflow (bnc#642009 CVE-2010-2962).
- patches.fixes/i915-sanity-check-pread-pwrite.patch: drm/i915:
  Sanity check pread/pwrite (bnc#642009 CVE-2010-2962).
* Tue Oct  5 2010 hare@suse.de
- patches.drivers/qla2xxx-drop-reference-before-wait-for-completion:
  Update patche after suggestion from Mike C.
* Tue Oct  5 2010 nfbrown@suse.de
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch-fix2:
  Another fix for race problem with sunrpc cache deferal
  (bnc#632568, bnc#636461).
* Mon Oct  4 2010 mmarek@suse.de
- Update reference module symbol versions.
* Sat Oct  2 2010 jslaby@suse.de
- Update to 2.6.32.24
* Fri Oct  1 2010 bphilips@suse.de
- patches.drivers/ixgbe-net-decreasing-real_num_tx_queues-needs-to-flush-qdi.patch:
  net: decreasing real_num_tx_queues needs to flush qdisc
  (bnc#625674).
- patches.fixes/sched-qdisc_reset_all_tx-is-calling-qdisc_reset-with.patch:
  sched: qdisc_reset_all_tx is calling qdisc_reset without
  qdisc_lock (bnc#625674).
* Fri Oct  1 2010 jslaby@suse.de
- patches.kabi/revert-struct-zone-change.patch: Fix struct zone
  kabi breakage.
- patches.suse/SoN-08-mm-page_alloc-emerg.patch: Refresh.
- patches.kabi/revert-mm-page-allocator-calculate-a-better-estimate.patch:
  Delete.
* Fri Oct  1 2010 hare@suse.de
- patches.drivers/qla2xxx-drop-reference-before-wait-for-completion:
  qla2xxx: Drop srb reference before waiting for completion
  (bnc#641247).
* Fri Oct  1 2010 jkosina@suse.cz
- patches.kabi/compat-make-compat_alloc_user_space-incorporate-the-access_ok-API-fixup-GENKSYMS.patch:
  hide kABI checker false positive coming from
  compat_alloc_userspace() fix (CVE-2010-3081 bnc#639709).
- patches.kabi/compat-make-compat_alloc_user_space-incorporate-the-access_ok-API-fixup.patch:
  compat-make-compat_alloc_user_space-incorporate-the-access_ok -
  API fixup (CVE-2010-3081 bnc#639709).
* Fri Oct  1 2010 hare@suse.de
- patches.fixes/scsi-dh-check-for-sdev-state-before-calling-activate:
  Fixup typo.
* Fri Oct  1 2010 hare@suse.de
- patches.fixes/scsi-dh-check-for-sdev-state-before-calling-activate:
  scsi_dh: Check for sdev state in scsi_dh_activate()
  (bnc#616080).
* Fri Oct  1 2010 hare@suse.de
- patches.drivers/mpt-fusion-hold-off-error-recovery: fusion:
  hold off error recovery while alternate ioc is initializing
  (bnc#618059).
* Fri Oct  1 2010 mgalbraith@suse.de
- patches.fixes/sched-fix-kill-migration-thread-in-CPU_POST_DEAD-suspend-regression:
  sched: fix kill migration thread in CPU_POST_DEAD suspend regression (bnc#642449).
* Wed Sep 29 2010 rjw@suse.de
- patches.fixes/PM-Hibernate-Make-some-boot-messages-look-less-scary.patch:
  PM / Hibernate: Make some boot messages look less scary
  (bnc#614226).
* Tue Sep 28 2010 jslaby@suse.de
- patches.kabi/input-compat-include-avoidance.patch: input:
  do not include input-compat.h.
- patches.kabi/0001-Revert-Input-add-compat-support-for-sysfs-and-proc-c.patch:
  Delete.
* Tue Sep 28 2010 rjw@suse.de
- patches.arch/x86-UV-Fix-initialization-of-max_pnode.patch: x86 /
  UV: Fix initialization of max_pnode (bnc#638618, FATE#306952).
* Tue Sep 28 2010 rjw@suse.de
- patches.arch/x86-uv-xpc_disconnect_fix.patch: x86 / UV: Fix
  handling of XPC channel messages coming too late (bnc#638613,
  FATE#306952).
* Tue Sep 28 2010 jslaby@suse.de
- patches.kabi/0001-Revert-Input-add-compat-support-for-sysfs-and-proc-c.patch:
  Revert "Input: add compat support for sysfs and /proc
  capabilities output".
- patches.kabi/0001-Revert-mm-page-allocator-calculate-a-better-estimate.patch:
  Revert "mm: page allocator: calculate a better estimate of
  NR_FREE_PAGES when memory is low and kswapd is awake".
- patches.kabi/emu10k1-snd_emu10k1-guard.patch: emu10k1: guard
  struct snd_emu10k1 kABI changes.
- patches.suse/SoN-08-mm-page_alloc-emerg.patch: Refresh.
  Another bunch of kabi fixes. Now it should build, however the two of them
  need be resolved properly.
* Tue Sep 28 2010 jslaby@suse.de
- patches.kabi/sched_sched_class_kABI_guard.patch: sched: guard
  struct sched_class kABI changes.
- patches.kabi/sched_struct_rq_kABI_guard.patch: sched: guard
  struct rq kABI changes.
- patches.kabi/sched_struct_sched_domain_kABI_guard.patch: sched:
  guard struct sched_domain kABI changes.
* Mon Sep 27 2010 jslaby@suse.de
- Update to 2.6.32.23:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.drivers/alsa-sp1-hda-55-alc259-hp-pin-fix
  - patches.drivers/cxgb3-fix-hot-plug-removal-crash.patch
  - patches.drivers/drm-i915-add-reclaimable-to-i915-self-reclaimable-page
  - patches.drivers/drm-i915-fix-hibernation-since-i915-self-reclaim-fix
  - patches.fixes/alsa-seq-oss-fix-double-free-at-error-path-of-snd_seq_oss_open
  - patches.fixes/can-add-limit-for-nframes-and-clean-up-signed-unsigned-variables
  - patches.fixes/char-Mark-dev-zero-and-dev-kmem-as-not-capable-of-wr.patch
  - patches.fixes/compat-make-compat_alloc_user_space-incorporate-the-access_ok
  - patches.fixes/drivers-net-cxgb3-cxgb3_main-c-prevent-reading-uninitialized-stack-memory
  - patches.fixes/drivers-net-eql-c-prevent-reading-uninitialized-stack-memory
  - patches.fixes/drivers-net-usb-hso-c-prevent-reading-uninitialized-memory
  - patches.fixes/drm-stop-information-leak-of-old-kernel-stack
  - patches.fixes/ext4-consolidate-in_range-definitions
  - patches.fixes/irda-correctly-clean-up-self-ias_obj-on-irda_bind-failure
  - patches.fixes/keys-fix-bug-in-keyctl_session_to_parent-if-parent-has-no-session-keyring
  - patches.fixes/keys-fix-rcu-no-lock-warning-in-keyctl_session_to_parent
  - patches.fixes/kill-migration-thread-in-CPU_POST_DEAD-instead-of-CPU_DEAD.diff
  - patches.fixes/ocfs2-dont-overwrite-error-codes-in-ocfs2_init_acl.patch
  - patches.fixes/ocfs2-fix-incorrect-checksum-validation.patch
  - patches.fixes/ocfs2-fix-the-nested-PR.patch
  - patches.fixes/revert_c6fc81afa2d7ef2f775e48672693d8a0a8a7325d.diff
  - patches.fixes/sched-cleanup-select_task_rq_fair
  - patches.fixes/sched-cpuacct-percpu-counter-batch.patch
  - patches.fixes/sched-fix-vmark-regression
  - patches.fixes/sched-more-generic_WAKE_AFFINE
  - patches.fixes/tracing-t_start-reset-ftrace_iter_hash-in-case-of-seek-pread
  - patches.fixes/use-rcu-lock-in-setpgid.patch
  - patches.fixes/wireless-extensions-fix-kernel-heap-content-leak
  - patches.fixes/x86-64-compat-retruncate-rax-after-ia32-syscall-entry-tracing
  - patches.fixes/x86-64-compat-test-rax-for-the-syscall-number-not-eax
  - patches.fixes/xfs-prevent-reading-uninitialized-stack-memory
- Update config files.
- patches.fixes/fix-guard-page-revert-side-effect.patch: mm:
  use addr instead of start to adjust guard page.
- patches.fixes/mm-independent-rr-slab.patch: Refresh.
- patches.fixes/mm-pagealloc-fix-congestion-wait.patch: Refresh.
- patches.fixes/sched-sysctl-for-normalized-tunables: Refresh.
- patches.kabi/revert-mm-make-the-mlock-stack-guard-page-checks-stricter.patch:
  Revert "mm: make the mlock() stack guard page checks stricter".
- patches.kabi/revert-mm-make-the-vma-list-be-doubly-linked.patch:
  Revert "mm: make the vma list be doubly linked".
- patches.kabi/sched_entity-put-back-nr_forced2_migrations.patch:
  Revert nr_forced2_migrations removal from sched_entity
- patches.kernel.org/revert-guard-page-for-stacks-that-grow-upwards.patch:
  Revert "guard page for stacks that grow upwards".
- patches.kernel.org/revert-mm-fix-page-table-unmap-for-stack-guard-page-properly.patch:
  Revert "mm: fix page table unmap for stack guard page properly".
- patches.kernel.org/revert-mm-make-stack-guard-page-logic-use-vm_prev-pointer.patch:
  Revert "mm: make stack guard page logic use vm_prev pointer".
- patches.suse/SoN-08-mm-page_alloc-emerg.patch: Refresh.
- patches.suse/staging-hyper-v-added-all-patches-for-hyper-v-same-as-2.6.35-now.patch:
  Refresh.
- patches.xen/xen3-patch-2.6.32.20-21: Refresh.
* Mon Sep 27 2010 hare@suse.de
- patches.fixes/scsi-dh-alua-handle-all-states: Add missing
  include.
* Mon Sep 27 2010 knikanth@suse.de
- patches.fixes/scsi-error-netlink-GFP_ATOMIC.patch: scsi mid
  layer passes the wrong allocation flag to netlink (bnc#638400).
* Mon Sep 27 2010 hare@suse.de
- patches.fixes/scsi-dh-alua-handle-all-states: scsi_dh_alua:
  Update to handle all states correctly (bnc#600043).
* Mon Sep 27 2010 hare@suse.de
- patches.drivers/aacraid-24702-update: aacraid race condition
  (bnc#636850).
* Thu Sep 23 2010 jeffm@suse.de
- patches.fixes/rose-fix-signedness-issues-wrt-digi-count:
  rose: Fix signedness issues wrt. digi count (CVE-2010-3310
  bnc#640721).
* Thu Sep 23 2010 knikanth@suse.de
- patches.suse/lock_page-speedup-avoid-cacheline-bouncing.patch:
  Delete. Causes lockup. (bnc#629170)
* Wed Sep 22 2010 tiwai@suse.de
- patches.drivers/lis3-add-support-for-hp-2011-bnb: hp_accel:
  Add axis-mapping for HP 2011 BNB models (bnc#639197).
* Wed Sep 22 2010 tiwai@suse.de
- patches.drivers/lis3-hp3dc-chip-support: lis3: Add support
  for new LIS3DC / HP3DC chip (bnc#639197).
* Wed Sep 22 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.22 (bnc#633733, bnc#638807).
- patches.xen/1026-blktap2-PG_reserved.patch: blktap2: eliminate bogus
  clearing of PG_reserved (bnc#624814).
- patches.xen/1027-lock-runqueue-xtime.patch: xen/x86: eliminate
  nesting of run-queue locks inside xtime_lock.
- patches.xen/1031-x86-privcmd-enoent.patch: xen/x86: make
  __direct_remap_pfn_range()'s return value meaningful (FATE#310510).
- patches.xen/1032-netback-add-sched-list-irqs.patch: xen: netback:
  save interrupt state in add_to_net_schedule_list_tail.
- patches.xen/1033-swiotlb-sync-bidirectional.patch: fix swiotlb sync
  functions to properly deal with DMA_BIDIRECTIONAL.
- patches.xen/xen-kzalloc: use kzalloc() in favor of
  kmalloc()+memset().
- patches.xen/sfc-kzalloc: use kzalloc() in favor of
  kmalloc()+memset().
- patches.xen/xen-blkfront-scsi_cmd_ioctl: blkfront: forward
  unknown IOCTLs to scsi_cmd_ioctl for /dev/sdX (bnc#639944).
- patches.xen/xen3-amd_nb_early_access_oops.patch: x86: AMD
  Northbridge: Verify NB's node is online (bnc#637944).
- patches.xen/xen3-revert-x86-don-t-send-sigbus-for-kernel-page-faults.patch:
  Revert "x86: don't send SIGBUS for kernel page faults".
- Update Xen config files.
* Wed Sep 22 2010 hare@suse.de
- patches.fixes/iscsi-set-sk_err-on-conn-stop: Root on multipath
  goes into unresponsive state for a long time (bnc#620443).
* Tue Sep 21 2010 bphilips@suse.de
- patches.drivers/cxgb3-Add-register-bit-definition-for-Fatal-Parity-E.patch:
  cxgb3: Add register bit definition for Fatal Parity Error
  (bnc#637639).
- patches.drivers/cxgb3-Avoid-flush_workqueue-deadlock.patch:
  cxgb3: Avoid flush_workqueue() deadlock (bnc#637639).
- patches.drivers/cxgb3-Leave-interrupts-for-fatal-errors-asserted-in-.patch:
  cxgb3: Leave interrupts for fatal errors asserted in common code
  (bnc#637639).
- patches.drivers/cxgb3-Set-FATALPERREN.patch: cxgb3: Set
  FATALPERREN (bnc#637639).
- patches.drivers/cxgb3-fix-hot-plug-removal-crash.patch: cxgb3:
  fix hot plug removal crash (bnc#637639).
- patches.drivers/cxgb3-remove-undefined-operations.patch:
  net/cxgb3: remove undefined operations.
- patches.fixes/infiniband_cxgb3_improve_dlpar_remove_on_active_rdma_traffic.patch:
  Remove changes included in fix hot plug removal crash
* Tue Sep 21 2010 jkosina@suse.cz
- patches.fixes/elousb-firmware-m-quirk.patch: fix build
- patches.fixes/elousb-firmware-m-quirk.patch: handle return value
  from input_register_dev() properly
* Tue Sep 21 2010 jkosina@suse.cz
- patches.fixes/elousb-firmware-m-quirk.patch: Elo touchscreen
  firmware M workaround (bnc#633593).
* Tue Sep 21 2010 jack@suse.de
- patches.fixes/bdi-Fix-warnings-in-__mark_inode_dirty-for-dev-zero-.patch:
  bdi: Fix warnings in __mark_inode_dirty for /dev/zero and
  friends (bnc#618072).
- patches.fixes/char-Mark-dev-zero-and-dev-kmem-as-not-capable-of-wr.patch:
  char: Mark /dev/zero and /dev/kmem as not capable of writeback
  (bnc#618072).
* Mon Sep 20 2010 mfasheh@suse.com
- patches.fixes/ocfs2-dont-overwrite-error-codes-in-ocfs2_init_acl.patch:
  ocfs2: do not overwrite error codes in ocfs2_init_acl
  (bnc#639161).
* Mon Sep 20 2010 hare@suse.de
- patches.suse/scsi-netlink-ml-module-param: kernel crash in
  netlink_broadcast (bnc#620654).
* Mon Sep 20 2010 trenn@suse.de
- patches.fixes/x86_acer_acpi_ec_call_reg_blacklist.patch:
  Call _Reg(0x3, 0x1) method in EC namespace if EC got set up,
  even there is on EC OpRegion (bnc#636561).
* Mon Sep 20 2010 trenn@suse.de
- patches.arch/amd_nb_early_access_oops.patch: x86: AMD
  Northbridge: Verify NB's node is online (bnc#637944).
* Sun Sep 19 2010 jkosina@suse.de
- patches.xen/xen3-x86-64-compat-test-rax-for-the-syscall-number-not-eax:
  Refresh to apply without fuzz gained in the fasttrack branch.
* Fri Sep 17 2010 mmarek@suse.cz
- Temporarily disable kabi checking for s390, the kabi will change
  for the next update.
- kabi/s390x/symsets-default.tar.gz: Delete.
- kabi/s390x/symsets-trace.tar.gz: Delete.
- kabi/s390x/symtypes-default: Delete.
- kabi/s390x/symtypes-trace: Delete.
- kabi/s390x/symvers-default: Delete.
- kabi/s390x/symvers-trace: Delete.
* Fri Sep 17 2010 jbeulich@novell.com
- patches.xen/xen3-x86-64-compat-retruncate-rax-after-ia32-syscall-entry-tracing:
  x86-64, compat: Retruncate rax after ia32 syscall entry tracing
  (CVE-2010-3301 bnc#639708).
- patches.xen/xen3-x86-64-compat-test-rax-for-the-syscall-number-not-eax:
  x86-64, compat: Test %%rax for the syscall number, not %%eax
  (CVE-2010-3301 bnc#639708).
* Fri Sep 17 2010 jeffm@suse.de
- patches.fixes/niu-fix-kernel-buffer-overflow-for-ethtool_grxclsrlall:
  niu: Fix kernel buffer overflow for ETHTOOL_GRXCLSRLALL
  (CVE-2010-3084 bnc#638274).
* Fri Sep 17 2010 jeffm@suse.de
- patches.fixes/execve-improve-interactivity-with-large-arguments:
  execve: improve interactivity with large arguments (bnc#635425).
- patches.fixes/execve-make-responsive-to-sigkill-with-large-arguments:
  execve: make responsive to SIGKILL with large arguments
  (bnc#635425).
- patches.fixes/setup_arg_pages-diagnose-excessive-argument-size:
  setup_arg_pages: diagnose excessive argument size (bnc#635425).
* Fri Sep 17 2010 jeffm@suse.de
- patches.fixes/wext-fix-potential-private-ioctl-memory-content-leak:
  wext: fix potential private ioctl memory content leak
  (CVE-2010-2955 bnc#635413).
* Thu Sep 16 2010 jeffm@suse.de
- patches.fixes/wireless-extensions-fix-kernel-heap-content-leak:
  wireless extensions: fix kernel heap content leak (CVE-2010-2955
  bnc#635413).
* Thu Sep 16 2010 jeffm@suse.de
- patches.fixes/keys-fix-bug-in-keyctl_session_to_parent-if-parent-has-no-session-keyring:
  KEYS: Fix bug in keyctl_session_to_parent() if parent has no
  session keyring (CVE-2010-2960 bnc#634637).
- patches.fixes/keys-fix-rcu-no-lock-warning-in-keyctl_session_to_parent:
  KEYS: Fix RCU no-lock warning in keyctl_session_to_parent()
  (CVE-2010-2960 bnc#634637).
* Thu Sep 16 2010 jeffm@suse.de
- patches.fixes/alsa-seq-oss-fix-double-free-at-error-path-of-snd_seq_oss_open:
  ALSA: seq/oss - Fix double-free at error path of
  snd_seq_oss_open() (CVE-2010-3080 bnc#638277).
* Thu Sep 16 2010 bphilips@suse.de
- patches.drivers/net-next-Fix-an-overflow-bug-in-vmxnet3-Tx-descripto.patch:
  net-next: Fix an overflow bug in vmxnet3 Tx descriptor
  (bnc#624020).
- patches.drivers/net-next-fix-LRO-feature-update-in-vmxnet3.patch:
  net-next: fix LRO feature update in vmxnet3 (bnc#624020).
- patches.drivers/net-next-vmxnet3-fixes-2-5-Interrupt-control-bitmap.patch:
  net-next: vmxnet3 fixes [2/5] Interrupt control bitmap
  (bnc#624020).
- patches.drivers/net-next-vmxnet3-fixes-3-5-Initialize-link-state-at-.patch:
  net-next: vmxnet3 fixes [3/5] Initialize link state at probe
  time (bnc#624020).
- patches.drivers/net-next-vmxnet3-fixes-4-5-Do-not-reset-when-the-dev.patch:
  net-next: vmxnet3 fixes [4/5] Do not reset when the device is
  not opened (bnc#624020).
- patches.drivers/net-next-vmxnet3-fixes-5-5-Respect-the-interrupt-typ.patch:
  net-next: vmxnet3 fixes [5/5] Respect the interrupt type in
  VM configuration (bnc#624020).
* Thu Sep 16 2010 jeffm@suse.de
- patches.fixes/x86-64-compat-retruncate-rax-after-ia32-syscall-entry-tracing:
  x86-64, compat: Retruncate rax after ia32 syscall entry tracing
  (CVE-2010-3301 bnc#639708).
- patches.fixes/x86-64-compat-test-rax-for-the-syscall-number-not-eax:
  x86-64, compat: Test %%rax for the syscall number, not %%eax
  (CVE-2010-3301 bnc#639708).
* Thu Sep 16 2010 jeffm@suse.de
- patches.fixes/compat-make-compat_alloc_user_space-incorporate-the-access_ok:
  compat: Make compat_alloc_user_space() incorporate the
  access_ok() (CVE-2010-3081 bnc#639709).
* Thu Sep 16 2010 bphilips@suse.de
- patches.fixes/net-enable-GRO-by-default-for-vlan-devices.patch:
  net: enable GRO by default for vlan devices (bnc#582730).
* Thu Sep 16 2010 knikanth@suse.de
- patches.suse/lock_page-speedup-avoid-cacheline-bouncing.patch:
  UV - PERF cacheline contention in __lock_page reclaiming pages
  from pagecache (bnc#629170).
* Thu Sep 16 2010 jslaby@suse.de
- patches.fixes/use-rcu-lock-in-setpgid.patch: pid: make setpgid()
  system call use RCU read-side critical section (bnc#639728).
* Wed Sep 15 2010 jeffm@suse.de
- patches.fixes/xfs-prevent-reading-uninitialized-stack-memory:
  Update references (CVE-2010-3078 bnc#637436).
* Wed Sep 15 2010 jeffm@suse.de
- patches.fixes/tracing-t_start-reset-ftrace_iter_hash-in-case-of-seek-pread:
  tracing: t_start: reset FTRACE_ITER_HASH in case of seek/pread
  (CVE-2010-3079 bnc#637502).
* Wed Sep 15 2010 jeffm@suse.de
- patches.fixes/drivers-net-usb-hso-c-prevent-reading-uninitialized-memory:
  drivers/net/usb/hso.c: prevent reading uninitialized memory
  (CVE-2010-3298 bnc#639483).
* Wed Sep 15 2010 jeffm@suse.de
- patches.fixes/drivers-net-cxgb3-cxgb3_main-c-prevent-reading-uninitialized-stack-memory:
  drivers/net/cxgb3/cxgb3_main.c: prevent reading uninitialized
  stack memory (CVE-2010-3296 bnc#639481).
* Wed Sep 15 2010 jeffm@suse.de
- patches.fixes/drivers-net-eql-c-prevent-reading-uninitialized-stack-memory:
  drivers/net/eql.c: prevent reading uninitialized stack memory
  (CVE-2010-3297 bnc#639482).
* Wed Sep 15 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-80-acer-quirk: ALSA: hda - Add
  quirk for Acer laptop with CX20585 codec (bnc#638860).
* Wed Sep 15 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-79-conexant-5066-support: ALSA:
  backport Conexant CX2058 chip support (bnc#638860).
* Tue Sep 14 2010 gregkh@suse.de
- patches.suse/staging-hyper-v-added-all-patches-for-hyper-v-same-as-2.6.35-now.patch:
  staging: hyper-v: Added all patches for Hyper-V - same as
  2.6.35 now (bnc#618379).
* Tue Sep 14 2010 jdelvare@suse.de
- patches.drivers/e1000e-remove-use-of-skb_dma_map.patch: e1000e:
  remove use of skb_dma_map (bnc#633268).
- patches.drivers/igb-remove-use-of-skb_dma_map.patch: igb:
  remove use of skb_dma_map (bnc#633268).
* Mon Sep 13 2010 rjw@suse.de
- patches.arch/ACPICA-Optimization-Reduce-the-number-of-namespace-walks.patch:
  ACPICA: Optimization: Reduce the number of namespace walks
  (bnc#601520, FATE#306952).
- patches.arch/ACPICA-Performance-enhancement-for-namespace-search-and-access.patch:
  ACPICA: Performance enhancement for namespace search and access
  (bnc#601520, FATE#306952).
* Mon Sep 13 2010 jdelvare@suse.de
- patches.fixes/bonding-jiffies2.patch: Update patch-mainline.
* Wed Sep  8 2010 hare@suse.de
- patches.suse/libfc-fix-remote-port-restart-problem:
  Modify to not break kABI.
* Wed Sep  8 2010 hare@suse.de
- patches.suse/libfc-fix-indefinite-rport-restart:
  Modify to not break kABI.
* Wed Sep  8 2010 jack@suse.de
- patches.fixes/ocfs2-grab_cache_page-recursion-fix: ocfs2:
  Avoid recursing into filesystems when allocating memory with
  filesystem locks held (bnc#633543).
* Tue Sep  7 2010 jeffm@suse.com
- patches.fixes/xfs-prevent-reading-uninitialized-stack-memory:
  xfs: prevent reading uninitialized stack memory (bnc#637436).
* Tue Sep  7 2010 hare@suse.de
- patches.fixes/iscsi-make-recovery_tmo-configurable:
  iscsi_transport: Modify recovery_tmo from sysfs (bnc#620443).
* Tue Sep  7 2010 hare@suse.de
- patches.fixes/scsi-update-fc_block_scsi_eh:
  Reenable.
* Tue Sep  7 2010 hare@suse.de
- patches.suse/libfc-fix-indefinite-rport-restart: libfc: fix
  indefinite rport restart (bnc#626880).
- patches.suse/libfc-fix-remote-port-restart-problem: libfc:
  Fix remote port restart problem (bnc#626880).
* Mon Sep  6 2010 nfbrown@suse.de
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch-fix:
  Fix race in sunrpc/cache introduced by patch to allow thread
  to block while waiting for cache update (bnc#632568).
- patches.fixes/nfsd-09-fix-kabi: Refresh.
- patches.fixes/sunrpc-monotonic-expiry: Refresh.
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  Refresh.
* Sat Sep  4 2010 jjolly@suse.de
- patches.arch/s390-21-01-qeth_connection_isolation_keep_reply.patch:
  qeth: timeout on connection isolation configuration errors
  (bnc#631075,LTC#66486).
- patches.arch/s390-21-02-dasd-fix-cqr-flags-in-erp.patch:
  dasd: let recovery cqr inherit flags from failed cqr
  (bnc#631075,LTC#66750).
- patches.arch/s390-22-tlb-proc-race.patch: kernel: fork vs
  /proc/stat race (bnc#635515,LTC#66686).
* Fri Sep  3 2010 jeffm@suse.com
- patches.fixes/irda-correctly-clean-up-self-ias_obj-on-irda_bind-failure:
  irda: Correctly clean up self->ias_obj on irda_bind() failure
  (CVE-2010-2954 bnc#636112).
* Fri Sep  3 2010 hare@suse.de
- patches.fixes/scsi-update-fc_block_scsi_eh: Disable
  until testing is complete.
* Fri Sep  3 2010 hare@suse.de
- patches.fixes/scsi-update-fc_block_scsi_eh: Fixup patch
  to handle FAST_IO_FAIL from error handler correctly (bnc#613330).
* Thu Sep  2 2010 hare@suse.de
- patches.fixes/scsi-update-fc_block_scsi_eh: Device offlined
  while array is momentarily unavailable (bnc#613330).
* Thu Sep  2 2010 hare@suse.de
- patches.fixes/scsi-return-needs-retry-for-busy-eh-cmds: Return
  NEEDS_RETRY for eh commands with status BUSY (bnc#613330).
* Thu Sep  2 2010 rjw@suse.de
- Fix ordering of patches in series.conf
* Wed Sep  1 2010 rjw@suse.de
- patches.arch/x86-UV-map-ACPI-tables-as-cacheable.patch: x86 /
  UV: Map ACPI tables as cacheable (bnc#632974, FATE#306952).
* Wed Sep  1 2010 rjw@suse.de
- patches.arch/x86_64-numa-Cacheline-aliasing-makes-for_each_populated_zone-extremely-expensive-V2.patch:
  Update references (bnc#632975, FATE#306952).
* Wed Sep  1 2010 jeffm@suse.com
- patches.kabi/drm-block-userspace-under-allocating-buffer-and-having-drivers-overwrite-it-v2:
  KABI: Workaround drm_ioctl_desc->cmd_drv addition.
* Wed Sep  1 2010 jeffm@suse.com
- patches.fixes/jfs-don-t-allow-os2-xattr-namespace-overlap-with-others:
  Delete.
* Wed Sep  1 2010 jeffm@suse.com
- patches.fixes/jfs-don-t-allow-os2-xattr-namespace-overlap-with-others:
  jfs: don't allow os2 xattr namespace overlap with others
  (CVE-2010-2946 bnc#633585).
* Wed Sep  1 2010 jeffm@suse.com
- patches.fixes/can-add-limit-for-nframes-and-clean-up-signed-unsigned-variables:
  can: add limit for nframes and clean up signed/unsigned
  variables (bnc#633581 CVE-2010-2959).
* Tue Aug 31 2010 rjw@suse.de
- patches.arch/x86-fix_irq_assignment-on-NUMA-systems.patch: x86:
  Fix irq vector assignment on large NUMA systems (bnc#622727,
  FATE#306952).
* Tue Aug 31 2010 jeffm@suse.com
- patches.fixes/net-sched-fix-some-kernel-memory-leaks: net sched:
  fix some kernel memory leaks (CVE-2010-2942 bnc#632309).
* Tue Aug 31 2010 jeffm@suse.com
- patches.fixes/ext4-consolidate-in_range-definitions: ext4:
  consolidate in_range() definitions (CVE-2010-3015 bnc#631801).
* Tue Aug 31 2010 jeffm@suse.com
- patches.fixes/drm-block-userspace-under-allocating-buffer-and-having-drivers-overwrite-it-v2:
  drm: block userspace under allocating buffer and having drivers
  overwrite it (v2) (bnc#628604).
* Tue Aug 31 2010 jeffm@suse.com
- patches.fixes/drm-stop-information-leak-of-old-kernel-stack:
  drm: stop information leak of old kernel stack (bnc#628604
  CVE-2010-2803).
* Tue Aug 31 2010 duwe@suse.de
- patches.arch/ppc-huge-page-pte: Fix bugs in huge page hashing
  (bnc#625167).
* Tue Aug 31 2010 jdelvare@suse.de
- patches.fixes/bonding-jiffies2.patch: Forgot to refresh
  before committing, sorry.
* Tue Aug 31 2010 jdelvare@suse.de
- patches.fixes/bonding-jiffies2.patch: fix jiffies overflow
  problems in bonding (bnc#613273).
* Tue Aug 31 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-78-add-id-for-the-CougarPoint-chipset:
  ALSA: intelhdmi - add id for the CougarPoint chipset
  (bnc#630068).
* Mon Aug 30 2010 knikanth@suse.de
- patches.arch/uv-rotor-init-random.patch: Delete. Patch reverted
  in mainline as well, due to build failure in IA64. (bnc#602150)
* Mon Aug 30 2010 knikanth@suse.de
- patches.arch/uv-rotor-init-random.patch: cpusets: randomize
  node rotor used in cpuset_mem_spread_node() (bnc#602150).
* Thu Aug 26 2010 rjw@suse.de
- patches.arch/x86_64-numa-Cacheline-aliasing-makes-for_each_populated_zone-extremely-expensive-V2.patch:
  x86_64 / NUMA: Cacheline aliasing makes for_each_populated_zone
  extremely expensive -V2 (bnc#630132, FATE#306952).
* Wed Aug 25 2010 rjw@suse.de
- patches.arch/x86-UV-fix-crash-on-UV-hubs-that-have-no-active-cpus.patch:
  x86 / UV: Fix crash on UV hubs that have no active cpus
  (bnc#630121, FATE#306952).
* Tue Aug 24 2010 rjw@suse.de
- patches.arch/x86-UV-Fix-uninitialized-uvhub_mask.patch: x86 /
  UV: Fix uninitialized uvhub_mask (bnc#630132, FATE#306952).
* Tue Aug 24 2010 tiwai@suse.de
- patches.drivers/iwl-add-LED-mode-option: iwlwifi: add LED mode
  to support different LED behavior (bnc#624340).
* Tue Aug 24 2010 tiwai@suse.de
- patches.drivers/ath9k-add-blink-module-parameter: ath9k:
  Add a module parameter to disable led blinking (bnc#624340).
* Mon Aug 23 2010 mhocko@suse.de
- patches.suse/SoN-08-mm-page_alloc-emerg.patch: Refresh.
- patches.fixes/vmstat-zone_low-fix.patch: Delete.
  Fix the low_wmark_pages directly in the offending patch.
* Sat Aug 21 2010 gregkh@suse.de
- kabi/severities: update the s390 wildcard as it wasn't picking up the proper
  match for the qeth driver.  Also add the s390 cio driver to the "PASS" list.
* Fri Aug 20 2010 gregkh@suse.de
- Update to 2.6.32.19:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.drivers/pci-disable-msi-on-K8M800
  - patches.fixes/PATCH-Skip-check-for-mandatory-locks-when-unlocking.patch
  - patches.fixes/acpi-fix-regression-where-_ppc-is-not-read-at-boot-even-when-ignore_ppc-0
  - patches.fixes/aic79xx-null-scb-in-nonpkt-busfree
  - patches.fixes/btrfs-add-btrfs_duplicate_item
  - patches.fixes/btrfs-add-delayed-iput
  - patches.fixes/btrfs-align-offsets-for-btrfs_ordered_update_i_size
  - patches.fixes/btrfs-apply-updated-fallocate-i_size-fix
  - patches.fixes/btrfs-avoid-orphan-inodes-cleanup-during-committing-transaction
  - patches.fixes/btrfs-avoid-orphan-inodes-cleanup-while-replaying-log
  - patches.fixes/btrfs-avoid-superfluous-tree-log-writeout
  - patches.fixes/btrfs-btrfs_mark_extent_written-uses-the-wrong-slot
  - patches.fixes/btrfs-check-return-value-of-open_bdev_exclusive-properly
  - patches.fixes/btrfs-check-total-number-of-devices-when-removing-missing
  - patches.fixes/btrfs-deal-with-null-acl-sent-to-btrfs_set_acl
  - patches.fixes/btrfs-deny-sys_link-across-subvolumes
  - patches.fixes/btrfs-do-not-mark-the-chunk-as-readonly-if-in-degraded-mode
  - patches.fixes/btrfs-do-not-try-and-lookup-the-file-extent-when-finishing-ordered-io
  - patches.fixes/btrfs-don-t-add-extent-0-to-the-free-space-cache-v2
  - patches.fixes/btrfs-fail-mount-on-bad-mount-options
  - patches.fixes/btrfs-fix-a-memory-leak-in-btrfs_init_acl
  - patches.fixes/btrfs-fix-btrfs_drop_extent_cache-for-skip-pinned-case
  - patches.fixes/btrfs-fix-disk_i_size-update-corner-case
  - patches.fixes/btrfs-fix-memory-leaks-in-error-paths
  - patches.fixes/btrfs-fix-missing-last-entry-in-readdir3
  - patches.fixes/btrfs-fix-oopsen-when-dropping-empty-tree
  - patches.fixes/btrfs-fix-per-root-used-space-accounting
  - patches.fixes/btrfs-fix-possible-panic-on-unmount
  - patches.fixes/btrfs-fix-race-between-allocate-and-release-extent-buffer
  - patches.fixes/btrfs-fix-race-in-btrfs_mark_extent_written
  - patches.fixes/btrfs-fix-regression-in-orphan-cleanup
  - patches.fixes/btrfs-kfree-correct-pointer-during-mount-option-parsing
  - patches.fixes/btrfs-make-error-return-negative-in-btrfs_sync_file
  - patches.fixes/btrfs-make-fallocate2-more-enospc-friendly
  - patches.fixes/btrfs-make-metadata-chunks-smaller
  - patches.fixes/btrfs-make-sure-fallocate-properly-starts-a-transaction
  - patches.fixes/btrfs-make-truncate2-more-enospc-friendly
  - patches.fixes/btrfs-pass-transaction-handle-to-security-and-acl-initialization-functions
  - patches.fixes/btrfs-remove-bug_on-due-to-mounting-bad-filesystem
  - patches.fixes/btrfs-rewrite-btrfs_drop_extents
  - patches.fixes/btrfs-run-orphan-cleanup-on-default-fs-root
  - patches.fixes/btrfs-show-discard-option-in-proc-mounts
  - patches.fixes/btrfs-use-correct-values-when-updating-inode-i_size-on-fallocate
  - patches.fixes/crypto-testmgr-fix-complain-about-lacking-test.patch
  - patches.fixes/dlm-fix-ordering-of-bast-and-cast.patch
  - patches.fixes/dlm-send-reply-before-bast.patch
  - patches.fixes/ext4-fix-optional-arg-mount-options
  - patches.fixes/ext4-make-sure-the-move_ext-ioctl-can-t-overwrite-append-only-files
  - patches.fixes/fix_clock_gettime_vsyscall_time_warp.diff
  - patches.fixes/ia64-fix-sba-iommu-to-handle-allocation-failure-properly
  - patches.fixes/ibmvscsi-add-barriers
  - patches.fixes/ibmvscsi-reduce-error-recovery-timeout
  - patches.fixes/kernel-mutex-adaptive-cpu-offline-livelock.patch
  - patches.fixes/loop-update-mtime.patch
  - patches.fixes/mandatory-lock-test
  - patches.fixes/mce_injection_enhancements_1668bfd5be9d8a52536c4865000fbbe065a3613b
  - patches.fixes/mce_injection_enhancements_9b9a29ecd75e310f75a9243e1c3538ad34598fcb
  - patches.fixes/md-write-behind-race
  - patches.fixes/nohz-delay-from-tip.diff
  - patches.fixes/ocfs2-Find-proper-end-cpos-for-a-leaf-refcount-block.patch
  - patches.fixes/ocfs2-set-MS_POSIXACL-on-remount.patch
  - patches.fixes/powerpc-eeh-fix-a-bug-when-pci-structure-is-null
  - patches.fixes/reiserfs-fix-oops-while-creating-privroot-with-selinux-enabled
  - patches.fixes/reiserfs-replay-honor-ro
  - patches.fixes/reuse-ktime-from-tip.diff
  - patches.fixes/sched-fix-cputime-monotonicity.patch
  - patches.fixes/sched-fix-task-times_granularity.patch
  - patches.fixes/x86_64_memory_hotplug_dev_mem.patch
  - patches.fixes/x86_ioapic_fix_out_of_order_gsi.patch
* Fri Aug 20 2010 gregkh@suse.de
- patches.kabi/kabi-acpi-guard-acpi_power_register-changes.patch:
  kabi: acpi: guard acpi_power_register changes.
* Fri Aug 20 2010 gregkh@suse.de
- patches.kabi/kabi-acpi-guard-acpi_processor_cx-changes: KABI:
  acpi: Guard acpi_processor_cx changes.
- patches.xen/xen3-auto-common.diff: Refresh.
- patches.xen/xen3-patch-2.6.32.16-17: Refresh.
* Fri Aug 20 2010 gregkh@suse.de
- kabi/severities: add drivers/ssb/* to the list of things we don't
  check the kabi for.
* Fri Aug 20 2010 gregkh@suse.de
- kabi/severities: add drivers/net/wireless/hostap/* to the list of
  things that we don't care about for kabi
* Fri Aug 20 2010 mhocko@suse.de
- patches.fixes/vmstat-zone_low-fix.patch: /proc/zoneinfo fix
  low watermark value.
* Wed Aug 18 2010 mgalbraith@suse.de
- patches.fixes/revert_c6fc81afa2d7ef2f775e48672693d8a0a8a7325d.diff:
  sched: revert 2.6.32-stable commit c6fc81a (bnc#615557).
* Tue Aug 17 2010 jack@suse.de
- patches.fixes/aio-ERESTARTSYS-handling.diff: aio: Do not return
  ERESTARTSYS as a result of AIO (bnc#612009).
* Tue Aug 17 2010 gregkh@suse.de
- patches.kabi/kabi-fix-up-struct-transacion_s-abi-change.patch:
  kabi: fix up struct transacion_s abi change.
* Mon Aug 16 2010 jslaby@suse.de
- patches.arch/x86-kdump-avoid-stack-dumps-fix.patch: x86, UV:
  Make kdump avoid stack dumps - fix !CONFIG_KEXEC breakage
  (bnc#616464).
- patches.arch/x86-kdump-avoid-stack-dumps.patch: x86, UV:
  Make kdump avoid stack dumps (bnc#616464).
* Sat Aug 14 2010 mfasheh@suse.com
- patches.fixes/ocfs2-fix-incorrect-checksum-validation.patch:
  ocfs2: Fix incorrect checksum validation error.
- patches.fixes/ocfs2-fix-metaecc-error-messages.patch: ocfs2:
  Fix metaecc error messages.
* Thu Aug 12 2010 gregkh@suse.de
- Update to 2.6.32.18
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.drivers/drm-i915-Fix-LVDS-presence-check
  - patches.drivers/drm-i915-parse-child-device-from-VBT
  - patches.drivers/e1000e-dont-inadvertently-re-set-INTX_DISABLE.patch
  - patches.fixes/gfs2-rename-causes-kernel-oops
  - patches.fixes/nfs-fix-acl-decoding
  - patches.kernel.org/cifs-fix-compile-error-with-__init-in-cifs_init_dns_resolver-definition.patch
  - patches.kernel.org/cifs-remove-__exit-mark-from-cifs_exit_dns_resolver.patch
* Thu Aug 12 2010 jslaby@suse.de
- patches.fixes/kdb-fix-ll.patch: kdb: break out of kdb_ll()
  when command is terminated (bnc#609172).
- patches.suse/kdb-bt-with-pt-regs.patch: KDB: fix backtrace
  failure (bnc#611094).
- patches.suse/kdb-fix-incomplete-backtrace.patch: Refresh.
* Wed Aug 11 2010 jack@suse.de
- patches.fixes/novfs-lindent: novfs: Lindent novfs source. Added to
  keep codebases among SLE11 SP1, 11.3, and master in sync.
* Wed Aug 11 2010 hare@suse.de
- patches.suse/qla2xxx-add-ql2xtargetreset-parm: Tape driver
  gets a rewind during boot (bnc#629552).
* Wed Aug 11 2010 jslaby@suse.cz
- patches.suse/rlim-0014-ipc-use-helpers-for-rlimits.patch: ipc:
  use rlimit helpers (FATE#305733).
- patches.suse/rlim-0015-SECURITY-add-task_struct-to-setrlimit.patch:
  rlimits: security, add task_struct to setrlimit (FATE#305733).
- patches.suse/rlim-0016-core-add-task_struct-to-update_rlimit_cpu.patch:
  rlimits: add task_struct to update_rlimit_cpu (FATE#305733).
- patches.suse/rlim-0017-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  rlimits: make sure ->rlim_max never grows in sys_setrlimit
  (FATE#305733).
- patches.suse/rlim-0017a--rlimits-selinux-do-rlimits-changes-under-task_lock.patch:
  rlimits: selinux, do rlimits changes under task_lock
  (FATE#305733).
- patches.suse/rlim-0018-core-split-sys_setrlimit.patch: rlimits:
  split sys_setrlimit (FATE#305733).
- patches.suse/rlim-0019-core-allow-setrlimit-to-non-current-tasks.patch:
  rlimits: allow setrlimit to non-current tasks (FATE#305733).
- patches.suse/rlim-0020-rlimits-do-security-check-under-task_lock.patch:
  rlimits: do security check under task_lock (FATE#305733).
- patches.suse/rlim-0021-FS-proc-switch-limits-reading-to-fops.patch:
  Refresh.
- patches.suse/rlim-0022-FS-proc-make-limits-writable.patch:
  Refresh.
- patches.suse/rlim-0020-core-optimize-setrlimit-for-current-task.patch:
  Delete.
  Refresh and update them because they were merged (some in
  slightly differrent form).
* Wed Aug 11 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.17.
* Tue Aug 10 2010 jeffm@suse.de
- patches.fixes/gfs2-rename-causes-kernel-oops: GFS2: rename
  causes kernel Oops (bnc#627386 CVE-2010-2798).
* Tue Aug 10 2010 jbohac@suse.cz
- patches.fixes/ipv6-fix-dad-race.patch: IPv6: fix DAD races
  (bnc#577967).
- patches.xen/ipv6-no-autoconf: Refresh.
* Sat Aug  7 2010 gregkh@suse.de
- patches.kabi/kabi-fix-up-struct-firmware-abi-change.patch:
  kabi: fix up struct firmware abi change.
* Sat Aug  7 2010 gregkh@suse.de
- patches.xen/xen3-auto-xen-arch.diff: Refresh.
* Fri Aug  6 2010 agruen@suse.de
- patches.fixes/nfs-fix-acl-decoding: nfs: fix acl decoding
  (bnc#629263).
* Fri Aug  6 2010 gregkh@suse.de
- patches.kernel.org/cifs-fix-compile-error-with-__init-in-cifs_init_dns_resolver-definition.patch:
  CIFS: Fix compile error with __init in cifs_init_dns_resolver()
  definition
- patches.kernel.org/cifs-remove-__exit-mark-from-cifs_exit_dns_resolver.patch:
  CIFS: Remove __exit mark from cifs_exit_dns_resolver().
* Fri Aug  6 2010 gregkh@suse.de
- Update to 2.6.32.17:
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.arch/ia64-64bit-spinaphore
  - patches.arch/x86-calgary-increase-max-phb-bus-num.patch
  - patches.drivers/drm-i915-Define-MI_ARB_STATE-bits
  - patches.drivers/drm-i915-enable-low-power-render-writes-on-GEN3-hardware
  - patches.drivers/igb-change-how-we-handle-alternate-mac-addresses.patch
  - patches.drivers/sky2-enable-rx-tx-in-sky2_phy_reinit.patch
  - patches.fixes/futex-futex_find_get_task-remove-credentails-check.patch
* Fri Aug  6 2010 gregkh@suse.de
- patches.kabi/revert-wrong-type-for-magic-argument-in-simple_fill_super-in-2.6.32.16.patch:
  Revert: wrong type for 'magic' argument in simple_fill_super()
  in 2.6.32.16.
* Thu Aug  5 2010 mfasheh@suse.com
- patches.fixes/ocfs2-Fix-orphan-add-in-ocfs2_create_inode_in_orphan.patch:
  ocfs2: Fix orphan add in ocfs2_create_inode_in_orphan
  (bnc#626321).
- patches.fixes/ocfs2-allow-return-of-new-inode-block-location-befor.patch:
  ocfs2: allow return of new inode block location before
  allocation of the inode (bnc#626321).
- patches.fixes/ocfs2-split-out-inode-alloc-code-from-ocfs2_mknod_lo.patch:
  ocfs2: split out inode alloc code from ocfs2_mknod_locked
  (bnc#626321).
- patches.fixes/ocfs2-split-out-ocfs2_prepare_orphan_dir-into-lockin.patch:
  ocfs2: split out ocfs2_prepare_orphan_dir() into locking and
  prep functions (bnc#626321).
- patches.fixes/ocfs2-use-ocfs2_alloc_dinode_update_counts-instead-o.patch:
  ocfs2: use ocfs2_alloc_dinode_update_counts() instead of open
  coding (bnc#626321).
* Thu Aug  5 2010 tiwai@suse.de
- patches.drivers/drm-i915-Fix-LVDS-presence-check: drm/i915:
  Fix LVDS presence check (bnc#621715).
- patches.drivers/drm-i915-parse-child-device-from-VBT: drm/i915:
  parse child device from VBT (bnc#621715).
* Thu Aug  5 2010 mmarek@suse.cz
- patches.kabi/ppc-add-perf_event-include: kabi: add
  linux/perf_event.h back to arch/powerpc/kernel/irq.c.
* Thu Aug  5 2010 jjolly@suse.de
- patches.arch/s390-20-01-etr-race.patch: kernel: etr clock
  synchronization race (bnc#627060,LTC#66220).
- patches.arch/s390-20-02-dasd-reserve-emergency-cqr.patch:
  dasd: allocate fallback cqr for reserve/release
  (bnc#627060,LTC#66227).
- patches.arch/s390-20-03-cio_use_all_paths.patch: cio: use all
  paths for some internal I/O (bnc#627060,LTC#66327).
* Wed Aug  4 2010 sjayaraman@suse.de
- patches.fixes/cifs-fix-vfs-busy-inode-errors: Revert the commit that fixes
  page refcount leak which is not required but causes hangs (bnc#627518).
* Wed Aug  4 2010 mmarek@suse.cz
- Update ppc64/vanilla config.
* Wed Aug  4 2010 trenn@suse.de
- patches.arch/x86_thinkpad_fix_x100e_s2ram.patch: thinkpad-acpi:
  X100e quick fixes (bnc#619002).
* Wed Aug  4 2010 bphilips@suse.de
- patches.drivers/tg3-Fix-IPv6-TSO-code-in-tg3_start_xmit_dma_bug.patch:
  tg3: Fix IPv6 TSO code in tg3_start_xmit_dma_bug().
* Wed Aug  4 2010 bphilips@suse.de
- patches.drivers/netxen-fix-register-usage.patch: netxen:
  fix register usage (bnc#600579).
* Tue Aug  3 2010 gregkh@suse.de
- patches.arch/ppc-extended_h_cede-add_offline_states: Refresh for
  query_cpu_stopped rename.
* Tue Aug  3 2010 gregkh@suse.de
- Update to 2.6.32.16
  - security fixes
  - lots of bugfixes
  - obsoletes:
  - patches.arch/ppc-public-query_cpu_stopped
  - patches.arch/ppc-start-only-stopped-cpus
  - patches.drivers/dmfe-tulip-Let-dmfe-handle-DM910x-except-for-SPARC-o.patch
  - patches.fixes/btrfs-should-add-a-permission-check-for-setfacl
  - patches.fixes/cifs-fix-oops-due-to-null-nameidata
  - patches.fixes/dm-snapshot-2TB-fix
  - patches.fixes/gfs2-fix-permissions-checking-for-setflags-ioctl
  - patches.fixes/ipmi-fix-deadlock.patch
  - patches.fixes/ixgbe-fix-return-of-invalid-txq.patch
  - patches.fixes/keys-find_keyring_by_name-can-gain-access-to-a-freed-keyring
  - patches.fixes/powerpc-fix-handling-of-strnlen-with-zero-len
  - patches.fixes/sctp-fix-skb_over_panic-resulting-from-multiple-invalid-parameter-errors
  - patches.fixes/virtio_net-make-delayed-refill-more-reliable.patch
* Mon Aug  2 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Package log.sh in the source rpm.
* Fri Jul 30 2010 gregkh@suse.de
- Update to 2.6.32.15:
  - bugfix
  - obsoletes:
  - patches.suse/revert-percpu-stable-changes.patch
* Fri Jul 30 2010 gregkh@suse.de
- Update to 2.6.32.14:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/s390-16-01-ptrace-fix-return-value.patch
  - patches.arch/x86-cacheinfo-turn-off-l3-cache-index-in-virtualized-envs.patch
  - patches.fixes/btrfs-check-for-read-permission-on-src-file-in-the-clone-ioctl
  - patches.fixes/proc-revert-provide-stack-info-01.patch
  - patches.fixes/proc-revert-provide-stack-info-02.patch
* Thu Jul 29 2010 bphilips@suse.de
- patches.drivers/netxen-fix-for-kdump.patch: netxen: fix for
  kdump (bnc#603464).
* Thu Jul 29 2010 nfbrown@suse.de
- patches.fixes/nfsd-allow-IPv6-sockets: NFSD: Support AF_INET6
  in svc_addsock() function (fate#307240).
- patches.fixes/nfsd-do-not-reg-v3-for-IPv6: Don't register
  NFSv2 and NFSv3 with portmap for IPv6 transports (FATE#307240).
* Wed Jul 28 2010 bphilips@suse.de
- patches.drivers/igb-change-how-we-handle-alternate-mac-addresses.patch:
  igb: change how we handle alternate mac addresses (bnc#619525).
* Wed Jul 28 2010 mfasheh@suse.com
- patches.fixes/ocfs2-fix-the-nested-PR.patch: Fix the nested
  PR lock calling issue in ACL                  (bnc#614332).
* Tue Jul 27 2010 mmarek@suse.cz
- kabi/severities: Ignore drivers/s390/net/qeth.
* Tue Jul 27 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.08.11.1-k8-update: qla2xxx:
  Update driver to version 8.03.01.08.11.1-k8 (bnc#622635).
* Tue Jul 27 2010 hare@suse.de
- patches.fixes/fcoe-remove-check-for-zero-fabric: fcoe: remove
  check for zero fabric name (bnc#625666).
* Mon Jul 26 2010 jjolly@suse.de
- patches.arch/s390-19-01-zfcp-unit-remove.patch: zfcp: Remove
  SCSI device during unit_remove (bnc#617464,LTC#65402).
- patches.arch/s390-19-02-zfcp-zero-fc.patch: zfcp: Zero memory
  for gpn_ft and adisc requests (bnc#617464,LTC#65466).
- patches.arch/s390-19-03-zfcp-fc-port-add-scsi-scan.patch:
  zfcp: Register SCSI devices after fc_remote_port_add
  (bnc#617464,LTC#65797).
- patches.arch/s390-19-04-zfcp-forced-terminate-rport-io.patch:
  zfcp: Use forced_reopen in terminate_rport_io callback
  (bnc#617464,LTC#65800).
- patches.arch/s390-19-05-zfcp-erp-timeout.patch: zfcp: Fail
  erp after timeout (bnc#617464,LTC#65801).
- patches.arch/s390-19-06-zfcp-erp-port-open-fail.patch:
  zfcp: Fix retry after failed "open port" erp action
  (bnc#617464,LTC#65806).
- patches.arch/s390-19-07-zfcp-forced-unblock.patch: zfcp: Do not
  unblock rport from REOPEN_PORT_FORCED (bnc#617464,LTC#65807).
- patches.arch/s390-19-08-zfcp-forced-fail.patch: zfcp:
  Do not try "forced close" when port is already closed
  (bnc#617464,LTC#65810).
- patches.arch/s390-19-09-qeth_clear_mac_bits.patch: Clear
  mac_bits field when switching between Layer 2 and Layer 3
  (bnc#617464,LTC#66065).
- patches.arch/s390-19-10-xip_race_condition.patch: filemap :
  fix race condition in xip_file_fault (bnc#617464,LTC#66066).
- patches.arch/s390-19-11-qeth-ipa-timeout.patch: qeth: avoid
  loop if ipa command response is missing (bnc#617464,LTC#66115).
* Mon Jul 26 2010 hare@suse.de
- patches.fixes/scsi-dh-alua-crash-on-stpg-failback: scsi_dh_alua:
  Sending STPG on failback causes kernel oops (bnc#624436).
* Mon Jul 26 2010 hare@suse.de
- patches.drivers/ipmi-add-parameter-to-limit-cpu-usage-in-kipmid.patch:
  Fixup patch for series2git.
- patches.fixes/btrfs-fix-loop-device-on-top-of-btrfs:
  Fixup patch for series2git.
* Fri Jul 23 2010 jack@suse.de
- patches.fixes/novfs-xattr-errcode-cleanup2: novfs: Fix error
  codes for getxattr for novfs (bnc#529535).
* Fri Jul 23 2010 tiwai@suse.de
- patches.drivers/drm-i915-Define-MI_ARB_STATE-bits: drm/i915:
  Define MI_ARB_STATE bits (bnc#621598).
- patches.drivers/drm-i915-add-reclaimable-to-i915-self-reclaimable-page:
  drm/i915: add 'reclaimable' to i915 self-reclaimable page
  allocations (bnc#621598).
- patches.drivers/drm-i915-enable-low-power-render-writes-on-GEN3-hardware:
  drm/i915: enable low power render writes on GEN3 hardware
  (bnc#621598).
* Fri Jul 23 2010 jack@suse.de
- patches.fixes/novfs-xattr-errcode-cleanup: novfs: code cleanup
  for one case of novfs return value (bnc#624606).
* Fri Jul 23 2010 jslaby@suse.de
- patches.suse/kdb-fix-incomplete-backtrace.patch: Disable temporarily
  (breaks build on i586).
* Fri Jul 23 2010 jslaby@suse.cz
- patches.suse/kdb-fix-incomplete-backtrace.patch: Refresh.
* Fri Jul 23 2010 jslaby@suse.cz
- patches.fixes/x86_64-uv-update-uv-arch-to-target-legacy-vga-i-o-correctly.patch:
  Refresh.
- patches.suse/kdb-common: Refresh.
- patches.suse/kdb-fix-incomplete-backtrace.patch: kdb shows
  incomplete backtrace (bnc#618444).
- patches.suse/kdb-x86: Refresh.
- patches.suse/kdb-x86-backtrace-code-to-use-the-in-kernel-show_stack-function:
  Refresh.
- patches.suse/x86-uv-kdb-support-for-uv-nmi-handler.patch:
  Refresh.
* Wed Jul 21 2010 mfasheh@suse.com
- patches.fixes/ocfs2-allow-huge-volumes.patch: OCFS2: Allow huge
  (> 16 TiB) volumes to mount (bnc#618424).
* Wed Jul 21 2010 jack@suse.de
- patches.fixes/novfs-xattr-memleak: novfs: Fix a memory leak
  that causes an OOM condition (bnc#610828).
* Tue Jul 20 2010 jack@suse.de
- patches.fixes/novfs-bdi-init.diff: novfs: backing device info
  initialization (bnc#623472).
* Tue Jul 20 2010 mhocko@suse.cz
- patches.fixes/futex-futex_find_get_task-remove-credentails-check.patch:
  futex: futex_find_get_task remove credentails check
  (bnc#607123).
* Thu Jul 15 2010 mmarek@suse.cz
- patches.kabi/struct-jbd2_buffer_trigger_type.patch: Fix kabi
  signature of struct jbd2_buffer_trigger_type.
* Thu Jul 15 2010 jdelvare@suse.de
- patches.drivers/e1000e-dont-inadvertently-re-set-INTX_DISABLE.patch:
  e1000e: don't inadvertently re-set INTX_DISABLE (bnc#610362).
* Thu Jul 15 2010 mmarek@suse.cz
- Update kabi files: Ignore changes to struct xfrm_state, the
  chances of KMPs using this struct are pretty slim.
* Wed Jul 14 2010 mfasheh@suse.com
- patches.fixes/ocfs2-No-need-to-zero-pages-past-i_size.patch:
  ocfs2: No need to zero pages past i_size.
- patches.fixes/ocfs2-When-zero-extending-do-it-by-page.patch:
  ocfs2: When zero extending, do it by page.
- patches.fixes/ocfs2-Zero-the-tail-cluster-when-extending-past-i_si.patch:
  ocfs2: Zero the tail cluster when extending past i_size.
* Wed Jul 14 2010 agruen@suse.de
- xfrm: Fix truncation length of authentication algorithms
  installed via PF_KEY (FATE#309537).
* Wed Jul 14 2010 mfasheh@suse.com
- patches.fixes/jbd2-ocfs2-Fix-block-checksumming-when-a-buffer-is-u.patch:
  jbd2/ocfs2: Fix block checksumming when a buffer is used in
  several transactions (bnc#606575).
* Tue Jul 13 2010 jdelvare@suse.de
- patches.drivers/mpt-fusion-fix-races-with-deleted.patch:
  fusion/mpt: Fix races with deleted targets (bnc#609506).
* Mon Jul 12 2010 duwe@suse.de
- patches.drivers/ehca-catch-ioremap-fail: Ib/ehca: Catch failing
  ioremap() (bnc#620021).
- patches.drivers/ehca-tasklet-init-fix: ib/ehca: init irq
  tasklet before irq can happen (bnc#620020).
- patches.drivers/ipoib-fix-pointer-refs: IB/ipoib: fix dangling
  pointer references to ipoib_neigh and ipoib_path (bnc#620904).
* Mon Jul 12 2010 bphilips@suse.de
- patches.drivers/sky2-enable-rx-tx-in-sky2_phy_reinit.patch:
  sky2: enable rx/tx in sky2_phy_reinit() (bnc#613171).
* Mon Jul 12 2010 jack@suse.de
- patches.fixes/novfs-overflow-fixes: novfs: security: Add buffer
  overflow, integer wraparound fixes (bnc#594362).
* Fri Jul  9 2010 rw@suse.de
- patches.arch/ia64-64bit-spinaphore:
  ia64: Use full 64 bits in spinaphore down_spin().  (bnc#619840)
* Thu Jul  8 2010 tiwai@suse.de
- patches.drivers/drm-i915-fix-hibernation-since-i915-self-reclaim-fix:
  drm/i915: fix hibernation since i915 self-reclaim fixes
  (bnc#599671).
* Thu Jul  8 2010 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.22: Fix deadlock in vif shutdown path.
* Tue Jul  6 2010 tiwai@suse.de
- patches.drivers/i915-fix-ironlake-edp-panel-setup-v4: i915:
  fix ironlake edp panel setup (v4) (bnc#598308).
* Tue Jul  6 2010 hare@suse.de
- patches.drivers/bfa-2.1.2.1-s11-update: bfa fixes from upstream
  (bnc#619536).
* Mon Jul  5 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-77-lenovo-thinkpad-x100e: ALSA:
  hda - add support for Lenovo ThinkPad X100e in conexant codec
  (bnc#619007).
* Fri Jul  2 2010 trenn@suse.de
- patches.arch/x86_mce_intel_decode_physical_fix_dynamic_debug.patch:
  For some reason the macro used by dynamic debug breaks things
  (bnc#619416).
* Wed Jun 30 2010 nfbrown@suse.de
- patches.fixes/dm-snapshot-2TB-fix: dm snapshot: simplify
  sector_to_chunk expression (bnc#614793).
* Wed Jun 30 2010 jbohac@suse.cz
- patches.fixes/bonding-fix-arp_validate-inside-bridge.patch:
  fix arp_validate for bonds inside a bridge (bnc#596113).
* Wed Jun 30 2010 agruen@suse.de
- xfrm: Custom truncation lengths for authentication algorithms
  (FATE#309537):
  + Define new XFRM netlink auth attribute with specified
    truncation bits.
  + Store aalg in xfrm_state with a user specified truncation
    length.
  + Use the user specified truncation length in ESP and AH.
* Wed Jun 30 2010 jeffm@suse.de
- patches.fixes/jbd-mark-super-uptodate: jbd: always mark super
  uptodate before dirty (bnc#618767).
* Wed Jun 30 2010 duwe@suse.de
- patches.drivers/ehea-lock-update: ehea: Fix kernel deadlock
  in DLPAR-mem processing (bnc#616369).
- patches.drivers/ehea-rmb-update: ehea: fix delayed packet
  processing (bnc#615003).
- patches.drivers/ipr-fix-allow_restart: ipr: move setting of
  the allow_restart flag for vsets and disks (bnc#617248).
* Mon Jun 28 2010 sjayaraman@suse.de
- patches.fixes/cifs-fix-vfs-busy-inode-errors: cifs: fix "Busy
  inodes after umount" issues (bnc#603528).
* Fri Jun 25 2010 bphilips@suse.de
- patches.drivers/cnic-Disable-statistics-initialization-for-eth-clien.patch:
  cnic: Disable statistics initialization for eth clients that
  do not support statistics (bnc#608435).
* Fri Jun 25 2010 bphilips@suse.de
- patches.drivers/tg3-Avoid-tx-lockups-on-5755-devices.patch:
  tg3: Avoid tx lockups on 5755+ devices (bnc#616088).
- patches.drivers/tg3-Disable-CLKREQ-in-L2.patch: tg3: Disable
  CLKREQ in L2 (bnc#616088).
- patches.drivers/tg3-Fix-a-memory-leak-on-5717-devices.patch:
  tg3: Fix a memory leak on 5717+ devices (bnc#616088).
- patches.drivers/tg3-Reduce-57765-core-clock-when-link-at-10Mbps.patch:
  tg3: Reduce 57765 core clock when link at 10Mbps (bnc#616088).
- patches.drivers/tg3-Relocate-APE-mutex-regs-for-5717.patch:
  tg3: Relocate APE mutex regs for 5717+ (bnc#616088).
- patches.drivers/tg3-Set-card-57765-card-reader-MRRS-to-1024B.patch:
  tg3: Set card 57765 card reader MRRS to 1024B (bnc#616088).
- patches.drivers/tg3.c-change-the-field-used-with-the-TG3.patch:
  drivers/net/tg3.c: change the field used with the
  TG3_FLAG_10_100_ONLY constant (bnc#616088).
* Fri Jun 25 2010 astarikovskiy@suse.de
- patches.arch/acpi-limit-sleep.patch Limit ACPI Sleep() to 1 second
  (bnc#557710)
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/ext4-make-sure-the-move_ext-ioctl-can-t-overwrite-append-only-files:
  ext4: Make sure the MOVE_EXT ioctl can't overwrite append-only
  files (bnc#612457 CVE-2010-2066).
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/l2tp-fix-oops-in-pppol2tp_xmit: l2tp: Fix oops
  in pppol2tp_xmit (bnc#616612).
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/gfs2-fix-permissions-checking-for-setflags-ioctl:
  GFS2: Fix permissions checking for setflags ioctl() (bnc#608576
  CVE-2010-1641).
* Wed Jun 23 2010 jeffm@suse.de
- btrfs fix rollup from v2.6.35:
  * Note: Features like aio and direct-io have not been added due to the
    infrastructure requirements that would be incompatible with the
    SLE11 SP1 KABI
  - patches.fixes/btrfs-add-a-df-ioctl-for-btrfs: Btrfs: add a
    "df" ioctl for btrfs.
  - patches.fixes/btrfs-add-a-function-to-lookup-a-directory-path-by-following-backrefs:
    Btrfs: add a function to lookup a directory path by following
    backrefs.
  - patches.fixes/btrfs-add-btrfs_duplicate_item: Btrfs: Add
    btrfs_duplicate_item.
  - patches.fixes/btrfs-add-check-for-changed-leaves-in-setup_leaf_for_split:
    Btrfs: add check for changed leaves in setup_leaf_for_split.
  - patches.fixes/btrfs-add-delayed-iput: Btrfs: Add delayed iput.
  - patches.fixes/btrfs-add-error-handle-for-btrfs_search_slot-in-btrfs_read_chunk_tree:
    Btrfs: Add error handle for btrfs_search_slot() in
    btrfs_read_chunk_tree().
  - patches.fixes/btrfs-add-ioctl-and-incompat-flag-to-set-the-default-mount-subvol:
    Btrfs: add ioctl and incompat flag to set the default mount
    subvol.
  - patches.fixes/btrfs-add-more-error-checking-to-btrfs_dirty_inode:
    Btrfs: add more error checking to btrfs_dirty_inode.
  - patches.fixes/btrfs-add-mount-o-compress-force: Btrfs: Add
    mount -o compress-force.
  - patches.fixes/btrfs-add-new-defrag-range-ioctl: Btrfs: add
    new defrag-range ioctl.
  - patches.fixes/btrfs-add-null-check-for-do_walk_down: Btrfs:
    add NULL check for do_walk_down().
  - patches.fixes/btrfs-add-search-and-inode-lookup-ioctls: Btrfs:
    add search and inode lookup ioctls.
  - patches.fixes/btrfs-align-offsets-for-btrfs_ordered_update_i_size:
    Btrfs: align offsets for btrfs_ordered_update_i_size.
  - patches.fixes/btrfs-allow-treeid-0-in-the-inode-lookup-ioctl:
    Btrfs: allow treeid==0 in the inode lookup ioctl.
  - patches.fixes/btrfs-apply-updated-fallocate-i_size-fix: Btrfs:
    apply updated fallocate i_size fix.
  - patches.fixes/btrfs-avoid-bug-when-dropping-root-and-reference-in-same-transaction:
    Btrfs: avoid BUG when dropping root and reference in same
    transaction.
  - patches.fixes/btrfs-avoid-enospc-errors-in-btrfs_dirty_inode:
    Btrfs: avoid ENOSPC errors in btrfs_dirty_inode.
  - patches.fixes/btrfs-avoid-orphan-inodes-cleanup-during-committing-transaction:
    Btrfs: Avoid orphan inodes cleanup during committing
    transaction.
  - patches.fixes/btrfs-avoid-orphan-inodes-cleanup-while-replaying-log:
    Btrfs: Avoid orphan inodes cleanup while replaying log.
  - patches.fixes/btrfs-avoid-superfluous-tree-log-writeout: Btrfs:
    Avoid superfluous tree-log writeout.
  - patches.fixes/btrfs-be-more-selective-in-the-defrag-ioctl:
    Btrfs: be more selective in the defrag ioctl.
  - patches.fixes/btrfs-btrfs_iget-returns-err_ptr: Btrfs:
    btrfs_iget() returns ERR_PTR.
  - patches.fixes/btrfs-btrfs_lookup_dir_item-can-return-err_ptr:
    Btrfs: btrfs_lookup_dir_item() can return ERR_PTR.
  - patches.fixes/btrfs-btrfs_mark_extent_written-uses-the-wrong-slot:
    Btrfs: btrfs_mark_extent_written uses the wrong slot.
  - patches.fixes/btrfs-btrfs_read_fs_root_no_name-returns-err_ptrs:
    Btrfs: btrfs_read_fs_root_no_name() returns ERR_PTRs.
  - patches.fixes/btrfs-buffer-results-in-the-space_info-ioctl:
    Btrfs: buffer results in the space_info ioctl.
  - patches.fixes/btrfs-cache-extent-state-in-find_delalloc_range:
    Btrfs: cache extent state in find_delalloc_range.
  - patches.fixes/btrfs-cache-ordered-extent-when-completing-io:
    Btrfs: cache ordered extent when completing io.
  - patches.fixes/btrfs-cache-the-extent-state-everywhere-we-possibly-can-v2:
    Btrfs: cache the extent state everywhere we possibly can V2.
  - patches.fixes/btrfs-change-how-we-mount-subvolumes: Btrfs:
    change how we mount subvolumes.
  - patches.fixes/btrfs-change-the-ordered-tree-to-use-a-spinlock-instead-of-a-mutex:
    Btrfs: change the ordered tree to use a spinlock instead of
    a mutex.
  - patches.fixes/btrfs-check-btrfs_get_extent-return-for-is_err:
    Btrfs: check btrfs_get_extent return for IS_ERR().
  - patches.fixes/btrfs-check-return-value-of-open_bdev_exclusive-properly:
    Btrfs: check return value of open_bdev_exclusive properly.
  - patches.fixes/btrfs-check-total-number-of-devices-when-removing-missing:
    Btrfs: check total number of devices when removing missing.
  - patches.fixes/btrfs-create-snapshot-references-in-same-commit-as-snapshot:
    Btrfs: create snapshot references in same commit as snapshot.
  - patches.fixes/btrfs-deal-with-null-acl-sent-to-btrfs_set_acl:
    Btrfs: deal with NULL acl sent to btrfs_set_acl.
  - patches.fixes/btrfs-deny-sys_link-across-subvolumes: Btrfs:
    deny sys_link across subvolumes.
  - patches.fixes/btrfs-dereferencing-freed-memory: Btrfs:
    dereferencing freed memory.
  - patches.fixes/btrfs-do-not-mark-the-chunk-as-readonly-if-in-degraded-mode:
    Btrfs: do not mark the chunk as readonly if in degraded mode.
  - patches.fixes/btrfs-do-not-try-and-lookup-the-file-extent-when-finishing-ordered-io:
    Btrfs: do not try and lookup the file extent when finishing
    ordered io.
  - patches.fixes/btrfs-don-t-add-extent-0-to-the-free-space-cache-v2:
    Btrfs: don't add extent 0 to the free space cache v2.
  - patches.fixes/btrfs-don-t-look-at-bio-flags-after-submit_bio:
    Btrfs: don't look at bio flags after submit_bio.
  - patches.fixes/btrfs-don-t-walk-around-with-task-state-task_running:
    Btrfs: don't walk around with task->state != TASK_RUNNING.
  - patches.fixes/btrfs-drop-verbose-enospc-printk: Btrfs: drop
    verbose enospc printk.
  - patches.fixes/btrfs-fail-mount-on-bad-mount-options: Btrfs:
    fail mount on bad mount options.
  - patches.fixes/btrfs-fail-to-mount-if-we-have-problems-reading-the-block-groups:
    Btrfs: fail to mount if we have problems reading the block
    groups.
  - patches.fixes/btrfs-finish-read-pages-in-the-order-they-are-submitted:
    Btrfs: finish read pages in the order they are submitted.
  - patches.fixes/btrfs-fix-a-memory-leak-in-btrfs_init_acl: Btrfs:
    fix a memory leak in btrfs_init_acl.
  - patches.fixes/btrfs-fix-block-generation-verification-race:
    Btrfs: Fix block generation verification race.
  - patches.fixes/btrfs-fix-btrfs_drop_extent_cache-for-skip-pinned-case:
    Btrfs: Fix btrfs_drop_extent_cache for skip pinned case.
  - patches.fixes/btrfs-fix-btrfs_mkdir-goto-for-no-free-objectids:
    btrfs: fix btrfs_mkdir goto for no free objectids.
  - patches.fixes/btrfs-fix-bug_on-for-fs-converted-from-extn:
    Btrfs: Fix BUG_ON for fs converted from extN.
  - patches.fixes/btrfs-fix-chunk-allocate-size-calculation: Btrfs:
    fix chunk allocate size calculation.
  - patches.fixes/btrfs-fix-data-enospc-check-overflow: Btrfs:
    fix data enospc check overflow.
  - patches.fixes/btrfs-fix-disk_i_size-update-corner-case: Btrfs:
    Fix disk_i_size update corner case.
  - patches.fixes/btrfs-fix-fallocate-regression: Btrfs: fix
    fallocate regression.
  - patches.fixes/btrfs-fix-gfp-flags-masking-in-the-compression-code:
    Btrfs: fix gfp flags masking in the compression code.
  - patches.fixes/btrfs-fix-key-checks-and-advance-in-the-search-ioctl:
    Btrfs: fix key checks and advance in the search ioctl.
  - patches.fixes/btrfs-fix-loop-device-on-top-of-btrfs: Btrfs:
    fix loop device on top of btrfs.
  - patches.fixes/btrfs-fix-memory-leaks-in-error-paths: Btrfs,
    fix memory leaks in error paths.
  - patches.fixes/btrfs-fix-missing-last-entry-in-readdir3: btrfs:
    fix missing last-entry in readdir(3).
  - patches.fixes/btrfs-fix-null-dereference-in-relocation-c:
    Btrfs: Fix null dereference in relocation.c.
  - patches.fixes/btrfs-fix-oopsen-when-dropping-empty-tree: Btrfs:
    Fix oopsen when dropping empty tree.
  - patches.fixes/btrfs-fix-per-root-used-space-accounting: Btrfs:
    Fix per root used space accounting.
  - patches.fixes/btrfs-fix-possible-panic-on-unmount: Btrfs:
    fix possible panic on unmount.
  - patches.fixes/btrfs-fix-race-between-allocate-and-release-extent-buffer:
    Btrfs: fix race between allocate and release extent buffer.
  - patches.fixes/btrfs-fix-race-in-btrfs_mark_extent_written:
    Btrfs: Fix race in btrfs_mark_extent_written.
  - patches.fixes/btrfs-fix-regression-in-orphan-cleanup: Btrfs:
    fix regression in orphan cleanup.
  - patches.fixes/btrfs-fix-remap_file_pages-error: Btrfs: fix
    remap_file_pages error.
  - patches.fixes/btrfs-fix-search_ioctl-key-advance: Btrfs:
    fix search_ioctl key advance.
  - patches.fixes/btrfs-fix-small-race-with-delalloc-flushing-waitqueue-s:
    Btrfs: fix small race with delalloc flushing waitqueue's.
  - patches.fixes/btrfs-fix-the-inode-ref-searches-done-by-btrfs_search_path_in_tree:
    Btrfs: fix the inode ref searches done by
    btrfs_search_path_in_tree.
  - patches.fixes/btrfs-flush-data-on-snapshot-creation: Btrfs:
    flush data on snapshot creation.
  - patches.fixes/btrfs-handle-err_ptr-from-posix_acl_from_xattr:
    Btrfs: handle ERR_PTR from posix_acl_from_xattr().
  - patches.fixes/btrfs-handle-error-returns-from-btrfs_lookup_dir_item:
    Btrfs: handle error returns from btrfs_lookup_dir_item().
  - patches.fixes/btrfs-handle-kmalloc-failure-in-inode-lookup-ioctl:
    Btrfs: handle kmalloc() failure in inode lookup ioctl.
  - patches.fixes/btrfs-handle-kzalloc-failure-in-open_ctree:
    Btrfs: handle kzalloc() failure in open_ctree().
  - patches.fixes/btrfs-integrate-metadata-reservation-with-start_transaction:
    Btrfs: Integrate metadata reservation with start_transaction.
  - patches.fixes/btrfs-introduce-contexts-for-metadata-reservation:
    Btrfs: Introduce contexts for metadata reservation.
  - patches.fixes/btrfs-introduce-global-metadata-reservation:
    Btrfs: Introduce global metadata reservation.
  - patches.fixes/btrfs-kfree-correct-pointer-during-mount-option-parsing:
    Btrfs: kfree correct pointer during mount option parsing.
  - patches.fixes/btrfs-kill-allocate_wait-in-space_info: Btrfs:
    Kill allocate_wait in space_info.
  - patches.fixes/btrfs-kill-init_btrfs_i: Btrfs: Kill
    init_btrfs_i().
  - patches.fixes/btrfs-kill-max_extent-mount-option: Btrfs:
    kill max_extent mount option.
  - patches.fixes/btrfs-link-block-groups-of-different-raid-types:
    Btrfs: Link block groups of different raid types.
  - patches.fixes/btrfs-make-df-be-a-little-bit-more-understandable:
    Btrfs: make df be a little bit more understandable.
  - patches.fixes/btrfs-make-error-return-negative-in-btrfs_sync_file:
    Btrfs: make error return negative in btrfs_sync_file().
  - patches.fixes/btrfs-make-fallocate2-more-enospc-friendly:
    Btrfs: Make fallocate(2) more ENOSPC friendly.
  - patches.fixes/btrfs-make-metadata-chunks-smaller: Btrfs:
    make metadata chunks smaller.
  - patches.fixes/btrfs-make-set-get-functions-for-the-super-compat_ro-flags-use-compat_ro:
    Btrfs: make set/get functions for the super compat_ro flags
    use compat_ro.
  - patches.fixes/btrfs-make-subvolid-0-mount-the-original-default-root:
    Btrfs: make subvolid=0 mount the original default root.
  - patches.fixes/btrfs-make-sure-fallocate-properly-starts-a-transaction:
    Btrfs: make sure fallocate properly starts a transaction.
  - patches.fixes/btrfs-make-sure-the-chunk-allocator-doesn-t-create-zero-length-chunks:
    Btrfs: make sure the chunk allocator doesn't create zero
    length chunks.
  - patches.fixes/btrfs-make-truncate2-more-enospc-friendly: Btrfs:
    Make truncate(2) more ENOSPC friendly.
  - patches.fixes/btrfs-metadata-enospc-handling-for-balance:
    Btrfs: Metadata ENOSPC handling for balance.
  - patches.fixes/btrfs-metadata-enospc-handling-for-tree-log:
    Btrfs: Metadata ENOSPC handling for tree log.
  - patches.fixes/btrfs-metadata-reservation-for-orphan-inodes:
    Btrfs: Metadata reservation for orphan inodes.
  - patches.fixes/btrfs-pass-transaction-handle-to-security-and-acl-initialization-functions:
    Btrfs: Pass transaction handle to security and ACL
    initialization functions.
  - patches.fixes/btrfs-pre-allocate-space-for-data-relocation:
    Btrfs: Pre-allocate space for data relocation.
  - patches.fixes/btrfs-prohibit-a-operation-of-changing-acl-s-mask-when-noacl-mount-option-used:
    Btrfs: prohibit a operation of changing acl's mask when noacl
    mount option used.
  - patches.fixes/btrfs-remove-bug_on-due-to-mounting-bad-filesystem:
    Btrfs: remove BUG_ON() due to mounting bad filesystem.
  - patches.fixes/btrfs-remove-duplicate-include-in-ioctl-c: Btrfs:
    remove duplicate include in ioctl.c.
  - patches.fixes/btrfs-remove-tree_search-in-extent_map-c: Btrfs:
    remove tree_search() in extent_map.c.
  - patches.fixes/btrfs-remove-unnecessary-finish_wait-in-wait_current_trans:
    Btrfs: Remove unnecessary finish_wait() in wait_current_trans().
  - patches.fixes/btrfs-return-keys-for-large-items-to-the-search-ioctl:
    Btrfs: return keys for large items to the search ioctl.
  - patches.fixes/btrfs-rewrite-btrfs_drop_extents: Btrfs: Rewrite
    btrfs_drop_extents.
  - patches.fixes/btrfs-run-orphan-cleanup-on-default-fs-root:
    Btrfs: run orphan cleanup on default fs root.
  - patches.fixes/btrfs-run-the-backing-dev-more-often-in-the-submit_bio-helper:
    Btrfs: run the backing dev more often in the submit_bio helper.
  - patches.fixes/btrfs-should-add-a-permission-check-for-setfacl:
    Btrfs: should add a permission check for setfacl.
  - patches.fixes/btrfs-show-discard-option-in-proc-mounts: Btrfs:
    Show discard option in /proc/mounts.
  - patches.fixes/btrfs-shrink-delay-allocated-space-in-a-synchronized:
    Btrfs: Shrink delay allocated space in a synchronized.
  - patches.fixes/btrfs-simplify-num_stripes-s-calculation-logical-for-__btrfs_alloc_chunk:
    Btrfs: Simplify num_stripes's calculation logical for
    __btrfs_alloc_chunk().
  - patches.fixes/btrfs-uninitialized-data-is-check_path_shared:
    Btrfs: uninitialized data is check_path_shared().
  - patches.fixes/btrfs-unwind-after-btrfs_start_transaction-errors:
    Btrfs: unwind after btrfs_start_transaction() errors.
  - patches.fixes/btrfs-update-existing-btrfs_device-for-renaming-device:
    btrfs: Update existing btrfs_device for renaming device.
  - patches.fixes/btrfs-update-metadata-reservation-for-delayed-allocation:
    Btrfs: Update metadata reservation for delayed allocation.
  - patches.fixes/btrfs-use-__u64-types-in-ioctl-h: Btrfs: use
    __u64 types in ioctl.h.
  - patches.fixes/btrfs-use-add_to_page_cache_lru-use-__page_cache_alloc:
    Btrfs: use add_to_page_cache_lru, use __page_cache_alloc.
  - patches.fixes/btrfs-use-correct-values-when-updating-inode-i_size-on-fallocate:
    Btrfs: Use correct values when updating inode i_size on
    fallocate.
  - patches.fixes/btrfs-use-memparse: btrfs: use memparse.
  - patches.fixes/btrfs-use-rb_root-to-intialize-rb_trees-instead-of-setting-rb_node-to-null:
    Btrfs: use RB_ROOT to intialize rb_trees instead of setting
    rb_node to NULL.
  - patches.fixes/btrfs-using-btrfs_stack_device_id-get-devid:
    btrfs: using btrfs_stack_device_id() get devid.
  - patches.fixes/err-h-add-helper-function-to-simplify-pointer-error-checking:
    err.h: add helper function to simplify pointer error checking.
* Tue Jun 22 2010 mfasheh@suse.com
- patches.fixes/ocfs2-Limit-default-local-alloc-size-within-bitmap-r.patch:
  ocfs2: Limit default local alloc size within bitmap range
  (bnc#501563).
* Tue Jun 22 2010 rjw@suse.de
- patches.arch/tlb_uv_update3.patch: x86 / UV: TLB shootdown
  (BAU) third set of bugfixes (bnc#611104, FATE#306952).
* Mon Jun 21 2010 jjolly@suse.de
- patches.arch/s390-18-01-kernel-panic-kprobes.patch: kernel:
  fix kernel panic caused by using kprobes (bnc#613542,LTC#64497).
* Mon Jun 21 2010 hare@suse.de
- patches.drivers/cxgb3i-zero-out-reserved-fields: cxgb3i:
  zero out reserved or un-used fields (bnc#574006).
* Wed Jun 16 2010 jdelvare@suse.de
- patches.drivers/watchdog-hpwdt-introduce-secs_to_ticks-macro.patch:
  watchdog: hpwdt (1/3): Introduce SECS_TO_TICKS() macro
  (makes next patch apply cleanly).
- patches.drivers/watchdog-hpwdt-allow-full-range-of-timer-values-supported-by-hardware.patch:
  watchdog: hpwdt (2/3): allow full range of timer values
  supported by hardware (bnc#612407).
* Tue Jun 15 2010 duwe@suse.de
- patches.arch/ppc64-kdump-rebase: powerpc: Move kdump default
  base address to 64MB on 64bit (bnc#607448).
* Mon Jun 14 2010 jkosina@suse.cz
- patches.fixes/virtio_net-Add-napi-schedule-to-napi_enable-call.patch:
  virtio_net: Add napi schedule to napi_enable call (bnc#606797).
* Mon Jun 14 2010 jkosina@suse.cz
- patches.fixes/virtio_net-make-delayed-refill-more-reliable.patch:
  virtio_net: Make delayed refill more reliable (bnc#606797).
* Mon Jun 14 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.13 and c/s 1017.
* Mon Jun 14 2010 jdelvare@suse.de
- patches.drivers/ipmi-add-parameter-to-limit-cpu-usage-in-kipmid.patch:
  Revert an incorrect change (bnc#468397, bnc#613906).
* Wed Jun  9 2010 mmarek@suse.cz
- Allow kabi change in drivers/s390/net/qeth.
* Wed Jun  9 2010 mgalbraith@suse.de
- patches.arch/bug-610783_uv_nortsched_boot_option.patch:
  Provide boot option to disable sched_rt_runtime (bnc#610783).
* Mon Jun  7 2010 bphilips@suse.de
- patches.drivers/cnic-Convert-cnic_local_flags-to-atomic-ops.patch:
  Refresh to add cnic_local_flags
* Mon Jun  7 2010 bphilips@suse.de
- patches.drivers/cnic-Convert-cnic_local_flags-to-atomic-ops.patch:
  cnic: Convert cnic_local_flags to atomic ops (bnc#608435).
- patches.drivers/cnic-Finetune-iSCSI-connection-reset.patch:
  cnic: Finetune iSCSI connection reset (bnc#608435).
- patches.drivers/cnic-Finetune-iSCSI-connection-set-up.patch:
  cnic: Finetune iSCSI connection set up (bnc#608435).
- patches.drivers/cnic-Fix-context-memory-init.-on-5709.patch:
  cnic: Fix context memory init. on 5709 (bnc#608435).
- patches.drivers/cnic-Fix-panic-in-cnic_iscsi_nl_msg_recv-when-device.patch:
  cnic: Fix panic in cnic_iscsi_nl_msg_recv() when device is down
  (bnc#608435).
- patches.drivers/cnic-Return-SPQ-credit-to-bnx2x-after-ring-setup-and.patch:
  cnic: Return SPQ credit to bnx2x after ring setup and shutdown
  (bnc#608435).
* Fri Jun  4 2010 jeffm@suse.com
- patches.fixes/reiserfs-xattr-crash-fix: reiserfs: Fix crash
  during umount (bnc#610598).
* Fri Jun  4 2010 jeffm@suse.com
- patches.fixes/ext4-fix-optional-arg-mount-options: ext4:
  Fix optional-arg mount options (bnc#611760).
* Fri Jun  4 2010 bphilips@suse.de
- patches.fixes/module-drop-the-lock-while-waiting-for-module-to-complete-initialization.patch: patch-mainline -> never (bnc#609281)
* Thu Jun  3 2010 jjolly@suse.de
- patches.arch/s390-17-01-cmm-unload.patch: cmm: fix module
  unload handling (bnc#607890,LTC#63956).
- patches.arch/s390-17-02-cio_reenable_mss_after_hibernation.patch:
  cio: reenable mss after hibernation (bnc#607890,LTC#64013).
- patches.arch/s390-17-03-zfcp_offline_sbal_wait.patch: zfcp:
  Do not wait for SBALs on stopped queue (bnc#607890,LTC#64249).
- patches.arch/s390-17-04-ccwgroup-drvdata-locking.patch:
  ccwgroup: add locking around drvdata access
  (bnc#607890,LTC#64325).
* Wed Jun  2 2010 bphilips@suse.de
- patches.drivers/e1000e-entropy-source.patch: Reintroduce IRQF_SHARED
  to fix non-MSI case (bnc#610362).
* Mon May 31 2010 rjw@suse.de
- patches.arch/x86-pci-add-option-to-not-assign-bars-if-not-already-assigned.patch:
  x86/PCI: Add option to not assign BAR's if not already assigned
  (bnc#603387).
* Mon May 31 2010 hare@suse.de
- patches.drivers/mptsas-eh_timeout-callback: modify patch header.
* Mon May 31 2010 hare@suse.de
- patches.drivers/mpt2sas-04.100.01.04-update: mpt2sas: array
  overrun when loading driver (bnc#608478).
* Fri May 28 2010 tonyj@suse.de
- rpm/package-descriptions: Change description for -trace (bnc#607628)
* Wed May 26 2010 hare@suse.de
- patches.drivers/mptsas-eh_timeout-callback: mptsas offlines
  paths after cable pull (bnc#603411).
* Wed May 26 2010 mgalbraith@suse.de
- Applied migration thread vs sched_rt_period_timer deadlock fix from bnc#603510.
- patches.fixes/kill-migration-thread-in-CPU_POST_DEAD-instead-of-CPU_DEAD.diff:
  kill migration thread in CPU_POST_DEAD instead of CPU_DEAD (bnc#603510).
* Tue May 25 2010 jeffm@suse.com
- Update config files: Cleaned up ppc64-vanilla.
* Tue May 25 2010 jkosina@suse.cz
- patches.fixes/ipmi-fix-deadlock.patch: IPMI: avoid deadlock
  during panic (bnc#580373).
* Sun May 23 2010 teheo@suse.de
- patches.drivers/pci-disable-msi-on-K8M800: pci: disable MSI
  on VIA K8M800 (bnc#599508).
* Fri May 21 2010 knikanth@suse.de
- patches.fixes/scsi-requeue-abort-request-race: Refresh. Fix a
  race in the patch. (bnc#588929)
* Thu May 20 2010 garloff@suse.de
- patches.suse/pagecache-limit-dirty.diff: Fix misplaced paren
  (thanks, JanB!).
* Thu May 20 2010 hare@suse.de
- patches.drivers/qla2xxx-fix-tgt-init-prli-payload.diff: SLES11
  SP1 GMC kernel not identifying qla2xxx LUNs (bnc#606977).
* Thu May 20 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.07.11.1-k8-update: qla2xxx:
  Minor updates and fixes from upstream (bnc#605001).
* Thu May 20 2010 gregkh@suse.de
- patches.arch/x86-mce-xeon75xx-fix-typo-causing-a-kernel-crash.patch:
  x86: mce-xeon75xx: fix typo causing a kernel crash (bnc#606778).
* Wed May 19 2010 jjolly@suse.de
- patches.arch/s390-16-01-ptrace-fix-return-value.patch:
  ptrace: fix return value of do_syscall_trace_enter()
  (bnc#605947,LTC#63473).
- patches.arch/s390-16-02-qeth-conf-mutex.patch: qeth: synchronize
  configuration interface (bnc#605947,LTC#63562).
* Tue May 18 2010 jeffm@suse.com
- patches.fixes/hvc_console-fix-race-between-hvc_close-and-hvc_remove:
  hvc_console: Fix race between hvc_close and hvc_remove
  (bnc#585385).
- patches.fixes/hvc_console-fix-race-between-hvc_close-and-hvc_remove2:
  hvc_console: Fix race between hvc_close and hvc_remove
  (bnc#585385).
* Tue May 18 2010 jeffm@suse.com
- patches.fixes/btrfs-check-for-read-permission-on-src-file-in-the-clone-ioctl:
  Btrfs: check for read permission on src file in the clone ioctl
  (bnc#606743).
* Sat May 15 2010 gregkh@suse.de
- patches.suse/xfs-dmapi-xfs-enable: Reorder a structure to get
  back the previous kabi signature.
* Sat May 15 2010 gregkh@suse.de
- Update config files for vanilla kernels
* Sat May 15 2010 gregkh@suse.de
- Update to 2.6.32.13
  - bugfixes
  - security fixes
  - obsoletes:
  - patches.arch/x86-enable-northbridges-unconditionally-on-amd-systems.patch
  - patches.drivers/bnx2-fix-lost-msi-x-problem-on-5709-nics.patch
  - patches.fixes/block-blk_abort_request-lock-fix
  - patches.fixes/hugetlb-fix-infinite-loop-in-get_futex_key.patch
  - patches.fixes/ocfs2-Compute-metaecc-for-superblocks-during-online-.patch
  - patches.fixes/reiserfs-fix-permissions-on-reiserfs_priv
  - patches.fixes/scsi-enable-barrier-retries-on-UNIT_ATTENTION
  - patches.fixes/scsi_debug-scale-virtual_gb-with-sector_size-properly
  - patches.fixes/sd-enable-retries-for-sync-cache
  - patches.fixes/staging-hv-fix-a-bug-affecting-ipv6.patch
  - patches.fixes/staging-hv-fix-up-memory-leak-on-hvcleanup.patch
  - patches.fixes/staging-hv-name-network-device-ethx-rather-than-sethx.patch
  - patches.fixes/tg3-fix-intx-fallback-when-msi-fails.patch
  - patches.fixes/x86_cpufreq_powernowk8_fix_wrong_freqs.patch
  - patches.xfs/xfs-add-a-shrinker-to-background-inode-reclaim.patch
* Fri May 14 2010 jeffm@suse.com
- patches.fixes/sctp-fix-oops-when-sending-queued-asconf-chunks:
  Update references (bnc#600375 CVE-2010-1173).
- patches.fixes/sctp-fix-skb_over_panic-resulting-from-multiple-invalid-parameter-errors:
  sctp: Fix skb_over_panic resulting from multiple invalid
  parameter errors (bnc#600375 CVE-2010-1173).
* Fri May 14 2010 jeffm@suse.com
- patches.fixes/sctp-fix-oops-when-sending-queued-asconf-chunks:
  Update references (bnc#600375 CVE-2010-1173).
- patches.fixes/sctp-fix-skb_over_panic-resulting-from-multiple-invalid-parameter-errors:
  sctp: Fix skb_over_panic resulting from multiple invalid
  parameter errors (CVE-2010...  (bnc#600375 CVE-2010-1173).
* Thu May 13 2010 jslaby@suse.de
- patches.fixes/proc-revert-provide-stack-info-01.patch: proc:
  partially revert "procfs: provide stack information for threads"
  (bnc#598677).
- patches.fixes/proc-revert-provide-stack-info-02.patch: revert
  "procfs: provide stack information for threads" and its fixup
  commits (bnc#598677).
- patches.kabi/task_struct-stack_start.patch:
- patches.trace/utrace-core: Refresh.
* Thu May 13 2010 rjw@suse.de
- supported.conf: add uv_mmtimer as requested by SGI in bnc#602232
* Wed May 12 2010 jbohac@suse.cz
- patches.fixes/ipv6-fix-dad-race.patch: Delete.
  (fixes bnc#604183, partially fixes bnc#602969 and
  reopens bnc#577967)
* Wed May 12 2010 gregkh@suse.de
- Update config files.
- patches.suse/staging-hv-added-new-hv_utils-driver-with-shutdown-as-first-functionality.patch:
  Staging: hv: Added new hv_utils driver with shutdown as first
  functionality (bnc#605321).
* Wed May 12 2010 jbohac@suse.cz
- patches.fixes/tcp_fix_oob_pollin_avoidance.patch: tcp: Fix
  OOB POLLIN avoidance (bnc#598493).
* Wed May 12 2010 gregkh@suse.de
- patches.suse/staging-hv-a-clocksource-for-linux-guests-hosted-on-hyperv.patch:
  Staging: hv: A clocksource for Linux guests hosted on HyperV
  (bnc#605321).
* Wed May 12 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix preserving of old symsets.
* Wed May 12 2010 mmarek@suse.cz
- Update reference module symbol versions, watch xfs kabi again.
* Tue May 11 2010 trenn@suse.de
  Add ProLiant DL580 G7 to use _CRS for PCI resources by default
  (bnc#578572)
- patches.fixes/x86_hp_add_more_usecrs_to_whitelist.patch:
  Refresh.
* Tue May 11 2010 tiwai@suse.de
- patches.drivers/drm-Keep-disabled-outputs-disabled-after-resume:
  drm: Keep disabled outputs disabled after suspend / resume
  (bnc#600256).
* Mon May 10 2010 jkosina@suse.cz
- kabi/severities: ignore XFS kABI for now (bnc#582872).
* Mon May 10 2010 jkosina@suse.cz
- patches.xfs/xfs-add-a-shrinker-to-background-inode-reclaim.patch:
  xfs: add a shrinker to background inode reclaim (bnc#582872).
- patches.xfs/xfs-cleanup-data-end-I-O-handlers.patch: Delete.
* Mon May 10 2010 garloff@suse.de
- patches.suse/pagecache-limit-dirty.diff: Make pagecache limit
  enforcement configurable for dirty pages. [FATE309111]
* Mon May 10 2010 gregkh@suse.de
- patches.fixes/staging-hv-auto-load-the-hyperv-pv-net-driver.patch:
  Staging: hv: Auto-load the hyperV PV net driver (None).
- patches.fixes/staging-hv-fix-a-bug-affecting-ipv6.patch:
  Staging: hv: Fix a bug affecting IPv6 (None).
- patches.fixes/staging-hv-fix-up-memory-leak-on-hvcleanup.patch:
  Staging: hv: Fix up memory leak on HvCleanup (None).
- patches.fixes/staging-hv-name-network-device-ethx-rather-than-sethx.patch:
  Staging: hv: name network device ethX rather than sethX (None).
* Sat May  8 2010 garloff@suse.de
- patches.suse/pagecache-limit-unmapped.diff: Fix calculation of
  number of unmapped (freeable) pages if shmem > mapped and add
  safety guard by crosschecking with the LRU lists. Finetune:
  Consider swapped out mem and apply an offset when increasing
  limit due to free mem.
* Fri May  7 2010 jeffm@suse.com
- patches.fixes/keys-find_keyring_by_name-can-gain-access-to-a-freed-keyring:
  KEYS: find_keyring_by_name() can gain access to a freed keyring
  (bnc#599955 CVE-2010-1437).
* Fri May  7 2010 garloff@suse.de
- patches.suse/pagecache-limit.patch: No more than 2 passes.
* Fri May  7 2010 jjolly@suse.de
- patches.arch/s390-15-01-dasd-fix-tasklet-sleep-on-race.patch:
  dasd: fix race between tasklet and dasd_sleep_on
  (bnc#602852,LTC#63146).
* Thu May  6 2010 garloff@suse.de
- patches.suse/pagecache-limit.patch: Finetune -- do larger
  batches and an additional pass if needed. [FATE309111]
* Thu May  6 2010 jkosina@suse.cz
- Update config files: refresh after ILLEGAL_POINTER_VALUE change.
* Thu May  6 2010 duwe@suse.de
- patches.arch/ppc-xics-affinity-fix: powerpc/pseries: Fix xics
  interrupt affinity (bnc#603148).
* Thu May  6 2010 jkosina@suse.cz
- patches.fixes/hugetlb-fix-infinite-loop-in-get_futex_key.patch:
  hugetlb: fix infinite loop in get_futex_key() when backed by
  huge pages (bnc#603205).
- update config files: run oldconfig
* Thu May  6 2010 hare@suse.de
- patches.fixes/scsi-enable-barrier-retries-on-UNIT_ATTENTION:
  Retry commands with UNIT_ATTENTION sense codes (bnc#591556).
- patches.fixes/sd-enable-retries-for-sync-cache: Enable retries
  for SYNCRONIZE_CACHE commands to fix I/O error (bnc#591556).
- patches.suse/dm-mpath-disable-abort-queue: dm-mpath: Disable
  abort queue (bnc#588929).
* Wed May  5 2010 jjolly@suse.de
- rpm/kernel-binary.spec.in: Disabled install_vdso for s390/s390x
  on kernel-vanilla (bnc#600535)
* Wed May  5 2010 jkosina@suse.cz
- patches.arch/x86-cacheinfo-turn-off-l3-cache-index-in-virtualized-envs.patch:
  x86, cacheinfo: Turn off L3 cache index disable feature in
  virtualized environments (bnc#602514).
- patches.arch/x86-enable-northbridges-unconditionally-on-amd-systems.patch:
  x86, k8 nb: Fix boot crash: enable k8_northbridges
  unconditionally on AMD systems (bnc#602514).
- patches.xen/xen3-auto-xen-kconfig.diff: Refresh.
* Wed May  5 2010 bphilips@suse.de
- patches.drivers/bnx2-fix-lost-msi-x-problem-on-5709-nics.patch:
  bnx2: Fix lost MSI-X problem on 5709 NICs (bnc#602980).
* Wed May  5 2010 jack@suse.de
- patches.fixes/ocfs2-Add-directory-entry-later-in-ocfs2_symlink-and.patch:
  ocfs2: Add directory entry later in ocfs2_symlink() and
  ocfs2_mknod() (bnc#595609).
- patches.fixes/ocfs2-add-OCFS2_INODE_SKIP_ORPHAN_DIR-flag-and-honor.patch:
  ocfs2: add OCFS2_INODE_SKIP_ORPHAN_DIR flag and honor it in
  the inode wipe code (bnc#595609).
- patches.fixes/ocfs2-avoid-direct-write-if-we-fall-back-to-buffered.patch:
  ocfs2: Avoid direct write if we fall back to buffered I/O
  (bnc#591039) - refreshed patch with a new version
- patches.fixes/ocfs2-use-OCFS2_INODE_SKIP_ORPHAN_DIR-in-ocfs2_mknod.patch:
  ocfs2: use OCFS2_INODE_SKIP_ORPHAN_DIR in ocfs2_mknod error path
  (bnc#595609).
- patches.fixes/ocfs2-use-OCFS2_INODE_SKIP_ORPHAN_DIR-in-ocfs2_symli.patch:
  ocfs2: use OCFS2_INODE_SKIP_ORPHAN_DIR in ocfs2_symlink error
  path (bnc#595609).
* Wed May  5 2010 hare@suse.de
- rpm/kernel-binary.spec.in: Enable install_vdso for s390/s390x
  (bnc#600535)
* Tue May  4 2010 duwe@suse.de
- patches.arch/ppc-public-query_cpu_stopped: powerpc: make
  query_cpu_stopped callable outside hotplug cpu (bnc#602208).
- patches.arch/ppc-start-only-stopped-cpus: powerpc: only call
  start-cpu when a CPU is stopped (bnc#602208).
* Tue May  4 2010 npiggin@suse.de
- patches.fixes/mm-independent-rr-slab.patch: Refresh.
* Tue May  4 2010 garloff@suse.de
- patches.suse/pagecache-limit.patch: As we only only enforce the
  unmapped pagecache, we can simplify significantly. [FATE309111]
- patches.suse/pagecache-limit-shmem.diff: Obsoleted.
* Tue May  4 2010 mmarek@suse.cz
- patches.fixes/keyspan-firmware-install.patch: Fix
  USB_SERIAL_KEYSPAN firmware dependencies (bnc#562095).
- Update config files.
* Tue May  4 2010 mmarek@suse.cz
- config.conf: Drop the config/s390/vanilla symlink, people keep
  breaking it.
- config/s390/vanilla: Delete.
* Tue May  4 2010 npiggin@suse.de
- patches.fixes/mm-independent-rr-slab.patch: independent rotors
  for slab and pagecache (bnc#600261).
- patches.suse/slab-memless-node-02-slab-use-numa_mem_id.patch:
  Refresh.
* Mon May  3 2010 bphilips@suse.de
- patches.fixes/tg3-fix-intx-fallback-when-msi-fails.patch: tg3:
  Fix INTx fallback when MSI fails (bnc#601198).
* Mon May  3 2010 jack@suse.de
- patches.fixes/novfs-truncate-EIO-fix.patch: novfs: ftruncate
  call returns EIO as it causes two open calls (bnc#596031).
* Mon May  3 2010 jack@suse.de
- patches.fixes/spinning-mutex-BKL-deadlock.patch: Updated the patch
  to the newer version that got posted for upstream inclusion
  (bnc#590705)
* Mon May  3 2010 bphilips@suse.de
- patches.fixes/ixgbe-fix-return-of-invalid-txq.patch: ixgbe:
  Fix return of invalid txq (bnc#601168).
* Sun May  2 2010 sjayaraman@suse.de
- patches.fixes/cifs-fix-oops-due-to-null-nameidata: Allow null nd
  (as nfs server uses) on create (bnc#593940).
* Fri Apr 30 2010 hare@suse.de
- patches.drivers/lpfc-8.3.5.8.1p-update: Update lpfc from
  8.3.5.8 to 8.3.5.8.1p (bnc#600983).
- patches.drivers/qla2xxx-8.03.01.06.11.1-k8-update: qla2xxx:
  Minor updates and fixes from upstream (bnc#599814).
* Fri Apr 30 2010 rjw@suse.de
- patches.fixes/kernel-core-add-pid_max-start-option.patch: init:
  Increase pid_max based on num_possible_cpus v4 (bnc#598253,
  FATE#306952).
* Thu Apr 29 2010 jeffm@suse.com
- patches.fixes/sctp-fix-oops-when-sending-queued-asconf-chunks:
  sctp: Fix oops when sending queued ASCONF chunks.
- patches.fixes/sctp-fix-to-calc-the-init-init-ack-chunk-length-correctly-is-set:
  sctp: fix to calc the INIT/INIT-ACK chunk length correctly
  is set (bnc#686813 CVE-2011-1573).
* Thu Apr 29 2010 jjolly@suse.de
- patches.arch/s390-14-01-vdso-ntp-multiplier.patch: vdso:
  use ntp adjusted clock multiplier (bnc#600516).
- patches.arch/s390-14-02-vdso-install.patch: vdso: add missing
  vdso_install target (bnc#600516).
* Thu Apr 29 2010 trenn@suse.de
- patches.fixes/x86_cpufreq_powernowk8_fix_wrong_freqs.patch:
  powernow-k8: Fix frequency reporting (bnc#599279).
* Thu Apr 29 2010 hare@suse.de
- patches.fixes/scsi-requeue-abort-request-race: Race between
  blk_abort_queue() and scsi_requeue_request() (bnc#588929).
* Thu Apr 29 2010 knikanth@suse.de
- patches.fixes/dm-release-map_lock-before-set_disk_ro: Refresh.
  Fix patch to call dm_table_get directly instead of calling
  dm_get_table unnecesarily.
* Wed Apr 28 2010 npiggin@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Fix 64bit bug (bnc#575194)
- patches.arch/x86-ftrace-fix-rodata-1.patch: Refresh.
- patches.xen/xen3-x86-ftrace-fix-rodata-1.patch: Refresh.
- patches.xen/xen3-x86-mark_rodata_rw.patch: Refresh.
* Wed Apr 28 2010 jkosina@suse.cz
- patches.suse/revert-percpu-stable-changes.patch: Revert module.c
  and module.h changes from -stable update (bnc#600364).
* Tue Apr 27 2010 jack@suse.de
- patches.fixes/spinning-mutex-BKL-deadlock.patch: Fix deadlock
  when acquiring mutex while holding BKL (bnc#590705).
* Mon Apr 26 2010 mmarek@suse.cz
- Update kabi files to allow a change in struct xfs_mount.
* Mon Apr 26 2010 jbenc@suse.cz
- supported.conf: removed hv drivers, as they are built as
  a separate KMP.
* Mon Apr 26 2010 mmarek@suse.cz
- patches.kabi/revert-2.6.32.12-b43: Revert b43 changes to
  preserve the kabi.
* Mon Apr 26 2010 gregkh@suse.de
- Update to final 2.6.32.12 release
* Mon Apr 26 2010 jbenc@suse.cz
- patches.suse/sched-revert-latency-defaults: Disable FAIR_SLEEPERS
  on s390.
- Update config files.
* Mon Apr 26 2010 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.32.12-rc2: Linux 2.6.32.12-rc2.
- patches.xen/xen3-add-support-for-intel-cougar-point-chipset.patch:
  Delete.
* Mon Apr 26 2010 hare@suse.de
- patches.drivers/qla4xxx-5.01.00.00.11.01-k13_5.01.00.00.11.01-k14.patch:
  QLA4xxx driver fixes for RC3 (bnc#585296).
* Mon Apr 26 2010 hare@suse.de
- patches.suse/fcoe-fix-a-circular-locking-is: fcoe: fix a
  circular locking issue with rtnl and sysfs mutex (bnc#595074).
- patches.suse/fcoe-fixes-wrong-error-exit-in: fcoe: fixes wrong
  error exit in fcoe_create (bnc#595074).
- patches.suse/libfc-set-seq_id-for-incoming: libfc: set seq_id
  for incoming sequence (bnc#595074).
* Sat Apr 24 2010 agraf@suse.de
- patches.fixes/kvm-rcu-0021-KVM-convert-slots_lock-to-a-mutex.patch:
  Unfuzz
* Sat Apr 24 2010 agraf@suse.de
- patches.fixes/kvm-rcu-0017-KVM-use-SRCU-for-dirty-log.patch:
  Rebase and enable again.
* Fri Apr 23 2010 gregkh@suse.de
- Update vanilla config files for .12-rc2 changes
* Fri Apr 23 2010 gregkh@suse.de
- Update to 2.6.32.12-rc2:
  - lots of bugfixes
  - security fixes
  - obsoletes:
  - patches.arch/i386-do-a-global-tlb-flush-in-S4-resume.patch
  - patches.arch/x86-32-clean-up-rwsem-inline-asm-statements.patch
  - patches.arch/x86-64-rwsem-64-bit-xadd-rwsem-implementation.patch
  - patches.arch/x86-64-rwsem-Avoid-store-forwarding-hazard-in-__downgrade_write.patch
  - patches.arch/x86-64-support-native-xadd-rwsem-implementation.patch
  - patches.arch/x86-Fix-breakage-of-UML-from-the-changes-in-the-rwsem-system.patch
  - patches.arch/x86-clean-up-rwsem-type-system.patch
  - patches.arch/x86_hpet_erratum_15.patch
  - patches.arch/x86_x2apic_double_enable_non_smp.patch
  - patches.drivers/add-support-for-intel-cougar-point-chipset.patch
  - patches.drivers/igb-add-support-for-82576NS-SerDes-adapter.patch
  - patches.drivers/lis3-fix-show-rate-for-8-bits-chips
  - patches.drivers/r8169-offical-fix-for-CVE-2009-4537-overlength-frame.patch
  - patches.fixes/PCIe-AER-reject-aer-inject-if-hardware-mask-error-reporting.patch
  - patches.fixes/dm-mpath-requeue-stall
  - patches.fixes/fc_bsg_request_packed
  - patches.fixes/fix-sched_getaffinity-1
  - patches.fixes/fix-sched_getaffinity-2
  - patches.fixes/fix-sched_getaffinity-3
  - patches.fixes/hid-fix-gyration-oops.patch
  - patches.fixes/ipoib-tx-queue-lockup-fix.patch
  - patches.fixes/kvm-disable-pvmmu-0001-KVM-x86-disable-paravirt-mmu-reporting.patch
  - patches.fixes/ocfs2-Change-bg_chain-check-for-ocfs2_validate_gd_parent.patch
  - patches.fixes/ocfs2-set-i_mode-on-disk-during-acl-operations.patch
  - patches.fixes/oom-fix-the-unsafe-usage-of-badness-in-proc_oom_score
  - patches.fixes/pci-fix-nested-spinlock-hang-in-aer_inject.patch
  - patches.fixes/pci-update-pci_set_vga_state-to-call-arch-functions.patch
  - patches.fixes/raw-fsync-EINVAL-fix.diff
  - patches.fixes/scsi-add-scsi-target-reset-support-to-ioctl
  - patches.fixes/scsi-fc-class-failfast-bsg-requests
  - patches.fixes/tty-release_one_tty-forgets-to-put-pids
  - patches.fixes/vgaarb-fix-vga-arbiter-to-accept-pci-domains-other-than-0.patch
  - patches.fixes/x86-amd-gart_Disable_GART_explicitly_before_initialization.patch
  - patches.fixes/x86-amd-iommu_enable_iommu_before_attaching_devices.patch
  - patches.fixes/x86-amd-iommu_revert_disable_IOMMUs_on_kernel_crash.patch
  - patches.fixes/x86-get-multinode-cpu-info-from-msr.patch
  - patches.fixes/xfs-nonblocking-inode-locking-io-completion.patch
  - patches.suse/rlim-0002-resource-move-kernel-function-inside-__KERNEL__.patch
  - patches.xfs/xfs-Avoid-inodes-in-reclaim-when-flushing-from-inode.patch
  - patches.xfs/xfs-Don-t-flush-stale-inodes.patch
  - patches.xfs/xfs-Ensure-we-force-all-busy-extents-in-range-to-dis.patch
  - patches.xfs/xfs-Fix-error-return-for-fallocate-on-XFS.patch
  - patches.xfs/xfs-I-O-completion-handlers-must-use-NOFS-allocation.patch
  - patches.xfs/xfs-Wrapped-journal-record-corruption-on-read-at-rec.patch
  - patches.xfs/xfs-check-for-not-fully-initialized-inodes-in-xfs_ir.patch
  - patches.xfs/xfs-fix-mmap_sem-iolock-inversion-in-xfs_free_eofblo.patch
  - patches.xfs/xfs-fix-stale-inode-flush-avoidance.patch
  - patches.xfs/xfs-fix-timestamp-handling-in-xfs_setattr.patch
  - patches.xfs/xfs-reclaim-all-inodes-by-background-tree-walks.patch
  - patches.xfs/xfs-reclaim-inodes-under-a-write-lock.patch
  - patches.xfs/xfs-simplify-inode-teardown.patch
  - patches.xfs/xfs-xfs_swap_extents-needs-to-handle-dynamic-fork-of.patch
* Fri Apr 23 2010 garloff@suse.de
- patches.suse/pagecache-limit-shmem.diff: Subtract shared memory
  when enforcing pagecache limit (FATE309111).
* Fri Apr 23 2010 rwysocki@suse.de
- patches.arch/intel-iommu-Dont-complain-that-ACPI_DMAR_SCOPE_TYPE_IOAPIC-is-not-supported.patch:
  intel-iommu: Don't complain that ACPI_DMAR_SCOPE_TYPE_IOAPIC
  is not supported (bnc#579639, FATE#306952).
* Thu Apr 22 2010 jslaby@suse.de
- patches.fixes/kdb-no-printk-logging.patch: Refresh.
  Added hunks in kdb_lsmod and kdb_env.
* Thu Apr 22 2010 jbohac@suse.cz
- patches.fixes/ipv6-fix-dad-race.patch: IPV6 - fix DAD race
  (bnc#577967, bnc#569916).
* Thu Apr 22 2010 jjolly@suse.de
- patches.arch/s390-13-01-nss-add-previous-stmt.patch:
  nss: add missing .previous statement to asm function
  (bnc#598553,LTC#62329).
- patches.arch/s390-13-02-zcore-reipl-check.patch: zcore: Fix
  reipl device detection (bnc#598553).
* Thu Apr 22 2010 tiwai@suse.de
- patches.drivers/drm-i915-IronLake-fix-VGA-output-at-S4: Fix
  IronLake VGA output at S4 (bnc#595755).
* Thu Apr 22 2010 agruen@suse.de
- patches.fixes/fix-sched_getaffinity-3: sched: Follow-up to
  the sched_getaffinity() fix (bnc#596720, bnc#598837).
* Thu Apr 22 2010 trenn@suse.de
- patches.fixes/x86_hp_add_more_usecrs_to_whitelist.patch:
  Add more HP machines to use pci=use_crs by default (bnc#578572).
* Thu Apr 22 2010 rwysocki@suse.de
- patches.fixes/kernel-core-add-pid_max-start-option.patch:
  init: Provide a kernel start parameter to increase pid_max
  (bnc#598253, FATE#306952).
* Thu Apr 22 2010 rwysocki@suse.de
- patches.arch/x86-UV-Delete-unneeded-boot-messages.patch: x86,
  UV: Delete unneeded boot messages (bnc#590585, FATE#306952).
* Thu Apr 22 2010 rwysocki@suse.de
- patches.arch/tlb_uv_update2.patch: Refresh.
* Wed Apr 21 2010 trenn@suse.de
- These fix kexec/kdump with AMD IOMMU enabled:
- patches.fixes/x86-amd-gart_Disable_GART_explicitly_before_initialization.patch:
  x86/gart: Disable GART explicitly before initialization
  (bnc#589650).
- patches.fixes/x86-amd-iommu_enable_iommu_before_attaching_devices.patch:
  x86/amd-iommu: enable iommu before attaching devices
  (bnc#589650).
- patches.fixes/x86-amd-iommu_revert_disable_IOMMUs_on_kernel_crash.patch:
  Revert "x86: disable IOMMUs on kernel crash" (bnc#589650).
* Wed Apr 21 2010 duwe@suse.de
- patches.fixes/ibmvscsi-add-barriers: ibmvfc: Fix command
  completion handling (bnc#598270).
- patches.fixes/ibmvscsi-reduce-error-recovery-timeout: ibmvfc:
  Reduce error recovery timeout (bnc#598270).
* Wed Apr 21 2010 jslaby@suse.de
- patches.fixes/kdb-no-printk-logging.patch: printk,kdb: capture
  printk() when in kdb shell (bnc#598246).
* Wed Apr 21 2010 tiwai@suse.de
- patches.drivers/drm-i915-Clear-TV-sense-state-bits-on-GM45:
  drm/i915: Clear the TV sense state bits on cantiga to make TV
  detection reliable (bnc#597648, bnc#597650).
* Wed Apr 21 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.11 and c/s 1014 (bnc#569194,
  bnc#591371).
- patches.xen/xen-blktap-teardown: blktap: fix cleanup after
  unclean application exit #2 (bnc#569194).
* Wed Apr 21 2010 sjayaraman@suse.de
- patches.suse/sched-revert-latency-defaults: Re-enable FAIR_SLEEPERS.
  Also disable NORMALIZED_SLEEPER which was actually a dead code earlier.
* Tue Apr 20 2010 jkosina@suse.cz
- patches.fixes/x86-get-multinode-cpu-info-from-msr.patch: x86,
  amd: Get multi-node CPU info from NodeId MSR instead of PCI
  config space (bnc#594066).
* Tue Apr 20 2010 nfbrown@suse.de
- patches.fixes/md-write-behind-race: md/raid1: delay reads that
  could overtake behind-writes (bnc#590415).
* Tue Apr 20 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.05.11.1-k8-update: qla2xxx:
  minor updates and fixes from upstream (bnc#596783).
* Tue Apr 20 2010 bphilips@suse.de
- patches.fixes/cnic-fix-crash-during-bnx2x-mtu-change.patch:
  Fix back port and add git-commit (bnc#564640)
* Mon Apr 19 2010 jack@suse.de
- patches.fixes/novfs-LFS-initialization: fs: novfs: Initialize
  super-block with standard macros.
- patches.fixes/novfs-return-ENOTEMPTY-when-deleting-nonempty-dir:
  fs: novfs: Return ENOTEMPTY when tyring to delete a non-empty
  folder (bnc#583964).
* Mon Apr 19 2010 jeffm@suse.com
- patches.fixes/tty-release_one_tty-forgets-to-put-pids: tty:
  release_one_tty() forgets to put pids (bnc#596462).
* Mon Apr 19 2010 jeffm@suse.com
- patches.fixes/oom-fix-the-unsafe-usage-of-badness-in-proc_oom_score:
  oom: fix the unsafe usage of badness() in proc_oom_score()
  (bnc#596460).
* Mon Apr 19 2010 duwe@suse.de
- patches.drivers/ehea-0102-0103-update: Fix feastlp3 drop to xmon
  with .free_pages+0x48/0x70 (ehea) (bnc#597120).
* Mon Apr 19 2010 duwe@suse.de
- patches.arch/ppc-pseries-cmm4kdump: kdump support for CMM
  (bnc#597583).
- Update appropriate ppc config files.
* Mon Apr 19 2010 npiggin@suse.de
- patches.fixes/kernel-mutex-adaptive-cpu-offline-livelock.patch:
  kernel mutex adaptive cpu offline livelock (bnc#595960,
  bnc#597135).
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, rpm/old-packages.conf:
  Obsolete kernel-vmi-base by kernel-pae-base (bnc#594271).
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/mkspec, rpm/old-packages.conf: Explicitly list ppc64 flavors
  that obsolete kernel-kdump.
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/old-packages.conf: s390(x) provides/obsoletes not needed
  anymore.
* Thu Apr 15 2010 tiwai@suse.de
- patches.drivers/lis3-add-support-for-hp-probook-2: lis3:
  Add axis quirk for HP ProBook 532x (bnc#596943).
* Thu Apr 15 2010 teheo@suse.de
- patches.fixes/block-blk_abort_request-lock-fix: libata/SCSI:
  fix locking around blk_abort_request() (bnc#585927).
* Wed Apr 14 2010 agruen@suse.de
- patches.fixes/fix-sched_getaffinity-{1,2}: sched_getaffinity():
  Allow less than NR_CPUS length (bnc#596720).
* Wed Apr 14 2010 jack@suse.de
- patches.fixes/raw-fsync-EINVAL-fix.diff: raw: fsync method is
  now required (bnc#590937).
* Tue Apr 13 2010 tiwai@suse.de
- patches.suse/bootsplash-console-fix: Fix rendering on linux
  console with bootsplash (bnc#595657).
* Mon Apr 12 2010 jack@suse.de
- patches.fixes/novfs-dentry-cache-limit.patch: novfs: Remove
  dcache count restricting code (bnc#576026).
* Mon Apr 12 2010 sjayaraman@suse.de
- patches.suse/SoN-11-mm-reserve.patch: Fix a build warning.
* Mon Apr 12 2010 bphilips@suse.de
- patches.drivers/igb-add-support-for-82576-et2-quad-port-server-adapter.patch:
  Delete, duplicate patch.
* Mon Apr 12 2010 jack@suse.de
- patches.fixes/novfs-fix-oops-in-scope-finding: novfs: fix an
  oops in novfs scope-finding code (bnc#588579) - actually enable
  the patch
* Mon Apr 12 2010 hare@suse.de
- patches.drivers/cnic-give-a-chance-for-the-uio-device-to-be-opened:
  Fixup compilation warnings.
- patches.drivers/qla2xxx-8.03.01.03.11.1-k8-update: Fixup compilation
  warnings.
- patches.fixes/ipr-strstrip-retval-fix: Fixup compilation
  warnings in ipr.
- patches.suse/dm-mpath-leastpending-select-path-fix: Compile
  warning in dm-least-pending.
* Mon Apr 12 2010 mszeredi@suse.cz
- patches.fixes/mempolicy-fix-get_mempolicy-for-relative-and-static-nodes.patch:
  mempolicy: fix get_mempolicy() for relative and static nodes
  (bnc#594305).
* Mon Apr 12 2010 hare@suse.de
- patches.drivers/hpsa-only-unmap-buffer-when-allocated: hpsa:
  unmap ioctl xfer buffer correctly (bnc#590856).
- patches.drivers/hpsa-update: Update HP SA driver to version
  2.0.2-1 (bnc#591376).
* Mon Apr 12 2010 jkosina@suse.cz
- series.conf: remove stale patch
* Mon Apr 12 2010 jkosina@suse.cz
- series.conf: added forgotten
  patches.drivers/igb-add-support-for-82576-et2-quad-port-server-adapter.patch
* Mon Apr 12 2010 bphilips@suse.de
- patches.fixes/ixgbe-power-down-phy-during-driver-resets.patch:
  ixgbe: Power down PHY during driver resets (bnc#594997).
* Mon Apr 12 2010 bphilips@suse.de
- patches.drivers/igb-add-support-for-82576-et2-quad-port-server-adapter.patch:
  igb: Add support for 82576 ET2 Quad Port Server Adapter.
* Mon Apr 12 2010 bphilips@suse.de
- patches.drivers/r8169-offical-fix-for-CVE-2009-4537-overlength-frame.patch:
  r8169: offical fix for CVE-2009-4537 (overlength frame DMAs)
  (bnc#567376, CVE-2009-4537).
* Mon Apr 12 2010 bphilips@suse.de
- patches.drivers/bnx2x-initialize-cnic-status-block-during-chip-reset.patch:
  bnx2x: Initialize cnic status block during chip reset
  (bnc#564640).
* Sun Apr 11 2010 coly.li@suse.de
- patches.fixes/ocfs2-avoid-direct-write-if-we-fall-back-to-buffered.patch:
  ocfs2: avoid direct write if we fall back to buffered
  (BNC#591039).
* Sat Apr 10 2010 mfasheh@suse.com
- patches.suse/ocfs2-Add-dir_resv_level-mount-option.patch:
  ocfs2: Add dir_resv_level mount option (bnc#501563 FATE#307247
  bnc#583539).
- patches.suse/ocfs2-change-default-reservation-window-sizes.patch:
  ocfs2: change default reservation window sizes (bnc#501563
  FATE#307247 bnc#583539).
- patches.suse/ocfs2-clean-up-localalloc-mount-option-size-parsing.patch:
  ocfs2: clean up localalloc mount option size parsing (bnc#501563
  FATE#307247 bnc#583539).
- patches.suse/ocfs2-increase-the-default-size-of-local-alloc-windo.patch:
  ocfs2: increase the default size of local alloc windows
  (bnc#501563 FATE#307247 bnc#583539).
* Sat Apr 10 2010 mfasheh@suse.com
  Ocfs2 fixes from the ocfs2.git repository which will go upstream soon:
- patches.fixes/ocfs2-Check-the-owner-of-a-lockres-inside-the-spinlo.patch:
  ocfs2: Check the owner of a lockres inside the spinlock.
- patches.fixes/ocfs2_dlmfs-User-DLM_-when-decoding-file-open-flags.patch:
  ocfs2_dlmfs: User DLM_* when decoding file open flags.
* Sat Apr 10 2010 coly.li@suse.de
- patches.fixes/ocfs2-Compute-metaecc-for-superblocks-during-online-.patch:
  ocfs2: Compute metaecc for superblocks during online resize. (BNC#592945).
- backport upstream ocfs2 to SLES11 SP1 kernel.
  - patches.fixes/Ocfs2-Handle-deletion-of-reflinked-oprhan-inodes-cor.patch:
    Ocfs2: Handle deletion of reflinked oprhan inodes correctly..
  - patches.fixes/Ocfs2-Journaling-i_flags-and-i_orphaned_slot-when-ad.patch:
    Ocfs2: Journaling i_flags and i_orphaned_slot when adding
    inode to orphan dir..
  - patches.fixes/PATCH-Skip-check-for-mandatory-locks-when-unlocking.patch:
    [PATCH] Skip check for mandatory locks when unlocking.
  - patches.fixes/fs-ocfs2-cluster-tcp.c-remove-use-of-NIPQUAD-use-pI4.patch:
    fs/ocfs2/cluster/tcp.c: remove use of NIPQUAD, use %%pI4.
  - patches.fixes/ocfs2-Clear-undo-bits-when-local-alloc-is-freed.patch:
    ocfs2: Clear undo bits when local alloc is freed.
  - patches.fixes/ocfs2-Fix-a-race-in-o2dlm-lockres-mastery.patch:
    ocfs2: Fix a race in o2dlm lockres mastery.
  - patches.fixes/ocfs2-Fix-the-update-of-name_offset-when-removing-xa.patch:
    ocfs2: Fix the update of name_offset when removing xattrs.
  - patches.fixes/ocfs2-Init-meta_ac-properly-in-ocfs2_create_empty_xa.patch:
    ocfs2: Init meta_ac properly in ocfs2_create_empty_xattr_block..
  - patches.fixes/ocfs2-Update-i_blocks-in-reflink-operations.patch:
    ocfs2: Update i_blocks in reflink operations..
* Sat Apr 10 2010 mfasheh@suse.com
- patches.fixes/sd-retry-readcap-on-ua: Fix build breakage in
  drivers/scsi/sd.c:
  /usr/src/packages/BUILD/kernel-default-2.6.32.11/linux-2.6.32/drivers/scsi/sd.c:
  In function 'read_capacity_10':
  /usr/src/packages/BUILD/kernel-default-2.6.32.11/linux-2.6.32/drivers/scsi/sd.c:
  1470: error: lvalue required as left operand of assignment
  make[4]: *** [drivers/scsi/sd.o] Error 1
  make[3]: *** [drivers/scsi] Error 2
  make[3]: *** Waiting for unfinished jobs....
* Fri Apr  9 2010 tiwai@suse.de
- patches.drivers/synaptics-hp-clickpad: Refresh.  Add missing
  call to restore LED status at reconnection (bnc#594835)
* Fri Apr  9 2010 hare@suse.de
- patches.fixes/sd-retry-readcap-on-ua: Compilation fix.
* Fri Apr  9 2010 hare@suse.de
- patches.fixes/sd-retry-readcap-on-ua: sd: retry read_capacity
  on UNIT_ATTENTION (bnc#590687).
* Fri Apr  9 2010 duwe@suse.de
- patches.arch/power7-type1-numa-affinity: powerpc: Add form 1
  NUMA affinity (bnc#594586).
* Fri Apr  9 2010 hare@suse.de
- patches.drivers/cnic-give-a-chance-for-the-uio-device-to-be-opened:
  Compile fix.
* Fri Apr  9 2010 hare@suse.de
- patches.suse/fcoe-libfc-increased-cdb-size: fcoe, libfc:
  increased CDB size to 16 bytes for fcoe. (bnc#595074).
- patches.suse/libfc-bug-in-erroring-out-upon: libfc: bug in
  erroring out upon FCP_RSP_LEN_VAL in fc_fcp_resp (bnc#595074).
* Fri Apr  9 2010 hare@suse.de
- patches.drivers/cnic-give-a-chance-for-the-uio-device-to-be-opened:
  cnic: Give a chance for the uio device to be opened
  (bnc#564640).
* Fri Apr  9 2010 hare@suse.de
- patches.drivers/bnx2i-mtu-change-bugfix: bnx2i: Bug fixes
  related to MTU changes (bnc#564640).
* Fri Apr  9 2010 knikanth@suse.de
- patches.fixes/loop-update-mtime.patch: loop: Update mtime when
  writing using aops (bnc#590738).
* Fri Apr  9 2010 jjolly@suse.de
- patches.arch/s390-12-01_callhome.patch: callhome:  fix broken
  proc interface and activate compid (bnc#594473).
- patches.arch/s390-12-02-vmalloc.patch: vmalloc: ipl failure
  with enabled memory cgroups (bnc#594473).
* Thu Apr  8 2010 rjw@suse.de
- patches.arch/tlb_uv_update2.patch: x86 / UV: TLB shootdown
  (BAU) update (bnc#594131, FATE#306952).
* Thu Apr  8 2010 rjw@suse.de
- patches.arch/x86-MCE-fix-MSR_IA32_MCI_CTL2-CMCI-threshold-setup.patch:
  x86, MCE, fix MSR_IA32_MCI_CTL2 CMCI threshold setup
  (bnc#592176).
* Thu Apr  8 2010 jeffm@suse.de
- patches.fixes/reiserfs-fix-permissions-on-reiserfs_priv:
  reiserfs: Fix permissions on .reiserfs_priv (bnc#593906
  CVE-2010-1146).
* Thu Apr  8 2010 bphilips@suse.de
- patches.drivers/ixgbe-Fix-82599-multispeed-fiber-link-issues-due-to-.patch:
  ixgbe: Fix 82599 multispeed fiber link issues due to Tx laser
  flapping (bnc#589804).
* Thu Apr  8 2010 jslaby@suse.de
- patches.suse/cgroup-disable-memcg-when-low-lowmem.patch:
  disable memory cgroup if low lowmem (bnc#586684).
* Thu Apr  8 2010 hare@suse.de
- patches.drivers/mpt2sas-04.100.01.03-update: Add missing
  hunk (bnc#591950).
* Thu Apr  8 2010 trenn@suse.de
- patches.fixes/pci_use_acpi_resources_whitelist.patch: Whitelist
  HP ProLiant DL980 to use pci=use_crs by default (bnc#578572).
* Thu Apr  8 2010 hare@suse.de
- patches.drivers/mpt2sas-04.100.01.03-update: mpt2sas: IOs
  needs to be pause until all handles are refreshed (bnc#591950).
* Thu Apr  8 2010 hare@suse.de
- patches.drivers/lpfc-8.3.5.8-update: Emulex lpfc fixes for RC3 -
  8.3.5.8 (bnc#594391).
* Wed Apr  7 2010 bphilips@suse.de
- patches.drivers/be2net-fix-bug-in-vlan-rx-path-for-big-endian-archit.patch:
  be2net: fix bug in vlan rx path for big endian architecture
  (bnc#594583).
* Wed Apr  7 2010 tiwai@suse.de
- patches.drivers/lis3-add-support-for-hp-probook: lis3: add
  support for HP ProBook 432x/442x/452x/522x (bnc#594399).
* Wed Apr  7 2010 jslaby@suse.de
- patches.fixes/sched-fix-cputime-monotonicity.patch: Update
  references (bnc#585241 bnc#590927).
- patches.fixes/sched-fix-task-times_granularity.patch: sched:
  Fix granularity of task_u/stime() (bnc#585241 bnc#590927).
- patches.fixes/sched-time-define-nsecs_to_jiffies.patch: sched,
  time: Define nsecs_to_jiffies() (bnc#585241 bnc#590927).
* Wed Apr  7 2010 jdelvare@suse.de
- patches.drivers/ipmi-add-parameter-to-limit-cpu-usage-in-kipmid.patch:
  ipmi: add parameter to limit CPU usage in kipmid (bnc#468397).
* Wed Apr  7 2010 tiwai@suse.de
- patches.drivers/lis3-fix-show-rate-for-8-bits-chips: lis3:
  fix show rate for 8 bits chips (bnc#594367).
* Wed Apr  7 2010 jkosina@suse.cz
- patches.fixes/hpwdt-fix-lower-timeout-limit.patch: hpwdt -
  fix lower timeout limit (bnc#581103).
* Wed Apr  7 2010 jkosina@suse.cz
- patches.fixes/hid-fix-gyration-oops.patch: HID: fix oops in
  gyration_event() (bnc#589329).
* Tue Apr  6 2010 bphilips@suse.de
- patches.drivers/cnic-Use-union-for-the-status-blocks-of-different-de.patch:
  cnic: Use union for the status blocks of different
  devices. (bnc#564640).
- patches.fixes/cnic-fix-crash-during-bnx2x-mtu-change.patch:
  cnic: Fix crash during bnx2x MTU change. (bnc#564640).
* Tue Apr  6 2010 rjw@suse.de
- patches.arch/x86-fix-unknown_nmi_error.patch: x86: Fix
  unknown_nmi_error() (bnc#593731).
* Tue Apr  6 2010 gregkh@suse.de
- patches.kabi/kabi-fix-up-struct-hrtimer_cpu_base-change.patch:
  KABI: fix up struct hrtimer_cpu_base change.
* Tue Apr  6 2010 tiwai@suse.de
- patches.drivers/drm-i915-Add-display-hotplug-event-on-Ironlake:
  drm/i915: Add display hotplug event on Ironlake (bnc#593318).
- patches.drivers/drm-i915-fix-eDP-pipe-mask: drm/i915: fix eDP
  pipe mask (bnc#593319).
- patches.drivers/drm-i915-fix-pixel-color-depth-setting-on-eDP:
  drm/i915: fix pixel color depth setting on eDP (bnc#593319).
- patches.drivers/drm-i915-parse-eDP-panel-color-depth-from-VBT-block:
  drm/i915: parse eDP panel color depth from VBT block
  (bnc#593319).
* Tue Apr  6 2010 trenn@suse.de
- patches.arch/x86_hpet_erratum_15.patch: x86, hpet: Erratum
  workaround for read after write of HPET comparator (bnc#587746).
- patches.arch/x86_x2apic_double_enable_non_smp.patch: x86: Fix
  double enable_IR_x2apic() call on SMP kernel on !SMP boards
  (bnc#593934).
* Tue Apr  6 2010 bphilips@suse.de
- Move patches.drivers/broadcom-Fix-slow-link-problem.patch to the right
  location in the series
* Tue Apr  6 2010 bphilips@suse.de
  Missed a tg3 fix
- patches.drivers/broadcom-Fix-slow-link-problem.patch: broadcom:
  Fix slow link problem (bnc#556234).
* Tue Apr  6 2010 bphilips@suse.de
  Break out these monolithic patches into individual patches from upstream:
    patches.drivers/phy-broadcom-bug-fixes-for-sp1.patch
    patches.drivers/tg3-update-version-to-3.104.patch
    patches.drivers/tg3-updates-from-f4188d-to-ba5b0bf.patch
- patches.drivers/broadcom-Consolidate-dev_flags-definitions.patch:
  broadcom: Consolidate dev_flags definitions (FATE#307117,
  bnc#556234).
- patches.drivers/broadcom-Isolate-phy-dsp-accesses.patch:
  broadcom: Isolate phy dsp accesses (FATE#307117, bnc#556234).
- patches.drivers/drivers-net-Move-and-to-end-of-previous-line.patch:
  drivers/net: Move && and || to end of previous line
  (bnc#573237).
- patches.drivers/drivers-net-use-DEFINE_PCI_DEVICE_TABLE.patch:
  drivers/net/: use DEFINE_PCI_DEVICE_TABLE() (bnc#573237).
- patches.drivers/tg3-5785-Set-port-mode-to-MII-when-link-down.patch:
  tg3: 5785: Set port mode to MII when link down (bnc#556234,
  FATE#307117).
- patches.drivers/tg3-Abort-phy-init-for-5717-serdes-devices.patch:
  tg3: Abort phy init for 5717 serdes devices (bnc#573237).
- patches.drivers/tg3-Add-50610M-phy-ID-for-5785.patch: tg3:
  Add 50610M phy ID for 5785 (bnc#556234, FATE#307117).
- patches.drivers/tg3-Add-5717-phy-ID.patch: tg3: Add 5717 phy ID
  (FATE#307117, bnc#556234).
- patches.drivers/tg3-Add-5717-serdes-phy-ID.patch: tg3: Add
  5717 serdes phy ID (bnc#573237).
- patches.drivers/tg3-Add-57765-asic-rev.patch: tg3: Add 57765
  asic rev (bnc#573237).
- patches.drivers/tg3-Add-57765-phy-ID-and-enable-devices.patch:
  tg3: Add 57765 phy ID and enable devices. (bnc#573237).
- patches.drivers/tg3-Add-AC131-power-down-support.patch: tg3:
  Add AC131 power down support (bnc#556234, FATE#307117).
- patches.drivers/tg3-Add-more-PCI-DMA-map-error-checking.patch:
  tg3: Add more PCI DMA map error checking (bnc#556234,
  FATE#307117).
- patches.drivers/tg3-Add-new-HW_TSO_3-flag-for-5717.patch: tg3:
  Add new HW_TSO_3 flag for 5717 (FATE#307117, bnc#556234).
- patches.drivers/tg3-Add-prodring-parameter-to-tg3_alloc_rx_skb.patch:
  tg3: Add prodring parameter to tg3_alloc_rx_skb() (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-Add-reliable-serdes-detection-for-5717-A0.patch:
  tg3: Add reliable serdes detection for 5717 A0 (bnc#573237).
- patches.drivers/tg3-Add-rx-prod-ring-consolidation.patch: tg3:
  Add rx prod ring consolidation (FATE#307117, bnc#556234).
- patches.drivers/tg3-Add-some-VPD-preprocessor-constants.patch:
  tg3: Add some VPD preprocessor constants (bnc#573237).
- patches.drivers/tg3-Allow-DMAs-to-cross-cacheline-boundaries.patch:
  tg3: Allow DMAs to cross cacheline boundaries (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-Assign-flags-to-fixes-in-start_xmit_dma_bug.patch:
  tg3: Assign flags to fixes in start_xmit_dma_bug (bnc#556234,
  FATE#307117).
- patches.drivers/tg3-Bypass-power-source-switching-for-57765.patch:
  tg3: Bypass power source switching for 57765 (bnc#573237).
- patches.drivers/tg3-Clean-tg3_init_one.patch: tg3: Clean
  tg3_init_one() (bnc#573237).
- patches.drivers/tg3-Consider-rx_std_prod_idx-a-hw-mailbox.patch:
  tg3: Consider rx_std_prod_idx a hw mailbox (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-Convert-PHY_ADDR-TG3_PHY_MII_ADDR.patch:
  tg3: Convert PHY_ADDR => TG3_PHY_MII_ADDR (bnc#556234,
  FATE#307117).
- patches.drivers/tg3-Create-aliases-for-rx-producer-mailbox-regs.patch:
  tg3: Create aliases for rx producer mailbox regs (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-Create-tg3_poll_msix-for-non-zero-MSIX-vecs.patch:
  tg3: Create tg3_poll_msix() for non-zero MSIX vecs (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-Disable-5717-serdes-and-B0-support.patch:
  tg3: Disable 5717 serdes and B0 support (bnc#573237).
- patches.drivers/tg3-Don-t-touch-RCB-nic-addresses.patch: tg3:
  Don't touch RCB nic addresses (FATE#307117, bnc#556234).
- patches.drivers/tg3-Enable-PLL-PD-when-CLKREQ-disabled-for-5717A0.patch:
  tg3: Enable PLL PD when CLKREQ disabled for 5717A0 (bnc#573237).
- patches.drivers/tg3-Extend-loopback-test-timeout.patch: tg3:
  Extend loopback test timeout (bnc#556234, FATE#307117).
- patches.drivers/tg3-Fix-5717-and-57765-memory-selftests.patch:
  tg3: Fix 5717 and 57765 memory selftests (bnc#573237).
- patches.drivers/tg3-Fix-DIDs-Enable-5717-support.patch: tg3:
  Fix DIDs, Enable 5717 support (FATE#307117, bnc#556234).
- patches.drivers/tg3-Fix-disappearing-57780-devices.patch: tg3:
  Fix disappearing 57780 devices (bnc#556234, FATE#307117).
- patches.drivers/tg3-Fix-std-prod-ring-nicaddr-for-5787-and-57765.patch:
  tg3: Fix std prod ring nicaddr for 5787 and 57765 (bnc#573237).
- patches.drivers/tg3-Fix-std-rx-prod-ring-handling.patch: tg3:
  Fix std rx prod ring handling (bnc#573237).
- patches.drivers/tg3-Fix-tx-mailbox-initialization.patch: tg3:
  Fix tx mailbox initialization (bnc#573237).
- patches.drivers/tg3-Improve-5785-PCIe-performance.patch: tg3:
  Improve 5785 PCIe performance (bnc#556234, FATE#307117).
- patches.drivers/tg3-Improve-internal-resource-allocations.patch:
  tg3: Improve internal resource allocations (bnc#573237).
- patches.drivers/tg3-Lay-proucer-ring-handling-groundwork.patch:
  tg3: Lay proucer ring handling groundwork (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-Make-TSS-enable-independent-of-MSI-X-enable.patch:
  tg3: Make TSS enable independent of MSI-X enable (bnc#573237).
- patches.drivers/tg3-Make-tg3_alloc_rx_skb-a-dst-only-operation.patch:
  tg3: Make tg3_alloc_rx_skb() a dst-only operation (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-Move-TG3_FLG2_PROTECTED_NVRAM-to-tg3_flags3.patch:
  tg3: Move TG3_FLG2_PROTECTED_NVRAM to tg3_flags3 (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-Move-napi_add-calls-below-tg3_get_invariants.patch:
  tg3: Move napi_add calls below tg3_get_invariants (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-Napify-tg3_start_xmit_dma_bug.patch: tg3:
  Napify tg3_start_xmit_dma_bug() (FATE#307117, bnc#556234).
- patches.drivers/tg3-Prevent-a-PCIe-tx-glitch.patch: tg3:
  Prevent a PCIe tx glitch (bnc#556234, FATE#307117).
- patches.drivers/tg3-Refine-TSO-and-MSI-discovery.patch: tg3:
  Refine TSO and MSI discovery (FATE#307117, bnc#556234).
- patches.drivers/tg3-Supply-a-nicaddr-for-57765-jumbo-RCB.patch:
  tg3: Supply a nicaddr for 57765 jumbo RCB (bnc#573237).
- patches.drivers/tg3-Turn-off-the-debug-UART-for-57765.patch:
  tg3: Turn off the debug UART for 57765 (bnc#573237).
- patches.drivers/tg3-Update-copyright-and-driver-version.patch:
  tg3: Update copyright and driver version (bnc#573237).
- patches.drivers/tg3-Update-version-to-3.103.patch: tg3: Update
  version to 3.103 (FATE#307117, bnc#556234).
- patches.drivers/tg3-Update-version-to-3.104.patch: tg3: Update
  version to 3.104 (FATE#307117, bnc#556234).
- patches.drivers/tg3-Use-pci_read_vpd-instead-of-private-method.patch:
  tg3: Use pci_read_vpd() instead of private method (bnc#573237).
- patches.drivers/tg3-Use-tg3_start_xmit_dma_bug-for-5717-A0.patch:
  tg3: Use tg3_start_xmit_dma_bug for 5717 A0 (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-broadcom-Add-APD-support-for-GPHYs.patch:
  tg3 / broadcom: Add APD support for GPHYs (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-broadcom-Add-PHY_BRCM_CLEAR_RGMII_MODE-flag.patch:
  tg3 / broadcom: Add PHY_BRCM_CLEAR_RGMII_MODE flag (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-broadcom-Add-code-to-disable-rxc-refclk.patch:
  tg3 / broadcom: Add code to disable rxc refclk (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-broadcom-Optionally-disable-TXC-if-no-link.patch:
  tg3 / broadcom: Optionally disable TXC if no link (FATE#307117,
  bnc#556234).
- patches.drivers/tg3-broadcom-Refine-AC131-APD-support.patch: tg3
  / broadcom: Refine AC131 APD support (FATE#307117, bnc#556234).
- patches.drivers/tg3-entropy-source.patch: Refresh.
- patches.drivers/tg3-remove-use-of-skb_dma_map-unmap.patch:
  tg3: remove use of skb_dma_map/unmap (bnc#573237).
- patches.drivers/tg3-rename-rx_-std-jmb-_ptr.patch: tg3: rename
  rx_[std|jmb]_ptr (FATE#307117, bnc#556234).
- patches.drivers/tg3-tg3_alloc_rx_skb-tnapi-tp.patch: tg3:
  tg3_alloc_rx_skb(tnapi => tp) (FATE#307117, bnc#556234).
* Mon Apr  5 2010 gregkh@suse.de
- update to 2.6.32.11:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/x86-Fix-sched_clock_cpu-for-systems-with-unsynchronized-TSC.patch
  - patches.arch/x86-apic-use-logical-flat-for-systems-with-8-or-fewer-logical-cpus.patch
  - patches.arch/x86-revert-apic-Use-logical-flat-on-intel-with-8-or-fewer-logical-cpus.patch
  - patches.arch/x86_64_apic_consider_hotplug_for_mode_logical_flat.patch
  - patches.drivers/alsa-sp1-hda-48-alc260-will-quirk-for-acer
  - patches.drivers/alsa-sp1-hda-68-fix-realtek-secondary-adcs
  - patches.drivers/alsa-sp1-hda-72-alc260-fix-basic-model
  - patches.drivers/drm-i915-Avoid-NULL-deref-in-get_pages-unwind-after-error.patch
  - patches.drivers/e1000e-enable-new-82567V-3-device.patch
  - patches.drivers/ixgbe-add-support-for-82599-KR-device-0x1517.patch
  - patches.fixes/cpuset-fix-cpuset_mem_spread_node-offline-node.patch
  - patches.fixes/pci_aer_unconditionally_clear_uncor_status.patch
  - patches.fixes/readahead-unplug-dev.patch
  - patches.fixes/sched-fix-sched_mc-regression-caused-by-change-in-sched-cpu_power
* Mon Apr  5 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-73-alc-fix-invalid-connection:
  Refresh.  Backported the fix for the fix
* Mon Apr  5 2010 jjolly@suse.de
- patches.arch/s390-phys_device.patch: memory hotplug: allow
  setting of phys_device (bnc#592703,LTC#62065).
* Thu Apr  1 2010 jeffm@suse.de
- Enabled TN3270 for use during boot (bnc#592943).
* Thu Apr  1 2010 jeffm@suse.de
- patches.fixes/reiserfs-fix-oops-while-creating-privroot-with-selinux-enabled:
  reiserfs: fix oops while creating privroot with selinux enabled.
* Thu Apr  1 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-70-alc269vb-support: ALSA: hda -
  Add ALC269VB support (bnc#591870).
- patches.drivers/alsa-sp1-hda-71-alc269-missing-hp-pins:
  ALSA: hda - Add missing hp_pins definitions for ALC269 quirks
  (bnc#591870).
- patches.drivers/alsa-sp1-hda-72-alc260-fix-basic-model: ALSA:
  hda - Fix secondary ADC of ALC260 basic model (bnc#591870).
- patches.drivers/alsa-sp1-hda-73-alc-fix-invalid-connection:
  ALSA: hda - Don't set invalid connection index in Realtek
  initialiaiton (bnc#591870).
- patches.drivers/alsa-sp1-hda-74-alc-fix-invalid-mute: ALSA: hda
  - Fix invalid bit values passed to snd_hda_codec_amp_stereo()
  (bnc#591870).
- patches.drivers/alsa-sp1-hda-75-alc269-fillup-adcs: ALSA:
  hda - Fix ADC/MUX assignment of ALC269 codec (bnc#591870).
- patches.drivers/alsa-sp1-hda-76-alc269-mute-led: ALSA: hda -
  Add mute LED support for HP laptop with ALC269 (bnc#591870).
* Thu Apr  1 2010 hare@suse.de
- patches.fixes/cciss-unmap-xfer-buffer-correctly: cciss causes
  kernel WARNING with intel_iommu=on (bnc#590856).
* Thu Apr  1 2010 hare@suse.de
- patches.drivers/mpt2sas-base-map-resources: mpt2sas: use
  correct pci_resource_flag (bnc#592472).
* Thu Apr  1 2010 bphilips@suse.de
- patches.drivers/r8169-offical-fix-for-CVE-2009-4537-overlength-frame.patch:
  r8169: offical fix for CVE-2009-4537 (overlength frame DMAs)
  (bnc#567376, CVE-2009-4537).
* Thu Apr  1 2010 bphilips@suse.de
- patches.fixes/module-drop-the-lock-while-waiting-for-module-to-complete-initialization.patch:
  module: drop the lock while waiting for module to complete
  initialization. (bnc#564638).
* Wed Mar 31 2010 trenn@suse.de
- patches.fixes/pci_fix_invalid_resource_length.patch: Refresh.
* Wed Mar 31 2010 trenn@suse.de
- patches.fixes/pci_fix_invalid_resource_length.patch: x86/PCI:
  truncate _CRS windows with _LEN > _MAX - _MIN + 1 (bnc#587427).
* Wed Mar 31 2010 mmarek@suse.de
- Import RC2 kabi files for ppc64.
* Wed Mar 31 2010 mmarek@suse.de
- Import RC2 kabi files for x86(_64), ia64 and s390x.
* Wed Mar 31 2010 jbeulich@novell.com
- Update Xen patches to c/s 1011.
* Wed Mar 31 2010 teheo@suse.de
- patches.drivers/libata-ata_piix-clear-spurious-IRQ:
  libata,ata_piix: detect and clear spurious IRQs (bnc#445872,
  bnc#589449).
* Mon Mar 29 2010 jjolly@suse.de
- patches.fixes/ipoib-tx-queue-lockup-fix.patch: ipoib: Fix
  lockup of the tx queue (bnc#587199).
* Mon Mar 29 2010 jjolly@suse.de
- patches.arch/s390-11-01-zfcp-ccw_remove_lock_dep.patch: zfcp:
  Remove lock dependency on CCW remove. (bnc#590926).
- patches.arch/s390-11-02-zfcp-unit_add_lock_dep.patch: zfcp:
  Remove lock dependency on unit add. (bnc#590926).
- patches.arch/s390-11-03-zfcp_unit_remove_lock_dep.patch: zfcp:
  Remove lock dependency on unit remove. (bnc#590926).
* Mon Mar 29 2010 jbeulich@novell.com
- patches.xen/xen-netfront-ethtool: netfront: ethtool -i does
  not return info about xennet driver (bnc#591179).
* Mon Mar 29 2010 trenn@suse.de
- patches.arch/ppc-unmap_vmallocs_on_hotremove.patch:
  powerpc/pseries: Flush lazy kernel mappings after unplug
  operations (bnc#590217).
* Sun Mar 28 2010 coly.li@suse.de
- patches.fixes/dlm-enable-debug.patch: Delete, CONFIG_DLM_DEBUG is
  enabled in kernel configuration, we don't need to explicitly
  enable it.
* Sat Mar 27 2010 astarikovskiy@suse.de
- patches.drivers/drm-i915-Avoid-NULL-deref-in-get_pages-unwind-after-error.patch:
  Fix NULL pointer dereference in i915_gem_object_save_bit_17_swizzle
  (bnc#591377).
* Fri Mar 26 2010 bphilips@suse.de
- patches.drivers/be2net-fix-mccq-create-for-big-endian-architectures.patch:
  be2net: fix mccq create for big endian architectures
  (bnc#591513).
* Fri Mar 26 2010 jkosina@suse.cz
- patches.xen/xen3-add-support-for-intel-cougar-point-chipset.patch:
  Fix build.
* Fri Mar 26 2010 hare@suse.de
- patches.fixes/sd-no-read-cap16-if-not-supported: sd: spurious
  error messages in READ_CAPACITY(16) (bnc#591473).
* Fri Mar 26 2010 hare@suse.de
- patches.fixes/scsi-allow-fc-lld-to-fast-fail-scsi-eh:
  scsi: Allow FC LLD to fast-fail scsi eh (bnc#591401).
- patches.fixes/zfcp-pass-return-code-from-fc_block_scsi_eh-to-scsi_eh:
  zfcp: Pass return code from fc_block_scsi_eh to scsi eh
  (bnc#591401).
* Fri Mar 26 2010 jkosina@suse.cz
- patches.drivers/add-support-for-intel-cougar-point-chipset.patch:
  include new LPC Controller Device IDs (bnc#565845).
* Fri Mar 26 2010 mmarek@suse.cz
- Disable kabi checking for now.
* Fri Mar 26 2010 hare@suse.de
- patches.drivers/bnx2i-update-to-2.1.1: bnx2i bugfixes from
  mainline (bnc#585492).
- patches.fixes/fixup-section-annotations: Fixup missing
  annotations.
* Fri Mar 26 2010 hare@suse.de
- patches.fixes/dm-mpath-abstract-dm_in_flight-function: dm:
  abstract dm_in_flight function (bnc#591318).
- patches.fixes/dm-mpath-requeue-stall: Refresh.
- patches.fixes/dm-mpath-simplify-rq-based-suspend: dm: simplify
  request based suspend (bnc#591318).
- patches.fixes/dm-mpath-trace-rq-based-remapping: dm: trace
  request based remapping (bnc#591318).
* Fri Mar 26 2010 knikanth@suse.de
- patches.fixes/dm-mpath-requeue-stall: dm mpath: fix stall when
  requeueing io (bnc#591318).
* Fri Mar 26 2010 rjw@suse.de
- Update config files.
- patches.arch/x86-32-clean-up-rwsem-inline-asm-statements.patch:
  x86-32: clean up rwsem inline asm statements (bnc#590859,
  FATE#306952).
- patches.arch/x86-64-rwsem-64-bit-xadd-rwsem-implementation.patch:
  x86-64, rwsem: 64-bit xadd rwsem implementation (bnc#590859,
  FATE#306952).
- patches.arch/x86-64-rwsem-Avoid-store-forwarding-hazard-in-__downgrade_write.patch:
  x86-64, rwsem: Avoid store forwarding hazard in
  __downgrade_write (bnc#590859, FATE#306952).
- patches.arch/x86-64-support-native-xadd-rwsem-implementation.patch:
  x86-64: support native xadd rwsem implementation (bnc#590859,
  FATE#306952).
- patches.arch/x86-Fix-breakage-of-UML-from-the-changes-in-the-rwsem-system.patch:
  x86: Fix breakage of UML from the changes in the rwsem system
  (bnc#590859, FATE#306952).
- patches.arch/x86-clean-up-rwsem-type-system.patch: x86: clean
  up rwsem type system (bnc#590859, FATE#306952).
- patches.xen/xen3-auto-arch-x86.diff: Refresh.
* Fri Mar 26 2010 bphilips@suse.de
- patches.drivers/igb-Add-support-for-82576-ET2-Quad-Port-Server-Adapt.patch:
  igb: Add support for 82576 ET2 Quad Port Server Adapter
  (bnc#591293).
* Thu Mar 25 2010 mfasheh@suse.com
- patches.fixes/ocfs2-always-try-for-maximum-bits-with-new-local-all.patch:
  ocfs2: Always try for maximum bits with new local alloc windows.
* Thu Mar 25 2010 bphilips@suse.de
- patches.drivers/igb-entropy-source.patch: Refresh for fuzz
* Thu Mar 25 2010 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Thu Mar 25 2010 bphilips@suse.de
- patches.drivers/igb-add-support-for-Intel-I350-Gigabit-Network-Conne.patch:
  igb: add support for Intel I350 Gigabit Network Connection
  (bnc#590980).
* Thu Mar 25 2010 jack@suse.de
- patches.fixes/novfs-fix-oops-in-scope-finding: novfs: fix an
  oops in novfs scope-finding code (bnc#588579).
* Thu Mar 25 2010 coly.li@suse.de
- patches.fixes/ocfs2-Change-bg_chain-check-for-ocfs2_validate_gd_parent.patch:
  ocfs2: Change bg_chain check for ocfs2_validate_gd_parent.(bnc#590401)
- back port upstream ocfs2 patches from 2.6.33
  - patches.fixes/Ocfs2-Move-ocfs2-ioctl-definitions-from-ocfs2_fs.h-t.patch:
    Ocfs2: Move ocfs2 ioctl definitions from ocfs2_fs.h to newly
    added ocfs2_ioctl.h.
  - patches.fixes/ocfs2-Add-a-name_len-field-to-ocfs2_xattr_info.patch:
    ocfs2: Add a name_len field to ocfs2_xattr_info..
  - patches.fixes/ocfs2-Add-current-comm-in-trace-output.patch:
    ocfs2: Add current->comm in trace output.
  - patches.fixes/ocfs2-Allocation-in-ocfs2_xa_prepare_entry-values-in.patch:
    ocfs2: Allocation in ocfs2_xa_prepare_entry(), values in
    ocfs2_xa_store_value().
  - patches.fixes/ocfs2-Attach-the-connection-to-the-lksb.patch:
    ocfs2: Attach the connection to the lksb.
  - patches.fixes/ocfs2-Clean-up-the-checks-for-CoW-and-direct-I-O.patch:
    ocfs2: Clean up the checks for CoW and direct I/O..
  - patches.fixes/ocfs2-Gell-into-ocfs2_xa_set.patch: ocfs2:
    Gell into ocfs2_xa_set().
  - patches.fixes/ocfs2-Handle-errors-while-setting-external-xattr-val.patch:
    ocfs2: Handle errors while setting external xattr values..
  - patches.fixes/ocfs2-Handle-value-tree-roots-in-ocfs2_xa_set_inline.patch:
    ocfs2: Handle value tree roots in ocfs2_xa_set_inline_value().
  - patches.fixes/ocfs2-Hang-the-locking-proto-on-the-cluster-conn-and.patch:
    ocfs2: Hang the locking proto on the cluster conn and use it
    in asts..
  - patches.fixes/ocfs2-Introduce-ocfs2_xa_loc.patch: ocfs2:
    Introduce ocfs2_xa_loc.
  - patches.fixes/ocfs2-Let-ocfs2_xa_prepare_entry-do-space-checks.patch:
    ocfs2: Let ocfs2_xa_prepare_entry() do space checks..
  - patches.fixes/ocfs2-Pass-lksbs-back-from-stackglue-ast-bast-functi.patch:
    ocfs2: Pass lksbs back from stackglue ast/bast functions..
  - patches.fixes/ocfs2-Pass-the-locking-protocol-into-ocfs2_cluster_c.patch:
    ocfs2: Pass the locking protocol into ocfs2_cluster_connect()..
  - patches.fixes/ocfs2-Prefix-the-member-fields-of-struct-ocfs2_xattr.patch:
    ocfs2: Prefix the member fields of struct ocfs2_xattr_info..
  - patches.fixes/ocfs2-Provide-ocfs2_xa_fill_value_buf-for-external-v.patch:
    ocfs2: Provide ocfs2_xa_fill_value_buf() for external value
    processing.
  - patches.fixes/ocfs2-Remove-the-ast-pointers-from-ocfs2_stack_plugi.patch:
    ocfs2: Remove the ast pointers from ocfs2_stack_plugins.
  - patches.fixes/ocfs2-Remove-xattrs-via-ocfs2_xa_loc.patch:
    ocfs2: Remove xattrs via ocfs2_xa_loc.
  - patches.fixes/ocfs2-Set-inline-xattr-entries-with-ocfs2_xa_set.patch:
    ocfs2: Set inline xattr entries with ocfs2_xa_set().
  - patches.fixes/ocfs2-Set-the-xattr-name-value-pair-in-one-place.patch:
    ocfs2: Set the xattr name+value pair in one place.
  - patches.fixes/ocfs2-Set-xattr-block-entries-with-ocfs2_xa_set.patch:
    ocfs2: Set xattr block entries with ocfs2_xa_set().
  - patches.fixes/ocfs2-Teach-ocfs2_xa_loc-how-to-do-its-own-journal-w.patch:
    ocfs2: Teach ocfs2_xa_loc how to do its own journal work.
  - patches.fixes/ocfs2-Use-a-separate-masklog-for-AST-and-BASTs.patch:
    ocfs2: Use a separate masklog for AST and BASTs.
  - patches.fixes/ocfs2-Wrap-calculation-of-name-value-pair-size.patch:
    ocfs2: Wrap calculation of name+value pair size..
  - patches.fixes/ocfs2-add-extent-block-stealing-for-ocfs2-v5.patch:
    ocfs2: add extent block stealing for ocfs2 v5.
  - patches.fixes/ocfs2-fix-warning-in-ocfs2_file_aio_write.patch:
    ocfs2: fix warning in ocfs2_file_aio_write().
  - patches.fixes/ocfs2-send-SIGXFSZ-if-new-filesize-exceeds-limit-v2.patch:
    ocfs2: send SIGXFSZ if new filesize exceeds limit -v2.
  - patches.fixes/ocfs2-userdlm-Add-tracing-in-userdlm.patch:
    ocfs2/userdlm: Add tracing in userdlm.
  - patches.fixes/ocfs2_dlmfs-Add-capabilities-parameter.patch:
    ocfs2_dlmfs: Add capabilities parameter..
  - patches.fixes/ocfs2_dlmfs-Don-t-honor-truncate.-The-size-of-a-dlmf.patch:
    ocfs2_dlmfs: Don't honor truncate.  The size of a dlmfs file
    is LVB_LEN.
  - patches.fixes/ocfs2_dlmfs-Enable-the-use-of-user-cluster-stacks.patch:
    ocfs2_dlmfs: Enable the use of user cluster stacks..
  - patches.fixes/ocfs2_dlmfs-Move-to-its-own-directory.patch:
    ocfs2_dlmfs: Move to its own directory.
  - patches.fixes/ocfs2_dlmfs-Use-poll-to-signify-BASTs.patch:
    ocfs2_dlmfs: Use poll() to signify BASTs..
  - patches.fixes/ocfs2_dlmfs-Use-the-stackglue.patch: ocfs2_dlmfs:
    Use the stackglue..
* Thu Mar 25 2010 jeffm@suse.de
- patches.fixes/powerpc-fix-handling-of-strnlen-with-zero-len:
  powerpc: fix handling of strnlen with zero len (bnc#582681).
* Thu Mar 25 2010 hare@suse.de
- patches.fixes/cciss-remove-scan-thread.patch: Delete
  incorrect hunk (bnc#578429)
* Thu Mar 25 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.04.11.1-k8-update: qla2xxx:
  minor updates and fixes from upstream (bnc#589906).
- patches.fixes/dmar-mark-dmar_ir_support-as-init: Wrong
  annotation for dmar_ir_support().
* Thu Mar 25 2010 hare@suse.de
- patches.drivers/ixgbe-filter-fip-frames-into-t: ixgbe: filter
  FIP frames into the FCoE offload queues (bnc#590995).
- patches.drivers/ixgbe-fix-for-real_num_tx_queu: ixgbe: fix
  for real_num_tx_queues update issue (bnc#590995).
- patches.drivers/ixgbe-priority-tag-fip-frames: ixgbe: Priority
  tag FIP frames (bnc#590995).
- patches.fixes/vlan-add-vlan_dev_select_queue: vlan: adds
  vlan_dev_select_queue (bnc#590995).
- patches.fixes/vlan-updates-real_num_tx_queues: vlan: updates
  vlan real_num_tx_queues (bnc#590995).
- patches.suse/fcoe-check-netif-operstate-ins: fcoe: check netif
  operstate instead of IFF_UP & link state (bnc#590996).
- patches.suse/fcoe-reset-fip-ctlr-link-state: fcoe: reset FIP
  ctlr link state on disable/enable (bnc#590996).
- patches.suse/libfcoe-don-t-fill-mac-desc-in: libfcoe: Don't
  fill MAC desc in FLOGI if FIP negotiated FPMA (bnc#590996).
* Thu Mar 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.10 and c/s 1007.
- patches.xen/xen-vscsi-module-alias: allow pv scsi hba driver
  to be loaded automatically.
- patches.xen/xen-vusb-module-alias: allow pv usb hcd driver to
  be loaded automatically (bnc#584213).
- patches.xen/xen3-x86-Reduce-per-cpu-warning-boot-up-messages.patch:
  x86: Reduce per cpu warning boot up messages (bnc#587669,
  FATE#306952).
- patches.xen/xen3-x86-pat-Update-page-flags-for-memtype-without-using-memtype_lock-V4.patch:
  x86 / PAT: Update the page flags for memtype atomically instead
  of using memtype_lock. -V4 (bnc#588008, FATE#306952).
* Wed Mar 24 2010 rjw@suse.de
- patches.arch/x86-pat-Update-page-flags-for-memtype-without-using-memtype_lock-V4.patch:
  x86 / PAT: Update the page flags for memtype atomically instead
  of using memtype_lock. -V4 (bnc#588008, FATE#306952).
- patches.arch/x86-pat-Update-page-flags-for-memtype-without-using-memtype_lock-V3.patch:
  Delete.
  Use the PG_* bit numbers correctly.
* Wed Mar 24 2010 agraf@suse.de
- patches.fixes/kvm-pause-filter-0003-KVM-SVM-Support-Pause-Filter-in-AMD-processors.patch:
  Fix warning.
* Wed Mar 24 2010 rw@suse.de
- patches.arch/ia64-page-migration-update:
  [ia64] Add locking to cpe_migrate. (bnc#569606).
* Wed Mar 24 2010 tiwai@suse.de
- patches.drivers/synaptics-hp-clickpad: Input: Add
  support of clickpad mode to synaptics mouse driver (v2)
  (bnc#547370,bnc#582529,bnc#589014).
- patches.drivers/synaptics-clickpad-area-param: Delete.
- patches.drivers/synaptics-clickpad-bottom-enable: Delete.
- patches.drivers/synaptics-clickpad-button-toggle: Delete.
* Wed Mar 24 2010 trenn@suse.de
- patches.fixes/infiniband_cxgb3_improve_dlpar_remove_on_active_rdma_traffic.patch:
  Improve safety of dlpar remove when rdma traffic is active
  (bnc#590727).
* Wed Mar 24 2010 trenn@suse.de
- patches.arch/ppc-mark_preferred_offline_state_before_removing_cpus.patch:
  Refresh.
* Wed Mar 24 2010 trenn@suse.de
- patches.arch/ppc-mark_preferred_offline_state_before_removing_cpus.patch:
  Mark preferred offline state as CPU_STATE_OFFLINE before
  removing cpus (bnc#590154).
* Tue Mar 23 2010 nfbrown@suse.de
- patches.fixes/mandatory-lock-test: 9p/ocfs2/gfs2: allow file
  unlock on 'mandatory locking' file (bnc#589280).
* Mon Mar 22 2010 mmarek@suse.cz
- kabi/severities: Ignore changes in arch/s390/kvm.
* Mon Mar 22 2010 mmarek@suse.cz
- rpm/find-provides: Fix a typo that broke -debuginfo provides.
* Mon Mar 22 2010 agraf@suse.de
  Fix S390 build with KVM RCU patches
- patches.fixes/kvm-rcu-0025-KVM-fix-s390-ia64-build-failures-introduced-by-mems.patch:
  KVM: fix s390/ia64 build failures introduced by memslot changes
  (bnc#589660).
* Mon Mar 22 2010 agraf@suse.de
  Add Git-commit and remove stray SOB lines
- patches.fixes/kvm-EPT-swap-0001-KVM-VMX-emulate-accessed-bit-for-EPT.patch:
  Refresh.
- patches.fixes/kvm-constant_tsc-0001-KVM-SVM-Adjust-tsc_offset-only-if-tsc_unstable.patch:
  Refresh.
- patches.fixes/kvm-disable-pvmmu-0001-KVM-x86-disable-paravirt-mmu-reporting.patch:
  Refresh.
- patches.fixes/kvm-null-deref-0001-KVM-x86-disallow-KVM_-SET-GET-_LAPIC-without-alloc.patch:
  Refresh.
- patches.fixes/kvm-null-deref-0002-KVM-only-clear-irq_source_id-if-irqchip-is-present.patch:
  Refresh.
- patches.fixes/kvm-pause-filter-0001-KVM-introduce-kvm_vcpu_on_spin.patch:
  Refresh.
- patches.fixes/kvm-pause-filter-0002-KVM-VMX-Add-support-for-Pause-Loop-Exiting.patch:
  Refresh.
- patches.fixes/kvm-pause-filter-0003-KVM-SVM-Support-Pause-Filter-in-AMD-processors.patch:
  Refresh.
- patches.fixes/kvm-rcu-0001-rcu-Add-synchronize_srcu_expedited.patch:
  Refresh.
- patches.fixes/kvm-rcu-0002-KVM-Call-pic_clear_isr-on-pic-reset-to-reuse-logi.patch:
  Refresh.
- patches.fixes/kvm-rcu-0003-KVM-Move-irq-sharing-information-to-irqchip-level.patch:
  Refresh.
- patches.fixes/kvm-rcu-0004-KVM-Change-irq-routing-table-to-use-gsi-indexed-arr.patch:
  Refresh.
- patches.fixes/kvm-rcu-0005-KVM-Maintain-back-mapping-from-irqchip-pin-to-gsi.patch:
  Refresh.
- patches.fixes/kvm-rcu-0006-KVM-Move-irq-routing-data-structure-to-rcu-locking.patch:
  Refresh.
- patches.fixes/kvm-rcu-0007-KVM-Move-irq-ack-notifier-list-to-arch-independent.patch:
  Refresh.
- patches.fixes/kvm-rcu-0008-KVM-Convert-irq-notifiers-lists-to-RCU-locking.patch:
  Refresh.
- patches.fixes/kvm-rcu-0009-KVM-Move-IO-APIC-to-its-own-lock.patch:
  Refresh.
- patches.fixes/kvm-rcu-0010-KVM-Drop-kvm-irq_lock-lock-from-irq-injection-path.patch:
  Refresh.
- patches.fixes/kvm-rcu-0011-KVM-modify-memslots-layout-in-struct-kvm.patch:
  Refresh.
- patches.fixes/kvm-rcu-0012-KVM-modify-alias-layout-in-x86s-struct-kvm_arch.patch:
  Refresh.
- patches.fixes/kvm-rcu-0013-KVM-split-kvm_arch_set_memory_region-into-prepare-a.patch:
  Refresh.
- patches.fixes/kvm-rcu-0014-KVM-introduce-gfn_to_pfn_memslot.patch:
  Refresh.
- patches.fixes/kvm-rcu-0015-KVM-use-gfn_to_pfn_memslot-in-kvm_iommu_map_pages.patch:
  Refresh.
- patches.fixes/kvm-rcu-0016-KVM-introduce-kvm-srcu-and-convert-kvm_set_memory_.patch:
  Refresh.
- patches.fixes/kvm-rcu-0017-KVM-use-SRCU-for-dirty-log.patch:
  Refresh.
- patches.fixes/kvm-rcu-0018-KVM-x86-switch-kvm_set_memory_alias-to-SRCU-update.patch:
  Refresh.
- patches.fixes/kvm-rcu-0019-KVM-convert-io_bus-to-SRCU.patch:
  Refresh.
- patches.fixes/kvm-rcu-0020-KVM-switch-vcpu-context-to-use-SRCU.patch:
  Refresh.
- patches.fixes/kvm-rcu-0021-KVM-convert-slots_lock-to-a-mutex.patch:
  Refresh.
- patches.fixes/kvm-rcu-0022-KVM-Bump-maximum-vcpu-count-to-64.patch:
  Refresh.
- patches.fixes/kvm-rcu-0023-KVM-avoid-taking-ioapic-mutex-for-non-ioapic-EOIs.patch:
  Refresh.
- patches.fixes/kvm-rcu-0024-KVM-fix-cleanup_srcu_struct-on-vm-destruction.patch:
  Refresh.
- patches.fixes/kvm-spurious-interrupt-0001-eventfd-allow-atomic-read-and-waitqueue-remove.patch:
  Refresh.
- patches.fixes/kvm-spurious-interrupt-0002-KVM-fix-spurious-interrupt-with-irqfd.patch:
  Refresh.
- patches.fixes/kvm-vcpu_events-0001-KVM-x86-Add-KVM_GET-SET_VCPU_EVENTS.patch:
  Refresh.
- patches.fixes/kvm-vcpu_events-0002-KVM-x86-Extend-KVM_SET_VCPU_EVENTS-with-selective.patch:
  Refresh.
- patches.fixes/kvm-vcpu_events-0003-KVM-x86-Adjust-KVM_VCPUEVENT-flag-names.patch:
  Refresh.
- patches.fixes/kvm-vcpu_events-0004-KVM-x86-Do-not-return-soft-events-in-vcpu_events.patch:
  Refresh.
- patches.fixes/kvm-vcpu_events-0005-KVM-x86-Save-restore-interrupt-shadow-mask.patch:
  Refresh.
* Mon Mar 22 2010 jbeulich@novell.com
- patches.fixes/tunnels-fix-netns-vs-proto-registration-ordering:
  Fix improper arguments passed to unregister_pernet_gen_device().
* Sun Mar 21 2010 jjolly@suse.de
- patches.arch/s390-10-01-zfcpdump-lpar-registers.patch:
  zcore: CPU registers may not be saved under LPAR
  (bnc#589679,LTC#61578).
- patches.arch/s390-10-02-cio_fix_drvdata_usage_for_the_console_subchannel.patch:
  cio: fix drvdata usage for the console subchannel (bnc#589679).
- patches.arch/s390-10-03-dasd-fix-erp-tcw-alignment.patch:
  dasd: fix alignment of transport mode recovery TCW (bnc#589679).
* Fri Mar 19 2010 mmarek@suse.cz
- kabi/severities: Ignore changes in arch/x86/kvm.
* Fri Mar 19 2010 agraf@suse.de
- patches.fixes/kvm-EPT-swap-0001-KVM-VMX-emulate-accessed-bit-for-EPT.patch:
  KVM: VMX: emulate accessed bit for EPT (bnc#589651).
- patches.fixes/kvm-constant_tsc-0001-KVM-SVM-Adjust-tsc_offset-only-if-tsc_unstable.patch:
  KVM: SVM: Adjust tsc_offset only if tsc_unstable (bnc#589657).
- patches.fixes/kvm-disable-pvmmu-0001-KVM-x86-disable-paravirt-mmu-reporting.patch:
  KVM: x86: disable paravirt mmu reporting (bnc#589656).
- patches.fixes/kvm-null-deref-0001-KVM-x86-disallow-KVM_-SET-GET-_LAPIC-without-alloc.patch:
  KVM: x86: disallow KVM_{SET,GET}_LAPIC without allocated
  in-kernel lapic (bnc#589654).
- patches.fixes/kvm-null-deref-0002-KVM-only-clear-irq_source_id-if-irqchip-is-present.patch:
  KVM: only clear irq_source_id if irqchip is present
  (bnc#589654).
- patches.fixes/kvm-pause-filter-0001-KVM-introduce-kvm_vcpu_on_spin.patch:
  KVM: introduce kvm_vcpu_on_spin (bnc#589655).
- patches.fixes/kvm-pause-filter-0002-KVM-VMX-Add-support-for-Pause-Loop-Exiting.patch:
  KVM: VMX: Add support for Pause-Loop Exiting (bnc#589655).
- patches.fixes/kvm-pause-filter-0003-KVM-SVM-Support-Pause-Filter-in-AMD-processors.patch:
  KVM: SVM: Support Pause Filter in AMD processors (bnc#589655).
- patches.fixes/kvm-rcu-0001-rcu-Add-synchronize_srcu_expedited.patch:
  rcu: Add synchronize_srcu_expedited() (bnc#589660).
- patches.fixes/kvm-rcu-0002-KVM-Call-pic_clear_isr-on-pic-reset-to-reuse-logi.patch:
  KVM: Call pic_clear_isr() on pic reset to reuse logic there
  (bnc#589660).
- patches.fixes/kvm-rcu-0003-KVM-Move-irq-sharing-information-to-irqchip-level.patch:
  KVM: Move irq sharing information to irqchip level (bnc#589660).
- patches.fixes/kvm-rcu-0004-KVM-Change-irq-routing-table-to-use-gsi-indexed-arr.patch:
  KVM: Change irq routing table to use gsi indexed array
  (bnc#589660).
- patches.fixes/kvm-rcu-0005-KVM-Maintain-back-mapping-from-irqchip-pin-to-gsi.patch:
  KVM: Maintain back mapping from irqchip/pin to gsi (bnc#589660).
- patches.fixes/kvm-rcu-0006-KVM-Move-irq-routing-data-structure-to-rcu-locking.patch:
  KVM: Move irq routing data structure to rcu locking
  (bnc#589660).
- patches.fixes/kvm-rcu-0007-KVM-Move-irq-ack-notifier-list-to-arch-independent.patch:
  KVM: Move irq ack notifier list to arch independent code
  (bnc#589660).
- patches.fixes/kvm-rcu-0008-KVM-Convert-irq-notifiers-lists-to-RCU-locking.patch:
  KVM: Convert irq notifiers lists to RCU locking (bnc#589660).
- patches.fixes/kvm-rcu-0009-KVM-Move-IO-APIC-to-its-own-lock.patch:
  KVM: Move IO APIC to its own lock (bnc#589660).
- patches.fixes/kvm-rcu-0010-KVM-Drop-kvm-irq_lock-lock-from-irq-injection-path.patch:
  KVM: Drop kvm->irq_lock lock from irq injection path
  (bnc#589660).
- patches.fixes/kvm-rcu-0011-KVM-modify-memslots-layout-in-struct-kvm.patch:
  KVM: modify memslots layout in struct kvm (bnc#589660).
- patches.fixes/kvm-rcu-0012-KVM-modify-alias-layout-in-x86s-struct-kvm_arch.patch:
  KVM: modify alias layout in x86s struct kvm_arch (bnc#589660).
- patches.fixes/kvm-rcu-0013-KVM-split-kvm_arch_set_memory_region-into-prepare-a.patch:
  KVM: split kvm_arch_set_memory_region into prepare and commit
  (bnc#589660).
- patches.fixes/kvm-rcu-0014-KVM-introduce-gfn_to_pfn_memslot.patch:
  KVM: introduce gfn_to_pfn_memslot (bnc#589660).
- patches.fixes/kvm-rcu-0015-KVM-use-gfn_to_pfn_memslot-in-kvm_iommu_map_pages.patch:
  KVM: use gfn_to_pfn_memslot in kvm_iommu_map_pages (bnc#589660).
- patches.fixes/kvm-rcu-0016-KVM-introduce-kvm-srcu-and-convert-kvm_set_memory_.patch:
  KVM: introduce kvm->srcu and convert kvm_set_memory_region to
  SRCU update (bnc#589660).
- patches.fixes/kvm-rcu-0017-KVM-use-SRCU-for-dirty-log.patch:
  KVM: use SRCU for dirty log (bnc#589660).
- patches.fixes/kvm-rcu-0018-KVM-x86-switch-kvm_set_memory_alias-to-SRCU-update.patch:
  KVM: x86: switch kvm_set_memory_alias to SRCU update
  (bnc#589660).
- patches.fixes/kvm-rcu-0019-KVM-convert-io_bus-to-SRCU.patch:
  KVM: convert io_bus to SRCU (bnc#589660).
- patches.fixes/kvm-rcu-0020-KVM-switch-vcpu-context-to-use-SRCU.patch:
  KVM: switch vcpu context to use SRCU (bnc#589660).
- patches.fixes/kvm-rcu-0021-KVM-convert-slots_lock-to-a-mutex.patch:
  KVM: convert slots_lock to a mutex (bnc#589660).
- patches.fixes/kvm-rcu-0022-KVM-Bump-maximum-vcpu-count-to-64.patch:
  KVM: Bump maximum vcpu count to 64 (bnc#589660).
- patches.fixes/kvm-rcu-0023-KVM-avoid-taking-ioapic-mutex-for-non-ioapic-EOIs.patch:
  KVM: avoid taking ioapic mutex for non-ioapic EOIs (bnc#589660).
- patches.fixes/kvm-rcu-0024-KVM-fix-cleanup_srcu_struct-on-vm-destruction.patch:
  KVM: fix cleanup_srcu_struct on vm destruction (bnc#589660).
- patches.fixes/kvm-spurious-interrupt-0001-eventfd-allow-atomic-read-and-waitqueue-remove.patch:
  eventfd - allow atomic read and waitqueue remove (bnc#589652).
- patches.fixes/kvm-spurious-interrupt-0002-KVM-fix-spurious-interrupt-with-irqfd.patch:
  KVM: fix spurious interrupt with irqfd (bnc#589652).
- patches.fixes/kvm-vcpu_events-0001-KVM-x86-Add-KVM_GET-SET_VCPU_EVENTS.patch:
  KVM: x86: Add KVM_GET/SET_VCPU_EVENTS (bnc#585490).
- patches.fixes/kvm-vcpu_events-0002-KVM-x86-Extend-KVM_SET_VCPU_EVENTS-with-selective.patch:
  KVM: x86: Extend KVM_SET_VCPU_EVENTS with selective updates
  (bnc#585490).
- patches.fixes/kvm-vcpu_events-0003-KVM-x86-Adjust-KVM_VCPUEVENT-flag-names.patch:
  KVM: x86: Adjust KVM_VCPUEVENT flag names (bnc#585490).
- patches.fixes/kvm-vcpu_events-0004-KVM-x86-Do-not-return-soft-events-in-vcpu_events.patch:
  KVM: x86: Do not return soft events in vcpu_events (bnc#585490).
- patches.fixes/kvm-vcpu_events-0005-KVM-x86-Save-restore-interrupt-shadow-mask.patch:
  KVM: x86: Save&restore interrupt shadow mask (bnc#585490).
* Fri Mar 19 2010 trenn@suse.de
- patches.drivers/cpufreq_processor_clocking_control_pcc_driver_cast_fix.patch:
  Fix cast warning in pcc driver. (trivial cast fix, no bug).
* Thu Mar 18 2010 rjw@suse.de
- patches.fixes/cciss-remove-scan-thread.patch: cciss: remove
  scan thread (bnc#578429).
* Thu Mar 18 2010 trenn@suse.de
- patches.fixes/pci_aer_unconditionally_clear_uncor_status.patch:
  PCI: unconditionally clear AER uncorr status register during
  cleanup (bnc#587681).
* Thu Mar 18 2010 jjolly@suse.de
- patches.arch/s390-dasd-emc-ckd-psf-and-security.patch:
  [S390] dasd: security and PSF update patch for EMC CKD ioctl
  (bnc#585608).
* Thu Mar 18 2010 rjw@suse.de
- patches.arch/x86-pat-Update-page-flags-for-memtype-without-using-memtype_lock-V3.patch:
  x86 / PAT: Update the page flags for memtype atomically instead
  of using memtype_lock. -V3 (bnc#588008, FATE#306952).
* Wed Mar 17 2010 jbohac@suse.cz
- patches.suse/allow_bonding_with_blacklisted_ipv6.patch:
  fixed build for archs/flavours without bonding
* Wed Mar 17 2010 jbohac@suse.cz
- patches.suse/allow_bonding_with_blacklisted_ipv6.patch: allow
  bonding with blacklisted ipv6 (bnc#585463).
* Wed Mar 17 2010 mmarek@suse.cz
- Update config files: set DVB_LGS8GL5=m to not break the kabi.
* Wed Mar 17 2010 hare@suse.de
- Disable CONFIG_USB_OHCI_HCD_SSB (bnc#588994)
* Wed Mar 17 2010 mmarek@suse.de
- Import RC1 kabi files.
* Tue Mar 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Move Obsoletes: msi-wmi-kmp to the
  sle11-ga group and make the comment more explanatory.
* Tue Mar 16 2010 trenn@suse.de
- rpm/kernel-binary.spec.in:
  bnc#587578
* Mon Mar 15 2010 mfasheh@suse.com
- patches.fixes/ocfs2-set-i_mode-on-disk-during-acl-operations.patch:
  ocfs2: set i_mode on disk during acl operations (bnc#575752).
* Mon Mar 15 2010 jjolly@suse.de
- patches.fixes/01-rnfs_read_complete_calc_rq_respages.patch:
  : Correct rqstp->rq_respages calculation (bnc#577355,LTC#60382).
- patches.fixes/rnfs_read_complete_calc_rq_respages.patch: Delete.
* Mon Mar 15 2010 gregkh@suse.de
- Update config files.
  - dvb Kconfig change due to 2.6.32.10
  - looks like CONFIG_DM_RAID got turned of, .10 did not do that, wierd
  - enabled Oprofile for ia64 vanilla.
* Mon Mar 15 2010 gregkh@suse.de
- Update to 2.6.32.10:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/x86-Avoid-race-condition-in-pci_enable_msix.patch
  - patches.drivers/alsa-sp1-hda-18-msi-wind-u115-fix
  - patches.drivers/drm-i915-fix-get_core_clock_speed-for-g33-class-desktop-chips.patch
  - patches.drivers/qla1280-request-firmware-lock
  - patches.drivers/staging-hv-add-a-pci-device-table.patch
  - patches.drivers/staging-hv-match-on-dmi-values-to-know-if-we-should-run.patch
  - patches.fixes/PM-Hibernate-fix-preallocating-of-memory.patch
  - patches.fixes/acpi_be_in_TS_POLLING_state_during_mwait.patch
  - patches.fixes/dvb-core-fix-dos-bug-in-ule-decapsulation-code-that-can-be-triggered-by-an-invalid
  - patches.fixes/dvb-l64781.ko-broken-with-gcc-4.5.patch
  - patches.fixes/fix-lookup_follow-on-automount-symlinks
  - patches.fixes/net-bug-fix-for-vlan-gro-issue.patch
  - patches.fixes/pci-hotplug-ibmphp-ebda-len.patch
  - patches.fixes/sched-fix-sched_mc_power_savings-for-non-SMT
  - patches.fixes/sched-fix-smt-scheduler-regression-in-find_busiest_queue
  - patches.fixes/x86_irq_setup_extra_ioapic_for_sci.patch
  - patches.trace/oprofile-no-tracing.diff
* Mon Mar 15 2010 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.32: Xen pv driver fix for
  CONFIG_CPUMASK_OFFSTACK.
* Mon Mar 15 2010 hare@suse.de
- patches.drivers/mpt2sas-03.100.03.00-update: Remove duplicate
  defines (bnc#587782).
* Sat Mar 13 2010 rjw@suse.de
- patches.arch/x86-UV-BAU-performance-and-error-recovery.patch:
  x86 / UV: BAU performance and error recovery (bnc#586806,
  FATE#306952).
* Sat Mar 13 2010 rjw@suse.de
- patches.arch/x86-Reduce-per-cpu-MCA-boot-up-messages.patch: x86:
  Reduce per cpu MCA boot up messages (bnc#587669, FATE#306952).
- patches.arch/x86-Reduce-per-cpu-warning-boot-up-messages.patch:
  x86: Reduce per cpu warning boot up messages (bnc#587669,
  FATE#306952).
* Sat Mar 13 2010 rjw@suse.de
- patches.arch/x86-UV-Fix-target_cpus-in-x2apic_uv_x.c.patch:
  x86 / UV: Fix target_cpus() in x2apic_uv_x.c (bnc#587673,
  FATE#306952).
* Fri Mar 12 2010 bphilips@suse.de
- patches.drivers/benet-fixes-required-for-be2net-to-work-on-bladeengine3-device.patch:
  Delete.
* Fri Mar 12 2010 hare@suse.de
- patches.drivers/qla4xxx-5.01.00.00.11.01-k12_5.01.00.00.11.01-k13.patch:
  Additional bug fixes required for the qla4xxx driver
  (bnc#585296).
* Fri Mar 12 2010 npiggin@suse.de
- patches.suse/mm-uninline-add-to-page-cache.patch: uninline
  add_to_page_cache (FATE309111).
- patches.suse/pagecache-limit.patch: Refresh.
* Fri Mar 12 2010 npiggin@suse.de
- patches.suse/pagecache-limit.patch: Introduce (optional)
  pagecache limit (FATE309111).
* Fri Mar 12 2010 trenn@suse.de
- patches.fixes/pci_use_list_for_resources_5_5.patch: Refresh.
  Don't add resources of pci busses if pci=nocrs
* Fri Mar 12 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-69-alc262-single-adc-fix: ALSA:
  hda - Fix capture on Sony VAIO with single input (bnc#577358).
* Fri Mar 12 2010 trenn@suse.de
- patches.fixes/pci_use_list_for_resources_5_5.patch: Refresh.
  bnc#587427
  - > Fix pci_use_crs logic which is inverted compared to mainline
* Fri Mar 12 2010 hare@suse.de
- patches.drivers/ixgbe-don-t-exceed-user-buffer: ixgbe: Don't
  allow user buffer count to exceed 256 (bnc#587739).
- patches.suse/libfc-fix-fcp-pkt-recovery: libfc: fix fcp pkt
  recovery in fc_fcp_recv_data (bnc#587739).
- patches.suse/libfc-fix-unnecessary-seq-id-jump: libfc: fixes
  unnecessary seq id jump (bnc#587739).
- patches.suse/libfc-use-offload-em-instance-again: libfc:
  use offload EM instance again instead jumping to next EM
  (bnc#587739).
* Fri Mar 12 2010 hare@suse.de
- patches.drivers/mpt2sas-04.100.01.02-update: Additional mpt2sas
  patch for sle11sp1 (bnc#587782).
* Fri Mar 12 2010 hare@suse.de
- patches.drivers/lpfc-8.3.5.7-update: Update Emulex lpfc driver
  to 8.3.5.7 (bnc#587692).
* Fri Mar 12 2010 jjolly@suse.de
- patches.drivers/iw_cxgb3-dlpar.patch: RDMA/cxgb3:
  Mark rdma device with CXIO_ERROR_FATAL when
  removing. (bnc#584958,LTC#61264).
* Fri Mar 12 2010 jjolly@suse.de
- patches.fixes/rnfs_read_complete_calc_rq_respages.patch: rnfs:
  Fix respages calculation (bnc#577355,LTC#60382).
* Fri Mar 12 2010 npiggin@suse.de
- Re-enable mmu notifier sleeping patches.
* Fri Mar 12 2010 rjw@suse.de
- patches.fixes/pci-update-pci_set_vga_state-to-call-arch-functions.patch:
  pci: Update pci_set_vga_state() to call arch functions
  (bnc#586343, FATE#306952).
- patches.fixes/vgaarb-fix-vga-arbiter-to-accept-pci-domains-other-than-0.patch:
  vgaarb: Fix VGA arbiter to accept PCI domains other than 0
  (bnc#586343, FATE#306952).
- patches.fixes/x86_64-uv-update-uv-arch-to-target-legacy-vga-i-o-correctly.patch:
  x86, uv: Update UV arch to target Legacy VGA I/O
  correctly. (bnc#586343, FATE#306952).
* Fri Mar 12 2010 rjw@suse.de
- patches.arch/x86-uv-Update-UV-mmr-definitions-header-file.patch:
  x86 / UV: Update UV mmr definitions header file (bnc#587562,
  FATE#306952).
* Thu Mar 11 2010 jeffm@suse.de
- patches.fixes/gre-fix-netns-vs-proto-registration-ordering:
  gre: fix netns vs proto registration ordering (bnc#580799).
- patches.fixes/tunnels-fix-netns-vs-proto-registration-ordering:
  tunnels: fix netns vs proto registration ordering (bnc#580799).
* Thu Mar 11 2010 jkosina@suse.cz
- series.conf: add forgotten patch:
  patches.fixes/scsi-fixup-vpd-page-allocation
* Thu Mar 11 2010 hare@suse.de
- patches.fixes/fc-transport-make-sure-cmds-are-completed-for-offlined-rport:
  Make sure commands are completed for offline rport (bnc#587114).
* Thu Mar 11 2010 hare@suse.de
- patches.fixes/scsi-fixup-vpd-page-allocation: eliminate
  potential kmalloc failure in scsi_get_vpd_page().
* Thu Mar 11 2010 npiggin@suse.de
- patches.fixes/mm-pagealloc-fix-congestion-wait.patch: Reduce
  page allocation stalls (bnc#561811).
* Thu Mar 11 2010 mmarek@suse.cz
- rpm/kernel-module-subpackage: Provide/Obsolete *-kmp-vmi by
  * -kmp-pae.
* Thu Mar 11 2010 jack@suse.de
- patches.fixes/readahead-unplug-dev.patch: readahead: add
  blk_run_backing_dev (bnc#587125).
* Thu Mar 11 2010 npiggin@suse.de
- Disable sleeping mmu notifier patches (bnc#578046). To be dropped
  completely if the problem is not resolved before RC1.
* Thu Mar 11 2010 hare@suse.de
- patches.drivers/s2io-fixing-dbg_print-macro.patch: Fixup
  for series2git.
- patches.drivers/scsi-transport-sas-enable-tlr:
  scsi_transport_sas: add support for transport layer retries
  (TLR) (bnc#584508).
- patches.fixes/fc_sdev_blocked.patch: Fixup for series2git.
* Thu Mar 11 2010 jslaby@suse.de
- patches.fixes/sched-fix-cputime-monotonicity.patch: sched,
  cputime: Introduce thread_group_times() (bnc#585241).
* Thu Mar 11 2010 jbeulich@novell.com
- patches.xen/xen-usbfront-schedule: Fix a scheduling race in
  usbfront (bnc#584218).
- patches.xen/xen-vbd-resize: Propagate changed size of VBDs
  (bnc#583677).
- patches.xen/xen-fix-check_tsc_unstable-undefined: Rename to ...
- patches.xen/xen3-x86-Fix-sched_clock_cpu-for-systems-with-unsynchronized-TSC.patch:
  ... this.
  (bnc#582878, FATE#306952).
- Refresh other Xen patches.
- supported.conf: Mark pvSCSI and pvUSB modules supported.
* Thu Mar 11 2010 mmarek@suse.cz
- patches.fixes/kbuild-Really-don-t-clean-bounds.h-and-asm-offsets.h:
  kbuild: Really don't clean bounds.h and asm-offsets.h
  (bnc#585743).
* Thu Mar 11 2010 hare@suse.de
- patches.drivers/mpt2sas-04.100.01.00-update: Update mpt2sas
  to version 4.100.01.00 (bnc#584508).
* Thu Mar 11 2010 knikanth@suse.de
- patches.fixes/xfs-nonblocking-inode-locking-io-completion.patch:
  Fix unintialized variable. Refresh.
* Thu Mar 11 2010 npiggin@suse.de
- patches.fixes/cpuset-fix-cpuset_mem_spread_node-offline-node.patch:
  cpuset: fix cpuset mem spreading returning offline node
  (bnc#575923).
- patches.fixes/cpuset-slab-memspread-fix.patch: Delete.
  Replace fix with upstream version.
* Thu Mar 11 2010 npiggin@suse.de
- patches.xen/xen3-x86-ftrace-fix-rodata-1.patch: XEN x86, cpa:
  Fix kernel text RO checks in static_protection (bnc#581940).
- patches.xen/xen3-x86-ftrace-fix-rodata-3.patch: XEN x86_64, cpa:
  Use only text section in set_kernel_text_rw/ro (bnc#581940).
* Thu Mar 11 2010 teheo@suse.de
- patches.suse/stop_machine-implement-lazy: stop_machine:
  implement stop_machine.lazy kernel parameter (bnc#586417).
* Thu Mar 11 2010 nfbrown@suse.de
- patches.fixes/nfs-bdi-leak.fix: NFS: ensure bdi_unregister is
  called on mount failure. (bnc#587073).
* Wed Mar 10 2010 jeffm@suse.de
- patches.suse/kdb-x86-backtrace-code-to-use-the-in-kernel-show_stack-function:
  KDB: x86 backtrace code to use the in-kernel show_stack()
  function (bnc#581057).
* Wed Mar 10 2010 bphilips@suse.de
- patches.drivers/be2net-update-version-2.101.346u-to-2.102.147s.patch:
  be2net: update version 2.101.346u to 2.102.147s (bnc#585124).
- patches.drivers/be2net-swap-only-first-2-fields-of-mcc_wrb.patch:
  renable, dropped accidently
* Wed Mar 10 2010 jdelvare@suse.de
- supported.conf: Add hwmon/ams back.
* Wed Mar 10 2010 npiggin@suse.de
- patches.arch/x86-ftrace-fix-rodata-1.patch: x86, cpa: Fix
  kernel text RO checks in static_protection (bnc#581940).
- patches.arch/x86-ftrace-fix-rodata-2.patch: x86_64, ftrace: Make
  ftrace use kernel identity mapping to modify code (bnc#581940).
- patches.arch/x86-ftrace-fix-rodata-3.patch: x86_64, cpa:
  Use only text section in set_kernel_text_rw/ro (bnc#581940).
* Wed Mar 10 2010 jeffm@suse.de
- patches.suse/kdb-fix-the-multi-word-nop-instructions-in-the-disassembler:
  kdb: fix the multi-word NOP instructions in the disassembler
  (bnc#584691).
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix symsets for non-split kernels.
* Wed Mar 10 2010 mmarek@suse.cz
- patches.suse/kbuild-record-built-in-o: kbuild: Record which
  objects make up a built-in.o file.
- rpm/built-in-where: Make use of the info to further split builtin
  symsets.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add symsets.pl to the src.rpm.
* Wed Mar 10 2010 jslaby@suse.de
- patches.suse/rlim-0005-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  posix-cpu-timers: cleanup rlimits usage (FATE#305733).
- patches.suse/rlim-0008-SPARC-use-helpers-for-rlimits.patch:
  Refresh.
- patches.suse/rlim-0009-X86-use-helpers-for-rlimits.patch: x86:
  Use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0010-FS-use-helpers-for-rlimits.patch: fs:
  use rlimit helpers (FATE#305733).
- patches.suse/rlim-0011-MM-use-helpers-for-rlimits.patch: mm:
  use rlimit helpers (FATE#305733).
- patches.suse/rlim-0012-core-use-helpers-for-rlimits.patch:
  kernel core: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0013-infiniband-use-helpers-for-rlimits.patch:
  RDMA: Use rlimit helpers (FATE#305733).
  Refreshed changelogs and Patch-mainline tags -- they are upstream.
* Wed Mar 10 2010 knikanth@suse.de
- patches.fixes/fc_sdev_blocked.patch: mid-layer unblocks blocked
  sdev leaving queue stopped (bnc#583356).
* Wed Mar 10 2010 bphilips@suse.de
- patches.drivers/ixgbe-Fix-DMA-mapping-unmapping-issues-when-HWRSC-is.patch:
  ixgbe: Fix DMA mapping/unmapping issues when HWRSC is enabled
  on IOMMU enabled kernels (bnc#584475).
* Wed Mar 10 2010 bphilips@suse.de
- patches.drivers/be2net-a-mini-optimization-in-rx_compl_process-co.patch:
  be2net: a mini optimization in rx_compl_process() code
  (bnc#585124).
- patches.drivers/be2net-don-t-rearm-mcc-cq-when-device-is-not-open.patch:
  be2net: don't rearm mcc cq when device is not open (bnc#585124).
- patches.drivers/be2net-download-NCSI-section-during-firmware-update.patch:
  be2net: download NCSI section during firmware update
  (bnc#585124).
- patches.drivers/be2net-fix-rx-path-to-ignore-a-flush-completion.patch:
  be2net: fix rx-path to ignore a flush completion (bnc#585124).
- patches.drivers/be2net-fix-tx-completion-polling.patch: be2net:
  fix tx completion polling (bnc#585124).
- patches.drivers/be2net-implement-EEH-pci-error-recovery-handlers.patch:
  be2net: implement EEH pci error recovery handlers (bnc#585124).
- patches.drivers/be2net-use-eq-id-to-calculate-cev-isr-reg-offset.patch:
  be2net: use eq-id to calculate cev-isr reg offset (bnc#585124).
* Wed Mar 10 2010 bphilips@suse.de
- patches.drivers/be2net-change-the-driver-description.patch:
  be2net: change the driver description (bnc#580793).
- patches.drivers/be2net-fix-to-limit-max-vlans-supported-in-certain-s.patch:
  be2net: fix to limit max vlans supported in certain skews
  (bnc#580793).
- patches.drivers/be2net-minor-code-optimizations.patch: be2net:
  minor code optimizations (bnc#580793).
- patches.drivers/be2net-remove-ASIC-generation-number-from-Kconfig.patch:
  be2net: remove ASIC generation number from Kconfig (bnc#580793).
- patches.drivers/be2net-set-proper-value-to-version-field-in-req-hdr.patch:
  be2net: set proper value to version field in req hdr
  (bnc#580793).
- patches.drivers/benet-fixes-required-for-be2net-to-work-on-bladeengine3-device.patch:
  benet: Fixes required for be2net to work on BladeEngine3 device
  (bnc#580793).
* Tue Mar  9 2010 rjw@suse.de
- patches.arch/x86-speed-up-microcode.ctl-on-SGI-UV.patch: x86:
  Speed up microcode.ctl on SGI UV (bnc#586364, FATE#306952).
* Tue Mar  9 2010 gregkh@suse.de
- patches.suse/trace-open.patch: io tracing.
  Needed for Moblin and for some SLED preloads.
* Tue Mar  9 2010 bphilips@suse.de
- patches.drivers/s2io-fixing-dbg_print-macro.patch: s2io:
  fixing DBG_PRINT() macro (bnc#585711).
* Tue Mar  9 2010 mmarek@suse.cz
- patches.xen/xen-fix-check_tsc_unstable-undefined: Fix xen
  build with patches.arch/x86-Fix-sched_clock_cpu_....
* Tue Mar  9 2010 mmarek@suse.cz
- patches.fixes/Have-mmu_notifiers-use-SRCU-so-they-may-safely-schedule-build-fix.patch:
  Really fix ia64 build.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/old-packages.conf: Obsolete kernel-vmi by kernel-default.
- rpm/kernel-module-subpackage: Also obsolete vmi KMPs.
* Tue Mar  9 2010 jkosina@suse.cz
- Update config files: set CONFIG_LSM_MMAP_MIN_ADDR=0 to be
  compatible with GA (LSM_ value is the minimal number settable
  by sysctl, the default stays the same - 65536).
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Package symsets in the -devel package.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/symsets.pl: Split symsets by module names instead of
  directory names.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/find-provides: Do not generate ksym(...) provides.
* Tue Mar  9 2010 jkosina@suse.cz
- patches.drivers/add-support-for-intel-cougar-point-chipset.patch:
  Enable snoop on CPT Audio (bnc#565845).
* Tue Mar  9 2010 rjw@suse.de
- patches.arch/x86-Fix-sched_clock_cpu-for-systems-with-unsynchronized-TSC.patch:
  x86: Fix sched_clock_cpu for systems with unsynchronized TSC
  (bnc#582878, FATE#306952).
* Tue Mar  9 2010 rjw@suse.de
- patches.fixes/Have-mmu_notifiers-use-SRCU-so-they-may-safely-schedule-build-fix.patch:
  mm: Fix compilation of mmu_notifier.c on IA-64 (bnc#578046,
  FATE#306952).
* Tue Mar  9 2010 hare@suse.de
- patches.drivers/megaraid-sas-04.27-update: Update megaraid
  sas to version 4.27 (bnc#577856).
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/find-provides, rpm/symsets.pl: Generate symsets again
  (bnc#582907).
* Tue Mar  9 2010 knikanth@suse.de
- patches.suse/dm-raid45-26-Nov-2009.patch: DMRAID45 module.
- patches.fixes/dm-raid45-fix-region-hash-double-free: Delete.
- patches.fixes/dm-raid45_exit_destroy_cache: Delete.
- patches.suse/dm-raid45_2.6.27_20081027.patch: Delete.
* Tue Mar  9 2010 hare@suse.de
- patches.fixes/fc-transport-dev_loss_tmo-overflow: Protect
  against overflow in dev_loss_tmo (bnc#584197).
* Tue Mar  9 2010 bphilips@suse.de
- patches.drivers/bnx2x-to-version-1.52.1-7.patch: bnx2x to
  version 1.52.1-7 a3aa18 to c16cc0 (bnc#584453).
* Tue Mar  9 2010 rjw@suse.de
- patches.arch/i386-do-a-global-tlb-flush-in-S4-resume.patch:
  i386: Do a global TLB flush in S4 resume.
* Tue Mar  9 2010 rjw@suse.de
- patches.fixes/Fix-unmap_vma-bug-related-to-mmu_notifiers.patch:
  Fix unmap_vma bug related to mmu_notifiers (bnc#578046,
  FATE#306952).
- patches.fixes/Have-mmu_notifiers-use-SRCU-so-they-may-safely-schedule.patch:
  Have mmu_notifiers use SRCU so they may safely schedule
  (bnc#578046, FATE#306952).
* Mon Mar  8 2010 mfasheh@suse.com
- patches.suse/gfs2-ro-fixes.patch: gfs2: fix spectator mounts
  (FATE#307584 bnc#580105).
* Mon Mar  8 2010 jjolly@suse.de
- patches.arch/s390-09-01-vdso-version.patch: vdso: glibc does
  not use vdso functions (bnc#583296).
- patches.arch/s390-09-02-dasd-fix_refcount.patch: dasd: Fix
  refcounting. (bnc#583296).
- patches.arch/s390-09-03-dasd-correct_offline_processing.patch:
  dasd: Correct offline processing. (bnc#583296).
- patches.arch/s390-09-04-qeth-no-online-recover.patch:
  qeth: avoid recovery during device online setting
  (bnc#583296,LTC#61167).
- patches.arch/s390-09-05-zfcp-ccw_fix_remove_list.patch: zfcp:
  Remove attached ports and units correctly. (bnc#583296).
- patches.arch/s390-09-06-qeth-dhcp.patch: qeth: l3 send dhcp
  in non pass thru mode (bnc#583296).
- patches.arch/s390-09-07-qeth-checksum-default.patch: qeth:
  change checksumming default for HiperSockets (bnc#583296).
* Mon Mar  8 2010 trenn@suse.de
- patches.fixes/pci_use_list_for_resources_1_5.patch: PCI:
  split up pci_read_bridge_bases() (bnc#578572).
- patches.fixes/pci_use_list_for_resources_2_5.patch: PCI: read
  bridge windows before filling in subtractive decode resources
  (bnc#578572).
- patches.fixes/pci_use_list_for_resources_3_5.patch: PCI: add
  pci_bus_for_each_resource(), remove direct bus->resource refs
  (bnc#578572).
- patches.fixes/pci_use_list_for_resources_4_5.patch: PCI:
  augment bus resource table with a list (bnc#578572).
- patches.fixes/pci_use_list_for_resources_5_5.patch: x86/PCI:
  use host bridge _CRS info by default on 2008 and newer machines
  (bnc#578572).
* Mon Mar  8 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-67-alc268-fix-quirk-check: ALSA:
  hda - Fix wrong model range check for ALC268 (bnc#585179).
- patches.drivers/alsa-sp1-hda-68-fix-realtek-secondary-adcs:
  ALSA: hda - Fix input source elements of secondary ADCs on
  Realtek (bnc#585179).
* Mon Mar  8 2010 mmarek@suse.cz
- Refresh vanilla configs.
* Sat Mar  6 2010 rjw@suse.de
- patches.suse/driver-core-reduce-level-of-request_firmware-messages.patch:
  Driver core: Reduce the level of request_firmware() messages
  (bnc#564618, FATE#306952).
* Fri Mar  5 2010 rw@suse.de
- Update config files:
  [ia64] Turn off CONFIG_PCI_IOV.  (bnc#560454)
* Fri Mar  5 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.9 and c/s 1003.
- patches.xen/xen-floppy: Xen: improve floppy behavior
  (bnc#584216).
- patches.xen/xen-fix_clock_gettime_vsyscall_time_warp.diff:
  Rename to ...
- patches.xen/xen3-fix_clock_gettime_vsyscall_time_warp.diff:
  ... this.
- patches.xen/xen3-x86_64_apic_consider_hotplug_for_mode_logical_flat.patch:
  x86, apic: Don't use logical-flat mode when CPU hotplug may
  exceed 8 CPUs (bnc#581567).
- patches.xen/xen3-x86_ioapic_fix_out_of_order_gsi.patch: x86:
  Fix out of order of gsi (bnc#569050).
* Fri Mar  5 2010 knikanth@suse.de
- patches.fixes/xfs-nonblocking-inode-locking-io-completion.patch:
  xfs: Non-blocking inode locking in IO completion (bnc#568319).
* Fri Mar  5 2010 npiggin@suse.de
- Update config files.
* Fri Mar  5 2010 npiggin@suse.de
- Update config files. i386 disable X86_PPRO_FENCE. This is a heavy
  partial workaround for very old and rare SMP PentiumPro systems.
* Fri Mar  5 2010 npiggin@suse.de
- patches.suse/x86-cacheline-size-128.patch: Refresh.
* Fri Mar  5 2010 npiggin@suse.de
- Update config files.
- patches.suse/x86-cacheline-size-128.patch: x86 set cacheline
  size to 128 bytes for generic CPUs.
* Fri Mar  5 2010 teheo@suse.de
- supported.conf: Mark CUSE unsupported.
* Thu Mar  4 2010 gregkh@suse.de
- patches.drivers/staging-hv-add-a-pci-device-table.patch:
  Staging: hv: add a pci device table.
- patches.drivers/staging-hv-match-on-dmi-values-to-know-if-we-should-run.patch:
  Staging: hv: match on DMI values to know if we should run..
* Thu Mar  4 2010 mmarek@suse.cz
- Drop kernel-vmi.
* Thu Mar  4 2010 rw@suse.de
- patches.rpmify/ia64-sn-fix-percpu-warnings:
  Update fix not to break sn2 modules.  (bnc#578059)
* Thu Mar  4 2010 bphilips@suse.de
- patches.drivers/igb-check-both-function-bits-in-status-register-in-w.patch:
  igb: check both function bits in status register in wol
  exception (bnc#557479).
* Thu Mar  4 2010 jack@suse.de
- supported.conf: Marked btrfs, exofs, cachefiles, nilfs2 as
  unsupported.
* Thu Mar  4 2010 bphilips@suse.de
- patches.drivers/tg3-Add-more-partno-entries-for-fallback-path.patch:
  tg3: Add more partno entries for fallback path (bnc#585191).
- patches.drivers/tg3-Add-support-for-2-new-selfboot-formats.patch:
  tg3: Add support for 2 new selfboot formats (bnc#585191).
- patches.drivers/tg3-Enforce-DMA-mapping-skb-assignment-ordering.patch:
  tg3: Enforce DMA mapping / skb assignment ordering (bnc#585191).
- patches.drivers/tg3-Fix-57765-A0-bootcode-race-condition.patch:
  tg3: Fix 57765 A0 bootcode race condition (bnc#585191).
- patches.drivers/tg3-Fix-AC131-loopback-test-errors-for-5785.patch:
  tg3: Fix AC131 loopback test errors for 5785 (bnc#585191).
- patches.drivers/tg3-Fix-napi-assignments-in-loopback-test.patch:
  tg3: Fix napi assignments in loopback test (bnc#585191).
- patches.drivers/tg3-Give-MSI-X-vec-1-rx-backlog-space.patch:
  tg3: Give MSI-X vec 1 rx backlog space (bnc#585191).
- patches.drivers/tg3-Make-57791-and-57795-10-100-only.patch:
  tg3: Make 57791 and 57795 10/100 only (bnc#585191).
- patches.drivers/tg3-Prevent-rx-producer-ring-overruns.patch:
  tg3: Prevent rx producer ring overruns (bnc#585191).
- patches.drivers/tg3-Turn-off-multiple-DMA-reads-for-5717.patch:
  tg3: Turn off multiple DMA reads for 5717 (bnc#585191).
- patches.drivers/tg3-Unwedge-stuck-MSI-X-vectors.patch: tg3:
  Unwedge stuck MSI-X vectors (bnc#585191).
* Thu Mar  4 2010 nfbrown@suse.de
- patches.fixes/sunrpc-monotonic-expiry: sunrpc: use monotonic
  time in expiry cache (bnc#578668).
* Thu Mar  4 2010 jjolly@suse.de
- patches.drivers/mlx4_core-missing-device-id-6778.patch:
  mlx4_core: missing device ID (bnc#585269).
* Thu Mar  4 2010 bphilips@suse.de
- patches.drivers/bnx2-update-firmware-and-some-bug-fixes-from-upstream.patch:
  bnx2: Update firmware and some bug fixes from
  upstream. (bnc#584451).
- patches.drivers/bnx2x-backports-v2.6.32-to-af901ca.patch:
  Refresh.
* Thu Mar  4 2010 rjw@suse.de
- patches.fixes/PM-Hibernate-fix-preallocating-of-memory.patch:
  PM / Hibernate: Fix preallocating of memory.
* Thu Mar  4 2010 rjw@suse.de
- Update the bnc#579647 patches to follow the upstream code.
- patches.arch/x86-UV-Add-UV-NMI-handler.patch: x86: Enable NMI
  on all cpus on UV (bnc#579647, FATE#306952).
- patches.suse/x86-uv-kdb-support-for-uv-nmi-handler.patch: x86 /
  UV: Add KDB support to UV NMI handler (bnc#579647, FATE#306952).
- patches.arch/x86-uv-nmi-handler-build-fix.patch: Delete.
- patches.arch/x86-uv-nmi-handler.patch: Delete.
* Wed Mar  3 2010 tonyj@suse.de
- Update config files.  Push trace changes into debug configs
* Wed Mar  3 2010 bphilips@suse.de
- patches.drivers/cxgb3-FIx-VLAN-over-Jumbo-frames.patch: cxgb3:
  FIx VLAN over Jumbo frames (bnc#585034).
- patches.drivers/cxgb3-Set-the-rxq.patch: cxgb3: Set the rxq
  (bnc#585034).
- patches.drivers/cxgb3-fix-GRO-checksum-check.patch: cxgb3:
  fix GRO checksum check (bnc#585034).
- patches.drivers/cxgb3-fix-link-flap.patch: cxgb3: fix link flap
  (bnc#585034).
* Wed Mar  3 2010 bphilips@suse.de
- patches.fixes/net-bug-fix-for-vlan-gro-issue.patch: net:
  bug fix for vlan + gro issue (bnc#584728).
* Wed Mar  3 2010 jbenc@suse.cz
- Update config files: enabled CONFIG_MAXSMP on x86_64 (FATE#306906).
* Wed Mar  3 2010 duwe@suse.de
- patches.arch/ppc-extended_h_cede-fix-kstack-resume: Powerpc:
  reset kernel stack on cpu online from cede state (bnc#573722).
- patches.arch/ppc-pseries-mach-cpu-die-rearrange-code: Powerpc:
  move checks in pseries_mach_cpu_die() (bnc#573722).
- patches.arch/ppc-pseries-mach-cpu-die-remove-debug-printk:
  Powerpc: reduce printk from pseries_mach_cpu_die() (bnc#573722).
* Wed Mar  3 2010 trenn@suse.de
- patches.fixes/x86_ioapic_fix_out_of_order_gsi.patch: x86:
  Fix out of order of gsi (bnc#569050).
* Wed Mar  3 2010 trenn@suse.de
- Update config files.
- patches.drivers/msi-wmi.patch: X86 drivers: Introduce msi-wmi
  driver (bnc#584617).
* Wed Mar  3 2010 bphilips@suse.de
- patches.drivers/ixgbe-add-support-for-82599-KR-device-0x1517.patch:
  ixgbe: add support for 82599 KR device 0x1517 (bnc#584820).
* Wed Mar  3 2010 bphilips@suse.de
- patches.drivers/e1000e-enable-new-82567V-3-device.patch:
  e1000e: enable new 82567V-3 device (bnc#584875).
* Tue Mar  2 2010 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Update
  references (bnc#501563 FATE#307247 bnc#583539). Refresh.
* Tue Mar  2 2010 jeffm@suse.com
- patches.fixes/dvb-core-fix-dos-bug-in-ule-decapsulation-code-that-can-be-triggered-by-an-invalid:
  dvb-core: Fix DoS bug in ULE decapsulation code that can be
  triggered by an invalid...  (bnc#584320).
* Tue Mar  2 2010 jeffm@suse.com
- patches.fixes/acpi-fix-regression-where-_ppc-is-not-read-at-boot-even-when-ignore_ppc-0:
  ACPI: Fix regression where _PPC is not read at boot even when
  ignore_ppc=0 (bnc#584574).
* Tue Mar  2 2010 sjayaraman@suse.de
- patches.fixes/sched-sysctl-for-normalized-tunables: Reinstate
  normalized sched sysctl values overriden by stable update
  2.6.32.6.7.
* Tue Mar  2 2010 knikanth@suse.de
- patches.fixes/bsg-SG_IO-compat_ioctl: Fix a bug in the patch
  introduced when backporting. Refresh.
* Mon Mar  1 2010 jeffm@suse.com
- patches.arch/powerpc-export-data-from-new-hcall-H_EM_GET_PARMS.patch:
  powerpc: export data from new hcall H_EM_GET_PARMS (bnc#584343).
* Mon Mar  1 2010 jeffm@suse.com
- patches.fixes/sched-fix-smt-scheduler-regression-in-find_busiest_queue:
  Refresh.
* Mon Mar  1 2010 jeffm@suse.com
- patches.fixes/sched-fix-sched_mc-regression-caused-by-change-in-sched-cpu_power:
  sched: Fix SCHED_MC regression caused by change in sched
  cpu_power (bnc#584209).
- patches.fixes/sched-fix-smt-scheduler-regression-in-find_busiest_queue:
  sched: Fix SMT scheduler regression in find_busiest_queue()
  (bnc#584209).
* Mon Mar  1 2010 jeffm@suse.com
- patches.fixes/fix-lookup_follow-on-automount-symlinks: fix
  LOOKUP_FOLLOW on automount "symlinks" (bnc#582552).
* Mon Mar  1 2010 knikanth@suse.de
- patches.fixes/dm-raid45-fix-region-hash-double-free: Fix region
  hash double free when context_alloc fails (bnc#565962).
* Mon Mar  1 2010 knikanth@suse.de
- patches.drivers/lpfc-8.3.5.6-update: Update Emulex lpfc driver
  to 8.3.5.6 (bnc#583900).
* Sat Feb 27 2010 coly.li@suse.de
- backport fs/dlm from 2.6.33
  - patches.fixes/dlm-Send-lockspace-name-with-uevents.patch: dlm:
    Send lockspace name with uevents.
  - patches.fixes/dlm-fix-ordering-of-bast-and-cast.patch: dlm:
    fix ordering of bast and cast.
  - patches.fixes/dlm-send-reply-before-bast.patch: dlm: send
    reply before bast.
  - patches.fixes/dlm-use-bastmode-in-debugfs-output.patch: dlm:
    use bastmode in debugfs output.
* Sat Feb 27 2010 knikanth@suse.de
- patches.fixes/dm-raid45_exit_destroy_cache: Free recovery
  stripes before destroying cache and do not destroy dirty log
  twice (bnc#565962).
* Sat Feb 27 2010 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in: Added
  patches.xfs to the RPM.
* Sat Feb 27 2010 bphilips@suse.de
- patches.drivers/qlge-0002-add-watchdog-timer.patch: Refresh.
- patches.drivers/qlge-Fix-bonding-mac-address-bug.patch: qlge:
  Fix bonding mac address bug. (bnc#581188).
- patches.drivers/qlge-Fix-dropping-of-large-non-TCP-UDP-frames.patch:
  qlge: Fix dropping of large non-TCP/UDP frames. (bnc#581188).
- patches.drivers/qlge-Fix-occasional-loopback-test-failure.patch:
  qlge: Fix occasional loopback test failure. (bnc#581188).
* Fri Feb 26 2010 jeffm@suse.de
- patches.xfs/xfs-uninline-xfs_get_extsz_hint.patch: exported symbol
* Fri Feb 26 2010 jeffm@suse.com
- patches.suse/xfs-dmapi-re-add-flags-for-xfs_free_eofblocks:
  xfs/dmapi: Re-add flags for xfs_free_eofblocks (bnc#582872).
- patches.xfs/XFS-Free-buffer-pages-array-unconditionally.patch:
  XFS: Free buffer pages array unconditionally (bnc#582872).
- patches.xfs/kill-I_LOCK.patch: kill I_LOCK (bnc#582872).
- patches.xfs/xfs-Avoid-inodes-in-reclaim-when-flushing-from-inode.patch:
  xfs: Avoid inodes in reclaim when flushing from inode cache
  (bnc#582872).
- patches.xfs/xfs-Don-t-flush-stale-inodes.patch: xfs: Don't
  flush stale inodes (bnc#582872).
- patches.xfs/xfs-Ensure-we-force-all-busy-extents-in-range-to-dis.patch:
  xfs: Ensure we force all busy extents in range to disk
  (bnc#582872).
- patches.xfs/xfs-Fix-error-return-for-fallocate-on-XFS.patch:
  xfs: Fix error return for fallocate() on XFS (bnc#582872).
- patches.xfs/xfs-I-O-completion-handlers-must-use-NOFS-allocation.patch:
  xfs: I/O completion handlers must use NOFS allocations
  (bnc#582872).
- patches.xfs/xfs-Remove-inode-iolock-held-check-during-allocation.patch:
  xfs: Remove inode iolock held check during allocation
  (bnc#582872).
- patches.xfs/xfs-Wrapped-journal-record-corruption-on-read-at-rec.patch:
  xfs: Wrapped journal record corruption on read at recovery
  (bnc#582872).
- patches.xfs/xfs-change-the-xfs_iext_insert-xfs_iext_remove.patch:
  xfs: change the xfs_iext_insert / xfs_iext_remove (bnc#582872).
- patches.xfs/xfs-check-for-not-fully-initialized-inodes-in-xfs_ir.patch:
  xfs: check for not fully initialized inodes in xfs_ireclaim
  (bnc#582872).
- patches.xfs/xfs-cleanup-bmap-extent-state-macros.patch: xfs:
  cleanup bmap extent state macros (bnc#582872).
- patches.xfs/xfs-cleanup-data-end-I-O-handlers.patch: xfs:
  cleanup data end I/O handlers (bnc#582872).
- patches.xfs/xfs-cleanup-dmapi-macros-in-the-umount-path.patch:
  xfs: cleanup dmapi macros in the umount path (bnc#582872).
- patches.xfs/xfs-fix-missing-error-check-in-xfs_rtfree_range.patch:
  xfs: fix missing error check in xfs_rtfree_range (bnc#582872).
- patches.xfs/xfs-fix-mmap_sem-iolock-inversion-in-xfs_free_eofblo.patch:
  xfs: fix mmap_sem/iolock inversion in xfs_free_eofblocks
  (bnc#582872).
- patches.xfs/xfs-fix-stale-inode-flush-avoidance.patch: xfs:
  fix stale inode flush avoidance (bnc#582872).
- patches.xfs/xfs-fix-timestamp-handling-in-xfs_setattr.patch:
  xfs: fix timestamp handling in xfs_setattr (bnc#582872).
- patches.xfs/xfs-improve-metadata-I-O-merging-in-the-elevator.patch:
  xfs: improve metadata I/O merging in the elevator (bnc#582872).
- patches.xfs/xfs-kill-the-STATIC_INLINE-macro.patch: xfs:
  kill the STATIC_INLINE macro (bnc#582872).
- patches.xfs/xfs-kill-xfs_bmbt_rec_32-64-types.patch: xfs:
  kill xfs_bmbt_rec_32/64 types (bnc#582872).
- patches.xfs/xfs-reclaim-all-inodes-by-background-tree-walks.patch:
  xfs: reclaim all inodes by background tree walks (bnc#582872).
- patches.xfs/xfs-reclaim-inodes-under-a-write-lock.patch: xfs:
  reclaim inodes under a write lock (bnc#582872).
- patches.xfs/xfs-remove-IO_ISAIO.patch: xfs: remove IO_ISAIO
  (bnc#582872).
- patches.xfs/xfs-remove-incorrect-sparse-annotation-for-xfs_iget_.patch:
  xfs: remove incorrect sparse annotation for xfs_iget_cache_miss
  (bnc#582872).
- patches.xfs/xfs-rename-xfs_attr_fetch-to-xfs_attr_get_int.patch:
  xfs: rename xfs_attr_fetch to xfs_attr_get_int (bnc#582872).
- patches.xfs/xfs-reset-the-i_iolock-lock-class-in-the-reclaim-pat.patch:
  xfs: reset the i_iolock lock class in the reclaim path
  (bnc#582872).
- patches.xfs/xfs-simplify-inode-teardown.patch: xfs: simplify
  inode teardown (bnc#582872).
- patches.xfs/xfs-simplify-xfs_buf_get-xfs_buf_read-interfaces.patch:
  xfs: simplify xfs_buf_get / xfs_buf_read interfaces
  (bnc#582872).
- patches.xfs/xfs-uninline-xfs_get_extsz_hint.patch: xfs:
  uninline xfs_get_extsz_hint (bnc#582872).
- patches.xfs/xfs-use-WRITE_SYNC_PLUG-for-synchronous-writeout.patch:
  xfs: use WRITE_SYNC_PLUG for synchronous writeout (bnc#582872).
- patches.xfs/xfs-xfs_swap_extents-needs-to-handle-dynamic-fork-of.patch:
  xfs: xfs_swap_extents needs to handle dynamic fork offsets
  (bnc#582872).
* Fri Feb 26 2010 astarikovskiy@suse.de
- patches.fixes/acpi_be_in_TS_POLLING_state_during_mwait.patch:
  ACPI: Be in TS_POLLING state during mwait (bnc#583022)
* Fri Feb 26 2010 trenn@suse.de
- supported.conf:
* Thu Feb 25 2010 tonyj@suse.de
- config/x86_64/trace: enable FUNCTION_GRAPH_TRACER
* Thu Feb 25 2010 mmarek@suse.cz
- rpm/split-modules: Do not duplicate base modules in the main
  package.
* Thu Feb 25 2010 tonyj@suse.de
- patches.trace/oprofile-no-tracing.diff: oprofile: remove
  tracing build dependency (disable remaining tracers)
- Update config files.
* Thu Feb 25 2010 tiwai@suse.de
- patches.drivers/synaptics-clickpad-bottom-enable: Add
  parameter to enable/disable the sensing of clickpad button area
  (bnc#58529).
- patches.drivers/synaptics-clickpad-button-toggle: Add clickpad
  button toggle support (bnc#547370, bnc#582643).
* Thu Feb 25 2010 knikanth@suse.de
- patches.suse/dm-mpath-no-activate-for-offlined-paths: Fix a bug
  in the patch. Refresh. (bnc#565962)
* Thu Feb 25 2010 rjw@suse.de
- patches.arch/x86-uv-nmi-handler-build-fix.patch: x86 / UV:
  Fix UV NMI handler build issue (bnc#579647, FATE#306952).
* Thu Feb 25 2010 rjw@suse.de
- patches.arch/x86-uv-nmi-handler.patch: x86 / UV: Add UV NMI
  handler (bnc#579647, FATE#306952).
- patches.suse/x86-add-kdb-support-for-unknown_nmi_error-handler.patch:
  x86: Add KDB support to unknown_nmi_error handler. (bnc#579647,
  FATE#306952).
- patches.suse/x86-uv-kdb-support-for-uv-nmi-handler.patch:
  Add KDB support to UV NMI handler. (bnc#579647, FATE#306952).
* Wed Feb 24 2010 jeffm@suse.com
- patches.fixes/powerpc-eeh-fix-a-bug-when-pci-structure-is-null:
  powerpc/eeh: Fix a bug when pci structure is null (bnc#579137).
* Tue Feb 23 2010 coly.li@suse.de
- Backport fs/ocfs2 and fs/dlm from 2.6.33-rc8
  - patches.fixes/dlm-always-use-GFP_NOFS.patch: dlm: always
  use GFP_NOFS.
  - patches.fixes/ocfs2-Do-not-downconvert-if-the-lock-level-is-alread.patch:
  ocfs2: Do not downconvert if the lock level is already
  compatible.
  - patches.fixes/ocfs2-Fix-contiguousness-check-in-ocfs2_try_to_merge.patch:
  ocfs2: Fix contiguousness check in
  ocfs2_try_to_merge_extent_map().
  - patches.fixes/ocfs2-Fix-memory-overflow-in-cow_by_page.patch:
  ocfs2: Fix memory overflow in cow_by_page..
  - patches.fixes/ocfs2-Fix-setting-of-OCFS2_LOCK_BLOCKED-during-bast.patch:
  ocfs2: Fix setting of OCFS2_LOCK_BLOCKED during bast.
  - patches.fixes/ocfs2-Only-bug-out-when-page-size-is-larger-than-clu.patch:
  ocfs2: Only bug out when page size is larger than cluster size..
  - patches.fixes/ocfs2-Plugs-race-between-the-dc-thread-and-an-unlock.patch:
  ocfs2: Plugs race between the dc thread and an unlock ast
  message.
  - patches.fixes/ocfs2-Prevent-a-livelock-in-dlmglue.patch: ocfs2:
  Prevent a livelock in dlmglue.
  - patches.fixes/ocfs2-Remove-overzealous-BUG_ON-during-blocked-lock-.patch:
  ocfs2: Remove overzealous BUG_ON during blocked lock processing.
  - patches.fixes/ocfs2-Use-compat_ptr-in-reflink_arguments.patch:
  ocfs2: Use compat_ptr in reflink_arguments..
  - patches.fixes/ocfs2-cluster-Make-o2net-connect-messages-KERN_NOTIC.patch:
  ocfs2/cluster: Make o2net connect messages KERN_NOTICE.
  - patches.fixes/ocfs2-dlm-Fix-printing-of-lockname.patch:
  ocfs2/dlm: Fix printing of lockname.
  - patches.fixes/ocfs2-dlm-Handle-EAGAIN-for-compatibility-v2.patch:
  ocfs2/dlm: Handle EAGAIN for compatibility - v2.
  - patches.fixes/ocfs2-dlm-Remove-BUG_ON-in-dlm-recovery-when-freeing.patch:
  ocfs2/dlm: Remove BUG_ON in dlm recovery when freeing locks
  of a dead node.
* Tue Feb 23 2010 gregkh@suse.de
- supported.conf: Support Microsoft HyperV drivers (FATE#309005)
* Tue Feb 23 2010 gregkh@suse.de
- Patch refresh after 2.6.32.9 update
* Tue Feb 23 2010 gregkh@suse.de
- Update to 2.6.32.9:
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.drivers/alsa-sp1-usb-01-avoid-oops-at-disconnect
  - patches.drivers/drm-i915-add-i915_lp_ring_sync-helper.patch
  - patches.drivers/drm-i915-fix-ironlake-crt-hotplug
  - patches.fixes/acpi_NULL_check_scan_bus.patch
  - patches.fixes/alsa-hda-intel-avoid-divide-by-zero-crash
  - patches.fixes/dm-stripe-zero-stripes
  - patches.fixes/fix-potential-crash-with-sys_move_pages
  - patches.fixes/futex-handle-user-space-corruption-gracefully
  - patches.fixes/futex_lock_pi-key-refcnt-fix
  - patches.fixes/nfs-fix-nfs_fscache_release_page.patch
  - patches.kernel.org/dasd-remove-strings-from-s390dbf.patch
  - patches.suse/rlim-0003-resource-add-helpers-for-fetching-rlimits.patch
* Tue Feb 23 2010 knikanth@suse.de
- patches.fixes/bsg-SG_IO-compat_ioctl: compat_ioct: fix bsg SG_IO
  (bnc#580991).
- patches.fixes/fc_bsg_request_packed: fc-transport: Use
  packed modifier for fc_bsg_request structure. (bnc#580991).
* Tue Feb 23 2010 mmarek@suse.cz
- Stop watching the kabi again.
- patches.kabi/struct-file-f_count: Delete.
- patches.kabi/task_struct-btrace_seq: Delete.
* Tue Feb 23 2010 jslaby@suse.de
- patches.fixes/mm-memcg-coalesce-charging.patch: Refresh.
- patches.fixes/mm-memcg-coalesce-uncharge.patch: memcg: coalesce
  uncharge during unmap/truncate (bnc#550906).
- patches.suse/perfmon2.patch: Refresh.
- patches.xen/tmem: Refresh.
* Tue Feb 23 2010 jack@suse.de
- patches.fixes/novfs-fix-inode-uid: novfs: Get proper UID when
  looking up inode (bnc#486997).
- patches.fixes/novfs-incorrect-filesize-fix: novfs: novfs
  reports incorrect file size (bnc#426536).
- patches.fixes/novfs-truncate-fix: novfs: Fixes corruption of
  OO documents on NSS Volumes (bnc#508259).
* Mon Feb 22 2010 jslaby@suse.de
- patches.fixes/mm-memcg-coalesce-charging.patch: memcg: coalesce
  charging via percpu storage (bnc#550906).
* Mon Feb 22 2010 mfasheh@suse.com
- Update config files. The Ocfs2 tracing option wasn't turned on for some
  reason. We really need this for debugging customer issues in the field.
* Mon Feb 22 2010 jeffm@suse.com
- patches.fixes/alsa-hda-intel-avoid-divide-by-zero-crash: ALSA:
  hda-intel: Avoid divide by zero crash (bnc#581718).
* Mon Feb 22 2010 jkosina@suse.cz
- patches.suse/cfq-turn-lowlatency-off-by-default.patch: CFQ:
  turn 'low_latency' knob off by default (bnc#572834).
* Mon Feb 22 2010 jbenc@suse.cz
- patches.suse/cgroup-disable-memory.patch: Delete, the rest of the
  patch does not make sense after commit 6b53b611.
* Mon Feb 22 2010 tonyj@suse.de
- delete lttng instrumentation patches (requested by jkosina)
- refresh patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Mon Feb 22 2010 hare@suse.de
- patches.drivers/qla1280-fallback-to-loaded-fw: qla1280: retain
  firmware for error recovery (bnc#578430).
- patches.drivers/qla1280-request-firmware-lock: qla1280:
  firmware load deadlocks kdump (bnc#578430).
- patches.drivers/qla4xxx-5.01.00.00.11.01-k11_5.01.00.00.11.01-k12.patch:
  Update qla4xxx to v5.01.00.00.11.01-k12 (bnc#556572).
* Mon Feb 22 2010 garloff@suse.de
- patches.xen/xen-fix_clock_gettime_vsyscall_time_warp.diff:
  Fix up xen compilation after last commits (bnc#581567).
* Sun Feb 21 2010 jkosina@suse.cz
- patches.fixes/fix_clock_gettime_vsyscall_time_warp.diff:
  put proper 'Patch-mainline' tag in.
* Sat Feb 20 2010 trenn@suse.de
- patches.arch/x86_64_apic_consider_hotplug_for_mode_logical_flat.patch:
  x86, apic: Don't use logical-flat mode when CPU hotplug may
  exceed 8 CPUs (bnc#581567).
* Sat Feb 20 2010 garloff@suse.de
- patches.fixes/fix_clock_gettime_vsyscall_time_warp.diff:
  Fix time warps with vsyscalls (bnc#569238).
* Fri Feb 19 2010 jkosina@suse.cz
- patches.arch/x86-calgary-increase-max-phb-bus-num.patch: x86:
  calgary - increase max phb bus number (bnc#581199).
* Fri Feb 19 2010 jslaby@suse.de
- patches.suse/cgroup-disable-memory.patch: Enable memcg by default.
  (bnc#436025 bnc#467688 bnc#550906).
* Fri Feb 19 2010 jbeulich@novell.com
- Refresh Xen patches.
- patches.xen/xen-x86-nohz-long-timeouts: Properly handle long
  timeouts when passed to VCPUOP_set_singleshot_timer.
- patches.xen/xen-x86-time-per-cpu: fold per-CPU accounting data
  into a structure.
- patches.xen/xen-x86-xtime-lock: reduce contention on xtime_lock
  (bnc#569014, bnc#571041, bnc#571769, bnc#572146).
- patches.xen/xen3-x86_irq_setup_extra_ioapic_for_sci.patch: x86:
  fix sci on ioapic 1 (bnc#572661).
* Fri Feb 19 2010 hare@suse.de
- patches.drivers/be2iscsi-BE3-support: be2iscsi: Add support
  for BE3 HBAs (bnc#568147).
- patches.drivers/lpfc-8.3.5.5-update: Update Emulex lpfc driver
  to 8.3.5.5 (bnc#579682).
- patches.drivers/qla2xxx-8.03.01.03.11.1-k8-update: qla2xxx:
  Updates to sync with 2.6.33-rc8 and scsi-misc-2.6 (bnc#580823).
- patches.drivers/qla4xxx-5.01.00.00.11.01-k10_5.01.00.00.11.01-k11.patch:
  qla4xxx update to v5.01.00.00.11.01-k11 (bnc#556572).
- patches.fixes/libiscsi-add-recover-target: libiscsi: Implement
  recover_target callback (bnc#568147).
- patches.fixes/qla2xxx-restore-pci-state-after-eeh-recovery:
  Delete.
* Fri Feb 19 2010 mmarek@suse.cz
- patches.kabi/struct-file-f_count: struct file kabi hack
  for i386.
- patches.kabi/task_struct-btrace_seq: task_struct kabi hack
  for i386.
* Fri Feb 19 2010 sjayaraman@suse.de
- patches.fixes/sched-fix-sched_mc_power_savings-for-non-SMT:
  Fix for sched_mc_powersavings for !SMT (bnc#579060, LTC#59030).
* Thu Feb 18 2010 jjolly@suse.de
- patches.arch/s390-08-01-zfcp_port_dequeue_race.patch:
  zfcp: cancel all pending work for a to be removed
  zfcp_port. (bnc#579111).
- patches.arch/s390-08-02-zfcp_fc_bsg_report_error.patch: zfcp:
  report BSG errors in correct field. (bnc#579111).
- patches.arch/s390-08-03-qdio-input-error.patch: qdio: continue
  polling for buffer state ERROR (bnc#579111,LTC#60735).
- patches.arch/s390-08-04-qdio-int_handler_warn.patch: qdio:
  prevent kernel bug message in interrupt handler. (bnc#579111).
- patches.arch/s390-08-05-hvc-iucv-alloc-dma.patch:
  hvc_iucv: allocate IUCV send/receive buffers in DMA zone
  (bnc#579111,LTC#60771).
* Thu Feb 18 2010 jjolly@suse.de
- patches.drivers/ehca-process-mad-null.patch: ib/ehca: fix
  in_wc handling in process_mad() (bnc#580140,LTC#60809).
* Thu Feb 18 2010 bphilips@suse.de
- patches.drivers/ethtool-Introduce-n-tuple-filter-programming-support.patch:
  ethtool: Introduce n-tuple filter programming support
  (bnc#580381) Drop this patch
- patches.drivers/ixgbe-Add-support-for-the-new-ethtool-n-tuple-progra.patch:
  ixgbe: Add support for the new ethtool n-tuple programming
  interface (bnc#580381) Drop this patch
* Thu Feb 18 2010 mmarek@suse.cz
- Import Beta3 kabi files.
* Thu Feb 18 2010 bphilips@suse.de
- patches.suse/tg3-5785-and-57780-asic-revs-not-working.patch:
  tg3: 5785 and 57780 asic revs not working (bnc#580780).
* Thu Feb 18 2010 gregkh@suse.de
- Fix s390 vanilla build:
  - patches.arch/s390-04-15-cio-split-pgid.patch: Refresh.
  - patches.kernel.org/dasd-remove-strings-from-s390dbf.patch:
    dasd: remove strings from s390dbf.
  - patches.arch/s390-05-15-dasd-s390dbf-strings.patch: Delete.
* Thu Feb 18 2010 bphilips@suse.de
- patches.drivers/ethtool-Introduce-n-tuple-filter-programming-support.patch:
  ethtool: Introduce n-tuple filter programming support
  (bnc#580381).
- patches.drivers/ixgbe-Add-support-for-the-new-ethtool-n-tuple-progra.patch:
  ixgbe: Add support for the new ethtool n-tuple programming
  interface (bnc#580381).
* Thu Feb 18 2010 bphilips@suse.de
- patches.drivers/ixgbe-prevent-speculative-processing-of-descriptors.patch:
  ixgbe: prevent speculative processing of descriptors
  (bnc#580416).
* Wed Feb 17 2010 jeffm@suse.com
- Update config files.
* Wed Feb 17 2010 bphilips@suse.de
- patches.drivers/tg3-entropy-source.patch: Refresh to fix fuzz
* Wed Feb 17 2010 npiggin@suse.de
- patches.fixes/cpuset-slab-memspread-fix.patch: cpuset: fix
  cpuset mem spreading returning offline node (bnc#575923).
* Wed Feb 17 2010 npiggin@suse.de
- patches.suse/slab-memless-node-01-introduce-numa_mem_id.patch:
  mm: introduce numa_mem_id (bnc#570492).
- patches.suse/slab-memless-node-02-slab-use-numa_mem_id.patch:
  mm: slab use numa_mem_id (bnc#570492).
- patches.suse/slab-memless-node-03-ia64-memoryless-nodes.patch:
  ia64: support memoryless nodes (bnc#570492).
- patches.suse/slab-memless-node-04-kernel-profile-memoryless-nodes.patch:
  kernel: support memoryless nodes in profiling (bnc#570492).
* Wed Feb 17 2010 bphilips@suse.de
- patches.drivers/drivers-net-request_irq-remove: Refresh.
- patches.drivers/igb-0001-add-support-for-the-82580-phy.patch:
  igb: add support for the 82580 phy (bnc#557479).
- patches.drivers/igb-0002-Add-full-support-for-82580-devices.patch:
  igb: Add full support for 82580 devices (bnc#557479).
- patches.drivers/igb-0003-add-support-for-82580-MAC.patch: igb:
  add support for 82580 MAC (bnc#557479).
- patches.drivers/igb-add-new-data-structure-for-handling-interrupts-a.patch:
  igb: add new data structure for handling interrupts and NAPI
  (bnc#557479).
- patches.drivers/igb-cleanup-interrupt-enablement-in-regards-to-msix_.patch:
  igb: cleanup interrupt enablement in regards to msix_other
  (bnc#557479).
- patches.drivers/igb-cleanup-some-of-the-code-related-to-hw-timestamp.patch:
  igb: cleanup some of the code related to hw timestamping
  (bnc#557479).
- patches.drivers/igb-entropy-source.patch: Refresh.
- patches.drivers/igb-use-packet-buffer-sizes-from-RXPBS-register.patch:
  igb: use packet buffer sizes from RXPBS register (bnc#557479).
- patches.drivers/ixgbe-entropy-source.patch: Refresh.
* Tue Feb 16 2010 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Tue Feb 16 2010 bphilips@suse.de
- patches.arch/x86-Avoid-race-condition-in-pci_enable_msix.patch:
  x86: Avoid race condition in pci_enable_msix() (bnc#572294).
* Mon Feb 15 2010 rjw@suse.de
- patches.arch/x86-uv-fix-uv_hub_macro-bug.patch: x86 / UV:
  Fix bug in uv_global_gru_mmr_address macro (bnc#579636,
  FATE#306952).
* Mon Feb 15 2010 tiwai@suse.de
- patches.drivers/drm-i915-adhoc-disable-lid-detection: drm/i915:
  Disable ACPI lid detection as an ad hoc workaround (bnc#577937).
* Mon Feb 15 2010 rw@suse.de
- patches.fixes/ia64-preserve-high-order-personality-bits:
  [ia64] Preserve personality flag bits across exec(2). (bnc#565124)
* Mon Feb 15 2010 sjayaraman@suse.de
- patches.fixes/nfs-fix-nfs_fscache_release_page.patch: NFS:
  Fix a bug in nfs_fscache_release_page() (bnc#569687).
* Sat Feb 13 2010 bphilips@suse.de
- patches.drivers/be2net-0000-fix-bug-in-rx-page-posting.patch:
  be2net: fix bug in rx page posting (bnc#556959).
- patches.drivers/be2net-0001-Add-link-test-to-list-of-ethtool-self-tests.patch:
  be2net: Add link test to list of ethtool self
  tests. (bnc#556959).
- patches.drivers/be2net-0002-ethtool-self-test-reorganization.patch:
  be2net: ethtool self test reorganization. (bnc#556959).
- patches.drivers/be2net-0003-bug-fix-in-be_read_eeprom.patch:
  be2net: bug fix in be_read_eeprom (bnc#556959).
- patches.drivers/be2net-0004-bug-fix-for-flashing-the-BladeEngine3-ASIC.patch:
  be2net: bug fix for flashing the BladeEngine3 ASIC (bnc#556959).
- patches.drivers/be2net-0005-remove-unused-pci-device-id.patch:
  be2net: remove unused pci device id (bnc#556959).
- patches.drivers/be2net-0006-bug-fix-in-be_change_mtu.patch:
  be2net: bug fix in be_change_mtu (bnc#556959).
* Sat Feb 13 2010 bphilips@suse.de
- patches.drivers/cxgb3-fixing-eeh-handlers.patch: cxgb3: Fixing
  EEH handlers (bnc#578980).
- patches.drivers/e1000e-call-pci_save_state-after-pci_restore_state.patch:
  e1000e: call pci_save_state() after pci_restore_state()
  (bnc#578981).
* Sat Feb 13 2010 gregkh@suse.de
- Update config files.
  disable CONFIG_DETECT_SOFTLOCKUP on i386 and x86-64 except
  for debug kernels.  Resolves bnc#572119 and potentially many more
  in the future.
* Fri Feb 12 2010 bphilips@suse.de
- patches.drivers/qlge-0003-add-check-for-eeh-failure-when-closing-device.patch:
  Refresh.
- patches.drivers/qlge-0025-drivers-net-Move-and-to-end-of-previous-line.patch:
  drivers/net: Move && and || to end of previous line
  (bnc#560420).
- patches.drivers/qlge-0026-Turn-on-RX-header-split-based-on-platform.patch:
  qlge: Turn on RX header split based on platform. (bnc#560420).
- patches.drivers/qlge-0027-Add-RX-frame-handlers-for-non-split-frames.patch:
  qlge: Add RX frame handlers for non-split frames. (bnc#560420).
- patches.drivers/qlge-0028-Add-napi-gro-frags-interface.patch:
  qlge: Add napi gro frags interface. (bnc#560420).
- patches.drivers/qlge-0029-drivers-net-qlge-qlge_main.c-use-pM-to-show-MAC-ad.patch:
  drivers/net/qlge/qlge_main.c: use %%pM to show MAC address
  (bnc#560420).
- patches.drivers/qlge-0030-drivers-net-use-DEFINE_PCI_DEVICE_TABLE.patch:
  drivers/net/: use DEFINE_PCI_DEVICE_TABLE() (bnc#560420).
- patches.drivers/qlge-0031-Add-data-for-firmware-dump.patch:
  qlge: Add data for firmware dump. (bnc#560420).
- patches.drivers/qlge-0032-Add-basic-firmware-dump.patch: qlge:
  Add basic firmware dump. (bnc#560420).
- patches.drivers/qlge-0033-Add-probe-regs-to-firmware-dump.patch:
  qlge: Add probe regs to firmware dump. (bnc#560420).
- patches.drivers/qlge-0034-Add-RAM-dump-to-firmware-dump.patch:
  qlge: Add RAM dump to firmware dump. (bnc#560420).
- patches.drivers/qlge-0035-Add-alternate-function-s-reg-dump-to-fw-dump.patch:
  qlge: Add alternate function's reg dump to fw
  dump. (bnc#560420).
- patches.drivers/qlge-0036-Add-serdes-reg-blocks-dump-to-firmware-dump.patch:
  qlge: Add serdes reg blocks dump to firmware dump. (bnc#560420).
- patches.drivers/qlge-0037-Add-xgmac-reg-blocks-to-firwmare-dump.patch:
  qlge: Add xgmac reg blocks to firwmare dump. (bnc#560420).
- patches.drivers/qlge-0038-Add-module-param-to-force-firmware-core-dump.patch:
  qlge: Add module param to force firmware core
  dump. (bnc#560420).
- patches.drivers/qlge-0003-Set-PCIE-max-read-request-size.patch:
  Delete.
- patches.drivers/qlge-0025-Add-performance-change-for-non-split-headers.patch:
  Delete.
- patches.drivers/qlge-0026-Add-firmware-core-dump.patch: Delete.
* Fri Feb 12 2010 jeffm@suse.com
- patches.fixes/futex-handle-user-space-corruption-gracefully:
  futex: Handle user space corruption gracefully (bnc#579439
  CVE-2010-0622).
- patches.fixes/futex_lock_pi-key-refcnt-fix: futex_lock_pi()
  key refcnt fix (bnc#579439 CVE-2010-0623).
* Fri Feb 12 2010 jeffm@suse.com
- patches.fixes/taskstats-alignment: delayacct: align to 8 byte
  boundary on 64-bit systems (bnc#578065).
* Fri Feb 12 2010 tiwai@suse.de
- patches.drivers/drm-i915-fix-ironlake-crt-hotplug: drm/i915:
  disable hotplug detect before Ironlake CRT detect (bnc#575047).
* Fri Feb 12 2010 tiwai@suse.de
- patches.drivers/drm-i915-fix-ironlake-crt-hotplug: drm/i915:
  disable hotplug detect before Ironlake CRT detect (bnc#575047).
* Fri Feb 12 2010 jkosina@suse.cz
- Update config files: enable MMU_NOTIFIER for SGI_XP
  (bnc#573803).
* Fri Feb 12 2010 duwe@suse.de
- patches.arch/ppc-extended_h_cede-update-to-mainline: Refresh.
  According to bnc#550447 c#18 this should be it.
* Fri Feb 12 2010 jkosina@suse.cz
- patches.fixes/ia64-select-mmu-notifier-for-sgi-xp.patch:
  Select MMU_NOTIFIER for SGI_XP (bnc#573803).
* Fri Feb 12 2010 trenn@suse.de
- patches.trace/lttng-instrumentation-swap.patch: Refresh.
* Fri Feb 12 2010 trenn@suse.de
- patches.arch/acpi_enable_C3_on_huge_latencies.patch: ACPI:
  allow C3 > 1000usec (Requested by Intel).
* Fri Feb 12 2010 trenn@suse.de
- patches.arch/x86_cpu_hotplug_map_numa_node_correctly.patch:
  x86: map hotadded cpu to correct node (bnc#567283).
- patches.xen/xen3-patch-2.6.19: Refresh.
* Fri Feb 12 2010 trenn@suse.de
- patches.fixes/bios_driven_exclude_firmware_error.patch: cpufreq,
  powernow-k8: Do not complain about missing tables when BIOS
  drives cpufreq (Requested by HP).
* Fri Feb 12 2010 trenn@suse.de
  Most of these never show up in productive code paths and are for
  injecting/faking HW errors. Thus I still add them that late:
- patches.fixes/mce_injection_enhancements_0474a60ec704324577782b1057d05b574388d552:
  HWPOISON: Use new shake_page in memory_failure (Requested by
  Intel for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_0d57eb8dfcb92e3dd928d792f4ed2b2fec680bb7:
  HWPOISON: Don't do early filtering if filter is disabled
  (Requested by Intel for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_12686d153abff397fa0927c620d5a3de84910b72:
  HWPOISON: Try to allocate migration page on the same node
  (Requested by Intel for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_138ce286eb6ee6d39ca4fb50516e93adaf6b605f:
  HWPOISON: return 0 to indicate success reliably (Requested by
  Intel for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_1668bfd5be9d8a52536c4865000fbbe065a3613b:
  HWPOISON: abort on failed unmap (Requested by Intel for better
  MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_1a9b5b7fe0c5dad8a635288882d36785dea742f9:
  mm: export stable page flags (Requested by Intel for better
  MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_1bfe5febe34d2be2120803c10720e179186357c9:
  HWPOISON: add an interface to switch off/on all the page filters
  (Requested by Intel for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_31d3d3484f9bd263925ecaa341500ac2df3a5d9b:
  HWPOISON: limit hwpoison injector to known page types (Requested
  by Intel for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_413f9efbc513d330f00352bb7cba060a729999d3:
  HWPOISON: mention HWPoison in Kconfig entry (Requested by
  Intel for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_478c5ffc0b50527bd2390f2daa46cc16276b8413:
  HWPOISON: add page flags filter (Requested by Intel for better
  MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_4fd466eb46a6a917c317a87fb94bfc7252a0f7ed:
  HWPOISON: add memory cgroup filter (Requested by Intel for
  better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_71f72525dfaaec012e23089c73331654ea7b12d3:
  HWPOISON: comment dirty swapcache pages (Requested by Intel
  for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_7c116f2b0dbac4a1dd051c7a5e8cef37701cafd4:
  HWPOISON: add fs/device filters (Requested by Intel for better
  MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_847ce401df392b0704369fd3f75df614ac1414b4:
  HWPOISON: Add unpoisoning support (Requested by Intel for
  better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_95d01fc664b9476e0d18e3d745bb209a42a33588:
  HWPOISON: remove the free buddy page handler (Requested by
  Intel for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_9b9a29ecd75e310f75a9243e1c3538ad34598fcb:
  HWPOISON: remove the anonymous entry (Requested by Intel for
  better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_d324236b3333e87c8825b35f2104184734020d35:
  memcg: add accessor to mem_cgroup.css (Requested by Intel for
  better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_d95ea51e3a7e9ee051d19f1dd283ca61d1aa5ec6:
  HWPOISON: make semantics of IGNORED/DELAYED clear (Requested
  by Intel for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_db0480b3a61bd6ad86ead3b8bbad094ab0996932:
  HWPOISON: comment the possible set_page_dirty() race (Requested
  by Intel for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_e42d9d5d47961fb5db0be65b56dd52fe7b2421f1:
  memcg: rename and export try_get_mem_cgroup_from_page()
  (Requested by Intel for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_f2c03debdfb387fa2e35cac6382779072b8b9209:
  HWPOISON: Remove stray phrase in a comment (Requested by Intel
  for better MCE/MCA testing).
- patches.fixes/mce_injection_enhancements_fe194d3e100dea323d7b2de96d3b44d0c067ba7a:
  HWPOISON: Use correct name for MADV_HWPOISON in documentation
  (Requested by Intel for better MCE/MCA testing).
* Fri Feb 12 2010 npiggin@suse.de
- patches.suse/SoN-05-reserve-slub.patch: Fix memory leak (bnc#554081)
* Fri Feb 12 2010 npiggin@suse.de
- patches.suse/slab-handle-memoryless-nodes-v2a.patch: Revert,
  preparing for reworked patch.
* Fri Feb 12 2010 jdelvare@suse.de
- supported.conf: saa7111 and saa7114 are gone.
* Thu Feb 11 2010 jkosina@suse.cz
- supported.conf:
  + ipt_recent has been renamed to xt_recent
  + ipt_hl and ipt_HL have been merged with v6 variant and renamed
    to xt_hl and xt_HL
* Thu Feb 11 2010 rw@suse.de
- Update config files, supported.conf:
  [ia64] Build cpe_migrate as module again.  (bnc#569606)
* Thu Feb 11 2010 jkosina@suse.cz
- patches.suse/suse-ppc64-branding: Make the message dependent on
  the booted kernel (regular vs. crashdump) (bnc#575884).
* Wed Feb 10 2010 jeffm@suse.com
- patches.suse/kdb-fix-kdb_cmds-to-include-the-arch-common-macro:
  kdb: fix kdb_cmds to include the arch common macro (bnc#578421).
* Wed Feb 10 2010 jbeulich@novell.com
- patches.xen/xen-x86_64-note-init-p2m: Refresh (bnc#578639).
* Wed Feb 10 2010 jbeulich@novell.com
- series.conf: Add forgotten patch.
* Wed Feb 10 2010 jeffm@suse.com
- patches.suse/kdb-handle-nonexistance-keyboard-controller: kdb:
  handle nonexistance keyboard controller (bnc#578051).
* Wed Feb 10 2010 gregkh@suse.de
- supported.conf: add vmxnet3 and vmw_pvscsi as supported drivers
* Wed Feb 10 2010 gregkh@suse.de
- patches.fixes/dvb-l64781.ko-broken-with-gcc-4.5.patch: dvb:
  l64781.ko broken with gcc 4.5.
* Tue Feb  9 2010 jeffm@suse.com
- patches.apparmor/apparmor-check-for-network-in-interrupt-and-work-around:
  apparmor: check for network in interrupt and work around
  (bnc#492961, bln#350789).
* Tue Feb  9 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.8 and c/s 993.
* Tue Feb  9 2010 jeffm@suse.com
- patches.fixes/fix-potential-crash-with-sys_move_pages: Fix
  potential crash with sys_move_pages (bnc#577753 CVE-2010-0415).
* Tue Feb  9 2010 gregkh@suse.de
- patch refresh fuzz due to stable kernel patch updates
* Tue Feb  9 2010 gregkh@suse.de
- Update to 2.6.32.8:
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/s390-07-01-zcrypt-errorhandling-of-872.patch
  - patches.arch/s390-07-02-dasd-dbf-null-pointer.patch
  - patches.arch/x86_node_hotplug_parse_srat_fix_2nd_ver.patch
  - patches.drivers/e1000-enhance-frame-fragment-detection.patch
  - patches.drivers/e1000e-enhance-frame-fragment-detection.patch
  - patches.fixes/iwlwifi_set_default_aggregation_frame_count_limit_to_31.patch
  - patches.fixes/kvm-adjust-kvmclock-offset.patch
  - patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch
* Tue Feb  9 2010 npiggin@suse.de
- patches.suse/x86-mark_rodata_rw.patch: fix x86-64 bug (bnc#575194)
  (folded patch attached in that bug).
* Tue Feb  9 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-66-idt-hp-mute-led-fix-polarity:
  ALSA: hda - Fix default polarity of mute-LED GPIO on 92HD83x/88x
  codecs (bnc#578190).
* Tue Feb  9 2010 sjayaraman@suse.de
- patches.fixes/sched-cpuacct-percpu-counter-batch.patch: sched:
  cpuacct: Use bigger percpu counter batch values for stats
  counters (bnc#575074).
- patches.fixes/sched-inline__percpu_counter_add.patch:
  percpu_counter: Make __percpu_counter_add an inline function
  on UP (bnc#575074).
* Mon Feb  8 2010 trenn@suse.de
- patches.fixes/x86_64_memory_hotplug_dev_mem.patch: memory
  hotplug: fix a bug on /dev/mem for 64-bit kernels (bnc#577771).
* Mon Feb  8 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-62-fix-hp-dv-mute-led: ALSA:
  hda - Fix mute led GPIO on HP dv-series notebooks (bnc#577927).
- patches.drivers/alsa-sp1-hda-63-idt-hp-mute-led-detect:
  ALSA: hda - Detect HP mute-LED GPIO setup from GPIO counts
  (bnc#577927).
- patches.drivers/alsa-sp1-hda-64-idt-hp-mute-led-cleanup: ALSA:
  hda - Merge HP mute-LED status callback on both IDT 92HD7x
  and 8x codecs (bnc#577927).
- patches.drivers/alsa-sp1-hda-65-idt-hp-mute-led-cleanup2:
  ALSA: hda - Remove static gpio_led setup via model (bnc#577927).
* Mon Feb  8 2010 tiwai@suse.de
- patches.drivers/synaptics-clickpad-area-param: Refresh.  Fixed
  the v-scroll area touch behavior.
* Mon Feb  8 2010 hare@suse.de
- patches.suse/blk-add-atomic-abort-flag: block: Implement
  REQ_ATOM_ABORT flag (bnc#527028).
- patches.suse/blk-queue-unprep-fn: block: Implement
  unprep_rq_fn() (bnc#527028).
* Mon Feb  8 2010 hare@suse.de
- patches.suse/fcoe-only-rmmod-fcoe-ko-if-no-active-connections:
  fcoe: Only rmmod fcoe.ko if there are no active connections
  (bnc#577529).
- patches.suse/libfc-call-ddp-setup-for-FCP-reads-only: libfc:
  call ddp setup for only FCP reads to avoid accessing junk fsp
  pointer (bnc#577529).
- patches.suse/libfc-don-t-assume-response-request-present:
  libfc: Don't assume response request present. (bnc#577529).
- patches.suse/libfc-fix-e_d_tov-ns-ms-scaling: libfc: Fix
  e_d_tov ns -> ms scaling factor in PLOGI response (bnc#577529).
- patches.suse/libfcoe-send-port-lka-every-fip_vn_ka_period:
  libfcoe: Send port LKA every FIP_VN_KA_PERIOD
  secs. (bnc#577529).
* Mon Feb  8 2010 jbeulich@novell.com
- Update Xen patches (bnc#575199).
* Mon Feb  8 2010 hare@suse.de
- patches.drivers/lpfc-8.3.5.4-update: Add missing include.
* Mon Feb  8 2010 sjayaraman@suse.de
- patches.fixes/sched-cleanup-select_task_rq_fair: sched:
  Cleanup select_task_rq_fair() (bnc#567474).
- patches.fixes/sched-fix-vmark-regression: sched: Fix vmark
  regression on big machines (bnc#567474).
- patches.fixes/sched-more-generic_WAKE_AFFINE: sched: More
  generic WAKE_AFFINE vs select_idle_sibling() (bnc#567474).
* Mon Feb  8 2010 hare@suse.de
- patches.drivers/pmcraid-2.6.33-rc6-update: Backport fixes for
  pmcraid from 2.6.33 (bnc#577232).
* Mon Feb  8 2010 hare@suse.de
- patches.drivers/lpfc-8.3.5.4-update: Patch to update Emulex
  LPFC driver to 8.3.5.4 (bnc#577203).
* Sat Feb  6 2010 trenn@suse.de
- supported.conf:
* Sat Feb  6 2010 rjw@suse.de
- add patch patches.arch/x86-Limit-number-of-per-cpu-TSC-sync-messages.patch
  to series.conf (forgotten by mistake)
* Sat Feb  6 2010 mfasheh@suse.com
- patches.fixes/ocfs2-Fix-refcnt-leak-on-ocfs2_fast_follow_link-erro.patch:
  ocfs2: Fix refcnt leak on ocfs2_fast_follow_link() error path.
- patches.fixes/ocfs2-Sync-max_inline_data_with_xattr-from-tools.patch:
  ocfs2: Sync max_inline_data_with_xattr from tools..
- patches.fixes/ocfs2-dlm-Ignore-LVBs-of-locks-in-the-Blocked-list.patch:
  ocfs2/dlm: Ignore LVBs of locks in the Blocked list.
- patches.fixes/ocfs2-dlm-Print-more-messages-during-lock-migration.patch:
  ocfs2/dlm: Print more messages during lock migration.
- patches.fixes/ocfs2-fix-a-misleading-variable-name.patch:
  ocfs2: fix a misleading variable name.
- patches.fixes/ocfs2-trivial-Remove-trailing-whitespaces.patch:
  ocfs2/trivial: Remove trailing whitespaces.
* Fri Feb  5 2010 jbohac@suse.cz
- Update config files.CONFIG_IPV6=m even for desktop flavours.
  (bnc#561611)
* Fri Feb  5 2010 bphilips@suse.de
- patches.drivers/ixgbe-only-process-one-ixgbe_watchdog_task-at-a-time.patch:
  ixgbe: only process one ixgbe_watchdog_task at a
  time. (bnc#562046).
* Fri Feb  5 2010 coly.li@suse.de
- patches.suse/64bytes_lvb_len.diff: delete from repo and series.conf.
  Keep dlm lvb length to 32byte for clvm (bnc#573460)
* Fri Feb  5 2010 duwe@suse.de
- Update config files: build BSR into ppc kernel, not as module.
  (bnc#572381)
- patches.arch/ppc-pseries-ncpus-1: powerpc: Add static fields
  to ibm,client-architecture call (bnc#570909).
- patches.arch/ppc-pseries-ncpus-2: powerpc/pseries: Pass more
  accurate number of supported cores to firmware (bnc#570909).
* Fri Feb  5 2010 mmarek@suse.cz
- Watch a subset of the kabi for i386/pae.
* Fri Feb  5 2010 jkosina@suse.cz
- patches.drivers/support-pci-domains-in-aer-inject: add support
  for PCI domains to aer_inject (bnc#573565, FATE#306815).
* Fri Feb  5 2010 mmarek@suse.cz
- Update config files: set CONFIG_ENTERPRISE_SUPPORT everywhere.
* Fri Feb  5 2010 tiwai@suse.de
- patches.drivers/drm-i915-fix-crt-hotplug-hang: drm/i915:
  Fix lock-up during hotplug detection (bnc#575047).
* Fri Feb  5 2010 coly.li@suse.de
-  disable patches.suse/64bytes_lvb_len.diff in series.conf
* Fri Feb  5 2010 bphilips@suse.de
- patches.drivers/be2net-swap-only-first-2-fields-of-mcc_wrb.patch:
  be2net: swap only first 2 fields of mcc_wrb (bnc#556959).
- patches.drivers/benet-from-v2.6.32-to-8f47afe0.patch: benet:
  from v2.6.32 to 8f47afe0 (bnc#556959).
* Thu Feb  4 2010 tiwai@suse.de
- patches.drivers/synaptics-clickpad-area-param: input: synaptics
  - add clickpad_area parameter (bnc#567703).
* Thu Feb  4 2010 mmarek@suse.de
- rpm/find-provides, rpm/kernel-binary.spec.in: Remove the previous
  hack and set STRIP_KEEP_SYMTAB='*/vmlinux-*' instead to avoid
  stripping symbols from the ppc vmlinux image (bnc#572148).
* Thu Feb  4 2010 jslaby@suse.de
- patches.fixes/pci-hotplug-ibmphp-ebda-len.patch: PCI hotplug:
  ibmphp: read the length of ebda and map entire ebda region
  (bnc#570284).
* Thu Feb  4 2010 sjayaraman@suse.de
- patches.fixes/sched-cpuacct-percpu-counter-batch.patch: Hold this
  patch as this triggers build failure in non-SMP configs and until
  a cleaner fix has been proposed and accepted.
* Thu Feb  4 2010 knikanth@suse.de
- patches.fixes/dm-stripe-zero-stripes: dm-stripe: return -EINVAL
  if stripe count is zero (bnc#576312).
* Thu Feb  4 2010 npiggin@suse.de
- patches.suse/files-slab-rcu.patch: Delete (bnc#566332). Could be fixed
  but it seems to be causing other slowdowns in file lookup fastpaths
  unfortunately. Back to the drawing board!
* Thu Feb  4 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete iwlagn-2-6-27-kmp
  (bnc#559533).
* Thu Feb  4 2010 tiwai@suse.de
- supported.conf: mark snd-wss-lib unsupported
* Thu Feb  4 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-61-add-idt92hd88x-support2:
  ALSA: hda - Adding support for another IDT 92HD83XXX codec
  (bnc#569354).
* Thu Feb  4 2010 sjayaraman@suse.de
- patches.fixes/sched-cpuacct-percpu-counter-batch.patch: sched:
  cpuacct: Use bigger percpu counter batch values for stats
  counters (bnc#575074).
* Thu Feb  4 2010 bphilips@suse.de
- patches.drivers/cxgb3-add-memory-barriers.patch: cxgb3: add
  memory barriers (bnc#576277).
* Thu Feb  4 2010 bphilips@suse.de
- patches.drivers/qlge-0001-move-reset-from-eeh-io_resume-to-slot_reset.patch:
  qlge: Move reset from eeh io_resume to slot_reset. (bnc#575956).
- patches.drivers/qlge-0002-add-watchdog-timer.patch: qlge:
  Add watchdog timer. (bnc#575956).
- patches.drivers/qlge-0003-add-check-for-eeh-failure-when-closing-device.patch:
  qlge: Add check for eeh failure when closing
  device. (bnc#575956).
* Wed Feb  3 2010 tonyj@suse.de
- Update config files.  Remove FTRACE from all non-trace kernels.
  fourier.suse.de/mlarch/SuSE/kernel/2010/kernel.2010.01/msg00233.html
  Some trace relics remain since OPROFILE selects CONFIG_TRACING even
  though it appears only RING_BUFFER is needed (mainline commit d69d59f4)
* Wed Feb  3 2010 jbohac@suse.cz
- supported.conf: marked em_cmp supported (bnc#568130)
* Wed Feb  3 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: automatically install a matching
  - devel package if kernel-source is installed.
* Wed Feb  3 2010 jbeulich@novell.com
- Fix Xen config files.
* Wed Feb  3 2010 hare@suse.de
- patches.drivers/be2iscsi-beta4-update: Update Emulex UCNA Open
  iSCSI driver for SLES11 SP1 (bnc#568147).
* Tue Feb  2 2010 jjolly@suse.de
- patches.arch/s390-07-01-zcrypt-errorhandling-of-872.patch:
  zcrypt: Do not remove coprocessor for error 8/72
  (bnc#575181,LTC#59763).
- patches.arch/s390-07-02-dasd-dbf-null-pointer.patch: dasd: Fix
  null pointer in s390dbf and discipline checking (bnc#575181).
- patches.arch/s390-07-03-cio-fix-vary-handling.patch: cio:
  channel path vary operation has no effect (bnc#575181).
- patches.arch/s390-07-04-dasd_online_offline_race.patch: dasd:
  fix online/offline race (bnc#575181).
* Tue Feb  2 2010 jbeulich@novell.com
- Update Xen patches to c/s 989.
- Update Xen config files (compatibility down to Xen 3.2.0).
- patches.xen/xen-netback-generalize: Netback: Generalize
  static/global variables into 'struct xen_netbk'.
- patches.xen/xen-netback-kernel-threads: Use Kernel thread to
  replace the tasklet.
- patches.xen/xen-netback-multiple-tasklets: Netback: Multiple
  tasklets support.
- patches.xen/xen3-add-support-for-intel-cougar-point-chipset.patch:
  Intel Cougar Point PCH Support (FATE#308854 bnc#565845).
- patches.xen/xen3-x86_irq_setup_extra_ioapic_for_sci.patch:
  x86: fix sci on ioapic 1 (bnc#572661).
* Tue Feb  2 2010 jjolly@suse.de
- patches.drivers/ehca-no-disable-irq-in-tasklet.patch: ib/ehca:
  Do not turn off irqs in tasklet context (bnc#575073,LTC#59985).
* Tue Feb  2 2010 jjolly@suse.de
- patches.drivers/ehca-ib-qp-max-supported.patch: ib/ehca:
  allow access by query_qp() (bnc#575072,LTC#59986).
* Tue Feb  2 2010 rgoldwyn@suse.de
- patches.fixes/novfs-err_ptr-fix.diff: Oops in novfs:unlink_local
  (bnc#569071).
* Tue Feb  2 2010 jkosina@suse.cz
- patches.suse/suse-ppc64-branding: the message about crashed kernel
  doesn't make sense any more with CONFIG_CRASH_DUMP enabled by
  default (bnc#575884).
* Tue Feb  2 2010 trenn@suse.de
- patches.fixes/x86_irq_setup_extra_ioapic_for_sci.patch: x86:
  fix sci on ioapic 1 (bnc#572661).
* Mon Feb  1 2010 agruen@suse.de
- patches.suse/file-capabilities-disable-by-default.diff: Also
  support the file_caps=<0|1> command line option for
  compatibility.
* Mon Feb  1 2010 jkosina@suse.cz
- patches.arch/uv_determine_revision_id_of_node_controller_chip.patch:
  UV: determine revision id of the node controller chip
  (bnc#575396).
* Mon Feb  1 2010 jkosina@suse.cz
- patches.arch/uv_use_replicated_cachelines_to_read_rtc.patch:
  UV: Use replicated RTC cachelines with hub 2.0 (bnc#575409).
* Fri Jan 29 2010 gregkh@suse.de
- Update to 2.6.32.7
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.arch/s390-04-07-cio-fix-double-free.patch
  - patches.arch/s390-04-12-cio-avoid-panic.patch
  - patches.arch/s390-05-01-netiucv-tx-bytes.patch
  - patches.arch/x86_enable_tsc_sync_check_again.patch
  - patches.drivers/alsa-sp1-hda-01-select-ibexpeak-handler
  - patches.drivers/alsa-sp1-hda-46-realtek-slave-sws-fix
  - patches.drivers/alsa-sp1-hda-51-fix-maxdata-obook4-quirk
  - patches.drivers/qlge-0002-Remove-explicit-setting-of-PCI-Dev-CTL-reg.patch
  - patches.drivers/qlge-0004-Add-handler-for-DCBX-firmware-event.patch
  - patches.drivers/qlge-0008-Don-t-fail-open-when-port-is-not-initialized.patch
  - patches.drivers/qlge-0024-Bonding-fix-for-mode-6.patch
  - patches.drivers/watchdog-iTCO_wdt-Add-support-for-Intel-Ibex-Peak.patch
  - patches.fixes/PCI-Always-set-prefetchable-base-limit-upper32-registers.patch
  - patches.fixes/bug-562290-Fix-isolcpus-boot-option.patch
  - patches.fixes/fc-transport-remove-BUG_ON
  - patches.fixes/hid-fixup-ncr-quirk.patch
  - patches.fixes/ipc-ns-fix-memory-leak-idr.patch
  - patches.fixes/iscsi-class-modify-handling-of-replacement-time
  - patches.fixes/libfc-remote-port-gets-st
  - patches.fixes/lpfc-ia64-hang
  - patches.fixes/md-start_ro-fix
  - patches.fixes/nfs-honour-server-preferred-io-size
  - patches.fixes/nfsd-acl.patch
  - patches.fixes/nohz_prevent_clocksource_wrapping_during_idle.patch
  - patches.fixes/pci_aer_mce_inject_check_osc_for_aer.patch
  - patches.fixes/sched-recalculate-tunables-on-hot-add-remove
  - patches.fixes/scsi-devinfo-update-hitachi-entries
  - patches.fixes/scsi_dh-always-attach-sysfs
  - patches.fixes/timers-init-Limit-the-number-of-per-cpu-calibration-bootup-messages.patch
  - patches.suse/fcoe-fix-checking-san-mac-address.patch
  - patches.suse/fcoe-fix-getting-san-mac-for-vlan-interface.patch
  - patches.suse/fcoe-initialize-return-value-in-fcoe_destroy.patch
  - patches.suse/fcoe-libfc-fix-an-libfc-issue-with-queue-ramp-down-in-libfc.patch
  - patches.suse/fcoe-remove-redundant-checking-of-netdev-netdev_ops.patch
  - patches.suse/libfc-don-t-warn_on-in-lport_timeout-for-reset-state.patch
  - patches.suse/libfc-fix-ddp-in-fc_fcp-for-0-xid.patch
  - patches.suse/libfc-fix-frags-in-frame-exceeding-skb_max_frags-in-fc_fcp_send_data.patch
  - patches.suse/libfc-fix-free-of-fc_rport_priv-with-timer-pending.patch
  - patches.suse/libfc-fix-memory-corruption-caused-by-double-frees-and-bad-error-handling.patch
  - patches.suse/libfc-fix-typo-in-retry-check-on-received-prli.patch
  - patches.suse/libfc-fix-wrong-scsi-return-status-under-fc_data_undrun.patch
  - patches.suse/libfc-lport-fix-minor-documentation-errors.patch
* Fri Jan 29 2010 trenn@suse.de
- patches.fixes/acpi_NULL_check_scan_bus.patch: acpi: Add NULL
  pointer check in acpi_bus_start (bnc#573401).
* Fri Jan 29 2010 trenn@suse.de
- patches.fixes/iwlwifi_set_default_aggregation_frame_count_limit_to_31.patch:
  iwlwifi: set default aggregation frame count limit to 31
  (Requested by Intel).
* Fri Jan 29 2010 agraf@suse.de
- patches.fixes/kvm-adjust-kvmclock-offset.patch: KVM: allow
  userspace to adjust kvmclock offset (bnc#570320).
* Fri Jan 29 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-60-add-idt92hd88x-support: ALSA:
  hda - Add support for IDT 92HD88 family codecs (bnc#569354).
* Fri Jan 29 2010 jkosina@suse.cz
- patches.fixes/pci-fix-nested-spinlock-hang-in-aer_inject.patch:
  update Patch-mainline tag.
* Fri Jan 29 2010 jkosina@suse.de
- Update config files: enable MMU_NOTIFIER for ia64 (bnc#573803).
* Fri Jan 29 2010 bphilips@suse.de
- patches.drivers/bnx2-v2.6.32-to-b746656.patch: bnx2: v2.6.32
  to b746656 (bnc#564635).
* Thu Jan 28 2010 gregkh@suse.de
- Update config files.
  CONFIG_EFI_VARS=y for x86-64 and ia64 (bnc#574771)
* Thu Jan 28 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-59-idt92hd83xxx-hp-mute-led: ALSA:
  hda - Add mute LED check for HP laptops with IDT 92HD83xxx codec
  (bnc#569354).
* Thu Jan 28 2010 mmarek@suse.cz
- rpm/apply-patches: Add support for an additional series file in
  patches.addon/series, this will be applied after the main series.
* Thu Jan 28 2010 mmarek@suse.cz
- rpm/apply-patches: put the patch loops from kernel-binary.spec.in
  and kernel-source.spec.in to one place.
* Wed Jan 27 2010 rjw@suse.de
- patches.arch/ACPI-Remove-repeated-registered-as-cooling_device-messages.patch:
  ACPI: Remove repeated registered as cooling_device messages
  (bnc#564618, FATE#306952).
* Wed Jan 27 2010 rjw@suse.de
- patches.arch/x86-ucode-amd-Load-ucode-patches-once-and-not-separately-of-each-CPU.patch:
  This patch has been removed from the mainline kernel due to regressions
  introduced by it.
  Delete.
* Wed Jan 27 2010 mfasheh@suse.com
- patches.fixes/ocfs2-Handle-O_DIRECT-when-writing-to-a-refcounted-c.patch:
  ocfs2: Handle O_DIRECT when writing to a refcounted cluster..
* Wed Jan 27 2010 jslaby@suse.de
- patches.suse/kdb-common: Fix hid crash (bnc#570591)
* Wed Jan 27 2010 jbeulich@novell.com
- Update EC2 config files.
* Wed Jan 27 2010 hare@suse.de
- patches.suse/dm-mpath-skip-disabled-devices-when-iterating:
  kernel Oops in multipathing after chchp -v 0 (bnc#570526).
* Wed Jan 27 2010 jkosina@suse.cz
- patches.fixes/pci-fix-nested-spinlock-hang-in-aer_inject.patch:
  pci: fix nested spinlock hang in aer_inject (bnc#573578).
* Wed Jan 27 2010 jjolly@suse.de
- needs_update:Cleaned up items listed under jjolly.
* Wed Jan 27 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-usb-01-avoid-oops-at-disconnect:
  ALSA: usb-audio - Avoid Oops after disconnect (bnc#565027).
* Tue Jan 26 2010 knikanth@suse.de
- supported.conf: Fix misspelt dm-region-hash and mark it supported
  correctly (bnc#565962)
* Mon Jan 25 2010 gregkh@suse.de
- Update to 2.6.32.6
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.drivers/8250_pnp-wacom-add
  - patches.drivers/staging-hv-fix-smp-problems-in-the-hyperv-core-code.patch
  - patches.kernel.org/scsi-enclosure-fix-oops-while-iterating-enclosure_status-array.patch
  - patches.kernel.org/x86-msr-cpuid-register-enough-minors-for-the-msr-and-cpuid-drivers.patch
* Mon Jan 25 2010 npiggin@suse.de
- patches.suse/slab-handle-memoryless-nodes-v2a.patch: slab -
  handle memoryless nodes V2a (bnc#436025, bnc#570492).
* Mon Jan 25 2010 trenn@suse.de
- Update config files.
- patches.arch/x86_mce_intel_decode_physical_address.patch: x86,
  mce: Xeon75xx specific interface to get corrected memory error
  information (bnc#573380, fate#307738).
- patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch:
  x86, mce: Xeon75xx specific interface to get corrected memory
  error information (bnc#573380, fate#307738).
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  x86, mce: Rename cpu_specific_poll to mce_cpu_specific_poll
  (bnc#573380, fate#307738).
- patches.xen/xen3-auto-arch-x86.diff: Refresh.
* Mon Jan 25 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-57-cx5051-toshiba-quirk:
  ALSA: hda - Add support for Toshiba Satellite M300
  (bnc#492233,bnc#565904).
- patches.drivers/alsa-sp1-hda-58-cx5051-lenovo-mute-fix: ALSA:
  hda - Change headphone pin control with master volume on cx5051
  (bnc#573050).
* Mon Jan 25 2010 trenn@suse.de
- patches.arch/x86_enable_tsc_sync_check_again.patch: x86:
  Reenable TSC sync check at boot, even with NONSTOP_TSC
  (bnc#573379).
* Mon Jan 25 2010 trenn@suse.de
- patches.arch/x86_node_hotplug_parse_srat_fix_2nd_ver.patch:
  x86: Set hotpluggable nodes in nodes_possible_map (bnc#567216).
- patches.arch/x86_node_hotplug_parse_srat_fix.patch: Delete.
* Mon Jan 25 2010 trenn@suse.de
- supported.conf:
  Add mce-inject and hwpoison-inject so that Intel can easier test
  this. As these are debug drivers, they might get reverted from
  support.conf again if kernel-extra package gets fixed for SLES,
  only seem to exist for SLED because "NCC is not yet working for SP1".
  (bnc#572552).
* Sat Jan 23 2010 bphilips@suse.de
- patches.drivers/tg3-updates-from-f4188d-to-ba5b0bf.patch: tg3:
  updates from f4188d to ba5b0bf (bnc#573237).
* Sat Jan 23 2010 rjw@suse.de
- patches.arch/x86-irq-check-move_in_progress-before-freeing-the-vector-mapping.patch:
  x86, irq: Check move_in_progress before freeing the vector
  mapping (bnc#558247).
* Sat Jan 23 2010 rjw@suse.de
- patches.arch/x86-apic-use-logical-flat-for-systems-with-8-or-fewer-logical-cpus.patch:
  x86, apic: use logical flat for systems with <= 8 logical cpus
  (bnc#567510).
- patches.arch/x86-revert-apic-Use-logical-flat-on-intel-with-8-or-fewer-logical-cpus.patch:
  x86: Revert "apic: Use logical flat on intel with <= 8 logical
  cpus" (bnc#567510).
* Sat Jan 23 2010 gregkh@suse.de
- Update to 2.6.32.5:
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.drivers/alsa-sp1-hda-54-alc861-capture-fix
  - patches.fixes/hid-add-device-ids-for-new-model-of-apple-wireless-keyboard
  - patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io
  - patches.fixes/reiserfs-truncate-blocks-not-used-by-a-write.patch
* Fri Jan 22 2010 tonyj@suse.de
- Update config files: drop UTRACE from default s390 configs
  as per communication from Ihno.
* Fri Jan 22 2010 gregkh@suse.de
- patches.kernel.org/x86-msr-cpuid-register-enough-minors-for-the-msr-and-cpuid-drivers.patch:
  x86, msr/cpuid: Register enough minors for the MSR and CPUID
  drivers (bnc#572720).
* Fri Jan 22 2010 gregkh@suse.de
- patches.kernel.org/scsi-enclosure-fix-oops-while-iterating-enclosure_status-array.patch:
  SCSI: enclosure: fix oops while iterating enclosure_status array
  (bnc#572818).
- patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array:
  Delete.
* Fri Jan 22 2010 duwe@suse.de
- Update config files.
- patches.arch/ppc-extended_h_cede-update-to-mainline: Incremental
  patch set to sync H_CEDE with actual mainline (bnc#550447,
  FATE#307059).
* Fri Jan 22 2010 trenn@suse.de
- Update config files.
  Add DMAR to -trace flavor -> get in sync with -default
* Fri Jan 22 2010 hare@suse.de
- patches.fixes/qla2xxx-restore-pci-state-after-eeh-recovery:
  Re-save PCI state after EEH recovery (bnc#570233).
* Fri Jan 22 2010 jjolly@suse.de
- patches.arch/s390-06-01-zfcp-introduce-bsg-timeout-callback.patch:
  zfcp: introduce BSG timeout callback (BNC#572659).
- patches.arch/s390-06-02-zfcp-set-hw-timeout-requested-by-bsg.patch:
  zfcp: set HW timeout requested by BSG request (BNC#572659).
* Fri Jan 22 2010 bphilips@suse.de
- patches.drivers/netxen-8f9b3f-to-c651a8.patch: netxen: 8f9b3f
  to c651a8 (bnc#572832).
* Fri Jan 22 2010 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh to
  newest version of patch.
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_KGDB=n
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_CRC_T10DIF=m for vanilla configs
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_CRC_T10DIF=m
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_EFI_VARS=m
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_RTC_LIB=m
  CONFIG_RTC_DRV_CMOS=m
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_VIDEO_OUTPUT_CONTROL=m
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_INPUT_FF_MEMLESS=m
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_LEDS_CLASS=m
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_EXT2_FS=m
  CONFIG_EXT3_FS=m
  CONFIG_FS_MBCACHE=m
  CONFIG_JBD=m
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_HID=m
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_I2C=m
  CONFIG_HWMON=m
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_MII=m
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_LIB80211=m
* Fri Jan 22 2010 gregkh@suse.de
- Update config files.
  CONFIG_X86_MSR=m
  CONFIG_X86_CPUID=m
* Thu Jan 21 2010 astarikovskiy@suse.de
- supported.conf: added power_meter driver (FATE #306959).
* Thu Jan 21 2010 tonyj@suse.de
- config.conf: add -trace flavor for s390* at Ihno's request
- Add more tracers to existing ppc64 trace config at IBM request
  Both related to FATE# 307051.
- patches.trace/ftrace-framepointer.diff: Delete.
* Thu Jan 21 2010 hare@suse.de
- patches.fixes/scsi-fc-class-allow-LLD-bsg-timeout:
  scsi_transport_fc: Allow LLD to reset FC BSG timeout
  (bnc#572658).
* Thu Jan 21 2010 jbeulich@novell.com
- patches.xen/xen-privcmd-mmap-batch-clear: privcmd: mmapbatch-v2
  fixes.
* Thu Jan 21 2010 hare@suse.de
- patches.drivers/lpfc-8.3.5-update: lpfc update to 8.3.5
  (bnc#572427).
- patches.drivers/lpfc-8.3.5.3-update: lpfc driver update to
  8.3.5.3 (bnc#572427).
* Thu Jan 21 2010 hare@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Update headers for series2git.
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Update headers for series2git.
* Wed Jan 20 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh. More updates and
  clean-up by Egbert (bnc#570082)
* Wed Jan 20 2010 jkosina@suse.cz
- patches.drivers/add-support-for-intel-cougar-point-chipset.patch:
  Intel Cougar Point PCH Support (FATE#308854 bnc#565845).
* Wed Jan 20 2010 jslaby@suse.de
- patches.drivers/bnx2x-backports-v2.6.32-to-af901ca.patch:
  Refresh.
  (change firmwares in makefile)
* Wed Jan 20 2010 jslaby@suse.de
- patches.suse/rlim-0006-PPC-use-helpers-for-rlimits.patch: Refresh.
- patches.suse/rlim-0007-S390-use-helpers-for-rlimits.patch: Refresh.
* Wed Jan 20 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.4 and c/s 984.
- Update Xen config files.
* Wed Jan 20 2010 bphilips@suse.de
- patches.drivers/bnx2i-backport-from-v2.6.32-to-45ca38e.patch:
  bnx2i: Backport from v2.6.32 to 45ca38e (bnc#564640).
- patches.drivers/bnx2x-backports-v2.6.32-to-af901ca.patch:
  bnx2x: backports v2.6.32 to af901ca (bnc#564638).
- patches.drivers/cnic-backport-from-v2.6.32-4e9c4f.patch: cnic:
  backport from v2.6.32-4e9c4f (bnc#564640).
* Wed Jan 20 2010 gregkh@suse.de
- Update config files.  2.6.32.4 changed one of them.
* Tue Jan 19 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh.  Fixed the text area
  calculation, and added the upscaling (bnc#570082).
* Tue Jan 19 2010 gregkh@suse.de
- Patch refresh for fuzz due to upstream -stable additions.
* Tue Jan 19 2010 gregkh@suse.de
- Update to 2.6.32.4
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.arch/module-handle-ppc64-relocating-kcrctabs-when-config_relocatable-y
  - patches.drivers/alsa-sp1-hda-53-alc861vd-capture-fix
  - patches.fixes/audit_untag_chunk.patch
  - patches.fixes/quota-fix-reserved-space-management-for-ordinary-fs.patch
  - patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1
* Tue Jan 19 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-55-alc259-hp-pin-fix: ALSA: hda -
  Fix parsing pin node 0x21 on ALC259 (bnc#571879).
- patches.drivers/alsa-sp1-hda-56-realtek-eapd-fix: ALSA: hda -
  Turn on EAPD only if available for Realtek codecs (bnc#571879).
* Tue Jan 19 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh.  Fix the hang-up with
  resolution changes (bnc#570082)
* Tue Jan 19 2010 jkosina@suse.cz
- supported.conf: added aesni-intel (bnc#566618 FATE#304209).
* Tue Jan 19 2010 jkosina@suse.cz
- Update config files: set CONFIG_CRYPTO_HMAC=y to avoid
  regression from SLE11 (bnc#571501).
* Tue Jan 19 2010 jack@suse.de
- patches.fixes/reiserfs-truncate-blocks-not-used-by-a-write.patch:
  reiserfs: truncate blocks not used by a write (bnc#483375).
* Mon Jan 18 2010 jeffm@suse.de
- patches.suse/smtnice-disable: Delete (obsolete).
* Mon Jan 18 2010 jeffm@suse.com
- Disabled custom ACPI table loading from initramfs again.
* Mon Jan 18 2010 jeffm@suse.com
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  Refresh.
* Mon Jan 18 2010 trenn@suse.de
- patches.arch/x86_node_hotplug_parse_srat_fix.patch:
  x86/mm/srat_64.c: nodes_parsed should include all nodes detected
  by ACPI (bnc#567140).
* Mon Jan 18 2010 hare@suse.de
- patches.fixes/aic79xx-null-scb-in-nonpkt-busfree: aic79xx: check
  for non-NULL scb in ahd_handle_nonpkt_busfree (bnc#542568).
* Mon Jan 18 2010 nfbrown@suse.de
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  Refresh to fix 60 second delay. (bnc#568271)
* Sat Jan 16 2010 tonyj@suse.de
- patches.fixes/audit_untag_chunk.patch: fix braindamage in
  audit_tree.c untag_chunk() (bnc#556282).
* Sat Jan 16 2010 rjw@suse.de
- patches.xen/xen-x86-rename-display_cacheinfo-to-cpu_detect_cache_sizes.patch:
  x86: Rename display_cacheinfo() to cpu_detect_cache_sizes().
* Fri Jan 15 2010 gregkh@suse.de
- Update config files.
- patches.drivers/vmw_pvscsi-scsi-driver-for-vmware-s-virtual-hba.patch:
  vmw_pvscsi: SCSI driver for VMware's virtual HBA.
* Fri Jan 15 2010 jeffm@suse.com
- patches.fixes/hid-add-device-ids-for-new-model-of-apple-wireless-keyboard:
  HID: add device IDs for new model of Apple Wireless Keyboard
  (bnc#568231).
* Fri Jan 15 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.01.11.1-k8-update: qla2xxx
  driver update to 8.03.01.01.11.1-k8 (bnc#560415).
- patches.drivers/qla2xxx-8.03.01.02.11.1-k8-update: qla2xxx
  driver update to 8.03.01.02.11.1-k8 (bnc#570233).
- patches.drivers/lpfc-add-raywire-id: Delete.
- patches.drivers/qla2xxx-8.03.01-k7-update: Delete.
* Fri Jan 15 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.01.11.1-k8-update: qla2xxx
  driver update to 8.03.01.01.11.1-k8 (bnc#560415).
- patches.drivers/qla2xxx-8.03.01.02.11.1-k8-update: qla2xxx
  driver update to 8.03.01.02.11.1-k8 (bnc#570233).
- patches.drivers/lpfc-add-raywire-id: Delete.
- patches.drivers/qla2xxx-8.03.01-k7-update: Delete.
* Fri Jan 15 2010 trenn@suse.de
- patches.suse/kdb_dont_touch_i8042_early.patch: Avoid early
  hang when i8042 controller is missing (bnc#528811).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/reiser4-sync_inodes: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: Delete (obsolete).
* Fri Jan 15 2010 mfasheh@suse.com
- patches.fixes/Ocfs2-Let-ocfs2-support-fiemap-for-symlink-and-fast-.patch:
  Ocfs2: Let ocfs2 support fiemap for symlink and fast symlink..
- patches.fixes/Ocfs2-Should-ocfs2-support-fiemap-for-S_IFDIR-inode.patch:
  Ocfs2: Should ocfs2 support fiemap for S_IFDIR inode?.
- patches.fixes/ocfs-stop-using-do_sync_mapping_range.patch:
  ocfs: stop using do_sync_mapping_range.
- patches.fixes/ocfs2-Add-reflinked-file-s-inode-to-inode-hash-earil.patch:
  ocfs2: Add reflinked file's inode to inode hash eariler..
- patches.fixes/ocfs2-Find-proper-end-cpos-for-a-leaf-refcount-block.patch:
  ocfs2: Find proper end cpos for a leaf refcount block..
- patches.fixes/ocfs2-Set-i_nlink-properly-during-reflink.patch:
  ocfs2: Set i_nlink properly during reflink..
- patches.fixes/ocfs2-always-include-acl-support.patch: ocfs2:
  Always include ACL support.
- patches.fixes/ocfs2-cluster-Make-fence-method-configurable-v2.patch:
  ocfs2/cluster: Make fence method configurable - v2.
- patches.fixes/ocfs2-devel-remove-redundant-OCFS2_MOUNT_POSIX_ACL-c.patch:
  ocfs2-devel: remove redundant OCFS2_MOUNT_POSIX_ACL check
  in ocfs2_get_acl_nolock().
- patches.fixes/ocfs2-explicit-declare-uninitialized-var-in-user_clu.patch:
  ocfs2: explicit declare uninitialized var in
  user_cluster_connect().
- patches.fixes/ocfs2-make-acl-use-the-default.patch: ocfs2:
  Make acl use the default.
- patches.fixes/ocfs2-refcounttree.c-cleanup.patch: ocfs2:
  refcounttree.c cleanup..
- patches.fixes/ocfs2-replace-u8-by-__u8-in-ocfs2_fs.h.patch:
  ocfs2: replace u8 by __u8 in ocfs2_fs.h.
- patches.fixes/ocfs2-return-EAGAIN-instead-of-EAGAIN-in-dlm.patch:
  ocfs2: return -EAGAIN instead of EAGAIN in dlm.
- patches.fixes/ocfs2-set-MS_POSIXACL-on-remount.patch: ocfs2:
  Set MS_POSIXACL on remount.
- patches.fixes/ocfs2-trivial-Use-le16_to_cpu-for-a-disk-value-in-xa.patch:
  ocfs2/trivial: Use le16_to_cpu for a disk value in xattr.c.
- patches.fixes/ocfs2-trivial-Use-proper-mask-for-2-places-in-hearbe.patch:
  ocfs2/trivial: Use proper mask for 2 places in hearbeat.c.
- patches.suse/fiemap-Add-new-extent-flag-FIEMAP_EXTENT_SHARED.patch:
  fiemap: Add new extent flag FIEMAP_EXTENT_SHARED.
- patches.suse/ocfs2-Use-FIEMAP_EXTENT_SHARED.patch: ocfs2:
  Use FIEMAP_EXTENT_SHARED.
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Thu Jan 14 2010 rjw@suse.de
- patches.arch/x86-Limit-number-of-per-cpu-TSC-sync-messages.patch:
  x86: Limit number of per cpu TSC sync messages (bnc#564618,
  FATE#306952).
- patches.arch/x86-Limit-the-number-of-processor-bootup-messages.patch:
  x86: Limit the number of processor bootup messages (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-CPU-cache-size-output-for-non-Intel-too.patch:
  x86: Remove CPU cache size output for non-Intel too (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-enabling-x2apic-message-for-every-CPU.patch:
  x86: Remove enabling x2apic message for every CPU (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-the-CPU-cache-size-printks.patch: x86:
  Remove the CPU cache size printk's (bnc#564618, FATE#306952).
- patches.arch/x86-cpu-mv-display_cacheinfo-cpu_detect_cache_sizes.patch:
  x86, cpu: mv display_cacheinfo -> cpu_detect_cache_sizes
  (bnc#564618, FATE#306952).
- patches.arch/x86-ucode-amd-Load-ucode-patches-once-and-not-separately-of-each-CPU.patch:
  x86: ucode-amd: Load ucode-patches once and not separately of
  each CPU (bnc#564618, FATE#306952).
- patches.fixes/sched-Limit-the-number-of-scheduler-debug-messages.patch:
  sched: Limit the number of scheduler debug messages (bnc#564618,
  FATE#306952).
- patches.fixes/timers-init-Limit-the-number-of-per-cpu-calibration-bootup-messages.patch:
  timers, init: Limit the number of per cpu calibration bootup
  messages (bnc#564618, FATE#306952).
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/add-initramfs-file_read_write: Build fix.
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/supported-flag-enterprise: Refresh.
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/supported-flag-sysfs: Properly report proprietary modules
* Thu Jan 14 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: initramfs: add
  initramfs_{read,write} (bnc#568120).
- Re-enabled custom ACPI table loading from initramfs.
* Thu Jan 14 2010 trenn@suse.de
- Update config files.
  Enable CONFIG_CPU_FREQ_DEBUG as requested by HP.
  This one adds conditional printks which can be enabled via:
  cpufreq.debug=7
* Thu Jan 14 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-54-alc861-capture-fix: ALSA: hda -
  Fix missing capture mixer for ALC861/660 codecs (bnc#567340).
* Thu Jan 14 2010 mmarek@suse.de
- rpm/find-provides, rpm/kernel-binary.spec.in: really fix ppc
  symbol provides.
* Thu Jan 14 2010 rjw@suse.de
- patches.arch/UV-Expose-irq_desc-node-in-proc.patch: Expose the
  irq_desc node as /proc/irq/*/node. (bnc#566745, fate#306952).
* Wed Jan 13 2010 bphilips@suse.de
- patches.drivers/dmfe-tulip-Let-dmfe-handle-DM910x-except-for-SPARC-o.patch:
  dmfe/tulip: Let dmfe handle DM910x except for SPARC on-board
  chips (bnc#537016).
* Wed Jan 13 2010 jkosina@suse.cz
- patches.fixes/crypto-testmgr-fix-complain-about-lacking-test.patch:
  crypto: testmgr - Fix complain about lack test for internal
  used algorithm (bnc#568278 FATE#306883).
* Wed Jan 13 2010 mmarek@suse.cz
- patches.suse/bootsplash-keep-multiple-data: Keep multiple
  splash screens for KMS (bnc#570082).
- patches.suse/bootsplash-scaler: Add bootsplash image scaler
  (bnc#570082).
* Wed Jan 13 2010 mmarek@suse.de
- rpm/kernel-binary.spec.in, rpm/find-provides: extract exported
  symbols from /boot/vmlinux before the image is stripped (affects
  ppc).
* Wed Jan 13 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Avoid atomic op by introducing discarding flag instead
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Avoid atomic op by introducing discarding flag instead
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: rename to patches.rpmify/ppc-crashdump-typefix
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  kernel/signal.c: fix kernel information leak with
  print-fatal-signals=1 (bnc#569902).
* Tue Jan 12 2010 rjw@suse.de
- needs_update: Remove some patches that we've got through the
  upstream.
* Tue Jan 12 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-53-alc861vd-capture-fix: ALSA:
  hda - Fix ALC861-VD capture source mixer (bnc#568305).
* Tue Jan 12 2010 trenn@suse.de
- patches.fixes/nohz_prevent_clocksource_wrapping_during_idle.patch:
  nohz: Prevent clocksource wrapping during idle (bnc#569238).
* Tue Jan 12 2010 jack@suse.de
- patches.suse/readahead-request-tunables.patch: Update readahead
  and max_sectors tunables (bnc#548529).
* Tue Jan 12 2010 jkosina@suse.cz
- patches.drivers/watchdog-iTCO_wdt-Add-support-for-Intel-Ibex-Peak.patch:
  iTCO_wdt: Add support for Intel Ibex Peak (bnc#557081
  FATE#308591).
* Tue Jan 12 2010 tonyj@suse.de
- needs_update: remove LTT/trace patches (assigned to jbl), all had
  already been taken care of by my fwd port to 2.6.32
* Tue Jan 12 2010 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k9-5.01.00.00.11.01-k10.patch:
  Fixup compilation error.
* Tue Jan 12 2010 rjw@suse.de
- patches.fixes/PCI-Always-set-prefetchable-base-limit-upper32-registers.patch:
  PCI: Always set prefetchable base/limit upper32 registers
  (bnc#569003).
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k9-5.01.00.00.11.01-k10.patch:
  Update qla4xxx driver for SLES11 SP1 (bnc#556572,FATE#307128).
* Mon Jan 11 2010 jblunck@suse.de
- needs_update: Removed some patches.
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/bfa-2.1.2.1-update: Update bfa driver to
  version 2.1.2.1 (bnc#561881).
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/fcoe-libfc-adds-enable-di: adds enable/disable
  for fcoe interface (bnc#562046).
- patches.fixes/fcoe-use-lld-s-wwpn-and-w: Use LLD's WWPN and
  WWNN for lport if LLD supports ndo_fcoe_get_wwn (bnc#562046).
- patches.fixes/libfc-reduce-hold-time-on: reduce hold time on
  SCSI host lock (bnc#562046).
- patches.fixes/libfc-remote-port-gets-st: remote port gets
  stuck in restart state without really restarting (bnc#562046).
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/mpt2sas-03.100.03.00-update: LSI mptsas2 driver
  update to 03.100.03.00 (bnc#566013).
* Mon Jan 11 2010 jbeulich@novell.com
- patches.xen/xen-x86_64-nx-user-mappings: Delete (bnc#568741).
- patches.xen/xen3-rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Delete.
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/qla4xxx-lun-reset-fix: Delete.
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/scsi-dh-rdac-add-ibm-174x: scsi_dh_rdac: Add
  two new IBM devices (bnc# 556159).
* Sat Jan  9 2010 jslaby@suse.de
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  Refresh.
- patches.suse/rlim-0002-resource-move-kernel-function-inside-__KERNEL__.patch:
  resource: move kernel function inside __KERNEL__ (FATE#305733).
- patches.suse/rlim-0003-resource-add-helpers-for-fetching-rlimits.patch:
  resource: add helpers for fetching rlimits (FATE#305733).
- patches.suse/rlim-0004-IA64-use-helpers-for-rlimits.patch:
  [IA64] use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0005-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  core: posix-cpu-timers, cleanup rlimits usage (FATE#305733).
- patches.suse/rlim-0006-PPC-use-helpers-for-rlimits.patch: PPC:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0007-S390-use-helpers-for-rlimits.patch:
  S390: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0008-SPARC-use-helpers-for-rlimits.patch:
  SPARC: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0009-X86-use-helpers-for-rlimits.patch: X86:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0010-FS-use-helpers-for-rlimits.patch: FS:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0011-MM-use-helpers-for-rlimits.patch: MM:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0012-core-use-helpers-for-rlimits.patch:
  core: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0013-infiniband-use-helpers-for-rlimits.patch:
  infiniband: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0014-ipc-use-helpers-for-rlimits.patch: ipc:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0015-SECURITY-add-task_struct-to-setrlimit.patch:
  SECURITY: add task_struct to setrlimit (FATE#305733).
- patches.suse/rlim-0016-core-add-task_struct-to-update_rlimit_cpu.patch:
  core: add task_struct to update_rlimit_cpu (FATE#305733).
- patches.suse/rlim-0017-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  sys_setrlimit: make sure ->rlim_max never grows (FATE#305733).
- patches.suse/rlim-0018-core-split-sys_setrlimit.patch: core:
  split sys_setrlimit (FATE#305733).
- patches.suse/rlim-0019-core-allow-setrlimit-to-non-current-tasks.patch:
  core: allow setrlimit to non-current tasks (FATE#305733).
- patches.suse/rlim-0020-core-optimize-setrlimit-for-current-task.patch:
  core: optimize setrlimit for current task (FATE#305733).
- patches.suse/rlim-0021-FS-proc-switch-limits-reading-to-fops.patch:
  FS: proc, switch limits reading to fops (FATE#305733).
- patches.suse/rlim-0022-FS-proc-make-limits-writable.patch:
  FS: proc, make limits writable (FATE#305733).
- patches.suse/rlim-0023-core-do-security-check-under-task_lock.patch:
  core: do security check under task_lock (FATE#305733).
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  Delete.
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  Delete.
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  Delete.
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: Delete.
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  Delete.
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  Delete.
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  Delete.
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  Delete.
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  Delete.
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  Delete.
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch: Delete.
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch: Delete.
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  Delete.
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  Delete.
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  Delete.
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  Delete.
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Delete.
  Sync with upstream. Drop limits syscalls altogether.
* Sat Jan  9 2010 jkosina@suse.cz
- patches.apparmor/apparmor.diff: Delete, as it is unused after
  splitup into smaller patches.
* Fri Jan  8 2010 sjayaraman@suse.de
- patches.suse/SoN-23-mm-swapfile.patch: Fix up the enum declaration
  to avoid conflict due to a upstream change.
* Fri Jan  8 2010 jkosina@suse.cz
- patches.fixes/quota-fix-reserved-space-management-for-ordinary-fs.patch:
  quota: fix reserved space management for ordinary fs.
* Fri Jan  8 2010 gregkh@suse.de
- patches.drivers/staging-hv-fix-smp-problems-in-the-hyperv-core-code.patch:
  Staging: hv: fix smp problems in the hyperv core code.
* Fri Jan  8 2010 jeffm@suse.de
- Disable set,getprlimit compat syscalls on xen.
* Fri Jan  8 2010 jeffm@suse.de
- Disabled custom ACPI table loading from initramfs until
  the scheduling while atomic issues are worked out.
* Fri Jan  8 2010 jeffm@suse.de
- Disabled set,getprlimit syscalls until the syscall numbers
  have been officially reserved.
* Fri Jan  8 2010 jeffm@suse.com
- patches.arch/module-handle-ppc64-relocating-kcrctabs-when-config_relocatable-y:
  module: handle ppc64 relocating kcrctabs when
  CONFIG_RELOCATABLE=y (bnc#566243).
* Thu Jan  7 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.3 and c/s 974.
- Update EC2 config files.
- patches.xen/xen3-x86-Remove-local_irq_enable-local_irq_disable-in-fixup_irqs.patch:
  x86: Remove local_irq_enable()/local_irq_disable() in
  fixup_irqs() (bnc#558247).
- patches.xen/xen3-x86-Unify-fixup_irqs-for-32-bit-and-64-bit-kernels.patch:
  x86: Unify fixup_irqs() for 32-bit and 64-bit kernels
  (bnc#558247).
- patches.xen/xen3-x86-intr-remap-Avoid-irq_chip-mask-unmask-in-fixup_irqs-for-intr-remapping.patch:
  x86, intr-remap: Avoid irq_chip mask/unmask in fixup_irqs()
  for intr-remapping (bnc#558247).
- patches.xen/xen-fix-compilation-after-rename_generic_int.patch:
  Delete.
- patches.xen/xen-scsifront-block-timeout-update: Delete.
- patches.xen/xen3-x86-fix-nodac: Delete.
* Thu Jan  7 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  e1000: enhance frame fragment detection (bnc#567376,
  CVE-2009-4536).
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  e1000e: enhance frame fragment detection (bnc#567376,
  CVE-2009-4538).
* Thu Jan  7 2010 gregkh@suse.de
- Update to 2.6.32.3
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/s390-04-03-dasd-diag-ro.patch
  - patches.drivers/alsa-sp1-hda-50-alc88x-missing-capsrc_nids
  - patches.fixes/qla2xxx-dpc-thread-can-execute-before-scsi-host
  - patches.fixes/scsi-ipr-fix-eeh-recovery
* Wed Jan  6 2010 rjw@suse.de
- patches.arch/x86-Force-irq-complete-move-during-cpu-offline.patch:
  x86: Force irq complete move during cpu offline (bnc#558247).
- patches.arch/x86-Remove-local_irq_enable-local_irq_disable-in-fixup_irqs.patch:
  x86: Remove local_irq_enable()/local_irq_disable() in
  fixup_irqs() (bnc#558247).
- patches.arch/x86-Remove-move_cleanup_count-from-irq_cfg.patch:
  x86: Remove move_cleanup_count from irq_cfg (bnc#558247).
- patches.arch/x86-Remove-unnecessary-mdelay-from-cpu_disable_common.patch:
  x86: Remove unnecessary mdelay() from cpu_disable_common()   .
- patches.arch/x86-Unify-fixup_irqs-for-32-bit-and-64-bit-kernels.patch:
  x86: Unify fixup_irqs() for 32-bit and 64-bit kernels
  (bnc#558247).
- patches.arch/x86-Use-EOI-register-in-io-apic-on-intel-platforms.patch:
  x86: Use EOI register in io-apic on intel platforms
  (bnc#558247).
- patches.arch/x86-intr-remap-Avoid-irq_chip-mask-unmask-in-fixup_irqs-for-intr-remapping.patch:
  x86, intr-remap: Avoid irq_chip mask/unmask in fixup_irqs()
  for intr-remapping (bnc#558247).
- patches.arch/x86-io-apic-Move-the-effort-of-clearing-remoteIRR-explicitly-before-migrating-the-irq.patch:
  x86, io-apic: Move the effort of clearing remoteIRR explicitly
  before migrating the irq (bnc#558247).
- patches.arch/x86-ioapic-Document-another-case-when-level-irq-is-seen-as-an-edge.patch:
  x86, ioapic: Document another case when level irq is seen as
  an edge (bnc#558247).
- patches.arch/x86-ioapic-Fix-the-EOI-register-detection-mechanism.patch:
  x86, ioapic: Fix the EOI register detection mechanism
  (bnc#558247).
* Wed Jan  6 2010 trenn@suse.de
- patches.fixes/pci_aer_mce_inject_check_osc_for_aer.patch: PCI:
  AER: fix aer inject result in kernel oops (bnc#566619).
* Wed Jan  6 2010 trenn@suse.de
- patches.fixes/PCIe-AER-reject-aer-inject-if-hardware-mask-error-reporting.patch:
  PCIe AER: reject aer inject if hardware mask error reporting
  (bnc#566621).
* Wed Jan  6 2010 gregkh@suse.de
- patches.xen/xen3-patch-2.6.29: Refresh due to conflicts from i915
  changes.  Ick, the xen code sucks rocks, it shouldn't be touching
  stuff here at all.
* Wed Jan  6 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  Refresh.
- patches.drivers/drm-i915-add-i915_lp_ring_sync-helper.patch:
  drm/i915: add i915_lp_ring_sync helper (bnc#568447).
- patches.drivers/drm-i915-fix-get_core_clock_speed-for-g33-class-desktop-chips.patch:
  drm/i915: fix get_core_clock_speed for G33 class desktop chips
  (bnc#568447).
- patches.drivers/drm-i915-fully-switch-off-overlay-when-not-in-use.patch:
  drm/i915: fully switch off overlay when not in use (bnc#568447).
- patches.drivers/drm-i915-implement-drmmode-overlay-support-v4.patch:
  drm/i915: implement drmmode overlay support v4 (bnc#568447).
- patches.drivers/drm-i915-implement-fastpath-for-overlay-flip-waiting.patch:
  drm/i915: implement fastpath for overlay flip waiting
  (bnc#568447).
* Wed Jan  6 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  Refresh.
* Tue Jan  5 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  drm/i915: Add ACPI OpRegion support for Ironlake (bnc#568436).
* Tue Jan  5 2010 tonyj@suse.de
- patches.fixes/oprofile_bios_ctr.patch: Update to newer version
* Mon Jan  4 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: move the x86 /boot/vmlinux-*.gz back
  to -base (bnc#563905).
* Wed Dec 30 2009 nfbrown@suse.de
- patches.fixes/nfs-fix-NFS4ERR_FILE_OPEN-handling:
  NFS4ERR_FILE_OPEN handling in Linux/NFS (bnc#526819).
* Mon Dec 28 2009 jeffm@suse.com
- patches.fixes/dmar-fix-oops-with-no-dmar-table: dmar: Fix oops
  with no DMAR table (bnc#548108).
* Sun Dec 27 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-52-hdmi-sticky-stream-tag: ALSA:
  hda - HDMI sticky stream tag support (FATE#306783).
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/xpc_first_contact_when_active.patch: X86: UV
  - xpc_make_first_contact hang due to not accepting ACTIVE
  state. (bnc#562288, fate#306952).
- patches.arch/xpc_fix_xpc_get_fifo_entry_uv.patch: x86: UV - XPC
  NULL deref when mesq becomes empty. (bnc#562288, fate#306952).
- patches.arch/xpc_introduce_xp_socket.patch: x86: UV - XPC
  needs to provide an abstraction for uv_gpa. (bnc#562288,
  fate #306952).
- patches.arch/xpc_pass_nasid_to_gru_create_message_queue.patch:
  UV - pass nasid instead of nid to gru_create_message_queue
  (bnc#562288, fate#306952).
- patches.arch/xpc_recv_msg_slots_wrap.patch: X86: UV - XPC
  receive message reuse triggers invalid BUG_ON(). (bnc#562288,
  fate#306952).
- patches.arch/xpc_uv_bios_changes.patch: x86: UV - Update XPC
  to handle updated BIOS interface. (bnc#562288, fate#306952).
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/bug-561989_gru_rollup.patch: SGI GRU Updates
  (bnc#561989, fate#306952).
* Wed Dec 23 2009 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: powerpc: use min_t in
  copy_oldmem_page.
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/bug-561946_uv_irq_affinity.patch: x86: SGI UV: Fix
  irq affinity for hub based interrupts (bnc#561946, fate#306952).
- patches.arch/bug-561946_uv_move_ioapic.patch: x86, apic: Move
  SGI UV functionality out of generic IO-APIC code (bnc#561946,
  fate#306952).
- patches.arch/bug-561946_uv_use_rtc.patch: x86: UV RTC: Always
  enable RTC clocksource (bnc#561946, fate#306952).
* Wed Dec 23 2009 jeffm@suse.com
- patches.fixes/ia64-fix-sba-iommu-to-handle-allocation-failure-properly:
  fix SBA IOMMU to handle allocation failure properly
  (bnc#545367).
* Tue Dec 22 2009 jeffm@suse.com
- Enabled CONFIG_CRASH_DUMP on ppc/ppc64 (bnc#566243).
* Tue Dec 22 2009 jeffm@suse.com
- patches.fixes/scsi-ipr-fix-eeh-recovery: ipr: fix EEH recovery
  (bnc#566613).
* Sun Dec 20 2009 trenn@suse.de
- Update config files.
- patches.drivers/cpufreq_ondemand_limit_fix.patch: cpufreq:
  Fix ondemand to not request targets outside policy limits
  (fate#306746).
- patches.drivers/cpufreq_processor_clocking_control_pcc_driver.patch:
  x86,cpufreq: Processor Clocking Control (PCC) driver
  (fate#306746).
- supported.conf:
* Sun Dec 20 2009 rjw@suse.de
- patches.arch/bug-561939_uv_bios_call_hwperf_updated.patch:
  x86, uv: Add serial number parameter to uv_bios_get_sn_info()
  (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_bios_call_hwperf.patch: Delete.
* Sat Dec 19 2009 jeffm@suse.com
- patches.fixes/scsi_debug-scale-virtual_gb-with-sector_size-properly:
  scsi_debug: scale virtual_gb with sector_size properly
  (bnc#535939).
* Sat Dec 19 2009 gregkh@suse.de
- patches.xen/xen3-fixup-xen: Refresh.  Fix up build error from
  .32.2 import
* Sat Dec 19 2009 gregkh@suse.de
- Update to 2.6.32.2
  - lots of security fixes
  - loads of bugfixes
  - other goodness
  - obsoletes:
  - patches.arch/bug-561939_bau_data_config.patch
  - patches.arch/bug-564471_x86_Fix_duplicated_UV_BAU_interrupt_vector.patch
  - patches.arch/s390-04-01-clear-high-regs.patch
  - patches.arch/s390-kvm-prefix.patch
  - patches.arch/s390-kvm-psw.patch
  - patches.arch/x86-fix-nodac
  - patches.arch/x86_mce_nfs-mig2
  - patches.fixes/firewire-ohci-handle-receive-packets-with-a-data-length-of-zero
  - patches.fixes/uart-txen-race.patch
* Fri Dec 18 2009 jeffm@suse.com
- Update config files: CONFIG_STRICT_DEVMEM=n. It was enabled
  mistakenly in commit 3df90f9e and affects using tools like
  crash with a live system.
* Fri Dec 18 2009 gregkh@suse.de
- Update config files.
  CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT = n (bnc#565607)
* Fri Dec 18 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-{24..51}-*: 2.6.33-rc1 backport
  fixes for HDMI and new Realtek codecs (FATE#306783)
- Refresh Patch-mainline tags in patches.drivers/alsa-*
* Fri Dec 18 2009 jjolly@suse.de
- patches.arch/s390-05-01-netiucv-tx-bytes.patch: netiucv:
  displayed TX bytes value much too high (BNC#565612).
- patches.arch/s390-05-02-cmm-suspend.patch: cmm: free pages on
  hibernate. (BNC#565612).
- patches.arch/s390-05-03-iucv-suspend.patch: iucv: add work_queue
  cleanup for suspend (BNC#565612).
- patches.arch/s390-05-04-zfcp-work-queue.patch: zfcp: Assign
  scheduled work to driver queue (BNC#565612).
- patches.arch/s390-05-05-zfcp-fail-commands.patch: zfcp: Don't
  fail SCSI commands when transitioning to blocked fc_rport
  (BNC#565612,LTC#58541).
- patches.arch/s390-05-06-zfcp-adisc.patch: zfcp: Improve ELS
  ADISC handling (BNC#565612).
- patches.arch/s390-05-07-zfcp-fsf-errors.patch: zfcp: Update
  FSF error reporting (BNC#565612).
- patches.arch/s390-05-08-zfcp-block.diff: zfcp: Block SCSI EH
  thread for rport state BLOCKED (BNC#565612).
- patches.arch/s390-05-09-ctcm-suspend-wait.diff: ctcm: suspend
  has to wait for outstanding I/O (BNC#565612).
- patches.arch/s390-05-10-rework-tso.diff: qeth: rework TSO
  functions (BNC#565612).
- patches.arch/s390-05-11-atomic-volatile.patch: kernel: improve
  code generated by atomic operations. (BNC#565612).
- patches.arch/s390-05-12-tape-remove-fn.patch: tape: incomplete
  device removal (BNC#565612).
- patches.arch/s390-05-13-qeth-blkt-defaults.patch: qeth:
  set default BLKT settings dependend on OSA hw level
  (BNC#565612,LTC#58654).
- patches.arch/s390-05-14-dasd-dasd-enable-prefix.patch: dasd:
  enable prefix independent of pav support (BNC#565612).
- patches.arch/s390-05-15-dasd-s390dbf-strings.patch: dasd:
  remove strings from s390dbf (BNC#565612).
- patches.arch/s390-05-16-dasd-wait-lcu-setup.patch: dasd:
  let device initialization wait for LCU setup (BNC#565612).
* Fri Dec 18 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix generating /boot/Kerntypes* for
  s390/vanilla.
* Fri Dec 18 2009 nfbrown@suse.de
- patches.fixes/md-start_ro-fix: md: fix small irregularity with
  start_ro module parameter (bnc#565219).
* Fri Dec 18 2009 rjw@suse.de
- patches.xen/xen-fix-compilation-after-rename_generic_int.patch:
  XEN: Fix compilation after renaming of generic_irqs.
* Fri Dec 18 2009 rjw@suse.de
- patches.arch/bug-561946_rename_generic_int.patch: x86: UV RTC:
  Rename generic_interrupt to x86_platform_ipi (bnc#561946,
  fate#306952).
* Thu Dec 17 2009 mmarek@suse.cz
- patches.suse/s390-Kerntypes.diff: S390: Generate Kerntypes file.
- rpm/kernel-binary.spec.in: install /boot/Kerntypes-$version.
* Thu Dec 17 2009 jeffm@suse.com
- patches.fixes/powerpc-fix-cpu-name-in-show-cpuinfo: powerpc:
  fix cpu name in show-cpuinfo (bnc#565267).
* Thu Dec 17 2009 hare@suse.de
- patches.fixes/fc-transport-remove-BUG_ON: scsi_transport_fc:
  remove invalid BUG_ON (bnc#564479).
- patches.fixes/lpfc-ia64-hang: lpfc: fix hang on SGI ia64
  platform (bnc#564479).
- patches.fixes/qla2xxx-dpc-thread-can-execute-before-scsi-host:
  qla2xxx: dpc thread can execute before scsi host has been added
  (bnc#564479).
- patches.suse/fc-transport-allow-dev_loss_tmo-disable: Remove
  capping from dev_loss_tmo (bnc#492469).
* Wed Dec 16 2009 gregkh@suse.de
- Update config files.
  - fix up CONFIG_IPV6 option that was built into the kernel
    incorrectly (bnc#564357)
* Wed Dec 16 2009 jeffm@suse.com
- patches.fixes/acpi-fix-build-when-config_acpi_custom_override_initramfs-is-not-defined:
  acpi: Fix build when CONFIG_ACPI_CUSTOM_OVERRIDE_INITRAMFS is
  not defined.
* Wed Dec 16 2009 jbeulich@novell.com
- Update Xen patches to c/s 960.
- Update Xen EC2 config files.
- patches.xen/xen3-bug-561933_uv_pat_is_gru_range.patch: x86:
  UV SGI: Don't track GRU space in PAT (bnc#561933, fate#306952).
- patches.xen/xen3-x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
* Wed Dec 16 2009 npiggin@suse.de
- needs_update:
- patches.fixes/aggressive-zone-reclaim.patch: be more aggressive
  with zone reclaims (bnc#476525).
* Wed Dec 16 2009 npiggin@suse.de
- needs_update:
- patches.suse/x86-mark_rodata_rw.patch: Refresh.
* Wed Dec 16 2009 npiggin@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
* Tue Dec 15 2009 jeffm@suse.com
- patches.fixes/firewire-ohci-handle-receive-packets-with-a-data-length-of-zero:
  firewire: ohci: handle receive packets with a data length of
  zero (bnc#564712 CVE-2009-4138).
* Tue Dec 15 2009 mmarek@suse.cz
- rpm/config.sh: set OBS_PROJECT and IBS_PROJECT variables for
  osc_wrapper.
* Tue Dec 15 2009 knikanth@suse.de
- supported.conf: Mark dm-log-userspace as supported (fate#307380).
* Tue Dec 15 2009 sjayaraman@suse.de
- patches.fixes/sched-recalculate-tunables-on-hot-add-remove:
  Fix the build failure due to previous commit.
* Tue Dec 15 2009 sjayaraman@suse.de
- patches.fixes/sched-recalculate-tunables-on-hot-add-remove:
  sched: Fix missing sched tunable recalculation on cpu add/remove
  (bnc#560317).
- patches.fixes/sched-make-tunable-scaling-configurable: sched:
  Make tunable scaling style configurable (bnc#560317).
- patches.fixes/sched-sysctl-for-normalized-tunables:  sched:
  Update normalized values on user updates via proc (bnc#560317).
* Tue Dec 15 2009 gregkh@suse.de
- Update config files.
  - make SCSI and ATA drivers modules again.
    (bnc#564357)
* Tue Dec 15 2009 gregkh@suse.de
- Update config files.
  - fix up USB options that were built into the kernel incorrectly
    (bnc#564357)
* Mon Dec 14 2009 jjolly@suse.de
- patches.arch/s390-04-01-clear-high-regs.patch: kernel:
  clear high-order bits after switching to 64-bit mode
  (BNC#563999,LTC#58088).
- patches.arch/s390-04-02-zcrypt-hrtimer.patch: zcrypt: Do not
  simultaneously schedule hrtimer (BNC#563999,LTC#58222).
- patches.arch/s390-04-03-dasd-diag-ro.patch: dasd: support DIAG
  access for read-only devices (BNC#563999,LTC#57147).
- patches.arch/s390-04-04-mm-fault-fix.patch: kernel: performance
  counter fix and page fault optimization (BNC#563999).
- patches.arch/s390-04-05-sclp-dump-indicator.patch: kernel:
  fix dump indicator (BNC#563999).
- patches.arch/s390-04-06-dasd-move-diag-kmsg.patch: dasd:
  move diag kmsg to generic dasd kmsg (BNC#563999).
- patches.arch/s390-04-07-cio-fix-double-free.patch: cio: double
  free under memory pressure (BNC#563999).
- patches.arch/s390-04-08-cio-fix-dev-stall.patch: cio: device
  recovery stalls after multiple hardware events (BNC#563999).
- patches.arch/s390-04-09-cio-recover-hw-changes.patch: cio:
  device recovery fails after concurrent hardware changes
  (BNC#563999).
- patches.arch/s390-04-10-cio-fix-onoffline-failure.patch: cio:
  setting a device online or offline fails for unknown reasons
  (BNC#563999).
- patches.arch/s390-04-11-cio-error-reporting.patch: cio:
  incorrect device state after device recognition and recovery
  (BNC#563999).
- patches.arch/s390-04-12-cio-avoid-panic.patch: cio: kernel
  panic after unexpected interrupt (BNC#563999).
- patches.arch/s390-04-13-cio-internal-io.patch: cio:
  initialization of I/O devices fails (BNC#563999).
- patches.arch/s390-04-14-cio-allow-offline.patch: cio: not
  operational devices cannot be deactivated (BNC#563999).
- patches.arch/s390-04-15-cio-split-pgid.patch: cio: erratic
  DASD I/O behavior (BNC#563999).
- patches.arch/s390-04-16-cio-path-verification.patch: cio:
  DASD cannot be set online (BNC#563999).
- patches.arch/s390-04-17-cio-steal-lock.patch: cio: DASD steal
  lock task hangs (BNC#563999).
- patches.arch/s390-04-18-cio-fix-memleak-chk-dev.patch: cio:
  memory leaks when checking unusable devices (BNC#563999).
- patches.arch/s390-04-19-cio-fix-deact-dev-panic.patch: cio:
  deactivated devices can cause use after free panic (BNC#563999).
* Mon Dec 14 2009 rjw@suse.de
- patches.arch/bug-561933_uv_pat_is_gru_range.patch: x86: UV SGI:
  Don't track GRU space in PAT (bnc#561933, fate#306952).
- patches.arch/bug-561939_bau_data_config.patch: x86: SGI UV
  BAU initialization (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_bios_call_hwperf.patch: x86: UV
  hardware performance counter and topology access  (bnc#561939,
  fate#306952).
- patches.arch/bug-561939_uv_gpa_is_mmr_space.patch: x86: UV -
  Introduce uv_gpa_is_mmr. (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_gpa_to_soc_phys_ram.patch:
  x86: UV - Introduce a means to translate from gpa ->
  socket_paddr. (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_ipi_macro.patch: x86: UV: Introduce
  uv_hub_ipi_value (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_mmap_low.patch: x86: SGI UV: Map
  low MMR ranges (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_cleanup.patch: x86: UV RTC:
  Clean up error handling (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_fixes.patch: x86: UV RTC:
  Fix early expiry handling  (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_setup_evt.patch: x86: UV RTC:
  Add clocksource only boot option (bnc#561939, fate#306952).
- patches.arch/bug-564471_x86_Fix_duplicated_UV_BAU_interrupt_vector.patch:
  x86: Fix duplicated UV BAU interrupt vector (bnc#564471).
* Mon Dec 14 2009 gregkh@suse.de
- Refresh patches to be clean of fuzz
* Mon Dec 14 2009 gregkh@suse.de
- Update to 2.6.32.1
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.fixes/ext4-fix-insufficient-checks-in-ext4_ioc_move_ext
  - patches.fixes/scsi-fix-bug-with-dma-maps-on-nested-scsi-objects
* Mon Dec 14 2009 jjolly@suse.de
- patches.drivers/dcb-data-center-bridging-ops-s: dcb: data
  center bridging ops should be r/o (BNC#562046).
- patches.drivers/drivers-net-request_irq-remove: drivers/net:
  request_irq - Remove unnecessary leading & from second arg
  (BNC#562046).
- patches.drivers/ethtool-add-direct-attach-supp: ethtool: Add
  Direct Attach support to connector port reporting (BNC#562046).
- patches.drivers/ixgbe-add-support-for-82599-al: ixgbe: Add
  support for 82599 alternative WWNN/WWPN prefix (BNC#562046).
- patches.drivers/ixgbe-add-support-for-82599-ba: ixgbe: add
  support for 82599 based Express Module X520-P2 (BNC#562046).
- patches.drivers/ixgbe-add-support-for-netdev_o: ixgbe: Add
  support for netdev_ops.ndo_fcoe_get_wwn to 82599 (BNC#562046).
- patches.drivers/ixgbe-change-default-ring-size: ixgbe: change
  default ring size (BNC#562046).
- patches.drivers/ixgbe-disable-flow-control-for: ixgbe: Disable
  Flow Control for certain devices (BNC#562046).
- patches.drivers/ixgbe-display-currently-attach: ixgbe: Display
  currently attached PHY through ethtool (BNC#562046).
- patches.drivers/ixgbe-fix-erroneous-display-of: ixgbe: Fix
  erroneous display of stats by ethtool -S (BNC#562046).
- patches.drivers/ixgbe-fix-kr-to-kx-fail-over-f: ixgbe: Fix KR
  to KX fail over for Mezzanine cards (BNC#562046).
- patches.drivers/ixgbe-fix-receive-address-regi: ixgbe:
  Fix Receive Address Register (RAR) cleaning and accounting
  (BNC#562046).
- patches.drivers/ixgbe-flush-the-lsc-mask-chang: ixgbe: Flush
  the LSC mask change to prevent repeated interrupts (BNC#562046).
- patches.drivers/ixgbe-handle-parameters-for-tx: ixgbe: handle
  parameters for tx and rx EITR, no div0 (BNC#562046).
- patches.drivers/ixgbe-links2-is-not-a-valid-re: ixgbe: LINKS2
  is not a valid register for 82598 (BNC#562046).
- patches.drivers/ixgbe-make-queue-pairs-on-sing: ixgbe: Make
  queue pairs on single MSI-X interrupts (BNC#562046).
- patches.drivers/ixgbe-modify-82599-hwrsc-stati: ixgbe: Modify
  82599 HWRSC statistics counters (BNC#562046).
- patches.drivers/ixgbe-only-set-clear-vfe-in-ix: ixgbe: Only
  set/clear VFE in ixgbe_set_rx_mode (BNC#562046).
- patches.drivers/ixgbe-performance-tweaks: ixgbe: performance
  tweaks (BNC#562046).
- patches.drivers/ixgbe-r_idx-not-used-in-ixgbe_: ixgbe: r_idx
  not used in ixgbe_msix_clean_rx() (BNC#562046).
- patches.drivers/ixgbe-select-fcoe-tx-queue-in-: ixgbe: select
  FCoE Tx queue in ndo_select_queue (BNC#562046).
- patches.drivers/ixgbe-use-eiam-to-automask-msi: ixgbe: use
  EIAM to automask MSI-X (BNC#562046).
- patches.drivers/ixgbe-use-known-user-priority-: ixgbe: use
  known user priority for FCoE when DCB is enabled (BNC#562046).
- patches.drivers/ixgbe-use-rx-buffer-length-fro: ixgbe: Use rx
  buffer length from rx ring for configuring rscctl (BNC#562046).
- patches.drivers/ixgbe-use-the-instance-of-net_: ixgbe: Use
  the instance of net_device_stats from net_device. (BNC#562046).
- patches.drivers/net-add-ndo_fcoe_get_wwn-to-ne: net: Add
  ndo_fcoe_get_wwn to net_device_ops (BNC#562046).
- patches.drivers/net-add-netdev_alloc_skb_ip_al: net: Add
  netdev_alloc_skb_ip_align() helper (BNC#562046).
- patches.drivers/net-use-netdev_alloc_skb_ip_al: net: Use
  netdev_alloc_skb_ip_align() (BNC#562046).
- patches.drivers/vlan-add-support-to-netdev_ops: vlan:
  Add support to netdev_ops.ndo_fcoe_get_wwn for VLAN device
  (BNC#562046).
- patches.fixes/fcoe-allow-scsi-fcp-to-be: fcoe: allow SCSI-FCP
  to be processed directly in softirq context (BNC#562046).
- patches.fixes/fcoe-libfc-add-get_lesb-t: fcoe, libfc: add
  get_lesb() to allow LLD to fill the link error status block
  (LESB) (BNC#562046).
- patches.fixes/libfc-add-fc-bb-5-lesb-co: libfc: add FC-BB-5
  LESB counters to fcoe_dev_stats (BNC#562046).
- patches.fixes/libfc-add-fcoe_fc_els_les: libfc: add
  fcoe_fc_els_lesb to fc_fcoe.h for FC-BB-5 LESB definitions
  (BNC#562046).
- patches.fixes/libfc-add-support-of-rece: libfc: add support
  of receiving ELS_RLS (BNC#562046).
- patches.fixes/libfc-add-target-reset-fl: libfc: Add target
  reset flag to FCP header file (BNC#562046).
- patches.fixes/libfc-fix-payload-size-pa: libfc: fix payload size
  passed to fc_frame_alloc() in fc_lport_els_request (BNC#562046).
- patches.fixes/libfcoe-add-checking-disa: libfcoe: add checking
  disable flag in FIP_FKA_ADV (BNC#562046).
- patches.fixes/libfcoe-add-tracking-fip-: libfcoe: add tracking
  FIP Missing Discovery Advertisement count (BNC#562046).
- patches.fixes/libfcoe-add-tracking-fip--0: libfcoe: add tracking
  FIP Virtual Link Failure count (BNC#562046).
* Mon Dec 14 2009 mmarek@suse.cz
- rpm/kabi.pl: Do not print harmless kabi changes by default.
* Mon Dec 14 2009 sjayaraman@suse.de
- patches.suse/sched-revert-latency-defaults: Revert sched
  latency defaults and turn FAIR_SLEEPERS off (bnc#557307).
* Mon Dec 14 2009 jkosina@suse.cz
- patches.fixes/uart-txen-race.patch: Serial: Do not read IIR in
  serial8250_start_tx when UART_BUG_TXEN (bnc#479304 bnc#509066).
* Sun Dec 13 2009 rjw@suse.de
- patches.fixes/bug-562290-Fix-isolcpus-boot-option.patch: sched:
  Fix isolcpus boot option (bnc#562290, fate#306952).
* Fri Dec 11 2009 mmarek@suse.cz
- patches.suse/supported-flag: Fix -Wmissing-prototypes warnings
  in modpost.c.
* Fri Dec 11 2009 mmarek@suse.cz
- patches.rpmify/modpost-segfault: modpost: fix segfault with
  short symbol names.
* Fri Dec 11 2009 jeffm@suse.com
- Moved kernel-docs into the git repo. It is now built automatically
  with the matching kernel sources.
* Fri Dec 11 2009 trenn@suse.de
- patches.suse/kdb_fix_ia64_build.patch: Fix ia64 - Export
  kdb_usb_kbds (none).
* Fri Dec 11 2009 trenn@suse.de
  Jeff updated kdb, try without this ugly workaround.
  If it still does not work, I have something better...
- patches.suse/kdb_x86_fix_hang.patch: Delete.
* Fri Dec 11 2009 hare@suse.de
  Cleanup patches for series2git:
- patches.suse/kdb-common: Refresh.
- patches.suse/kdump-dump_after_notifier.patch: Refresh.
* Fri Dec 11 2009 trenn@suse.de
  Updated MCE/MCA patches from Andi -> delete the old ones:
- patches.arch/x86_mce_hwpoison-action_result-valid-pfn.patch:
  HWPOISON: return ENXIO on invalid page number (fate#307738).
- patches.arch/x86_mce_hwpoison-is-free-page.patch: HWPOISON:
  detect free buddy pages explicitly (fate#307738).
- patches.arch/x86_mce_hwpoison-no-double-ref.patch: HWPOISON:
  avoid grabbing the page count multiple times during madvise
  injection (fate#307738).
- patches.arch/x86_mce_madvise-locking: HWPOISON: Use
  get_user_page_fast in hwpoison madvise (fate#307738).
- patches.arch/x86_mce_nfs-mig2: NFS: Fix nfs_migrate_page()
  (fate#307738).
- patches.arch/x86_mce_offline-inject: HWPOISON: Add a madvise()
  injector for soft page offlining (fate#307738).
- patches.arch/x86_mce_page-offline: HWPOISON: Add soft page
  offline support (fate#307738).
- patches.arch/x86_mce_ref-to-flags: HWPOISON: Turn ref argument
  into flags argument (fate#307738).
- patches.arch/x86_mce_shake-page: HWPOISON: Be more aggressive
  at freeing non LRU caches (fate#307738).
- patches.arch/x86_mce_undef-lru: HWPOISON: Undefine short-hand
  macros after use to avoid namespace conflict (fate#307738).
- patches.arch/x86_mce_lru_cleanup.patch: Delete.
- patches.arch/x86_mce_page_offlining.patch: Delete.
- patches.arch/x86_mce_page_offlining_test_ability.patch: Delete.
- patches.arch/x86_mce_test_page.patch: Delete.
* Fri Dec 11 2009 hare@suse.de
- needs_update: Merge or delete remaining patches.
- patches.fixes/scsi-dh-emc-mode-select-10-size: DM-MPIO fails
  to tresspass LUNs on CLARiiON arrays (bnc#484529).
- patches.fixes/scsi-dh-emc-rw-mismatch: Server crashes when
  path failures occur against EMC storage (bnc#474482).
- patches.fixes/scsi-dh-rdac-add-stk: STK arrays missing from
  rdac devicehandler (bnc#503855).
- patches.fixes/scsi-retry-alua-transition-in-progress: I/O
  errors for ALUA state transitions (bnc#491289).
- patches.suse/dm-mpath-no-activate-for-offlined-paths: DM-MPIO
  fails to tresspass LUNs on CLARiiON arrays (bnc#484529).
- patches.suse/dm-mpath-no-partitions-feature: Disable partitions
  scan for multipathed devices (bnc#402922,bnc#514767).
* Fri Dec 11 2009 tiwai@suse.de
- Update config files: set back to CONFIG_SOUND=m
* Fri Dec 11 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-23-hp-mute-led-gpio-fixes:
  ALSA: hda - Fix LED GPIO setup for HP laptops with IDT codecs
  (bnc#547357,bnc#523487).
* Fri Dec 11 2009 jeffm@suse.de
- patches.suse/kdb-usb-rework: Fix ia64.
* Fri Dec 11 2009 jeffm@suse.com
- Update config files: Enable USB_SERIAL_DEBUG.
* Fri Dec 11 2009 jeffm@suse.com
- patches.suse/kdb-usb-rework: kdb: Cleanup KDB_USB.
* Fri Dec 11 2009 jeffm@suse.com
- Update config files.
  - Disabled USB_TEST and USB_LIBUSUAL.
* Thu Dec 10 2009 jeffm@suse.com
- Update config files. Re-enable missing options:
  - CONFIG_FRAMEBUFFER_CONSOLE_ROTATION=y
  - CONFIG_VIDEO_GO7007=m (and related options)
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/netxen-0008-reset-sequence-changes.patch:
  Refresh to fix fuzz
* Thu Dec 10 2009 jeffm@suse.com
- Updated KDB to v4.4-2.6.32-3 and re-enabled USB keyboard support.
* Thu Dec 10 2009 mmarek@suse.de
- rpm/kernel-binary.spec.in: Fix vmlinux stripping on power
  (bnc#559547)
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/netxen-0000-Use-the-instance-of-net_device_stats-from-net.patch:
  netxen: Use the instance of net_device_stats from
  net_device. (bnc#560003, fate#307134).
- patches.drivers/netxen-0001-remove-sub-64-bit-mem-accesses.patch:
  netxen: remove sub 64-bit mem accesses (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0002-add-access-to-on-chip-memory-for-tools.patch:
  netxen: add access to on chip memory for tools (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0003-annotate-register-windowing-code.patch:
  netxen: annotate register windowing code (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0004-separate-register-and-memory-access-lock.patch:
  netxen: separate register and memory access lock (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0005-add-sysfs-entries-for-diag-tools.patch:
  netxen: add sysfs entries for diag tools (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0006-defines-for-next-revision.patch:
  netxen: defines for next revision (bnc#560003, fate#307134).
- patches.drivers/netxen-0007-128-memory-controller-support.patch:
  netxen: 128 memory controller support (bnc#560003, fate#307134).
- patches.drivers/netxen-0008-reset-sequence-changes.patch:
  netxen: reset sequence changes (bnc#560003, fate#307134).
- patches.drivers/netxen-0009-onchip-memory-access-change.patch:
  netxen: onchip memory access change (bnc#560003, fate#307134).
- patches.drivers/netxen-0010-fix-error-codes-in-for-tools-access.patch:
  netxen: fix error codes in for tools access (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0011-sysfs-control-for-auto-firmware-recovery.patch:
  netxen: sysfs control for auto firmware recovery (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0012-update-version-to-4.0.62.patch:
  netxen; update version to 4.0.62 (bnc#560003, fate#307134).
- patches.drivers/netxen-0013-fix-builds-for-SYSFS-n-or-MODULES-n.patch:
  netxen: fix builds for SYSFS=n or MODULES=n (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0014-support-for-new-firmware-file-format.patch:
  netxen: support for new firmware file format (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0015-refactor-indirect-register-access.patch:
  netxen: refactor indirect register access (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0016-add-PCI-IDs-for-new-chip.patch:
  netxen: add PCI IDs for new chip (bnc#560003, fate#307134).
- patches.drivers/netxen-0017-update-module-info.patch: netxen:
  update module info (bnc#560003, fate#307134).
- patches.drivers/netxen-0018-module-firmware-hints.patch:
  netxen: module firmware hints (bnc#560003, fate#307134).
- patches.drivers/netxen-0019-update-version-to-4.0.65.patch:
  netxen: update version to 4.0.65 (bnc#560003, fate#307134).
- patches.drivers/netxen-0020-remove-PCI-IDs-of-CNA-device.patch:
  netxen: remove PCI IDs of CNA device (bnc#560003, fate#307134).
- patches.drivers/netxen-0021-fix-debug-tools-access-for-NX2031.patch:
  netxen : fix debug tools access for NX2031 (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0022-fix-failure-cases-for-fw-hang-recovery.patch:
  netxen: fix failure cases for fw hang recovery (bnc#560003,
  fate#307134).
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/qlge-0001-Use-the-instance-of-net_device_stats-from-net_.patch:
  qlge: Use the instance of net_device_stats from
  net_device. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0002-Remove-explicit-setting-of-PCI-Dev-CTL-reg.patch:
  qlge: Remove explicit setting of PCI Dev CTL reg. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0003-Set-PCIE-max-read-request-size.patch:
  qlge: Set PCIE max read request size. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0004-Add-handler-for-DCBX-firmware-event.patch:
  qlge: Add handler for DCBX firmware event. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0005-Store-firmware-revision-as-early-as-possible.patch:
  qlge: Store firmware revision as early as possible. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0006-Remove-inline-math-for-small-rx-buf-mapping.patch:
  qlge: Remove inline math for small rx buf mapping. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0007-Get-rid-of-firmware-handler-debug-code.patch:
  qlge: Get rid of firmware handler debug code. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0008-Don-t-fail-open-when-port-is-not-initialized.patch:
  qlge: Don't fail open when port is not initialized. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0009-Add-CBFC-pause-frame-counters-to-ethtool-stats.patch:
  qlge: Add CBFC pause frame counters to ethtool
  stats. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0010-Size-RX-buffers-based-on-MTU.patch:
  qlge: Size RX buffers based on MTU. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0011-Add-ethtool-get-set-pause-parameter.patch:
  qlge: Add ethtool get/set pause parameter. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0012-Add-ethtool-blink-function.patch:
  qlge: Add ethtool blink function. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0013-Add-ethtool-wake-on-LAN-function.patch:
  qlge: Add ethtool wake on LAN function. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0014-Add-ethtool-register-dump-function.patch:
  qlge: Add ethtool register dump function. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0015-Add-ethtool-self-test.patch: qlge:
  Add ethtool self-test. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0016-Change-naming-on-vlan-API.patch:
  qlge: Change naming on vlan API. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0017-Fix-indentations.patch: qlge: Fix
  indentations. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0018-Add-firmware-driver-sub-command-support.patch:
  qlge: Add firmware/driver sub-command support. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0019-Clean-up-netdev-stats-usage.patch:
  qlge: Clean up netdev->stats usage. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0020-Do-not-change-frame-routing-during-suspend.patch:
  qlge: Do not change frame routing during suspend. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0021-Add-asic-reset-to-open-call.patch:
  qlge: Add asic reset to open call. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0022-Clean-up-module-parameter-name.patch:
  qlge: Clean up module parameter name. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0023-Change-version-to-v1.00.00.23.00.00-01.patch:
  qlge: Change version to v1.00.00.23.00.00-01. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0024-Bonding-fix-for-mode-6.patch: qlge:
  Bonding fix for mode 6. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0025-Add-performance-change-for-non-split-headers.patch:
  qlge: Add performance change for non-split headers. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0026-Add-firmware-core-dump.patch: qlge:
  Add firmware core dump. (bnc#560420, FATE#307130).
* Thu Dec 10 2009 hare@suse.de
- needs_update: Delete more merged fixes.
- patches.suse/dm-mpath-leastpending-path-update: Refresh.
* Thu Dec 10 2009 hare@suse.de
- needs_update: Delete merged driver fixes.
- patches.drivers/megaraid-mbox-fix-SG_IO: megaraid_mbox: Oops
  on SG_IO (bnc#475619).
* Thu Dec 10 2009 duwe@suse.de
- Disable PHYP_DUMP for all PPC flavours, per bnc#541302.
* Thu Dec 10 2009 jbenc@suse.cz
- patches.suse/novfs-fix-debug-message.patch: novfs: fix debug
  message.
* Thu Dec 10 2009 hare@suse.de
- patches.fixes/tehuti-firmware-name: Tehuti network driver
  references wrong firmware (bnc#562092).
* Wed Dec  9 2009 tonyj@suse.de
- patches.suse/audit-export-logging.patch: fix section mismatch due to
  previous checkin
* Wed Dec  9 2009 tonyj@suse.de
- patches.suse/audit-export-logging.patch: export audit logging
  symbols.
* Wed Dec  9 2009 jbohac@suse.cz
- Update config files: added CONFIG_IP_NF_MATCH_IPV4OPTIONS
  to ppc64/trace
* Wed Dec  9 2009 jeffm@suse.com
- patches.fixes/ext4-fix-insufficient-checks-in-ext4_ioc_move_ext:
  ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT (bnc#561018
  CVE-2009-4131).
* Wed Dec  9 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.32: Fix a potentially serious mis-merge
  in swiotlb code.
* Wed Dec  9 2009 jjolly@suse.de
- patches.fixes/nohz-delay-from-tip.diff: nohz: Introduce
  arch_needs_cpu.
- patches.fixes/reuse-ktime-from-tip.diff: nohz: Reuse ktime in
  sub-functions of tick_check_idle..
- series.conf: Moved s390 patchs to proper place
* Wed Dec  9 2009 npiggin@suse.de
- patches.fixes/ipc-ns-fix-memory-leak-idr.patch: ipc: ns fix
  memory leak (bnc#518767).
- patches.fixes/ipc-remove-unreachable-code-in-semc.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-add-a-per-semaphore-pending-list.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-if-semops-fail.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-single-semop-operations.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-single-sops-when-semval-is-zero.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-sem-optimise-undo-list-search.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-sem-preempt-improve.patch:  (bnc#518767).
- patches.fixes/ipc-semc-sem-use-list-operations.patch:
  (bnc#518767).
* Wed Dec  9 2009 bphilips@suse.de
- needs_update: patches moved upstream or obsoleted by upstream
* Tue Dec  8 2009 mmarek@suse.cz
- patches.suse/kbuild-generate-modules.builtin: Update to what will
  hopefully be in 2.6.33.
- patches.suse/kbuild-rebuild-fix-for-Makefile.modbuiltin: Delete.
* Tue Dec  8 2009 jbohac@suse.cz
- Update config files.
- patches.suse/netfilter-ipv4options: netfilter ipv4options
  match from patch-o-matic-ng (bnc#131728 - FATE#182).
* Tue Dec  8 2009 npiggin@suse.de
- needs_update:
- patches.suse/mm-devzero-optimisation.patch: mm: /dev/zero
  optimisation (bnc#430738).
* Tue Dec  8 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-22-alc888-exclude-unusable-adcs:
  ALSA: hda - Exclude unusable ADCs for ALC88x (bnc#561235).
* Tue Dec  8 2009 mmarek@suse.cz
- patches.drivers/reenable-generic_serial: Revert "tty: Mark
  generic_serial users as BROKEN".
- Update config files: enable RIO and SX.
- rpm/generic_serial-blacklist: blacklist generic_serial users from
  automatic loading (bnc#551348).
* Tue Dec  8 2009 rgoldwyn@suse.de
- needs_update: patches merged upstream
- novfs patches to be handled by novfs team
* Tue Dec  8 2009 npiggin@suse.de
- needs_update:
- patches.suse/mm-vmalloc-fail-dump-stack.patch: mm: improve
  vmalloc reporting (bnc#511079).
* Tue Dec  8 2009 npiggin@suse.de
- needs_update: most of mine are merged. apparmor patch sent to Andreas.
* Tue Dec  8 2009 coly.li@suse.de
- patches.suse/64bytes_lvb_len.diff: use 64byte lvb len.(bnc#515645)
* Tue Dec  8 2009 agraf@suse.de
- patches.arch/s390-kvm-prefix.patch: KVM: s390: Fix prefix
  register checking in arch/s390/kvm/sigp.c (FATE#306513).
- patches.arch/s390-kvm-psw.patch: KVM: s390: Make psw available
  on all exits, not just a subset (FATE#306513).
* Mon Dec  7 2009 tiwai@suse.de
- patches.drivers/synaptics-hp-clickpad: Input: Add support of
  clickpad mode to synaptics mouse driver (bnc#547370).
* Mon Dec  7 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32 final and c/s 958.
- patches.xen/xen-dcdbas: force proper address translation
  in DCDBAS.
- patches.xen&xen-vmalloc_32: guarantee 32-bit
  (bus-)addressability of vmalloc_32() output (bnc#548010,
  bnc#552492).
- patches.xen/xen-x86_64-nx-user-mappings: set NX bit in kernel
  version of top level user mode page table entries.
- patches.xen/xen3-rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  x86: add ia32 compat prlimit syscalls (FATE#305733).
- patches.xen/xen3-x86-64-align-rodata-kernel-section-to-2mb-with-config_debug_rodata:
  x86-64: align RODATA kernel section to 2MB with
  CONFIG_DEBUG_RODATA (bnc#558249).
- patches.xen/xen3-x86-64-preserve-large-page-mapping-for-1st-2mb-kernel-txt-with-config_debug_rodata:
  x86-64: preserve large page mapping for 1st 2MB kernel txt
  with CONFIG_DEBUG_RODATA (bnc#558249).
- patches.xen/xen3-x86-fix-nodac: x86: fix iommu=nodac parameter
  handling (bnc#463829, bnc#482220).
- patches.xen/xen3-x86-mcp51-no-dac: x86: disallow DAC for MCP51
  PCI bridge (bnc#463829, bnc#482220).
- Update EC2 config files (disable CAN_DEV and UIO).
* Mon Dec  7 2009 jbeulich@novell.com
- patches.arch/x86-crypto-add-ghash-algorithm-test.patch,
  patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  Fix build warnings.
* Mon Dec  7 2009 hare@suse.de
- patches.drivers/lpfc-add-raywire-id: Add missing PCI-ID to lpfc.
* Sat Dec  5 2009 tonyj@suse.de
- config.conf: add trace flavor for ppc64 (fate# 307051)
- Update config files.
* Fri Dec  4 2009 jeffm@suse.com
- Split apparmor.diff out into separate patches to align more
  closely with the upstream AppArmor 2.4 repo.
- patches.apparmor/apparmor-fix-cap-audit_caching-preemption-disabling:
  AppArmor: Fix cap audit_caching preemption disabling.
- patches.apparmor/apparmor-fix-change_profile-failing-lpn401931:
  AppArmor: Fix change_profile failing lpn401931.
- patches.apparmor/apparmor-fix-change_profile-failure: AppArmor:
  Fix change_profile failure.
- patches.apparmor/apparmor-fix-determination-of-forced-audit-messages:
  AppArmor: Fix determination of forced AUDIT messages..
- patches.apparmor/apparmor-fix-failure-to-audit-change_hat-correctly:
  AppArmor: fix failure to audit change_hat correctly.
- patches.apparmor/apparmor-fix-file-auditing-when-quiet-is-used:
  AppArmor: Fix file auditing when quiet is used.
- patches.apparmor/apparmor-fix-leak-when-profile-transition-table-fails-unpack:
  AppArmor: Fix leak when profile transition table fails unpack.
- patches.apparmor/apparmor-fix-mediation-of-created-paths-that-look-like-deleted-paths:
  AppArmor: Fix mediation of created paths that look like
  "deleted" paths.
- patches.apparmor/apparmor-fix-oops-after-profile-removal:
  AppArmor: Fix oops after profile removal.
- patches.apparmor/apparmor-fix-oops-when-auditing-the-addition-of-profile-namespace:
  AppArmor: Fix oops when auditing the addition of profile
  namespace.
- patches.apparmor/apparmor-fix-oops-when-in-apparmor_bprm_set_creds:
  AppArmor: Fix Oops when in apparmor_bprm_set_creds.
- patches.apparmor/apparmor-fix-profile-namespace-removal:
  AppArmor: Fix profile namespace removal..
- patches.apparmor/apparmor-fix-refcounting-bug-causing-leak-of-creds-and-oops:
  AppArmor: Fix refcounting bug causing leak of creds and oops.
- patches.apparmor/apparmor-fully-close-race-condition-for-deleted-paths:
  AppArmor: Fully close race condition for deleted paths.
- patches.apparmor/apparmor-missing-unlock: AppArmor: Add missing
  unlock to next_profile.
- patches.apparmor/apparmor-policy-load-and-replacement-can-fail-to-alloc-mem:
  AppArmor: Policy load and replacement can fail to alloc mem.
- patches.apparmor/apparmor-fix-security_ops-task_setrlimit-api-use:
  AppArmor: Fix security_ops->task_setrlimit API use.
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
- patches.suse/revert-usb-remove-phidget-drivers-from-kernel-tree.patch:
  Revert "USB: remove phidget drivers from kernel tree.".
* Fri Dec  4 2009 jjolly@suse.de
- patches.arch/s390-message-catalog.diff: Updated patch
  (bnc#549193,FATE#306999,LTC#57210).
* Fri Dec  4 2009 mmarek@suse.cz
- supported.conf: Update wireless drivers.
* Fri Dec  4 2009 jjolly@suse.de
- patches.arch/s390-03-qeth-hs-traffic-analyzer.patch: qeth:
  HiperSockets Network Traffic Analyzer (bnc#560674).
* Fri Dec  4 2009 hare@suse.de
- patches.drivers/qla2xxx-8.03.01-k7-update: qla2xxx driver
  update to 8.03.01-k7 (bnc#560415).
* Fri Dec  4 2009 mmarek@suse.cz
- rpm/package-descriptions: Add description for kernel-vmi.
* Fri Dec  4 2009 trenn@suse.de
- patches.arch/x86_mce_lru_cleanup.patch: HWPOISON: Undefine lru
  define after table to avoid namespace conflict (fate#307738).
- patches.arch/x86_mce_page_offlining.patch: Add soft page
  offline support (fate#307738).
- patches.arch/x86_mce_page_offlining_test_ability.patch:
  HWPOISON: Add a madvise() injector for soft page offlining
  (fate#307738).
- patches.arch/x86_mce_test_page.patch: Expose Test pageflagA
  and set pageflagB primitive (fate#307738).
* Fri Dec  4 2009 mmarek@suse.cz
- config.conf: Add vmi to kernel-syms.
* Fri Dec  4 2009 mmarek@suse.cz
- Add the vmi flavor again.
* Fri Dec  4 2009 sjayaraman@suse.de
- patches.suse/SoN-18-netvm-skbuff-reserve.patch: add emergeny flag
  inside kmemcheck boundaries.
- patches.xen/xen3-auto-common.diff: Refresh.
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for x86-64 and i386 vanilla (bnc#560402)
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for x86-64 (bnc#560402)
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for i386 (bnc#560402)
* Thu Dec  3 2009 jeffm@suse.com
- patches.arch/ppc-spufs-07-Don-t-spu_acquire_saved-unnecessarily.patch:
  Delete. (bnc#560043)
* Thu Dec  3 2009 jeffm@suse.com
- Cleanup config files.
* Thu Dec  3 2009 bphilips@suse.de
- patches.drivers/tg3_libphy_workaround: Delete. We have all of the 57780
  phylib and tg3 changes due to 2.6.32 bump.
* Thu Dec  3 2009 duwe@suse.de
- back out cpuidle feature that is still unconsistent.
* Thu Dec  3 2009 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Thu Dec  3 2009 duwe@suse.de
- patches.suse/cpuidle-cleanup: Refresh.
  Fix the "fixed" feature patch set from IBM.
* Thu Dec  3 2009 mfasheh@suse.com
- Update config files.
- patches.suse/gfs2-ro-mounts-only.patch: gfs2: allow spectator
  mounts for migration to ocfs2 (FATE#307584).
* Thu Dec  3 2009 duwe@suse.de
- Update config files for 2.6.32 (again).
* Thu Dec  3 2009 duwe@suse.de
- Update config files for cpuidle.
* Thu Dec  3 2009 tiwai@suse.de
- patches.drivers/8250_pnp-wacom-add: serial/8250_pnp.c: add
  new Wacom devices (bnc#544763).
* Thu Dec  3 2009 duwe@suse.de
- patches.suse/cpuidle-cleanup: Refresh.
  one lonely hunk already seems to be in 2.6.32 final
* Thu Dec  3 2009 duwe@suse.de
- bnc#552860 / FATE#307104: kernel idle low power, take 2:
- patches.suse/cpuidle-cleanup: Refresh.
- patches.suse/cpuidle-cleanup-x86: Refresh.
- patches.suse/cpuidle-eliminate-ppcmdpowersave1: Refresh.
* Thu Dec  3 2009 jeffm@suse.com
- Updated to 2.6.32-final.
  - 2 patches eliminated.
* Thu Dec  3 2009 hare@suse.de
- Update config files: Enable Hibernation for zSeries.
* Thu Dec  3 2009 mmarek@suse.cz
- Update config files: Disable CONFIG_MFD_PCF50633, the chip is
  unlikely to be used on architectures we support.
* Thu Dec  3 2009 mmarek@suse.cz
- rpm/split-modules: Print which supported modules need unsupported
  modules.
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: support lis3lv02d, hp_accel needs it.
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: hp_accel is supported (FATE #306448).
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: remove wm831x drivers, we no longer ship them.
* Thu Dec  3 2009 jdelvare@suse.de
- Update config files: disable all new hwmon drivers on ppc
  (default and vanilla) for consistency.
* Thu Dec  3 2009 mmarek@suse.cz
- supported.conf: Add wm831x, needed by drivers/input/misc/wm831x-on.
* Thu Dec  3 2009 mmarek@suse.cz
- supported.conf: Fix up after commit bfea0bd.
* Thu Dec  3 2009 jdelvare@suse.de
- Update config files: disable WM831x and WM8350 support entirely,
  as recommended by the drivers author. These devices are only
  found on embedded devices such as music players or mobile phones.
* Thu Dec  3 2009 hare@suse.de
- supported.conf: Mark pmcraid and igbvf as supported;
  OSD drivers as unsupported.
* Thu Dec  3 2009 jdelvare@suse.de
- Restore link from config/s390/vanilla to config/s390x/vanilla.
* Thu Dec  3 2009 jbeulich@novell.com
- supported.conf: Update Xen drivers.
* Thu Dec  3 2009 tonyj@suse.de
- needs_update: readd
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch
  patches.suse/perfmon2-remove_syscalls.patch
* Thu Dec  3 2009 gregkh@suse.de
- rpm/post.sh:
- rpm/postun.sh: woh dluoc I tegrof ot esolc eht fi
* Thu Dec  3 2009 gregkh@suse.de
- rpm/post.sh:
- rpm/postun.sh: If this is a Moblin-based box, don't run yast-bootloader
* Wed Dec  2 2009 jdelvare@suse.de
- Update config files: stop shipping wm831x-hwmon, wm8350-hwmon,
  i2c-simtec and i2c-designware.
- supported.conf: remove i2c-simtec.
* Wed Dec  2 2009 jdelvare@suse.de
- supported.conf: Add all new hwmon and i2c/busses drivers. The
  former unsupported, the latter supported.
* Wed Dec  2 2009 jdelvare@suse.de
- Update config files: disable CONFIG_I2C_VOODOO3.
- supported.conf: drop i2c-voodoo3, superseded by tdfxfb.
* Wed Dec  2 2009 jdelvare@suse.de
- supported.conf: Drop hwmon and i2c/chips drivers which have been
  obsoleted.
* Wed Dec  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete perfmon-kmp.
* Wed Dec  2 2009 mmarek@suse.cz
- supported.conf: Add perfmon, hid and input modules.
* Wed Dec  2 2009 tiwai@suse.de
- Update config files: Fix vanilla configs
* Wed Dec  2 2009 tiwai@suse.de
- Update config files: disabled CONFIG_SND_SOC* in ppc configs.
* Wed Dec  2 2009 tiwai@suse.de
- Updated the sound section of supported.conf
* Wed Dec  2 2009 gregkh@suse.de
- Update config files. disable USB OTG drivers that should not
  have been enabled.
* Wed Dec  2 2009 gregkh@suse.de
- supported.conf: remove some usb drivers that were deleted or renamed.
* Wed Dec  2 2009 gregkh@suse.de
- supported.conf: update usb driver section
* Wed Dec  2 2009 mmarek@suse.cz
- rpm/check-supported-list: Skip modules in Documentation and
  drivers/staging.
* Wed Dec  2 2009 jbenc@suse.cz
- patches.fixes/mac80211-fix-remote-DoS.patch: mac80211: fix
  remote DoS (bnc#558267).
* Tue Dec  1 2009 tiwai@suse.de
- Forward-port 11.2 patches:
  patches.drivers/alsa-sp1-hda-18-msi-wind-u115-fix: ALSA: hda -
    Add a position_fix quirk for MSI Wind U115.
  patches.drivers/alsa-sp1-hda-19-cx5047-test-mode-fix: ALSA:
    hda - Fix Cxt5047 test mode (bnc#559062).
  patches.drivers/alsa-sp1-hda-20-fsc-amilo-pi1505-fix: ALSA:
    hda - Add a pin-fix for FSC Amilo Pi1505 (bnc#557403).
  patches.drivers/alsa-sp1-hda-21-hp-dv3-position-fix-quirk:
    ALSA: hda - Add position_fix quirk for HP dv3 (bnc#555935).
* Mon Nov 30 2009 jeffm@suse.com
- patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io:
  megaraid_sas: Fix permissions on poll_mode_io (bnc#557180
  CVE-2009-3939).
* Mon Nov 30 2009 jeffm@suse.com
- patches.arch/x86-64-add-comment-for-rodata-large-page-retainment:
  x86-64: add comment for RODATA large page retainment
  (bnc#558249).
- patches.arch/x86-64-align-rodata-kernel-section-to-2mb-with-config_debug_rodata:
  x86-64: align RODATA kernel section to 2MB with
  CONFIG_DEBUG_RODATA (bnc#558249).
- patches.arch/x86-64-preserve-large-page-mapping-for-1st-2mb-kernel-txt-with-config_debug_rodata:
  x86-64: preserve large page mapping for 1st 2MB kernel txt
  with CONFIG_DEBUG_RODATA (bnc#558249).
* Mon Nov 30 2009 teheo@suse.de
- needs_update: drop libata patches which are already included in
  2.6.31 vanilla.
* Mon Nov 30 2009 teheo@suse.de
- needs_update: drop patches which are already included in 2.6.31
  vanilla.
* Mon Nov 30 2009 teheo@suse.de
  Forward port two x86 patches from SLE11.
- needs_update:
- patches.arch/x86-fix-nodac: x86: fix iommu=nodac parameter
  handling (bnc#463829).
- patches.arch/x86-mcp51-no-dac: x86: disallow DAC for MCP51
  PCI bridge (bnc#463829).
* Mon Nov 30 2009 agraf@suse.de
- Update config files: Enable KSM (FATE#306513)
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: acpi dock patch was hmacht's, not mine
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: sysfs debugging crash patch is now upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: jeffm merged novfs patches into the main novfs patch.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: qualcomm modem driver is upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: squashfs is now upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: via driver bugfixes never went upstream, and people
  are complaining about them, so they were dropped.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove staging driver entries, they are all upstream.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove hv driver entries, those are upstream now.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove xen patches with my name on it.  Just because
  I refreshed the patch, doesn't mean I own it or even like the
  thing :)
* Sat Nov 28 2009 sjayaraman@suse.de
- patches.suse/SoN-11-mm-reserve.patch: Fix build errors in -trace
  and ppc64 flavors.
* Fri Nov 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Abort if supported modules depend on
  unsupported ones.
* Fri Nov 27 2009 mmarek@suse.cz
- supported.conf: mark cnic as supported (needed by bnx2i).
* Fri Nov 27 2009 jbenc@suse.cz
- patches.suse/panic-on-io-nmi-SLE11-user-space-api.patch: API
  fix: X86: sysctl to allow panic on IOCK NMI error (bnc#427979).
- patches.suse/kdb-common: Refresh.
- patches.suse/kdump-dump_after_notifier.patch: Refresh.
* Fri Nov 27 2009 jbohac@suse.cz
- patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  CPUFREQ: ondemand: Limit default sampling rate to 300ms
  max. (bnc#464461).
* Fri Nov 27 2009 trenn@suse.de
- needs_update:
  One I still have to send upstream, but it's nicer error output
  only, SP1 is fine in respect to removing all these, thanks.
* Fri Nov 27 2009 hare@suse.de
- Update config files: Compile in efivars module for
  x86_64 (FATE#306931).
* Fri Nov 27 2009 sjayaraman@suse.de
- needs_update:	sjayaraman's patches are either upstream already or
  rebased to SP1.
* Fri Nov 27 2009 sjayaraman@suse.de
- Update config files: NFS_SWAP=y.
* Fri Nov 27 2009 sjayaraman@suse.de
- patches.trace/lttng-instrumentation-swap.patch: Refresh and fix
  a build failure with fuzz factor 0.
* Fri Nov 27 2009 sjayaraman@suse.de
- Rebase Swap-over-NFS(SoN) patches:
- patches.xen/tmem: Refresh to accomodate changes due to SoN patches.
- patches.xen/xen3-auto-common.diff: Refresh to accomodate changes
  due to SoN patches.
* Fri Nov 27 2009 knikanth@suse.de
- needs_update: Verify knikanth's patches in SLE11 but not in SP1
- patches.fixes/dm-release-map_lock-before-set_disk_ro: Release
  md->map_lock before set_disk_ro  (bnc#556899 bnc#479784).
* Fri Nov 27 2009 nfbrown@suse.de
- Restore following patches from SLES11 that are still needed for
  SLES11-SP1
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  sunrpc/cache: allow thread to block while waiting for cache
  update. (bnc#498708).
- patches.fixes/nfsd-06-sunrpc-cache-retry-cache-lookups-that-return-ETIMEDO.patch:
  sunrpc/cache: retry cache lookups that return -ETIMEDOUT
  (bnc#498708).
- patches.fixes/nfsd-07-nfsd-idmap-drop-special-request-deferal-in-favour-of.patch:
  nfsd/idmap: drop special request deferal in favour of improved
  default. (bnc#498708).
- patches.fixes/nfsd-09-fix-kabi: Fix kabi breakage in previous
  nfsd patch series (bnc#498708).
* Thu Nov 26 2009 coly.li@suse.de
- needs_update: remove patches item of coly.li, lmb and mfasheh.
- patches.fixes/dlm-enable-debug.patch: update the patch from SLES11
  to SLES11 SP1 tree.
* Thu Nov 26 2009 jslaby@suse.cz
- patches.fixes/make-note_interrupt-fast.diff: Fix performance
  regression on large IA64 systems (bnc #469589).
* Thu Nov 26 2009 mmarek@suse.cz
- rpm/old-packages.conf: obsolete kernel-kdump on ppc.
- config.conf: delete kdump configs.
- config/ppc/kdump: Delete.
- config/ppc64/kdump: Delete.
* Thu Nov 26 2009 duwe@suse.de
- patches.arch/ppc-extended_h_cede-Export_memory_sysdev_class:
  Refresh. Fix "typo", memory_sysdev_class should be exported
  only to GPL'ed modules.
* Thu Nov 26 2009 hare@suse.de
  Fixup patches for series2git:
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Thu Nov 26 2009 duwe@suse.de
- config.conf: disable build of ppc kdump flavours
  (FATE#304346)
* Thu Nov 26 2009 tiwai@suse.de
- patches.drivers/libata-missing-_SDD-is-not-an-error:
  libata-acpi: missing _SDD is not an error (bnc#551942).
* Thu Nov 26 2009 jbenc@suse.cz
- patches.fixes/mac80211-fix-spurious-delba-handling.patch:
  mac80211: fix spurious delBA handling (bnc#558267,
  CVE-2009-4026, CVE-2009-4027).
* Thu Nov 26 2009 tiwai@suse.de
- patches.drivers/sky2-add-register-definitions: sky2: add
  register definitions for new chips (bnc#544760).
- patches.drivers/sky2-88E8059-support: sky2: 88E8059 support
  (bnc#544760).
- patches.drivers/sky2-optima-tcp-offload-fix: net: Fix Yukon-2
  Optima TCP offload setup (bnc#544760).
- patches.drivers/sky2-optima-fix-pci-cfg: net: Add missing
  TST_CFG_WRITE bits around sky2_pci_write (bnc#544760).
* Thu Nov 26 2009 nfbrown@suse.de
- Update config files.
  disable CONFIG_MULTICOE_RAID456 as it is not yet stable.
  Enable CONFIG_ASYNC_TX_DMA for FATE#306368
* Thu Nov 26 2009 gregkh@suse.de
- clean up patch fuzz
* Thu Nov 26 2009 gregkh@suse.de
- patches.drivers/via-unichrome-drm-bugfixes.patch: Delete.
  it never went upstream, so we should drop it as well.
* Wed Nov 25 2009 tonyj@suse.de
- patches.trace/lttng-*: update for 2.6.32
- patches.trace/lttng-instrumentation-timer.patch: Delete.
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Wed Nov 25 2009 tonyj@suse.de
- patches.fixes/oprofile_bios_ctr.patch: detect oprofile counters
  reserved by bios (FATE#307426).
* Wed Nov 25 2009 jeffm@suse.com
- patches.fixes/netfilter-remove-pointless-config_nf_ct_acct-warning:
  netfilter: Remove pointless CONFIG_NF_CT_ACCT warning
  (bnc#552033 (and others)).
* Tue Nov 24 2009 hare@suse.de
- Update config files.
- patches.drivers/mpt-fusion-4.22.00.00-update: Update MPT Fusion
  driver to 4.22.00.00-suse (bnc#556587).
- patches.drivers/mpt-fusion-4.16.00.00-update: Delete.
* Tue Nov 24 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-17-fix-mute-LED-sync-idt92h383xxx:
  ALSA: hda - Fix mute-LED sync on HP laptops with IDT92HD83xxx
  codecs (bnc#547357).
* Tue Nov 24 2009 duwe@suse.de
- patches.arch/ppc-extended_h_cede-*: Increase power savings
  by allowing the core to sleep.
  (FATE##307059, bnc#550447)
* Tue Nov 24 2009 sjayaraman@suse.de
- patches.suse/kconfig-automate-kernel-desktop: automate a few config
  options for kernel-desktop (FATE#305694).
* Tue Nov 24 2009 agraf@suse.de
- patches.arch/kvm-only-export-selected-pv-ops-feature-structs:
  Update references (bnc#556135, FATE#306453).
- patches.arch/kvm-replace-kvm-io-delay-pv-ops-with-linux-magic:
  Update references (bnc#556135, FATE#306453).
- patches.arch/kvm-split-paravirt-ops-by-functionality: Update
  references (bnc#556135, FATE#306453).
- patches.arch/kvm-split-the-KVM-pv-ops-support-by-feature:
  Update references (bnc#556135, FATE#306453).
* Mon Nov 23 2009 jeffm@suse.com
- Enabled:
  patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array
* Mon Nov 23 2009 jkosina@suse.de
- patches.arch/x86-crypto-add-ghash-algorithm-test.patch: crypto:
  Add ghash algorithm test before provide to users (FATE#306883,
  bnc#554578).
* Mon Nov 23 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  incorporate "ghash - put proper .data section in place" fix
* Mon Nov 23 2009 sjayaraman@suse.de
- Update config files.
  - Add new options KERNEL_DESKTOP and DEFAULT_VM_DIRTY_RATIO.
  - Enable KERNEL_DESKTOP for only desktop flavor.
* Mon Nov 23 2009 sjayaraman@suse.de
- patches.suse/mm-tune-dirty-limits.patch: mm: Make default
  VM dirty ratio configurable to suit different workloads
  (bnc#552883).
* Fri Nov 20 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in, rpm/mkspec: build kernel-syms only for
  supported architectures.
* Fri Nov 20 2009 jeffm@suse.com
- Enabled B43_PHY_LP=y for PHY support on certain b43 chips.
* Fri Nov 20 2009 mmarek@suse.cz
- config.conf: Remove the -desktop flavor from kernel-syms.
* Fri Nov 20 2009 mmarek@suse.cz
- patches.suse/export-sync_page_range: Revert "vfs: Remove
  generic_osync_inode() and sync_page_range{_nolock}()"
  (bnc#557231).
* Fri Nov 20 2009 jbeulich@novell.com
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  Fix a bad-pointer warning.
* Fri Nov 20 2009 agruen@suse.de
- rpm/macros.kernel-source: Add kernel_module_package_moddir()
  macro for cross-distro compatibility (FATE 305225).
* Fri Nov 20 2009 jslaby@suse.cz
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: Update
  references (FATE#305733).
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Update references (FATE#305733).
* Fri Nov 20 2009 jslaby@suse.cz
- Add writable resource limits support
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  SECURITY: selinux, fix update_rlimit_cpu parameter.
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  SECURITY: add task_struct to setrlimit.
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  core: add task_struct to update_rlimit_cpu.
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  sys_setrlimit: make sure ->rlim_max never grows.
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: core:
  split sys_setrlimit.
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  core: allow setrlimit to non-current tasks.
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  core: optimize setrlimit for current task.
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  FS: proc, make limits writable.
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  core: posix-cpu-timers, cleanup rlimits usage.
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  core: do security check under task_lock.
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  resource: add helpers for fetching rlimits.
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  IA64: use helpers for rlimits.
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch: PPC:
  use helpers for rlimits.
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  S390: use helpers for rlimits.
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  SPARC: use helpers for rlimits.
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch: X86:
  use helpers for rlimits.
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch: FS:
  use helpers for rlimits.
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch: MM:
  use helpers for rlimits.
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  core: use helpers for rlimits.
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  misc: use helpers for rlimits.
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  core: rename setrlimit to do_setrlimit.
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  core: implement getprlimit and setprlimit syscalls.
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  unistd: add __NR_[get|set]prlimit syscall numbers.
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  COMPAT: add get/put_compat_rlimit.
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  x86: add ia32 compat prlimit syscalls.
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/phy-broadcom-bug-fixes-for-sp1.patch:
  phy/broadcom: bug fixes for SP1 (FATE#307117, bnc#556234).
- patches.drivers/tg3-update-version-to-3.104.patch: tg3: Update
  version to 3.104 (bnc#556234, FATE#307117).
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/phy-broadcom-bug-fixes-for-sp1.patch:
  phy/broadcom: bug fixes for SP1 (FATE#307117, bnc#556234).
- patches.drivers/tg3-update-version-to-3.104.patch: tg3: Update
  version to 3.104 (bnc#556234, FATE#307117).
* Fri Nov 20 2009 hare@suse.de
- patches.drivers/megaraid-04.12-update: megaraid: Update
  megaraid_sas to version 04.12 (FATE#307125).
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/bnx2-entropy-source.patch: bnx2: entropy source
  (FATE#307517).
- patches.drivers/e1000-entropy-source.patch: Enable e1000 as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/e1000e-entropy-source.patch: Enable e1000e as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/igb-entropy-source.patch: Enable igb as entropy
  source (disabled by default) (FATE#307517).
- patches.drivers/ixgbe-entropy-source.patch: Enable ixgbe as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/tg3-entropy-source.patch: tg3: entropy source
  (FATE#307517).
* Fri Nov 20 2009 hare@suse.de
- patches.fixes/scsi-fix-bug-with-dma-maps-on-nested-scsi-objects:
  scsi_lib_dma: fix bug with dma maps on nested scsi objects
  (bnc#556595).
- patches.fixes/scsi-introduce-helper-function-for-blocking-eh:
  scsi_transport_fc: Introduce helper function for blocking
  scsi_eh (bnc#556595).
- patches.fixes/scsi-skip-nonscsi-device-for-dma: Delete.
* Fri Nov 20 2009 hare@suse.de
  Whitespace cleanup for series2git:
- patches.arch/s390-message-catalog.diff: Refresh.
- patches.drivers/aacraid-24701-update: Refresh.
- patches.suse/crasher-26.diff: Refresh.
- patches.suse/kdb-common: Refresh.
- patches.suse/kdb-ia64: Refresh.
- patches.suse/kdb-x86: Refresh.
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/perfmon2_ioctl.patch: Refresh.
- patches.suse/stack-unwind: Refresh.
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/igb-add-support-for-82576NS-SerDes-adapter.patch:
  igb: add support for 82576NS SerDes adapter (FATE#306856).
* Fri Nov 20 2009 jbeulich@novell.com
- patches.suse/dm-mpath-evaluate-request-result-and-sense:
  Fix for !CONFIG_SCSI (in -ec2).
* Fri Nov 20 2009 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: ocfs2:
  allocation reservations (bnc#501563 FATE#307247).
* Fri Nov 20 2009 jjolly@suse.de
- patches.suse/perfmon2.patch: Refresh.
- patches.arch/x86-self-ptrace.patch: Delete. (bnc#554585,LTC#57794)
- patches.suse/self-ptrace.patch: Delete. (bnc#554585,LTC#57794)
* Fri Nov 20 2009 jeffm@suse.com
- Update to 2.6.32-rc8.
  - Eliminated 1 patch.
* Fri Nov 20 2009 jeffm@suse.de
- patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array:
  enclosure: fix oops while iterating enclosure_status array
  (bnc#540997).
* Thu Nov 19 2009 tonyj@suse.de
- Update config files.
- patches.suse/perfmon2.patch: perfmon2 (FATE#303968).
- patches.suse/perfmon2_ioctl.patch: switch to ioctl interface
  for perfmon2.
- patches.suse/perfmon2_noutrace.patch: remove UTRACE code
  from perfmon2.
- patches.xen/xen3-patch-2.6.28: Refresh.
* Thu Nov 19 2009 jjolly@suse.de
- Update config files.
- patches.arch/s390-message-catalog.diff: Kernel message
  catalog. (bnc#549193,LTC#57210,FATE#306999).
- rpm/kernel-binary.spec.in:
* Thu Nov 19 2009 jbohac@suse.cz
- patches.suse/add-queue_depth-ramp-up-code.patch: add queue_depth
  ramp up code (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-add-a-separate-scsi-transport-template-for-npiv-vports.patch:
  fcoe: add a separate scsi transport template for NPIV vports
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-add-check-to-fail-gracefully-in-bonding-mode.patch:
  fcoe: add check to fail gracefully in bonding mode (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-call-ndo_fcoe_enable-disable-to-turn-fcoe-feature-on-off-in-lld.patch:
  fcoe: Call ndo_fcoe_enable/disable to turn FCoE feature on/off
  in LLD (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-checking-san-mac-address.patch: fcoe: Fix
  checking san mac address (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-getting-san-mac-for-vlan-interface.patch:
  fcoe: Fix getting san mac for VLAN interface (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-fix-setting-lport-s-wwnn-wwpn-to-use-san-mac-address.patch:
  fcoe: Fix setting lport's WWNN/WWPN to use san mac address
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-using-vlan-id-in-creating-lport-s-wwwn-wwpn.patch:
  fcoe: Fix using VLAN ID in creating lport's WWWN/WWPN
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-formatting-cleanups-and-commenting.patch:
  fcoe: Formatting cleanups and commenting (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-increase-fcoe_max_lun-to-0xffff-65535.patch:
  fcoe: Increase FCOE_MAX_LUN to 0xFFFF (65535) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-initialize-return-value-in-fcoe_destroy.patch:
  fcoe: initialize return value in fcoe_destroy (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-libfc-fix-an-libfc-issue-with-queue-ramp-down-in-libfc.patch:
  fcoe, libfc: fix an libfc issue with queue ramp down in libfc
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-libfc-use-single-frame-allocation-api.patch:
  fcoe, libfc: use single frame allocation API (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-npiv-vport-create-destroy.patch: fcoe: NPIV
  vport create/destroy (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-remove-extra-function-decalrations.patch:
  fcoe: remove extra function decalrations (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-remove-redundant-checking-of-netdev-netdev_ops.patch:
  fcoe: remove redundant checking of netdev->netdev_ops
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-use-netif_f_fcoe_mtu-flag-to-set-up-max-frame-size-lport-mfs.patch:
  fcoe: Use NETIF_F_FCOE_MTU flag to set up max frame size
  (lport->mfs) (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-vport-symbolic-name-support.patch: fcoe: vport
  symbolic name support (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-host-number-to-lport-link-up-down-messages.patch:
  libfc: add host number to lport link up/down
  messages. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-libfc-fc_libfc-ch-for-libfc-internal-routines.patch:
  libfc: Add libfc/fc_libfc.[ch] for libfc internal routines
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-queue_depth-ramp-up.patch: libfc:
  add queue_depth ramp up (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-routine-to-copy-data-from-a-buffer-to-a-sg-list.patch:
  libfc: Add routine to copy data from a buffer to a SG list
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-set_fid-function-to-libfc-template.patch:
  libfc: add set_fid function to libfc template (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-add-some-generic-npiv-support-routines-to-libfc.patch:
  libfc: add some generic NPIV support routines to libfc
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-adds-can_queue-ramp-up.patch: libfc: adds
  can_queue ramp up (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-adds-missing-exch-release-for-accepted-rrq.patch:
  libfc: adds missing exch release for accepted RRQ (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-changes-to-libfc_host_alloc-to-consolidate-initialization-with-allocation.patch:
  libfc: changes to libfc_host_alloc to consolidate initialization
  with allocation (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-combine-name-server-registration-request-functions.patch:
  libfc: combine name server registration request functions
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-combine-name-server-registration-response-handlers.patch:
  libfc: combine name server registration response handlers
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-convert-to-scsi_track_queue_full.patch:
  libfc: convert to scsi_track_queue_full (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-do-not-use-did_no_connect-for-pkt-alloc-failures.patch:
  libfc: do not use DID_NO_CONNECT for pkt alloc
  failures. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-don-t-warn_on-in-lport_timeout-for-reset-state.patch:
  libfc: don't WARN_ON in lport_timeout for RESET state
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-export-fc-headers.patch: libfc: Export FC
  headers (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-add-fc-passthrough-support.patch: libfc,
  fcoe: Add FC passthrough support (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-fcoe-don-t-export_symbols-unnecessarily.patch:
  libfc, fcoe: Don't EXPORT_SYMBOLS unnecessarily (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-fixes-for-highmem-skb-linearize-panics.patch:
  libfc, fcoe: fixes for highmem skb linearize panics
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-increase-els-and-ct-timeouts.patch:
  libfc fcoe: increase ELS and CT timeouts (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fix-an-issue-of-pending-exch-es-after-i-f-destroyed-or-rmmod-fcoe.patch:
  libfc: fix an issue of pending exch/es after i/f destroyed or
  rmmod fcoe (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-ddp-in-fc_fcp-for-0-xid.patch: libfc: fix
  ddp in fc_fcp for 0 xid (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-fc_els_resp_type-to-correct-display-of-ct-responses.patch:
  libfc: fix fc_els_resp_type to correct display of CT responses
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-frags-in-frame-exceeding-skb_max_frags-in-fc_fcp_send_data.patch:
  libfc: Fix frags in frame exceeding SKB_MAX_FRAGS in
  fc_fcp_send_data (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-free-of-fc_rport_priv-with-timer-pending.patch:
  libfc: fix free of fc_rport_priv with timer pending
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-memory-corruption-caused-by-double-frees-and-bad-error-handling.patch:
  libfc: fix memory corruption caused by double frees and bad
  error handling (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-rnn_id-smashing-skb-payload.patch: libfc:
  fix RNN_ID smashing skb payload (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-fix-symbolic-name-registrations-smashing-skb-data.patch:
  libfc: fix symbolic name registrations smashing skb data
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-typo-in-retry-check-on-received-prli.patch:
  libfc: fix typo in retry check on received PRLI (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fix-wrong-scsi-return-status-under-fc_data_undrun.patch:
  libfc: Fix wrong scsi return status under FC_DATA_UNDRUN
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-formatting-cleanups-across-libfc.patch:
  libfc: Formatting cleanups across libfc (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-libfcoe-fdisc-els-for-npiv.patch: libfc,
  libfcoe: FDISC ELS for NPIV (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-lport-fix-minor-documentation-errors.patch:
  libfc: lport: fix minor documentation errors (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-move-libfc_init-and-libfc_exit-to-fc_libfc-c.patch:
  libfc: Move libfc_init and libfc_exit to fc_libfc.c
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-move-non-common-routines-and-prototypes-out-of-libfc-h.patch:
  libfc: Move non-common routines and prototypes out of libfc.h
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-reduce-can_queue-for-all-fcp-frame-allocation-failures.patch:
  libfc: reduce can_queue for all FCP frame allocation failures
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-register-fc4-features-with-the-fc-switch.patch:
  libfc: register FC4 features with the FC switch (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-register-symbolic-node-name-rsnn_nn.patch:
  libfc: Register Symbolic Node Name (RSNN_NN) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-register-symbolic-port-name-rspn_id.patch:
  libfc: Register Symbolic Port Name (RSPN_ID) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-remove-fc_fcp_complete.patch: libfc: Remove
  fc_fcp_complete (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-remove-unused-fc_lport-pointer-from-fc_fcp_pkt_abort.patch:
  libfc: Remove unused fc_lport pointer from fc_fcp_pkt_abort
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-removes-initializing-fc_cpu_order-and-fc_cpu_mask-per-lport.patch:
  libfc: removes initializing fc_cpu_order and fc_cpu_mask per
  lport (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-removes-unused-disc_work-and-ex_list.patch:
  libfc: removes unused disc_work and ex_list (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-rnn_id-may-be-required-before-rsnn_nn-with-some-switches.patch:
  libfc: RNN_ID may be required before RSNN_NN with some switches
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-rpn_id-is-obsolete-and-unnecessary.patch:
  libfc: RPN_ID is obsolete and unnecessary (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-vport-link-handling-and-fc_vport-state-managment.patch:
  libfc: vport link handling and fc_vport state managment
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-allow-fip-to-be-disabled-by-the-driver.patch:
  libfcoe: Allow FIP to be disabled by the driver (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfcoe-do-not-pad-fip-keep-alive-to-full-frame-size.patch:
  libfcoe: Do not pad FIP keep-alive to full frame size
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-don-t-send-els-in-fip-mode-if-no-fcf-selected.patch:
  libfcoe: don't send ELS in FIP mode if no FCF selected
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fcoe-libfcoe-npiv-support.patch:
  libfcoe, fcoe: libfcoe NPIV support (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfcoe-fcoe-simplify-receive-flogi-response.patch:
  libfcoe: fcoe: simplify receive FLOGI response (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-allow-fip-receive-to-be-called-from-irq.patch:
  libfcoe: fip: allow FIP receive to be called from
  IRQ. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-should-report-link-to-libfc-whether-selected-or-not.patch:
  libfcoe: FIP should report link to libfc whether selected or
  not (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-use-scsi-host-number-to-identify-debug-messages.patch:
  libfcoe: fip: use SCSI host number to identify debug
  messages. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-formatting-and-comment-cleanups.patch:
  libfcoe: formatting and comment cleanups (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/modify-change_queue_depth-to-take-in-reason-why-it-is-being-called.patch:
  modify change_queue_depth to take in reason why it is being
  called (fate#306857, fate#306859, bnc#551175).
- patches.suse/scsi-error-have-scsi-ml-call-change_queue_depth-to-handle-queue_full.patch:
  scsi error: have scsi-ml call change_queue_depth to handle
  QUEUE_FULL (fate#306857, fate#306859, bnc#551175).
* Thu Nov 19 2009 hare@suse.de
- patches.suse/dm-mpath-accept-failed-paths: Fixup patch to apply.
* Thu Nov 19 2009 hare@suse.de
  Port patches from SLES11:
- patches.fixes/scsi-dh-queuedata-accessors: Kernel bug triggered
  in multipath (bnc#486001).
- patches.suse/dm-mpath-accept-failed-paths: Refresh.
- patches.suse/dm-mpath-detach-existing-hardware-handler:
  multipath: detach existing hardware handler if none was
  specified.
- patches.suse/dm-mpath-requeue-for-stopped-queue: Delete.
* Thu Nov 19 2009 hare@suse.de
- patches.suse/dm-mpath-evaluate-request-result-and-sense:
  multipath: Evaluate request result and sense code
  (FATE#303695,bnc#433920,bnc#442001).
* Thu Nov 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Kill support for kernel-$flavor
  symbols, we need a unified kernel-source for all flavors.
* Thu Nov 19 2009 hare@suse.de
- patches.fixes/bnx2i-use-common-iscsi-suspend-queue: bnx2i:
  use common iscsi suspend queue (FATE#307215).
- patches.fixes/iscsi-class-modify-handling-of-replacement-time:
  iscsi class: modify handling of replacement timeout
  (FATE#307215).
- patches.fixes/iser-set-tgt-and-lu-reset-timeout: iser: set
  tgt and lu reset timeout (FATE#307215).
- patches.fixes/libiscsi-add-warm-target-reset-tmf-support:
  libiscsi: add warm target reset tmf support (FATE#307215).
- patches.fixes/libiscsi-check-tmf-state-before-sending-pdu:
  libiscsi: Check TMF state before sending PDU (FATE#307215).
- patches.fixes/libiscsi-fix-login-text-checks-in-pdu-inject:
  libiscsi: fix login/text checks in pdu injection code
  (FATE#307215).
- patches.fixes/scsi-add-scsi-target-reset-support-to-ioctl:
  add scsi target reset support to scsi ioctl.
- patches.fixes/scsi-devinfo-update-hitachi-entries: scsi_devinfo:
  update Hitachi entries (v2).
- patches.fixes/scsi-fc-class-failfast-bsg-requests: [SCSI]
  fc class: fail fast bsg requests.
- patches.drivers/cxgb3i: Delete.
- patches.drivers/cxgb3i-fixed-offload-array-size: Delete.
- patches.fixes/disable-lro-per-default: Delete.
* Thu Nov 19 2009 hare@suse.de
- patches.fixes/scsi_dh-always-attach-sysfs: scsi_dh: create
  sysfs file, dh_state for all SCSI disk devices.
- patches.fixes/scsi_dh-change-activate-interface: scsi_dh: Change
  the scsidh_activate interface to be asynchronous (bnc#556144).
- patches.fixes/scsi_dh-make-alua-handler-asynchronous: scsi_dh:
  Make alua hardware handler's activate() async (bnc#556144).
- patches.fixes/scsi_dh-make-hp_sw-handler-asynchronous: scsi_dh:
  Make hp hardware handler's activate() async (bnc#556144).
- patches.fixes/scsi_dh-make-rdac-handler-asynchronous: scsi_dh:
  Make rdac hardware handler's activate() async (bnc#556144).
* Thu Nov 19 2009 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k8_sles11-03-update: Delete.
- patches.drivers/qla4xxx-sles11-update: Delete.
* Thu Nov 19 2009 hare@suse.de
- Update config files.
- patches.drivers/hpsa: hpsa: New driver SCSI driver for HP
  Smart Array (FATE#307153,bnc#555855).
- supported.conf: Mark hpsa as supported.
* Thu Nov 19 2009 jjolly@suse.de
- patches.arch/s390-01-qeth-isolation.patch: qeth: Exploit QDIO
  Data Connection Isolation (bnc#555199,LTC#57826,FATE#307015).
- patches.arch/s390-02-01-cex3-init-msg.patch:
  zcrypt: initialize ap_messages for cex3 exploitation
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-02-cex3-special-command.patch:
  zcrypt: special command support for cex3 exploitation
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-03-cex3-device.patch: zcrypt: add support
  for cex3 device types (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-04-cex3-use-def.patch: zcrypt: use
  definitions for cex3 (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-05-zcrypt-speed-cex2c.patch:
  zcrypt: adjust speed rating between cex2 and pcixcc
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-06-zcrypt-speed-cex3.patch:
  zcrypt: adjust speed rating of cex3 adapters
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-sles11sp1-01-qeth-isolation.patch: Delete.
* Thu Nov 19 2009 jjolly@suse.de
- patches.arch/s390-sles11sp1-01-qeth-isolation.patch:
  qeth: Exploit QDIO Data Connection Isolation
  (bnc#555199,LTC#57826,FATE#307015).
* Wed Nov 18 2009 jeffm@suse.com
- scripts/sequence-patch.sh: Add automatic generation of supported
  modules list.
* Wed Nov 18 2009 jeffm@suse.com
- Update config files: Enable CONFIG_ACPI_CUSTOM_OVERRIDE_INITRAMFS
* Wed Nov 18 2009 jeffm@suse.com
- patches.suse/acpi-generic-initramfs-table-override-support:
  ACPI: generic initramfs table override support (bnc#533555).
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  init: move populate_rootfs back to start_kernel (bnc#533555).
* Wed Nov 18 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  incorporate "crypto: ghash-intel - Hard-code pshufb" fix
* Wed Nov 18 2009 jeffm@suse.com
- patches.suse/hung_task_timeout-configurable-default:
  hung_task_timeout: configurable default (bnc#552820).
  - Default to runtime-disabled on all flavors except debug.
* Wed Nov 18 2009 agraf@suse.de
- patches.fixes/kvm-ioapic.patch: Ignore apic polarity
  (bnc#556564).
- patches.fixes/kvm-macos.patch: Implement some missing intercepts
  so osx doesn't blow up (bnc#556564).
* Wed Nov 18 2009 hare@suse.de
- supported.conf: mark missing 10Gb drivers as supported
  (bnc#555793)
* Wed Nov 18 2009 hare@suse.de
- patches.drivers/aacraid-24701-update: Problems with aacraid
  (bnc#524242,FATE#307437).
* Wed Nov 18 2009 hare@suse.de
  Cleanup patches for series2git:
- patches.apparmor/apparmor.diff: Refresh.
- patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch:
  Refresh.
- patches.suse/bootsplash: Refresh.
- patches.suse/nfs4acl-ext3.diff: Refresh.
- patches.suse/silent-stack-overflow-2.patch: Refresh.
- patches.suse/suse-ppc32-mol.patch: Refresh.
- patches.suse/xfs-dmapi-src: Refresh.
* Wed Nov 18 2009 agraf@suse.de
- Update config files to enable pv-ops for KVM clock. (bnc#556135)
* Wed Nov 18 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-01-select-ibexpeak-handler: ALSA:
  hda - select IbexPeak handler for Calpella (FATE#306783).
- patches.drivers/alsa-sp1-hda-02-vectorize-get_empty_pcm_device:
  ALSA: hda - vectorize get_empty_pcm_device() (FATE#306783).
- patches.drivers/alsa-sp1-hda-03-allow-up-to-4-HDMI: ALSA:
  hda - allow up to 4 HDMI devices (FATE#306783).
- patches.drivers/alsa-sp1-hda-04-convert-intelhdmi-global-references:
  ALSA: hda - convert intelhdmi global references to local
  parameters (FATE#306783).
- patches.drivers/alsa-sp1-hda-05-remove-intelhdmi-dependency-on-multiout:
  ALSA: hda - remove intelhdmi dependency on multiout
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-06-use-pcm-prepare-callbacks-for-intelhdmi:
  ALSA: hda - use pcm prepare/cleanup callbacks for intelhdmi
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-07-reorder-intelhemi-prepare-callbacks:
  ALSA: hda - reorder intelhdmi prepare/cleanup callbacks
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-08-vectorize-intelhdmi: ALSA:
  hda - vectorize intelhdmi (FATE#306783).
- patches.drivers/alsa-sp1-hda-09-get-intelhtemi-max-channels:
  ALSA: hda - get intelhdmi max channels from widget caps
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-10-auto-parse-intelhdmi-cvt-pin:
  ALSA: hda - auto parse intelhdmi cvt/pin configurations
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-11-remove-static-intelhdmi-config:
  ALSA: hda - remove static intelhdmi configurations
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-12-reset-pins-idt-codec-free:
  ALSA: hda - Reset pins of IDT/STAC codecs at free (bnc#544779).
- patches.drivers/alsa-sp1-hda-13-add-reboot-notifier: ALSA:
  hda - Add reboot notifier to each codec (bnc#544779).
- patches.drivers/alsa-sp1-hda-14-add-missing-export: ALSA: hda -
  Add missing export for snd_hda_bus_reboot_notify (bnc#544779).
- patches.drivers/alsa-sp1-hda-15-fix-build-warning: ALSA: hda -
  Add a proper ifdef to a debug code (FATE#306783).
- patches.drivers/alsa-sp1-hda-16-stac-dual-headphones-fix:
  ALSA: hda - Fix detection of dual headphones (bnc#556532).
* Wed Nov 18 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  crypto: ghash - Add PCLMULQDQ accelerated implementation
  (FATE#306883, bnc#554578).
- Update config files: set CRYPTO_GHASH_CLMUL_NI_INTEL=m
- patches.xen/xen3-patch-2.6.28: Refresh to apply cleanly
* Wed Nov 18 2009 agraf@suse.de
- patches.arch/kvm-only-export-selected-pv-ops-feature-structs:
  Only export selected pv-ops feature structs (bnc#556135).
- patches.arch/kvm-replace-kvm-io-delay-pv-ops-with-linux-magic:
  Replace kvm io delay pv-ops with linux magic (bnc#556135).
- patches.arch/kvm-split-paravirt-ops-by-functionality: Split
  paravirt ops by functionality (bnc#556135).
- patches.arch/kvm-split-the-KVM-pv-ops-support-by-feature:
  Split the KVM pv-ops support by feature (bnc#556135).
- patches.xen/xen3-patch-2.6.23: Refresh.
- patches.xen/xen3-patch-2.6.31: Refresh.
* Wed Nov 18 2009 teheo@suse.de
- patches.suse/kbuild-icecream-workaround: Delete.
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Also enable CONFIG_DMAR (fate#306796) for vanilla flavors
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Do the same for i386
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Enabling CONFIG_DMAR (fate#306796), introduces these changes:
    +CONFIG_HAVE_INTEL_TXT=y
  - # CONFIG_DMAR is not set
    +CONFIG_DMAR=y
    +# CONFIG_DMAR_DEFAULT_ON is not set
    +CONFIG_DMAR_FLOPPY_WA=y
    +# CONFIG_INTEL_TXT is not set
  Done for x86_64 for now only.
* Mon Nov 16 2009 jkosina@suse.de
- patches.fixes/hid-fixup-ncr-quirk.patch: HID: fixup quirk for
  NCR devices (bnc#548807).
* Fri Nov 13 2009 mmarek@suse.cz
- rpm/*.spec.in, rpm/kernel-module-subpackage: add
  Provides: multiversion(kernel) to binary kernel packages,
  kernel-source, kernel-syms and all KMPs so that zypp can be
  configured to keep multiple versions of these packages
  (fate#305311).
* Fri Nov 13 2009 npiggin@suse.de
- Disable LGUEST on x86 32. It doesn't build properly without PARAVIRT.
* Wed Nov 11 2009 jack@suse.cz
- patches.fixes/zisofs-large-pagesize-read.patch: zisofs:
  Implement reading of compressed files when PAGE_CACHE_SIZE >
  compress block size (bnc#540349).
* Wed Nov 11 2009 npiggin@suse.de
- Update config files.
* Wed Nov 11 2009 npiggin@suse.de
- Disable PARAVIRT_GUEST on x86 32 and 64.
* Tue Nov 10 2009 teheo@suse.de
- patches.drivers/libata-ahci-aspire-3810t-noncq: ahci: disable
  NCQ on Aspire 3810t (bnc#522790).
* Tue Nov 10 2009 npiggin@suse.de
- Update config files.
* Tue Nov 10 2009 npiggin@suse.de
- Update config files. Disable CONFIG_CC_STACKPROTECTOR on all
  x86 kernels except debug. Overhead is prohibitive.
* Mon Nov  9 2009 npiggin@suse.de
- patches.suse/files-slab-rcu.patch: SLAB_DESTROY_BY_RCU for
  file slab.
* Mon Nov  9 2009 npiggin@suse.de
- Update config files. Vanilla doesn't have unwinder, trace selects
  options which select frame pointers.
* Mon Nov  9 2009 npiggin@suse.de
- Disable FRAME_POINTER on i386 and x86-64, all kernels. Unwind info
  should provide all this functionality.
* Mon Nov  9 2009 nfbrown@suse.de
- patches.fixes/nfs-honour-server-preferred-io-size: NFS: Honour
  server-preferred io sizes (bnc#550648).
* Mon Nov  9 2009 nfbrown@suse.de
- patches.fixes/nfs-slot-table-alloc: Don't fail allocations
  for the slot table when mounting an NFS filesystem (bnc#519820).
* Fri Nov  6 2009 trenn@suse.de
- patches.arch/x86_amd_fix_erratum_63.patch: x86/amd-iommu:
  Workaround for erratum 63 (bnc#548274).
* Fri Nov  6 2009 jeffm@suse.de
- Disabled PARAVIRT_GUEST on ia64/trace and ia64/vanilla.
* Fri Nov  6 2009 trenn@suse.de
- patches.suse/kdb_x86_fix_hang.patch: X86 KDB: Reduce timeout
  for blinking LEDs (bnc#528811).
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix last change.
* Fri Nov  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32-rc6 and c/s 941.
- Update Xen config files.
- supported.conf: Add domctl.
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add the /lib/modules/.../{source,devel}
  symlinks to the -devel package (bnc#548728).
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete kvm-kmp.
* Thu Nov  5 2009 jeffm@suse.com
- Update to 2.6.32-rc6.
  - 2 patches eliminated
  - NR_CPUS=4096 on ia64/vanilla again
* Thu Nov  5 2009 jeffm@suse.com
- Performance: Disabled CONFIG_PARAVIRT on all flavors.
* Thu Nov  5 2009 mmarek@suse.cz
- Delete unused 2.6.31.y patches.
* Thu Nov  5 2009 mmarek@suse.cz
- supported.conf: add libfcoe and fix typo.
* Thu Nov  5 2009 mmarek@suse.cz
- supported.conf: update so that supported modules don't require
  unsupported ones by adding following modules: async_pq
  async_raid6_recov ath blkback_pagemap crypto_hash drm_kms_helper
  fddi fscache lib80211 libfcoe libipw libiscsi_tcp llc md_mod mdio
  mfd_core nf_defrag_ipv4 p8022 psnap raid6_pq tr ttm ucb1400_core
  v4l2_compat_ioctl32.
* Thu Nov  5 2009 mmarek@suse.cz
- config.conf: remove kernel-ps3-devel (does not exist) and
  kernel-debug-devel (not needed most of the time) from
  kernel-syms.
* Thu Nov  5 2009 hare@suse.de
- Update config files: Set CONFIG_HZ to 100 for zSeries
  (bnc#552564).
* Thu Nov  5 2009 hare@suse.de
- Update config files: Increase MAX_RAW_DEVS to 4096 on
  zSeries (bnc#552565).
* Wed Nov  4 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: delete stray text.
* Tue Nov  3 2009 mmarek@suse.cz
- config.conf: remove the ec2 flavor from kernel-syms, most KMPs
  don't make any sense on ec2
  (http://lists.opensuse.org/opensuse-kernel/2009-11/msg00001.html).
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete also brocade-bfa-kmp.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: add split-modules to the src.rpm.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete enic-kmp and fnic-kmp.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete kmps by their full name, not
  just the foo-kmp virtual dependency (bnc#472410).
* Thu Oct 29 2009 tonyj@suse.de
- Update ppc/ps3 config for CONFIG_UTRACE
* Thu Oct 29 2009 tonyj@suse.de
- patches.trace/utrace-core: Update for SP1 (FATE# 304321)
* Wed Oct 28 2009 nfbrown@suse.de
- patches.fixes/nfsd-acl.patch: nfsd: Fix sort_pacl in
  fs/nfsd/nf4acl.c to actually sort groups (bnc#549748).
* Wed Oct 28 2009 jdelvare@suse.de
- Update config files:
  CONFIG_NTFS_FS=n
  We handle NTFS through FUSE these days.
* Tue Oct 27 2009 jbohac@suse.cz
- Update config files:
  CONFIG_NETLABEL=y
  CONFIG_SECURITY_NETWORK_XFRM=y
  (fate#307284)
* Tue Oct 27 2009 jkosina@suse.de
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  fix compilation failure for configs with CONFIG_SMP=n and
  CONFIG_FAR_GROUP_SCHED=y
* Tue Oct 27 2009 jbeulich@novell.com
- Update config files (MINIX_FS=m globally, NTFS_FS off for -ec2).
- supported.conf: Add fs/minix.
* Tue Oct 27 2009 jkosina@suse.de
- patches.fixes/percpu-allow-pcpu_alloc-to-be-called-with-IRQs-off:
  percpu: allow pcpu_alloc() to be called with IRQs off
  (bnc#548119).
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  Update to newer version which is going to be merged upstream.
* Fri Oct 23 2009 jeffm@suse.com
- Update to 2.6.32-rc5-git3.
* Fri Oct 23 2009 mmarek@suse.cz
- Update config files: set NR_CPUS back to 2048 for ia64/vanilla
  until there is a fix in mainline.
* Fri Oct 23 2009 mmarek@suse.cz
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  fix for !CONFIG_SMP.
* Fri Oct 23 2009 mmarek@suse.cz
- patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch:
  Cleanup and make boot splash work with KMS (bnc#544645).
* Thu Oct 22 2009 jeffm@suse.com
- Re-enabled NR_CPUS=4096 on ia64.
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  sched: move rq_weight data array out of .percpu (bnc#548119).
* Tue Oct 20 2009 jbeulich@novell.com
- Update x86-64 Xen config file (NR_CPUS=512).
- Refresh a few Xen patches.
- rpm/kernel-binary.spec.in: Handle -ec2 flavor.
- rpm/package-descriptions: Describe -ec2 flavor.
- rpm/post.sh: Handle -ec2 flavor.
* Tue Oct 20 2009 jbeulich@novell.com
- patches.fixes/use-totalram_pages: Delete.
* Tue Oct 20 2009 jbeulich@novell.com
- config.conf: Add -ec2 configs (fate#305273)
- Add ec2 config files.
- patches.xen/xen-unpriv-build: No need to build certain bits
  when building non-privileged kernel.
- supported.conf: Add fs/nls/nls_base.
* Mon Oct 19 2009 jeffm@suse.com
- Temporarily reduce NR_CPUS to 2048 on ia64 to avoid build
  failures (bnc#548119)
* Mon Oct 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: [s390x] ignore errors from
  dwarfextract for now.
* Fri Oct 16 2009 mmarek@suse.cz
- Update config files: set CONFIG_ENTERPRISE_SUPPORT=y.
* Fri Oct 16 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix the logic for determining the base
  package in the %%post scripts.
* Fri Oct 16 2009 jeffm@suse.com
- Update config files.
* Fri Oct 16 2009 jeffm@suse.com
- Update to 2.6.32-rc5.
* Fri Oct 16 2009 mmarek@suse.de
- patches.rpmify/ia64-sn-fix-percpu-warnings: ia64/sn: fix
  percpu warnings.
* Fri Oct 16 2009 mmarek@suse.de
- Update config files: disable MTD_GPIO_ADDR, VME_CA91CX42 and
  VME_TSI148 on ia64 to fix build.
* Fri Oct 16 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: undo the -base merge for now.
* Fri Oct 16 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: mark kernel-source as arch dependent
  again. The content is noarch, but changing the rpm architecture
  breaks online update.
* Fri Oct 16 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.32-rc4: Fix AGP for PowerPC.
* Fri Oct 16 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32-rc4 and c/s 938.
- config.conf: Re-enable Xen.
- Update x86 config files.
* Tue Oct 13 2009 jeffm@suse.com
- patches.rpmify/staging-missing-sched.h: Added missing sites.
* Mon Oct 12 2009 jeffm@suse.com
- patches.rpmify/staging-missing-sched.h: staging: Complete
  sched.h removal from interrupt.h.
* Mon Oct 12 2009 jeffm@suse.de
- patches.apparmor/ptrace_may_access-fix: apparmor:
  ptrace_may_access -> ptrace_access_check.
* Mon Oct 12 2009 jeffm@suse.de
- Update config files.
* Mon Oct 12 2009 jeffm@suse.de
- Updated to 2.6.32-rc4.
  - Eliminated 4 patches.
  - Refreshed context.
* Mon Oct 12 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: Refresh and enable.
* Fri Oct  9 2009 jeffm@suse.de
- Cleanup unused patches:
  - patches.fixes/iwl3945-fix-rfkill.patch: Delete.
  - patches.fixes/iwlagn-fix-rfkill.patch: Delete.
  - patches.suse/kdb-serial-8250: Delete.
  - patches.suse/kdb-sysctl-context: Delete.
* Fri Oct  9 2009 jeffm@suse.de
- patches.fixes/scsi-add-tgps-setting: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.arch/x86_64-hpet-64bit-timer.patch: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.suse/kbuild-icecream-workaround: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.rpmify/spin_is_contended-fix: Delete.
* Fri Oct  9 2009 jeffm@suse.de
- patches.arch/mm-avoid-bad-page-on-lru: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- Update vanilla config files.
* Fri Oct  9 2009 jeffm@suse.de
- Update to 2.6.32-rc3.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/tsi148-dependency: vme/tsi148: Depend on VIRT_TO_BUS
* Thu Oct  8 2009 jeffm@suse.de
- patches.suse/kdb-x86-build-fixes: kdb: Use $srctree not $TOPDIR
  in Makefile.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/winbond-prepare_multicast: winbond: implement
  prepare_multicast and fix API usage.
- patches.rpmify/winbond_beacon_timers: winbond: use
  bss_conf->beacon_int instead of conf->beacon_int.
- patches.rpmify/winbond-build-fixes: Delete.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/rtl8192e-build-fixes: rtl8192e: Add #include
  <linux/vmalloc.h>.
* Thu Oct  8 2009 jeffm@suse.de
- patches.suse/kdb-build-fixes: kdb: Build fixes.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/iio-s390-build-fix: iio: Don't build on s390.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/winbond-build-fixes: winbond: API fix.
* Thu Oct  8 2009 jeffm@suse.de
- Update vanilla config files.
* Thu Oct  8 2009 jeffm@suse.de
- Update config files.
* Thu Oct  8 2009 jeffm@suse.de
- Updated to 2.6.32-rc1 (AKA 2.6.32-rc2).
  - Eliminated 28 patches.
  - 14 patches need further review.
  - Xen and AppArmor are currently disabled.
  - USB support in KDB is disabled.
* Wed Oct  7 2009 gregkh@suse.de
- patches.kernel.org/patch-2.6.31.2-3: Linux 2.6.31.3.
  - major tty bugfix
* Wed Oct  7 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc268-automic-fix: ALSA: hda -
  Fix yet another auto-mic bug in ALC268 (bnc#544899).
* Wed Oct  7 2009 knikanth@suse.de
- patches.suse/block-seperate-rw-inflight-stats: Fix the regression,
  "iostat reports wrong service time and utilization", introduced
  by this patch  (bnc#544926).
* Tue Oct  6 2009 gregkh@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Delete.
- patches.xen/xen3-x86-mark_rodata_rw.patch: Delete.
  - both of these were not being used anyway.
* Tue Oct  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31.2.
* Tue Oct  6 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc660vd-asus-a7k-fix: ALSA: hda -
  Add a workaround for ASUS A7K (bnc#494309).
* Mon Oct  5 2009 gregkh@suse.de
- refresh patch fuzz due to 2.6.31.2 import.
* Mon Oct  5 2009 gregkh@suse.de
- Update to Linux 2.6.31.2:
  - bugfixes, lots of them.
  - security fixes
* Mon Oct  5 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc861-toshiba-fix: ALSA: hda -
  Fix invalid initializations for ALC861 auto mode (bnc#544161).
* Fri Oct  2 2009 gregkh@suse.de
- Update config files.
- patches.drivers/add-via-chrome9-drm-support.patch: Delete.
  The code never got upstream and looks incorrect.
* Fri Oct  2 2009 tiwai@suse.de
- patches.drivers/alsa-ctxfi-04-fix-surround-side-mute: ALSA:
  ctxfi: Swapped SURROUND-SIDE mute.
- patches.drivers/alsa-hda-2.6.32-rc1-toshiba-fix: ALSA: hda -
  Added quirk to enable sound on Toshiba NB200.
- patches.drivers/alsa-hda-2.6.32-rc2: ALSA: backport 2.6.32-rc2
  fixes for HD-audio.
* Thu Oct  1 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31.1 and c/s 934.
* Thu Oct  1 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete quickcam-kmp (bnc#543361).
* Wed Sep 30 2009 gregkh@suse.de
- Update to 2.6.31.1
  - lots of bugfixes
  - security fixes
* Tue Sep 29 2009 trenn@suse.de
- Disabled patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch
  with +trenn (bnc#542767)
* Wed Sep 23 2009 teheo@suse.de
- Update config files.  Build pci-stub driver into the kernel so that
  built in pci drivers can be blocked from attaching to devices.
* Tue Sep 22 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage: when building against Linus'
  kernels (2.6.x), append a .0 to the kernel version embedded in
  the KMP version, to ensure that such KMP is older than a KMP
  built against a subsequent stable kernel (2.6.x.y, y > 0).
* Mon Sep 21 2009 jeffm@suse.de
- Update config files.
* Mon Sep 21 2009 jeffm@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: Ported to
  2.6.31 (bnc#533555).
* Sat Sep 19 2009 mmarek@suse.cz
- rpm/postun.sh: do not remove the bootloader entry if the kernel
  version didn't change (bnc#533766).
* Sat Sep 19 2009 mmarek@suse.cz
- rpm/postun.sh: remove dead code.
* Fri Sep 18 2009 jeffm@suse.de
- patches.fixes/reiserfs-replay-honor-ro: reiserfs: Properly
  honor read-only devices (bnc#441062).
* Thu Sep 17 2009 jeffm@suse.de
- patches.arch/acpi_srat-pxm-rev-ia64.patch: Use SRAT table rev
  to use 8bit or 16/32bit PXM fields (ia64) (bnc#503038).
- patches.arch/acpi_srat-pxm-rev-store.patch: Store SRAT table
  revision (bnc#503038).
- patches.arch/acpi_srat-pxm-rev-x86-64.patch: Use SRAT table
  rev to use 8bit or 32bit PXM fields (x86-64) (bnc#503038).
* Thu Sep 17 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-rc1: ALSA HD-audio backport
  from 2.6.32-rc1.
* Wed Sep 16 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31 final.
* Tue Sep 15 2009 teheo@suse.de
  Backport attach inhibition for builtin pci drivers from 2.6.32-rc.
- patches.drivers/pci-separate-out-pci_add_dynid: pci: separate
  out pci_add_dynid().
- patches.drivers/pci_stub-add-ids-parameter: pci-stub: add
  pci_stub.ids parameter.
* Tue Sep 15 2009 teheo@suse.de
  Backport patches from 2.6.32-rc to ease ossp testing.
- Update config files - SOUND_OSS_CORE_PRECLAIM is set to N.
- patches.drivers/implement-register_chrdev: chrdev: implement
  __register_chrdev().
- patches.drivers/sound-make-oss-device-number-claiming-optional:
  sound: make OSS device number claiming optional and schedule
  its removal.
- patches.drivers/sound-request-char-major-aliases-for-oss-devices:
  sound: request char-major-* module aliases for missing OSS
  devices.
* Mon Sep 14 2009 sdietrich@suse.de
- patches.suse/novfs-client-module: Update header todo list with
  locking nits (semaphore used as mutex / completion)
* Mon Sep 14 2009 jeffm@suse.com
- Revert back to CONFIG_M586TSC from CONFIG_M686 for default flavor
  (bnc#538849)
* Fri Sep 11 2009 jbeulich@novell.com
- patches.suse/crasher-26.diff: Add capability to also trigger a
  kernel warning.
* Fri Sep 11 2009 knikanth@suse.de
- patches.suse/block-seperate-rw-inflight-stats: Seperate read
  and write statistics of in_flight requests (fate#306525).
* Thu Sep 10 2009 gregkh@suse.de
- patch fuzz removal now that 2.6.31 is the base.
* Thu Sep 10 2009 gregkh@suse.de
- Update config files.
    CONFIG_MOUSE_PS2_ELANTECH=y
    CONFIG_MOUSE_PS2_TOUCHKIT=y
    (bnc#525607)
* Thu Sep 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-pre: Refresh: fix misc realtek
  issues, add another Nvidia HDMI device id
* Thu Sep 10 2009 jeffm@suse.de
- Updated to 2.6.31-final.
* Tue Sep  8 2009 gregkh@suse.de
- refresh patches for fuzz due to upstream changes
* Tue Sep  8 2009 gregkh@suse.de
- Update to 2.6.31-rc9
  - obsoletes:
  - patches.drivers/alsa-hda-fix-01-add-missing-mux-for-vt1708
  - patches.drivers/alsa-hda-fix-02-mbp31-hp-fix
* Tue Sep  8 2009 knikanth@suse.de
- patches.fixes/scsi_dh-Provide-set_params-interface-in-emc-device-handler.patch:
  scsi_dh: Provide set_params interface in emc device handler
  (bnc#521607).
- patches.fixes/scsi_dh-Use-scsi_dh_set_params-in-multipath.patch:
  scsi_dh: Use scsi_dh_set_params() in multipath. (bnc#521607).
- patches.fixes/scsi_dh-add-the-interface-scsi_dh_set_params.patch:
  scsi_dh: add the interface scsi_dh_set_params() (bnc#521607).
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: delete obsolete macro.
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: require minimum versions of
  module-init-tools and perl-Bootloader, the %%post script is no
  longer compatible with ancient versions.
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete %%name-base <= 2.6.31, the
  previous <= 2.6.30-1 didn't catch some cases obviously
  (bnc#533766).
* Fri Sep  4 2009 jeffm@suse.de
- Enabled CONFIG_SCSI_DEBUG=m (bnc#535923).
* Fri Sep  4 2009 mmarek@suse.cz
- kabi/severities, rpm/kabi.pl, rpm/kernel-binary.spec.in,
- rpm/kernel-source.spec.in: Use a simple script to check kabi by
  comparing Module.symvers files (similar to the old SLES9 one).
- rpm/built-in-where: Delete.
- rpm/symsets.pl: Delete.
- kabi/commonsyms: Delete.
- kabi/usedsyms: Delete.
* Fri Sep  4 2009 mmarek@suse.cz
- patches.suse/kbuild-rebuild-fix-for-Makefile.modbuiltin:
  kbuild: rebuild fix for Makefile.modbuiltin.
* Thu Sep  3 2009 gregkh@suse.de
- patches.drivers/usb-storage-increase-the-bcd-range-in-sony-s-bad-device-table.patch:
  Delete, it was wrong.
* Wed Sep  2 2009 jbeulich@novell.com
- Update Xen config files.
* Wed Sep  2 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc8 and c/s 931.
- patches.fixes/use-totalram_pages: use totalram_pages in favor
  of num_physpages for sizing boot time allocations (bnc#509753).
- patches.xen/xen-x86-per-cpu-vcpu-info: x86: use per-cpu storage
  for shared vcpu_info structure.
* Wed Sep  2 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-pre: Refresh; merged fixes for
  IDT92HD73* codecs
* Tue Sep  1 2009 jeffm@suse.com
- patches.apparmor/apparmor.diff: Update to latest git.
* Tue Sep  1 2009 jeffm@suse.com
- patches.arch/add_support_for_hpet_msi_intr_remap.patch:
  intr-remap: generic support for remapping HPET MSIs
  (bnc#532758).
- patches.arch/add_x86_support_for_hpet_msi_intr_remap.patch:
  x86: arch specific support for remapping HPET MSIs (bnc#532758).
* Tue Sep  1 2009 mmarek@suse.cz
- rpm/package-descriptions: fix description of the x86_64
  kernel-desktop package (bnc#535457).
* Mon Aug 31 2009 jeffm@suse.com
- Update to 2.6.31-rc8.
  - Eliminated 1 patch.
* Mon Aug 31 2009 tiwai@suse.de
- patches.drivers/alsa-hda-fix-01-add-missing-mux-for-vt1708:
  ALSA: hda - Add missing mux check for VT1708 (bnc#534904).
- patches.drivers/alsa-hda-fix-02-mbp31-hp-fix: ALSA: hda -
  Fix MacBookPro 3,1/4,1 quirk with ALC889A.
- patches.drivers/alsa-hda-2.6.32-pre: Refresh.
* Wed Aug 26 2009 tiwai@suse.de
- patches.drivers/alsa-hda-[0-9]*: Delete, fold into a single patch
  patches.drivers/alsa-hda-2.6.32-pre
* Tue Aug 25 2009 gregkh@suse.de
- Update config files.
- patches.drivers/samsung-backlight-driver.patch: Delete.
* Tue Aug 25 2009 jbeulich@novell.com
- scripts/run_oldconfig.sh: Consistently use $prefix.
* Mon Aug 24 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete %%name-base <= 2.6.30-1
  (bnc#530752).
* Mon Aug 24 2009 jeffm@suse.com
- Update to 2.6.31-rc7.
  - Eliminated 3 patches.
* Mon Aug 24 2009 jeffm@suse.com
- Update config files: Enable CONFIG_PROC_EVENTS.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/post.sh: Do not call /sbin/module_upgrade, the rename
  happened before SLES10.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/module-renames: Delete, we don't need to care about modules
  renamed before SLES10. Also, current mkinitrd gets the list of
  storage drivers based on pci ids.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/post.sh, rpm/postun.sh: drop support for SLE10, the package
  can't be installed on SLE10 as is, so why not make it more
  adventurous.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: remove product(openSUSE) supplements
  from the -extra subpackage which doesn't exist on openSUSE
  anymore.
* Thu Aug 20 2009 tiwai@suse.de
- patches.drivers/alsa-hda-fix-0*: Backport from 2.6.31-rc fixes
  (to be merged)
- patches.drivers/alsa-hda-32-Reword-auto-probe-messages: Refresh.
- patches.drivers/alsa-hda-33-IDT-codec-updates: Refresh.
* Thu Aug 20 2009 jbeulich@novell.com
- Update config files (modularize crypto again).
- supported.conf: Add resulting modules as supported.
* Wed Aug 19 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc6 and c/s 928.
* Tue Aug 18 2009 tiwai@suse.de
- patches.drivers/alsa-hda-48-alc268-oops-fix: ALSA: hda -
  Fix invalid capture mixers with some ALC268 models.
* Tue Aug 18 2009 gregkh@suse.de
- patches.drivers/usb-storage-increase-the-bcd-range-in-sony-s-bad-device-table.patch:
  USB: storage: increase the bcd range in Sony's bad device
  table. (bnc#466554).
* Mon Aug 17 2009 gregkh@suse.de
- patches.drivers/samsung-backlight-driver.patch: Change the range from
  0-255 to 0-7 to make it easier for HAL to handle the device without a
  need for custom scripts.
* Mon Aug 17 2009 jeffm@suse.com
- Updated to 2.6.31-rc6.
* Sun Aug 16 2009 gregkh@suse.de
- patches.drivers/samsung-backlight-driver.patch: added N120 support
  and some other devices that were integrated into the driver from
  upstream.
* Sun Aug 16 2009 coly.li@suse.de
- supported.conf:
  set kernel/fs/dlm/dlm as unsupported, since fs/dlm is provided
  separately in the ocfs2 KMP package
* Sat Aug 15 2009 tiwai@suse.de
- patches.drivers/alsa-hda-47-idt92hd8x-fix: ALSA: hda - Fix /
  clean up IDT92HD83xxx codec parser (bnc#531533).
* Sat Aug 15 2009 gregkh@suse.de
- Update config files.
- patches.drivers/samsung-backlight-driver.patch: Samsung
  backlight driver (bnc#527533, bnc#531297).
* Fri Aug 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add some hints how to set the %%jobs
  macro (bnc#530535).
* Fri Aug 14 2009 mmarek@suse.cz
- rpm/modversions: for overriden functions, keep the keyword in
  - -pack.
* Thu Aug 13 2009 jeffm@suse.com
- Updated to 2.6.31-rc5-git9.
  - Eliminated 7 patches.
* Thu Aug 13 2009 tiwai@suse.de
- patches.drivers/alsa-hda-42-hp-more-quirk: ALSA: hda - Add
  quirks for some HP laptops (bnc#527284).
- patches.drivers/alsa-hda-4[35]-*: Improve Realtek codec mic
  support
- patches.drivers/alsa-hda-46-stac-lo-detect-fix: ALSA: hda -
  Enable line-out detection only with speakers (bnc#520975).
* Wed Aug 12 2009 mmarek@suse.cz
- rpm/split-modules, rpm/kernel-binary.spec.in: add the base files
  also to the main package. That way, kernel-$flavor-base is not
  needed in normal setups (fate#307154).
* Wed Aug 12 2009 mmarek@suse.cz
- rpm/find-provides: no rpm provides for drivers/staging. It's
  higly unlikely that any KMP would require them and they just
  take up space in the rpm metadata.
* Tue Aug 11 2009 tiwai@suse.de
- patches.drivers/alsa-hda-41-msi-white-list: ALSA: hda - Add
  a white-list for MSI option (bnc#529971).
* Tue Aug 11 2009 tiwai@suse.de
- patches.drivers/alsa-hda-39-dont-override-ADC-definitions:
  ALSA: hda - Don't override ADC definitions for ALC codecs
  (bnc#529467).
- patches.drivers/alsa-hda-40-auto-mic-support-for-realtek:
  ALSA: hda - Add auto-mic support for Realtek codecs.
* Tue Aug 11 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: do not rename kernel-source.rpmlintrc
  for the -rt variant.
* Mon Aug 10 2009 mmarek@suse.cz
- patches.rpmify/staging-rtl8192su-fix-build-error.patch: move to
  patches.rpmify to fix vanilla ppc builds.
* Mon Aug 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-38-fix-ALC269-vmaster: ALSA: hda -
  Add missing vmaster initialization for ALC269 (bnc#527361).
* Mon Aug 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-33-IDT-codec-updates: Refresh.
* Fri Aug  7 2009 jeffm@suse.com
- patches.fixes/recordmcount-fixup: recordmcount: Fixup wrong
  update_funcs() call.
* Fri Aug  7 2009 tiwai@suse.de
- patches.drivers/alsa-soc-fsl-build-fixes: ASoC: Add missing
  DRV_NAME definitions for fsl/* drivers (to fix PPC builds)
* Fri Aug  7 2009 tiwai@suse.de
- patches.arch/wmi-Fix-kernel-panic-when-stack-protection-enabled:
  wmi: Fix kernel panic when stack protection
  enabled. (bnc#529177).
- supported.conf: Update HD-audio modules
* Fri Aug  7 2009 mmarek@suse.cz
- make config/s390/vanilla a symlink again.
* Fri Aug  7 2009 mmarek@suse.de
- rpm/kernel-binary.spec.in: do not manually extract vmlinux
  debuginfo on ppc(64), rpm does it itself.
* Thu Aug  6 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in: Added kernel-spec-macros to Sources.
* Thu Aug  6 2009 jeffm@suse.de
- patches.suse/linux-2.6.29-even-faster-kms.patch: Disabled. It
  doesn't wake up the display on certain hardware.
* Wed Aug  5 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: do not split the -extra subpackage on
  openSUSE (bnc#528097).
* Wed Aug  5 2009 jeffm@suse.de
- Updated to 2.6.31-rc5-git3.
  - Eliminated 4 patches.
* Wed Aug  5 2009 gregkh@suse.de
- kernel-source.changes: remove old (pre 2008) messages, and move 2008
  to kernel-source.changes.old.  No need to spam email addresses that
  are no longer with the company for failed kernel builds.
* Wed Aug  5 2009 gregkh@suse.de
- patches.drivers/staging-rtl8192su-fix-build-error.patch:
  Staging: rtl8192su: fix build error.
* Wed Aug  5 2009 jeffm@suse.de
- patches.suse/supported-flag-enterprise: Make the supported
  flag configurable at build time (bnc#528097).
* Wed Aug  5 2009 gregkh@suse.de
- Update config files.
  disable CONFIG_DRM_RADEON_KMS as per bnc#527910 for vanilla builds
* Tue Aug  4 2009 gregkh@suse.de
- Update config files.
  disable CONFIG_DRM_RADEON_KMS as per bnc#527910
* Tue Aug  4 2009 jeffm@suse.de
- patches.rpmify/ttm-pgprot-fixes: ttm: Use pgprot_val for
  comparing pgprot_t.
* Tue Aug  4 2009 tiwai@suse.de
- patches.drivers/alsa-hda-3[0-8]*: ALSA HD-audio updates
- Update config files: enable CONFIG_SND_HDA_CIRRUS=y
* Mon Aug  3 2009 jeffm@suse.de
- Update config files: CONFIG_FRAME_WARN=2048 on all arches, fixes
  ppc build failures.
* Mon Aug  3 2009 jeffm@suse.de
- patches.xen/xen3-patch-2.6.31-rc4-rc5: Fixup pgtable port
* Mon Aug  3 2009 jeffm@suse.de
- Updated to 2.6.31-rc5.
  - Eliminated 11 patches.
* Mon Aug  3 2009 coly.li@suse.de
- Update config files to enable CONFIG_DLM_DEBUG.
* Fri Jul 31 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc4 and c/s 916.
- patches.xen/xen3-driver-core-misc-add-nodename-support-for-misc-devices.patch:
  Delete.
- patches.xen/xen3-panic-on-io-nmi.diff: Delete.
- config.conf: Re-enable Xen.
- Update config files.
* Wed Jul 29 2009 tiwai@suse.de
- Update config files: revert to CONFIG_SND=m and enabled again
  CONFIG_SND_DEBUG=y
* Tue Jul 28 2009 mmarek@suse.cz
- Update config files: disable CONFIG_PRISM2_USB on ia64 and ppc.
* Tue Jul 28 2009 mmarek@suse.cz
- Update config files: disable CONFIG_FB_UDL on ia64.
* Tue Jul 28 2009 jbeulich@novell.com
- config.conf: Remove duplicate i386/desktop entry.
* Tue Jul 28 2009 tiwai@suse.de
- patches.drivers/alsa-hda-29-Add-quirk-for-Dell-Studio-1555:
  ALSA: hda - Add quirk for Dell Studio 1555 (bnc#525244).
* Mon Jul 27 2009 tiwai@suse.de
- patches.drivers/alsa-pcm-*: ALSA PCM fixes
- Fix/enhancement patches backported from ALSA tree
  * patches.drivers/alsa-core-Add-new-TLV-types-for-dBwith-min-max:
    ALSA: Add new TLV types for dBwith min/max (for usb).
  * patches.drivers/alsa-ctxfi-*: SB X-Fi support (FATE#306935).
  * patches.drivers/alsa-hda-*: More HD-audio fixes
  * patches.drivers/alsa-ice-*: ICE17xx fixes
  * patches.drivers/alsa-midi-*: MIDI fixes
  * patches.drivers/alsa-usb-*: USB-audio/MIDI fixes
- Remove obsoleted patches: patches.drivers/alsa-ad1984a-hp-quirks,
  patches.drivers/alsa-ca0106-capture-bufsize-fix,
  patches.drivers/alsa-ctxfi
- Update config files.
* Mon Jul 27 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, scripts/tar-up.sh: really drop
  config-subst from the package.
* Mon Jul 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: manually create a -devel-debuginfo
  subpackage with vmlinux.debug to fix build with new rpm. This
  works for ix86 and x86_64, other archs might need further fixes.
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: more ia64 fixes
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: rtl8192su: compile fixes.
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: rtl8192su: compile fixes.
* Sat Jul 25 2009 jeffm@suse.de
- config.conf: Re-enabled trace flavor.
* Fri Jul 24 2009 jeffm@suse.de
- Update config files: Disabled optimize for size on i386 and x86_64
  across all flavors.
* Fri Jul 24 2009 jeffm@suse.de
- Update to 2.6.31-rc4.
* Thu Jul 23 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: cleanup %%cpu_arch_flavor definition,
  make %%symbols a variable and only use it for selecting patches.
  Also drop the RT symbol as there are not rt patches currently.
* Thu Jul 23 2009 mmarek@suse.cz
- Change the s390(x) config layout so that each arch has its own
  subdirectory, as it is done for other archs. s390/vanilla is a
  symlink to s390x/vanilla.
* Thu Jul 23 2009 mmarek@suse.cz
- rpm/kernel-*.spec.in, rpm/kernel-spec-macros: move some common
  macros to kernel-spec-macros.
* Wed Jul 22 2009 tiwai@suse.de
- patches.drivers/alsa-ca0106-capture-bufsize-fix: ALSA: ca0106 -
  Fix the max capture buffer size (bnc#521890).
* Wed Jul 22 2009 tiwai@suse.de
- patches.drivers/alsa-ctxfi: Add SoundBlaster X-Fi support
  (FATE#306935).
- Update config files.
* Wed Jul 22 2009 trenn@suse.de
  These are mainline:
- patches.drivers/cpufreq_add_cpu_number_paramater_1.patch:
  Delete.
- patches.drivers/cpufreq_add_idle_microaccounting_6.patch:
  Delete.
- patches.drivers/cpufreq_change_load_calculation_2.patch: Delete.
- patches.drivers/cpufreq_changes_to_get_cpu_idle_us_5.patch:
  Delete.
- patches.drivers/cpufreq_get_cpu_idle_time_changes_3.patch:
  Delete.
- patches.drivers/cpufreq_parameterize_down_differential_4.patch:
  Delete.
* Wed Jul 22 2009 trenn@suse.de
  These are mainline:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Delete.
- patches.arch/thinkpad_fingers_off_backlight_igd.patch: Delete.
* Tue Jul 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: remove double-slash from include2/asm
  symlink.
* Tue Jul 21 2009 mmarek@suse.cz
- config.conf, rpm/mkspec: exclude trace, kdump and ia64/debug from
  the kernel-syms package. These flavor are often excluded in KMPs,
  so excluding them from kernel-syms reduces useless build
  dependencies. KMPs can buildrequire kernel-$flavor-devel
  explicitely if desired.
* Tue Jul 21 2009 mmarek@suse.cz
  Delete obsolete apparmor patches.
- patches.apparmor/add-path_permission.diff: Delete.
- patches.apparmor/add-security_path_permission: Delete.
- patches.apparmor/apparmor-2.6.25.diff: Delete.
- patches.apparmor/apparmor-audit.diff: Delete.
- patches.apparmor/apparmor-intree.diff: Delete.
- patches.apparmor/apparmor-lsm.diff: Delete.
- patches.apparmor/apparmor-main.diff: Delete.
- patches.apparmor/apparmor-misc.diff: Delete.
- patches.apparmor/apparmor-module_interface.diff: Delete.
- patches.apparmor/apparmor-network.diff: Delete.
- patches.apparmor/apparmor-path_permission: Delete.
- patches.apparmor/apparmor-ptrace-2.6.27.diff: Delete.
- patches.apparmor/apparmor-rlimits.diff: Delete.
- patches.apparmor/d_namespace_path.diff: Delete.
- patches.apparmor/d_namespace_path_oops_fix.diff: Delete.
- patches.apparmor/do_path_lookup-nameidata.diff: Delete.
- patches.apparmor/export-security_inode_permission-for-aufs:
  Delete.
- patches.apparmor/file-handle-ops.diff: Delete.
- patches.apparmor/fix-complain.diff: Delete.
- patches.apparmor/fix-vfs_rmdir.diff: Delete.
- patches.apparmor/fork-tracking.diff: Delete.
- patches.apparmor/fsetattr-reintro-ATTR_FILE.diff: Delete.
- patches.apparmor/fsetattr-restore-ia_file.diff: Delete.
- patches.apparmor/fsetattr.diff: Delete.
- patches.apparmor/remove_suid.diff: Delete.
- patches.apparmor/security-create.diff: Delete.
- patches.apparmor/security-getxattr.diff: Delete.
- patches.apparmor/security-link.diff: Delete.
- patches.apparmor/security-listxattr.diff: Delete.
- patches.apparmor/security-mkdir.diff: Delete.
- patches.apparmor/security-mknod.diff: Delete.
- patches.apparmor/security-readlink.diff: Delete.
- patches.apparmor/security-removexattr.diff: Delete.
- patches.apparmor/security-rename.diff: Delete.
- patches.apparmor/security-rmdir.diff: Delete.
- patches.apparmor/security-setattr.diff: Delete.
- patches.apparmor/security-setxattr.diff: Delete.
- patches.apparmor/security-symlink.diff: Delete.
- patches.apparmor/security-unlink.diff: Delete.
- patches.apparmor/security-xattr-file.diff: Delete.
- patches.apparmor/sysctl-pathname.diff: Delete.
- patches.apparmor/unambiguous-__d_path.diff: Delete.
- patches.apparmor/vfs-getxattr.diff: Delete.
- patches.apparmor/vfs-link.diff: Delete.
- patches.apparmor/vfs-listxattr.diff: Delete.
- patches.apparmor/vfs-mkdir.diff: Delete.
- patches.apparmor/vfs-mknod.diff: Delete.
- patches.apparmor/vfs-notify_change.diff: Delete.
- patches.apparmor/vfs-removexattr.diff: Delete.
- patches.apparmor/vfs-rename.diff: Delete.
- patches.apparmor/vfs-rmdir.diff: Delete.
- patches.apparmor/vfs-setxattr.diff: Delete.
- patches.apparmor/vfs-symlink.diff: Delete.
- patches.apparmor/vfs-unlink.diff: Delete.
* Tue Jul 21 2009 npiggin@suse.de
- Update config files for bnc#522686 -- set
  CONFIG_SECURITY_DEFAULT_MMAP_MIN_ADDR=65536.
* Mon Jul 20 2009 jeffm@suse.de
- Update config files: Disabled optimize for size on all flavors
  (FATE#305694)
* Mon Jul 20 2009 jeffm@suse.de
- Update config files.
* Mon Jul 20 2009 jeffm@suse.com
- Update to 2.6.30.2
  - lots of security and bug fixes
  - Obsoleted patches.fixes/firmware-memmap-64bit.diff
* Mon Jul 20 2009 mmarek@suse.cz
- rpm/split-modules: set LC_COLLATE=C
* Sat Jul 18 2009 jeffm@suse.de
- rpm/package-descriptions: Added desktop description.
* Sat Jul 18 2009 jeffm@suse.de
- rpm/package-descriptions: Added desktop description.
* Sat Jul 18 2009 jeffm@suse.de
- Add -desktop flavors for i386 and x86_64
  - Disabled group scheduler and groups
  - Disabled optimize for size
  - Enabled full preemption
  - Set HZ=1000
* Sat Jul 18 2009 jeffm@suse.de
- Add -desktop flavors for i386 and x86_64 (FATE#305694)
  - Disabled group scheduler and groups
  - Disabled optimize for size
  - Enabled full preemption
  - Set HZ=1000
* Fri Jul 17 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: ia64 build fix
* Fri Jul 17 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: simplify the add_dirs_to_filelist
  function and make it less chatty in build logs.
* Thu Jul 16 2009 jeffm@suse.com
- patches.apparmor/apparmor.diff: ia64 build fix
* Thu Jul 16 2009 jeffm@suse.com
- patches.apparmor/security-default-lsm: security: Define default
  LSM (bnc#442668).
* Thu Jul 16 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: AppArmor.
* Thu Jul 16 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: AppArmor.
* Thu Jul 16 2009 jeffm@suse.de
- patches.rpmify/sgi-hotplug-fixup: hotplug: fix sgi-hotplug
  attribute handling.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: drop the config-subst script, use
  scripts/config instead.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix debugsource generation.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/split-modules: fix last change.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/split-modules: fix for module names with underscores or
  dashes.
* Wed Jul 15 2009 jeffm@suse.de
- Update to 2.6.31-rc3.
  - Eliminated 2 patches.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: annotate in which products the
  obsoleted kmps were last used, remove "ralink-rt2860-kmp" which
  I couldn't find anywhere.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete btusb-kmp (bnc#514375).
* Tue Jul 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/split-modules: move generating of
  the base / main / unsupported module lists to a separate script.
  Avoids 6k modinfo calls and fixes module dependencies
  (bnc#512179).
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix include2/asm symlink (bnc#509680).
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/modversions: fix overriding of function symbols.
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/modversions: fix overriding of unknown symbols.
* Tue Jul  7 2009 jkosina@suse.de
- patches.suse/e1000e_allow_bad_checksum: Delete.
- patches.suse/e1000e_call_dump_eeprom: Delete.
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  Delete.
  Delete the leftover debugging patches for e1000e EEPROM corruption
  that are not needed anymore.
* Tue Jul  7 2009 aj@suse.de
- README.BRANCH: Update, kotd will become 11.2 eventually.
* Mon Jul  6 2009 jeffm@suse.com
- Update to 2.6.31-rc2.
* Fri Jul  3 2009 jeffm@suse.com
- Update to 2.6.31-rc1-git10.
  - Eliminated 28 patches.
  - Xen is disabled.
* Fri Jul  3 2009 mmarek@suse.cz
- patches.suse/kbuild-generate-modules.builtin: kbuild: generate
  modules.builtin.
- rpm/kernel-binary.spec.in: package modules.builtin for use by
  modprobe / mkinitrd.
* Fri Jul  3 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in: simplify
  the patch applying loops to reduce noise in build logs.
* Tue Jun 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: chmod +x find-provides
* Tue Jun 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: do not "annotate" the packaged
  Modules.symvers
- patches.suse/modpost-filter-out-built-in-depends: Delete.
* Tue Jun 30 2009 jbeulich@novell.com
- patches.arch/ia64-page-migration: Fix compiler warning.
* Mon Jun 29 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: move /boot/symvers* files back to
  - base, these are needed during KMP installation.
* Mon Jun 29 2009 mmarek@suse.cz
- patches.fixes/kbuild-fix-generating-of-.symtypes-files: kbuild:
  fix generating of *.symtypes files.
- patches.suse/genksyms-add-override-flag.diff: Refresh.
- rpm/kernel-binary.spec.in: create the *.symref files in the build
  directory
* Fri Jun 26 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add Provides: kernel-{base,extra} to
  the subpackages (bnc#516827).
* Wed Jun 24 2009 gregkh@suse.de
- Update config files.
  revert the ACPI and thermal config changes:
    config/i386/pae and config/x86-64/default:
  CONFIG_ACPI_AC=m
  CONFIG_ACPI_BATTERY=m
  CONFIG_ACPI_BUTTON=m
  CONFIG_ACPI_VIDEO=m
  CONFIG_ACPI_FAN=m
  CONFIG_ACPI_PROCESSOR=m
  CONFIG_ACPI_THERMAL=m
  CONFIG_ACPI_CONTAINER=m
  CONFIG_X86_ACPI_CPUFREQ=m
  CONFIG_THERMAL=m
* Wed Jun 24 2009 gregkh@suse.de
- patches.suse/ec_merge_irq_and_poll_modes.patch: Delete.
- patches.suse/linux-2.6.29-retry-root-mount.patch: Delete.
* Wed Jun 24 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30 and c/s 908.
- Update Xen config files.
- patches.xen/tmem: Transcendent memory ("tmem") for Linux.
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_ACPI_AC=y
  CONFIG_ACPI_BATTERY=y
  CONFIG_ACPI_BUTTON=y
  CONFIG_ACPI_VIDEO=y
  CONFIG_ACPI_FAN=y
  CONFIG_ACPI_PROCESSOR=y
  CONFIG_ACPI_THERMAL=y
  CONFIG_ACPI_CONTAINER=y
  CONFIG_X86_ACPI_CPUFREQ=y
  CONFIG_THERMAL=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_SND_TIMER=y
  CONFIG_SND_PCM=y
  CONFIG_SND_SEQUENCER=y
  CONFIG_SND_MIXER_OSS=y
  CONFIG_SND_PCM_OSS=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  fix up config mistake in x86-64/default made in last commit.
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_VIDEO_OUTPUT_CONTROL=y
  CONFIG_SOUND=y
  CONFIG_SND=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_I2C=y
  CONFIG_HWMON=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_IPV6=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_HID=y
  CONFIG_USB_STORAGE=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_ATA_PIIX=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_USB_EHCI_HCD=Y
  CONFIG_USB_OHCI_HCD=Y
  CONFIG_USB_UHCI_HCD=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_CFG80211=Y
  CONFIG_LIB80211=Y
  CONFIG_MAC80211=Y
  CONFIG_ATH5K=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_X86_MSR=Y
  CONFIG_X86_CPUID=Y
* Fri Jun 19 2009 gregkh@suse.de
- comment out broken acpi patch for the moment.
* Fri Jun 19 2009 gregkh@suse.de
- move the "preload" branch into master to get 2.6.30 working
  for Moblin.
- Update config files.
- patches.drivers/alsa-ad1984a-hp-quirks: ALSA: update HP
  quirks for Zenith & co (bnc#472789, bnc#479617, bnc#502425,
  bnc#503101).
- patches.suse/driver-core-add-nodename-callbacks.patch: Driver
  Core: add nodename callbacks.
- patches.suse/driver-core-aoe-add-nodename-for-aoe-devices.patch:
  Driver Core: aoe: add nodename for aoe devices.
- patches.suse/driver-core-block-add-nodename-support-for-block-drivers.patch:
  Driver Core: block: add nodename support for block drivers..
- patches.suse/driver-core-bsg-add-nodename-for-bsg-driver.patch:
  Driver Core: bsg: add nodename for bsg driver.
- patches.suse/driver-core-devtmpfs-driver-core-maintained-dev-tmpfs.patch:
  Driver Core: devtmpfs - kernel-maintained tmpfs-based /dev.
- patches.suse/driver-core-drm-add-nodename-for-drm-devices.patch:
  Driver Core: drm: add nodename for drm devices.
- patches.suse/driver-core-dvb-add-nodename-for-dvb-drivers.patch:
  Driver Core: dvb: add nodename for dvb drivers.
- patches.suse/driver-core-input-add-nodename-for-input-drivers.patch:
  Driver Core: input: add nodename for input drivers.
- patches.suse/driver-core-misc-add-nodename-support-for-misc-devices.patch:
  Driver Core: misc: add nodename support for misc devices..
- patches.suse/driver-core-raw-add-nodename-for-raw-devices.patch:
  Driver Core: raw: add nodename for raw devices.
- patches.suse/driver-core-sound-add-nodename-for-sound-drivers.patch:
  Driver Core: sound: add nodename for sound drivers.
- patches.suse/driver-core-usb-add-nodename-support-for-usb-drivers.patch:
  Driver Core: usb: add nodename support for usb drivers..
- patches.suse/driver-core-x86-add-nodename-for-cpuid-and-msr-drivers.patch:
  Driver Core: x86: add nodename for cpuid and msr drivers..
- patches.suse/ec_merge_irq_and_poll_modes.patch: ACPI: EC:
  Merge IRQ and POLL modes.
- patches.suse/linux-2.6.29-dont-wait-for-mouse.patch: fastboot:
  remove "wait for all devices before mounting root" delay.
- patches.suse/linux-2.6.29-enable-async-by-default.patch:
  enable async_enabled by default.
- patches.suse/linux-2.6.29-even-faster-kms.patch: speed up kms
  even more.
- patches.suse/linux-2.6.29-jbd-longer-commit-interval.patch:
  jbd: longer commit interval.
- patches.suse/linux-2.6.29-kms-after-sata.patch: make kms happen
  after sata.
- patches.suse/linux-2.6.29-retry-root-mount.patch: fastboot:
  retry mounting the root fs if we can't find init.
- patches.suse/linux-2.6.29-silence-acer-message.patch: Silence
  acer wmi driver on non-acer machines.
- patches.suse/linux-2.6.29-touchkit.patch: some new touch screen
  device ids
  .
- patches.suse/uvcvideo-ignore-hue-control-for-5986-0241.patch:
  uvcvideo: ignore hue control for 5986:0241 (bnc#499152).
- patches.suse/devtmpfs.patch: Delete.
* Fri Jun 12 2009 greg@suse.de
- scripts/sequence-patch.sh: fix bug in ketchup usage
* Wed Jun 10 2009 jeffm@suse.com
- Update to 2.6.30-final.
* Wed Jun 10 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30-rc8 and c/s 898.
- Update Xen config files.
- patches.xen/pci-reserve: linux/pci: reserve io/memory space
  for bridge.
- patches.xen/xen-x86-exports: Delete.
* Tue Jun  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: update copyright header and
  change indentation to what autobuild enforces on checkin. No
  functional change.
* Tue Jun  9 2009 jbeulich@novell.com
- patches.suse/stack-unwind-add-declaration.patch: Fold into ...
- patches.suse/stack-unwind: ... this one.
* Tue Jun  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: move /boot/vmlinux-*.gz to -devel
  again.
- rpm/find-provides: don't generate the ksym() provides ourself,
  let rpm do it. Add a workaround for vmlinux-*.gz in -devel.
* Mon Jun  8 2009 jeffm@suse.com
- patches.suse/reiser4-set_page_dirty_notag: mm: Add
  set_page_dirty_notag() helper for reiser4.
* Fri Jun  5 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage: add Enhances: kernel-$flavor to
  kmps (bnc#502092).
* Thu Jun  4 2009 jeffm@suse.de
- Update to 2.6.30-rc8.
* Thu Jun  4 2009 sdietrich@suse.de
- supported.conf: remove duplicate kernel/drivers/md/dm-log
* Thu Jun  4 2009 teheo@suse.de
  Conver ide major allocation.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_devt parameter (fate#305584).
* Mon Jun  1 2009 jeffm@suse.de
- Update to 2.6.30-rc7-git4.
* Fri May 29 2009 teheo@suse.de
  Rename mangle_minor to mangle_devt and also cover sd major allocation.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_devt parameter (fate#305584).
* Fri May 29 2009 teheo@suse.de
- Update config files to enable DEBUG_BLOCK_EXT_DEVT on all configs
  except for vanilla and ppc/ps3.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_minor parameter (fate#305584).
* Thu May 28 2009 jdelvare@suse.de
- patches.fixes/scsi-scan-blist-update: Add BLIST_REPORTLUN2 to
  EMC SYMMETRIX (bnc#185164, bnc#191648, bnc#505578).
* Wed May 27 2009 jeffm@suse.com
- Update to 2.6.30-rc7-git2.
* Wed May 27 2009 gregkh@suse.de
- patches.drivers/ath1e-add-new-device-id-for-asus-hardware.patch:
  ath1e: add new device id for asus hardware.
* Tue May 26 2009 mmarek@suse.cz
- rpm/mkspec: when using a custom release number, create a
  get_release_number.sh script for autobuild.
* Tue May 26 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: workaround for bnc#507084: strip
  binaries in /usr/src/linux-obj/*/*/scripts.
* Tue May 26 2009 jdelvare@suse.de
- patches.drivers/r8169-allow-true-forced-mode-setting.patch:
  r8169: allow true forced mode setting (bnc#467518).
* Mon May 25 2009 mmarek@suse.cz
- switch i386 flavors back to -default (non-pae) and -pae for
  milestone2
* Sun May 24 2009 mmarek@suse.cz
- rpm/find-provides: fix for kernel-kdump.
* Sat May 23 2009 mmarek@suse.cz
- rpm/find-provides, rpm/kernel-binary.spec.in, rpm/symsets.pl:
  workaround to fix provides of built-in symbols: move vmlinux*.gz
  back to -base and extract the provides from it.
* Fri May 22 2009 teheo@suse.de
- patches.arch/i586-unwind-quick-fix: i586-relocs: ignore NONE
  relocation.
* Fri May 22 2009 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh, rpm/mkspec, scripts/tar-up.sh: avoid
  unpacking the patches tarballs in compute-PATCHVERSION.sh.
* Fri May 22 2009 mmarek@suse.cz
- rpm/mkspec: add --release option to set a custom release string.
- scripts/tar-up.sh: revive -rs option.
* Wed May 20 2009 mmarek@suse.cz
- patches.arch/acpi_thermal_passive_blacklist.patch,
  patches.suse/devtmpfs.patch: fix patches to apply with git-apply.
* Tue May 19 2009 sdietrich@suse.de
- patches.suse/stack-unwind-add-declaration.patch: Fix compile
  error when CONFIG_STACK_UNWIND is not set.
* Tue May 19 2009 jblunck@suse.de
- patches.rpmify/arm-arch_include_asm-fix.diff: ARM: move
  mach-types.h to arch/include/asm.
* Tue May 19 2009 jeffm@suse.com
- Set CONFIG_FRAMEBUFFER_CONSOLE=y
* Tue May 19 2009 jeffm@suse.com
- Restored CONFIG_BOOTSPLASH=y and CONFIG_FB_VESA=y on
  x86/x86_64 (bnc#504608)
* Tue May 19 2009 jbeulich@novell.com
- patches.xen/sfc-endianness: fix building with gcc 4.4.
* Tue May 19 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30/rc6-git3 and c/s 873.
* Mon May 18 2009 jeffm@suse.com
- Updated to 2.6.30-rc6-git3.
  - Eliminated 4 patches.
* Fri May 15 2009 jeffm@suse.de
- doc/README.SUSE: Updated to reflect building in an external
  directory so as not to contaminate /usr/src/linux
* Thu May 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix path in
  /usr/src/linux-obj/.../Makefile.
* Thu May 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: provide kernel-$flavor-devel =
  %%version-%%source_rel in the -devel packages (bnc#503280).
* Wed May 13 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: also fix kernel-$flavor-devel requires
  (bnc#503280).
* Wed May 13 2009 mmarek@suse.cz
- rpm/mkspec: fix kernel-syms requires (bnc#503280).
* Mon May 11 2009 jeffm@suse.com
- patches.fixes/dup2-retval-fix: dup2: Fix return value with
  oldfd == newfd and invalid fd (bnc#498042).
* Mon May 11 2009 jeffm@suse.com
- patches.fixes/reiserfs-xattr-fixup: reiserfs: clean up ifdefs.
- patches.fixes/reiserfs-xattr-root-fixup: reiserfs: deal with
  NULL xattr root w/ xattrs disabled.
- patches.fixes/reiserfs-xattrs-disabled-perms: reiserfs: fixup
  perms when xattrs are disabled.
- patches.fixes/reiserfs-expose-privroot: reiserfs: allow exposing
  privroot w/ xattrs enabled.
* Mon May 11 2009 jeffm@suse.de
- Updated to 2.6.30-rc5-git1.
  - Eliminated 4 patches.
* Wed May  6 2009 gregkh@suse.de
- Update config files. update vanilla configs so that the build works.
* Wed May  6 2009 gregkh@suse.de
- Update config files.
- patches.suse/devtmpfs.patch: driver-core: devtmpfs - driver-core
  maintained /dev tmpfs.
* Tue May  5 2009 jeffm@suse.com
- Update config files.
* Tue May  5 2009 jeffm@suse.com
- Update to 2.6.30-rc4-git1.
- patches.rpmify/fix-unexpected-non-allocable-warnings-with-suse-gcc:
  kbuild, modpost: fix "unexpected non-allocatable" warning with
  SUSE gcc.
* Tue May  5 2009 jbeulich@novell.com
- patches.fixes/iwl3945-build: iwl3945: fix ia64/ppc build.
* Tue May  5 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.30-rc4: Fix ia64 build.
* Tue May  5 2009 jbeulich@novell.com
- patches.suse/stack-unwind: Also initialize PT_GS() on 32-bit.
- patches.arch/x86_64-unwind-annotations: Refresh.
* Tue May  5 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29-rc4 and c/s 867.
- Update i386 and x86_64 config files.
- config.conf: Re-enable Xen.
* Tue May  5 2009 teheo@suse.de
- patches.suse/kbuild-icecream-workaround: kbuild: add workaround
  for icecream bug (bnc#495786).
* Fri May  1 2009 jeffm@suse.com
- patches.fixes/reiserfs-xattr-locking: reiserfs: Expand i_mutex
  to enclose lookup_one_len.
* Fri May  1 2009 jeffm@suse.com
- Update to 2.6.30-rc4.
  - Eliminated 2 patches.
* Fri May  1 2009 jeffm@suse.com
- patches.drivers/libata-prefer-over-ide: libata: prefer libata
  drivers over ide ones (bnc#433105).
- patches.fixes/reiserfs-xattr-locking: reiserfs: Expand i_mutex
  to enclose lookup_one_len.
- patches.kernel.org/patch-2.6.30-rc3-rc4:
- patches.suse/no-frame-pointer-select: Fix stack unwinder Kconfig
  (bnc#402518).
- patches.arch/s390-08-05-af_iucv-msgpeek-fix.patch: Delete.
- patches.fixes/fix-periodic-mode-programming-on-amd81xx: Delete.
* Thu Apr 30 2009 mmarek@suse.cz
- scripts/submit-to-bs: tentative script to submit a new kernel to
  openSUSE:Factory
* Tue Apr 28 2009 npiggin@suse.de
- patches.apparmor/unambiguous-__d_path.diff: Put a reminder in here
  to fix the lock order problem when the patch is updated to HEAD.
* Mon Apr 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: Fix prepending EXTRAVERSION,
  rename the variable back to @RELEASE_PREFIX@.
* Mon Apr 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: prepend the EXTRAVERSION to
  the rpm release string (note that this won't have any effect in
  the openSUSE:* projects).
* Fri Apr 24 2009 gregkh@suse.de
- Update config files.
  - build rtc_cmos driver into the kernel for i386 and x86-64 default
    kernels.  This should automatically take care of the rtc/system time
    syncing so we don't need to do it in a boot script and should speed
    up booting time a lot.
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change CONFIG_ATA=y and CONFIG_SATA_AHCI=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to CONFIG_EXT2_FS=y and CONFIG_EXT3_FS=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to CONFIG_SCSI=y and CONFIG_BLK_DEV_SD=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to use CONFIG_USB=y
* Thu Apr 23 2009 jeffm@suse.de
- Added legacy config.
* Thu Apr 23 2009 jeffm@suse.de
- Temporarily disabled patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch
* Thu Apr 23 2009 jeffm@suse.de
- Moved i386 kernel-default to kernel-legacy.
- Moved i386 kernel-pae config to kernel-default.
- Disabled CONFIG_ISA in i386 kernel-default to improve boot speed.
* Thu Apr 23 2009 jeffm@suse.de
- Update to 2.6.30-rc3.
* Thu Apr 23 2009 jeffm@suse.de
- patches.fixes/fix-periodic-mode-programming-on-amd81xx: x86:
  hpet: fix periodic mode programming on AMD 81xx.
- patches.fixes/hpet-boot-fix: Delete.
* Mon Apr 20 2009 jeffm@suse.de
- patches.fixes/hpet-boot-fix: hpet: fix "IO-APIC + timer doesn't work!"
* Mon Apr 20 2009 jeffm@suse.de
- Update to 2.6.30-rc2-git6.
* Wed Apr 15 2009 jeffm@suse.de
- Update to 2.6.30-rc2.
  - trace and xen flavors disabled.
  - CONFIG_OTUS disabled on ppc.
  - request-based multipath could use some testing.
  - Eliminated 96 patches.
* Fri Apr 10 2009 jeffm@suse.de
- rpm/devel-post.sh, rpm/kernel-binary.spec.in: Created i586 symlink
  for i386.
* Fri Apr 10 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Added /usr/src/linux-obj to -devel
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Use xargs -r to fix case when no
  modules are supported.
* Fri Apr 10 2009 jeffm@suse.com
- Moved linux-obj symlink handling to kernel-$flavor-devel.
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/package-descriptions: Add comment.
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, scripts/tar-up.sh: Rename the timestamp
  file to source-timestamp instead, so that autobuild does not add
  the timestamp verbatim.
* Thu Apr  9 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29 final and c/s 854.
- patches.xen/sfc-external-sram: enable access to Falcon's
  external SRAM (bnc#489105).
- patches.xen/sfc-sync-headers: sync Solarflare accelerator
  headers (bnc#489105).
- Update Xen config files.
* Wed Apr  8 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Fix last change: do not add the
  timestamp if it is already added verbatim (by prepare_spec during
  checkin)
* Tue Apr  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Add source timestamp to package
  descriptions.
* Tue Apr  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: add descriptions to
  generated spec files.
- rpm/package-descriptions: descriptions of binary packages.
* Mon Apr  6 2009 jeffm@suse.com
- Enabled STAGING on !x86 and disabled COMEDI.
* Mon Apr  6 2009 jeffm@suse.com
- patches.rpmify/split-package: Enable
* Mon Apr  6 2009 jeffm@suse.com
- Update config files: Fixed i386-vanilla.
* Mon Apr  6 2009 jeffm@suse.com
- patches.fixes/xfs-export-debug: xfs: export assertion handler.
* Mon Apr  6 2009 jeffm@suse.com
- Switch from SPARSEMEM to DISCONTIGMEM on i386.
* Sun Apr  5 2009 jeffm@suse.com
- scripts/tar-up_and_run_mbuild.sh: Added pae to the important
  specfiles list.
* Fri Apr  3 2009 jeffm@suse.com
- Update config files: Fix missing ia64-debug.
* Fri Apr  3 2009 jeffm@suse.com
- patches.xen/sfc-resource-driver: Fix uninitialized var warning.
* Fri Apr  3 2009 jeffm@suse.com
- Drop NR_CPUS back to 128 on i386.
* Fri Apr  3 2009 jeffm@suse.com
- rpm/kernel-binary.spec.in: Added CONFIG_SPLIT_PACKAGE.
* Fri Apr  3 2009 jeffm@suse.de
- Update config files: Enabled STAGING drivers on -vanilla.
* Fri Apr  3 2009 jblunck@suse.de
- patches.rpmify/rpm-kernel-config: Rediff.
* Fri Apr  3 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: chmod +x mkspec arch-symbols
  compute-PATCHVERSION.sh
* Fri Apr  3 2009 jeffm@suse.com
- Update config files: Enabled STAGING drivers.
* Fri Apr  3 2009 jeffm@suse.com
- Sync up kernel configs for x86/x86_64 flavors.
* Fri Apr  3 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: do not package the binary
  spec files anymore.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/modversions: keep the override keyword in --pack.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, scripts/tar-up.sh: remove
  @TOLERATE_UNKNOWN_NEW_CONFIG_OPTIONS@ expansion, check for a file
  named TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS in sourcedir instead.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in: set LC_ALL=C in rpm -q call
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add @FLAVOR@ again to avoid %%%%(...)
  expansion
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/mkspec: new script to generate spec files from *.spec.in
  templates
- rpm/compute-PATCHVERSION.sh, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in, rpm/kernel-syms.spec.in: add to the
  source rpm
- scripts/tar-up.sh: just tar up patches directories and call
  mkspec
* Tue Mar 31 2009 mmarek@suse.cz
- rpm/kernel-dummy.spec.in: Delete.
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.KSYMS: Add to repo.
* Tue Mar 31 2009 mmarek@suse.cz
- config.conf, rpm/old-packages.conf, scripts/arch-symbols,
  scripts/run_oldconfig.sh, scripts/tar-up.sh: drop the arch
  symbols completely, only map the various ix86 archs to i386.
* Tue Mar 31 2009 mmarek@suse.cz
- doc/README.SUSE: allow_unsupported_modules needs to be set before
  installing the kernel (bnc#484664).
* Tue Mar 31 2009 jeffm@suse.de
- Add %%changelog to spec files
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Clean up %%build_$flavor macros
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-source.spec.in: Create kernel-source-vanilla
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-syms.spec.in, scripts/tar-up.sh: Depend on kernel-$flavor-devel
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Create a %%using_buildservice macro
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/sequence-patch.sh, scripts/tar-up.sh:
  kernel-{binary,source}: Remove arch guards
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.SUSE, rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/tar-up.sh: Move development files from kernel-source to
  kernel-$flavor-devel
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Remove $CONFIG_MODULES
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Remove duplicate CONFIG_DEBUG_INFO=y
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Use macros for cpu_arch
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in:
  kernel-{source,binary}: Use path-related rpm macros
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in,  rpm/kernel-source.spec.in:
  Use a %%kernelrelease macro.
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-source.spec.in, rpm/source-post.sh, scripts/tar-up.sh:
  Use %%variant instead of $variant
* Tue Mar 31 2009 jeffm@suse.de
- kernel-source: Kill old obsoletes
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, scripts/tar-up.sh:
  Use %%var instead of @VAR@ except where necessary
* Tue Mar 31 2009 jeffm@suse.de
- kernel-syms: Sort by flavor, not architecture
* Tue Mar 31 2009 jeffm@suse.de
- kernel-syms: Stop the architecture %%else madness
* Tue Mar 31 2009 jeffm@suse.de
- kernel-binary: Stop the architecture %%else madness
* Mon Mar 30 2009 jeffm@suse.de
- Removed -RT guards and a dead patch.
* Mon Mar 30 2009 jeffm@suse.de
- patches.fixes/reiserfs-prealloc-fix: Delete.
* Mon Mar 30 2009 jeffm@suse.de
- patches.suse/reiserfs-inode-init: Delete.
* Thu Mar 26 2009 mmarek@suse.cz
- rpm/config.sh: introduce rpm/config.sh, defining SRCVERSION and
  VARIANT variables.
* Tue Mar 24 2009 jeffm@suse.de
- Update to 2.6.29-final.
  - Eliminated 4 patches.
* Fri Mar 20 2009 jbeulich@novell.com
- Update Xen config files.
- Update Xen patches to 2.6.29-rc8 and c/s 821.
* Wed Mar 18 2009 mmarek@suse.cz
- rpm/kernel-*.spec.in, scripts/tar-up.sh: don't add "<RELEASE>"
  to the release, breaks plain rpmbuild.
* Tue Mar 17 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: don't generate symsets
- rpm/kernel-syms.spec.in: don't package symsets
- rpm/find-provides: disable symset provides
- rpm/macros.kernel-source: don't check for /boot/symsets*
  (fate#305945)
* Tue Mar 17 2009 knikanth@suse.de
- patches.fixes/loop-barriers: Delete.
- patches.fixes/loop-barriers2: Delete.
  Remove non-mainline patches to loop driver making it honour
  O_SYNC, sync requests and barriers. (bnc#485089), (bnc#471249)
* Mon Mar 16 2009 bphilips@suse.de
- README: add rough guide to updating KABI
* Fri Mar 13 2009 jeffm@suse.com
- Update to 2.6.29-rc8.
* Thu Mar 12 2009 jbeulich@novell.com
- patches.fixes/fix-nf_conntrack_slp,
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch,
  patches.suse/perfmon2.patch,
  patches.suse/silent-stack-overflow-2.patch: fix build warnings.
* Thu Mar 12 2009 jbeulich@novell.com
- Update Xen patches addressing several issues in initial commit
- Update Xen config files (re-enable oprofile, disable novfs).
- patches.xen/xen3-x86_64-unwind-annotations: fix unwind annotations
  in entry_64-xen.S.
* Thu Mar 12 2009 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: fix unwind annotations in
  entry_64.S.
* Thu Mar 12 2009 rgoldwyn@suse.de
- patches.suse/novfs-creds-change-2.6.29: Changing credential
  according to new task_struct.
* Wed Mar 11 2009 jblunck@suse.de
- rpm/kernel-binary.spec.in: Use split_packages only if supported.conf
  is not empty.
* Mon Mar  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: renamed modprobe config to
  /etc/modprobe.d/50-module-renames.conf (required by new
  module-init-tools).
* Mon Mar  9 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.29-rc4: fix ia64 build.
* Mon Mar  9 2009 jbeulich@novell.com
- Update Xen config files (get tracing options back in sync with
  default).
* Fri Mar  6 2009 jeffm@suse.de
- Update config files: Enable CONFIG_FRAME_POINTER on Xen.
* Fri Mar  6 2009 jeffm@suse.de
- config.conf: Enabled Xen for building.
* Fri Mar  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29-rc7.
* Fri Mar  6 2009 jbenc@suse.cz
- Update config files: enabled wireless debugging in -debug flavors.
* Fri Mar  6 2009 mmarek@suse.cz
- rpm/get_release_number.sh.in, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in, rpm/kernel-syms.spec.in,
  scripts/tar-up.sh, doc/README.SUSE: finally drop kernel-dummy
- rpm/prepare-build.sh: Delete.
* Wed Mar  4 2009 jeffm@suse.com
- Update to 2.6.29-rc7.
  - Eliminated 1 patch.
* Wed Mar  4 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: workaround a bash bug (bnc#481817)
  in kernel-vanilla.spec.
* Tue Mar  3 2009 jeffm@suse.com
- patches.suse/export-security_inode_permission: Export
  security_inode_permission for aufs.
* Thu Feb 26 2009 jeffm@suse.com
- scripts/tar-up.sh: Add -u to update existing spec files.
* Thu Feb 26 2009 sven@suse.de
- rpm/kernel-binary.spec.in: Fix sub-package install-time conflict.
* Wed Feb 25 2009 mmarek@suse.cz
- scripts/tar-up.sh: create tarballs that don't change
  unnecessarily: set owner/group to nobody/nobody, mtime to time of
  the latest commit and sort the input files.
* Tue Feb 24 2009 jeffm@suse.com
- Update to 2.6.29-rc6-git1.
* Sat Feb 21 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in: also check if the package versions match
  (bnc#478462)
* Fri Feb 20 2009 jbeulich@novell.com
- patches.suse/stack-unwind: fix 32-bit arch_unwind_init_running().
* Fri Feb 20 2009 jbeulich@novell.com
- patches.suse/stack-unwind: fix patch fuzz.
* Fri Feb 20 2009 jbeulich@novell.com
- misc/xen-port-patches.py: Adjust fro new x86 header placement.
- patches.arch/x86_64-unwind-annotations: fix unwind annotations
  (bnc#472783).
- patches.suse/stack-unwind: Properlz hook up unwinder again.
* Fri Feb 20 2009 jeffm@suse.de
- patches.suse/kdb-common: Build fix with -I directive.
* Fri Feb 20 2009 jeffm@suse.de
- Update config files.
* Fri Feb 20 2009 jeffm@suse.de
- Update to 2.6.29-rc5-git3.
  - Eliminated 1 patch.
* Thu Feb 19 2009 mmarek@suse.cz
- rpm/symsets.pl: allow passing only Module.symvers and no modules
* Wed Feb 18 2009 olh@suse.de
- disable ppc601 support, disable unused framebuffer drivers
* Wed Feb 18 2009 olh@suse.de
- disable kdump on ppc32
* Mon Feb 16 2009 jeffm@suse.com
- Update config files.
* Sat Feb 14 2009 jeffm@suse.de
- Update to 2.6.29-rc5.
* Fri Feb 13 2009 jeffm@suse.de
- Update to 2.6.29-rc4-git7.
  - Eliminated 2 patches.
* Mon Feb  9 2009 jeffm@suse.de
- patches.rpmify/spin_is_contended-fix: spin_is_contended
  Kconfig fixes.
* Mon Feb  9 2009 jeffm@suse.de
- Updated to 2.6.29-rc4.
  - Eliminated 3 patches.
* Fri Feb  6 2009 jeffm@suse.com
- patches.fixes/fix-warning-while-mapping-0-1MB-range-with-dev-mem:
  x86, pat: fix warn_on_once() while mapping 0-1MB range.
* Fri Feb  6 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage, rpm/post.sh, rpm/postun.sh: fix
  last change: don't pass -e to weak-modules2.
* Fri Feb  6 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage, rpm/post.sh, rpm/postun.sh: pass
  down shell options like -x to weak-modules2 to make debugging
  with rpm -ivv easier.
* Tue Feb  3 2009 jeffm@suse.de
- patches.fixes/fix-nf_conntrack_slp: make nf_conntrack_slp
  actually work (bnc#470963).
* Tue Feb  3 2009 mmarek@suse.cz
- scripts/tar-up.sh: fix branch name in KOTD packages.
* Tue Feb  3 2009 olh@suse.de
- config.conf: readde -debug flavor for ppc64
* Tue Feb  3 2009 olh@suse.de
- patches.fixes/scsi-ibmvfc_prli_initiator_fix.patch:
  Better handle other FC initiators (bnc#471217 - LTC51238)
* Tue Feb  3 2009 mmarek@suse.cz
- scripts/wd-functions.sh: display master as "master", not "HEAD"
  or "".
* Mon Feb  2 2009 jeffm@suse.de
- patches.fixes/ath9k-fix-led_device_naming.diff: ath9k: fix
  led naming.
- patches.fixes/b43legacy-fix-led_device_naming.diff: b43legacy:
  fix led naming.
- patches.fixes/iwlwifi-fix-iwl-3945_led_device_naming.diff:
  iwlwifi: another led naming fix.
- patches.fixes/iwlwifi-fix-iwl-led_device_naming.diff: iwlwifi:
  fix led naming   .
- patches.fixes/rt2x00-fix-led_device_naming.diff: rt2x00:
  fix led naming.
* Mon Feb  2 2009 jeffm@suse.de
- Updated to 2.6.29-rc3-git3.
  - Eliminated 6 patches.
* Mon Feb  2 2009 jeffm@suse.de
- Updated to 2.6.29-rc3.
  - AppArmor is disabled.
  - Xen is disabled.
  - Eliminated 745 patches.
* Mon Feb  2 2009 jeffm@suse.de
- Enabled patches.suse/reiserfs_warning-reentrant
* Mon Feb  2 2009 rw@suse.de
- patches.fixes/xpc-pass-physical,
  patches.kabi/xpc-pass-physical:
  kABI: restore upstream patch, add ABI cover-up. (bnc#458811)
* Mon Feb  2 2009 olh@suse.de
- patches.fixes/serial-jsm-enable_ms.patch:
  Add enable_ms to jsm driver (bnc#471224 - LTC51066)
* Mon Feb  2 2009 olh@suse.de
- patches.arch/ppc-optimize-sync.patch:
  Optimise smp_{r,w}mb and mutex (bnc#471222 - LTC51356)
* Sat Jan 31 2009 gregkh@suse.de
- refresh patches for fuzz due to 2.6.27.14-rc1 import.
* Sat Jan 31 2009 gregkh@suse.de
- patches.kabi/abi-fix-add-epoll_devs-back-to-struct-user_struct.patch:
  ABI fix: add epoll_devs back to struct user_struct.
* Sat Jan 31 2009 gregkh@suse.de
- Update to 2.6.27.14-rc1
  - lots of security fixes
  - lots of bugfixes
  - obsoletes:
  - patches.drivers/alsa-virtuoso-no-eeprom-overwrite
  - patches.drivers/pata_via.c-support-vx855-and-future-chips-whose-ide-controller-use-0x0571.patch
  - patches.fixes/SUNRPC-Fix-autobind-on-cloned-rpc-clients.patch
  - patches.fixes/sysfs-fix-problems-with-binary-files.patch
  - patches.fixes/xpc-fix-NULL-deref
  - patches.fixes/xpc-write-barrier
* Fri Jan 30 2009 olh@suse.de
- patches.arch/ppc-pseries-migration_hang_fix.patch:
  Fix partition migration hang under load (bnc#470563 - LTC51153)
* Fri Jan 30 2009 olh@suse.de
- disable CONFIG_DEBUG_STACKOVERFLOW and CONFIG_DEBUG_STACK_USAGE
  on ppc/ppc64
* Fri Jan 30 2009 teheo@suse.de
- patches.drivers/libata-fix-EH-device-failure-handling: libata:
  fix EH device failure handling (bnc#470845).
* Thu Jan 29 2009 jjolly@suse.de
- patches.arch/s390-08-08-add_qdio_utilization.patch: zfcp:
  queue_full is lacking the entry for qdio utilization
  (bnc#466462).
* Thu Jan 29 2009 gregkh@suse.de
- add ability to debug kernel using USB debug connector.
- Update config files.
- patches.suse/usb-move-ehci-reg-def.patch: usb: move ehci
  reg def.
- patches.suse/x86-usb-debug-port-early-console-v4.patch: x86:
  usb debug port early console, v4.
* Thu Jan 29 2009 mmarek@suse.cz
- patches.kabi/abi-fix-add-s_syncing-back-to-struct-super_block.patch
  patches.kabi/abi-fix-add-wb_sync_hold-enum-writeback_sync_modes.patch
  patches.kabi/export-iwl_rx_allocate
  patches.kabi/sched-kabi-compat-hack.patch: Introduce
  patches.kabi/ for patches that only work around kabi issues and
  can be safely dropped at the next SP.
* Wed Jan 28 2009 agruen@suse.de
- patches.xen/xen-x86-mark_rodata_rw.patch: Add missing pageattr.c
  changes to pageattr-xen.c (bnc#439348).
* Wed Jan 28 2009 agruen@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
- patches.xen/xen-x86-mark_rodata_rw.patch: xen specific part
  (bnc#439348).
* Wed Jan 28 2009 mmarek@suse.cz
- config/s390/s390: the -man package still fails for s390, disable
  it
* Wed Jan 28 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix build of the -man subpackage on
  31bit s390
* Wed Jan 28 2009 mmarek@suse.cz
- fix kernel-default.ppc64 reference symsets
* Wed Jan 28 2009 jslaby@suse.cz
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
  [cpu_mask_to_apicid bigsmp fix]
* Wed Jan 28 2009 olh@suse.de
- patches.fixes/scsi-ibmvscsi-module_alias.patch:
  map scsi proc_name to module name (bnc#459933 - LTC50724)
* Tue Jan 27 2009 jeffm@suse.de
- Update config files: Disable ftrace in -debug on ppc64
* Tue Jan 27 2009 jeffm@suse.de
- config.conf: Added -debug flavor for ppc64.
* Tue Jan 27 2009 bwalle@suse.de
- patches.drivers/libfc-set-the-release-function.diff:
  Whitespace change.
* Tue Jan 27 2009 hare@suse.de
- patches.drivers/libfc-fix-read-IO-data-integrity: libfc:
  IO data integrity issue when a IO data frame lost (bnc#469536).
* Tue Jan 27 2009 jbeulich@novell.com
- re-enable patches.xen/xen3-e1000e_Export_set_memory_ro-rw.
* Tue Jan 27 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  include prototype for PFN_UP() (bnc#462546 - LTC50009)
* Mon Jan 26 2009 kkeil@suse.de
- patches.suse/e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls.
  readded to avoid kabi change
* Mon Jan 26 2009 jeffm@suse.de
- config.conf: Added kernel-vmi to i386.
* Mon Jan 26 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  use PFN_UP() for end_pfn (bnc#462546 - LTC50009)
* Mon Jan 26 2009 mmarek@suse.cz
- kabi: import FCoE changes
* Mon Jan 26 2009 hare@suse.de
- patches.suse/dm-mpath-requeue-for-stopped-queue: disable
  wrong debug message again.
* Mon Jan 26 2009 rw@suse.de
- patches.fixes/taskstats-alignment:
  IA64: fill 'struct taskstats' on stack and 'memcpy' result to skb.
  (bnc#448410)
* Mon Jan 26 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  fix calculation of reserve_size (bnc#462546 - LTC50009)
* Mon Jan 26 2009 kkeil@suse.de
- patches.fixes/disable-lro-per-default: Disable LRO per default
  in igb and ixgbe. (bnc#467519)
* Mon Jan 26 2009 jbeulich@novell.com
- Just comment out patches.xen/xen3-e1000e_* (to address build error)
  until disposition of their originals is known.
* Mon Jan 26 2009 kkeil@suse.de
- patches.fixes/sctp_do_not_use_stale_copy_of_sk: Do not use
  stale copy of sk. (bnc#440104)
* Mon Jan 26 2009 jblunck@suse.de
  Renamed some patches so they get included in vanilla builds.
- patches.rpmify/firmware-path: Renamed.
- patches.rpmify/no-include-asm: Renamed.
- patches.suse/md-raid-metadata-PAGE_SIZE.patch: Renamed.
* Mon Jan 26 2009 olh@suse.de
- patches.suse/led_classdev.sysfs-name.patch: use correct name
  for /sys/devices/virtual/leds/ entries (bnc#468350)
* Mon Jan 26 2009 kkeil@suse.de
- patches.suse/e1000e_Export_set_memory_ro-rw: Delete.
- patches.suse/e1000e_allow_bad_checksum: Delete.
- patches.suse/e1000e_call_dump_eeprom: Delete.
- patches.suse/e1000e_ioremap_sanity_check: Delete.
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  Delete.
  Remove not mainline e1000e patches which were added to help with
  the e1000e NVM corruption - root issue is fixed
* Mon Jan 26 2009 kkeil@suse.de
- patches.drivers/tg3_libphy_workaround: tg3 libphy workaround.
  (bnc#468725)
* Mon Jan 26 2009 hare@suse.de
- supported.conf: Correct spelling for dm-least-pending
  path checker.
* Mon Jan 26 2009 hare@suse.de
- patches.suse/dm-mpath-check-info-before-access: Kernel Oops
  during path failover (bnc#458393).
* Sun Jan 25 2009 gregkh@suse.de
- refresh patch fuzz now that 2.6.27.13 is in tree
* Sun Jan 25 2009 gregkh@suse.de
- Update to final version of 2.6.27.13
* Sat Jan 24 2009 gregkh@suse.de
- dynamic debugging fixes backported from upstream:
- patches.drivers/driver-core-add-newlines-to-debugging-enabled-disabled-messages.patch:
  driver core: add newlines to debugging enabled/disabled
  messages.
- patches.drivers/driver-core-fix-dynamic_debug-cmd-line-parameter.patch:
  Driver core: fix 'dynamic_debug' cmd line parameter.
- patches.drivers/driver-core-fix-using-ret-variable-in-unregister_dynamic_debug_module.patch:
  driver core: fix using 'ret' variable in
  unregister_dynamic_debug_module.
* Sat Jan 24 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch:
  (fix return of an unitialized value (bnc#469017)
* Sat Jan 24 2009 mmarek@suse.cz
- update kabi files: ignore changes in struct pcie_link_state as
  it is an internal structure only.
* Sat Jan 24 2009 mmarek@suse.cz
- patches.suse/genksyms-add-override-flag.diff: genksyms: add
  - -override flag.
- rpm/kernel-binary.spec.in: set KBUILD_OVERRIDE=1
* Sat Jan 24 2009 ghaskins@suse.de
- patches.fixes/sched-kabi-compat-hack.patch: sched: leave
  RT_GROUP_SCHED structure components intact to preserve kABI.
  broke kabi with fix for 456542
* Sat Jan 24 2009 trenn@suse.de
- patches.fixes/cpufreq_export_latency.patch: CPUFREQ: Introduce
  /sys/devices/system/cpu/cpu*/cpufreq/cpuinfo_transition_latency
  (bnc#464461).
- patches.fixes/cpufreq_ondemand_adjust_sampling_rate_limit.patch:
  CPUFREQ: ondemand/conservative: sanitize sampling_rate
  restrictions (bnc#464461).
- patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  CPUFREQ: ondemand: Limit default sampling rate to 300ms
  max. (bnc#464461).
- patches.fixes/x86_cpufreq_powernow-k8_acpi_latency_values.patch:
  X86 powernow-k8 cpufreq: Get transition latency from acpi _PSS
  object (bnc#464461).
* Fri Jan 23 2009 jeffm@suse.de
- patches.fixes/xfs-dmapi-fixes: xfs/dmapi: fix crash on mount
  (bnc#458027).
* Fri Jan 23 2009 ghaskins@suse.de
- Update config files: Disable RT_GROUP_SCHED (bnc#456542).
  The RT_GROUP_SCHED feature is experimental and clearly broken, so
  lets turn it off for now.
* Fri Jan 23 2009 jeffm@suse.de
- patches.fixes/hpilo-open-close-fix: hpilo open/close fix
  (bnc#466517).
* Fri Jan 23 2009 hare@suse.de
- patches.suse/dm-mpath-requeue-for-stopped-queue: Handle I/O
  on stopped queues correctly (bnc#458393).
* Fri Jan 23 2009 jbenc@suse.cz
- patches.suse/mnt-want-write-speedup.patch,
  patches.suse/mnt_clone_write.patch: modified not to break kABI,
  enabled (bnc#436953).
* Fri Jan 23 2009 jbenc@suse.cz
- patches.fixes/iwlagn-fix-rfkill.patch: iwlagn: fix hw-rfkill
  while the interface is down (bnc#446158).
* Fri Jan 23 2009 mmarek@suse.cz
- kabi/severities: temporarily enable changes in FcOE modules.
* Fri Jan 23 2009 hare@suse.de
- patches.arch/s390-08-06-personality.patch: kernel: setting 32
  bit personality doesn't work (bnc#466462).
- patches.arch/s390-08-07-compat_wrappers.patch: kernel:
  Add missing wrapper functions for 31 bit compat
  syscalls. (bnc#466462,LTC#51229).
- patches.fixes/block-leave-the-request-timeout-timer-running:
  Delete obsolete patch.
* Fri Jan 23 2009 bwalle@suse.de
- patches.drivers/fcoe-change-fcoe_sw-sg_tablesi.diff: change
  fcoe_sw sg_tablesize to SG_ALL (bnc #459142).
- patches.drivers/fcoe-check-return-for-fc_set_m.diff: check
  return for fc_set_mfs (bnc #459142).
- patches.drivers/fcoe-fix-frame-length-validati.diff: fix frame
  length validation in the early receive path (bnc #459142).
- patches.drivers/fcoe-fix-incorrect-use-of-struct-module.diff:
  fcoe: fix incorrect use of struct module (bnc #468051).
- patches.drivers/fcoe-improved-load-balancing-i.diff: improved
  load balancing in rx path (bnc #459142).
- patches.drivers/fcoe-logoff-of-the-fabric-when.diff: Logoff
  of the fabric when destroying interface (bnc #459142).
- patches.drivers/fcoe-remove-warn_on-in-fc_set.diff: remove
  WARN_ON in fc_set_mfs (bnc #459142).
- patches.drivers/fcoe-user_mfs-is-never-used.diff: user_mfs is
  never used (bnc #459142).
- patches.drivers/libfc-add-fc_disc-c-locking-co.diff: Add
  fc_disc.c locking comment block (bnc #459142).
- patches.drivers/libfc-ensure-correct-device_pu.diff: libfc:
  Ensure correct device_put/get usage (round 2).
- patches.drivers/libfc-fix-rport-recursive-lock.diff: libfc:
  Fix rport recursive lock on rport mutex (bnc #459142).
- patches.drivers/libfc-handle-rrq-exch-timeout.diff: libfc:
  handle RRQ exch timeout (bnc #465596).
- patches.drivers/libfc-improve-fc_lport-c-locki.diff: Improve
  fc_lport.c locking comment block (bnc #459142).
- patches.drivers/libfc-improve-fc_rport-c-locki.diff: Improve
  fc_rport.c locking comment block (459142).
- patches.drivers/libfc-make-fc_disc-inline-with.diff: make
  fc_disc inline with the fc_lport structure (bnc #459142).
- patches.drivers/libfc-make-rscn-parsing-more-r.diff: make RSCN
  parsing more robust (bnc #459142).
- patches.drivers/libfc-make-sure-we-access-the.diff: make sure
  we access the CRC safely (bnc #459142).
- patches.drivers/libfc-pass-lport-in-exch_mgr_r.diff: libfc:
  Pass lport in exch_mgr_reset (bnc #465596).
- patches.drivers/libfc-remove-debug-print-state.diff: libfc:
  Remove debug print statement, too verbose (bnc #459142).
- patches.drivers/libfc-set-the-release-function.diff: Set
  the release function for the rport's kobject (round 2)
  (bnc #459142).
- patches.drivers/libfc-updated-comment-for-orde.diff: updated
  comment for order of em and ex locks (bnc #459142).
- patches.drivers/libfc-updated-libfc-fcoe-modul.diff: updated
  libfc fcoe module ver to 1.0.6 (bnc #459142).
- patches.drivers/libfc-use-an-operations-struct.diff: use an
  operations structure for rport callbacks (bnc #459142).
- patches.drivers/libfc-when-rport-goes-away-re.diff: libfc:
  when rport goes away (re-plogi), clean up exchanges to/from
  rport (bnc #465596).
- patches.drivers/libfc_locking.diff: libfc, fcoe: fixed locking
  issues with lport->lp_mutex around lport->link_status (bnc
  [#468053]).
- patches.drivers/libfc_rport.diff: libfc: rport retry on LS_RJT
  from certain ELS (bnc #468054).
* Fri Jan 23 2009 hare@suse.de
- patches.fixes/qla2xxx-check-fc-rport-validity:
  qla2xxx: added check for fcport is valid in
  qla2x00_terminate_rport_io(). (bnc#467624).
* Fri Jan 23 2009 tiwai@suse.de
- patches.drivers/alsa-hda-gateway-t1616-quirk: ALSA: hda -
  Add quirk for Gateway T1616 laptop (bnc#467597).
- patches.drivers/alsa-hda-hp-dv4-quirk: ALSA: hda - Add model
  entry for HP dv4.
- patches.drivers/alsa-hda-intel-d945-ref-quirk: ALSA: hda -
  Add model=ref for Intel board with STAC9221 (bnc#406529).
* Fri Jan 23 2009 hare@suse.de
- patches.fixes/blk-leave-sync-timer-running: block: Rediff
- patches.fixes/block-use-round_jiffies_up: Block: use
  round_jiffies_up() (bnc#464155).
- Add missing patches to series.conf:
  patches.fixes/round-jiffies-up
  patches.fixes/block-use-round_jiffies_up
  patches.fixes/block-fix-blk_start_queueing
  patches.fixes/suppress-buffer-IO-errors
  patches.fixes/block-optimizations-in-blk_rq_timed_out_timer
  patches.fixes/block-add-comment-in-blk_rq_timed_out
* Fri Jan 23 2009 olh@suse.de
- update patches.fixes/scsi-ibmvscsi-vio_leak.patch:
  handle also drivers/scsi/ibmvscsi/ibmvfc.c
* Fri Jan 23 2009 sjayaraman@suse.de
- patches.fixes/cifs-fix-oops-on-ipv6-mount: cifs: make sure we
  allocate enough storage for socket address (467691).
* Fri Jan 23 2009 gregkh@suse.de
- patches.kernel.org/abi-fix-add-wb_sync_hold-enum-writeback_sync_modes.patch:
  ABI fix: add WB_SYNC_HOLD enum writeback_sync_modes.
* Fri Jan 23 2009 gregkh@suse.de
- patches.kernel.org/abi-fix-add-s_syncing-back-to-struct-super_block.patch:
  ABI fix: add s_syncing back to struct super_block.
* Fri Jan 23 2009 gregkh@suse.de
- update to 2.6.27.13-rc1:
  - security updates
  - lots of bugfixes
  - obsoletes:
  - patches.arch/ppc-fix_hugepage_check.patch
  - patches.drivers/alsa-hda-ad1986a-laptop-eapd-model-back
  - patches.drivers/alsa-hda-samsung-q45-quirk
  - patches.fixes/security-introduce-missing-kfree.patch
  - patches.fixes/xpc-fix-heartbeat
- Update config files.
* Thu Jan 22 2009 kkeil@suse.de
- patches.drivers/e1000-fix-shared-emc.patch: e1000: fix bug
  with shared interrupt during reset (bnc#396687)
* Thu Jan 22 2009 tonyj@suse.de
- patches.fixes/revert-bgcolor-line-feed-93f78da4.patch: Revert
  "vt: fix background color on line feed" (bnc#418613).
* Thu Jan 22 2009 jbenc@suse.cz
- patches.fixes/iwlwifi-fix-rs_get_rate-oops.patch: iwlwifi:
  fix rs_get_rate WARN_ON() (bnc#456002).
- Reordered wireless patches to group together patches touching the same
  driver.
* Thu Jan 22 2009 bphilips@suse.de
- patches.drivers/disable-catas_reset-by-default-to-avoid-problems-with-eeh.patch:
  disable catas_reset by default to avoid problems with EEH
  (bnc#456389).
* Thu Jan 22 2009 rw@suse.de
- patches.fixes/xpc-pass-physical:
  fixed kABI breakage. (bnc#458811)
* Thu Jan 22 2009 bwalle@suse.de
- scripts/tar-up_and_run_mbuild.sh: s390 (the 31 bit variant) is
  not an important spec file.
* Thu Jan 22 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: fixed kABI
  breakage, reenabled.
* Thu Jan 22 2009 mmarek@suse.cz
- rpm/modversions: eat the "override" keyword before parsing the
  symbol definition.
* Thu Jan 22 2009 olh@suse.de
- patches.fixes/scsi-ibmvscsi-vio_leak.patch:
  Correct VIO bus/device CMO accounting problems (bnc#468304 - LTC51205)
* Thu Jan 22 2009 olh@suse.de
- patches.suse/of_platform_driver.module-owner.patch:
  add missing module symlink to /sys/bus/*/driver/*
  in struct of_platform_driver.
* Thu Jan 22 2009 kkeil@suse.de
- patches.drivers/ixgbe_DCB_compile_err.patch: DCB compile
  error fix - new version from Intel  (bnc#465923)
* Thu Jan 22 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch: allow 64-bit mode
  for HPET Timer0 (bnc#456700).
  (fix compilation on i386 and add hpet64 to kernel-parameters.txt)
* Thu Jan 22 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch: allow 64-bit mode
  for HPET Timer0 (bnc#456700).
* Thu Jan 22 2009 rw@suse.de
- patches.fixes/xpc-pass-physical:
  sgi-xpc: need to pass the physical address, not virtual. (bnc#458811)
- patches.fixes/xpc-fix-heartbeat:
  sgi-xpc: eliminate false detection of no heartbeat. (bnc#464545)
* Thu Jan 22 2009 jkosina@suse.de
- patches.fixes/input-add-nomux-dell-vostro-1510.patch: Input:
  add Dell Vostro 1510 to nomux list (bnc#404881).
* Thu Jan 22 2009 jblunck@suse.de
- scripts/compute-PATCHVERSION.sh: Fix SRCVERSION parsing (bnc#465113).
* Thu Jan 22 2009 tiwai@suse.de
- patches.drivers/alsa-hda-add-volume-offset: ALSA: hda - Add
  extra volume offset to standard volume amp macros (bnc#466428).
- patches.drivers/alsa-hda-stac-reduce-volume-scale: ALSA: hda -
  Halve too large volume scales for STAC/IDT codecs (bnc#466428).
* Thu Jan 22 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.12-update: Update lpfc from 8.2.8.11
  to 8.2.8.12 (bnc#467713).
* Thu Jan 22 2009 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: fix missing jl arg
* Wed Jan 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: delete duplicate error message in the
  kabi checks
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/remove_kernel_physical_mapping_init_from_init:
  move kernel_physical_mapping_init to __meminit (bnc#467474).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: disabled, as it changes
  kABI.
* Wed Jan 21 2009 gregkh@suse.de
- patches.fixes/security-introduce-missing-kfree.patch: security:
  introduce missing kfree (bnc#467322).
- patches.fixes/sysfs-fix-problems-with-binary-files.patch:
  sysfs: fix problems with binary files.
* Wed Jan 21 2009 rw@suse.de
- patches.arch/ia64-page-migration.fix:
  fix deadlock caused by cpe_migrate.ko and mark it supported.
  (bnc#464676)
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/sn-irq-affinity: sn2: preserve irq affinity set
  in PROM (bnc#457679).
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/uv_zalias_support: uv: Support for non-nasid 0
  systems (bnc#458869).
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/xpc-fix-NULL-deref: sgi-xpc: Remove NULL pointer
  dereference. (bnc#466563).
- patches.fixes/xpc-write-barrier: sgi-xpc: ensure flags are
  updated before bte_copy (bnc#466563).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/ipw2200-workaround-firmware-restarts-when-scanning.patch:
  ipw2200: fix scanning while associated (bnc#459067).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/iwl3945-fix-rfkill.patch: iwl3945: report
  killswitch changes even if the interface is down (bnc#446013).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: mac80211:
  add direct probe before association (bnc#461889).
* Wed Jan 21 2009 hare@suse.de
- patches.drivers/mptsas-discover-all-devices: mptsas driver
  fails to discover devices (bnc#459932).
* Wed Jan 21 2009 jbeulich@novell.com
- Update Xen patches to 2.6.27.12.
- patches.xen/764-netback-foreign-pages.patch: netback: handle
  non-netback foreign pages.
- patches.xen/769-evtchn-CPU-offline.patch: evtchn: Fix CPU offlining
  to switch all affected ports belonging to a particular /dev/evcthn
  user.
- patches.xen/gso-size-check.patch: gso: Ensure that the packet
  is long enough.
- patches.xen/xen-S3-MSI: fix Dom0 resume from S3 when MSI is
  in use (bnc#435596).
- patches.xen/xen3-e1000e_ioremap_sanity_check: ioremap sanity
  check to catch mapping requests exceeding the BAR sizes
  (bnc#425480).
- patches.xen/xen3-x86-fix-kmap-contig.patch: x86: contiguous
  kmap fix (bnc#449812).
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/radeon-monitor-jsxx-quirk.patch:
  implement correct model matching
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/dm-mpath-tracking-nr-bytes:
  lpp_end_io gets nr_bytes as third arg
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/radeon-monitor-jsxx-quirk.patch:
  match all JSxx/QSxx models based on the first 4 chars in 'model'
* Wed Jan 21 2009 olh@suse.de
- update patches.arch/ppc-axon-missing-msi-workaround-5.diff:
  Fix MSI after kexec (bnc#467633)
* Tue Jan 20 2009 gregkh@suse.de
- clean up patch fuzz after 2.6.27.12 inclusion.
* Tue Jan 20 2009 gregkh@suse.de
- Update to the real 2.6.27.12
* Tue Jan 20 2009 jeffm@suse.de
- patches.suse/reiserfs_warning-reentrant: reiserfs: eliminate
  reiserfs_warning from uniqueness functions; Fixes deadlock.
* Tue Jan 20 2009 olh@suse.de
- patches.drivers/cxgb3-ser.patch:
  reset the adapter on fatal error (bnc#466062 - LTC51042)
* Tue Jan 20 2009 jjolly@suse.de
- patches.arch/s390-08-03-iucv-cpu-hotremove.diff: iucv: failing
  cpu hot remove for inactive iucv (bnc#466462,LTC#51104).
- patches.arch/s390-08-04-compat-sigaltstack.diff:
  kernel: 31 bit compat sigaltstack syscall fails with
  - EFAULT. (bnc#466462,LTC#50888).
- patches.arch/s390-08-05-af_iucv-msgpeek-fix.patch:
  af_iucv: System hang if recvmsg() is used with MSG_PEEK
  (bnc#466462,LTC#51136).
* Tue Jan 20 2009 hare@suse.de
- patches.suse/dm-mpath-accept-failed-paths: Only accept
  non-existing paths when adding failed paths (bnc#467579)
* Tue Jan 20 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: set CONFIG_DEBUG_INFO=y in the
  packaged .configs if builfing debug packages (bnc#460887)
* Mon Jan 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: set %%tolerate_kabi_changes to 6
* Mon Jan 19 2009 mmarek@suse.cz
- patches.suse/export-iwl_rx_allocate: reintroduce
  EXPORT_SYMBOL(iwl_rx_allocate).
* Mon Jan 19 2009 mmarek@suse.cz
- import SLE11 RC2 reference kabi
* Mon Jan 19 2009 hare@suse.de
- patches.drivers/mpt-return-all-sense-data: MPT Fusion doesn't
  return all sense data (bnc#466179).
* Sat Jan 17 2009 gregkh@suse.de
- Update to 2.6.27.12-rc2
* Fri Jan 16 2009 od@suse.de
- patches.arch/x86-call-boot-IRQ-quirks-at-end-of-device-init-and-during-resume.patch:
  call boot IRQ quirks at end of device init and during resume.
- patches.arch/x86-disable-AMD-ATI-boot-interrupt-generation.patch:
  update to upstream variant of this patch:
  - integrate an older quirk to make IO-APIC mode work on AMD
    8131 rev. A0 and B0
  - fix boot IRQ disabling logic for AMD 813x
  - remove unneeded code for AMD SB700S
* Fri Jan 16 2009 jbeulich@novell.com
- patches.arch/x86-fix-kmap-contig.patch: x86: contiguous kmap
  fix (bnc#449812).
* Fri Jan 16 2009 olh@suse.de
- enable mptsas in kdump kernel to allow crashdump on QS2x blades
* Fri Jan 16 2009 tiwai@suse.de
  Fix STAC925x patch again
- patches.drivers/alsa-hda-stac925x-init-fix: ALSA: hda - Fix
  (yet more) STAC925x issues (bnc#460478).
* Fri Jan 16 2009 jjolly@suse.de
- patches.arch/s390-08-01-cio-fix-mp-mode.diff: cio: fix
  subchannel multipath mode setup (bnc#466462,LTC#51047).
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: zfcp: fix
  memory alignment for GPN_FT requests. (bnc#466462).
* Thu Jan 15 2009 gregkh@suse.de
- Update config files for vanilla kernel versions due to new config
  option added in 2.6.27.12-rc1.
* Thu Jan 15 2009 gregkh@suse.de
- Update to 2.6.27.12-rc1:
  - security fixes
  - fixes CVE-2009-0029
  - bug fixes all over the place.
  - obsoletes the following patches:
  - patches.arch/ppc-cmm_no_kdump.patch
  - patches.drivers/alsa-caiaq-midi-oops-fix
  - patches.drivers/alsa-hda-hp-6730b-quirk
  - patches.drivers/ibmvfc-host_init_delay.patch
  - patches.drivers/ibmvfc-improve_sync_events.patch
  - patches.fixes/PCI-Suspend-and-resume-PCI-Express-ports-with-interrupts-disabled.patch
  - patches.fixes/PCI-handle-PCI-state-saving-with-interrupts-disabled.patch
  - patches.fixes/fs-symlink-write_begin-allocation-context-fix.patch
  - patches.fixes/mm-lockless-pagecache-barrier.patch
  - patches.fixes/pci-rework-suspend-of-devices-with-no-drivers.patch
  - patches.fixes/uv-remove-erroneous-BAU-init
- Update config files.
* Thu Jan 15 2009 tiwai@suse.de
- patches.drivers/alsa-virtuoso-no-eeprom-overwrite: sound:
  virtuoso: do not overwrite EEPROM on Xonar D2/D2X (bnc#462365).
* Thu Jan 15 2009 bwalle@suse.de
- patches.suse/s390-System.map.diff:
  Strip L2^B symbols (bnc #456682).
* Thu Jan 15 2009 tiwai@suse.de
- patches.drivers/alsa-hda-gateway-fix: ALSA: patch_sigmatel:
  Add missing Gateway entries and autodetection (bnc#460478).
- patches.drivers/alsa-hda-gateway-fix2: ALSA: hda - More fixes
  on Gateway entries (bnc#460478).
- patches.drivers/alsa-hda-hp-dv5-mic-fix: ALSA: hda - Fix HP
  dv5 mic input (bnc#462913).
- patches.drivers/alsa-hda-hp-dv5-quirk: ALSA: hda - Add quirk
  for another HP dv5 (bnc#462913).
- patches.drivers/alsa-hda-idt92hd83-fix-typo: ALSA: hda -
  Fix a typo.
- patches.drivers/alsa-hda-samsung-q45-quirk: ALSA: hda - Add
  automatic model setting for Samsung Q45.
- patches.drivers/alsa-hda-seek-for-codec-id: ALSA: hda - Add
  a new function to seek for a codec ID (bnc#460478).
- patches.drivers/alsa-hda-sigmatel-no-hp-reset: ALSA: hda -
  Don't reset HP pinctl in patch_sigmatel.c (bnc#460478).
- patches.drivers/alsa-hda-stac925x-init-fix: ALSA: hda - Fix
  missing initialization of NID 0x0e for STAC925x (bnc#460478).
* Thu Jan 15 2009 olh@suse.de
- patches.arch/ppc-fix_hugepage_check.patch:
  is_hugepage_only_range() must account for both 4kB and 64kB
  slices (bnc#466229 - LTC51063)
* Wed Jan 14 2009 jeffm@suse.de
- Update config files: Disabled PARAVIRT on vanilla and LGUEST.
* Wed Jan 14 2009 jeffm@suse.de
- Enabled patches.suse/unlock_page-speedup.patch
* Wed Jan 14 2009 rjw@suse.de
- patches.fixes/PCI-PM-Split-PCI-Express-port-suspend-resume.patch:
  PCI PM: Split PCI Express port suspend-resume (bnc#455926).
- patches.fixes/PCI-Suspend-and-resume-PCI-Express-ports-with-interrupts-disabled.patch:
  PCI: Suspend and resume PCI Express ports with interrupts
  disabled (bnc#455926).
- patches.fixes/PCI-handle-PCI-state-saving-with-interrupts-disabled.patch:
  PCI: handle PCI state saving with interrupts disabled
  (bnc#455926).
- patches.fixes/pci-rework-suspend-of-devices-with-no-drivers.patch:
  PCI: Rework default handling of suspend and resume (bnc#455926).
* Wed Jan 14 2009 jeffm@suse.de
- Update config files: Disable PARAVIRT.
* Wed Jan 14 2009 gregkh@suse.de
- refresh patches for fuzz due to update to 2.6.27.11
* Wed Jan 14 2009 gregkh@suse.de
- Update to final version of 2.6.27.11
* Wed Jan 14 2009 kkeil@suse.de
- patches.drivers/ixgbe-dcb-setstate.patch: Bugfix for ixgbe
  and kernel DCB netlink code. (bnc#458194)
- patches.drivers/ixgbe_DCB_compile_err.patch: DCB compile
  error fix. (bnc#465923)
- Update config files.
* Wed Jan 14 2009 trenn@suse.de
- patches.fixes/acpi_irq_quirk_pci_irq_derive.patch: Delete.
  It came out that this is an already fixed BIOS bug. The quirk
  is not needed anymore.
* Wed Jan 14 2009 trenn@suse.de
- patches.fixes/acpi_fix_double_slash_root_prefix_handling.patch:
  In AcpiNsGetInternalNameLength, skip the redundant backslash
  of RootPrefix (http://bugzilla.kernel.org/show_bug.cgi?id=11541
  http://www.acpica.org/bugzilla/show_bug.cgi?id=739).
- patches.fixes/acpi_video_always_update_sys.patch: video: always
  update the brightness when poking "brightness" (bnc#450149).
- patches.fixes/acpi_video_handle_reversed_brightness_info.patch:
  ACPI: video: Fix reversed brightness behavior on ThinkPad SL
  series (bnc#450149).
* Wed Jan 14 2009 olh@suse.de
- patches.fixes/sched-fix-__load_balance_iterator-for-cfs-with-on.patch:
  fix __load_balance_iterator() for cfs with only one task
  (bnc#457594 - LTC50544)
* Wed Jan 14 2009 olh@suse.de
- patches.fixes/xfs-redirty-ENOSPC.patch: Re-dirty pages on
  ENOSPC when converting delayed allocations (bnc#433112 - LTC48749)
* Wed Jan 14 2009 npiggin@suse.de
- Added guarded patches:
- patches.suse/mnt-want-write-speedup.patch: fs: mnt_want_write
  speedup (bnc#436953).
- patches.suse/mnt_clone_write.patch: fs: introduce
  mnt_clone_write (bnc#436953).
- patches.suse/unlock_page-speedup.patch: mm: unlock_page speedup
  (bnc#436953).
* Wed Jan 14 2009 gregkh@suse.de
- Update config files.
- patches.drivers/add-via-chrome9-drm-support.patch: add Via
  chrome9 drm support.
* Wed Jan 14 2009 gregkh@suse.de
- patches.drivers/pata_via.c-support-vx855-and-future-chips-whose-ide-controller-use-0x0571.patch:
  pata_via.c: Support VX855 and future chips whose IDE controller
  use 0x0571..
* Tue Jan 13 2009 hare@suse.de
- patches.fixes/scsi-restart-lookup-by-target: Modify patch
  after suggestions from James Bottomley (bnc#465346).
* Tue Jan 13 2009 hare@suse.de
- patches.fixes/scsi-restart-lookup-by-target: Restart
  scsi_device_lookup_by_target() (bnc#465346).
* Tue Jan 13 2009 olh@suse.de
- update patches.drivers/cxgb3-Allocate-multiqueues-at-init-time:
  Allow multiqueue setting in MSI-X mode only (bnc#464351 - LTC50966)
* Tue Jan 13 2009 olh@suse.de
- patches.drivers/cxgb3i-mainline.patch: fixes bug in tag release
  and sync-up cxgb3i with mainline state (bnc#464508 - LTC50816)
* Tue Jan 13 2009 gregkh@suse.de
- Update to 2.6.27.11-rc1:
  - lots of minor fixes
  - obsoletes:
  - patches.fixes/md-bitmap-read-do-not-overflow
  - patches.suse/scsi-scsi_transport_srp-shost_data.patch
* Mon Jan 12 2009 gregkh@suse.de
- supported.conf: add kernel/drivers/acpi/acpi_memhotplug as supported
* Mon Jan 12 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh: handle arch
  symlinks like i586 -> i386 in /usr/src/linux-obj.
* Mon Jan 12 2009 gregkh@suse.de
- supported.conf: updated staging and other drivers
* Mon Jan 12 2009 kkeil@suse.de
- patches.drivers/r8169-Tx-performance-tweak-helper: r8169:
  Tx performance tweak helper.
- patches.drivers/r8169-add-8168-8101-registers-description:
  r8169: add 8168/8101 registers description.
- patches.drivers/r8169-add-hw-start-helpers-for-the-8168-and-the-8101:
  r8169: add hw start helpers for the 8168 and the 8101.
- patches.drivers/r8169-additional-8101-and-8102-support: r8169:
  additional 8101 and 8102 support.
- patches.drivers/r8169-use-pci_find_capability-for-the-PCI-E-features:
  r8169: use pci_find_capability for the PCI-E features.
  (bnc#448168)
* Mon Jan 12 2009 dgollub@suse.de
- scripts/tar-up_and_run_mbuild.sh: use $BUILD_DIR instead of fixed
  "kernel-source" string, to stay in sync with with differet kernel
  variants.
* Mon Jan 12 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh, rpm/source-pre.sh:
  replace the /usr/src/linux-obj symlink with a directory containing
  per-flavor symlinks instead. This allows us to install kernel-source /
  syms and kernel-source-rt / syms-rt in parallel and still find
  everything below /usr/src/linux-obj/.
- rpm/kernel-binary.spec.in: for -rt, install into
    /usr/src/linux-$version-rt-obj.
- rpm/kernel-syms.spec.in: fix kernel-source requires for -rt.
* Sun Jan 11 2009 jkosina@suse.de
- patches.drivers/input-usbtouchscreen-hw-calibration.patch:
  Input: usbtouchscreen - allow reporting calibrated data
  (bnc#444814).
* Fri Jan  9 2009 mmarek@suse.cz
- patches.suse/file-capabilities-add-file_caps-switch.diff:
  fix parsing of the file_caps commandline option (bnc#264075)
* Fri Jan  9 2009 trenn@suse.de
- patches.arch/x86_fix_llc_shared_map__cpu_llc_id_anomolies.patch:
  x86: fix intel x86_64 llc_shared_map/cpu_llc_id anomolies
  (bnc#464329).
* Fri Jan  9 2009 olh@suse.de
- patches.arch/ppc-cmm_no_kdump.patch:
  Disable Collaborative Memory Manager for kdump (bnc#460552 - LTC50789)
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/cgroup-disable-memory.patch: memcg: disable the
  memory controller by default.
- patches.suse/add-enable_cgroup-parameter.patch: Delete.
- patches.suse/disable-cgroups.patch: Delete.
* Fri Jan  9 2009 olh@suse.de
- patches.suse/radeon-monitor-jsxx-quirk.patch
  fix compile errors
* Fri Jan  9 2009 jslaby@suse.de
- patches.fixes/ath5k-ignore-calibration-return-value.patch:
  ath5k: ignore the return value of
  ath5k_hw_noise_floor_calibration (bnc#446541).
* Fri Jan  9 2009 jslaby@suse.de
- patches.fixes/cgroups-suppress-cloning-warning.patch: cgroups:
  suppress bogus warning messages (bnc#460961).
* Fri Jan  9 2009 olh@suse.de
- patches.suse/radeon-monitor-jsxx-quirk.patch: Add quirk for
  the graphics adapter in some JSxx (bnc#461002 - LTC50817)
* Fri Jan  9 2009 trenn@suse.de
- patches.fixes/acpi_irq_quirk_pci_irq_derive.patch: ACPI: Do not
  derive IRQ from parent bridge/device via boot param/dmi list
  (bnc#437211).
- patches.suse/acpi_osi_sle11_ident.patch: Provide possibility
  for vendors to fix BIOS issues for SLE11 only (none).
* Fri Jan  9 2009 hare@suse.de
- patches.drivers/blk-request-based-multipath-update: Rediff.
- patches.fixes/scsi-refactor-busy-processing: refactor
  sdev/starget/shost busy checking; break out from
  blk-request-based-multipath-update.
* Fri Jan  9 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.11-update: Update lpfc from 8.2.8.10
  to 8.2.8.11 (bnc#464662).
- patches.fixes/scsi-call-unprep_request-under-lock: scsi_lib:
  only call scsi_unprep_request() under queue lock (bnc#464155).
- patches.fixes/scsi-fix-hang-in-starved-list-processing: Fix
  hang in starved list processing (bnc#464155).
* Fri Jan  9 2009 kkeil@suse.de
- patches.drivers/bnx2-Add-PCI-ID-for-5716S: bnx2: Add PCI ID
  for 5716S
- patches.drivers/bnx2-Fix-bug-in-bnx2_free_rx_mem_: bnx2:
  Fix bug in bnx2_free_rx_mem() (bnc#464130)
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/disable-cgroups.patch: Disable all cgroups
  (bnc#436025).
* Fri Jan  9 2009 hare@suse.de
- Backporting block layer fixes (bnc#464155):
  * patches.fixes/block-add-comment-in-blk_rq_timed_out: add
    comment in blk_rq_timed_out() about why next can not be 0
  * patches.fixes/block-fix-blk_start_queueing: block: Fix
    blk_start_queueing() to not kick a stopped queue.
  * patches.fixes/block-leave-the-request-timeout-timer-running:
    block: leave the request timeout timer running even on an
    empty list.
  * patches.fixes/block-optimizations-in-blk_rq_timed_out_timer:
    block: optimizations in blk_rq_timed_out_timer().
  * patches.fixes/block-suppress-buffer-IO-errors: block: Supress
    Buffer I/O errors when SCSI REQ_QUIET flag set.
  * patches.fixes/block-use-round_jiffies_up: Block: use
    round_jiffies_up().
  * patches.fixes/round-jiffies-up: Add round_jiffies_up and
    related routines.
* Fri Jan  9 2009 jbeulich@novell.com
- patches.xen/xen3-acpi-pci-pci-msi-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI MSI _OSC support capabilities called when root
  bridge added (bnc#438941).
* Fri Jan  9 2009 hare@suse.de
- patches.fixes/scsi_dh-retry-on-UNIT_ATTENTION: scsi_dh_rdac
  does not retry MODE SENSE on UNIT ATTENTION (bnc#464155).
- patches.suse/scsi-check-removed-device-for-offline: Only check
  for SDEV_OFFLINE and SDEV_DEL, not SDEV_CANCEL.
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/add-enable_cgroup-parameter.patch: Add
  cgroup_enable parameter (bnc#436025).
* Fri Jan  9 2009 gregkh@suse.de
- patches.drivers/acpi-pci-include-missing-acpi.h-file-in-pci-acpi.h.patch:
  ACPI/PCI: include missing acpi.h file in
  pci-acpi.h. (bnc#438941).
* Fri Jan  9 2009 gregkh@suse.de
- clean up patch fuzz
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/acpi-pci-pci-msi-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI MSI _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-pcie-aer-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCIe AER _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-pcie-aspm-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCIe ASPM _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-remove-obsolete-_osc-capability-support-functions.patch:
  ACPI/PCI: remove obsolete _OSC capability support functions
  (bnc#438941).
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/acpi-pci-call-_osc-support-during-root-bridge-discovery.patch:
  ACPI/PCI: call _OSC support during root bridge discovery
  (bnc#438941).
- patches.drivers/acpi-pci-change-pci_osc_control_set-to-query-control-bits-first.patch:
  ACPI/PCI: Change pci_osc_control_set() to query control bits
  first (bnc#438941).
- patches.drivers/acpi-pci-fix-possible-race-condition-on-_osc-evaluation.patch:
  ACPI/PCI: Fix possible race condition on _OSC evaluation
  (bnc#438941).
- patches.drivers/acpi-pci-include-missing-acpi.h-file-in-pci-acpi.h.patch:
  ACPI/PCI: include missing acpi.h file in
  pci-acpi.h. (bnc#438941).
- patches.drivers/acpi-pci-pci-extended-config-_osc-support-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI extended config _OSC support called when root
  bridge added (bnc#438941).
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/bnx2x-version-update.patch: bnx2x: Version
  Update (bnc#439679).
* Thu Jan  8 2009 jjolly@suse.de
- patches.arch/s390-07-01-zfcp-port-failed-message.diff: zfcp:
  Remove message for failed port (bnc#464466).
- patches.arch/s390-07-02-zfcp-unchained-fsf.diff: zfcp: Add
  support for unchained FSF requests (bnc#464466).
- patches.arch/s390-07-03-topology-fix.diff: kernel: fix cpu
  topology support (bnc#464466).
- patches.arch/s390-07-04-dasd-failfast.patch: dasd: Add
  'failfast' device feature. (bnc#464466,LTC#43066).
* Thu Jan  8 2009 tiwai@suse.de
- patches.drivers/alsa-caiaq-midi-oops-fix: ALSA: caiaq - Fix
  Oops with MIDI.
* Thu Jan  8 2009 knikanth@suse.de
- patches.fixes/dm-avoid-put-table-dm_any_congested: dm: avoid
  destroying table in dm_any_congested (bnc#457205).
- patches.fixes/dm-table-ref-count: dm table: rework reference
  counting (bnc#457205).
- patches.fixes/dm-unbind-drop-ref: dm table: drop reference at
  unbind (bnc#457205).
* Thu Jan  8 2009 olh@suse.de
- update kdump config, disable some unused drivers
* Thu Jan  8 2009 olh@suse.de
- refresh config files, no functional changes
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ehea-modinfo.patch:
  use separate table for module alias (bnc#435215 - LTC48564)
* Thu Jan  8 2009 tiwai@suse.de
  Backport fixes for HD-audio from the upstream:
- patches.drivers/alsa-hda-ad1882-id-typo-fix: ALSA: hda -
  Fix typos for AD1882 codecs.
- patches.drivers/alsa-hda-ad1986a-laptop-eapd-model-back: ALSA:
  hda - make laptop-eapd model back for AD1986A.
- patches.drivers/alsa-hda-hp2230s-quirk: ALSA: hda - Add quirk
  for HP 2230s (bnc#461660).
- patches.drivers/alsa-hda-sigmatel-add-missing-terminators:
  ALSA: hda - Add missing terminators in patch_sigmatel.c.
* Thu Jan  8 2009 bwalle@suse.de
- Update config files: Enable CONFIG_EHEA=m (and CONFIG_IBMEBUS=y)
  for ppc/kdump and ppc64/kdump (bnc #459119).
* Thu Jan  8 2009 jblunck@suse.de
- Make kernel-source.changes incremental again
* Thu Jan  8 2009 olh@suse.de
- supported.conf: rename dm-leastpending-path to dm-leastpending
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ehea-modinfo.patch:
  add alias entry for portN properties (bnc#435215 - LTC48564)
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ibmvfc-abort-response.patch:
  Fixup command response translation (bnc#459383 - LTC50695)
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ibmvfc-improve_sync_events.patch:
  Improve async event handling (bnc#460567 - LTC50778)
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/via-unichrome-drm-bugfixes.patch: via: Unichrome
  DRM bugfixes.
* Thu Jan  8 2009 coly.li@suse.de
- Move patch from patches.suse/dlm-fix-shutdown-cleanup.patch to
  patches.fixes/dlm-fix-shutdown-cleanup.patch
* Thu Jan  8 2009 coly.li@suse.de
- Fixes a regression from commit
  0f8e0d9a317406612700426fad3efab0b7bbc467,
  "dlm: allow multiple lockspace creates".
* Wed Jan  7 2009 olh@suse.de
- patches.arch/ppc-pseries-cpu-migrate.patch: Update
  default_server during migrate_irqs_away (bnc#460566 - LTC50723)
* Wed Jan  7 2009 jack@suse.cz
- patches.suse/mm-increase-dirty-limits.patch: Increase limits
  for starting writeback of dirty data (bnc#449662).
* Wed Jan  7 2009 ghaskins@suse.de
- Update config files (part of bnc#448412).
* Wed Jan  7 2009 ghaskins@suse.de
- patches.fixes/ia64-configure-HAVE_UNSTABLE_SCHED_CLOCK-for-SGI_SN.patch:
  configure HAVE_UNSTABLE_SCHED_CLOCK for SGI_SN systems (bnc#448412).
* Wed Jan  7 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.10-update: Emulex 8.2.8.10 driver
  patches for SLE11 (bnc#460775).
* Wed Jan  7 2009 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Update Patch-mainline
  header. Patch is not refreshed as it breaks kabi (FATE#304489).
* Wed Jan  7 2009 hare@suse.de
- patches.drivers/cciss-driver-panic-on-volume-delete: cciss
  driver may panic if a logical volume is deleted (bnc#459553).
* Wed Jan  7 2009 hare@suse.de
- patches.suse/scsi-netlink-ml: Use GFP_ATOMIC to avoid deadlocks
  (bnc#461747).
* Wed Jan  7 2009 hare@suse.de
- patches.fixes/fc_transport-devloss-callback-restore: FC devloss
  callback not called when devloss timer fires (bnc#463289).
* Wed Jan  7 2009 hare@suse.de
- patches.suse/dm-mpath-leastpending-path-update: Update
  least-pending-IO dynamic load balancer (bnc#444199).
- patches.suse/dm-mpath-queue-length-load-balancing: Rediff.
- patches.suse/dm-mpath-service-time-load-balancing: Rediff.
- patches.suse/dm-mpath-tracking-nr-bytes: Rediff.
- patches.suse/dm-mpath-leastpending-path: Delete.
* Tue Jan  6 2009 jeffm@suse.de
- patches.fixes/uv-remove-erroneous-BAU-init: UV: remove erroneous
  BAU initialization (bnc#463313).
* Tue Jan  6 2009 jjolly@suse.de
- patches.arch/s390-06-01-qeth-ext-src-mac-addr.patch: qeth:
  exploit source MAC address for inbound layer3 packets
  (bnc#458339).
- patches.arch/s390-06-02-qeth-layercrash.patch: qeth: avoid
  crash in case of layer mismatch for VSWITCH (bnc#458339).
- patches.arch/s390-06-03-dasd_sim_sense_condition.patch: Fix
  unsolicited SIM sense condition. (bnc#458339).
- patches.arch/s390-06-04-qdio_ssqd_memcpy.patch: qdio: fix
  broken memcpy (bnc#458339).
- patches.arch/s390-06-05-qdio_s390dbf.patch: qdio: rework
  s390dbf usage  (bnc#458339).
- patches.arch/s390-06-06-qdio_inbound_ack.patch: qdio: rework
  inbound buffer acknowledgement (bnc#458339).
- patches.arch/s390-06-07-cio-attach_detach.patch: cio: Crashes
  when repeatetly attaching/detaching devices. (bnc#458339).
* Tue Jan  6 2009 npiggin@suse.de
- patches.arch/x86-fix-kmap-contig.patch: x86: Jan's comments for
  contiguous kmap fix (bnc#449812).
* Tue Jan  6 2009 npiggin@suse.de
- patches.fixes/mm-lockless-pagecache-barrier.patch: update.
* Mon Jan  5 2009 mmarek@suse.cz
- patches.suse/modpost-filter-out-built-in-depends: modpost:
  filter out "built-in" depends (bnc#450085).
- patches.drivers/0002-Staging-add-TAINT_CRAP-flag-to-drivers-staging-modu.patch:
  refresh.
* Mon Jan  5 2009 npiggin@suse.de
- Fix ps3 config.
* Mon Jan  5 2009 npiggin@suse.de
- patches.fixes/mm-lockless-pagecache-barrier.patch: mm lockless
  pagecache barrier fix.
* Mon Jan  5 2009 npiggin@suse.de
- patches.fixes/fs-symlink-write_begin-allocation-context-fix.patch:
  fs symlink write_begin allocation context fix.
* Mon Jan  5 2009 npiggin@suse.de
- Update config files.
* Mon Jan  5 2009 npiggin@suse.de
- patches.suse/cgroup-freezer.patch: cgroup freezer update (bnc#417294,
  fate#304191, fate#201036).
* Wed Dec 31 2008 npiggin@suse.de
- patches.fixes/s390-lru_add_drain_all.patch: mm: remove UP
  version of lru_add_drain_all() (bnc#458380).
* Wed Dec 31 2008 npiggin@suse.de
- patches.arch/x86-fix-kmap-contig.patch: x86: contiguous kmap
  fix (bnc#449812).
* Mon Dec 29 2008 jeffm@suse.de
- patches.arch/thinkpad_acpi-hotkey-notify-fix: thinkpad_acpi:
  Fix oops with incompatible backlight interface.
* Mon Dec 22 2008 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  fix bootmem reservation on uninitialized node (bunc#457029 - LTC50483)
* Mon Dec 22 2008 olh@suse.de
- patches.fixes/scsi-ibmvscsi-can_queue_fix.patch: Make
  max_requests module parameter more accurate (bnc#458499 - LTC50637)
* Sat Dec 20 2008 tiwai@suse.de
- patches.drivers/alsa-hda-hp-dv7-quirk: ALSA: hda - Add quirk
  for another HP dv7 (bnc#461108).
* Sat Dec 20 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-pm-support: More fixes (bnc#447624).
* Fri Dec 19 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Print more info.
* Fri Dec 19 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-capture-no-44khz: ALSA: disable
  44.1kHz capture on CA0106 (bnc#447624).
- patches.drivers/alsa-ca0106-pm-support: ALSA: ca0106 - Add
  power-amangement support (bnc#447624).
- patches.drivers/alsa-hda-92hd73x-desktop-fixes: ALSA: Fix
  plaback problems on Intel desktops with IDT codecs.
* Fri Dec 19 2008 jbeulich@novell.com
- patches.arch/x86_sgi-uv-scir.patch,
  patches.suse/e1000e_ioremap_sanity_check,
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch,
  patches.suse/perfmon2.patch,
  patches.suse/silent-stack-overflow-2.patch: eliminate build warnings.
* Fri Dec 19 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-rt2870-wireless-driver.patch:
  Staging: add rt2870 wireless driver.
* Fri Dec 19 2008 nfbrown@suse.de
- patches.fixes/md-bitmap-read-do-not-overflow: md: Don't read
  past end of bitmap when reading bitmap. (bnc#459557).
* Thu Dec 18 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Fixed ordering.
* Thu Dec 18 2008 jeffm@suse.de
- patches.fixes/reiserfs-ensure-nonzero-transaction: Delete.
* Thu Dec 18 2008 gregkh@suse.de
- Updated to final 2.6.27.10 release
* Thu Dec 18 2008 trenn@suse.de
- patches.arch/x86-apic-force-bigsmp-apic-on-IBM-EXA3-4.patch:
  Use apic=bigsmp on specific xseries machines (bnc#440497).
* Thu Dec 18 2008 trenn@suse.de
- patches.arch/x86_restrict_pci_early_quirks_to_root_bridges.patch:
  Only scan the root bus in early PCI quirks. (bnc#57886).
* Thu Dec 18 2008 jbeulich@novell.com
- patches.xen/746-pirq-status-page.patch: Merge in c/s 751.
- patches.xen/761-highpte.patch: blktap, gntdev: fix highpte handling.
- patches.xen/762-xencons-hvc.patch: add hvc compatibility mode to xencons.
- patches.xen/xen3-patch-2.6.27.7-8: Linux 2.6.27.8.
- patches.xen/xen3-patch-2.6.27.8-9: Linux 2.6.27.9.
- patches.xen/xen-x86-exports: export a few more symbols
  (bnc#458222).
- patches.xen/xen3-perfmon2_remove_syscalls.patch: Rename to ...
- patches.xen/xen3-perfmon2-remove_syscalls.patch: ... this.
* Thu Dec 18 2008 nfbrown@suse.de
- patches.fixes/md-disable-recovery-on-faulty-degraded-array:
  Disable recovery when degraded RAID1 array appears to be
  faulty. (bnc#447835).
* Wed Dec 17 2008 mmarek@suse.cz
- rpm/symsets.pl: fix uninitialized variable
* Wed Dec 17 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in:
  - add genksyms reference files so that genksyms can explain why
    did checksums change
* Wed Dec 17 2008 gregkh@suse.de
- patches.drivers/via-framebuffer-driver.patch: Delete.  It
  oopses badly and is not needed for the HP2133 hardware, as
  it has switched to Intel chipsets.
* Wed Dec 17 2008 gregkh@suse.de
- Upate to 2.6.27.10-rc1, fixing lots of problems.
  - obsoletes:
  - patches.drivers/libata-update-ST-FLUSH-blacklist
  - patches.fixes/iwlwifi_fix_oops.patch
  - patches.fixes/v4l-dvb-avoid-writing-outside-array
* Tue Dec 16 2008 jeffm@suse.de
- patches.suse/reiserfs-barrier-default: Make reiserfs default
  to barrier=flush.
* Tue Dec 16 2008 mmarek@suse.cz
- addded symtypes-* files to the RC1 reference kabi
* Tue Dec 16 2008 jeffm@suse.de
- patches.fixes/ext3-mark-super-uptodate: ext3: always mark
  super uptodate before dirty (bnc#457043).
* Tue Dec 16 2008 hare@suse.de
- patches.fixes/blk-dont-invoke-request_fn-on-stopped-queue:
  block: only call ->request_fn when the queue is not stopped
  (bnc#457041).
- patches.fixes/blk-get-extra-reference-before-unmap: block:
  hold extra reference to bio in blk_rq_map_user_iov().
- patches.fixes/blk-move-unplug_work-init: block: move
  q->unplug_work initialization.
- patches.fixes/blk-set-segment-boundary-mask: block: fix setting
  of max_segment_size and seg_boundary mask.
- patches.fixes/dm-mpath-send-activate-to-every-path: Handle
  multiple paths in a path group properly during pg_init.
- patches.fixes/scsi_dh-add-lsi-ids-to-rdac: Adding LSI vendor
  and product IDs to RDAC device handler.
- patches.suse/dm-mpath-accept-failed-paths: Accept failed paths
  for multipath maps (bnc#458037,bnc#458393).
- patches.suse/scsi-check-removed-device-for-offline: Check if
  device is removed in scsi_device_online() (bnc#456747).
* Tue Dec 16 2008 hare@suse.de
- Enable 3270 console (bnc#457039)
* Tue Dec 16 2008 rjw@suse.de
- Update config files.
- patches.suse/mm-do-not-disable-memory-hotplug-when-hibernation-is-enabled.patch:
  mm: Do not disable memory hotplug when hibernation is enabled
  (bnc#438914).
* Mon Dec 15 2008 jeffm@suse.de
- patches.fixes/iwlwifi_fix_oops.patch: iwlwifi: clean key table
  in iwl_clear_stations_table function (bnc#457062).
* Mon Dec 15 2008 jjolly@suse.de
- patches.drivers/cxgb3i_ddp.patch: cxgb3i - added pdu size
  check and fixed ddp page setup (bnc#449519).
* Mon Dec 15 2008 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k8_sles11-04-update: qla4xxx
  driver SLES 11 Beta6 update (bnc#458186).
* Mon Dec 15 2008 oneukum@suse.de
- patches.suse/usb_correct_config_ti_04b3_4543.diff: fix
  ti_usb_3410_5052 driver for device 04b3:4543 (bnc#395775).
* Sun Dec 14 2008 gregkh@suse.de
- Update to 2.6.27.9
  - obsoleted:
  - patches.fixes/applicom-fix-unchecked-ioctl-range
  - patches.fixes/watchdog-ib700wdt-buffer-underflow
* Fri Dec 12 2008 jeffm@suse.de
- patches.fixes/reiserfs-ensure-nonzero-transaction: reiserfs:
  ensure nonzero transaction (bnc#447406).
* Fri Dec 12 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Update to print accurate refcount.
* Fri Dec 12 2008 jblunck@suse.de
- .gitignore: Ignore backup files.
* Fri Dec 12 2008 hare@suse.de
- patches.fixes/scsi-check-host-lookup-failure: Correct
  scsi_host_lookup return value (bnc#456532).
- patches.suse/dm-mpath-accept-failed-paths: Accept failed paths
  for multipath maps (bnc#458037).
* Fri Dec 12 2008 fseidel@suse.de
- patches.fixes/hso_killswitch.patch: hso: rfkill type should
  be WWAN (bnc#458625).
* Fri Dec 12 2008 fseidel@suse.de
- patches.fixes/hso_killswitch.patch:
  fix hso rfkillswitch type to WWAN (bnc#458625)
* Fri Dec 12 2008 mmarek@suse.cz
- import SLE11 RC1 reference kabi
* Fri Dec 12 2008 gregkh@suse.de
- refresh patches to apply cleanly due to 2.6.27.9-rc addition.
* Fri Dec 12 2008 gregkh@suse.de
- remove patches that were obsoleted by 2.6.27.9-rc2
  - patches.arch/ppc-mpic-dont-reset-affinity-for-secondary-MPIC-on-boot.patch
  - patches.arch/x86-hpet-use-WARN_ON_ONCE
  - patches.drivers/alsa-hda-acer-quirk
  - patches.drivers/alsa-hda-alc888-medion-add
  - patches.drivers/alsa-hda-dell-studio-15-quirk
  - patches.drivers/alsa-hda-dell-studio-1535-quirk
  - patches.drivers/alsa-hda-hp-6730s-quirk
  - patches.drivers/alsa-hda-hp-elitebook-8530p-quirk
  - patches.drivers/alsa-hda-hp-mobile-fix
  - patches.drivers/alsa-hda-stac-no-hp-as-line-out-switch
  - patches.drivers/cell_edac.patch
  - patches.fixes/acpi-set-SCI_EN-on-MacBook.patch
  - patches.fixes/atm-duplicate-listen-on-socket-corrupts-the-vcc-table.patch
  - patches.fixes/block-enforce-minimum-SG_IO-timeout
  - patches.fixes/cxgb3-remove-duplicate-tests-in-lro
  - patches.fixes/cxgb3_fix_race_in_EEH
  - patches.fixes/hibernate-x86-fix-breakage-on-x86_32-with-PAE.patch
  - patches.fixes/pci_aspm_check_endless_loop_safe.patch
  - patches.fixes/sched-fix-bug-in-sched-domain-degenerate.patch
  - patches.fixes/x86-arch_add_memory-remove-debug
  - patches.fixes/x86-memory-hotplug-off-by-one
* Fri Dec 12 2008 gregkh@suse.de
- update to 2.6.27.9-rc2:
  - lots of bugfixes
  - some security updates
* Thu Dec 11 2008 gregkh@suse.de
- intermediate commit as part of adding 2.6.27.9-rc1 to the tree.
* Thu Dec 11 2008 hare@suse.de
- Compile in zfcpdump module for S/390 (bnc#446367).
* Thu Dec 11 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: one more fix to make kabi checks work
* Thu Dec 11 2008 teheo@suse.de
- patches.drivers/libata-update-ST-FLUSH-blacklist: libata:
  fix Seagate NCQ+FLUSH blacklist (bnc#458192).
* Wed Dec 10 2008 nfbrown@suse.de
- patches.suse/SoN-fix-sync: Cope with racy nature of sync_page
  in swap_sync_page (441793).
* Wed Dec 10 2008 jjolly@suse.de
- patches.arch/s390-05-09-cleanup-of-portopen-requests.patch:
  zfcp: fix erp timeout cleanup for port open requests
  (bnc#450096).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/watchdog-ib700wdt-buffer-underflow: ib700wdt.c -
  fix buffer_underflow bug (bnc#457898).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/applicom-fix-unchecked-ioctl-range: applicom: Fix
  an unchecked user ioctl range and an error return (bnc#457897).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/block-enforce-minimum-SG_IO-timeout: Enforce a
  minimum SG_IO timeout (bnc#457896).
* Wed Dec 10 2008 mmarek@suse.cz
- rpm/find-provides: don't fail if a subpackage doesn't contain
  any modules (such as the -man subpackage on s390x)
* Wed Dec 10 2008 tiwai@suse.de
- patches.drivers/alsa-hda-hp-6730b-quirk: ALSA: hda - Add quirk
  for HP6730B laptop (bnc#457909).
- patches.drivers/alsa-hda-hp-6730s-quirk: ALSA: hda - Add
  another HP model (6730s) for AD1884A.
- patches.drivers/alsa-hda-hp-elitebook-8530p-quirk: ALSA: hda -
  Make the HP EliteBook 8530p use AD1884A model laptop.
* Wed Dec 10 2008 olh@suse.de
- patches.drivers/ibmvfc-add_sync.patch:
  Fix errors due to inconsistent command data (bnc#456654 - LTC50451)
- patches.drivers/ibmvfc-host_init_delay.patch:
  Delay NPIV login retry and add retries (bnc#456654 - LTC50451)
* Wed Dec 10 2008 teheo@suse.de
- patches.drivers/libata-pata_hpt366-fix-cable-detection:
  pata_hpt366: fix cable detection, (bnc#362159).
- patches.drivers/libata-pata_hpt366-fix-clock-detection:
  pata_hpt366: fix clock detection (bnc#362159).
- patches.drivers/libata-pata_hpt366-no-ATAPI-DMA: pata_hpt366:
  no ATAPI DMA (bnc#362159).
- patches.drivers/libata-pata_hpt366-reimplement-mode-programming:
  pata_hpt366: reimplement mode programming (bnc#362159).
* Tue Dec  9 2008 agruen@suse.de
- supported.conf: Mark xfs_dmapi as supported (bnc#457668).
* Tue Dec  9 2008 jeffm@suse.de
- patches.fixes/x86-arch_add_memory-remove-debug: x86: remove
  debug code from arch_add_memory() (bnc#457526).
- patches.fixes/x86-memory-hotplug-off-by-one: x86, memory
  hotplug: remove wrong -1 in calling init_memory_mapping()
  (bnc#457526).
* Tue Dec  9 2008 agruen@suse.de
- rpm/{kernel-module-subpackage,macros.kernel-source}: Remove
  a leftover hardcoded dependency on the kernel-source package so
  that KMPs can alternatively be built against a kernel other
  than (kernel-source + kernel-syms), such as (kernel-source-rt +
  kernel-syms-rt).
* Tue Dec  9 2008 trenn@suse.de
- patches.fixes/pci_aspm_check_endless_loop_safe.patch: PCIe:
  ASPM: Break out of endless loop waiting for PCI config bits
  to switch (bnc#449799).
* Tue Dec  9 2008 mmarek@suse.cz
- rpm/symsets.pl:
  - add --required-modules option to tell which modules this
    subpackage requires via dependencies. This is needed to
    preserve symsets when modules move from one subpackage to
    another.
  - add POD help and --help option.
- rpm/kernel-binary.spec.in: make use of --required-modules
* Tue Dec  9 2008 nfbrown@suse.de
- patches.fixes/xfs-barrier-fix.patch: Fix propagation of
  EOPNOTSUPP when barriers are not supported. (bnc#438608).
* Mon Dec  8 2008 rjw@suse.de
- patches.fixes/tg3-fix-default-wol.patch: net (tg3): Fix failure
  to enable WoL by default when possible (bnc#447371).
* Mon Dec  8 2008 olh@suse.de
- patches.arch/ppc-valid-hugepage-size-hugetlb_get_unmapped_area.patch:
  Check for valid hugepage size in hugetlb_get_unmapped_area
  (bnc#456433 - LTC50170).
* Mon Dec  8 2008 trenn@suse.de
- patches.fixes/pci_aspm_check_endless_loop.patch: Delete.
* Mon Dec  8 2008 rw@suse.de
- patches.drivers/sgi-xp-no-uv:
  SGI SN: Eliminate dependency of the XP/XPC drivers on GRU. (bnc#442442)
* Mon Dec  8 2008 rw@suse.de
- Update config files for ia64:
  Disable PERMIT_BSP_REMOVE.  (bnc#386714)
* Mon Dec  8 2008 mmarek@suse.cz
- rpm/find-provides, rpm/kernel-binary.spec.in: figure out what
  subpackage is being processed in find-provides and just print
  the symsets computed in the spec.
* Mon Dec  8 2008 olh@suse.de
- rpm/post.sh: use flavor-rpmarch to match boards on powerpc
* Mon Dec  8 2008 mmarek@suse.cz
- rpm/kernel-module-subpackage: skip empty KMPs with a warning in
  the kmp %%%%postun
* Mon Dec  8 2008 jjohansen@suse.de
- Update config files.
- patches.apparmor/fix-complain.diff: fix enforcement of deny
  rules in complain mode (bnc#426159).
- patches.apparmor/fix-security-param.diff: fix recognition of
  security= boot parameter (bnc#442668).
- patches.apparmor/fork-tracking.diff: fix log messages to enable
  tools profile learning (bnc#447564).
* Mon Dec  8 2008 olh@suse.de
- rpm/post.sh: update board detection to use rpmarch instead flavor
* Mon Dec  8 2008 hare@suse.de
- patches.fixes/block-integrity-update: Block integrity update
  (FATE#304345).
- patches.suse/dm-block-integrity: Block integrity support for
  DM and MD (FATE#304345).
- patches.suse/dm-mpath-add-start-io: dm-mpath: add a path
  selector interface (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-queue-length-load-balancing: dm-mpath: add
  queue-length dynamic load balancer (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-service-time-load-balancing:
  dm-mpath: add service-time oriented dynamic load balancer
  (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-tracking-nr-bytes: dm-mpath:
  interface change for service-time dynamic load balancer
  (FATE#303862,FATE#302108).
- supported.conf: Update to correctly reference dynamic load
  balancer modules (bnc#444199)
* Mon Dec  8 2008 tonyj@suse.de
- patches.suse/perfmon2-add_ioctl_interface.patch: switch to
  ioctl interface for perfmon2.
- patches.suse/perfmon2-fix_disabled.patch: fix initializion of
  perfmon disabled.
- patches.suse/perfmon2-remove_get_base_syscall_attr.patch:
  remove perfmon syscall_base attribyute.
- patches.suse/perfmon2-remove_syscalls.patch: drop additional
  perfmon2 syscalls.
- patches.xen/xen3-perfmon2_remove_syscalls.patch: drop additional
  perfmon2 syscalls.
* Sat Dec  6 2008 trenn@suse.de
- patches.arch/acpi_ec_provide_non_interrupt_mode_boot_param.patch:
  ACPI: EC: Don't degrade to poll mode at storm
  automatically. (bnc#446142).
- patches.fixes/pci_aspm_check_endless_loop.patch: PCIE Break
  out of endless loop waiting for PCI config bits to switch
  (bnc#449799).
* Sat Dec  6 2008 gregkh@suse.de
- refresh patches to apply cleanly.
* Sat Dec  6 2008 gregkh@suse.de
- Update to final 2.6.27.8 release
  - contains 2 changes from 2.6.27.8-rc1
* Fri Dec  5 2008 jbeulich@novell.com
- patches.xen/xen-configurable-guest-devices: fix a typo.
* Fri Dec  5 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch:
  move crq_queue_create at the end of initialization (bnc#455929).
* Fri Dec  5 2008 hare@suse.de
- patches.drivers/open-fcoe-fnic-patches: Open-FCoE bugfixes
  for fnic.
- patches.drivers/open-fcoe-rc1-update: Update open-FCoE with
  latest patches from Intel (bnc#438954).
* Fri Dec  5 2008 jbeulich@novell.com
- Update Xen x86-64 config (2k guest devices, 1k outstanding transmits
  in netback).
* Fri Dec  5 2008 hare@suse.de
- patches.arch/s390-zfcp-synchronize-scsi-register: No udev
  events for zfcp online / offline (bnc#443667).
- patches.fixes/scsi-remove-scmd-timeout: Fix block timeout
  residue problems (bnc#447249,bnc#441335).
- patches.fixes/scsi-eh_stu-timeout: Delete obsolet patch.
* Fri Dec  5 2008 bphilips@suse.de
- patches.fixes/saa7134-fix-resource-map-sanity-check-conflict.patch:
  saa7134: fix resource map sanity check conflict (bnc#446733).
* Fri Dec  5 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-rtl8187se-driver.patch: Staging:
  add rtl8187se driver.  Needed for MSI Wind and other netbooks.
* Fri Dec  5 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-serverengines-benet-10gb-ethernet-driver.patch:
  Staging: Add ServerEngines benet 10Gb ethernet driver.
* Fri Dec  5 2008 gregkh@suse.de
- update the wlan-ng driver to the latest upstream version, making
  it much more useful (it actually works now...)
* Fri Dec  5 2008 nfbrown@suse.de
- patches.fixes/sunrpc-module-refcount-fix: Add a reference to
  sunrpc in svc_addsock (443379).  This avoid a bug where
  refcount on sunrpc can go zero or negative.
* Thu Dec  4 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: reiserfs: print more
  information when an empty journal list is encountered
  (bnc#447406 bnc#399966).
* Thu Dec  4 2008 gregkh@suse.de
- patches.fixes/atm-duplicate-listen-on-socket-corrupts-the-vcc-table.patch:
  ATM: duplicate listen() on socket corrupts the vcc table
  (CVE-2008-5079).
* Thu Dec  4 2008 jack@suse.cz
- Update config files.
* Thu Dec  4 2008 jack@suse.cz
  XFS update on request from SGI:
- patches.apparmor/vfs-notify_change.diff: Add a vfsmount
  parameter to notify_change(). (refreshed)
- patches.suse/xfs-account-for-allocated-blocks-when-expanding-directories:
  Account for allocated blocks when expanding directories
  (bnc#450658).
- patches.suse/xfs-check-for-valid-transaction-headers-in-recovery:
  XFS: Check for valid transaction headers in recovery
  (bnc#450658).
- patches.suse/xfs-dmapi-enable: VFS changes to support DMAPI
  (bnc#450658).
- patches.suse/xfs-dmapi-src: DMAPI Source  (bnc#450658).
- patches.suse/xfs-dmapi-xfs-enable: DMAPI support for xfs
  (bnc#450658).
- patches.suse/xfs-handle-memory-allocation-failures-during-log-initialisation:
  handle memory allocation failures during log initialisation
  (bnc#450658).
- patches.suse/xfs-nfsd-dmapi-aware: Make NFSD DMAPI aware
  (74107, 173874, bnc#450658).
- patches.suse/xfs-wait-for-all-IO-on-truncate-to-zero: Wait
  for all I/O on truncate to zero file size (bnc#450658).
- patches.suse/xfs-dmapi-2.6.27: Delete.
- patches.suse/xfs-dmapi-xfs-2.6.27: Delete.
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-mpic-dont-reset-affinity-for-secondary-MPIC-on-boot.patch:
  Don't reset affinity for secondary MPIC on boot (bnc#456408 - LTC50397).
* Thu Dec  4 2008 jjolly@suse.de
- Update config files.
- patches.arch/s390-05-04-fix_rport_status_check.patch: zfcp:
  fix remote port status check (bnc#450096).
- patches.arch/s390-05-05-stp-etr-stop-machine.patch: stp/etr:
  smp_call_function races. (bnc#450096).
- patches.arch/s390-05-06-stp-etr-mutex.patch: stp/etr: serialize
  work. (bnc#450096).
- patches.arch/s390-05-07-generic-ipi.patch: kernel:
  smp_call_function races. (bnc#450096).
- patches.arch/s390-05-08-topology.patch: kernel: disable cpu
  topology support by default (bnc#450096,LTC#50392).
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-cell-gdb-watchpoints.patch:
  Fix GDB watchpoints on Cell (bnc#456405 - LTC50396).
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-syscall-xer.so.1.patch: Fix system calls on
  Cell entered with XER.SO=1 (bnc#456406 - LTC50395).
* Thu Dec  4 2008 hare@suse.de
- patches.suse/genhd-disk-ro-uevents: Send uevents for
  write_protect changes (bnc#440959).
* Thu Dec  4 2008 mmarek@suse.cz
- supported.conf: mark kernel/net/ipv4/ipvs/ip_vs/* and
  kernel/net/ipv4/netfilter/ipt_CLUSTERIP as unsupported,
  a supported variant will be provided in a separate KMP
  (bnc#455959)
* Thu Dec  4 2008 schwab@suse.de
- Set CONFIG_IA64_CPE_MIGRATE=m.
* Thu Dec  4 2008 jbeulich@novell.com
- supported.conf: Mark pciback as support, sfc_resource, sfc_netback,
  and sfc_netutil as externally supported, add sfc_netfront, and mark
  xenscsi and xen-scsibk as unsupported.
* Thu Dec  4 2008 mszeredi@suse.de
- patches.suse/SoN-fix-uninitialized-variable.patch: Fix use of
  uninitialized variable in cache_grow() (bnc#444597).
* Thu Dec  4 2008 hare@suse.de
- patches.fixes/scsi-eh_stu-timeout: make scsi_eh_try_stu use
  block timeout (bnc#447249,bnc#441335).
* Thu Dec  4 2008 gregkh@suse.de
- patches.fixes/jbd2-create-proc-entry-fix.patch: Delete. It's not needed
  anymore now that 2.6.27.8-rc1 has a similar fix.
* Wed Dec  3 2008 gregkh@suse.de
- Update to 2.6.27.8-rc1:
  - lots of bugfixes
  - some security fixes as well.
  - obsoletes lots of existing patches:
  - patches.arch/ppc-spufs-02-add-a-missing-mutex_unlock.patch
  - patches.arch/ppc-spufs-11-Fix-spinning-in-spufs_ps_fault-on-sig.patch
  - patches.drivers/libata-fix-ata_tf_read_block-overflow
  - patches.drivers/libata-fix-ata_tf_to_lba48-overflow
  - patches.drivers/libata-seagate-firmware-bug
  - patches.drivers/parport-serial-array-overflow-fix
  - patches.fixes/af_unix-soft-lockup-fix.patch
  - patches.fixes/cifs-add-cifs_sock_list
  - patches.fixes/cifs-cleanup-cifs_mount
  - patches.fixes/cifs-cleanup-proto-handling
  - patches.fixes/cifs-disable-sess-sharing
  - patches.fixes/cifs-fix-build-breakage
  - patches.fixes/cifs-fix-data-corruption
  - patches.fixes/cifs-fix-dead-tcon-check
  - patches.fixes/cifs-fix-oops-on-failed-mount
  - patches.fixes/cifs-fix-reconnection-flags
  - patches.fixes/cifs-fix-smb-send2
  - patches.fixes/cifs-fix-writepages
  - patches.fixes/cifs-reinstate-sess-sharing-sans-races
  - patches.fixes/cifs-reinstate-treecon-sharing
  - patches.fixes/ext4_add-missing-unlock-to-ext4-check-descriptors
  - patches.fixes/ext4_create-proc-ext4-stats-file-more-carefully
  - patches.fixes/ext4_fix_whitespace_checkpatch_issues
  - patches.fixes/ext4_update-flex-bg-counters-when-resizing
  - patches.fixes/fix-inotify-watch-removal-umount-races
  - patches.fixes/hpwdt-execute-page.diff
  - patches.fixes/hpwdt-kdump.diff
  - patches.fixes/ia64-fix-boot-panic-caused-by-offline-CPUs.patch
  - patches.fixes/x86_cpufreq_powernow-k8_handle_invalid_state_gracefully.patch
* Wed Dec  3 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.19: Fix a kernel warning during shutdown.
- patches.xen/xen3-patch-2.6.27,
  patches.xen/xen-netback-notify-multi,
  patches.xen/xen-virq-per-cpu-irq: Refresh.
* Wed Dec  3 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch: change
  init order to fill in shost_data (bnc#455929).
* Wed Dec  3 2008 hare@suse.de
- patches.suse/scsi-netlink-ml: Use GFP_ATOMIC for
  skb allocation.
* Wed Dec  3 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch:
  add debug for Scsi_Host->shost_data (bnc#455929).
* Wed Dec  3 2008 hare@suse.de
- supported.conf: mark dm-leastpending-path as supported
  (bnc#444199)
* Wed Dec  3 2008 teheo@suse.de
  Patch updated to remove strcmp() on NULL strings.
- patches.drivers/libata-ata_piix-borked-tecra-m4-broken-suspend:
  ata_piix: add borked Tecra M4 to broken suspend list
  (bnc#398270).
* Wed Dec  3 2008 jbeulich@novell.com
- Update Xen patches to c/s 728 (plus several indivual ones)
- patches.xen/735-balloon-exit.patch: remove sysfs files during balloon
  module exit.
- patches.xen/737-kexec-free.patch: kexec: Don't pass
  limit_pages_to_max_mfn() regions to xen_destroy_contiguous_region().
- patches.xen/740-blkback-resource-leak.patch: blkback, blktap: Fix
  potential resource leak.
- patches.xen/746-pirq-status-page.patch: use shared page indicating
  the need for an EOI notification
- patches.xen/747-x86-undo-mfn-limit.patch: revert the effect of
  xen_limit_pages_to_max_mfn()
- patches.xen/748-x86-ioapic-cleanup.patch: cleanup IO-APIC code
- patches.xen/panic-on-io-nmi-xen.diff: Rename to ...
- patches.xen/xen3-panic-on-io-nmi.diff: ... this.
- patches.xen/uv-sysfs-no-xen.diff: Replace by ...
- patches.xen/xen3-uv_setup_irq.diff: ... this.
- patches.xen/xen3-x86_sgi_uv_early_detect_oem.patch: x86, uv:
  add early detection of UV system types (bnc#429984).
- patches.xen/xen-fb-bad-irq: Delete.
* Wed Dec  3 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.9-update: Update Emulex lpfc driver
  to 8.2.8.9 (bnc#420767).
* Wed Dec  3 2008 knikanth@suse.de
- patches.suse/cfq-ioc-race: Exiting queue and task might race
  to free cic (bnc#444346).
* Wed Dec  3 2008 sjayaraman@suse.de
- patches.fixes/cifs-reinstate-sess-sharing-sans-races: Adjust as it
  didn't apply cleanly.
* Wed Dec  3 2008 sjayaraman@suse.de
- Fix data corruption issues (411655).
  patches.fixes/cifs-fix-data-corruption
  patches.fixes/cifs-fix-smb-send2
- Fix multiple oopses, memory corruption due to mount/umount races
  (https://bugzilla.samba.org/show_bug.cgi?id=5720).
  patches.fixes/cifs-add-cifs_sock_list
  patches.fixes/cifs-cleanup-cifs_mount
  patches.fixes/cifs-cleanup-proto-handling
  patches.fixes/cifs-disable-sess-sharing
  patches.fixes/cifs-fix-build-breakage
  patches.fixes/cifs-fix-dead-tcon-check
  patches.fixes/cifs-fix-oops-on-failed-mount
  patches.fixes/cifs-fix-reconnection-flags
  patches.fixes/cifs-fix-writepages
  patches.fixes/cifs-reinstate-sess-sharing-sans-races
  patches.fixes/cifs-reinstate-treecon-sharing
* Tue Dec  2 2008 jeffm@suse.de
- scripts/git-create-branch: Helper script to create a new
  branch.
* Tue Dec  2 2008 mmarek@suse.cz
- rpm/get_release_number.sh.in, scripts/tar-up.sh: append first
  eight digits of the commit id to the release string. This makes
  it easier to match rpm release numbers with commits.
* Tue Dec  2 2008 mszeredi@suse.de
- patches.fixes/af_unix-soft-lockup-fix.patch: net: Fix soft
  lockups/OOM issues w/ unix garbage collector (bnc#449739
  CVE-2008-5300).
* Tue Dec  2 2008 hare@suse.de
- patches.drivers/qla2xxx-8.02.01.02.11.0-k9-update: qla2xxx:
  additional fixes/updates for SLES11 (bnc#450197).
- patches.fixes/scsi-fixup-failfast-definitions: fc_transport:
  fix old bug on bitflag definitions (bnc#447814).
* Tue Dec  2 2008 goldwyn@suse.de
- patches.suse/novfs-map-drives-correctly.diff
- patches.suse/novfs-merge-changes.diff: Modified to revert
  some changes in novfs_set_map_drive()
- patches.suse/novfs-clear-mappeddrives.patch: Unlink mapped
  drives on exit (bnc#449451).
* Tue Dec  2 2008 mmarek@suse.cz
- supported.conf: mark ocfs2 as unsupported, a supported variant
  will be provided in a separate KMP (bnc#449824)
* Tue Dec  2 2008 olh@suse.de
- patches.drivers/ehca-rejecting-dynamic-mem-add-remove.patch:
  update error message (bnc#448301 - LTC50134)
* Tue Dec  2 2008 hare@suse.de
- Update config files for S/390: Disable FCoE and sync
  default and s390.
- supported.conf: Mark KVM as supported.
* Tue Dec  2 2008 jjolly@suse.de
- ...and added the patches to the series.conf (bnc#450096)
* Tue Dec  2 2008 jjolly@suse.de
- patches.arch/s390-05-01-zfcp-message-linebreak.patch: zfcp:
  Wrong placement of linebreak in message (bnc#450096).
- patches.arch/s390-05-02-zfcp-invalid-non-null-return.patch:
  zfcp: invalid return value on failing fsf_req creation
  (bnc#450096).
- patches.arch/s390-05-03-zfcp-wka-port.patch: zfcp: Fix opening
  of wka ports (bnc#450096).
* Mon Dec  1 2008 kkeil@suse.de
- patches.drivers/cxgb3-Add-1G-fiber-support: cxgb3: Add 1G
  fiber support.
- patches.drivers/cxgb3-Allocate-multiqueues-at-init-time: cxgb3:
  Allocate multiqueues at init time.
- patches.drivers/cxgb3-More-flexible-support-for-PHY-interrupts:
  cxgb3: More flexible support for PHY interrupts..
- patches.drivers/cxgb3-Support-for-Aeluros-2005-PHY: cxgb3:
  Support for Aeluros 2005 PHY.
- patches.drivers/cxgb3-allow-for-PHY-reset-status: cxgb3:
  allow for PHY reset status.
- patches.drivers/cxgb3-commnonize-LASI-phy-code: cxgb3:
  commnonize LASI phy code.
- patches.drivers/cxgb3-eeprom-read-fixes.patch:
  cxgb3 - eeprom read fixes.
- patches.drivers/cxgb3-enable-lro-through-ethtool: cxgb3 -
  enable lro control through ethtool.
- patches.drivers/cxgb3-simplify-port-type-struct-and-usage:
  cxgb3: simplify port type struct and usage.
- patches.drivers/cxgb3-update-driver-version: cxgb3: update
  driver version. (bnc#446739)
* Mon Dec  1 2008 mmarek@suse.cz
- rpm/macros.kernel-source: one more fix to the flavor selection
  code (for some reason %%* contained a newline)
* Mon Dec  1 2008 trenn@suse.de
- patches.arch/acpi_x2APIC_madt_enhancements.patch: ACPICA:
  x2APIC support: changes for MADT and SRAT ACPI tables (fate
  303948 and fate 303984).
- patches.fixes/acpi_check_for_invalid_handle.patch: ACPICA:
  Add check for invalid handle in acpi_get_object_info
  (http://www.acpica.org/bugzilla/show_bug.cgi?id=474).
- patches.fixes/acpi_dereference_object_if_possible.patch:
  ACPICA: Add function to dereference returned reference objects
  (http://bugzilla.kernel.org/show_bug.cgi?id=11105).
- patches.fixes/acpi_do_not_load_acpi_cpufreq_acpioff.patch:
  ACPI: don't load acpi_cpufreq if acpi=off (no reference).
* Mon Dec  1 2008 trenn@suse.de
- patches.fixes/acpi_copy_tables_fix_suspend.patch: ACPICA:
  Copy dynamically loaded tables to local buffer (bnc#410726).
* Sat Nov 29 2008 nfbrown@suse.de
- patches.fixes/SUNRPC-Fix-autobind-on-cloned-rpc-clients.patch:
  SUNRPC: Fix autobind on cloned rpc clients.
  Importantly, this removes a 'BUG_ON' that fires. (450083).
* Sat Nov 29 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-borked-tecra-m4-broken-suspend:
  ata_piix: add borked Tecra M4 to broken suspend list
  (bnc#398270).
* Sat Nov 29 2008 bwalle@suse.de
- UV updates from SGI (bnc#442455, #442455).
  o patches.fixes/ia64_uv_partition_id.diff:
    Add partition id, coherence id, and region size to UV
  o patches.fixes/ia64_uv_watchlist.diff:
    Add UV watchlist suppor
  o patches.fixes/null_irq_desc_name.diff:
    genirq: NULL struct irq_desc's member 'name' in
    dynamic_irq_cleanup()
  o patches.fixes/uv-bios_call_memprotect.diff:
    Add UV bios call to change memory protections
  o patches.fixes/uv-bios_call_partition.diff:
    x86: Add UV partition call
  o patches.fixes/uv-bios_call_reserve_page.diff:
    Add UV bios call to get the address of the reserved page
  o patches.fixes/uv-bios_call_watchlist.diff:
    Add UV bios calls to allocate and free watchlists
  o patches.fixes/uv-bios_common.diff:
    x86: Add UV bios call infrastructure
  o patches.fixes/uv-efi_bios.diff:
    x86: Add UV EFI table entry
  o patches.fixes/uv-sn_region_size.diff:
    Use consistent names for region size and conherence id on x86
    and ia64
  o patches.fixes/uv-sysfs.diff:
    x86: Add UV sysfs entries
  o patches.fixes/uv-xp-change_memprotect.diff:
    Define xp_expand_memprotect() and xp_restrict_memprotect()
  o patches.fixes/uv-xpc-get_sn_info.diff:
    Define xp_partition_id and xp_region_size
  o patches.fixes/uv-xpc_create_gru_mq_uv.diff:
    Add the code to create the activate and notify gru message
    queues
  o patches.fixes/uv-xpc_get_part_rsvd_page.diff:
    Add support for getting the address of a partition's reserved
    page
  o patches.fixes/uv_setup_irq.diff:
    x86, UV: add uv_setup_irq() and uv_teardown_irq() functions, v3
- Refresh Xen patches
  o patches.xen/xen3-auto-arch-x86.diff
  o patches.xen/xen3-patch-2.6.19
- patches.xen/xen-x86-no-lapic: Add uv_irq.o
- patches.xen/uv-sysfs-no-xen.diff:
  Don't build UV sysfs support on Xen.
* Fri Nov 28 2008 trenn@suse.de
- patches.fixes/x86_cpufreq_powernow-k8_handle_invalid_state_gracefully.patch:
  powernow-k8: ignore out-of-range PstateStatus value (no
  bug avail).
* Fri Nov 28 2008 sassmann@suse.de
- Update config files.
  activate ALTIVEC in ps3 config
* Fri Nov 28 2008 hare@suse.de
- patches.drivers/open-fcoe-beta4-update: rediff.
- patches.drivers/open-fcoe-beta6-update: Incremental Open-FCoE
  for Beta6 (bnc#438954).
* Fri Nov 28 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sony-vaio-vgn-sr19xn-quirk: ALSA:
  hda - Add quirk for Sony VAIO VGN-SR19XN (bnc#450080).
* Fri Nov 28 2008 olh@suse.de
- rpm/kernel-binary.spec.in: move Module.symvers creation into
  CONFIG_MODULES section, a static kernel exports nothing
* Fri Nov 28 2008 olh@suse.de
- rpm/post*.sh: kernel-vanilla has now vmlinux-vanilla symlink
* Fri Nov 28 2008 teheo@suse.de
  Block layer timer bug fixed.  Multipath patch update is just patch
  refresh.
- patches.drivers/block-internal-dequeue-shouldnt-start-timer:
  block: internal dequeue shouldn't start timer (bnc#449880).
- patches.drivers/blk-request-based-multipath-update: Block layer
  fixes for request-based multipathing (References: FATE#302108).
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: fix no-op macro args
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: fix compile on ppc32
* Thu Nov 27 2008 olh@suse.de
- rpm/kernel-binary.spec.in: always create a dummy initrd because
  mkinitrd is called unconditionally
* Thu Nov 27 2008 olh@suse.de
- rpm/kernel-binary.spec.in: kernel-ps3 needs a suffix
* Thu Nov 27 2008 olh@suse.de
- remove last traces of kernel-um handling
* Thu Nov 27 2008 hare@suse.de
- patches.fixes/qla2xxx-disable-automatic-queue-tracking: qla2xxx:
  Conditionally disable queue_full tracking (bnc#449386).
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: no sysrq on Cell QS21/QS22
  serial console (bnc#422987,bnc#96313 - LTC47675/LTC16841).
* Thu Nov 27 2008 olh@suse.de
- patches.arch/ppc-memoryless-nodes.patch: fix booting with
  memoryless nodes (443280 - LTC49675)
* Thu Nov 27 2008 teheo@suse.de
- patches.drivers/libata-seagate-firmware-bug: libata: blacklist
  Seagate drives which time out FLUSH_CACHE when used with NCQ
  (bnc#449531).
* Wed Nov 26 2008 agruen@suse.de
- rpm/macros.kernel-source: Fix the kernel flavor selection logic
  for the %%kernel_module_package macro.
* Wed Nov 26 2008 hare@suse.de
- patches.fixes/blk-leave-sync-timer-running: move to
  correct place in series.conf and rediff
- patches.drivers/cciss-newids.patch: Delete.
* Wed Nov 26 2008 hare@suse.de
- patches.drivers/cciss-newids.patch: Support for newcciss
  controller (bnc#448416).
- patches.fixes/blk-leave-sync-timer-running: block: leave
  request timeout timer running on an empty list (bnc#447249).
* Tue Nov 25 2008 mszeredi@suse.de
- patches.fixes/slab-alloc_slabmgmt-fix.patch: slab: remove
  GFP_THISNODE clearing from alloc_slabmgmt() (bnc#444597).
* Tue Nov 25 2008 sjayaraman@suse.de
- patches.suse/SoN-11-mm-page_alloc-emerg.patch: Fix accidental side-effect
  that this patch introduced by reverting patches.fixes/oom-warning
  (bnc #444597).
* Tue Nov 25 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-pm-support: ALSA: ca0106 - Add
  power-amangement support (bnc#447624).
- patches.drivers/alsa-hda-dell-92hd73xx-models: ALSA: hda -
  Check model for Dell 92HD73xx laptops (bnc#446025).
- patches.drivers/alsa-hda-dell-studio-1535-quirk: ALSA: hda -
  mark Dell studio 1535 quirk (bnc#446025).
- patches.drivers/alsa-hda-spdif-bits-cache-fix: ALSA: hda -
  Fix caching of SPDIF status bits.
- patches.drivers/alsa-hda-stac-no-hp-as-line-out-switch: ALSA:
  hda - No 'Headphone as Line-out' swich without line-outs
  (bnc#446025).
- patches.drivers/alsa-hda-stac-yet-more-fixes: ALSA: hda -
  Fix AFG power management on IDT 92HD* codecs (bnc#446025).
* Tue Nov 25 2008 jeffm@suse.de
- patches.fixes/fix-inotify-watch-removal-umount-races: Fix
  inotify watch removal/umount races (bnc#446973 CVE-2008-5182).
* Tue Nov 25 2008 jeffm@suse.de
- patches.fixes/uv-redundant-creation-of-proc-dir: UV: redundant
  creation of sgi_uv (bnc#444799).
* Mon Nov 24 2008 agruen@suse.de
- supported.conf: dm-raid45 depends on a few more modules
  (bnc#440208, bnc#441310).
* Mon Nov 24 2008 agruen@suse.de
- Switch from a no_file_caps command line switch to file_caps={0,1}
  for enabling/disabling file capabilities, and make file_caps=0
  the default: we cannot get the no_file_caps option added to the
  kernel command line anymore (perl-Bootloader, bnc#418366).
* Mon Nov 24 2008 agruen@suse.de
- supported.conf: dm-raid4-5 was renamed to dm-raid45 (bnc#440208,
  bnc#441310).
* Mon Nov 24 2008 agruen@suse.de
- Update config files: switch from CONFIG_PREEMPT_VOLUNTARY to
  CONFIG_PREEMPT_NONE.
* Mon Nov 24 2008 ghaskins@suse.de
- patches.fixes/sched-fix-bug-in-sched-domain-degenerate.patch:
  sched: fix a bug in sched domain degenerate (bnc#442464).
* Mon Nov 24 2008 mmarek@suse.cz
- doc/README.SUSE: document that setting allow_unsupported_modules
  to 1 in /etc/modprobe.d/unsupported-modules is required to make
  self-compiled kernels work.
* Mon Nov 24 2008 bwalle@suse.de
- patches.fixes/hpwdt-kdump.diff: Sync with latest upstream
  submission.
* Sun Nov 23 2008 trenn@suse.de
- patches.arch/x86_sgi_uv_early_detect_oem.patch: x86, uv:
  add early detection of UV system types (bnc#429984).
* Sat Nov 22 2008 olh@suse.de
- enable CONFIG_CGROUP_NS on ia64, s390 and powerpc (bnc#447507 - LTC50053)
* Sat Nov 22 2008 rjw@suse.de
- patches.fixes/ia64-fix-boot-panic-caused-by-offline-CPUs.patch:
  fix boot panic caused by offline CPUs (bnc#440386).
* Fri Nov 21 2008 agruen@suse.de
- config/x86_64/maxcpus: Delete.
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: s/CVS/GIT/
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/symsets.pl: fix module names in export lists
  (kernel/irq/built-in was printed as irq/built-in)
* Fri Nov 21 2008 agruen@suse.de
- Update x86_64/{debug,default,trace,vanilla} config files:
  increase NR_CPUS to 512.
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/symsets.pl: Replace the bash and awk scripts around symsets
  and kabi checking with a single script that generates symsets,
  reuses symsets from older kernels and checks for kabi changes for
  each of the split packages (kabi checking and symset reuse
  require a set of reference files, which does not exist yet)
- rpm/list-exported-symbols: Delete.
- rpm/split-into-symsets: Delete.
- scripts/kabi-checks: Delete.
- kabi/severities: table of kabi change severities
- rpm/built-in-where, rpm/find-provides,
  rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/tar-up.sh: update to use symsets.pl
* Fri Nov 21 2008 kkeil@suse.de
- patches.drivers/ixgbe-sfp.patch: include additional fixes from
  Intel (bnc#442411)
* Fri Nov 21 2008 kkeil@suse.de
- patches.fixes/igb_ethtool.patch: add missing ethtool hooks
  (bnc#435551)
* Fri Nov 21 2008 jjolly@suse.de
- patches.arch/s390-04-08-cio-ungroup-race-fix.patch:
  cio: ccwgroup online vs. ungroup race condition
  (bnc#445100,LTC#50092).
- patches.arch/s390-04-09-zfcp-host-busy-count-fix.patch: zfcp:
  prevent double decrement on host_busy counter (bnc#445100).
* Fri Nov 21 2008 agruen@suse.de
- rpm/macros.kernel-source:
  + Rename the -s option to -t in the %%kernel_module_package macro
    for improved cross-distro compatibility.
  + Define %%kernel_module_package_release as 1 for feature tests.
  + Define %%kernel_module_package_buildreqs for use by KMPs: that
    way, KMPs can either use this macro for compatibility, or
    they can substitute other packages for special cases.
* Fri Nov 21 2008 hare@suse.de
- patches.drivers/cxgb3i: add cxgb3i iscsi driver
  (FATE#304154,bnc#433500).
- patches.drivers/cxgb3i-fixed-offload-array-size: cxgb3i -
  fixed offload wr array size (bnc#447409).
- patches.fixes/dm-table-switch-to-readonly: dm multipath devices
  are not getting created for readonly devices (bnc#382705).
- patches.suse/dm-mpath-null-pgs: Allow zero paths for multipath
  priority groups (bnc#372684).
- patches.suse/scsi-netlink-ml: Netlink interface for SCSI
  sense codes (FATE#303789).
* Fri Nov 21 2008 goldwyn@suse.de
- patches.suse/novfs-map-drives-correctly.diff: Fix oops in
  set_map_drive (bnc#446824, bnc#444469).
* Fri Nov 21 2008 jbeulich@novell.com
- patches.xen/xen3-x86-vmware-tsc-03-detect-from-hypervisor:
  Fix Xen pv driver build.
* Fri Nov 21 2008 olh@suse.de
- patches.arch/ppc-spufs-01-use-inc_nlink.patch: use inc_nlink
- patches.arch/ppc-spufs-02-add-a-missing-mutex_unlock.patch
- patches.arch/ppc-spufs-03-sputrace-Only-enable-logging-on-open.patch
- patches.arch/ppc-spufs-04-sputrace-Don-t-block-until-the-read.patch
- patches.arch/ppc-spufs-05-Use-state_mutex-for-switch_log-lockin.patch
- patches.arch/ppc-spufs-06-Don-t-require-full-buffer-in-switch_l.patch
- patches.arch/ppc-spufs-07-Don-t-spu_acquire_saved-unnecessarily.patch
- patches.arch/ppc-spufs-08-Use-kmalloc-rather-than-kzalloc-for-s.patch
- patches.arch/ppc-spufs-09-Improve-search-of-node-for-contexts-w.patch
- patches.arch/ppc-spufs-10-Explain-conditional-decrement-of-aff_.patch
- patches.arch/ppc-spufs-11-Fix-spinning-in-spufs_ps_fault-on-sig.patch
  update spufs to current mainline state (bnc#447133 - LTC50070)
* Fri Nov 21 2008 tiwai@suse.de
- patches.drivers/parport-serial-array-overflow-fix: Fix array
  overflow in parport_serial.c (bnc#447067).
* Fri Nov 21 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dell-studio-15-quirk: ALSA: hda -
  Add a quirk for Dell Studio 15 (bnc#446025).
- patches.drivers/alsa-hda-stac-dell-m4-3-quirk: ALSA: hda:
  Add STAC_DELL_M4_3 quirk (bnc#446025).
* Fri Nov 21 2008 npiggin@suse.de
- patches.suse/silent-stack-overflow-2.patch: avoid silent stack
  overflow over the heap. Try again.
* Fri Nov 21 2008 gregkh@suse.de
- Refresh patches to apply cleanly after 2.6.27.7 update.
* Fri Nov 21 2008 gregkh@suse.de
- Update to 2.6.27.7
  - lots of bugfixes and security updates.
  - obsoletes:
  - patches.arch/s390-04-05-topology-lock.diff
  - patches.drivers/bnx2x-zero-PMF
  - patches.drivers/input-alps-add-signature-for-dualpoint-found-in-dell-latitude-e6500.patch
  - patches.fixes/cdc-acm.c-fix-recursive-lock-in-acm_start_wb-error-path.patch
  - patches.fixes/sony_laptop_fix_suspend.patch
  - patches.kernel.org/iwlagn-avoid-sleep-in-softirq-context.patch
  - patches.kernel.org/memory-hotplug-fix-page_zone-calculation-in-test_pages_isolated.patch
  - patches.kernel.org/touch_mnt_namespace-when-the-mount-flags-change.patch:
* Fri Nov 21 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-clear-spurious-IRQ: ata_piix:
  detect and clear spurious IRQs (bnc#445872).
* Fri Nov 21 2008 npiggin@suse.de
- patches.fixes/mm-madvise-fix.patch: mm: madvise correct return
  code (bnc#352998).
* Thu Nov 20 2008 jack@suse.cz
- patches.suse/ocfs2-Change-quotafile-names.patch: ocfs2: Change
  file names of local quota files to be consistent (fate#302681).
- patches.suse/ocfs2-Fix-hang-in-quota-recovery-code.patch:
  ocfs2: Fix hang in quota recovery code (fate#302681).
- patches.suse/ocfs2-Fix-oops-when-one-quotatype-enabled: ocfs2:
  Fix oops when only usrquota or grpquota feature is enabled
  (fate#302681).
* Thu Nov 20 2008 garloff@suse.de
- patches.suse/panic-on-io-nmi.diff
  patches.xen/panic-on-io-nmi-xen.diff:
  New kernel sysctl panic-on-io-nmi, which is set will cause a
  kernel panic on receiving an IOCK NMI (bnc#427979).
* Thu Nov 20 2008 jjolly@suse.de
- patches.arch/s390-04-06-cio-sac-update.diff: cio: update sac
  values (bnc#445100).
- patches.arch/s390-04-07-als.patch: kernel: Add processor type
  march=z10 and a processor type safety check. (bnc#445100).
* Thu Nov 20 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-hp-gpio-switch-fix: ALSA: hda:
  STAC_DELL_M6 EAPD (bnc#446025).
* Thu Nov 20 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27.6 and c/s 724.
- Update Xen config files.
- patches.xen/xen-fb-bad-irq: xenfb: don't use irq before it
  gets set up (bnc#445659).
- patches.xen/xen-netback-notify-multi: netback: use multicall
  for send multiple notifications.
- patches.xen/xen-netback-nr-irqs: netback: reduce overhead of
  IRQ recording.
* Thu Nov 20 2008 kkeil@suse.de
- patches.drivers/igb-pf.patch: removed (no SR-IOV) (bnc#440614)
* Thu Nov 20 2008 olh@suse.de
- disable patches.arch/ppc-efika-bestcomm-ata-dma.patch
  crashes the sound driver
* Thu Nov 20 2008 jjolly@suse.de
- rpm/kernel-binary.spec.in: excluded vanilla build from creating
  the man package
* Thu Nov 20 2008 hare@suse.de
- patches.drivers/ibmvfc-async-events-oops: ibmvfc oops while
  processing async events (bnc#445541).
- patches.drivers/mpt-fusion-4.16.00.00-update: MPT fusion driver
  update to 4.16.00.00 (bnc#425660).
- patches.fixes/dm-mpath-NULL-pgpath-in-activate_path: Do not
  call activate_path() if pgpath is NULL (bnc#442676).
- patches.fixes/scsi-dh-rdac-initialize-passive-path: Initialize
  path state to be passive when path is not owned (bnc#442676).
- patches.suse/dm-mpath-leastpending-path: Dynamic load balancing
  policy for device mapper multipath (bnc#444199).
* Thu Nov 20 2008 olh@suse.de
- patches.fixes/bug-437171_1_sched_clock_lock.patch: sched: only
  update rq->clock while holding rq->lock (437171 - LTC47404).
- patches.fixes/bug-437171_2_sched_delta_weight.patch: sched:
  revert back to per-rq vruntime (437171 - LTC47404).
- patches.fixes/bug-437171_3_rework_wakeup_preemption.patch:
  sched: rework wakeup preemption (437171 - LTC47404).
- patches.fixes/bug-437171_4_sched_reinstate_vruntime_wakeup.patch:
  sched: re-instate vruntime based wakeup preemption (437171 -
  LTC47404).
* Thu Nov 20 2008 trenn@suse.de
- Update config files.
  Fixed debug build, added dependent config option.
* Thu Nov 20 2008 trenn@suse.de
- Update config files.
  - > unified i386/x86_64 debug kernels:
  - added CONFIG_NO_HZ=y to i386-debug
  - added CONFIG_DEBUG_INFO to x86_64-debug
  Differ method to receive processor_id depending whether the processor
  got declared as a regular ACPI device or as a processor object:
- patches.arch/acpi_behave_uniquely_based_on_processor_declaration.patch:
  ACPI: Behave uniquely based on processor declaration definition
  type (bnc#440062).
- patches.arch/acpi_disambiguate_processor_declaration_type.patch:
  ACPI: Disambiguate processor declaration type (bnc#440062).
- patches.arch/acpi_processor_cleanups.patch: ACPI: 80 column
  adherence and spelling fix (no functional change) (bnc#440062).
- patches.xen/xen3-auto-common.diff: xen3 common.
  Fix missing bit for ThinkPad brightness switching:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Do not use video backlight switching for Lenovo ThinkPads.
- patches.fixes/sony_laptop_fix_suspend.patch: sony-laptop:
  Ignore missing _DIS method on pic device (bnc#446487).
* Thu Nov 20 2008 hare@suse.de
- patches.fixes/dm-mpath-reattach-dh: Do not detach hardware
  handler when removing multipath maps (bnc#435688).
- patches.fixes/scsi-dh-alua-send-stpg: Always send STPG for
  explicit tgps mode.
* Thu Nov 20 2008 jjolly@suse.de
- rpm/kernel-binary.spec.in: Added kernel man package for s390x
* Thu Nov 20 2008 olh@suse.de
- patches.arch/ppc-of-irq-map.patch: fix IRQ assignment if
  interrupts property is missing (bnc#446610 - LTC50006)
* Thu Nov 20 2008 rjw@suse.de
- patches.fixes/acpi-set-SCI_EN-on-MacBook.patch: ACPI suspend:
  Blacklist boxes that require us to set SCI_EN directly on resume
  (bnc#444786).
* Wed Nov 19 2008 tiwai@suse.de
- patches.arch/x86-hpet-pre-read: x86: workaround for mccreary
  HPET read problem (bnc#433746).
* Wed Nov 19 2008 trenn@suse.de
- patches.arch/0008-sony-laptop-fingers-off-backlight.patch:
  sony-laptop: fingers off backlight if video.ko is serving
  this functionality.
  - > Fix typo, must not invert logic at this point
* Wed Nov 19 2008 kkeil@suse.de
- patches.drivers/e1000e_add_ECC: e1000e: enable ECC (bnc#445829)
* Wed Nov 19 2008 mmarek@suse.cz
- scripts/tar-up.sh: record the git branch name in the spec files
  (no branch name means master)
* Wed Nov 19 2008 jkosina@suse.de
- patches.drivers/elousb.patch: fix values of maximum X and Y
  coordinates so that they are compliant with the values that
  the device contains in its descriptor (bnc#442865)
* Wed Nov 19 2008 goldwyn@suse.de
- patches.suse/novfs-merge-changes.diff: Merge changes left out
  during code pull (bnc#445000).
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-bsr-multinode.patch: Add support for
  multiple BSR nodes in the device tree. (bnc#443665 - LTC49817)
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-cmm-pagecounter.patch:
  Update page in counter for CMM (bnc#445540 - LTC49942)
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-bsr-4k.patch: Unable to Use Small
  BSR register on Power LPAR (bnc#443673 - LTC49749)
* Wed Nov 19 2008 jjolly@suse.de
- config/s390/s390: Update config files: added CONFIG_UTRACE=y and
  CONFIG_HAVE_ARCH_TRACEHOOK=y
* Wed Nov 19 2008 jjolly@suse.de
- patches.drivers/ehca-fix-possible-nullpointer-access-v2.patch:
  ehca: fix a possible nullpointer access (bnc#441966).
* Wed Nov 19 2008 jjolly@suse.de
- patches.arch/ppc-axon-missing-msi-workaround-5.diff:
  powerpc/cell/axon-msi: retry on missing interrupt (bnc#445964).
* Wed Nov 19 2008 jjolly@suse.de
- patches.drivers/0001-IB-ehca-Fix-problem-with-max-number-of-QPs-and-CQs.patch:
  Fix problem with max number of QPs and CQs (bnc#441619).
* Tue Nov 18 2008 bwalle@suse.de
- Disable CONFIG_STRICT_DEVMEM for i386 and x86_64 (bnc#443852).
* Tue Nov 18 2008 jjolly@suse.de
- Update config files.
- patches.trace/s390-syscall-get-nr.diff: fix syscall_get_nr..
- patches.trace/s390-utrace-enablement.patch: Backport s390
  kernel components required for utrace enablement.
* Tue Nov 18 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: on s390(x) call dwarfextract to create the
  Kerntypes file for use with old lcrash debuggers.
* Tue Nov 18 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-92hd71bxx-gpio-fix: ALSA:
  hda - Fix GPIO initialization in patch_stac92hd71bxx()
  (bnc#445321,bnc#445161).
- patches.drivers/alsa-hda-stac-gpio-unsol-resume-fix:
  ALSA: hda - Fix resume of GPIO unsol event for STAC/IDT
  (bnc#445321,bnc#445161).
- patches.drivers/alsa-hda-stac-hp-pavilion-quirks: ALSA: hda -
  Add quirks for HP Pavilion DV models (bnc#445321,bnc#445161).
* Tue Nov 18 2008 tiwai@suse.de
- patches.arch/x86-hpet-use-WARN_ON_ONCE: x86: HPET: convert
  WARN_ON to WARN_ON_ONCE (bnc#433746).
* Tue Nov 18 2008 sdietrich@suse.de
  RT development has moved to slert-devel branch.
- Remove RT patches from master branch.
  (itemized RT patch list suppressed)
* Tue Nov 18 2008 olh@suse.de
- patches.arch/ppc-efika-bestcomm-ata-dma.patch: use ATA DMA (bnc#445856)
* Tue Nov 18 2008 olh@suse.de
- config/ppc/ppc64: reenable 64k PAGE_SIZE to keep the config
  flavor on ppc and ppc64 in sync
  the last change had also no bug number to fix the possible bug
  in the Xserver.
* Tue Nov 18 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-acer-dmic: ALSA: hda - Split
  ALC268 acer model (bnc#420048).
* Tue Nov 18 2008 jjolly@suse.de
- patches.arch/s390-04-01-qdio_prevent_double_shutdown.patch:
  qdio: prevent double qdio shutdown in case of I/O
  errors. (bnc#445100).
- patches.arch/s390-04-02-qdio-osa-port-count.patch: qdio:
  fix qeth port count detection. (bnc#445100).
- patches.arch/s390-04-03-kmsg.patch: kmsg: do not change pr_xyz
  messages without KMSG_COMPONENT (bnc#445100).
- patches.arch/s390-04-04-dasd_fatal_error_log_sense.patch:
  dasd: log sense for fatal errors. (bnc#445100).
- patches.arch/s390-04-05-topology-lock.diff: kernel: Fix locking
  in cpu topology code. (bnc#445100).
* Tue Nov 18 2008 jjolly@suse.de
- patches.arch/s390-personality-mask.patch: fix s390x_newuname.
* Tue Nov 18 2008 gregkh@suse.de
- patches.drivers/staging-rt2860-enable-wpa_supplicant-support.patch:
  Staging: rt2860: enable WPA_SUPPLICANT support (bnc#437959).
* Mon Nov 17 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.7-update: Update lpfc to 8.2.8.7
  (bnc#420767).
- patches.drivers/qla4xxx-5.01.00-k8_sles11-03-update: Update
  qla4xxx to 5.01.00-k8_sles11-03     (bnc#444884).
- patches.fixes/dm-mpath-reattach-dh: Reattach device handler
  for multipath devices (bnc#435688).
- patches.fixes/scsi-add-tgps-setting: Add TGPS setting to
  scsi devices.
- patches.fixes/scsi-dh-alua-retry-UA: Retry ALUA device handler
  initialization on Unit Attention.
* Mon Nov 17 2008 jeffm@suse.de
- patches.fixes/v4l-dvb-avoid-writing-outside-array: V4L/DVB
  (9621): Avoid writing outside shadow.bytes array (bnc#445569).
* Mon Nov 17 2008 fseidel@suse.de
- patches.fixes/ipw2200-send-noassoc.patch: ipw2200: fix oops
  in ipw_tx_skb (bnc#397390).
* Sat Nov 15 2008 rjw@suse.com
- patches.fixes/hibernate-x86-fix-breakage-on-x86_32-with-PAE.patch:
  x86: Hibernate: Fix breakage on x86_32 with CONFIG_NUMA set
  (bnc#439126).
* Sat Nov 15 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sigmatel-hp-m4-check-fix: ALSA:
  hda - Check model type instead of SSID in patch_92hd71bxx()
  (bnc#444349).
- patches.drivers/alsa-hda-sigmatel-vref-event-fix: ALSA: hda:
  STAC_VREF_EVENT value change (bnc#444349).
* Sat Nov 15 2008 gregkh@suse.de
- patches.kernel.org/memory-hotplug-fix-page_zone-calculation-in-test_pages_isolated.patch:
  memory hotplug: fix page_zone() calculation in
  test_pages_isolated() (bnc#445163).
* Fri Nov 14 2008 gregkh@suse.de
- patches.drivers/input-alps-add-signature-for-dualpoint-found-in-dell-latitude-e6500.patch:
  Input: ALPS - add signature for DualPoint found in Dell Latitude
  E6500 (bnc#436719).
* Fri Nov 14 2008 hare@suse.de
- patches.fixes/scsi-eh-timed-out-missing-braces: scsi_error:
  fix indentation and braces disagreement - add braces.
- patches.fixes/scsi-retry-TASK_ABORTED: scsi_error: TASK ABORTED
  status handling improvement.
- patches.fixes/scsi-retry-transport-error: scsi_error regression:
  Fix idempotent command handling.
* Fri Nov 14 2008 hare@suse.de
- patches.fixes/scsi-eh-timed-out-missing-braces: scsi_error:
  fix indentation and braces disagreement - add braces.
- patches.fixes/scsi-retry-TASK_ABORTED: scsi_error: TASK ABORTED
  status handling improvement.
- patches.fixes/scsi-retry-transport-error: scsi_error regression:
  Fix idempotent command handling.
* Fri Nov 14 2008 bwalle@suse.de
- patches.fixes/hpwdt-execute-page.diff:
  [WATCHDOG] [hpwdt] Set the mapped BIOS address space as
  executable (bnc#430680).
* Fri Nov 14 2008 tiwai@suse.de
- patches.arch/x86-vmware-tsc-01-add-TSC_RELIABLE,
  patches.arch/x86-vmware-tsc-02-add-X86_FEATURE_HYPERVISOR,
  patches.arch/x86-vmware-tsc-03-detect-from-hypervisor,
  patches.arch/x86-vmware-tsc-04-use-TSC_RELIABLE,
  patches.arch/x86-vmware-tsc-05-skip-tsc-clocksource,
  patches.arch/x86-vmware-tsc-06-fix-vmware_get_tsc,
  patches.arch/x86-vmware-tsc-07-DMI-product-serial-key,
  patches.xen/xen-x86-vmware-tsc-fix:
    VMware tsc clocksource workaround (bnc#441338).
* Fri Nov 14 2008 tiwai@suse.de
- Fixed a typo in definition of X86_FEATURE_XTOPOLOGY (bnc#443293)
  in patches.arch/x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4
* Fri Nov 14 2008 agruen@suse.de
- Update CONFIG_X86_RESERVE_LOW_64K in config/x86_64/maxcpus as
  well.
- patches.suse/bug-425240_nr_cpus-mem_cgroup_stat-fix.diff:
  rename to patches.suse/mem_cgroup_stat-dynamic-alloc, and update
  to newer version.
* Fri Nov 14 2008 bwalle@suse.de
- patches.fixes/kdump-x86-sparsemem.diff: x86, kdump: fix invalid
  access on i386 sparsemem (bnc#440525).
- patches.xen/linux-2.6.19-rc1-kexec-move_segment_code-i386.patch:
  Refresh.
* Thu Nov 13 2008 gregkh@suse.de
- patches.kernel.org/iwlagn-avoid-sleep-in-softirq-context.patch:
  iwlagn: avoid sleep in softirq context (bnc#444382).
* Thu Nov 13 2008 philips@suse.de
- patches.fixes/cdc-acm.c-fix-recursive-lock-in-acm_start_wb-error-path.patch:
  cdc-acm.c: fix recursive lock in acm_start_wb error path.
* Thu Nov 13 2008 gregkh@suse.de
- enable CONFIG_X86_RESERVE_LOW_64K for i386 and x86-64 vanilla
  configs.
* Thu Nov 13 2008 gregkh@suse.de
- enable CONFIG_X86_RESERVE_LOW_64K on i386 and x86-64 to fix some
  suspend/resume issues (option added in 2.6.27.6)
* Thu Nov 13 2008 gregkh@suse.de
- refresh patches so that everything applies cleanly.
* Thu Nov 13 2008 gregkh@suse.de
- Update to 2.6.27.6:
  - fixes some security issues
  - lots of bugfixes
  - obsoletes:
  - patches.arch/acpi-dock-avoid-check-_STA-method.patch:
  - patches.arch/ppc-gigantic-page-fix2.patch:
  - patches.arch/ppc-gigantic-page-fix3.patch:
  - patches.drivers/alsa-hda-dell-eq-option:
  - patches.drivers/cciss-fix-procfs-firmware-regression.patch:
  - patches.drivers/cciss-fix-sysfs-symlink.patch:
  - patches.drivers/libata-fix-last_reset-timestamp-handling:
  - patches.kernel.org/md-raid10-recovoery-fix.path:
* Thu Nov 13 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: package modules.order (bnc#441384)
* Thu Nov 13 2008 agruen@suse.de
- config.conf: Add x86_64/maxcpus as the 4096-cpu configuration
  and switch back to at most 128 cpus in the other configs. This
  avoids wasting memory on all but the most extreme x86_64
  systems.
- rpm/kernel-binary.spec.in: define a kernel-$flavor symbol to
  allow per-flavor patches. (Use this for testing only!)
- patches.suse/bug-425240_nr_cpus-mem_cgroup_stat-fix.diff: Add
  this patch conditionally for x86_64/maxcpus for now pending
  test results from bnc#425240.
* Thu Nov 13 2008 tiwai@suse.de
- patches.drivers/alsa-hda-beep-dig-switch: ALSA: hda - Add
  digital beep playback switch for STAC/IDT codecs (#444572).
- patches.drivers/alsa-hda-beep-null-check-fix: ALSA: hda -
  Missing NULL check in hda_beep.c.
* Thu Nov 13 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: fix to
  make it work with iSCSI (bnc#444234)
* Thu Nov 13 2008 olh@suse.de
- mark some powerpc device drivers as supported to move them out of
  kernel-extra, otherwise installation-images will not pick them up
- ps3vram, mtd, mtdblock, mtd_blkdevs (bnc#444220)
- PowerMac, Efika and Pegasos2 storage and network drivers
* Wed Nov 12 2008 bwalle@suse.de
- patches.fixes/firmware-memmap-64bit.diff: Always use 64 bit
  addresses for the firmware memory map.
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-powermac-ibook-g4-mic-fix: ALSA: powermac -
  Rename mic-analog loopback mixer element (bnc#444194).
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-hp-detect-fix: ALSA: hda -
  Fix IDT/STAC multiple HP detection (bnc#443267).
* Wed Nov 12 2008 agruen@suse.de
- patches.suse/module-ref-dynamic-alloc: fall back to vmalloc if
  kmalloc fails (bnc#425240).
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac9200-missing-mux-capture: ALSA:
  hda - Add missing analog-mux mixer creation for STAC9200
  (bnc#443738).
- patches.drivers/alsa-hda-stac92xx-mic-pin-fix: ALSA: hda -
  Fix input pin initialization for STAC/IDT codecs (bnc#443738).
* Tue Nov 11 2008 philips@suse.de
- rpm/kernel-binary.spec.in: remove Recommends: kerneloops, opt-in will
  be implemented in the 11.2 installer
* Tue Nov 11 2008 jeffm@suse.de
- patches.fixes/reiserfs-error-buffer-locking: reiserfs: add
  locking around error buffer.
- patches.fixes/reiserfs-varargs-fix: reiserfs: prepare_error_buf
  wrongly consumes va_arg.
* Tue Nov 11 2008 tiwai@suse.de
- patches.suse/module-ref-dynamic-alloc: Allocate module.ref
  array dynamically (bnc#425240).
- Update config files: back to NR_CPUS=4096
* Tue Nov 11 2008 jblunck@suse.de
- Update config files: Set NR_CPUS on x86_64 back to 128 again for
  now: with NR_CPUS=4096, the size of eack .ko file increases by
  496 KiB because of the static struct module in
  .gnu.linkonce.this_module.
* Tue Nov 11 2008 schwab@suse.de
- patches.arch/ppc-select: Fix wrong error code from ppc32 select.
* Tue Nov 11 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: also encode the architecture into the
  packageand supplements.
* Tue Nov 11 2008 teheo@suse.de
- patches.drivers/libata-fix-ata_tf_read_block-overflow: libata:
  Avoid overflow in ata_tf_read_block() when tf->hba_lbal > 127
  (bnc#443661).
- patches.drivers/libata-fix-ata_tf_to_lba48-overflow: libata:
  Avoid overflow in ata_tf_to_lba48() when tf->hba_lbal > 127
  (bnc#443661).
* Tue Nov 11 2008 teheo@suse.de
- patches.drivers/libata-pata_sch-slave-poss: pata_sch: slave
  devices (bnc#443657).
* Mon Nov 10 2008 schwab@suse.de
- config/ppc/ppc64: Disable 64k pages to work around X server bug.
* Mon Nov 10 2008 olh@suse.de
- rpm/kernel-binary.spec.in: fix variable assignment in last change
* Mon Nov 10 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: encode the architecture into
  subpackage dependencies (bnc#440961)
* Mon Nov 10 2008 olh@suse.de
- handle arch differences for cpu and kbuild correctly
* Mon Nov 10 2008 schwab@suse.de
- patches.arch/ia64-page-migration. patches.arch/mm-avoid-bad-page-on-lru:
  migrade pages off of pages with correctable errors.
* Mon Nov 10 2008 mmarek@suse.cz
- scripts/tar-up.sh: do not generate kernel-source-rt.spec and
  kernel-syms-rt.spec if RT is not enabled.
* Mon Nov 10 2008 sdietrich@suse.de
- config.conf: Suppress RT configurations.
* Sun Nov  9 2008 jeffm@suse.de
- config.conf: Removed previous workaround.
- rpm/kernel-binary.spec.in: Remove @FLAVOR@ from %%symbols.
* Sat Nov  8 2008 jeffm@suse.de
- config.conf: Workaround for kernel-ppc64 on head-ppc.
* Sat Nov  8 2008 gregkh@suse.de
- Update to the "real" 2.6.27.5.  No code changes from what we had
  in our tree previously, with the exception for the version number
  change.
* Fri Nov  7 2008 bwalle@suse.de
- patches.fixes/kdb-read-CR.diff:
  Support '\n' in KDB (bnc#442808).
* Fri Nov  7 2008 gregkh@suse.de
- disable perfmon support in the -trace kernels as it doesn't build
  properly.
* Fri Nov  7 2008 schwab@suse.de
- patches.arch/compat-sys-swapcontext: Fix msr check in sys_swapcontext.
* Fri Nov  7 2008 hare@suse.de
- patches.drivers/ixgbe-add-bcna-support: DCB: Add BCNA support
  to ixgbe.
- patches.drivers/open-fcoe-beta3-update: Open-FCoE update for
  Beta3 (bnc#438954).
- patches.drivers/open-fcoe-beta4-update: Open-FCoE: Update for
  Beta4 (bnc#438954).
- patches.drivers/open-fcoe-beta5-update: Open-FCoE: Update for
  Beta5 (bnc#438954).
- patches.fixes/dcb-fix-setpfcstate: Fix setpfcstate (bnc#438954).
- patches.fixes/dcb-setting-pg-will-cause-tx-hang: DCB: setting
  pg will cause tx unit hangs (bnc#438954).
- patches.fixes/multiq-requeue-should-rewind-current_band:
  multiq: requeue should rewind the current_band (bnc#438954).
- patches.fixes/scsi-dh-rdac-retry-mode-select: Retry mode select
  in RDAC device handler (bnc#441337).
- patches.fixes/scsi-dh-rdac-set-default-ownership: scsi_dh_rdac:
  make sure the ownership is set correctly (bnc#441337).
- patches.fixes/scsi-skip-nonscsi-device-for-dma: Update patch
  to check for ->bus instead of ->type (bnc#431294).
* Fri Nov  7 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dell-studio-probe-fix: ALSA: hda -
  Fix probe errors on Dell Studio Desktop (bnc#440907).
- patches.drivers/alsa-hda-hp-3013-master-fix: ALSA: hda -
  Fix ALC260 hp3013 master switch (bnc#441068).
* Fri Nov  7 2008 jjolly@suse.de
- patches.arch/s390-03-07-qeth_hsi_mcl_string.patch:
  qeth: pre z9 systems return HiperSocket version string
  different. (bnc#440610,LTC#49052).
- patches.arch/s390-03-08-zfcp-abort-race.patch: zfcp: eliminate
  race between validation and locking. (bnc#440610).
- patches.arch/s390-03-09-zfcp-oops-during-target-scan.patch:
  zfcp: prevent SCSI target scan for vanished rport
  (bnc#440610,LTC#49373).
* Fri Nov  7 2008 olh@suse.de
- Update config files for RT
* Fri Nov  7 2008 olh@suse.de
- build a kernel-default in dist ppc64, its identical to kernel-ppc64
  otherwise unused
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-source.spec.in: map ppc/ppc64 to powerpc
* Fri Nov  7 2008 kkeil@suse.de
- patches.drivers/igb-pf.patch: VF enabled igb driver (fate#305004)
* Fri Nov  7 2008 olh@suse.de
- stop building kernel-default and kernel-ps3 in dist ppc64,
  they are openSuSE only packages
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-binary.spec.in: extracting debuginfo from vdso fails
  on powerpc, disable vdso_install for the time being
* Fri Nov  7 2008 jbeulich@novell.com
- patches.xen/xen3-intel-ibex-peak-device-ids.patch: x86/PCI: irq
  and pci_ids patch for Intel Ibex Peak DeviceIDs (bnc#415383).
* Fri Nov  7 2008 olh@suse.de
- rpm/post.sh: reject legacy iSeries again
* Fri Nov  7 2008 olh@suse.de
- build a 32bit and a 64bit vanilla kernel on powerpc
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-binary.spec.in: no vdso in vanilla and ps3 kernel
* Fri Nov  7 2008 gregkh@suse.de
- patches.kernel.org/net-fix-recursive-descent-in-__scm_destroy.patch:
  net: Fix recursive descent in __scm_destroy()..
* Fri Nov  7 2008 olh@suse.de
- remove patches.arch/ppc64-rpanote-relocate-firmware.patch
  older firmware versions can handle relocation properly (bnc#427960)
* Fri Nov  7 2008 jjolly@suse.de
- patches.drivers/cxgb3-get_drvinfo-deadlock.patch: RDMA/cxgb3:
  deadlock in iw_cxgb3 can cause hang when configuring
  interface. (bnc#430998).
* Fri Nov  7 2008 gregkh@suse.de
- patches.suse/perfmon2.patch: perfmon2 (bnc#430298).
* Fri Nov  7 2008 nfbrown@suse.de
- patches.fixes/nfs-write.c-bug-removal.patch: Revert "NFS:
  Allow redirtying of a completed unstable write." (442267).
  It causes a BUG().
* Fri Nov  7 2008 nfbrown@suse.de
- patches.kernel.org/md-raid10-recovoery-fix.path: md: fix bug
  in raid10 recovery..
- patches.suse/md-notify-when-stopped: md: notify udev when an
  md array is stopped..:  Removed much of this patch as it turned out
  to be both buggy and unnecessary (the ioctl can be done from
  mdadm).
* Thu Nov  6 2008 kkeil@suse.de
- patches.drivers/ixgbe-sfp.patch: ixgbe driver update to add
  Longcove (SFP+) NIC support for FCoE needs (bnc#442411)
* Thu Nov  6 2008 gregkh@suse.de
- enable CONFIG_X86_SUMMIT, CONFIG_X86_ES7000, and CONFIG_X86_BIGSMP
  for the i386 default kernel, so that the installer can actually
  boot on "modern" multiprocessor i386 boxes (bnc#428247)
* Thu Nov  6 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Call make vdso_install only on x86 and ppc.
* Thu Nov  6 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Call make vdso_install to install the
  vdso shared objects for debugging.
* Thu Nov  6 2008 jjolly@suse.de
- patches.drivers/intel-ibex-peak-device-ids.patch: x86/PCI: irq
  and pci_ids patch for Intel Ibex Peak DeviceIDs (bnc#415383).
- patches.drivers/intel-ibex-peak-device-support.patch: i2c-i801:
  Add support for Intel Ibex Peak (bnc#415383).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-03-01-stp-init.patch: Fixed patch for build
- patches.arch/s390-03-04-qdio_multicast_performance.patch: dasd:
  fix  message flood for unsolicited interrupts (bnc#440610).
- patches.arch/s390-03-05-dasd-block-uevent.patch: dasd: DASD
  uevents are not sent correctly (bnc#440610,LTC#49429).
- patches.arch/s390-03-06-zfcp-hexdump.patch: zfcp: fix hexdump
  data in s390dbf traces (bnc#440610).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-03-01-stp-init.patch: kernel: Fix
  initialization of stp. (bnc#440610,LTC#49639).
- patches.arch/s390-03-02-setup_memory.patch: kernel: Fix range
  for add_active_range() in setup_memory() (bnc#440610,LTC#49639).
- patches.arch/s390-03-03-dasd_unsolicited_interrupt.patch:
  dasd: fix  message flood for unsolicited interrupts
  (bnc#440610,LTC#49639).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-02-10-zfcp-scan-online.patch: wait for port
  scan when setting FCP device online (bnc#434333).
* Thu Nov  6 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27.4 and c/s 718.
- Update Xen config files.
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch: Include
  pv-ops-Xen changes here
- patches.xen/x86_sgi_xen-x86-cpus4096.patch: Delete.
- patches.xen/xen-configurable-guest-devices: allow number of
  guest devices to be configurable.
- patches.xen/xen-cpufreq-report: make /proc/cpuinfo track
  CPU speed.
- patches.xen/xen-ipi-per-cpu-irq: fold IPIs onto a single
  IRQ each.
- patches.xen/xen-rtl2860-build: Rename to ...
- patches.xen/xen-rt2860-build: ... this.
- patches.xen/xen-sysdev-suspend: use base kernel suspend/resume
  infrastructure.
- patches.xen/xen-virq-per-cpu-irq: fold per-CPU VIRQs onto a
  single IRQ each.
- patches.xen/xen-x86-mmu-batching: Delete.
- patches.xen/xen3-patch-2.6.27.3-4: Linux 2.6.27.4.
- patches.xen/xen3-x2APIC_PATCH_20_of_41_cff73a6ffaed726780b001937d2a42efde553922:
  x64, x2apic/intr-remap: introcude self IPI to genapic routines
  (fate #303948 and fate #303984).
- patches.xen/xen3-x86_sgi_cpus4096-02-fix-send_call_func_ip.patch:
  x86: reduce stack requirements for send_call_func_ipi
  (bnc#425240 FATE304266).
- patches.xen/xen3-x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
* Thu Nov  6 2008 sassmann@suse.de
- patches.arch/ppc-ps3-introduce-ps3_gpu_mutex.patch: required for
  new ps3vram patch
- patches.arch/ppc-ps3-ps3vram-mtd.patch: updated ps3vram patch
  that works with firmware 2.50 (bnc#442227)
* Thu Nov  6 2008 olh@suse.de
- remove unneeded BuildRequires for dtc
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v3.patch: Feature removed
  (bnc#417299)
* Thu Nov  6 2008 gregkh@suse.de
- patches.suse/file-capabilities-add-no_file_caps-switch.patch:
  file capabilities: add no_file_caps switch (v4).
  add the patch back into the tree.
* Wed Nov  5 2008 jblunck@suse.de
- patches.suse/coredump_filter-add-elfhdr-default.patch: Dump
  elf headers to core per default.
* Wed Nov  5 2008 teheo@suse.de
  Fix !CONFIG_DMI case.
- patches.drivers/dmi-introduce-dmi_first_match: DMI:
  Introduce dmi_first_match to make the interface more flexible
  (bnc#441721).
* Wed Nov  5 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: update patch
  to skip all devices with no dma_parms (bnc#431294)
* Wed Nov  5 2008 agruen@suse.de
- rpm/kernel-module-subpackage: Remove the obsolete kernel-$flavor
  dependency (bnc#440961).
* Wed Nov  5 2008 jjolly@suse.de
- patches.arch/s390-01-05-kmsg-v2.patch: Removed and replaced with
  v3 of the patch from IBM (bnc#417300)
- patches.arch/s390-01-05-kmsg-v3.patch: Kernel message catalog
  infrastucture and message generation (bnc#417300).
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  Patch edited to allow new kmsg patch
* Wed Nov  5 2008 agruen@suse.de
- Update config files: set CONFIG_MODULE_FORCE_LOAD=y to allow
  ignoring ABI mismatches. (This is still unsafe to do!)
* Wed Nov  5 2008 tiwai@suse.de
  Backport fixes from 2.6.28-rc.
- patches.drivers/alsa-hda-acer-quirk: ALSA: hda - Add a quirk
  for another Acer Aspire (1025:0090) (bnc#426935).
- patches.drivers/alsa-hda-alc888-medion-add: ALSA: hda - Add
  a quirk for MEDION MD96630 (bnc#412548).
- patches.drivers/alsa-hda-dell-eq-option: ALSA: hda: make a
  STAC_DELL_EQ option.
- patches.drivers/alsa-hda-proc-gpio-fix: ALSA: hda - Limit the
  number of GPIOs show in proc.
* Wed Nov  5 2008 gregkh@suse.de
- refresh -rt patches to remove fuzz.
* Wed Nov  5 2008 teheo@suse.de
  Backport two more device specific workarounds from 2.6.28-rc.
- patches.drivers/libata-add-and-use-HORKAGE_ATAPI_MOD16_DMA:
  libata: implement ATA_HORKAGE_ATAPI_MOD16_DMA and apply it.
- patches.drivers/libata-whitelist-good-bridges: libata: add
  whitelist for devices with known good pata-sata bridges.
* Wed Nov  5 2008 gregkh@suse.de
- refresh patches to remove fuzz
* Wed Nov  5 2008 teheo@suse.de
  Backport double spin off workaround.
- patches.drivers/dmi-introduce-dmi_first_match: DMI:
  Introduce dmi_first_match to make the interface more flexible
  (bnc#441721).
- patches.drivers/libata-ahci-blacklist-double-spin-off: SATA
  AHCI: Blacklist system that spins off disks during ACPI power
  off (bnc#441721).
- patches.drivers/libata-ata_piix-blacklist-double-spin-off:
  SATA PIIX: Blacklist system that spins off disks during ACPI
  power off (bnc#441721).
- patches.drivers/libata-implement-NO_SPINDOWN: SATA: Blacklisting
  of systems that spin off disks during ACPI power off (rev. 2)
  (bnc#441721).
- patches.drivers/libata-sata_sil-blacklist-double-spin-off:
  SATA Sil: Blacklist system that spins off disks during ACPI
  power off (bnc#441721).
- patches.drivers/power-introduce-system_entering_hibernation:
  Hibernation: Introduce system_entering_hibernation (bnc#441721).
* Wed Nov  5 2008 gregkh@suse.de
- fix rt tree that was broken by 2.6.27.5-rc1
* Wed Nov  5 2008 olh@suse.de
- update patches.arch/ppc-powerpc-debug-pci-hotplug.patch
  fix booting on ppc32 (bnc#439491 - LTC48584)
* Wed Nov  5 2008 teheo@suse.de
  Backport sata_via fixes from 2.6.28-rc.
- patches.drivers/libata-sata_via-fix-support-for-5287: sata_via:
  fix support for 5287 (bnc#441718).
- patches.drivers/libata-sata_via-load-DEVICE-register-when-CTL-changes:
  sata_via: load DEVICE register when CTL changes (bnc#441718).
- patches.drivers/libata-sata_via-restore-vt-_prepare_host-error-handling:
  sata_via: restore vt*_prepare_host error handling (bnc#441718).
* Wed Nov  5 2008 teheo@suse.de
  Backport laptop table and pci device ID table entries from 2.6.28-rc.
- patches.drivers/libata-ata_piix-add-Hercules-EC-900-mini-to-laptop-tbl:
  ata_piix: add Hercules EC-900 mini-notebook to ich_laptop
  short cable list.
- patches.drivers/libata-ata_piix-add-intel-ibex-pci-ids:
  ata_piix: IDE Mode SATA patch for Intel Ibex Peak DeviceIDs.
* Wed Nov  5 2008 teheo@suse.de
  Backport slave_link from 2.6.28-rc to fix ata_piix probing problem.
- patches.drivers/libata-ata_piix-use-slave_link: ata_piix:
  drop merged SCR access and use slave_link instead (bnc#441420).
- patches.drivers/libata-eh-fix-slave-link-EH-action-mask-handling:
  libata-eh: fix slave link EH action mask handling (bnc#441420).
- patches.drivers/libata-implement-slave_link: libata: implement
  slave_link (bnc#441420).
- patches.drivers/libata-make-SCR-access-ops-per-link: libata:
  make SCR access ops per-link (bnc#441420).
- patches.drivers/libata-misc-updates-to-prepare-for-slave-link:
  libata: misc updates to prepare for slave link (bnc#441420).
- patches.drivers/libata-reimplement-link-iterator: libata:
  reimplement link iterator (bnc#441420).
- patches.drivers/libata-set-device-class-to-NONE-if-phys_offline:
  libata: set device class to NONE if phys_offline (bnc#441420).
- patches.drivers/libata-transfer-EHI-control-flags-to-slave-ehc.i:
  libata: transfer EHI control flags to slave ehc.i (bnc#441420).
* Wed Nov  5 2008 gregkh@suse.de
- Update to 2.6.27.5-rc1:
  - fixes lots of things, including a few CVE entries
  - obsoletes, and caused to be deleted:
  - patches.arch/ppc-pseries_16g-numa.patch
  - patches.arch/ppc-pseries_hugepage_pagetable_allocation.patch
  - patches.arch/ppc-pseries_mem-limit-16g.patch
  - patches.arch/s390-02-02-smp-sysdev.patch
  - patches.drivers/alsa-hda-reboot-notifier
  - patches.drivers/libata-sata_nv-hardreset-fix
  - patches.fixes/acpi-clear-wake-status.patch
  - patches.fixes/agp-fix-stolen-memory-counting-on-g4x.patch
  - patches.suse/file-capabilities-add-no_file_caps-switch.diff
  - patches.suse/file-capabilities-turn-on-by-default.diff
- Update config files.
* Wed Nov  5 2008 kkeil@suse.de
- patches.drivers/bnx2-Add-bnx2_shutdown_chip: bnx2: Add
  bnx2_shutdown_chip()
- patches.drivers/bnx2-check-running.patch: Check netif_running
  in most ethtool operations    (bnc#440052)
* Wed Nov  5 2008 kkeil@suse.de
- patches.drivers/ixgbe-copper_pond.patch: ixgbe: add device
  support for 82598AT (copper 10GbE) adapters (bnc#441471)
* Tue Nov  4 2008 tonyj@suse.de
- patches.rt/fork_init_nrcpus.patch: Fix oops in fork_init.
* Tue Nov  4 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix typo
* Tue Nov  4 2008 rw@suse.de
- patches.drivers/bnx2x-zero-PMF:
  bnx2x: Removing the PMF indication when unloading.  (bnc#439679)
* Tue Nov  4 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: make also -base and -extra x86
  subpackages not installable on x86_64
* Tue Nov  4 2008 jjolly@suse.de
- patches.arch/s390-01-04-fcpperf-3-v2.patch: (kernel):FCP -
  Performance Data colletion & analysis patch update (bnc#417243).
- patches.arch/s390-01-04-fcpperf-3.patch: Removed for update
* Tue Nov  4 2008 miklos@szeredi.hu
- patches.apparmor/d_namespace_path_oops_fix.diff: fix oops in
  d_namespace_path (bnc#433504).
* Tue Nov  4 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: scsi_lib_dma.c :
  fix bug w/ dma on virtual fc ports (bnc#431294).
* Tue Nov  4 2008 sdietrich@suse.de
- Update RT config files: Enable CONFIG_NO_HZ on i386/rt_debug.
  - Refresh config files.
* Tue Nov  4 2008 teheo@suse.de
- patches.drivers/libata-fix-last_reset-timestamp-handling:
  libata: fix last_reset timestamp handling (bnc#441340).
* Tue Nov  4 2008 hare@suse.de
- patches.drivers/qla2xxx-8.02.01-k9-update: Update qla2xxx to
  8.02.01-k9 (bnc#439208).
* Tue Nov  4 2008 gregkh@suse.de
- refresh patches to apply cleanly.
* Mon Nov  3 2008 jeffm@suse.de
- patches.suse/dm-raid45_2.6.27_20081027.patch: Compile fix.
* Mon Nov  3 2008 tiwai@suse.de
- patches.drivers/alsa-emu10k1-audigy-fixes: ALSA: emu10k1 -
  Add more invert_shared_spdif flag to Audigy models (bnc#440862).
- patches.drivers/alsa-hda-alc269-fsc-amilo: ALSA: hda - Add
  ALC269 fujitsu model (bnc#440626).
* Mon Nov  3 2008 jeffm@suse.de
- patches.suse/dm-raid45_2.6.27_20081027.patch: Update dmraid45.
* Mon Nov  3 2008 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Fix dm table
  ref count (FATE#304489).
* Mon Nov  3 2008 teheo@suse.de
  BNC reference added.
- patches.drivers/libata-dont-restore-DET-on-detach: libata:
  mask off DET when restoring SControl for detach (bnc#440980).
* Mon Nov  3 2008 teheo@suse.de
- patches.drivers/libata-dont-restore-DET-on-detach: libata:
  mask off DET when restoring SControl for detach.
* Mon Nov  3 2008 olh@suse.de
- add patches.arch/ppc-clock_gettime-nanoseconds.patch
  update also nanoseconds (bnc#439908 - LTC49499)
* Mon Nov  3 2008 teheo@suse.de
- scripts/vc: s/GIT_COMMITER_EMAIL/GIT_COMMITTER_EMAIL and add
  SUSE_COMMITTER_EMAIL.
* Mon Nov  3 2008 teheo@suse.de
  BNC reference added.
- patches.drivers/libata-sata_nv-hardreset-fix: sata_nv: fix
  generic, nf2/3 detection regression (bnc#429344).
* Mon Nov  3 2008 teheo@suse.de
- patches.drivers/libata-sata_nv-hardreset-fix: sata_nv: fix
  generic, nf2/3 detection regression.
* Sun Nov  2 2008 sdietrich@suse.de
- Update RT config files: enable more lock debugging,
  latency features, make x86_64 and i386 consistent.
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/kprobes_make_pointer_decl_consistent.patch: Make
  kprobe locking consistent with lock-type declarations
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/mem_cgroup_charge_statistics-smp_processor_id.patch:
  Use raw_smp_processor_id in __mem_cgroup_stat_add_safe.
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/mem_cgroup_charge_statistics-smp_processor_id.patch:
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/workqueue-introduce-create_rt_workqueue.patch:
  workqueue: introduce create_rt_workqueue. (from 2.6.28)
  Refresh to eliminate fuzz:
  - patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
* Sat Nov  1 2008 sdietrich@suse.de
- Update RT config files:
  - Sync with SLES 11 default/debug configs
  - Limit CPUS to 32
  - Disable CONFIG_RADIX_TREE_CONCURRENT
  - Disable CONFIG_RADIX_TREE_OPTIMISTIC
  - Disable CONFIG_PREEMPT_RCU_BOOST
  - Enable CONFIG_RTMUTEX_CHECK
- Adapt RT patches to changes made by:
  x86_sgi_cpus4096-05-update-send_IPI_mask.patch
  - patches.rt/mitigate-resched-flood-update.patch: Update
    smp_send_reschedule_allbutself_cpumask mask parameter.
  - patches.rt/x86-nmi-send_IPI_mask-pointer-fix.patch: Update
    smp_send_nmi_allbutself  mask parameter.
  Resolve conflicts introduced by:
  x86_sgi_cpus4096-05-update-send_IPI_mask.patch
  - patches.rt/nmi-profiling-base.patch
  - patches.rt/send-nmi-all-preempt-disable.patch
  Refresh to eliminate fuzz
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.27-RT.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
* Sat Nov  1 2008 bwalle@suse.de
- patches.fixes/kdb-fix-stack-overflow.patch:
  kdb: fix stack overflow for large NR_CPUS count (bnc#440361).
* Fri Oct 31 2008 trenn@suse.de
  Fate 304268 and 304266. SGI scir driver (replaces the more intrusive
  leds one) and the rather intrusive x86_64 4096 CPU support patches:
- Update config files.
- patches.arch/x86_uv_early_detect.patch: Delete hacks that were
  necessary while waiting for x2apic code. (bnc#429984).
- patches.arch/x86_sgi-uv-scir.patch: SGI X86 UV: Provide a
  System Activity Indicator driver (FATE304268 bnc#426066).
- patches.arch/x86_sgi_cpus4096-01-fix-smp_call_function.patch:
  smp: reduce stack requirements for smp_call_function_mask
  (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-02-fix-send_call_func_ip.patch:
  x86: reduce stack requirements for send_call_func_ipi
  (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
- patches.arch/x86_sgi_cpus4096-06-optimize-cpumask-in-sched_c.patch:
  Additional cpumask fixups (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-04-add-for_each_cpu_mask_and.patch:
  Add for_each_cpu_mask_and (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-07_pae_compile_fixups.patch:
  more cpumask cleanups for previous (x86_sgi_cpu4096..) patches
  (Additional cpumask fixups).
- patches.suse/kdb-x86: kdb-v4.4-2.6.27-rc8-x86-1 (FATE#303971).
- patches.xen/xen3-patch-2.6.27: Linux: Update to 2.6.27.
- patches.xen/x86_sgi_xen-x86-cpus4096.patch: x86 cpumask xen:
  Updates to support NR_CPUS=4096 (Additional cpumask fixups).
* Fri Oct 31 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-alc269-dmic: ALSA: hda -
  Add digital-mic for ALC269 auto-probe mode (bnc#440626).
- patches.drivers/alsa-hda-realtek-mic-automute-fix: ALSA: hda -
  Disable broken mic auto-muting in Realtek codes (bnc#440626).
* Fri Oct 31 2008 hare@suse.de
- Update config files.
- patches.drivers/cxgb3i: add cxgb3i iscsi driver
  (FATE#304154,bnc#433500).
- patches.drivers/cxgb3-private-iscsi-ip-addresses: cxgb3 -
  manage private iSCSI IP addresses (FATE#304154,bnc#433500).
- patches.drivers/open-iscsi-offloading-support: support for iscsi
  pdu digest offload and payload DDP. (FATE#304154,bnc#433500).
- patches.fixes/cxgb3-remove-duplicate-tests-in-lro: cxgb3 -
  remove duplicate tests in lro (FATE#304154, bnc#430538).
- supported.conf: Mark cxgb3i as supported.
* Fri Oct 31 2008 bwalle@suse.de
- patches.suse/kdb-resolve-uv-conflict.diff:
  Resolve KDB conflicts with UV (bnc#440376).
* Fri Oct 31 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sigmatel-spdif-fix: ALSA: hda -
  Fix SPDIF mute on IDT/STAC codecs.
- patches.drivers/alsa-hda-reboot-notifier: ALSA: hda - Add
  reboot notifier.
* Fri Oct 31 2008 jack@suse.cz
- patches.suse/ocfs2-Fix-mount-cleanup-after-quota-failure.patch:
  ocfs2: Fix mount cleanup after quota failure (fate#302681).
- patches.suse/ocfs2-Fix-oop-in-recovery-without-quotas:
  ocfs2: Fix recovery of nodes when quota feature is disabled
  (fate#302681).
- patches.suse/ocfs2-Fix-grace-time-syncing.patch: ocfs2: Fix
  grace time syncing (fate#302681).
* Fri Oct 31 2008 teheo@suse.de
- patches.drivers/block-del-timer-after-dequeue: blk: move
  blk_delete_timer call in end_that_request_last (bnc#440076
  bnc#440173).
* Thu Oct 30 2008 trenn@suse.de
- patches.arch/x86_agpgart-g33-stoeln-fix-2.patch: Avoid oops
  on G33 in 1MB stolen Mem case (bnc#391261).
* Thu Oct 30 2008 gregkh@suse.de
- patches.fixes/agp-fix-stolen-memory-counting-on-g4x.patch:
  agp: Fix stolen memory counting on G4X. (bnc#437618).
* Thu Oct 30 2008 oneukum@suse.de
- patches.fixes/sd_liberal_28_sense_invalid.diff: fix medium
  presence misdetection in usb storage device  (bnc#362850).
* Thu Oct 30 2008 olh@suse.de
- add patches.fixes/scsi-ibmvscsi-show-config.patch
  use 4k buffer to transfer config data (439970 - LTC49349)
* Thu Oct 30 2008 teheo@suse.de
- patches.drivers/block-add-timeout-on-dequeue: block: add timer
  on blkdev_dequeue_request() not elv_next_request() (bnc#440076).
* Wed Oct 29 2008 sdietrich@suse.de
  Refresh RT patches:
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.27-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/check-for-migration-during-push.patch: RT: fix
  push_rt_task() to handle dequeue_pushable properly.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.27-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.27-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.27-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.27-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.27-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.27-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.27-RT
  event-tracer: add clockevent trace.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.27-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.27-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.27-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-net-bug-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/fix-up-comment.patch: RT: Remove comment that is
  no longer true.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.27-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/futex-fifo-warn-sysctl.patch: Linux-RT 2.6.27-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.27-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.27-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.27-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.27-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/kdb-rtmisc.patch: Misc KDB fixes for RT (debug
  builds).
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.27-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.27-RT.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.27-RT
  mm: lock_page_ref.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.27-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.27-RT
  reduce pagetable-freeing latencies.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.27-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.27-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.27-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.27-RT
  read lock Priority Inheritance implementation.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.27-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.27-RT
  softirq preemption: optimization.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.27-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.27-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.27-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.27-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/partreadd-lttng-instrumentation-irq.patch: readd
  RT compatible version of lttng-instrumentation-irq.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.27-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.27-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.27-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.27-RT.
- patches.rt/prof-sysctl-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.27-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.27-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.27-RT
  radix-tree: optimistic locking.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.27-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.27-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.27-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/s_files.patch: Linux-RT 2.6.27-RT
  remove global files_lock.
- patches.rt/sched-add-needs_post_schedule.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.27-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.27-RT
  sched-fix-dequeued-race.patch.
- patches.rt/sched-make-double-lock-balance-fair.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/sched-only-push-once-per-queue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-properly-account-irq-and-rt-load.patch:
  Linux-RT 2.6.27-RT
  sched: properly account IRQ and RT load in .
- patches.rt/sched-rt-runtime-lock-raw.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.27-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/start_irq_thread.patch: Linux-RT 2.6.27-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.27-RT
  rt: dont disable irqs in usb.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.27-RT.
* Wed Oct 29 2008 gregkh@suse.de
- s/rtl2860/rt2860/
- remove driver from the Xen build as it's dying for some reason.
- add obsoletes for ralink-rt2860-kmp
* Wed Oct 29 2008 olh@suse.de
- update patches.arch/ppc-oprofile-spu.patch
  add missing ARRAY_SIZE(pm_signal_local)
* Wed Oct 29 2008 hare@suse.de
- patches.arch/s390-symmetrix-ioctl.patch: Add ioctl support
  for EMC Symmetrix Subsystem Control I/O (bnc#439221)
* Wed Oct 29 2008 jbeulich@suse.de
- patches.xen/xen-rtl2860-build: fix issue with Windows-style
  types used in rtl2680.
* Wed Oct 29 2008 olh@suse.de
- build af_packet as a module on powerpc (bnc#433540)
* Wed Oct 29 2008 olh@suse.de
- add patches.arch/ppc-oprofile-spu-mutex-locking.patch
  Fix mutex locking for cell spu-oprofile (bnc#422501 - LTC47617)
* Wed Oct 29 2008 olh@suse.de
- add patches.arch/ppc-oprofile-spu.patch
  fix local array size in activate spu profiling function (bnc#439553 - LTC48925)
* Wed Oct 29 2008 olh@suse.de
- update patches.drivers/ehea.patch
  Add hugepage detection (bnc#439599 - LTC48958)
* Wed Oct 29 2008 gregkh@suse.de
- patches.drivers/staging-add-agnx-wireless-driver.patch: Staging:
  add agnx wireless driver.
- patches.drivers/staging-add-otus-atheros-wireless-network-driver.patch:
  Staging: add otus Atheros wireless network driver.
- patches.drivers/staging-add-rtl2860-wireless-driver.patch:
  Staging: add rtl2860 wireless driver (bnc#437959).
- Update config files.
* Tue Oct 28 2008 jkosina@suse.de
- patches.suse/silent-stack-overflow-2.patch: disabled, as it
  causes kernel hangs triggered by grub (bnc#439448).
* Tue Oct 28 2008 kkeil@suse.de
- update patches.suse/SoN-17-net-ps_rx.patch
  fix i/o corruption on rx in ixgbe (bnc#438929)
* Tue Oct 28 2008 jdelvare@suse.de
- config/powerpc/*: Fixup configuration files after last change.
* Tue Oct 28 2008 jdelvare@suse.de
- config/*: Include many multimedia drivers which has been dropped
  accidentally. This includes the pwc, ivtv, zr36067 drivers and
  many old webcam drivers (bnc#439489).
- supported.conf: Add all these drivers again.
* Tue Oct 28 2008 tiwai@suse.de
- patches.drivers/alsa-hda-analog-update,
  patches.drivers/alsa-hda-atihdmi-update,
  patches.drivers/alsa-hda-beep,
  patches.drivers/alsa-hda-hp-mobile-fix,
  patches.drivers/alsa-hda-nvidia-hdmi,
  patches.drivers/alsa-hda-probe-fix,
  patches.drivers/alsa-hda-proc-fix,
  patches.drivers/alsa-hda-realtek-update,
  patches.drivers/alsa-hda-sigmatel-update,
  patches.drivers/alsa-hda-spdif-slave,
  patches.drivers/alsa-hda-via-rec-fix,
  patches.drivers/alsa-hda-via-update:
    ALSA updates, mostly taken from 2.6.28-rc1 patches
- Update config files.
* Tue Oct 28 2008 jdelvare@suse.de
- Actually CONFIG_SND_HDA_HWDEP is a boolean, sorry.
* Tue Oct 28 2008 jdelvare@suse.de
- config/ia64/vanilla, config/x86_64/vanilla: fix configuration
  discrepancy, CONFIG_SND_HDA_HWDEP=m.
* Tue Oct 28 2008 olh@suse.de
- add patches.arch/ppc-pcibios_allocate_bus_resources.patch
  add patches.arch/ppc-powerpc-debug-pci-hotplug.patch
  fix DLPAR on pseries (bnc#439491 - LTC48584)
* Tue Oct 28 2008 olh@suse.de
- add patches.arch/ppc-powerpc-fix-pci-unmap-io.patch
  Fix unmapping of IO space on 64-bit (bnc#439491 - LTC48584)
* Tue Oct 28 2008 olh@suse.de
- update ps3 config, remove unneeded options to reduce vmlinux size
* Tue Oct 28 2008 neilb@suse.de
- patches.suse/md-notify-when-stopped: md: notify udev when an
  md array is stopped. (fate#303894).
* Tue Oct 28 2008 gregkh@suse.de
- use the panasonic laptop driver that was accepted by upstream, not the
  pcc-acpi driver, which was rejected:
  - patches.drivers/staging-add-pcc-acpi-driver.patch: Delete.
  - patches.drivers/panasonic-laptop-add-panasonic-let-s-note-laptop-extras-driver-v0.94.patch:
    panasonic-laptop: add Panasonic Let's Note laptop extras
    driver v0.94.
- Update config files.
* Mon Oct 27 2008 gregkh@suse.de
- patches.drivers/via-framebuffer-driver.patch: Via Framebuffer
  driver.
- Update config files.
* Mon Oct 27 2008 bwalle@suse.de
- patches.fixes/hpwdt-kdump.diff:
  Don't change permission of sysfs file (did that accidentally
  when changing the default value).
* Mon Oct 27 2008 trenn@suse.de
- patches.arch/x86_uv_early_detect.patch: Delete hacks that were
  necessary while waiting for x2apic code. (bnc#429984).
* Mon Oct 27 2008 tj@suse.de
  Refresh the govault patch.
- patches.drivers/libata-add-waits-for-govault: libata: add
  waits for GoVault (bnc#246451).
* Sun Oct 26 2008 bwalle@suse.de
- patches.fixes/kdb-oops-panic.diff:
  Fix NULL pointer dereference when regs == NULL (bnc#439007).
- patches.fixes/hpwdt-kdump.diff:
  Fix kdump when using hpwdt (bnc#436786).
* Sun Oct 26 2008 gregkh@suse.de
- refresh patches to apply cleanly and properly.
* Sun Oct 26 2008 gregkh@suse.de
- Update to 2.6.27.4
* Sat Oct 25 2008 agruen@suse.de
- Fix the dependencies between the split kernel packages and KMPs
  (FATE 303631).
- Fix for kernel paclages which are not split.
- rpm/kernel-source.spec.in: Update list of scripts to include.
* Sat Oct 25 2008 jjolly@suse.de
- patches.arch/s390-02-02-smp-sysdev.patch: kernel: sysdev class
  file creation (bnc#434333)
- patches.arch/s390-02-03-zfcp.patch: Fix zfcp problems that have
  been found (bnc#434333)
- patches.arch/s390-02-04-qeth-mac.patch: qeth: use firmware
  MAC-address for layer2 hsi-devices (bnc#434333)
- patches.arch/s390-02-05-qeth-recovery.patch: qeth: qeth recovery
  fails (bnc#434333)
- patches.arch/s390-02-06-qeth-offset.patch: qeth: fix offset error
  in non prealloc header path (bnc#434333,LTC#48840)
- patches.arch/s390-02-07-qeth-ipv6check.patch: qeth: remove
  unnecessary support ckeck in sysfs route6 (bnc#434333)
- patches.arch/s390-02-08-qeth-panic.patch: qeth: avoid
  skb_under_panic for malformatted inbound data (bnc#434333)
- patches.arch/s390-02-09-tape-lock.patch: tape device driver:
  improve locking (bnc#434333)
* Sat Oct 25 2008 neilb@suse.de
- patches.kernel.org/touch_mnt_namespace-when-the-mount-flags-change.patch:
  touch_mnt_namespace when the mount flags change (FATE#304218).
* Fri Oct 24 2008 gregkh@suse.de
- Updated to 2.6.27.4-rc3:
  - fixed ath5k suspend/resume regression
  - fixed pvrusb2 so it actually works
* Fri Oct 24 2008 jack@suse.cz
- patches.suse/ocfs2-Implementation-of-local-and-global-quota-file.patch:
  ocfs2: Implementation of local and global quota file handling
  (fate#302681). - fixed 64-bit division
* Fri Oct 24 2008 jeffm@suse.de
- Update config files for -rt.
* Fri Oct 24 2008 hare@suse.de
- patches.suse/cgroup-freezer.patch: Add TIF_FREEZE for s390.
* Fri Oct 24 2008 olh@suse.de
- move patches.suse/md-raid-metadata-PAGE_SIZE.patch
  to patches.kernel.org/md-raid-metadata-PAGE_SIZE.patch
  to allow raid0 with 64k PAGE_SIZE
* Fri Oct 24 2008 jack@suse.cz
- Update config files.
- supported.conf: Added new quota module
- patches.suse/xfs-dmapi-enable: Enable XFS DMAPI. - Refreshed
  Quotas for OCFS2:
- patches.suse/quota-Add-callbacks-for-allocating-and-destroying-d.patch:
  quota: Add callbacks for allocating and destroying dquot
  structures (fate#302681).
- patches.suse/quota-Increase-size-of-variables-for-limits-and-ino.patch:
  quota: Increase size of variables for limits and inode usage
  (fate#302681).
- patches.suse/quota-Remove-bogus-optimization-in-check_idq-an.patch:
  quota: Remove bogus 'optimization' in check_idq() and
  check_bdq() (fate#302681).
- patches.suse/quota-Make-_SUSPENDED-just-a-flag.patch: quota:
  Make _SUSPENDED just a flag (fate#302681).
- patches.suse/quota-Allow-to-separately-enable-quota-accounting-a.patch:
  quota: Allow to separately enable quota accounting and enforcing
  limits (fate#302681).
- patches.suse/ext3-Use-sb_any_quota_loaded-instead-of-sb_any_qu.patch:
  ext3: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled() (fate#302681).
- patches.suse/ext4-Use-sb_any_quota_loaded-instead-of-sb_any_qu.patch:
  ext4: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled() (fate#302681).
- patches.suse/reiserfs-Use-sb_any_quota_loaded-instead-of-sb_an.patch:
  reiserfs: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled(). (fate#302681).
- patches.suse/quota-Remove-compatibility-function-sb_any_quota_en.patch:
  quota: Remove compatibility function sb_any_quota_enabled()
  (fate#302681).
- patches.suse/quota-Introduce-DQUOT_QUOTA_SYS_FILE-flag.patch:
  quota: Introduce DQUOT_QUOTA_SYS_FILE flag (fate#302681).
- patches.suse/quota-Move-quotaio_v-12-.h-from-include-linux-to-f.patch:
  quota: Move quotaio_v[12].h from include/linux/ to fs/
  (fate#302681).
- patches.suse/quota-Split-off-quota-tree-handling-into-a-separate.patch:
  quota: Split off quota tree handling into a separate file
  (fate#302681).
- patches.suse/quota-Convert-union-in-mem_dqinfo-to-a-pointer.patch:
  quota: Convert union in mem_dqinfo to a pointer (fate#302681).
- patches.suse/quota-Allow-negative-usage-of-space-and-inodes.patch:
  quota: Allow negative usage of space and inodes (fate#302681).
- patches.suse/quota-Keep-which-entries-were-set-by-SETQUOTA-quota.patch:
  quota: Keep which entries were set by SETQUOTA quotactl
  (fate#302681).
- patches.suse/quota-Add-helpers-to-allow-ocfs2-specific-quota-ini.patch:
  quota: Add helpers to allow ocfs2 specific quota initialization,
  freeing and recovery (fate#302681).
- patches.suse/quota-Implement-function-for-scanning-active-dquots.patch:
  quota: Implement function for scanning active dquots
  (fate#302681).
- patches.suse/ocfs2-Fix-check-of-return-value-of-ocfs2_start_tran.patch:
  ocfs2: Fix check of return value of ocfs2_start_trans()
  (fate#302681).
- patches.suse/ocfs2-Support-nested-transactions.patch: ocfs2:
  Support nested transactions (fate#302681).
- patches.suse/ocfs2-Fix-checking-of-return-value-of-new_inode.patch:
  ocfs2: Fix checking of return value of new_inode()
  (fate#302681).
- patches.suse/ocfs2-Let-inode-be-really-deleted-when-ocfs2_mknod_.patch:
  ocfs2: Let inode be really deleted when ocfs2_mknod_locked()
  fails (fate#302681).
- patches.suse/ocfs2-Assign-feature-bits-and-system-inodes-to-quot.patch:
  ocfs2: Assign feature bits and system inodes to quota feature
  and quota files (fate#302681).
- patches.suse/ocfs2-Mark-system-files-as-not-subject-to-quota-acc.patch:
  ocfs2: Mark system files as not subject to quota accounting
  (fate#302681).
- patches.suse/ocfs2-Implementation-of-local-and-global-quota-file.patch:
  ocfs2: Implementation of local and global quota file handling
  (fate#302681).
- patches.suse/ocfs2-Add-quota-calls-for-allocation-and-freeing-of.patch:
  ocfs2: Add quota calls for allocation and freeing of inodes
  and space (fate#302681).
- patches.suse/ocfs2-Enable-quota-accounting-on-mount-disable-on.patch:
  ocfs2: Enable quota accounting on mount, disable on umount
  (fate#302681).
- patches.suse/ocfs2-Implement-quota-syncing-thread.patch: ocfs2:
  Implement quota syncing thread (fate#302681).
- patches.suse/ocfs2-Implement-quota-recovery.patch: ocfs2:
  Implement quota recovery (fate#302681).
* Fri Oct 24 2008 kkeil@suse.de
- patches.fixes/cxgb3_fix_race_in_EEH: cxgb3: fix race in EEH.
  (bnc#430093)
* Fri Oct 24 2008 jeffm@suse.de
- Refreshed context for -RT patches so they apply again.
* Fri Oct 24 2008 rw@suse.de
- patches.drivers/sgi-ioc4-request-submodules:
  Make ioc4 request dependant modules.  (bnc#429215)
* Fri Oct 24 2008 hare@suse.de
- Update config files: Disable FAIL_MAKE_REQUEST.
* Fri Oct 24 2008 tiwai@suse.de
- patches.drivers/alsa-usb-exclude-1st-slot: Delete this old ugly
  workaround patch.
* Fri Oct 24 2008 hare@suse.de
- Include patches from upstream:
  - patches.fixes/block-use-bio_has_data: Implement bio_has_data().
  - patches.fixes/block-git-fixes: Block layer fixes for 2.6.28.
  - patches.fixes/block-rq-affinity: Implement rq affinity.
  - patches.fixes/dm-mpath-remove-is_active: dm mpath: remove
    is_active from struct dm_path.
  - patches.fixes/block-discard-requests: Implement block discard.
  - patches.drivers/dm-abort-queue-on-failed-paths: dm: Call
    blk_abort_queue on failed paths (bnc#417544).
  - patches.drivers/block-call-sync-on-cleanup: block:
    blk_cleanup_queue() should call blk_sync_queue().
- Refaktor and update request-based multipath patches:
  - patches.drivers/blk-request-based-multipath-update:
    Update request-based multipathing patches to upstream version
    (bnc#434105).
  - patches.suse/rq-based-multipath: Update to latest version
    of request-based multipathing patchset (bnc#434105)
  - patches.drivers/block-abort-request-rq-complete-marking:
    use rq complete marking in blk_abort_request (bnc#434105).
  - patches.fixes/scsi-atomic-blk-timer-deletes: Delete.
  - patches.fixes/dm-mpath-abort-queue: Delete.
  - patches.suse/rq-based-block-layer: Delete.
  - patches.suse/rq-based-dm-interface: Delete.
  - patches.suse/rq-based-multipath-functions: Delete.
  - patches.suse/rq-based-init-crash: Delete.
- Update patches to upstream version:
  - patches.drivers/bdev-resize-check-for-device-resize
  - patches.drivers/bdev-resize-added-flush_disk
  - patches.drivers/bdev-resize-call-flush_disk
  - patches.drivers/bdev-resize-sd-driver-calls
  - patches.drivers/block-timeout-handling
  - patches.drivers/bdev-resize-adjust-block-device-size
  - patches.drivers/bdev-resize-wrapper-for-revalidate_disk
  - patches.drivers/block-abort-queue
  - patches.fixes/scsi-enhance-error-codes
- Rediff patches:
  - patches.fixes/scsi-misc-git-update
  - patches.suse/dm-barrier-single-device
  - patches.suse/kdb-common
  - patches.drivers/lpfc-8.2.8-update
  - patches.drivers/lpfc-8.2.8.3-update
  - patches.drivers/mpt-fusion-4.00.43.00-update
* Fri Oct 24 2008 bwalle@suse.de
- patches.suse/kdump-dump_after_notifier.patch: Add sysctl also
  to kernel/sysctl_check.c.
* Fri Oct 24 2008 bwalle@suse.de
- Obsolete uvcvideo-kmp.
* Fri Oct 24 2008 jbeulich@suse.de
- rpm/kernel-binary.spec.in: Provide 'kernel' also for Xen (bnc#362918).
* Fri Oct 24 2008 jbeulich@suse.de
- patches.arch/x86_64-unwind-annotations: fix unwind annotations.
- patches.xen/xen3-x86_64-unwind-annotations: fix unwind
  annotations.
* Fri Oct 24 2008 jbeulich@suse.de
- Update Xen patches to 2.6.27.3 and c/s 704
- patches.xen/xen3-x2APIC_PATCH_27_of_41_9fa8c481b55e80edd8c637573f87853bb6b600f5:
  x64, x2apic/intr-remap: introduce CONFIG_INTR_REMAP (fate
  [#303948] and fate #303984).
- patches.xen/xen3-x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4:
  x86: use cpuid vector 0xb when available for detecting cpu
  topology (fate #303948 and fate #303984).
- patches.xen/xen-kconfig-compat-3.2.0: add 3.2.0-compatibility
  configure option.
- patches.xen/xen-x86-exit-mmap: be more aggressive about
  de-activating mm-s under destruction.
- patches.xen/xen-x86-machphys-prediction: properly predict
  phys<->mach translations.
- patches.xen/xen-x86-mmu-batching: utilize
  arch_{enter,leave}_lazy_cpu_mode().
- patches.xen/xen-x86-no-lazy-tlb: ensure inadvertent uses of
  lazy TLB data are caught during the build.
- Update Xen config files.
* Fri Oct 24 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in:
  - do not split kernel-kdump into -base and -extra
  - fix case when a build results in no unsupported modules
* Fri Oct 24 2008 bwalle@suse.de
- patches.fixes/kdb-kdump.diff:
  Fix CONFIG_KDB_KDUMP on xSeries (bnc#436454).
* Fri Oct 24 2008 agruen@suse.de
- supported.conf: Mark dmapi as supported (by SGI).
* Fri Oct 24 2008 olh@suse.de
- disable all unsupported drivers in kernel-kdump
* Fri Oct 24 2008 npiggin@suse.de
- patches.suse/silent-stack-overflow-2.patch: avoid silent stack
  overflow over the heap (bnc#44807 bnc#211997).
* Fri Oct 24 2008 gregkh@suse.de
- Update to 2.6.27.4-rc2
* Fri Oct 24 2008 gregkh@suse.de
- disable CONFIG_SYSFS_DEPRECATED_V2 from powerpc/rt config file
* Fri Oct 24 2008 gregkh@suse.de
- Update to 2.6.27.4-rc1
  - lots of bugfixes, and obsoletes some current patches:
  - patches.fixes/ext3-avoid-printk-flood-with-dir-corruption: Delete.
  - patches.fixes/ext2-avoid-printk-flood-with-dir-corruption: Delete.
  - patches.fixes/wdm_autoload.diff: Delete.
* Fri Oct 24 2008 npiggin@suse.de
- Fix ppc and ps3 configs
* Fri Oct 24 2008 npiggin@suse.de
- Update config files.
- patches.suse/cgroup-freezer.patch: cgroup freezer (bnc#417294,
  fate#304191, fate#201036).
* Fri Oct 24 2008 npiggin@suse.de
- Update config files. Enable cgroups for all archs (bnc#417527)
* Fri Oct 24 2008 npiggin@suse.de
- patches.arch/ppc-gigantic-page-fix2.patch: powerpc gigantic
  pages fix 2 (bnc#434026).
- patches.arch/ppc-gigantic-page-fix3.patch: powerpc gigantic
  pages fix 3 (bnc#434026).
- patches.trace/lttng-instrumentation-hugetlb.patch: de-fuzz
* Fri Oct 24 2008 gregkh@suse.de
- disabled CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT on x86-64
  vanilla kernel.
* Fri Oct 24 2008 gregkh@suse.de
- patches.drivers/cciss-fix-procfs-firmware-regression.patch:
  cciss: fix procfs firmware regression (bnc435644).
- patches.drivers/cciss-fix-sysfs-symlink.patch: cciss: fix
  sysfs symlink (bnc435644).
* Fri Oct 24 2008 gregkh@suse.de
- disable CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT on x86-64.  To use
  Calgary iommu systems, you now must manually pass "iommu=calgary" to
  get this hardware support back enabled.  This is the recommended
  proceedure right now, from IBM, otherwise the hardware crashes.
  bnc#436450.
* Fri Oct 24 2008 gregkh@suse.de
- clean up all fuzz in patches to get them to apply cleanly.
* Thu Oct 23 2008 gregkh@suse.de
- delete patches.arch/s390-01-03-cmm2-v2.patch as it touched core
  kernel code and was rejected from upstream.
  - patches.arch/s390-01-03-cmm2-v2.patch: Delete.
  - patches.arch/s390-01-03-cmm2-v2a.patch: Delete.
* Thu Oct 23 2008 gregkh@suse.de
- Update to version 3.4 of squashfs:
  - patches.suse/squashfs3.3-patch: Delete.
  - patches.suse/squashfs-patch-2.6.25: Delete.
  - patches.suse/squashfs-patch-2.6.27: Delete.
  - patches.suse/squashfs-3.4.patch: squashfs v3.4.
* Thu Oct 23 2008 jeffm@suse.de
- patches.fixes/block-sanitize-invalid-partition-table-entries:
  block: sanitize invalid partition table entries (bnc#371657).
* Thu Oct 23 2008 olh@suse.de
- add patches.arch/ppc-pseries_mem-limit-16g.patch
  Don't use a 16G page if beyond mem= limits (bnc#438111 - LTC49329)
* Thu Oct 23 2008 kkeil@suse.de
- Update x86 64bit config files to include WAN support (bnc#437692)
* Thu Oct 23 2008 olh@suse.de
- add patches.drivers/cell_edac.patch
  Fix incorrect edac_mode in csrow causing oops (bnc#437757 - LTC49143)
* Thu Oct 23 2008 olh@suse.de
- update patches.suse/nameif-track-rename.patch
  print also application and pid
* Thu Oct 23 2008 jkosina@suse.de
- patches.fixes/hid-rdesc-quirk-for-sony-vaio-VGX-TP1E.patch:
  HID: Fix Sony Vaio VGX report descriptor (bnc#437758).
* Thu Oct 23 2008 olh@suse.de
- add patches.drivers/ehca-rejecting-dynamic-mem-add-remove.patch
  reject dynamic memory add/remove (bnc#434651 - LTC48744)
* Thu Oct 23 2008 npiggin@suse.de
- Update config files.
* Thu Oct 23 2008 npiggin@suse.de
- patches.suse/x86-gb-linear-map.patch: Enable GB mapped linear
  KVA on x86 (bnc#437674).
- patches.xen/xen3-patch-2.6.26: merge
* Wed Oct 22 2008 gregkh@suse.de
- update to 2.6.27.3
  - lots of bugfixes
  - CVE-2008-3831 fix
* Wed Oct 22 2008 jeffm@suse.de
- scripts/vc: Handle unset $EDITOR
* Wed Oct 22 2008 jeffm@suse.de
- patches.suse/export-release_open_intent: Export
  release_open_intent for NFS branches with aufs.
* Wed Oct 22 2008 jdelvare@suse.de
- supported.conf: Mark the ibmaem and ibmpex hwmon drivers as
  supported by IBM.
- supported.conf: Mark the i5k_amb hwmon driver as supported.
* Wed Oct 22 2008 olh@suse.de
- add patches.drivers/ehea.patch
  Fix memory hotplug support (436447 - LTC48713)
* Wed Oct 22 2008 olh@suse.de
- add patches.arch/ppc-pseries_hugepage_pagetable_allocation.patch
  Cleanup hugepage pagetable allocation (bnc# 433503 - LTC48757)
* Wed Oct 22 2008 sassmann@suse.de
  Add PS3 audio patches:
- patches.arch/ppc-ps3-add-passthrough-support-for-non-audio-streams.patch:
  ps3: Add passthrough support for non-audio streams.
- patches.arch/ppc-ps3-add-ps3av-audio-mute-analog.patch:
  ps3: Add ps3av_audio_mute_analog().
- patches.arch/ppc-ps3-add-support-for-SPDIF-HDMI-passthrough.patch:
  ps3: Add support for SPDIF/HDMI passthrough.
* Tue Oct 21 2008 sdietrich@suse.de
- patches.rt/genirq-usb.patch: Make status_cache u32
- patches.rt/genirq-ohci1394.patch: Enable ohci1394 IRQ
  threading.
* Tue Oct 21 2008 hare@suse.de
- patches.fixes/dm-mpath-abort-queue: rediff.
- patches.fixes/scsi-atomic-blk-timer-deletes: scsi: atomic blk
  timer deletes (LTC#48990, bnc#434105).
- patches.suse/rq-based-block-layer: rq-based multipathing:
  rediff.
* Tue Oct 21 2008 hare@suse.de
- patches.fixes/scsi-inquiry-too-short-ratelimit: INQUIRY result
  too short (5) message flood (bnc#432535).
* Tue Oct 21 2008 npiggin@suse.de
- patches.suse/filp-slab-rcu: Delete.
* Tue Oct 21 2008 sdietrich@suse.de
  USB IRQ threading (experimental: guarded by genirq):
- patches.rt/genirq1-make-irqreturn_t-an-enum: genirq: make
  irqreturn_t an enum.
- patches.rt/genirq2-add-quick-check-handler.patch: genirq:
  add a quick check handler.
- patches.rt/genirq3-add-threaded-irq-handler-support: genirq:
  add threaded interrupt handler support.
- patches.rt/genirq4-add-helper-to-check-whether-irq-thread-should-run:
  genirq: add a helper to check whether the irqthread should run.
- patches.rt/genirq5-make-irq-threading-robust: genirq: make
  irq threading robust.
- patches.rt/genirq-usb.patch: genirq threading for ehci, ohci
  and uhci USB hosts..
- patches.rt/genirq-wlan-ng-compat.patch: Remove redundant,
  obsolete 2.4 compatibility code in wlan-ng.
  Ack:
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
* Mon Oct 20 2008 gregkh@suse.de
- patches.arch/x2APIC_PATCH_x86-mach_apicdef.h-need-to-include-before-smp.h.patch:
  x86: mach_apicdef.h need to include before smp.h.
  fixes build error on i386 pae kernels.
* Mon Oct 20 2008 bwalle@suse.de
- patches.suse/kdump-dump_after_notifier.patch:
  Add dump_after_notifier sysctl (bnc#436678).
* Mon Oct 20 2008 gregkh@suse.de
- scripts/wd-functions.sh: reverse git and cvs checks (check for
  cvs before git).  This solves the problem if you are using a cvs
  tree, yet it happens to live in a directory that way up the
  directory chain is in a git tree (like for people who keep portions
  of their $HOME in git).
* Mon Oct 20 2008 gregkh@suse.de
- Update config files: enable CONFIG_GENERICARCH and CONFIG_BIGSMP
  on i386-pae kernels. (bnc#428247)
* Mon Oct 20 2008 ptesarik@suse.cz
- patches.arch/x86-tracehook: fix the order of arguments in
  /proc/$pid/syscall on x86_64.
* Mon Oct 20 2008 bwalle@suse.de
- Update config files: Enable CONFIG_KVM_KMP for RT config, run
  oldconfig.
* Mon Oct 20 2008 bwalle@suse.de
- patches.arch/ppc-vmcoreinfo.diff: Correct to reflect mainline
  state.
* Mon Oct 20 2008 hare@suse.de
- Update config files.
- patches.suse/kvm-as-kmp: Allow KVM to be built as KMP
  (FATE#303679).
* Mon Oct 20 2008 jjolly@suse.de
- patches.arch/s390-01-05-kmsg-v2.patch: Instrument the kernel
  components such that a kernel message catalog as well as related
  man pages can be automatically generated. (bnc#417300)
- patches.arch/s390-01-06-zfcp-cleanup-v2.patch: Update patch to
  fit on recent kmsg patch changes. (bnc#417550)
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  Update patch to fit on recent kmsg patch changes.
- config/s390/{default,s390}: Added CONFIG_KMSG_IDS=y
* Mon Oct 20 2008 bwalle@suse.de
- supported.conf: Mark 'crasher' as supported to avoid installing
  the "extra" package only for that module.
* Mon Oct 20 2008 olh@suse.de
- add patches.arch/ppc-pseries_16g-numa.patch
  fix crash with more 2 numa nodes and 16G hugepage (bnc#436452 - LTC48839)
* Sat Oct 18 2008 gregkh@suse.de
- Update to 2.6.27.2.
  - lots of bugfixes
* Sat Oct 18 2008 tonyj@suse.de
- patches.rt/fix-preempt-none.patch: Fix preempt-none build
  errors
* Fri Oct 17 2008 jeffm@suse.de
- patches.suse/SoN-20-netvm-reserve-inet.patch-fix: SoN: Fix
  initialization of ipv4_route_lock (bnc#435994).
* Fri Oct 17 2008 kkeil@suse.de
- patches.drivers/tg3-Add-57780-ASIC-revision.patch: tg3: Add
  57780 ASIC revision. (bnc#434147)
- patches.drivers/broadcom-Add-support-for-the-57780-integrated-PHY.patch:
  broadcom: Add support for the 57780 integrated PHY. (bnc#434147)
- patches.drivers/bnx2x-eeh.patch: bnx2x: EEH recovery fix.(bnc#433875)
* Fri Oct 17 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: Add the auto-generated (by mkdumprd)
  kdump initrd to %%ghost so that the file gets removed when
  uninstalling the kernel.
* Fri Oct 17 2008 mfasheh@suse.com
- ocfs2 ACL / security attribute support
  - patches.suse/ocfs2-Remove-unused-function-restore_extent_block.patch
  - patches.suse/ocfs2-Merge-transactions-during-xattr-set.patch
  - patches.suse/ocfs2-xattr.-ch-definition-cleanups.patch
  - patches.suse/ocfs2-Add-security-xattr-support-in-ocfs2.patch
  - patches.suse/ocfs2-Add-POSIX-ACL-support-in-ocfs2.patch
* Thu Oct 16 2008 mfasheh@suse.com
- ocfs2 fixes / updates from 2.6.28 merge window
  - patches.suse/ocfs2-xattr.c-Fix-a-bug-when-inserting-xattr.patch
  - patches.suse/ocfs2-Add-empty-bucket-support-in-xattr.patch
  - patches.suse/ocfs2-Remove-pointless.patch
  - patches.suse/ocfs2-make-la_debug_mutex-static.patch
  - patches.suse/ocfs2-Documentation-update-for-user_xattr-nouser_.patch
  - patches.suse/ocfs2-use-smaller-counters-in-ocfs2_remove_xattr_cl.patch
  - patches.suse/ocfs2-Don-t-check-for-NULL-before-brelse.patch
  - patches.suse/ocfs2-Uninline-ocfs2_xattr_name_hash.patch
  - patches.suse/ocfs2-Move-trusted-and-user-attribute-support-into.patch
  - patches.suse/ocfs2-Calculate-EA-hash-only-by-its-suffix.patch
  - patches.suse/ocfs2-Refactor-xattr-list-and-remove-ocfs2_xattr_ha.patch
  - patches.suse/ocfs2-Separate-out-sync-reads-from-ocfs2_read_block.patch
  - patches.suse/ocfs2-Require-an-inode-for-ocfs2_read_block-s.patch
  - patches.suse/ocfs2-Simplify-ocfs2_read_block.patch
  - patches.suse/ocfs2-Move-ocfs2_bread-into-dir.c.patch
  - patches.suse/ocfs2-Kill-the-last-naked-wait_on_buffer-for-cach.patch
  - patches.suse/ocfs2-Make-cached-block-reads-the-common-case.patch
  - patches.suse/ocfs2-fix-build-error.patch
* Thu Oct 16 2008 mfasheh@suse.com
- ocfs2 dynamic local alloc patches
* Thu Oct 16 2008 jslaby@suse.de
- patches.drivers/tpm-bcm0102-workaround.patch: tpm: work around
  bug in Broadcom BCM0102 chipset (bnc#425747 FATE304221).
- patches.drivers/tpm-correct-timeouts.patch: tpm: correct tpm
  timeouts to jiffies conversion (bnc#425747 FATE304221).
* Thu Oct 16 2008 ihno@suse.de
- added patches.arch/s390-01-03-cmm2-v2a.patch
  fix the sequence of initilisations.
* Thu Oct 16 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: Make the kernel-$flavor-extra packages
  supplement kernel-$flavor on openSUSE and SLED so that those
  packages will get installed by default, using the product(...)
  dependencies provided by the *-release packages.
* Thu Oct 16 2008 tonyj@suse.de
- Previous checkin was totally broken wrt rt config files.
  Revert to previous versions and incorporate any changes from
  run_oldconfig. Sole changes to previous versions is to remove
  CONFIG_DYNAMIC_FTRACE from rt_debug configs which is consistent
  with change in 2.6.27.1
* Thu Oct 16 2008 gregkh@suse.de
- Update to 2.6.27.1
  - disables a problem config option, only affected the vanilla,
    debug, and rt kernel variants.
* Wed Oct 15 2008 olh@suse.de
- add patches.arch/ppc-pseries_pfn-mem-rm.patch
  fix hotplug memory remove (bnc#435181 - LTC48640)
* Wed Oct 15 2008 mmarek@suse.cz
- rpm/post.sh, rpm/postun.sh: run weak-modules, depmod and mkinitrd
  on older distros (bnc#435246)
  Fixed fix for bnc#435104 ("/boot/" was missing in some places)
* Wed Oct 15 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: don't recommend the -extra subpackage
  (fate#303631)
- rpm/postun.sh, rpm/post.sh: remove the temporary workaround
* Wed Oct 15 2008 olh@suse.de
- drop patches.arch/ppc-iseries-remove-AVAILABLE_VETH.patch
  not needed anymore
* Wed Oct 15 2008 nfbrown@suse.de
- patches.fixes/nfs-file-cred-context-null: nfs_file_cred should
  cope if 'file' hasn't been opened properly (bnc#431785).
* Wed Oct 15 2008 tonyj@suse.de
- Update RT patches to latest .27 Windriver version (all patches)
- Disable patches.rt/swap-spinlock-fix.patch
- Guard filp-slab-rcu for RT
* Tue Oct 14 2008 jkosina@suse.de
- patches.fixes/input-add-acer-aspire-5710-to-nomux.patch: Input:
  Add Acer Aspire 5710 to nomux blacklist (bnc#404881).
* Tue Oct 14 2008 oneukum@suse.de
- patches.fixes/ehci_sched.diff: Delete.
  in mainline now. done to the right tree.
* Tue Oct 14 2008 mmarek@suse.cz
- rpm/postun.sh, rpm/post.sh: temporarily ignore errors from
  weak-modules2 --{add,remove}-kernel-modules until
  module-init-tools has rebuilt
* Tue Oct 14 2008 jkosina@suse.de
- patches.fixes/input-add-amilo-pro-v-to-nomux.patch: Delete.
  The patch is already upstream in 2.6.27
* Tue Oct 14 2008 jeffm@suse.de
- patches.suse/osync-error: Update position after check for -EIO
  (bnc#434910).
* Tue Oct 14 2008 npiggin@suse.de
- patches.suse/rlimit-memlock-64k.patch: Increase default
  RLIMIT_MEMLOCK to 64k (bnc#329675).
* Tue Oct 14 2008 sjayaraman@suse.de
- Update config files: CIFS_EXPERIMENTAL=y and CIFS_DFS_UPCALL=y
  (FATE#303758).
* Tue Oct 14 2008 jbeulich@novell.com
- patches.xen/xen-irq-probe: restrict IRQ probing (bnc#431572).
* Tue Oct 14 2008 ptesarik@suse.cz
- patches.trace/utrace-core: undo overzealous #ifdef's, which
  removed too much code in case UTRACE_CONFIG was unset.
* Tue Oct 14 2008 jbeulich@novell.com
- patches.fixes/reiserfs-commit-ids-unsigned-ints: Remove L suffix
  from constant compared against.
* Tue Oct 14 2008 olh@suse.de
- call bootloader_entry without leading /boot/ (bnc#435104)
* Tue Oct 14 2008 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh, rpm/functions.sh:
  kill functions.sh, put the relink() function to source-post.sh
  directly
- rpm/postun.sh, rpm/pre.sh, rpm/preun.sh, rpm/post.sh,
  rpm/kernel-binary.spec.in: unify generation of the scriptlets,
  switch to the new weak-modules2 script
* Tue Oct 14 2008 olh@suse.de
- disable unused ide_platform driver
* Tue Oct 14 2008 jdelvare@suse.de
- supported.conf: Remove i2c-core and i2c-piix4 from base.
* Tue Oct 14 2008 gregkh@suse.de
- supported.conf: remove ide-core and ide-cdrom from base on request
  from Tejun.
* Mon Oct 13 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-pcc-acpi-driver.patch: Staging:
  add pcc-acpi driver.
- rpm/kernel-binary.spec.in: Obsoletes pcc-acpi-kmp
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: it's pcc-acpi and it's not obsolete, yet.
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: obsoletes at76_usb-kmp
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: obsoletes et131x-kmp, ivtv-kmp, and
  ppc-acpi-kmp
* Mon Oct 13 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-at76_usb-wireless-driver.patch: staging:
  at76_usb wireless driver.
* Mon Oct 13 2008 gregkh@suse.de
- refresh all patches (except xen and rt) to apply cleanly
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: add Obsoletes: wlan-ng-kmp as the needed
  driver is now included from the staging tree.
* Mon Oct 13 2008 gregkh@suse.de
- put proper Patch-mainline: markings on staging patches
* Mon Oct 13 2008 gregkh@suse.de
- patches.drivers/staging-workaround-build-system-bug.patch:
  Staging: workaround build system bug.
* Mon Oct 13 2008 aj@suse.de
- rpm/post.sh: Fix typo that breaks script.
* Mon Oct 13 2008 gregkh@suse.de
- disabled staging drivers for -rt trees
* Mon Oct 13 2008 gregkh@suse.de
- Add -staging tree:
  - added TAINT_CRAP flag
  - added eth131x network driver
  - added slicoss network driver
  - added sgx network driver
  - added me4000 data collection driver
  - added go7007 video capture driver
  - added USB/IP host and client driver
  - added w35und wifi network driver
  - added prism2 usb wifi network driver
  - added echo cancellation driver
- only enabled these on x86 platforms
* Mon Oct 13 2008 jjolly@suse.de
- patches.arch/s390-02-01-xpram.patch: xpram: per device block
  request queues (bnc#434333,LTC#49030)
* Mon Oct 13 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Updated supported.conf checker to
  eliminate false positives.
* Mon Oct 13 2008 sjayaraman@suse.de
- patches.suse/SoN-14-mm-reserve.patch: Fix a compiler warning.
* Mon Oct 13 2008 jbenc@suse.cz
- supported.conf: mark drivers/net/wireless/b43* and
  driver/net/wireless/rt2x00/* as unsupported because of known
  problems we cannot fix.
* Mon Oct 13 2008 oneukum@suse.de
- patches.fixes/wdm_autoload.diff:  add MODULE_DEVICE_TABLE to
  cdc-wdm driver to compute a proper alias (bnc#433817).
* Mon Oct 13 2008 ptesarik@suse.cz
- Update config files (CONFIG_UTRACE for rt flavours).
* Mon Oct 13 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.27-rc3: Fix uninitialized data issue.
* Mon Oct 13 2008 ptesarik@suse.cz
- patches.trace/utrace-core: utrace core (FATE#304321).
  CONFIG_UTRACE enabled only for kernel-trace.
- Update config files.
* Mon Oct 13 2008 aj@suse.de
- patches.suse/SoN-14-mm-reserve.patch: Add cast to fix compiler warning.
* Mon Oct 13 2008 sjayaraman@suse.de
- Remove another stale swap-over-nfs patch.
  patches.suse/SoN-29-nfs-alloc-recursions.patch: Delete.
* Fri Oct 10 2008 jeffm@suse.de
- Updated to 2.6.27 final.
* Fri Oct 10 2008 tonyj@suse.de
- Update config files
- Fix conflicts, remove most -RT guards added in recent RT update
  patches.rt/apic-dumpstack.patch: refresh
  patches.rt/preempt-irqs-core.patch: refresh
  patches.rt/print-might-sleep-hack.patch: refresh
  patches.rt/partrevert-lttng-instrumentation-irq.patch: add
  patches.rt/partreadd-lttng-instrumentation-irq.patch: add
- Drop unused RT patches
  patches.rt/mips-change-raw-spinlock-type.patch
  patches.rt/nmi-watchdog-disable.patch
  patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch
  patches.rt/lockstat-fix-contention-points.patch
  patches.rt/sched-cpupri-priocount.patch
  patches.rt/nmi-watchdog-fix-1.patch
  patches.rt/cache_pci_find_capability.patch
  patches.rt/fix-emac-locking-2.6.16.patch
  patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch
  patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch
  patches.rt/tie-pi-into-task.patch
  patches.rt/idle2-fix.patch
  patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch
  patches.rt/rtmutex-initialize-waiters.patch
  patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch
  patches.rt/add-generalized-pi-interface.patch
  patches.rt/warn-on-rt-scatterlist.patch
  patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch
  patches.rt/trace-eip2ip.patch
  patches.rt/sched_rt-fixup.patch
  patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch
  patches.rt/trace_hist-latediv.patch
  patches.rt/sched-cpupri-hotplug-support.patch
  patches.rt/idle-fix.patch
  patches.rt/ftrace-fix-get-kprobe-wreckage.patch
  patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch
  patches.rt/ftrace-function-record-nop.patch
  patches.rt/ftrace-document-update1.patch
  patches.rt/26-rt1-chirag.patch
  patches.rt/trace_hist-divzero.patch
  patches.rt/latency-tracing-ppc.patch
  patches.rt/rtmutex-defer-pi-until-sleepy.patch
  patches.rt/pmtmr-override.patch
  patches.rt/sched-prioritize-non-migrating-rt-tasks.patch
  patches.rt/rtmutex-use-runtime-init.patch
  patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch
  patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch
  patches.rt/lockdep-lock_set_subclass.patch
  patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch
  patches.rt/rt-mutex-irq-flags-checking.patch
  patches.rt/ftrace-upstream.patch
  patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch
  patches.rt/ftrace-preempt-trace-check.patch
  patches.rt/rtmutex-add_readers.patch
  patches.rt/lockdep-avoid-fork-waring.patch
  patches.rt/arm-omap-02.patch
  patches.rt/fix-acpi-build-weirdness.patch
  patches.rt/cycles-to-ns-trace-fix.patch
  patches.rt/ftrace-compile-fixes.patch
  patches.rt/ftrace-wakeup-rawspinlock.patch
  patches.rt/rtmutex-convert-to-libpi.patch
  patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch
  patches.rt/ftrace-trace-sched.patch
* Fri Oct 10 2008 mfasheh@suse.com
- supported.conf: mark kernel/fs/gfs2 unsupported
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark kernel/sound/pci/snd-cs5530 unsupported due
  to sb16 dependancy issues
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/account-reserved-pages: Delete.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/supported-flag-sysfs: Updated to build with
  CONFIG_MODULES=n.
* Thu Oct  9 2008 jeffm@suse.de
- Updated to 2.6.27-rc9, but still disabled:
  - patches.suse/silent-stack-overflow
  - patches.xen/xen3-silent-stack-overflow
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: thermal_sys, not thermal_sysfs.
* Thu Oct  9 2008 jeffm@suse.de
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Updated against
  2.6.27-rc9.
* Thu Oct  9 2008 jdelvare@suse.de
- supported.conf: Fix the name of the thermal_sys module.
- config/x86_64/rt_timing: THERMAL_HWMON is a boolean.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/netfilter-ipv4options: Updated to 2.6.27-rc9,
  enabled, and marked supported (bnc#131728 - FATE#182).
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/serial8250_console_write-ier: Delete.
- patches.fixes/fix-serial-8250-UART_BUG_TXEN-test: Delete.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark kernel/sound/pci/snd-als4000 unsupported due
  to dependancy on isa sb16 driver.
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/dont-writeback-fd-bdev-inodes.patch: Delete.
- patches.arch/s390-ccwgroup-attribute-ignore-newline: Delete.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark drivers/net/wan/hdlc_x25 unsupported due to
  symbol dependancy tree.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/osync-error: make sure O_SYNC writes properly
  return -EIO (bnc#58622).
* Thu Oct  9 2008 bwalle@suse.de
- patches.arch/ppc-vmcoreinfo.diff:
  Add additional symbols to /sys/kernel/vmcoreinfo data for
  ppc(64).
* Thu Oct  9 2008 trenn@suse.de
- patches.xen/xen-x2APIC_build_fix.patch: Adopt Xen to x2APIC
  patchset (fate#303984 and fate#303948).
- Update config files.
  Disable interrupt remapping for Xen -> this is something for
  the hypervisor.
* Thu Oct  9 2008 jeffm@suse.de
- Update config files: THERMAL_HWMON=y in vanilla configs.
* Thu Oct  9 2008 jeffm@suse.de
- Update config files: THERMAL_HWMON=y; is boolean and enables
  functionality in the already modular THERMAL module.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/supported-flag-sysfs: Export supported status
  via sysfs.
* Thu Oct  9 2008 carnold@novell.com
- Update config files.  Disabled the in kernel KVM modules in
  preference to using them as KMPs.  See also brogers@novell.com
* Thu Oct  9 2008 jeffm@suse.de
- Added a -iu|--ignore-unsupported-deps option to allow builds
  with supported.conf problems.
* Thu Oct  9 2008 jdelvare@suse.de
- config/i386/*, config/x86_64/*, config/ia64/*, supported.conf:
  Build hwmon and thermal as modules.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark hdlc_ppp unsupported as syncppp is unsupported.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark ubifs as unsupported as it relies on mtd/ubi/
* Thu Oct  9 2008 bwalle@suse.de
- patches.arch/ppc-dynamic-reconfiguration.diff:
  powerpc: Add support for dynamic reconfiguration memory in
  kexec/kdump kernels (bnc#431492).
* Thu Oct  9 2008 carnold@novell.com
- rpm/kernel-binary.spec.in: package kernel-xen has dependency to
  xen (bnc#431215).
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark TPM drivers a supported, as IBM and others
  rely on them.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: fix a dependancy link with the isa sb driver with
  unsupported symbols
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark ieee80122 modules as supported, as other
  supported modules need them.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark all of the mtd drivers as unsupported to fix
  the build errors (and to reflect our policy here.)
* Thu Oct  9 2008 bwalle@suse.de
- Set CONFIG_KDB_CONTINUE_CATASTROPHIC to 0 (bnc#429910).
* Thu Oct  9 2008 jdelvare@suse.de
- Don't build the tps65010 driver, it's only used on OMAP at the
  moment.
* Thu Oct  9 2008 mmarek@suse.cz
- rpm/built-in-where: make it work with a four-column
  Modules.symvers (bnc#433533)
* Thu Oct  9 2008 bwalle@suse.de
- Update KDB to v4.4-2.6.27-rc8.
* Thu Oct  9 2008 olh@suse.de
- disable legacy iseries (bnc#433685 - LTC48946)
* Thu Oct  9 2008 olh@suse.de
- enable battery_pmu on ppc32
* Thu Oct  9 2008 trenn@suse.de
- supported.conf:
  Marked these unsupported:
  cpufreq-nforce2
  e_powersaver
  gx-suspmod
  longhaul
  longrun
  p4-clockmod
  powernow-k6
  powernow-k7
  speedstep-ich
  speedstep-smi
  Even Via CPUs are exporting cpu freq steps via ACPI and work fine
  with acpi-cpufreq. No need to support the old, some are known
  broken, drivers.
* Thu Oct  9 2008 olh@suse.de
- add patches.suse/md-raid-metadata-PAGE_SIZE.patch
  ignore PAGE_SIZE in md metadata, for raid0 (bnc#429490)
* Thu Oct  9 2008 teheo@suse.de
- patches.xen/xen3-auto-common.diff: minor patch apply fix after
  libata-prefer-over-ide.
* Wed Oct  8 2008 teheo@suse.de
- patches.drivers/libata-prefer-over-ide: libata: prefer libata
  drivers over ide ones (bnc#433105).
* Wed Oct  8 2008 carnold@novell.com
- patches.xen/xen-op-packet: add support for new operation type
  BLKIF_OP_PACKET (fate#300964).
- patches.xen/xen-blkfront-cdrom: implement forwarding of CD-ROM
  specific commands (fate#300964).
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: major update.  Lots of new drivers added as this
  file hadn't been updated for a lot of kernel revisions.
  This should close out a lot of bugs about "unsupported" modules,
  like bnc#433541.
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: sorted the file correctly so we can start determining
  what we are not supporting easier.
* Wed Oct  8 2008 jeffm@suse.de
- Updated -rt for context against -rc9 and the x2APIC patches:
  - patches.rt/new-softirq-code.patch
  - patches.rt/preempt-irqs-core.patch
  - patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch
  - CONFIG_INTR_REMAP=n for now
  - patches.rt/preempt-softirqs-core.patch
  - patches.rt/rt-slab-new.patch
  - patches.rt/slab-irq-nopreempt-fix.patch
  - Update config files: NFS_SWAP=n
* Wed Oct  8 2008 trenn@suse.de
  x2APIC and interrupt remapping enablement.
  Xen needs further work to build again.
  Commit ids are from x86 tip git tree:
- patches.arch/x2APIC_fix_section_mismatch.patch: Fix several
  section mismatches (none).
- patches.arch/x2APIC_PATCH_01_0f4896665a02b465ddca59a560983b24ec28c64b:
  dmar: fix dmar_parse_dev() devices_cnt error condition check
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_01_of_41_e61d98d8dad0048619bb138b0ff996422ffae53b:
  x64, x2apic/intr-remap: Intel vt-d, IOMMU code reorganization
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_02_228324076234ca6a8cd34be89be78022773459f1:
  dmar: use list_for_each_entry_safe() in dmar_dev_scope_init()
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_02_of_41_c42d9f32443397aed2d37d37df161392e6a5862f:
  x64, x2apic/intr-remap: fix the need for sequential array
  allocation of iommus (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_03_3f1fdb3673bb5638fa94186dc391cbc4879590bc:
  dmar: initialize the return value in dmar_parse_dev() (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_03_of_41_1886e8a90a580f3ad343f2065c84c1b9e1dac9ef:
  x64, x2apic/intr-remap: code re-structuring, to be used by both
  DMA and Interrupt remapping (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_04_f12c73e7fa7ebf9ad6defee2c4fb2664e743e970:
  dmar: fix using early fixmap mapping for DMAR table parsing
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_04_of_41_aaa9d1dd63bf89b62f4ea9f46de376ab1a3fbc6c:
  x64, x2apic/intr-remap: use CONFIG_DMAR for DMA-remapping
  specific code (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_05_7be42004065ce4df193aeef5befd26805267d0d9:
  x86, lguest: fix apic_ops build on UP (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_06_caf43bf7c6a55e89b6df5179df434d67e24aa32e:
  x86, xen: fix apic_ops build on UP (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_06_of_41_ad3ad3f6a2caebf56869b83b69e23eb9fa5e0ab6:
  x64, x2apic/intr-remap: parse ioapic scope under vt-d structures
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_07_511d9d34183662aada3890883e860b151d707e22:
  x86: apic_ops for lguest (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_07_of_41_cf1337f0447e5be8e66daa944f0ea3bcac2b6179:
  x64, x2apic/intr-remap: move IOMMU_WAIT_OP() macro to
  intel-iommu.h (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_08_of_41_fe962e90cb17a8426e144dee970e77ed789d98ee:
  x64, x2apic/intr-remap: Queued invalidation infrastructure
  (part of VT-d) (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_09_94a8c3c2437c8946f1b6c8e0b2c560a7db8ed3c6:
  x86: let 32bit use apic_ops too - fix (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_09_of_41_2ae21010694e56461a63bfc80e960090ce0a5ed9:
  x64, x2apic/intr-remap: Interrupt remapping infrastructure
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_10_of_41_b6fcb33ad6c05f152a672f7c96c1fab006527b80:
  x64, x2apic/intr-remap: routines managing Interrupt remapping
  table entries. (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_11_of_41_72b1e22dfcad1daca6906148fd956ffe404bb0bc:
  x64, x2apic/intr-remap: generic irq migration support from
  process context (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_12_of_41_d94d93ca5cc36cd78c532def62772c98fe8ba5d7:
  x64, x2apic/intr-remap: 8259 specific mask/unmask routines
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_13_of_41_4dc2f96cacd1e74c688f94348a3bfd0a980817d5:
  x64, x2apic/intr-remap: ioapic routines which deal with initial
  io-apic RTE setup (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_14_of_41_0c81c746f9bdbfaafe64322d540c8b7b59c27314:
  x64, x2apic/intr-remap: introduce read_apic_id() to genapic
  routines (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_15_of_41_2d7a66d02e11af9ab8e16c76d22767e622b4e3d7:
  x64, x2apic/intr-remap: Interrupt-remapping and x2apic support,
  fix (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_16_of_41_1b374e4d6f8b3eb2fcd034fcc24ea8ba1dfde7aa:
  x64, x2apic/intr-remap: basic apic ops support (fate #303948
  and fate #303984).
- patches.arch/x2APIC_PATCH_17_of_41_32e1d0a0651004f5fe47f85a2a5c725ad579a90c:
  x64, x2apic/intr-remap: cpuid bits for x2apic feature (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_18_of_41_1cb11583a6c4ceda7426eb36f7bf0419da8dfbc2:
  x64, x2apic/intr-remap: disable DMA-remapping if
  Interrupt-remapping is detected (temporary quirk) (fate #303948
  and fate #303984).
- patches.arch/x2APIC_PATCH_19_of_41_13c88fb58d0112d47f7839f24a755715c6218822:
  x64, x2apic/intr-remap: x2apic ops for x2apic mode support
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_20_of_41_cff73a6ffaed726780b001937d2a42efde553922:
  x64, x2apic/intr-remap: introcude self IPI to genapic routines
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_21_of_41_12a67cf6851871ca8df42025c94f140c303d0f7f:
  x64, x2apic/intr-remap: x2apic cluster mode support (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_22_of_41_5c520a6724e912a7e6153b7597192edad6752750:
  x64, x2apic/intr-remap: setup init_apic_ldr for UV (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_23_of_41_89027d35aa5b8f45ce0f7fa0911db85b46563da0:
  x64, x2apic/intr-remap: IO-APIC support for interrupt-remapping
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_24_of_41_75c46fa61bc5b4ccd20a168ff325c58771248fcd:
  x64, x2apic/intr-remap: MSI and MSI-X support for interrupt
  remapping infrastructure (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_25_1_of_41_4c9961d56ec20c27ec5d02e49fd7427748312741:
  x86: make read_apic_id return final apicid (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_25_2_of_41_c535b6a1a685eb23f96e2c221777d6c1e05080d5:
  x86: let 32bit use apic_ops too (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_25_of_41_6e1cb38a2aef7680975e71f23de187859ee8b158:
  x64, x2apic/intr-remap: add x2apic support, including enabling
  interrupt-remapping (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_26_of_41_2d9579a124d746a3e0e0ba45e57d80800ee80807:
  x64, x2apic/intr-remap: support for x2apic physical mode support
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_27_of_41_9fa8c481b55e80edd8c637573f87853bb6b600f5:
  x64, x2apic/intr-remap: introduce CONFIG_INTR_REMAP (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_28_1_of_41_f910a9dc7c865896815e2a95fe33363e9522f277:
  x86: make 64bit have get_apic_id (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_29_of_41_277d1f5846d84e16760131a93b7a67ebfa8eded4:
  x2apic: uninline uv_init_apic_ldr() (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_30_of_41_ad66dd340f561bdde2285992314d9e4fd9b6191e:
  x2apic: xen64 paravirt basic apic ops (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_34_of_41_1b9b89e7f163336ad84200b66a17284dbf26aced:
  x86: add apic probe for genapic 64bit, v2 (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_35_of_41_d25ae38b7e005af03843833bbd811ffe8c5f8cb4:
  x86: add apic probe for genapic 64bit - fix (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_36_of_41_276605dddb74cbf1b77696e32c4a947e42cec52d:
  x2apic: use x2apic id reported by cpuid during topology
  discovery (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4:
  x86: use cpuid vector 0xb when available for detecting cpu
  topology (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_41_of_41_11c231a962c740b3216eb6565149ae5a7944cba7:
  x86: use x2apic id reported by cpuid during topology discovery,
  fix (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_42_of_41_77322deb4bc676a5ee645444e7ed1a89f854473d:
  x86: io-apic - interrupt remapping fix (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_43_of_41_2c72d93f6593f386f5760ca8e7ac7026948c31d7:
  x2apic: fix reserved APIC register accesses in
  print_local_APIC() (fate #303948 and fate #303984).
- patches.drivers/sgi-uv-led: SGI UV: Provide a LED driver and
  some System Activity Indicators (FATE#304268).
- patches.suse/kdb-x86: kdb-v4.4-2.6.27-rc5-x86-1 (FATE#303971).
- patches.xen/xen-x86-no-lapic: Disallow all accesses to the
  local APIC page (191115).
- patches.xen/xen3-auto-arch-x86.diff: xen3 arch-x86.
- patches.xen/xen3-patch-2.6.19: Linux 2.6.19.
- patches.xen/xen3-patch-2.6.26: 2.6.26.
- Update config files:
  Added CONFIG_INTR_REMAP to all x86_64 flavors
* Wed Oct  8 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: added Obsoletes: atl2-kmp as this
  driver is now included in the kernel package.
* Wed Oct  8 2008 jjolly@suse.de
- patches.arch/s390-01-04-fcpperf-4-v2.patch: Update for fcpperf-4
  patch to bring in sync with upstream version. (bnc#417243)
- patches.arch/s390-01-04-fcpperf-4.patch: Removed, replaced by
  updated patch
* Wed Oct  8 2008 sjayaraman@suse.de
- Remove stale swap-over-nfs patches.
- patches.suse/SoN-05-page_alloc-reserve.patch: Delete.
- patches.suse/SoN-06-reserve-slub.patch: Delete.
* Wed Oct  8 2008 agruen@suse.de
- No uml patches left, so remove the code referring to
  patches.uml.tar.bz2.
* Wed Oct  8 2008 ghaskins@suse.de
  Guarded by +RT
- patches.rt/fix-up-comment.patch: RT: Remove comment that is
  no longer true.
- patches.rt/check-for-migration-during-push.patch: RT: fix
  push_rt_task() to handle dequeue_pushable properly.
* Wed Oct  8 2008 agruen@suse.de
- Add DMAPI patches (supported by SGI).
- Update config files: enable DMAPI.
* Wed Oct  8 2008 sjayaraman@suse.de
- Doh, forgot to remove stale files from cvs
- Update config files NFS_SWAP=y.
* Wed Oct  8 2008 sjayaraman@suse.de
- Refreshed to -v19 of swap over nfs patchset.
  o netns, ipv6 fixes
  o patch ordering changes due to additional patches
- Adjust patches.xen/xen3-auto-common.diff to avoid conflict.
* Wed Oct  8 2008 bwalle@suse.de
- Enable CONFIG_MFD_SM501_GPIO also for RT.
* Wed Oct  8 2008 bwalle@suse.de
- Refresh patches.rt/mips-remove-duplicate-kconfig.patch.
* Wed Oct  8 2008 bwalle@suse.de
- Update to 2.6.27-rc9.
- Enable new configuration option CONFIG_MFD_SM501_GPIO.
- Drop following patches (mainline):
  o patches.suse/e1000e_debug_contention_on_NVM_SWFLAG
  o patches.suse/e1000e_do_not_ever_sleep_in_interrupt_context
  o patches.suse/e1000e_drop_stats_lock, e1000e_fix_lockdep_issues
  o patches.suse/e1000e_mmap_range_chk,
  o patches.suse/e1000e_reset_swflag_after_resetting_hardware
  o patches.suse/e1000e_update_versione1000e_write_protect_ichx_nvm
- Adjust/refresh following patches:
  o patches.arch/s390-01-03-cmm2-v2.patch
  o patches.drivers/e1000e_add_82574L.patch
  o patches.drivers/e1000e_add_ICH9_BM.patch
  o patches.drivers/e1000e_add_LOM_devices.patch
  o patches.suse/e1000e_allow_bad_checksum
  o patches.suse/e1000e_call_dump_eeprom
  o patches.suse/e1000e_ioremap_sanity_check
  o patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory
* Wed Oct  8 2008 mmarek@suse.cz
- rpm/kernel-module-subpackage: switch KMPs to the new
  weak-modules2 script, which handles running depmod and mkinitrd
* Wed Oct  8 2008 hare@suse.de
- supported.conf: mark igb as supported.
* Wed Oct  8 2008 agruen@suse.de
- kernel-source-rt must not provide a kernel-source symbol: this
  would break dependencies.
* Wed Oct  8 2008 olh@suse.de
- update patches.suse/ppc-no-LDFLAGS_MODULE.patch
  use suggested patch from kernel.org bugzilla
* Wed Oct  8 2008 olh@suse.de
- add patches.arch/ppc-pseries_remove_lmb-PAGE_SHIFTT.patch
  fix oops in pseries_remove_lmb with 64k PAGE_SIZE (bnc#431380)
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: mark efivars.ko as supported
* Wed Oct  8 2008 gregkh@suse.de
- enable yealink driver (bnc#432841)
* Tue Oct  7 2008 oneukum@suse.de
- patches.fixes/ehci_sched.diff: fix hang in disable_periodic
  (bnc#403346).
* Tue Oct  7 2008 trenn@suse.de
- patches.fixes/fujisu_laptop_fix_section_mismatch.patch: Fix
  section mismatch in fujitsu_laptop driver (none).
* Tue Oct  7 2008 hare@suse.de
- patches.fixes/sd-needs-updating: Driver 'sd' needs updating
  (bnc#406656).
* Tue Oct  7 2008 agruen@suse.de
- rpm/post.sh: Catch mkinitrd error code indicating missing
  required modules. Only add a bootloader entry if an initrd
  could be created, but re-add the bootloader entry even if
  the initrd already existed before (bnc#431703).
* Tue Oct  7 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.4-update: Update lpfc to 8.2.8.4
  (bnc#420767).
- patches.drivers/qla4xxx-sles11-update: qla4xxx driver fixes
  for SLES11 (bnc#432976).
* Tue Oct  7 2008 olh@suse.de
- mark legacy iseries storage as supported
* Mon Oct  6 2008 jdelvare@suse.de
- supported.conf: Add the ad7414, adcxx and ibmaem hwmon drivers as
  unsupported.
* Mon Oct  6 2008 jdelvare@suse.de
- config/ia64/*: Don't built i2c-amd756-s4882 and i2c-nforce2-s4985
  on ia64, these are motherboard-specific drivers for x86_64
  motherboards.
- config/powerpc/*: Don't built i2c-isch on powerpc, it is a driver
  for x86 hardware.
- config/*: Don't built i2c-simtec on i386, x86_64 and ia64, there
  is no Simtec hardware based on these architectures.
* Sun Oct  5 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: Fix the logic splitting up the symbols
  defined in vmlinux by subsystem. (Actually, per directory, under
  the assumption that there is enough of a correlation).
* Sun Oct  5 2008 greg@suse.de
- supported.conf: add ohci-hcd to base.  Fix up other USB drivers
  (USB network drivers had moved, others were missing)
* Sun Oct  5 2008 gregkh@suse.de
- patches.drivers/atl2-add-atl2-network-driver.patch: atl2:
  add atl2 network driver.
- Update config files (even the rt ones).
* Fri Oct  3 2008 jkosina@suse.de
- patches.suse/e1000e_debug_contention_on_NVM_SWFLAG: fix bogus
  WARN_ON() condition, as per upstream commit 95b866d5a
* Fri Oct  3 2008 olh@suse.de
- mark ibmvfc as supported (bnc#417555 - fate#304178 - LTC46935)
* Fri Oct  3 2008 olh@suse.de
- compile windfarm_pm121 into the kernel
* Fri Oct  3 2008 jeffm@suse.de
- doc/README.SUSE, scripts/tar-up_and_run_mbuild.sh,
  scripts/run_oldconfig.sh,
  scripts/sequence-patch.sh: Eliminated defconfig.$flavor
* Fri Oct  3 2008 olh@suse.de
- mark Cell drivers as supported
* Fri Oct  3 2008 tonyj@suse.de
- Update config files
  rt configs not updated for per-module-dynamic-debug-messages.patch
* Fri Oct  3 2008 gregkh@suse.de
- change patches.suse/supported-flag to show which modules are
  unsupported and externally supported in oops messages.  Also change
  the taint values as the documentation was totally wrong.
* Fri Oct  3 2008 tonyj@suse.de
- Reenable RT debug builds, compile tested only
- Update config files
- Fix tracer issues
  patches.rt/event-trace-hrtimer-trace.patch
  patches.rt/trace-events-handle-syscalls.patch
  patches.rt/trace-ktime-scalar.patch
  patches.rt/tracer-event-trace.patch
- patches.rt/kdb-disable-ist.patch: Disable stackfault and debug stacks for kdb
- patches.rt/kdb-rtmisc.patch: Misc KDB fixes for RT
- patches.rt/novfs-rtmisc.patch: Misc NOVFS fixes for RT
* Fri Oct  3 2008 gregkh@suse.de
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  driver core: basic infrastructure for per-module dynamic
  debug messages.
- refresh patches.trace/tracepoints.patch: Kernel Tracepoints.
- Update config files.
* Thu Oct  2 2008 agruen@suse.de
- Introduce kernel-source-rt and kernel-syms-rt packages, needed
  for building real-time KMPs.
* Thu Oct  2 2008 schwab@suse.de
- Don't clean <asm/nr-irqs.h>.
* Thu Oct  2 2008 jblunck@suse.de
- supported.conf: add qeth_l2 and qeth_l3 as supported modules
* Thu Oct  2 2008 jkosina@suse.de
- patches.suse/e1000e_write_protect_ichx_nvm: e1000e: update to
  the latest version of the patch as provided by Intel
* Thu Oct  2 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc8 and c/s 684.
- patches.xen/xen-e1000e_Export_set_memory_ro-rw: Replace by ...
- patches.xen/xen3-e1000e_Export_set_memory_ro-rw: this, and put
  in proper place in series.conf.
- patches.xen/xen-rwlocks-enable-interrupts: Replace by ...
- patches.xen/xen3-rwlocks-enable-interrupts: this, and put in
  proper place in series.conf.
* Wed Oct  1 2008 jeffm@suse.de
- scripts/sequence-patch.sh
- scripts/run_oldconfig.sh: x86 defconfigs go under arch/x86.
* Wed Oct  1 2008 olh@suse.de
- enable msi on ppc64 (bnc#430937)
* Wed Oct  1 2008 tiwai@suse.de
- rpm/kernel-source.spec.in: Remove /lib/modules from file list
  as it's already in filesystem
* Wed Oct  1 2008 tiwai@suse.de
- rpm/kernel-source.spec.in: Fixed missing endif
* Wed Oct  1 2008 tiwai@suse.de
- Update config files: make floppy module on i386, too
* Wed Oct  1 2008 tiwai@suse.de
- supported.conf: update sound drivers
* Wed Oct  1 2008 tonyj@suse.de
- update RT to 2.6.27-rc8
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
* Wed Oct  1 2008 agruen@suse.de
- Update -rt config files.
* Tue Sep 30 2008 gregkh@suse.de
- update to 2.6.27-rc8
  - obsoletes these patches:
  - patches.arch/ia64-kdump_proc_iomem.diff
  - patches.drivers/qla2xxx-defer-risc-interrupt-enablement
  - patches.fixes/usb-hcd-interrupt-shared.patch
* Tue Sep 30 2008 jkosina@suse.de
- additional patches to track down and fix e1000e NVM corruption
- patches.suse/e1000e_ioremap_sanity_check: ioremap sanity check
  to catch mapping requests exceeding the BAR sizes (bnc#425480).
- patches.suse/e1000e_write_protect_ichx_nvm: e1000e: write
  protect ICHx NVM to prevent malicious write/erase (bnc#425480).
* Tue Sep 30 2008 hare@suse.de
- Update config files.
* Tue Sep 30 2008 hare@suse.de
- patches.drivers/mpt-fusion-4.00.43.00-update: Update MPT Fusion
  driver to v4.00.43.00 (bnc#425660).
- patches.kernel.org/gdth-section-conflict: Add missing annotations.
* Tue Sep 30 2008 sassmann@suse.de
- Update config files: Disabled everything unnecessary in
  ps3 config file
* Tue Sep 30 2008 olh@suse.de
- disable ninja32 and ns87415 pata drivers on ppc64
* Tue Sep 30 2008 sdietrich@suse.de
- config.conf: enable rt for i386/x86_64
- Update config files: Preliminary sync with default and debug configs.
- config/x86_64/rt_timing: Delete.
- patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT radix-tree: gang slot lookups.
- patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT mm: lockless probe.
- patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: speculative get page.
- patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: lockless pagecache lookups.
- patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: spinlock tree_lock.
- patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/RT_utsname.patch: Linux-RT 2.6.27-RT.
- patches.rt/aacraid-compat-sem.patch: Linux-RT 2.6.27-RT.
- patches.rt/adapt-remove-extra-try-to-lock.patch: Linux-RT
  2.6.27-RT.
- patches.rt/adaptive-adjust-pi-wakeup.patch: Linux-RT 2.6.27-RT.
- patches.rt/adaptive-earlybreak-on-steal.patch: Linux-RT
  2.6.27-RT
  rtmutex: break out early on first run.
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch: Linux-RT
  2.6.27-RT.
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.27-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-compile-fix.patch: Linux-RT 2.6.27-RT
  ARM: compile fix for event tracing.
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-latency-tracer-support.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-omap-02.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-05.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-preempt-config.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-trace-preempt-idle.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/cache_pci_find_capability.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT Cache calls to pci_find_capability.
- patches.rt/call_rcu_bh-rename-of-call_rcu.patch: Linux-RT
  2.6.27-RT
  just rename call_rcu_bh instead of making it a macro.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.27-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.27-RT.
- patches.rt/cycles-to-ns-trace-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-irqpoll.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-lpptest-on-nonlinux.patch: Linux-RT
  2.6.27-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.27-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.27-RT.
- patches.rt/dont-let-rt-rw_semaphores-do-non_owner-locks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.27-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.27-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.27-RT
  event-tracer: add clockevent trace.
- patches.rt/export-schedule-on-each-cpu.patch: Linux-RT
  2.6.27-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-a-previously-reverted-fix.patch: Linux-RT
  2.6.27-RT
  Fix a previously reverted "fix".
- patches.rt/fix-adaptive-hack.patch: Linux-RT 2.6.27-RT
  fix-adaptive-hack.patch.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.27-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-circular-locking-deadlock.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.27-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/fix-emac-locking-2.6.16.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/fix-emergency-reboot.patch: Linux-RT 2.6.27-RT
  call reboot notifier list when doing an emergency reboot.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch: Linux-RT 2.6.27-RT.
- patches.rt/floppy-resume-fix.patch: Linux-RT 2.6.27-RT
  floppy: suspend/resume fix.
- patches.rt/frace-use-tsc.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-compile-fixes.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT rt: remove call to stop tracer.
- patches.rt/ftrace-document-event-tracer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ftrace-document-update1.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: document updates.
- patches.rt/ftrace-dont-trace-markers.patch: Linux-RT 2.6.27-RT
  ftrace: dont trace markers.
- patches.rt/ftrace-fix-get-kprobe-wreckage.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT ftrace-fix-missing-kprobe-include.pathc.
- patches.rt/ftrace-fix-header.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-function-record-nop.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: define function trace nop.
- patches.rt/ftrace-hotplug-fix.patch: Linux-RT 2.6.27-RT
  ftrace: cpu hotplug fix.
- patches.rt/ftrace-m68knommu-add-FTRACE-support.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ftrace-m68knommu-generic-stacktrace-function.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ftrace-preempt-trace-check.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: only trace preempt off with
  preempt tracer.
- patches.rt/ftrace-print-missing-cmdline.patch: Linux-RT
  2.6.27-RT
  ftrace: fix the command line printing.
- patches.rt/ftrace-record-comm-on-ctrl.patch: Linux-RT 2.6.27-RT
  ftrace: record comm on function ctrl change.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.27-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/ftrace-trace-sched.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: trace sched.c.
- patches.rt/ftrace-use-preempt-disable-not-irq-disable.patch:
  Linux-RT 2.6.27-RT
  ftrace: avoid lockdep recursion.
- patches.rt/ftrace-wakeup-rawspinlock.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: user raw spin lock for wakeup
  function trace.
- patches.rt/generic-cmpxchg-use-raw-local-irq-variant.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.27-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/git-ignore-script-lpp.patch: Linux-RT 2.6.27-RT.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.27-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/hack-fix-rt-migration.patch: Linux-RT 2.6.27-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.27-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem-redo-mainline.patch: Linux-RT 2.6.27-RT.
- patches.rt/highmem-revert-mainline.patch: Linux-RT 2.6.27-RT.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.27-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.27-RT.
- patches.rt/i386-mark-atomic-irq-ops-raw.patch: Linux-RT
  2.6.27-RT.
- patches.rt/i386-nmi-watchdog-show-regs.patch: Linux-RT
  2.6.27-RT.
- patches.rt/idle-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/idle2-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/irda-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/irq-mask-fix.patch: Linux-RT 2.6.27-RT
  genirq: fix simple and fasteoi irq handlers.
- patches.rt/jbd_assertions_smp_only.patch: Linux-RT 2.6.27-RT.
- patches.rt/kmap-atomic-i386-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/kmap-atomic-prepare.patch: Linux-RT 2.6.27-RT.
- patches.rt/kprobes-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.27-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/latency-measurement-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/latency-tracing-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/latency-tracing-ppc.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.27-RT.
- patches.rt/local_irq_save_nort-in-swap.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lock-init-plist-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/lock_list.patch: Linux-RT 2.6.27-RT
  lock_list - a fine grain locked double linked list.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.27-RT
  mm: lock_page_ref.
- patches.rt/lockdep-avoid-fork-waring.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: fix if define to prove locking.
- patches.rt/lockdep-lock_set_subclass.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT lockdep: lock_set_subclass - reset a held
  lock's subclass.
- patches.rt/lockdep-more-entries.patch: Linux-RT 2.6.27-RT.
- patches.rt/lockdep-prettify.patch: Linux-RT 2.6.27-RT
  lockdep: prettify output.
- patches.rt/lockdep-rt-mutex.patch: Linux-RT 2.6.27-RT
  lockdep-rt: annotate PREEMPT_RT DEFINE_MUTEX.
- patches.rt/lockdep-rt-recursion-limit-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.27-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/lockdep_lock_set_subclass_fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockstat-fix-contention-points.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT lockstat: fix contention points.
- patches.rt/lockstat-output.patch: Linux-RT 2.6.27-RT
  lockstat: warn about disabled lock debugging.
- patches.rt/lockstat-rt-hooks.patch: Linux-RT 2.6.27-RT.
- patches.rt/lockstat_bounce_rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/loopback-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/m68knommu-make-cmpxchg-RT-safe.patch: Linux-RT
  2.6.27-RT.
- patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/mapping_nrpages-fix.patch: Linux-RT 2.6.27-RT
  mapping_nrpages-fix.patch.
- patches.rt/mapping_nrpages.patch: Linux-RT 2.6.27-RT
  mm/fs: abstract address_space::nrpages.
- patches.rt/mips-change-raw-spinlock-type.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT RT: change from raw_spinlock_t to
  __raw_spinlock_t.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Linux-RT 2.6.27-RT
  RT: remove conflicting rtc_lock declaration.
- patches.rt/mips-remove-duplicate-kconfig.patch: Linux-RT
  2.6.27-RT.
- patches.rt/mips-remove-finish-arch-switch.patch: Linux-RT
  2.6.27-RT
  RT: remove finish_arch_switch.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/mm-concurrent-pagecache-rt.patch: Linux-RT 2.6.27-RT
  mm: -rt bits for concurrent pagecache.
- patches.rt/mm-concurrent-pagecache.patch: Linux-RT 2.6.27-RT
  mm: concurrent pagecache write side.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.27-RT
  reduce pagetable-freeing latencies.
- patches.rt/move-native-irq.patch: Linux-RT 2.6.27-RT.
- patches.rt/msi-suspend-resume-workaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.27-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.27-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.27-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.27-RT
  read lock Priority Inheritance implementation.
- patches.rt/native-sched-clock-booboo.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.27-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/netpoll-8139too-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.27-RT
  softirq preemption: optimization.
- patches.rt/nf_conntrack-fix-smp-processor-id.patch: Linux-RT
  2.6.27-RT.
- patches.rt/nf_conntrack-weird-crash-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/nfs-stats-miss-preemption.patch: Linux-RT 2.6.27-RT
  nfs: fix missing preemption check.
- patches.rt/nmi-profiling.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-show-regs-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-disable.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT x86_64: do not enable the NMI watchdog
  by default.
- patches.rt/nmi-watchdog-fix-1.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-2.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-fix-3.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-fix-4.patch: Linux-RT 2.6.27-RT.
- patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT local_bh_enable() is safe for
  irqs_disabled().
- patches.rt/ntfs-local-irq-save-nort.patch: Linux-RT 2.6.27-RT.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.27-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.27-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.27-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.27-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/percpu-locked-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-netfilter.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-netfilter2.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-powerpc-fixups.patch: Linux-RT
  2.6.27-RT.
- patches.rt/percpu_list.patch: Linux-RT 2.6.27-RT
  percpu_list.
- patches.rt/plist-debug.patch: Linux-RT 2.6.27-RT.
- patches.rt/pmtmr-override.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT pmtmr: allow command line override of
  ioport.
- patches.rt/posix-cpu-timers-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-flush_tlb_pending-is-no-more.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-ftrace-stop-on-oops.patch: Linux-RT 2.6.27-RT
  powerpc: ftrace stop on crash.
- patches.rt/powerpc-match-__rw_yield-function-declaration-to-prototype.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-chpr-set-rtc-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-gtod-notrace-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-make-tlb-batch-64-only.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-tlbflush-preempt.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc32-latency-compile-hack-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ppc32_notrace_init_functions.patch: Linux-RT
  2.6.27-RT
  don't trace early init functions for ppc32.
- patches.rt/ppc64-fix-preempt-unsafe-paths-accessing-per_cpu-variables.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-Kconfig.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-idle-poll-loop-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-m68knommu-make-timer-interrupt-non-threaded.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-ack-irq-fixups.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-b5.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-b6.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-more-fasteoi.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-ppc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-bagde4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-footbridge.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-integrator.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-pxa.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-shark.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-compile-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ftrace.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ide.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-input.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-loopback.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mellanox-driver-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.27-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-add-raw-relax-macros.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b2.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b3.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-celleb-raw-spinlocks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-missing-raw-spinlocks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-tlb-batching.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.27-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-profiling.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rcu.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sched-cpupri.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-sched-i386.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sound.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-supress-nohz-softirq-warning.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-supress-rtc-printk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-usb.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-warn-and-bug-on-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-warn-and-bug-on.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-dont-bug-on-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-in-atomic-hack-fix.patch: Linux-RT 2.6.27-RT
  fix printk in atomic hack.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.27-RT.
- patches.rt/proportions-raw-locks.patch: Linux-RT 2.6.27-RT.
- patches.rt/qrcu.patch: Linux-RT 2.6.27-RT
  QRCU with lockless fastpath.
- patches.rt/quicklist-release-before-free-page-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/quicklist-release-before-free-page.patch: Linux-RT
  2.6.27-RT.
- patches.rt/radix-concurrent-lockdep.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-percpu-hack-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.27-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-lockdep-plus1.patch: Linux-RT 2.6.27-RT
  lockdep: add +1 to radix tree array.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.27-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.27-RT
  radix-tree: optimistic locking.
- patches.rt/raw-spinlocks-for-nmi-print.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rcu-hrt-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-new-7.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-default.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-fix-bad-dyntick-accounting.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rcu-torture-preempt-update.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-trace-fix-free.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcupreempt-boost-early-init.patch: Linux-RT
  2.6.27-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.27-RT.
- patches.rt/relay-fix.patch: Linux-RT 2.6.27-RT
  relay: fix timer madness.
- patches.rt/remove-check-pgt-cache-calls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/replace-bugon-by-warn-on.patch: Linux-RT 2.6.27-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-apis.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-avoid-deadlock-in-swap.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-delayed-prio.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: propagate prio for delayed work.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-list-mods.patch: Linux-RT 2.6.27-RT
  rt: list_splice2.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.27-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-irq-flags-checking.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-namespace.patch: Linux-RT 2.6.27-RT
  rt-mutex-namespace.patch.
- patches.rt/rt-mutex-ppc-fix-a5.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-ppc.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-use-inline.patch: Linux-RT 2.6.27-RT
  rt-mutex-cleanup.patch.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-plist-mods.patch: Linux-RT 2.6.27-RT
  rt: plist_head_splice.
- patches.rt/rt-rwlock-conservative-locking.patch: Linux-RT
  2.6.27-RT
  rwlock: be more conservative in locking reader_lock_count.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-sched-groups.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-workqeue-prio.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue support.
- patches.rt/rt-workqueue-barrier.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: fix barriers.
- patches.rt/rt-wq-barrier-fix.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: wait_on_work() fixup.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.27-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/rtmutex-debug-fix.patch: Linux-RT 2.6.27-RT
  rtmutex-debug-fix.patch.
- patches.rt/rtmutex-debug.h-cleanup.patch: Linux-RT 2.6.27-RT
  lock debugging: clean up rtmutex-debug.h.
- patches.rt/rtmutex-lateral-steal.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-rearrange.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-remove-xchg.patch: Linux-RT 2.6.27-RT
  rtmutex - remove double xchg.
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-fixes.patch: Linux-RT 2.6.27-RT
  rwlock: fix pi_list race conditions.
- patches.rt/rwlock-implement-downgrade-write.patch: Linux-RT
  2.6.27-RT
  rwlocks multi downgrade write.
- patches.rt/rwlock-pi-lock-reader.patch: Linux-RT 2.6.27-RT.
- patches.rt/rwlock-prio-fix.patch: Linux-RT 2.6.27-RT
  rwlock: reset prio on unlocks and wakeups.
- patches.rt/rwlock-protect-reader_lock_count.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-slowunlock-mutex-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-slowunlock-mutex-fix2.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-torture-no-rt.patch: Linux-RT 2.6.27-RT
  rwlock: fix torture test to handle non-rt.
- patches.rt/rwlock-torture.patch: Linux-RT 2.6.27-RT
  rwlock: rwlock torture test.
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlocks-fix-no-preempt-rt.patch: Linux-RT 2.6.27-RT
  rwlock: fix non PREEMPT_RT case.
- patches.rt/rwlocks-multiple-readers.patch: Linux-RT 2.6.27-RT
  implement rwlocks management.
- patches.rt/rwsems-multiple-readers.patch: Linux-RT 2.6.27-RT
  add framework for multi readers on rwsems.
- patches.rt/s_files-pipe-fix.patch: Linux-RT 2.6.27-RT
  s_files: free_write_pipe() fix.
- patches.rt/s_files-schedule_on_each_cpu_wq.patch: Linux-RT
  2.6.27-RT.
- patches.rt/s_files.patch: Linux-RT 2.6.27-RT
  remove global files_lock.
- patches.rt/sched-clock-nmi.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-cpupri-hotplug-support.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-cpupri-priocount.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.27-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.27-RT
  sched-fix-dequeued-race.patch.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-rt-stats.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched_prio.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched_rt-fixup.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/schedule-tail-balance-disable-irqs.patch: Linux-RT
  2.6.27-RT.
- patches.rt/schedule_on_each_cpu-enhance.patch: Linux-RT
  2.6.27-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/send-nmi-all-preempt-disable.patch: Linux-RT
  2.6.27-RT.
- patches.rt/seq-irqsave.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.27-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/softlockup-add-irq-regs-h.patch: Linux-RT 2.6.27-RT
  core: make asm/irq_regs.h available on every platform.
- patches.rt/spinlock-trylock-cleanup-sungem.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.27-RT
  rt: dont disable irqs in usb.
- patches.rt/swap-spinlock-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-add-event-markers-arm.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-do-not-wakeup-when-irqs-disabled.patch:
  Linux-RT 2.6.27-RT
  trace-do-not-wakeup-when-irqs-disabled.patch.
- patches.rt/trace-eip2ip.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT Re: 2.6.25.4-rt4.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-ktime-scalar.patch: Linux-RT 2.6.27-RT
  ftrace: print ktime values in readable form.
- patches.rt/trace_hist-divzero.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT trace_hist.c: divide-by-zero problem (2).
- patches.rt/trace_hist-latediv.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracer-event-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/use-edge-triggered-irq-handler-instead-of-simple-irq.patch:
  Linux-RT 2.6.27-RT
  [AT91: PATCH]: Use edge triggered interrupt handling for
  AT91-GPIO instead of simple_irq-handler.
- patches.rt/user-no-irq-disable.patch: Linux-RT 2.6.27-RT.
- patches.rt/vortex-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/warn-on-rt-scatterlist.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT remove warn on for scatterlist in preempt
  rt.
- patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/x86-64-tscless-vgettimeofday.patch: Linux-RT
  2.6.27-RT
  x86_64 GTOD: offer scalable vgettimeofday.
- patches.rt/x86_64-tsc-sync-irqflags-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/26-rt1-chirag.patch: Linux-RT 2.6.27-RT
  This patch should solve some of the bug messages..
- patches.rt/add-generalized-pi-interface.patch: Linux-RT
  2.6.27-RT
  add generalized priority-inheritance interface.
- patches.rt/rtmutex-add_readers.patch: Linux-RT 2.6.27-RT
  RT: wrap the rt_rwlock "add reader" logic.
- patches.rt/rtmutex-defer-pi-until-sleepy.patch: Linux-RT
  2.6.27-RT
  rtmutex: pi-boost locks as late as possible.
- patches.rt/rtmutex-initialize-waiters.patch: Linux-RT 2.6.27-RT
  rtmutex: formally initialize the rt_mutex_waiters.
- patches.rt/rtmutex-use-runtime-init.patch: Linux-RT 2.6.27-RT
  rtmutex: use runtime init for rtmutexes.
- patches.rt/tie-pi-into-task.patch: Linux-RT 2.6.27-RT
  sched: add the basic PI infrastructure to the task_struct.
- patches.rt/rtmutex-convert-to-libpi.patch: Linux-RT 2.6.27-RT
  rtmutex: convert rtmutexes to fully use the PI library.
- patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch:
  Linux-RT 2.6.27-RT
  ftrace: fix elevated preempt_count in wakeup-tracer.
- patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch:
  Linux-RT 2.6.27-RT
  seqlock: make sure that raw_seqlock_t retries readers while
  writes are pending.
- patches.rt/event-tracer-syscall-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-acpi-build-weirdness.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/ftrace-upstream.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/gcc-warnings-shut-up.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.27-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-preempt-schedule-irq-entry-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/random-driver-latency-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-page_alloc.patch: Linux-RT 2.6.27-RT
  rt-friendly per-cpu pages.
- patches.rt/rt-slab-new.patch: Linux-RT 2.6.27-RT.
- patches.rt/bit-spinlocks-fix-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/compat_rwsem-fix-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/drivers_base_mutex.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-net-bug-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-ppc-define-mcount.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-report-failure.patch: Linux-RT 2.6.27-RT
  ftrace: warn on failure to disable mcount callers.
- patches.rt/ftrace-upstream-temp.patch: Linux-RT 2.6.27-RT.
- patches.rt/futex-fifo-warn-sysctl.patch: Linux-RT 2.6.27-RT.
- patches.rt/futex-trivial-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockdep-atomic-fixup.patch: Linux-RT 2.6.27-RT.
- patches.rt/namespace-lock-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-prof-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/plist-fix-static-node-init.patch: Linux-RT 2.6.27-RT.
- patches.rt/powerpc-01-separate-the-irq-radix-tree-insertion.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-02-make-the-irq-reverse-mapping-radix-tree-lockless.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-fix-prev-revert-fix-again.patch: Linux-RT
  2.6.27-RT.
- patches.rt/prof-sysctl-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-apply-rcu_process_callbacks-from-mainline.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-tracing-preempt-disable-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rt-wq-flush_work.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-debug-magic.patch: Linux-RT 2.6.27-RT
  rtmutex: check integrity.
- patches.rt/sched-add-needs_post_schedule.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-generic-hide-smp-warning.patch: Linux-RT
  2.6.27-RT
  suppress warning of smp_processor_id use..
- patches.rt/sched-make-double-lock-balance-fair.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-only-push-if-pushable.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-only-push-once-per-queue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-properly-account-irq-and-rt-load.patch:
  Linux-RT 2.6.27-RT
  sched: properly account IRQ and RT load in .
- patches.rt/sched-rt-runtime-lock-raw.patch: Linux-RT 2.6.27-RT.
- patches.rt/seqlock-01-make-sure-that-raw_seqlock-retries.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/seqlock-02-fix-elevated-preempt-count.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/seqlock-serialize-against-writers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/seqlocks-handle-rwlock-and-spin.patch: Linux-RT
  2.6.27-RT
  seqlock - fix for both PREEMPT_RT and non PREEMPT_RT.
- patches.rt/shorten-posix-cpu-timers-name.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sysctl-compile-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracepoint-backport.patch: Linux-RT 2.6.27-RT.
- patches.rt/x86-tlbstate-lock-raw.patch: Linux-RT 2.6.27-RT.
* Tue Sep 30 2008 olh@suse.de
- enable ipmi message handler on ppc64 (bnc#430705)
* Tue Sep 30 2008 olh@suse.de
- create flavor symlinks unconditionally
  they do not depend on presence of modules
* Mon Sep 29 2008 agruen@suse.de
- Update config files after Swap-over-NFS backout.
* Mon Sep 29 2008 agruen@suse.de
- kernel-vanilla and kernel-p3 are not split into main, -base, and
  - extra packages. Fix the bogus dependencies on those packages.
* Mon Sep 29 2008 jkosina@suse.de
- disabled the following Swap-over-NFS patches, as they cause panic
  in IPv6 code:
  - patches.suse/SoN-01-mm-gfp-to-alloc_flags.patch: mm:
    gfp_to_alloc_flags() (FATE#303834).
  - patches.suse/SoN-02-mm-setup_per_zone_pages_min.patch: mm:
    serialize access to min_free_kbytes (FATE#303834).
  - patches.suse/SoN-03-doc.patch: swap over network documentation
    (FATE#303834).
  - patches.suse/SoN-04-mm-gfp-to-alloc_flags-expose.patch: mm:
    expose gfp_to_alloc_flags() (FATE#303834).
  - patches.suse/SoN-05-page_alloc-reserve.patch: mm: tag reseve
    pages (FATE#303834).
  - patches.suse/SoN-06-reserve-slub.patch: mm: slb: add knowledge
    of reserve pages (FATE#303834).
  - patches.suse/SoN-07-mm-kmem_estimate_pages.patch: mm:
    kmem_alloc_estimate() (FATE#303834).
  - patches.suse/SoN-08-mm-PF_MEMALLOC-softirq.patch: mm: allow
    PF_MEMALLOC from softirq context (FATE#303834).
  - patches.suse/SoN-09-mm-page_alloc-emerg.patch: mm: emergency
    pool (FATE#303834).
  - patches.suse/SoN-10-global-ALLOC_NO_WATERMARKS.patch: mm:
    system wide ALLOC_NO_WATERMARK (FATE#303834).
  - patches.suse/SoN-11-mm-page_alloc-GFP_EMERGENCY.patch: mm:
    __GFP_MEMALLOC (FATE#303834).
  - patches.suse/SoN-12-mm-reserve.patch: mm: memory reserve
    management (FATE#303834).
  - patches.suse/SoN-13-mm-selinux-emergency.patch: selinux:
    tag avc cache alloc as non-critical (FATE#303834).
  - patches.suse/SoN-14-net-backlog.patch: net: wrap
    sk->sk_backlog_rcv() (FATE#303834).
  - patches.suse/SoN-15-net-ps_rx.patch: net: packet split receive
    api (FATE#303834).
  - patches.suse/SoN-16-net-sk_allocation.patch: net:
    sk_allocation() - concentrate socket related allocations
    (FATE#303834).
  - patches.suse/SoN-17-netvm-reserve.patch: netvm: network reserve
    infrastructure (FATE#303834).
  - patches.suse/SoN-18-netvm-reserve-inet.patch: netvm: INET
    reserves. (FATE#303834).
  - patches.suse/SoN-19-netvm-skbuff-reserve.patch: netvm: hook
    skb allocation to reserves (FATE#303834).
  - patches.suse/SoN-20-netvm-sk_filter.patch: netvm: filter
    emergency skbs. (FATE#303834).
  - patches.suse/SoN-21-netvm-tcp-deadlock.patch: netvm: prevent
    a stream specific deadlock (FATE#303834).
  - patches.suse/SoN-22-emergency-nf_queue.patch: netfilter:
    NF_QUEUE vs emergency skbs (FATE#303834).
  - patches.suse/SoN-23-netvm.patch: netvm: skb processing
    (FATE#303834).
  - patches.suse/SoN-24-mm-swapfile.patch: mm: add support for
    non block device backed swap files (FATE#303834).
  - patches.suse/SoN-25-mm-page_file_methods.patch: mm: methods
    for teaching filesystems about PG_swapcache pages (FATE#303834).
  - patches.suse/SoN-26-nfs-swapcache.patch: nfs: teach the NFS
    client how to treat PG_swapcache pages (FATE#303834).
  - patches.suse/SoN-27-nfs-swapper.patch: nfs: disable data cache
    revalidation for swapfiles (FATE#303834).
  - patches.suse/SoN-28-nfs-swap_ops.patch: nfs: enable swap on NFS
    (FATE#303834).
  - patches.suse/SoN-29-nfs-alloc-recursions.patch: nfs: fix various
    memory recursions possible with swap over NFS. (FATE#303834).
  - patches.xen/xen3-auto-common.diff: xen3 common.
* Mon Sep 29 2008 ptesarik@suse.cz
- patches.arch/x86-tracehook: x86 tracehook (FATE#304321).
  Provide the base infrastructure for utrace on x86.
* Mon Sep 29 2008 schwab@suse.de
- config/powerpc/vanilla: configure to 64bit.
* Mon Sep 29 2008 schwab@suse.de
- rpm/functions.sh: remove readlink emulation.
* Mon Sep 29 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.3-update: Update lpfc to 8.2.8.3
  (bnc#420767).
* Mon Sep 29 2008 rw@suse.de
- Update ia64 config files.  (bnc#429881)
* Mon Sep 29 2008 jjolly@suse.de
- patches.drivers/ehca-flush-cqe.patch: adds software flush CQE
  generation (bnc#430344)
* Mon Sep 29 2008 jkosina@suse.de
- patches.suse/e1000e_allow_bad_checksum: fix infinite loop bug in
  e1000_probe() in case the card has invalid EEPROM checksum
* Mon Sep 29 2008 agruen@suse.de
- Do not split kernels which have modules disabled (kernel-ps3)
  or which do not differentiate between supported and unsupported
  modules (kernel-vanilla).
* Mon Sep 29 2008 hare@suse.de
- patches.drivers/open-fcoe-dcb-support: Fix section annotation
  for ixgbe.
- patches.fixes/scsi-enhance-error-codes: Add missing hunk.
- patches.fixes/open-iscsi-git-update: Open-iSCSI updates
  (FATE#304283).
- patches.kernel.org/gdth-section-conflict: Fixup gdth
  section annotations.
* Mon Sep 29 2008 aj@suse.de
- Silence /etc/rpm/macros.kernel-source via rpmlintrc.
* Mon Sep 29 2008 jbeulich@novell.com
- Enable Solarflare driver link and resource driver patches.
- Update x86 config files.
* Mon Sep 29 2008 agruen@suse.de
- rpm/kernel-source.spc.in: Try to get rid of a hack that makes
  uname -r pretend in build environments that the kernel from
  the installed kernel-source package is the running kernel:
  packages assuming this are completely broken ans should really
  be fixed.
* Mon Sep 29 2008 agruen@suse.de
- rpm/kernel-source.spec.in: Prepare for the upcoming introduction
  of kernel-source-rt (and kernel-syms-rt) for producing KMPs for
  real-time kernels.
- rpm/install-configs: Remove; this script didn't improve things.
* Sun Sep 28 2008 aj@suse.de
- rpm/kernel-source.rpmlintrc: New file to silence warnings about
  zero size files
- rpm/kernel-source.spec.in: Install it.
- rpm/kernel-source.spec.in: Make /etc/rpm/macros.kernel-source
  a config file to silence rpmlint.
* Sun Sep 28 2008 jdelvare@suse.de
- supported.conf: Update the list of i2c bus drivers.
  - i2c-i810, i2c-prosavage and i2c-savage4 are gone.
  - i2c-isch and i2c-nforce2-s4985 are new, mark as supported.
* Sun Sep 28 2008 aj@suse.de
- rpm/kernel-source.spec.in: Do not package .gitignore files.
* Sun Sep 28 2008 agruen@suse.de
- Fix CONFIG_MODULES=n case.
- config.conf: Some cleanups.
* Sat Sep 27 2008 agruen@suse.de
- Split the binary kernel packages into three parts:
  + kernel-$flavor-base: very reduced hardware support, intended
  to be used in virtual machine images
  + kernel-$flavor: extends the base package; contains all kernel
  modules we can support
  + kernel-$flavor-extra: all other kernel modules which may be
  useful, but which we cannot support.
* Sat Sep 27 2008 agruen@suse.de
- Hardlink duplicate files automatically: It doesn't save much,
  but it keeps rpmlint from breaking the package build.
* Sat Sep 27 2008 agruen@suse.de
- Add consistency check: supported modules must not depend on
  unsupported ones ... and guess what, there was a large number of
  such modules. Fix this by adding all the dependent modules to
  supported.conf.
* Sat Sep 27 2008 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Implement barrier
  support for single device DM devices (FATE#304489).
* Fri Sep 26 2008 jeffm@suse.de
- scripts/tar-up_and_run_mbuild.sh: Added -xen flavor to default
  mbuild spec list.
* Fri Sep 26 2008 jeffm@suse.de
- patches.xen/xen-e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls for xen. (bnc#425480).
* Fri Sep 26 2008 kkeil@suse.de
- patches.suse/e1000e_mmap_range_chk:check ranges in pci_mmap
  * updated version with better reporting (bnc#425480)
* Fri Sep 26 2008 kkeil@suse.de
- patches to track down and fix the e1000e NVM corruption
  (bnc#425480)
- patches.suse/e1000e_allow_bad_checksum: e1000e: allow bad
  checksum
- patches.suse/e1000e_call_dump_eeprom: e1000e: dump eeprom to
  dmesg for ich8/9
- patches.suse/e1000e_debug_contention_on_NVM_SWFLAG: e1000e:
  debug contention on NVM SWFLAG
- patches.suse/e1000e_do_not_ever_sleep_in_interrupt_context:
  e1000e: do not ever sleep in interrupt context
- patches.suse/e1000e_drop_stats_lock: e1000e: drop stats lock
- patches.suse/e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls
- patches.suse/e1000e_fix_lockdep_issues: e1000e: fix lockdep
  issues
- patches.suse/e1000e_mmap_range_chk: check ranges in pci_mmap
- patches.suse/e1000e_reset_swflag_after_resetting_hardware:
  e1000e: reset swflag after resetting hardware
- patches.suse/e1000e_update_version: update version
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  e1000e: Use set_memory_ro()/set_memory_rw() to protect flash
  memory
-   cleanup old not longer used patches
  * patches.drivers/e1000-7.6.5-napi-tail.patch
  * patches.drivers/e1000-7.6.9.2
  * patches.drivers/e1000-7.6.9.2-napi
* Fri Sep 26 2008 kkeil@suse.de
- Enable CONFIG_SGI_IOC4=m in x86_64 (bnc#430275)
* Fri Sep 26 2008 jeffm@suse.de
- patches.arch/acpi-export-hotplug_execute: acpi: export
  acpi_os_hotplug_execute.
* Fri Sep 26 2008 jeffm@suse.de
- patches.xen/xen-rwlocks-enable-interrupts: add missing
  __raw_{read,write}_lock_flags to xen's asm/spinlock.h.
* Fri Sep 26 2008 jeffm@suse.de
- patches.arch/acpi-bay-remove-from-makefile: acpi: remove bay.c
  from makefile.
* Fri Sep 26 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Disabled sparse checking. Too many
  false positives.
* Fri Sep 26 2008 trenn@suse.de
  No functional change:
- patches.arch/acpi_thermal_passive_blacklist.patch: Avoid
  critical temp shutdowns on specific ThinkPad T4x(p) and R40
  (https://bugzilla.novell.com/show_bug.cgi?id=333043).
  Dock bug fixes (kacpid runs amok on Dells after suspend):
- patches.arch/acpi-dock-avoid-check-_STA-method.patch: avoid
  check _STA method (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-eject-request-process.patch: fix
  eject request process (fate#304731,bnc#401740).
  More Dock improvements, unrelated to above fixes:
- patches.arch/acpi-bay-remove-useless-code.patch: remove useless
  code (fate#304731,bnc#401740).
- patches.arch/acpi-dock-Fix-duplicate-notification-handler-register.patch:
  Fix duplicate notification handler register
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-_LCK-support-for-dock.patch: add _LCK
  support for dock (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-for-bay-in-a-dock-station.patch:
  fix for bay in a dock station (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-hotplug-race.patch: fix hotplug race
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-introduce-.uevent-for-devices-in-dock.patch:
  introduce .uevent for devices in dock (fate#304731,bnc#401740).
- patches.arch/acpi-libata-hotplug-to-align-with-dock-driver.patch:
  libata hotplug to align with dock driver
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-makeing-dock-driver-supports-bay-and-battery-hotplug.patch:
  makeing dock driver supports bay and battery hotplug
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-add-type-sysfs-file-for-dock.patch:
  add 'type' sysfs file for dock (fate#304731,bnc#401740).
- patches.fixes/acpi_use_acpi_exception.patch: ACPI dock/bay:
  Use ACPI_EXCEPTION instead of printk(KERN_ERR.
* Fri Sep 26 2008 jeffm@suse.de
- Update config files: NFS_SWAP=y
* Fri Sep 26 2008 ptesarik@suse.cz
- patches.suse/rwlocks-enable-interrupts: Allow rwlocks to
  re-enable interrupts (bnc#387784).
- patches.arch/ia64-rwlocks-enable-interrupts: ia64: re-enable
  interrupts when waiting for a rwlock (bnc#387784).
* Fri Sep 26 2008 sjayaraman@suse.de
- Add Swap over NFS patchset.
- Adjust patches.xen/xen3-auto-common.diff to avoid conflict on skbuff.h
  as both xen and swap-over-nfs want to add some bits to the skbuff structure.
- patches.suse/SoN-01-mm-gfp-to-alloc_flags.patch: mm:
  gfp_to_alloc_flags() (FATE#303834).
- patches.suse/SoN-02-mm-setup_per_zone_pages_min.patch: mm:
  serialize access to min_free_kbytes (FATE#303834).
- patches.suse/SoN-03-doc.patch: swap over network documentation
  (FATE#303834).
- patches.suse/SoN-04-mm-gfp-to-alloc_flags-expose.patch: mm:
  expose gfp_to_alloc_flags() (FATE#303834).
- patches.suse/SoN-05-page_alloc-reserve.patch: mm: tag reseve
  pages (FATE#303834).
- patches.suse/SoN-06-reserve-slub.patch: mm: slb: add knowledge
  of reserve pages (FATE#303834).
- patches.suse/SoN-07-mm-kmem_estimate_pages.patch: mm:
  kmem_alloc_estimate() (FATE#303834).
- patches.suse/SoN-08-mm-PF_MEMALLOC-softirq.patch: mm: allow
  PF_MEMALLOC from softirq context (FATE#303834).
- patches.suse/SoN-09-mm-page_alloc-emerg.patch: mm: emergency
  pool (FATE#303834).
- patches.suse/SoN-10-global-ALLOC_NO_WATERMARKS.patch: mm:
  system wide ALLOC_NO_WATERMARK (FATE#303834).
- patches.suse/SoN-11-mm-page_alloc-GFP_EMERGENCY.patch: mm:
  __GFP_MEMALLOC (FATE#303834).
- patches.suse/SoN-12-mm-reserve.patch: mm: memory reserve
  management (FATE#303834).
- patches.suse/SoN-13-mm-selinux-emergency.patch: selinux:
  tag avc cache alloc as non-critical (FATE#303834).
- patches.suse/SoN-14-net-backlog.patch: net: wrap
  sk->sk_backlog_rcv() (FATE#303834).
- patches.suse/SoN-15-net-ps_rx.patch: net: packet split receive
  api (FATE#303834).
- patches.suse/SoN-16-net-sk_allocation.patch: net:
  sk_allocation() - concentrate socket related allocations
  (FATE#303834).
- patches.suse/SoN-17-netvm-reserve.patch: netvm: network reserve
  infrastructure (FATE#303834).
- patches.suse/SoN-18-netvm-reserve-inet.patch: netvm: INET
  reserves. (FATE#303834).
- patches.suse/SoN-19-netvm-skbuff-reserve.patch: netvm: hook
  skb allocation to reserves (FATE#303834).
- patches.suse/SoN-20-netvm-sk_filter.patch: netvm: filter
  emergency skbs. (FATE#303834).
- patches.suse/SoN-21-netvm-tcp-deadlock.patch: netvm: prevent
  a stream specific deadlock (FATE#303834).
- patches.suse/SoN-22-emergency-nf_queue.patch: netfilter:
  NF_QUEUE vs emergency skbs (FATE#303834).
- patches.suse/SoN-23-netvm.patch: netvm: skb processing
  (FATE#303834).
- patches.suse/SoN-24-mm-swapfile.patch: mm: add support for
  non block device backed swap files (FATE#303834).
- patches.suse/SoN-25-mm-page_file_methods.patch: mm: methods
  for teaching filesystems about PG_swapcache pages (FATE#303834).
- patches.suse/SoN-26-nfs-swapcache.patch: nfs: teach the NFS
  client how to treat PG_swapcache pages (FATE#303834).
- patches.suse/SoN-27-nfs-swapper.patch: nfs: disable data cache
  revalidation for swapfiles (FATE#303834).
- patches.suse/SoN-28-nfs-swap_ops.patch: nfs: enable swap on NFS
  (FATE#303834).
- patches.suse/SoN-29-nfs-alloc-recursions.patch: nfs: fix various
  memory recursions possible with swap over NFS. (FATE#303834).
- patches.xen/xen3-auto-common.diff: xen3 common.
* Fri Sep 26 2008 ptesarik@suse.cz
- split patches.arch/s390-01-01-self-ptrace-v3.patch to make it
  more obvious that the patch is not constrained to s390.
  The new series is:
    patches.suse/self-ptrace.patch: the generic pieces
    patches.arch/x86-self-ptrace.patch: implementation for x86
    patches.arch/s390-01-01-self-ptrace-v3.patch: dtto for s390
* Thu Sep 25 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc7 and c/s 676.
* Thu Sep 25 2008 olh@suse.de
- add patches.arch/ppc64-rpanote-relocate-firmware.patch
  update RPA note for firmware relocation (bnc#427960 - LTC48297)
* Wed Sep 24 2008 jblunck@suse.de
  This adds some tracepoint instrumentation taken from the LTTng patch
  series. Tracepoints are enabled for kernel-debug and kernel-trace only. I
  disabled ftrace for all flavors except kernel-debug and kernel-trace as well.
- Update config files.
- rpm/kernel-source.spec.in,kernel-binary.spec.in, config.conf: Add trace
  flavor
- patches.fixes/ia64-sparse-fixes.diff: ia64-kvm: fix sparse
  warnings.
- patches.xen/xen3-fixup-common: rediff
- patches.xen/xen3-auto-common.diff: rediff
- patches.xen/xen3-patch-2.6.21: rediff
- patches.xen/xen3-patch-2.6.26: rediff
- patches.trace/rcu-read-sched.patch
- patches.trace/markers-use-rcu-read-lock-sched.patch
- patches.trace/tracepoints.patch
- patches.trace/tracepoints-use-table-size-macro.patch
- patches.trace/tracepoints-documentation.patch
- patches.trace/tracepoints-tracepoint-synchronize-unregister.patch
- patches.trace/tracepoints-documentation-fix-teardown.patch
- patches.trace/tracepoints-samples.patch
- patches.trace/tracepoints-samples-fix-teardown.patch
- patches.trace/lttng-instrumentation-irq.patch
- patches.trace/lttng-instrumentation-scheduler.patch
- patches.trace/lttng-instrumentation-timer.patch
- patches.trace/lttng-instrumentation-kernel.patch
- patches.trace/lttng-instrumentation-filemap.patch
- patches.trace/lttng-instrumentation-swap.patch
- patches.trace/lttng-instrumentation-memory.patch
- patches.trace/lttng-instrumentation-page_alloc.patch
- patches.trace/lttng-instrumentation-hugetlb.patch
- patches.trace/lttng-instrumentation-net.patch
- patches.trace/lttng-instrumentation-ipv4.patch
- patches.trace/lttng-instrumentation-ipv6.patch
- patches.trace/lttng-instrumentation-socket.patch
- patches.trace/lttng-instrumentation-fs.patch
- patches.trace/lttng-instrumentation-ipc.patch
- patches.trace/ftrace-port-to-tracepoints.patch
- patches.trace/ftrace-framepointer.diff
* Tue Sep 23 2008 jjolly@suse.de
- patches.arch/s390-01-03-cmm2-v2.patch: kernel (new function):
  Collaborative Memory Management Stage II (bnc#417244)
- patches.xen/xen3-auto-common.diff: Modified patch to allow for
  the new patch
* Tue Sep 23 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Enable sparse checking and section
  mismatch checking.
* Tue Sep 23 2008 jeffm@suse.de
- patches.kernel.org/arch-include-asm-fixes: kbuild: Properly
  handle arch/$arch/include/asm (bnc#427473).
* Mon Sep 22 2008 jeffm@suse.de
- patches.fixes/ext2-avoid-printk-flood-with-dir-corruption:
  ext2: Avoid printk floods in the face of directory corruption
  (bnc#427244 CVE-2008-3528).
- patches.fixes/ext3-avoid-printk-flood-with-dir-corruption:
  ext3: Avoid printk floods in the face of directory corruption
  (bnc#427244 CVE-2008-3528).
* Mon Sep 22 2008 jeffm@suse.de
- Update to 2.6.27-rc7.
  - Eliminated 2 patches.
  - patches.arch/s390-01-04-fcpperf-4.patch: Fixed up context.
* Mon Sep 22 2008 trenn@suse.de
  Workaround for ThinkPad brightness switching:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Do not use video backlight switching for Lenovo ThinkPads.
  Commented out for now, possibly to be included later
- patches.drivers/cpufreq_add_cpu_number_paramater_1.patch:
  cpufreq: Add a cpu parameter to __cpufreq_driver_getavg()..
- patches.drivers/cpufreq_add_idle_microaccounting_6.patch:
  cpufreq,ondemand: Use get_cpu_idle_time_us() to get
  micro-accounted idle information.
- patches.drivers/cpufreq_change_load_calculation_2.patch:
  cpufreq, ondemand: Change the load calculation, optimizing
  for dependent cpus.
- patches.drivers/cpufreq_changes_to_get_cpu_idle_us_5.patch:
  export get_cpu_idle_time_us() .
- patches.drivers/cpufreq_get_cpu_idle_time_changes_3.patch:
  cpufreq,ondemand: Prepare changes for doing micro-accounting.
- patches.drivers/cpufreq_parameterize_down_differential_4.patch:
  cpufreq, ondemand: Use a parameter for down differential.
  Added CONFIG_PCIEASPM for rt, xen, powerpc and IA64 to be more
  consistent across different kernel flavors as suggested on the
  kernel list:
- Update config files.
* Mon Sep 22 2008 hare@suse.de
- patches.drivers/open-fcoe-libfc: Fix build error on IA64.
- patches.fixes/scsi-terminate-target-reset: Target reset hangs
  (bnc#427267).
- supported.conf: Update to include supported SCSI adapters.
* Fri Sep 19 2008 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Re-enable after removing FTRACE
  related change.
- Update x86 non-debug config files: Turn off FRAME_POINTER and FTRACE.
* Fri Sep 19 2008 nfbrown@suse.de
- patches.fixes/md-Allow-metadata_version-to-be-updated-for-externa.patch:
  md: Allow metadata_version to be updated for externally managed
  metadata. (FATE#304218).
- patches.fixes/md-Don-t-try-to-set-an-array-to-read-auto-if-it-i.patch:
  md: Don't try to set an array to 'read-auto' if it is already
  in that state. (FATE#304218).
* Thu Sep 18 2008 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Disable.
- Re-enable CONFIG_FRAME_POINTER in x86 config files.
* Thu Sep 18 2008 jbeulich@novell.com
- Update i386 and x86-64 config files (disable CONFIG_FRAME_POINTER in
  non-debug configs).
- patches.suse/stack-unwind: Add missing put_cpu()-s for x86-64.
- patches.suse/no-frame-pointer-select: Fix stack unwinder Kconfig
  (bnc#402518).
* Thu Sep 18 2008 hare@suse.de
- Update config files.
- patches.drivers/open-fcoe-driver: fcoe: Fibre Channel over
  Ethernet driver (FATE#303913).
- patches.drivers/open-fcoe-libfc: libfc: a modular software
  Fibre Channel implementation (FATE#303913).
- patches.drivers/open-fcoe-header-files: FC protocol definition
  header files (FATE#303913).
- patches.drivers/open-fcoe-dcb-support: FCoE: Add DCB support
  (FATE#303913).
- patches.drivers/ixgbe-fcoe-bugfixes: ixgbe: Bugfixes for FCoE.
- patches.fixes/vlan-gso-size-fix: vlan: device not reading gso
  max size of parent. (FATE#303913).
- patches.fixes/pkt_action-skbedit: pkt_action: add new action
  skbedit.
- patches.fixes/pkt_sched_multiq_support: pkt_sched: Add
  multiqueue scheduler support (FATE#303913).
- supported.conf: Update to include FCoE and device_handler
  modules
* Wed Sep 17 2008 jbeulich@novell.com
- supported.conf: adjust name of ide-cd (is now ide-cd_mod).
* Wed Sep 17 2008 hare@suse.de
- patches.drivers/qla2xxx-defer-risc-interrupt-enablement:
  qla2xxx: Defer enablement of RISC interrupts until ISP
  initialization completes (FATE#304113).
- patches.drivers/qla2xxx-8.02.01-k8-update: Update qla2xxx to
  8.02.01-k8 (FATE#304113).
* Wed Sep 17 2008 hare@suse.de
- patches.fixes/scsi-retry-hardware-error: make scsi_check_sense
  HARDWARE_ERROR return ADD_TO_MLQUEUE on retry (FATE#304042)
* Tue Sep 16 2008 olh@suse.de
- disable CONFIG_SPARSEMEM_VMEMMAP on ppc64 to allow memory remove
  (bnc#417537)
* Mon Sep 15 2008 jkosina@suse.de
- Update config files (build elousb driver as module)
- patches.drivers/elousb.patch: Elo USB touchscreen driver
  (FATE#304972).
* Mon Sep 15 2008 hare@suse.de
- patches.fixes/dm-mpath-abort-queue: Abort queued requests for
  multipath (FATE#304151).
* Mon Sep 15 2008 hare@suse.de
- Update config files: Disable CONFIG_OCFS2_COMPAT_JBD
* Mon Sep 15 2008 hare@suse.de
- patches.xen/xen-scsifront-block-timeout-update: Update XEN
  scsifront driver to request timeouts.
* Mon Sep 15 2008 sdietrich@suse.de
- Update config files: Enable GROUP_SCHED, FAIR_GROUP_SCHED,
  RT_GROUP_SCHED, CGROUP_SCHED
* Mon Sep 15 2008 hare@suse.de
- patches.drivers/block-timeout-handling: Fix typo.
* Fri Sep 12 2008 duwe@suse.de
- Add LED driver for SGI "UV" systems (FATE#304268)
* Fri Sep 12 2008 hare@suse.de
- patches.drivers/bdev-resize-added-flush_disk: Added
  flush_disk to factor out common buffer cache flushing code
  (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-adjust-block-device-size:
  Adjust block device size after an online resize of a
  disk. (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-call-flush_disk: Call flush_disk()
  after detecting an online resize. (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-check-for-device-resize:
  Check for device resize when rescanning partitions
  (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-sd-driver-calls: SCSI sd driver
  calls revalidate_disk wrapper (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-wrapper-for-revalidate_disk:
  Wrapper for lower-level revalidate_disk
  routines. (FATE#302348,FATE#303786).
- patches.drivers/block-timeout-handling: block: unify request
  timeout handling (FATE#304151,bnc#417544).
- patches.fixes/scsi-misc-git-update: SCSI misc fixes
  (FATE#303485,FATE#303484).
- patches.fixes/scsi-enhance-error-codes: Separate failfast into
  multiple bits (FATE#303485,FATE#303484).
- patches.suse/rq-based-block-layer: rediff.
- patches.suse/rq-based-multipath-functions: rediff.
- patches.suse/no-partition-scan: rediff.
* Fri Sep 12 2008 hare@suse.de
- patches.fixes/scsi-misc-git-update: SCSI misc fixes,
  required by the driver updates (FATE#303485,FATE#303484)
* Fri Sep 12 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.1-update: Update lpfc to 8.2.8.1
  (bnc#420767).
- patches.drivers/lpfc-8.2.8-update: Emulex lpfc driver update
  to 8.2.8 (FATE#303485,bnc#420767).
* Fri Sep 12 2008 bwalle@suse.de
- patches.arch/ia64-kdump_proc_iomem.diff:
  IA64: assign a distinguishable label to uncached memory in
  /proc/iomem (to fix MCA on kdump boot).
* Thu Sep 11 2008 jack@suse.cz
  Latest ext4 fixes from ext4 patch queue:
- patches.fixes/ext4-Add-inode-to-journal-handle-after-block-alloca.patch:
  ext4: Don't add the inode to journal handle until after the
  block is allocated (fate#303783).
- patches.fixes/ext4_add-missing-unlock-to-ext4-check-descriptors:
  ext4: add missing unlock in ext4_check_descriptors() on error
  path (fate#303783).
- patches.fixes/ext4-Add-percpu-dirty-block-accounting.patch:
  ext4: Add percpu dirty block accounting. (fate#303783).
- patches.fixes/ext4_create-proc-ext4-stats-file-more-carefully:
  ext4: fix #11321: create /proc/ext4/*/stats more carefully
  (fate#303783).
- patches.fixes/ext4_fix_longlong_checkpatch_issues: ext4:
  Fix long long checkpatch warnings (fate#303783).
- patches.fixes/ext4_fix_printk_checkpatch_issues: ext4:
  Add printk priority levels to clean up checkpatch warnings
  (fate#303783).
- patches.fixes/ext4_fix_whitespace_checkpatch_issues: ext4:
  Fix whitespace checkpatch warnings/errors (fate#303783).
- patches.fixes/ext4_i_disksize_lock_race_fix.patch: ext4:
  Properly update i_disksize. (fate#303783).
- patches.fixes/ext4_invalidate_pages_when_delalloc_alloc_fail.patch:
  ext4: invalidate pages if delalloc block allocation
  fails. (fate#303783).
- patches.fixes/ext4-Make-sure-all-the-block-allocation-paths-reser.patch:
  ext4: Make sure all the block allocation paths reserve blocks
  (fate#303783).
- patches.fixes/ext4_nonmballoc_reservation_ENOSPC_fix.patch:
  ext4: Fix ext4 nomballoc allocator for ENOSPC (fate#303783).
- patches.fixes/ext4-Retry-block-allocation-if-we-have-free-blocks.patch:
  ext4: Retry block allocation if we have free blocks left
  (fate#303783).
- patches.fixes/ext4-Retry-block-reservation.patch: ext4: Retry
  block reservation (fate#303783).
- patches.fixes/ext4-Signed-arithematic-fix.patch: ext4: Signed
  arithematic fix (fate#303783).
- patches.fixes/ext4-Switch-to-non-delalloc-mode-when-we-are-low-on.patch:
  ext4: Switch to non delalloc mode when we are low on free
  blocks count. (fate#303783).
- patches.fixes/ext4_truncate_block_allocated_on_a_failed_ext4_write_begin.patch:
  ext4: truncate block allocated on a failed ext4_write_begin
  (fate#303783).
- patches.fixes/ext4_update-flex-bg-counters-when-resizing:
  Update flex_bg free blocks and free inodes counters when
  resizing. (fate#303783).
- patches.fixes/percpu_counter_sum_cleanup.patch: percpu counter:
  clean up percpu_counter_sum_and_set() (fate#303783).
* Thu Sep 11 2008 bwalle@suse.de
- Enable KDB for i386 and x86_64 in "default" and "pae"
  configuration with CONFIG_KDB_OFF set to "y" (FATE#303971).
- Set CONFIG_KDB_CONTINUE_CATASTROPHIC=2 in all configurations
  that have KDB enabled.
* Thu Sep 11 2008 jslaby@suse.de
- Update config files.
  enable PID_NS and USER_NS
  (FATE#303785, FATE#304371)
* Thu Sep 11 2008 jeffm@suse.de
- Update config files.
  - Enabled CONFIG_XFRM_SUB_POLICY (FATE#303781)
* Thu Sep 11 2008 mfasheh@suse.com
- Added POSIX File Locks support for Ocfs2  (FATE#110294)
  - patches.suse/ocfs2-POSIX-file-locks-support.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Added Ocfs2 JBD2 Support  (FATE#302877)
  - patches.suse/ocfs2-Limit-inode-allocation-to-32bits.patch
  - patches.suse/ocfs2-Add-the-inode64-mount-option.patch
  - patches.suse/ocfs2-Switch-over-to-JBD2.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Added Ocfs2 Extended Attributes Support (FATE#302067)
  - patches.suse/ocfs2-Modify-ocfs2_num_free_extents-f.patch
  - patches.suse/ocfs2-Use-ocfs2_extent_list-instead-o.patch
  - patches.suse/ocfs2-Abstract-ocfs2_extent_tree-in-b.patch
  - patches.suse/ocfs2-Make-high-level-btree-extend-co.patch
  - patches.suse/ocfs2-Add-the-basic-xattr-disk-layout-in-ocf.patch
  - patches.suse/ocfs2-Add-helper-function-in-uptodate.patch
  - patches.suse/ocfs2-Add-extent-tree-operation-for-x.patch
  - patches.suse/ocfs2-reserve-inline-space-for-extend.patch
  - patches.suse/ocfs2-Add-extended-attribute-support.patch
  - patches.suse/ocfs2-Add-xattr-index-tree-operations.patch
  - patches.suse/ocfs2-Add-xattr-bucket-iteration-for.patch
  - patches.suse/ocfs2-Add-xattr-lookup-code-xattr-btr.patch
  - patches.suse/ocfs2-Optionally-limit-extent-size-in.patch
  - patches.suse/ocfs2-Enable-xattr-set-in-index-btree.patch
  - patches.suse/ocfs2-Delete-all-xattr-buckets-during.patch
  - patches.suse/ocfs2-Add-incompatible-flag-for-exten.patch
  - patches.suse/ocfs2-fix-printk-format-warnings.patch
  - patches.suse/ocfs2-Prefix-the-extent-tree-operations-structure.patch
  - patches.suse/ocfs2-Prefix-the-ocfs2_extent_tree-structure.patch
  - patches.suse/ocfs2-Make-ocfs2_extent_tree-get-put-instead-of-all.patch
  - patches.suse/ocfs2-Make-private-into-object-on-ocfs2_extent_.patch
  - patches.suse/ocfs2-Provide-the-get_root_el-method-to-ocfs2_ext.patch
  - patches.suse/ocfs2-Use-struct-ocfs2_extent_tree-in-ocfs2_num_fre.patch
  - patches.suse/ocfs2-Determine-an-extent-tree-s-max_leaf_clusters.patch
  - patches.suse/ocfs2-Create-specific-get_extent_tree-functions.patch
  - patches.suse/ocfs2-Add-an-insertion-check-to-ocfs2_extent_tree_o.patch
  - patches.suse/ocfs2-Make-ocfs2_extent_tree-the-first-class-repres.patch
  - patches.suse/ocfs2-Comment-struct-ocfs2_extent_tree_operations.patch
  - patches.suse/ocfs2-Change-ocfs2_get_-_extent_tree-to-ocfs2_ini.patch
  - patches.suse/ocfs2-bug-fix-for-journal-extend-in-xattr.patch
  - patches.suse/ocfs2-Resolve-deadlock-in-ocfs2_xattr_free_.patch
  - patches.suse/ocfs2-Add-xattr-mount-option-in-ocfs2_show_options.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Add patches.fixes/jbd2-create-proc-entry-fix.patch
  jbd2: Create proc entry with bdevname+i_ino.
  (FATE#302877)
* Thu Sep 11 2008 mfasheh@suse.com
- Add patches.fixes/dlm-allow-multiple-lockspaces.patch
  dlm: allow multiple lockspace creates
  (FATE#110294)
* Thu Sep 11 2008 schwab@suse.de
- Update kdb patches.
* Thu Sep 11 2008 jslaby@suse.de
- Update config files.
  change CONFIG_NODES_SHIFT from 6 to 9
  (FATE#304261)
* Wed Sep 10 2008 trenn@suse.de
- Update config files.
  Added: CONFIG_PCIEASPM
* Wed Sep 10 2008 kkeil@suse.de
- patches.drivers/e1000e_add_82574L.patch: e1000e: add support
  for new 82574L part.
- patches.drivers/e1000e_add_ICH9_BM.patch: e1000e: add support
  for the 82567LM-4 device.
- patches.drivers/e1000e_add_LOM_devices.patch: e1000e: add
  support for 82567LM-3 and 82567LF-3 (ICH10D).
  (FATE#303916)
* Wed Sep 10 2008 hare@suse.de
- patches.suse/no-partition-scan: Implement 'no_partition_scan'
  commandline option (FATE#303697)
* Wed Sep 10 2008 jeffm@suse.de
- patches.kernel.org/ipmi-section-conflict.diff: ipmi: Fix
  section type conflicts.
- patches.kernel.org/psmouse-section-conflict.diff: psmouse:
  fix section type conflict.
- patches.kernel.org/carmine-section-mismatch: video: Fix section
  mismatch in carminefb.
- patches.kernel.org/md-section-conflict: md: Fix section
  conflicts.
- patches.kernel.org/setup_APIC_timer-section-mismatch: x86:
  Fix section conflict with kvm_setup_secondary_clock.
* Wed Sep 10 2008 trenn@suse.de
- patches.arch/thinkpad_fingers_off_backlight_igd.patch:
  Serve ThinkPad IGD devices backlight functionality through
  thinkpad_acpi (fate #302883).
- supported.conf: Add most important laptop drivers as supported:
    kernel/drivers/misc/asus_laptop
    kernel/drivers/misc/eeepc-laptop
    kernel/drivers/misc/msi-laptop
    kernel/drivers/misc/fujitsu-laptop
    kernel/drivers/acpi/wmi
    kernel/drivers/misc/hp-wmi
* Wed Sep 10 2008 jeffm@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: Fixed up
  some section conflicts.
* Wed Sep 10 2008 jeffm@suse.de
- Update to 2.6.27-rc6.
* Wed Sep 10 2008 jeffm@suse.de
- supported.conf: Added missing netfilter modules.
* Wed Sep 10 2008 jeffm@suse.de
- supported.conf: Updated netfilter module names.
* Wed Sep 10 2008 jeffm@suse.de
- patches.kernel.org/firmware-path: Updated header.
* Wed Sep 10 2008 jkosina@suse.de
- Update config files: support more than 4 serial ports
  (FATE#303314)
* Wed Sep 10 2008 olh@suse.de
- set CONFIG_CMM=y instead of =m to simplify virtual partition memory
  (bnc#417554)
* Tue Sep  9 2008 bphilips@suse.de
- rpm/kernel-binary.spec.in: add Recommends: kerneloops
* Tue Sep  9 2008 olh@suse.de
- Updated to 2.6.27-rc5-git10
* Mon Sep  8 2008 olh@suse.de
- Updated to 2.6.27-rc5-git9
* Fri Sep  5 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v3.patch: system call
  notification with self_ptrace (bnc#417299)
- patches.arch/s390-01-02-dcss-64-v2.patch: dcssblk (new function):
  Add support for >2G DCSS and stacked contiguous DCSS support.
  (bnc#417246)
- patches.arch/s390-01-04-fcpperf-{1-4}.patch: (kernel):FCP -
  Performance Data colletion & analysis (bnc#417243)
* Fri Sep  5 2008 olh@suse.de
- add patches.fixes/usb-hcd-interrupt-shared.patch
  fix interrupt handling for shared irqs, for PS3 (bnc#409961)
* Fri Sep  5 2008 olh@suse.de
- Updated to 2.6.27-rc5-git7
* Thu Sep  4 2008 olh@suse.de
- build with CONFIG_POWER4_ONLY (bnc#417566)
  this disables support for POWER3 and RS64 cpus
* Thu Sep  4 2008 jkosina@suse.de
- switch from Reno to Cubic as default TCP congestion algorithm
  (bnc#422825)
* Thu Sep  4 2008 bwalle@suse.de
- Update KDB patches. Fix build on x86_64-debug.
* Wed Sep  3 2008 jeffm@suse.de
- mark crc-t10dif as supported
* Wed Sep  3 2008 olh@suse.de
- mark pata_pdc2027x as supported
* Wed Sep  3 2008 olh@suse.de
- mark spidernet as supported
* Wed Sep  3 2008 olh@suse.de
- mark ehea as supported
* Wed Sep  3 2008 trenn@suse.de
- supported.conf:
  Mark dock (libata depends on it), bay, acpi_memhotplug, hpilo
  as supported
  Remove or adjust supported laptop drivers that went from
  drivers/acpi to drivers/misc
* Wed Sep  3 2008 hare@suse.de
- supported.conf: Mark virtio modules as supported.
* Tue Sep  2 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc5 and c/s 651.
* Tue Sep  2 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v2.patch: kernel
  (new function): System call notification with self_ptrace
  (bnc#417299,FATE#304021)
* Mon Sep  1 2008 agruen@suse.de
- File capabilities: replace our no_file_caps patch with what is
  supposed to end up in 2.6.28.
* Mon Sep  1 2008 bwalle@suse.de
- patches.arch/ia64-node_mem_map-node_start_pfn.diff:
  Fix memory map for ia64/discontmem for kdump.
* Mon Sep  1 2008 olh@suse.de
- Updated to 2.6.27-rc5-git2
* Fri Aug 29 2008 jeffm@suse.de
- Updated to 2.6.27-rc5.
  - Eliminated 2 patches.
  - KDB has an incompatible change on x86_64, so kernel-debug
    will fail there.
* Fri Aug 29 2008 olh@suse.de
- update message in post.sh to display also the rpm FLAVOR
* Thu Aug 28 2008 olh@suse.de
- update patches.suse/dm-raid45-2.6.25-rc2_20080221.patch
  rename rh_init to region_hash_init to avoid conflict
  with existing powerpc symbol on powerpc
* Thu Aug 28 2008 olh@suse.de
- disable musb, not useful, does not compile
* Tue Aug 26 2008 trenn@suse.de
  Vendor specific drivers vs generic video driver.
  Distinguish which ACPI driver should do backlight switching.
  This patch series is queued up for 2.6.28 in the ACPI branch:
- patches.arch/0000-ACPI-video-Ignore-devices-not-present.patch:
  ACPI: video: Ignore devices that aren't present in hardware.
- patches.arch/0001-Check-for-ACPI-backlight-support.patch: Check
  for ACPI backlight support otherwise use vendor ACPI drivers.
- patches.arch/0002-Acer-WMI-fingers-off-backlight-video.ko.patch:
  Acer-WMI: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0003-Asus-acpi-fingers-off-backlight.patch:
  asus-acpi: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0004-Compal-fingers-off-backlight.patch: compal:
  fingers off backlight if video.ko is serving this functionality.
- patches.arch/0005-eeepc-laptop-fingers-off.patch: eeepc-laptop:
  fingers off backlight if video.ko is serving this functionality.
- patches.arch/0006-fujitsu-laptop-fingers-off-backlight.patch:
  fujitsu-laptop: fingers off backlight if video.ko is serving
  this functionality.
- patches.arch/0007-msi-laptop-fingers-off-backlight.patch:
  msi-laptop: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0008-sony-laptop-fingers-off-backlight.patch:
  sony-laptop: fingers off backlight if video.ko is serving
  this functionality.
- patches.arch/0009-thinkpad_acpi-fingers-off-backlight.patch:
  thinkpad_acpi: fingers off backlight if video.ko is serving
  this functionality.
  I had to refresh these. While one patch was broken,
  two lines were missing, "patch" from 11.0 still worked, while
  "patch" from 10.3 did not:
- patches.xen/add-console-use-vt: add console_use_vt.
- patches.xen/linux-2.6.19-rc1-kexec-move_segment_code-i386.patch:
  kexec: Move asm segment handling code to the assembly file
  (i386).
* Mon Aug 25 2008 jeffm@suse.de
- Disabled patches.kernel.org/ia64-asm-nr-irqs
* Mon Aug 25 2008 jeffm@suse.de
- patches.fixes/pseries-compile-fix: pseries: compile fix.
* Mon Aug 25 2008 jeffm@suse.de
- patches.kernel.org/musb-powerpc-conflict: musb: compile fix
  for powerpc.
* Mon Aug 25 2008 jeffm@suse.de
- patches.kernel.org/ia64-asm-nr-irqs: ia64: nr-irqs.h generation
  should place it in arch/../asm.
* Mon Aug 25 2008 jeffm@suse.de
- Update config files.
* Mon Aug 25 2008 jeffm@suse.de
- Updated to 2.6.27-rc4.
  - Refreshed context.
* Mon Aug 25 2008 trenn@suse.de
- patches.arch/x86-introduce-pci-noioapicquirk-kernel-cmdline.patch:
  x86, pci: introduce pci=noioapicquirk kernel cmdline option.
  Mysterious patch problem in include/asm-x86/pci.h
- patches.fixes/acpi-clear-wake-status.patch: Clear wak_sts
  register on resume.
* Mon Aug 25 2008 trenn@suse.de
- patches.suse/acpi_provide_non_windows_osi_boot_param.patch:
  Delete.
* Mon Aug 25 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc4.
- patches.xen/xen-x86_64-dump-user-pgt: dump the correct page
  tables for user mode faults.
- patches.xen/xen-x86_64-pgd-alloc-order: don't require order-1
  allocations for pgd-s.
- patches.xen/xen-x86_64-pgd-pin: make pinning of pgd pairs
  transparent to callers.
- patches.xen/xen-blktap-write-barriers: blktap: Write Barriers.
- patches.xen/xen-x86-pmd-handling: consolidate pmd/pud/pgd entry
  handling.
- patches.xen/xen-x86-bigmem: fix issues with the assignment of
  huge amounts of memory.
- patches.xen/xen-msix-restore: print at least a message if MSI-X
  restore failed.
- config.conf: Re-enable Xen.
- patches.xen/sfc-i2c: Delete.
- Update config files.
* Fri Aug 22 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Adjust and re-enable.
- Update config files.
* Tue Aug 19 2008 jeffm@suse.de
- patches.kernel.org/ps3-lpm-include: Delete.
* Tue Aug 19 2008 jeffm@suse.de
- Removed unused patches.
* Tue Aug 19 2008 tiwai@suse.de
- Update config files: Use CONFIG_INPUT_PCSPKR=m (bnc#225221)
* Mon Aug 18 2008 schwab@suse.de
- Update config files.
* Mon Aug 18 2008 schwab@suse.de
- Update kdb patches.
* Fri Aug 15 2008 tiwai@suse.de
- patches.arch/ppc-ipic-suspend-without-83xx-fix: Fix build_error
  without CONFIG_PPC_83xx.
- Update config files.
* Fri Aug 15 2008 tiwai@suse.de
- Update config files: disable CONFIG_IPIC for ppc/default and
  vanilla again to fix build
* Fri Aug 15 2008 tiwai@suse.de
- rpm/kernel-binary.spec.in: fix build without firmware files
* Fri Aug 15 2008 jeffm@suse.de
- patches.kernel.org/no-include-asm: kbuild: correctly link
  include/asm in external builds.
* Fri Aug 15 2008 jeffm@suse.de
- patches.kernel.org/ath9k-workaround-gcc-ICE-again-on-powerpc:
  ath9k: work around gcc ICE again.
* Thu Aug 14 2008 jeffm@suse.de
- patches.suse/novfs-gregorian-day-fix: novfs: Fix GregorianDay
  conflict.
* Thu Aug 14 2008 jeffm@suse.de
- Enabled patches.kernel.org/firmware-path
* Thu Aug 14 2008 jeffm@suse.de
- patches.apparmor/add-security_path_permission: Fixed duplicate
  export of security_inode_permission.
* Thu Aug 14 2008 jeffm@suse.de
- patches.apparmor/add-security_path_permission: Add missing
  stub for security_path_permission when CONFIG_SECURITY_APPARMOR=n
* Thu Aug 14 2008 jeffm@suse.de
- patches.kernel.org/firmware-path: firmware: Allow
  release-specific firmware dir.
- rpm/kernel-binary.spec.in: Add firmware files.
* Thu Aug 14 2008 jeffm@suse.de
- patches.kernel.org/ia64-export-cpu_core_map: ia64: Export
  cpu_core_map for topology_core_siblings.
* Thu Aug 14 2008 jeffm@suse.de
- Updated to 2.6.27-rc3.
  - AppArmor mostly merged. There may be some hiccups.
  - Xen and RT temporarily disabled for merging.
  - 17 patches eliminated.
* Thu Aug 14 2008 ghaskins@suse.de
  Guarded by +RT
- patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch:
  seqlock: make sure that raw_seqlock_t retries readers while
  writes are pending.
- patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch:
  ftrace: fix elevated preempt_count in wakeup-tracer.
* Fri Aug  8 2008 hare@suse.de
- Update config files for RT kernel to activate SCSI
  device handler.
* Fri Aug  8 2008 jbeulich@novell.com
- patches.xen/xen3-fixup-common, patches.xen/xen3-fixup-kconfig,
  patches.xen/xen3-patch-2.6.24, patches.xen/xen3-patch-2.6.25: Fix
  a couple of bugs and inconsistencies.
* Fri Aug  8 2008 schwab@suse.de
- Fix reference to $RPM_BUILD_ROOT in makefiles.
* Fri Aug  8 2008 hare@suse.de
- patches.fixes/dm-mpath-hp-sw.patch: Delete.
- Update config files.
- patches.fixes/dm-2.6.27-update: Upstream device-mapper patches
  (FATE#302108).
- patches.fixes/scsi_dh-2.6.27-update: SCSI device handler update
  (FATE#302269,FATE#303696,FATE#303754,FATE#304125).
- patches.suse/rq-based-block-layer: rq-based multipathing:
  block layer changes (FATE#302108).
- patches.suse/rq-based-dm-interface: rq-based multipathing:
  device-mapper interface (FATE#302108).
- patches.suse/rq-based-multipath-functions: rq-based
  multipathing: request-based functions to multipath
  (FATE#302108).
* Thu Aug  7 2008 jbeulich@novell.com
- Update Xen patches to c/s 623.
- patches.xen/sfc-network-driver: Delete.
- patches.xen/xen-balloon-hvm-min: Delete.
- patches.xen/xen-netfront-flip-prod: Delete.
- patches.xen/xen-x86_64-init-cleanup: Delete.
- patches.xen/sfc-i2c: sfc: Use kernel I2C system and i2c-algo-bit
  driver (disabled).
- patches.xen/sfc-driverlink: Solarflare: Resource driver (disabled).
- Update Xen config files.
* Wed Aug  6 2008 olh@suse.de
- add patches.suse/ppc-no-LDFLAGS_MODULE.patch
  do not link external modules against arch/powerpc/lib/crtsavres.o
* Tue Aug  5 2008 jeffm@suse.de
- patches.fixes/reiserfs-commit-ids-unsigned-ints: reiserfs:
  audit transaction ids to always be unsigned ints (bnc#410847).
* Tue Aug  5 2008 jeffm@suse.de
- README.BRANCH: Took ownership of 11.1 tree.
* Tue Aug  5 2008 jeffm@suse.de
- README: Changed w3d links to wiki links.
* Tue Aug  5 2008 ghaskins@suse.de
  Fixed misnamed rt_trace to rt_timing
- config/x86_64/rt_trace: Delete.
- Update config files.
- config.conf:
* Tue Aug  5 2008 ghaskins@suse.de
  Added x86_64/rt_trace kernel flavor (based on ftrace)
- Update config files.
- config.conf:
* Tue Aug  5 2008 ghaskins@suse.de
  Guarded by +RT
- Fix rtmutex-tester build problem with rt_debug
- patches.rt/rtmutex-convert-to-libpi.patch: rtmutex: convert
  rtmutexes to fully use the PI library.
* Tue Aug  5 2008 ghaskins@suse.de
  Guarded by +RT
- Remove version.patch to stop build breakage
* Tue Aug  5 2008 jjohansen@suse.de
- update apparmor patches with fixes for
  - broken getcwd (bnc#413915)
  - ref counting bug in getcwd and d_namespace_path when used
    on disconnected paths (bnc#414607)
  - typeo in patches that keep selinux from compiling (bnc#414609)
  - incorporate smack patch into base apparmor patches, so
    that smack can be built (bnc#414610)
* Tue Aug  5 2008 jslaby@suse.de
- patches.fixes/ath5k-fix-memory-corruption.patch: Ath5k: fix
  memory corruption (bnc#414635).
- patches.fixes/ath5k-kill-tasklets-on-shutdown.patch: Ath5k:
  kill tasklets on shutdown (bnc#414638).
* Mon Aug  4 2008 gregkh@suse.de
- README.BRANCH: added file.
* Mon Aug  4 2008 olh@suse.de
- disable CONFIG_SECURITY_ROOTPLUG because /init in initrd will
  not run if USB is compiled in and a specific USB device is not
  present
* Mon Aug  4 2008 jslaby@suse.de
- patches.fixes/tpm-write-data-types.patch: tpm: Use correct
  data types for sizes in tpm_write() and tpm_read() (bnc#400211).
* Fri Aug  1 2008 ghaskins@suse.de
  PI rework v0.5 and a fix from upstream for 26-rt1
- patches.rt/26-rt1-chirag.patch: This patch should solve some
  of the bug messages..
- patches.rt/add-generalized-pi-interface.patch: add generalized
  priority-inheritance interface.
- patches.rt/tie-pi-into-task.patch: sched: add the basic PI
  infrastructure to the task_struct.
- patches.rt/rtmutex-initialize-waiters.patch: rtmutex: formally
  initialize the rt_mutex_waiters.
- patches.rt/rtmutex-add_readers.patch: RT: wrap the rt_rwlock
  "add reader" logic.
- patches.rt/rtmutex-use-runtime-init.patch: rtmutex: use runtime
  init for rtmutexes.
- patches.rt/rtmutex-convert-to-libpi.patch: rtmutex: convert
  rtmutexes to fully use the PI library.
- patches.rt/rtmutex-defer-pi-until-sleepy.patch: rtmutex:
  pi-boost locks as late as possible.
* Fri Aug  1 2008 schwab@suse.de
- Reenable EFI_RTC.
* Fri Aug  1 2008 trenn@suse.de
- Update config files.
  Unset on forgotten archs:
  CONFIG_X86_REROUTE_FOR_BROKEN_BOOT_IRQS
* Fri Aug  1 2008 trenn@suse.de
- patches.fixes/x86_hpet_amd_quirk.patch: Workaround a hpet BIOS
  bug which is common on latest AMD driven boards (bnc#387053).
* Fri Aug  1 2008 sassmann@suse.de
  Add boot interrupt patches from linux-2.6-tip
- patches.arch/x86-acpi-reroute-PCI-interrupt-to-legacy-boot-interrupt.patch
- patches.arch/x86-add-PCI-IDs-for-devices-that-need-boot-irq-quirk.patch
- patches.arch/x86-disable-AMD-ATI-boot-interrupt-generation.patch
- patches.arch/x86-disable-broadcomm-boot-interrupt-generation.patch
- patches.arch/x86-disable-intel-boot-interrupt-generation.patch
- patches.arch/x86-introduce-config-option-for-pci-reroute-quirks.patch
- patches.arch/x86-introduce-pci-ioapicreroute-kernel-cmdline.patch
- patches.arch/x86-introduce-pci-noioapicquirk-kernel-cmdline.patch
- Update config files.
  * reroute of boot interrupts is enabled for RT only!
* Thu Jul 31 2008 sdietrich@suse.de
  Update to 2.6.26-rt1:
- config.conf: Enable i386/x86_64 - RT / RT_debug
- Update config files:
  * Sync to default config.
  * Disable (broken):
  - Novell Netware Filesystem support (novfs) (EXPERIMENTAL) (NOVFS)
  - ISP 1760 HCD support (USB_ISP1760_HCD)
  - KDB
  - QLogic InfiniPath Driver (INFINIBAND_IPATH)
  Remove obsolete patches:
- patches.rt/arm-cmpxchg-support-armv6.patch: Delete.
- patches.rt/arm-cmpxchg.patch: Delete.
- patches.rt/arm-fix-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-leds-timer.patch: Delete.
- patches.rt/arm-omap-03.patch: Delete.
- patches.rt/arm-omap-04.patch: Delete.
- patches.rt/disable-sched-rt-groups.patch: Delete.
- patches.rt/drivers-edac-add-support-for-HS21XM-SMI-remediation:
  Delete.
- patches.rt/drivers-edac-add-support-for-HS21_LS21-SMI-remediation:
  Delete.
- patches.rt/drivers-edac-add-sysfs_notify-calls.patch: Delete.
- patches.rt/drivers-edac-i5000-turn-off-unsupported-check:
  Delete.
- patches.rt/drivers-edac-new-amd64.patch: Delete.
- patches.rt/drivers-edac-new-k8-rev-f.patch: Delete.
- patches.rt/drivers-edac-prevent-potential-printk-storm: Delete.
- patches.rt/drivers-edac-test_device.patch: Delete.
- patches.rt/ep93xx-clockevents-fix.patch: Delete.
- patches.rt/ep93xx-clockevents.patch: Delete.
- patches.rt/ep93xx-timer-accuracy.patch: Delete.
- patches.rt/fix-alternate_node_alloc.patch: Delete.
- patches.rt/fix-irq-flags-size.patch: Delete.
- patches.rt/foo.patch: Delete.
- patches.rt/ftrace-add-nr_syscalls.patch: Delete.
- patches.rt/ftrace-alloc-pages.patch: Delete.
- patches.rt/ftrace-cpu-clock-update.patch: Delete.
- patches.rt/ftrace-debug-use-preempt-disable-notrace.patch:
  Delete.
- patches.rt/ftrace-direct-calls.patch: Delete.
- patches.rt/ftrace-disable-daemon.patch: Delete.
- patches.rt/ftrace-dont-use-raw-irq-save.patch: Delete.
- patches.rt/ftrace-eventtrace-fixup.patch: Delete.
- patches.rt/ftrace-filter-functions.patch: Delete.
- patches.rt/ftrace-fix-ip.patch: Delete.
- patches.rt/ftrace-flip-fix.patch: Delete.
- patches.rt/ftrace-handle-time-outside-of-lockdep.patch: Delete.
- patches.rt/ftrace-irqsoff-smp-processor-id-fix.patch: Delete.
- patches.rt/ftrace-lockdep-notrace-annotations.patch: Delete.
- patches.rt/ftrace-max-update-fixes.patch: Delete.
- patches.rt/ftrace-move-memory-management-to-generic.patch:
  Delete.
- patches.rt/ftrace-nop-calls.patch: Delete.
- patches.rt/ftrace-peterz-cpu_clock.patch: Delete.
- patches.rt/ftrace-remove-max-printks.patch: Delete.
- patches.rt/ftrace-safe-traversal-hlist.patch: Delete.
- patches.rt/ftrace-stop-function-trace-fix.patch: Delete.
- patches.rt/ftrace-unlock-mutex-in-output.patch: Delete.
- patches.rt/ftrace-update-cnt-stat-fix.patch: Delete.
- patches.rt/ftracer-build-fix.patch: Delete.
- patches.rt/futex-performance-hack-sysctl-fix.patch: Delete.
- patches.rt/futex-performance-hack.patch: Delete.
- patches.rt/git-ignore-module-markers.patch: Delete.
- patches.rt/irq-flags-unsigned-long.patch: Delete.
- patches.rt/kernel-bug-after-entering-something-from-login.patch:
  Delete.
- patches.rt/kthread-cpus-allowed-init.patch: Delete.
- patches.rt/kvm-lapic-migrate-latency-fix.patch: Delete.
- patches.rt/kvm-make-less-noise.patch: Delete.
- patches.rt/kvm-preempt-rt-resched-delayed.patch: Delete.
- patches.rt/latency-tracing-prctl-api-hack.patch: Delete.
- patches.rt/netfilter-more-debugging.patch: Delete.
- patches.rt/page-alloc-use-real-time-pcp-locking-for-page-draining.patch:
  Delete.
- patches.rt/pcounter-percpu-protect.patch: Delete.
- patches.rt/percpu-locked-powerpc-fixups-a6.patch: Delete.
- patches.rt/powerpc-rearrange-thread-flags-to-work-with-andi-instruction.patch:
  Delete.
- patches.rt/ppc-add-mcount.patch: Delete.
- patches.rt/ppc-add-ppc32-mcount.patch: Delete.
- patches.rt/ppc-mark-notrace-mainline.patch: Delete.
- patches.rt/ppc-mcount-dummy-functions.patch: Delete.
- patches.rt/ppc-rename-xmon-mcount.patch: Delete.
- patches.rt/ppc-select-mcount.patch: Delete.
- patches.rt/preempt-irqs-ppc-celleb-beatic-eoi.patch: Delete.
- patches.rt/preempt-irqs-softirq-in-hardirq.patch: Delete.
- patches.rt/preempt-realtime-powerpc-a7.patch: Delete.
- patches.rt/preempt-realtime-ppc-more-resched-fixups.patch:
  Delete.
- patches.rt/preempt-realtime-ppc-need-resched-delayed.patch:
  Delete.
- patches.rt/preempt-realtime-sh.patch: Delete.
- patches.rt/preempt-realtime-supress-cpulock-warning.patch:
  Delete.
- patches.rt/rcu-preempt-trace-markers-1.patch: Delete.
- patches.rt/rcu-preempt-trace-markers-2.patch: Delete.
- patches.rt/rcu-various-fixups.patch: Delete.
- patches.rt/rt-mutex-arm-fix.patch: Delete.
- patches.rt/rt-mutex-delayed-resched.patch: Delete.
- patches.rt/rt-mutex-drop-generic-TIF_NEED_RESCHED_DELAYED.patch:
  Delete.
- patches.rt/rt-time-starvation-fix.patch: Delete.
- patches.rt/rtmutex-adaptive-locks.patch: Delete.
- patches.rt/rtmutex-adaptive-timeout.patch: Delete.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
- patches.rt/sched-fix-rt-task-wakeup.patch: Delete.
- patches.rt/sched-fix-sched-fair-wakeup.patch: Delete.
- patches.rt/sched-rt-push-only-new.patch: Delete.
- patches.rt/schedule_on_each_cpu-enhance-rt.patch: Delete.
- patches.rt/tasklet-fix-preemption-race.patch: Delete.
- patches.rt/tasklet-more-fixes.patch: Delete.
- patches.rt/time-gcc-linker-error.patch: Delete.
- patches.rt/tracer-use-sched-clock.patch: Delete.
- patches.rt/write-try-lock-irqsave.patch: Delete.
- patches.rt/x86-delay-enable-preempt-tglx.patch: Delete.
  Introduce 2.6.26-RT1:
- patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch:
  Linux-RT 2.6.26-RT
  radix-tree: gang slot lookups.
- patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch: Linux-RT
  2.6.26-RT
  mm: lockless probe.
- patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch:
  Linux-RT 2.6.26-RT
  mm: speculative get page.
- patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch:
  Linux-RT 2.6.26-RT
  mm: lockless pagecache lookups.
- patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch:
  Linux-RT 2.6.26-RT
  mm: spinlock tree_lock.
- patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/RT_utsname.patch: Linux-RT 2.6.26-RT.
- patches.rt/aacraid-compat-sem.patch: Linux-RT 2.6.26-RT.
- patches.rt/adapt-remove-extra-try-to-lock.patch: Linux-RT
  2.6.26-RT.
- patches.rt/adaptive-adjust-pi-wakeup.patch: Linux-RT 2.6.26-RT.
- patches.rt/adaptive-earlybreak-on-steal.patch: Linux-RT
  2.6.26-RT
  rtmutex: break out early on first run.
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch: Linux-RT
  2.6.26-RT.
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.26-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.26-RT.
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.26-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-compile-fix.patch: Linux-RT 2.6.26-RT
  ARM: compile fix for event tracing.
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-latency-tracer-support.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-02.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-05.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-preempt-config.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-trace-preempt-idle.patch: Linux-RT 2.6.26-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/cache_pci_find_capability.patch: Linux-RT 2.6.26-RT
  Cache calls to pci_find_capability.
- patches.rt/call_rcu_bh-rename-of-call_rcu.patch: Linux-RT
  2.6.26-RT
  just rename call_rcu_bh instead of making it a macro.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.26-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.26-RT.
- patches.rt/cycles-to-ns-trace-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-irqpoll.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-lpptest-on-nonlinux.patch: Linux-RT
  2.6.26-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.26-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.26-RT.
- patches.rt/dont-let-rt-rw_semaphores-do-non_owner-locks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.26-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.26-RT.
- patches.rt/event-tracer-syscall-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.26-RT.
- patches.rt/export-schedule-on-each-cpu.patch: Linux-RT
  2.6.26-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-acpi-build-weirdness.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.26-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-circular-locking-deadlock.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-emac-locking-2.6.16.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-emergency-reboot.patch: Linux-RT 2.6.26-RT
  call reboot notifier list when doing an emergency reboot.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch: Linux-RT 2.6.26-RT.
- patches.rt/floppy-resume-fix.patch: Linux-RT 2.6.26-RT
  floppy: suspend/resume fix.
- patches.rt/ftrace-compile-fixes.patch: Linux-RT 2.6.26-RT
  rt: remove call to stop tracer.
- patches.rt/ftrace-dont-trace-markers.patch: Linux-RT 2.6.26-RT
  ftrace: dont trace markers.
- patches.rt/ftrace-fix-header.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-function-record-nop.patch: Linux-RT 2.6.26-RT
  ftrace: define function trace nop.
- patches.rt/ftrace-print-missing-cmdline.patch: Linux-RT
  2.6.26-RT
  ftrace: fix the command line printing.
- patches.rt/ftrace-record-comm-on-ctrl.patch: Linux-RT 2.6.26-RT
  ftrace: record comm on function ctrl change.
- patches.rt/ftrace-trace-sched.patch: Linux-RT 2.6.26-RT
  ftrace: trace sched.c.
- patches.rt/ftrace-upstream.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-use-preempt-disable-not-irq-disable.patch:
  Linux-RT 2.6.26-RT
  ftrace: avoid lockdep recursion.
- patches.rt/gcc-warnings-shut-up.patch: Linux-RT 2.6.26-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.26-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.26-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/git-ignore-script-lpp.patch: Linux-RT 2.6.26-RT.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.26-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/hack-fix-rt-migration.patch: Linux-RT 2.6.26-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.26-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem-redo-mainline.patch: Linux-RT 2.6.26-RT.
- patches.rt/highmem-revert-mainline.patch: Linux-RT 2.6.26-RT.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.26-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.26-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.26-RT.
- patches.rt/i386-mark-atomic-irq-ops-raw.patch: Linux-RT
  2.6.26-RT.
- patches.rt/i386-nmi-watchdog-show-regs.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.26-RT.
- patches.rt/irda-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/irq-mask-fix.patch: Linux-RT 2.6.26-RT
  genirq: fix simple and fasteoi irq handlers.
- patches.rt/jbd_assertions_smp_only.patch: Linux-RT 2.6.26-RT.
- patches.rt/kmap-atomic-i386-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/kmap-atomic-prepare.patch: Linux-RT 2.6.26-RT.
- patches.rt/kprobes-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.26-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/latency-measurement-drivers.patch: Linux-RT
  2.6.26-RT.
- patches.rt/latency-tracing-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/latency-tracing-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.26-RT.
- patches.rt/local_irq_save_nort-in-swap.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lock-init-plist-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/lock_list.patch: Linux-RT 2.6.26-RT
  lock_list - a fine grain locked double linked list.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.26-RT
  mm: lock_page_ref.
- patches.rt/lockdep-avoid-fork-waring.patch: Linux-RT 2.6.26-RT
  ftrace: fix if define to prove locking.
- patches.rt/lockdep-lock_set_subclass.patch: Linux-RT 2.6.26-RT
  lockdep: lock_set_subclass - reset a held lock's subclass.
- patches.rt/lockdep-more-entries.patch: Linux-RT 2.6.26-RT.
- patches.rt/lockdep-prettify.patch: Linux-RT 2.6.26-RT
  lockdep: prettify output.
- patches.rt/lockdep-rt-mutex.patch: Linux-RT 2.6.26-RT
  lockdep-rt: annotate PREEMPT_RT DEFINE_MUTEX.
- patches.rt/lockdep-rt-recursion-limit-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.26-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/lockdep_lock_set_subclass_fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lockstat-fix-contention-points.patch: Linux-RT
  2.6.26-RT
  lockstat: fix contention points.
- patches.rt/lockstat-output.patch: Linux-RT 2.6.26-RT
  lockstat: warn about disabled lock debugging.
- patches.rt/lockstat-rt-hooks.patch: Linux-RT 2.6.26-RT.
- patches.rt/lockstat_bounce_rt.patch: Linux-RT 2.6.26-RT.
- patches.rt/loopback-revert.patch: Linux-RT 2.6.26-RT.
- patches.rt/mapping_nrpages.patch: Linux-RT 2.6.26-RT
  mm/fs: abstract address_space::nrpages.
- patches.rt/mips-change-raw-spinlock-type.patch: Linux-RT
  2.6.26-RT
  RT: change from raw_spinlock_t to __raw_spinlock_t.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Linux-RT 2.6.26-RT
  RT: remove conflicting rtc_lock declaration.
- patches.rt/mips-remove-duplicate-kconfig.patch: Linux-RT
  2.6.26-RT.
- patches.rt/mips-remove-finish-arch-switch.patch: Linux-RT
  2.6.26-RT
  RT: remove finish_arch_switch.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.26-RT.
- patches.rt/mm-concurrent-pagecache-rt.patch: Linux-RT 2.6.26-RT
  mm: -rt bits for concurrent pagecache.
- patches.rt/mm-concurrent-pagecache.patch: Linux-RT 2.6.26-RT
  mm: concurrent pagecache write side.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.26-RT
  reduce pagetable-freeing latencies.
- patches.rt/move-native-irq.patch: Linux-RT 2.6.26-RT.
- patches.rt/msi-suspend-resume-workaround.patch: Linux-RT
  2.6.26-RT.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.26-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.26-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.26-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.26-RT
  read lock Priority Inheritance implementation.
- patches.rt/native-sched-clock-booboo.patch: Linux-RT 2.6.26-RT.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.26-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/netpoll-8139too-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.26-RT
  softirq preemption: optimization.
- patches.rt/nf_conntrack-fix-smp-processor-id.patch: Linux-RT
  2.6.26-RT.
- patches.rt/nf_conntrack-weird-crash-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.26-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/nmi-profiling.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-show-regs-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-disable.patch: Linux-RT 2.6.26-RT
  x86_64: do not enable the NMI watchdog by default.
- patches.rt/nmi-watchdog-fix-1.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-2.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-3.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-4.patch: Linux-RT 2.6.26-RT.
- patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch:
  Linux-RT 2.6.26-RT
  local_bh_enable() is safe for irqs_disabled().
- patches.rt/ntfs-local-irq-save-nort.patch: Linux-RT 2.6.26-RT.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.26-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.26-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.26-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.26-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/percpu-locked-mm.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-netfilter.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-netfilter2.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-powerpc-fixups.patch: Linux-RT
  2.6.26-RT.
- patches.rt/percpu_list.patch: Linux-RT 2.6.26-RT
  percpu_list.
- patches.rt/plist-debug.patch: Linux-RT 2.6.26-RT.
- patches.rt/posix-cpu-timers-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/powerpc-flush_tlb_pending-is-no-more.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/powerpc-match-__rw_yield-function-declaration-to-prototype.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ppc-chpr-set-rtc-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-gtod-notrace-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ppc-make-tlb-batch-64-only.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-tlbflush-preempt.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc32-latency-compile-hack-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ppc32_notrace_init_functions.patch: Linux-RT
  2.6.26-RT
  don't trace early init functions for ppc32.
- patches.rt/preempt-irqs-Kconfig.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-i386-idle-poll-loop-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-ack-irq-fixups.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-b5.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-b6.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-more-fasteoi.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-ppc-preempt-schedule-irq-entry-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-x86-64.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-bagde4.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-footbridge.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-integrator.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-pxa.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-shark.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-compile-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ftrace.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ide.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-input.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-loopback.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mellanox-driver-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.26-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-add-raw-relax-macros.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b2.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b3.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-celleb-raw-spinlocks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-missing-raw-spinlocks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-tlb-batching.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.26-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-profiling.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-rcu.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-sched-cpupri.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-sched-i386.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-sound.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-supress-nohz-softirq-warning.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-supress-rtc-printk.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-usb.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-warn-and-bug-on-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-warn-and-bug-on.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.26-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.26-RT.
- patches.rt/printk-dont-bug-on-sched.patch: Linux-RT 2.6.26-RT.
- patches.rt/printk-in-atomic-hack-fix.patch: Linux-RT 2.6.26-RT
  fix printk in atomic hack.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.26-RT.
- patches.rt/proportions-raw-locks.patch: Linux-RT 2.6.26-RT.
- patches.rt/qrcu.patch: Linux-RT 2.6.26-RT
  QRCU with lockless fastpath.
- patches.rt/quicklist-release-before-free-page-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/quicklist-release-before-free-page.patch: Linux-RT
  2.6.26-RT.
- patches.rt/radix-concurrent-lockdep.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-percpu-hack-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.26-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.26-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.26-RT
  radix-tree: optimistic locking.
- patches.rt/random-driver-latency-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-hrt-fixups.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-new-7.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-default.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-fix-bad-dyntick-accounting.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rcu-torture-preempt-update.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-trace-fix-free.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcupreempt-boost-early-init.patch: Linux-RT
  2.6.26-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.26-RT.
- patches.rt/relay-fix.patch: Linux-RT 2.6.26-RT
  relay: fix timer madness.
- patches.rt/remove-check-pgt-cache-calls.patch: Linux-RT
  2.6.26-RT.
- patches.rt/replace-bugon-by-warn-on.patch: Linux-RT 2.6.26-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-apis.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-avoid-deadlock-in-swap.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-delayed-prio.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: propagate prio for delayed work.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-list-mods.patch: Linux-RT 2.6.26-RT
  rt: list_splice2.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.26-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-irq-flags-checking.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-ppc-fix-a5.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-page_alloc.patch: Linux-RT 2.6.26-RT
  rt-friendly per-cpu pages.
- patches.rt/rt-plist-mods.patch: Linux-RT 2.6.26-RT
  rt: plist_head_splice.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-sched-groups.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-slab-new.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-workqeue-prio.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue support.
- patches.rt/rt-workqueue-barrier.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: fix barriers.
- patches.rt/rt-wq-barrier-fix.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: wait_on_work() fixup.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.26-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/rtmutex-debug.h-cleanup.patch: Linux-RT 2.6.26-RT
  lock debugging: clean up rtmutex-debug.h.
- patches.rt/rtmutex-lateral-steal.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-rearrange.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-remove-xchg.patch: Linux-RT 2.6.26-RT
  rtmutex - remove double xchg.
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-implement-downgrade-write.patch: Linux-RT
  2.6.26-RT
  rwlocks multi downgrade write.
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlocks-fix-no-preempt-rt.patch: Linux-RT 2.6.26-RT
  rwlock: fix non PREEMPT_RT case.
- patches.rt/rwlocks-multiple-readers.patch: Linux-RT 2.6.26-RT
  implement rwlocks management.
- patches.rt/rwsems-multiple-readers.patch: Linux-RT 2.6.26-RT
  add framework for multi readers on rwsems.
- patches.rt/s_files-pipe-fix.patch: Linux-RT 2.6.26-RT
  s_files: free_write_pipe() fix.
- patches.rt/s_files-schedule_on_each_cpu_wq.patch: Linux-RT
  2.6.26-RT.
- patches.rt/s_files.patch: Linux-RT 2.6.26-RT
  remove global files_lock.
- patches.rt/sched-clock-nmi.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.26-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-rt-stats.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched_prio.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched_rt-fixup.patch: Linux-RT 2.6.26-RT.
- patches.rt/schedule-tail-balance-disable-irqs.patch: Linux-RT
  2.6.26-RT.
- patches.rt/schedule_on_each_cpu-enhance.patch: Linux-RT
  2.6.26-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/send-nmi-all-preempt-disable.patch: Linux-RT
  2.6.26-RT.
- patches.rt/seq-irqsave.patch: Linux-RT 2.6.26-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.26-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.26-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.26-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/softlockup-add-irq-regs-h.patch: Linux-RT 2.6.26-RT
  core: make asm/irq_regs.h available on every platform.
- patches.rt/spinlock-trylock-cleanup-sungem.patch: Linux-RT
  2.6.26-RT.
- patches.rt/swap-spinlock-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.26-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.26-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.26-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace-add-event-markers-arm.patch: Linux-RT
  2.6.26-RT.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.26-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace_hist-divzero.patch: Linux-RT 2.6.26-RT
  trace_hist.c: divide-by-zero problem (2).
- patches.rt/trace_hist-latediv.patch: Linux-RT 2.6.26-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.26-RT.
- patches.rt/tracer-event-trace.patch: Linux-RT 2.6.26-RT.
- patches.rt/use-edge-triggered-irq-handler-instead-of-simple-irq.patch:
  Linux-RT 2.6.26-RT
  [AT91: PATCH]: Use edge triggered interrupt handling for
  AT91-GPIO instead of simple_irq-handler.
- patches.rt/user-no-irq-disable.patch: Linux-RT 2.6.26-RT.
- patches.rt/version.patch: Linux-RT 2.6.26-RT
  add -rt extra-version.
- patches.rt/vortex-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/x86-64-tscless-vgettimeofday.patch: Linux-RT
  2.6.26-RT
  x86_64 GTOD: offer scalable vgettimeofday.
- patches.rt/x86_64-tsc-sync-irqflags-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.26-RT
  event-tracer: add clockevent trace.
- patches.rt/ftrace-hotplug-fix.patch: Linux-RT 2.6.26-RT
  ftrace: cpu hotplug fix.
- patches.rt/ftrace-wakeup-rawspinlock.patch: Linux-RT 2.6.26-RT
  ftrace: user raw spin lock for wakeup function trace.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-tree-lockdep-plus1.patch: Linux-RT 2.6.26-RT
  lockdep: add +1 to radix tree array.
- patches.rt/rwlock-fixes.patch: Linux-RT 2.6.26-RT
  rwlock: fix pi_list race conditions.
- patches.rt/rwlock-prio-fix.patch: Linux-RT 2.6.26-RT
  rwlock: reset prio on unlocks and wakeups.
- patches.rt/rwlock-torture.patch: Linux-RT 2.6.26-RT
  rwlock: rwlock torture test.
- patches.rt/sched-cpupri-hotplug-support.patch: Linux-RT
  2.6.26-RT.
- patches.rt/sched-cpupri-priocount.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace-eip2ip.patch: Linux-RT 2.6.26-RT
  Re: 2.6.25.4-rt4.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-adaptive-hack.patch: Linux-RT 2.6.26-RT
  fix-adaptive-hack.patch.
- patches.rt/fix-a-previously-reverted-fix.patch: Linux-RT
  2.6.26-RT
  Fix a previously reverted "fix".
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.26-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/frace-use-tsc.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-document-event-tracer.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ftrace-document-update1.patch: Linux-RT 2.6.26-RT
  ftrace: document updates.
- patches.rt/ftrace-fix-get-kprobe-wreckage.patch: Linux-RT
  2.6.26-RT
  ftrace-fix-missing-kprobe-include.pathc.
- patches.rt/ftrace-m68knommu-add-FTRACE-support.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ftrace-m68knommu-generic-stacktrace-function.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ftrace-preempt-trace-check.patch: Linux-RT 2.6.26-RT
  ftrace: only trace preempt off with preempt tracer.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.26-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/generic-cmpxchg-use-raw-local-irq-variant.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/idle2-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/idle-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch: Linux-RT
  2.6.26-RT.
- patches.rt/m68knommu-make-cmpxchg-RT-safe.patch: Linux-RT
  2.6.26-RT.
- patches.rt/mapping_nrpages-fix.patch: Linux-RT 2.6.26-RT
  mapping_nrpages-fix.patch.
- patches.rt/nfs-stats-miss-preemption.patch: Linux-RT 2.6.26-RT
  nfs: fix missing preemption check.
- patches.rt/pmtmr-override.patch: Linux-RT 2.6.26-RT
  pmtmr: allow command line override of ioport.
- patches.rt/powerpc-ftrace-stop-on-oops.patch: Linux-RT 2.6.26-RT
  powerpc: ftrace stop on crash.
- patches.rt/ppc64-fix-preempt-unsafe-paths-accessing-per_cpu-variables.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-m68knommu-make-timer-interrupt-non-threaded.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mm.patch~: Linux-RT 2.6.26-RT.
- patches.rt/raw-spinlocks-for-nmi-print.patch: Linux-RT
  2.6.26-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-debug-fix.patch: Linux-RT 2.6.26-RT
  rtmutex-debug-fix.patch.
- patches.rt/rt-mutex-namespace.patch: Linux-RT 2.6.26-RT
  rt-mutex-namespace.patch.
- patches.rt/rt-mutex-use-inline.patch: Linux-RT 2.6.26-RT
  rt-mutex-cleanup.patch.
- patches.rt/rt-rwlock-conservative-locking.patch: Linux-RT
  2.6.26-RT
  rwlock: be more conservative in locking reader_lock_count.
- patches.rt/rwlock-pi-lock-reader.patch: Linux-RT 2.6.26-RT.
- patches.rt/rwlock-protect-reader_lock_count.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-slowunlock-mutex-fix2.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-slowunlock-mutex-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-torture-no-rt.patch: Linux-RT 2.6.26-RT
  rwlock: fix torture test to handle non-rt.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.26-RT
  sched-fix-dequeued-race.patch.
- patches.rt/serial-locking-rt-cleanup.patch~: Linux-RT 2.6.26-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.26-RT
  rt: dont disable irqs in usb.
- patches.rt/trace-do-not-wakeup-when-irqs-disabled.patch:
  Linux-RT 2.6.26-RT
  trace-do-not-wakeup-when-irqs-disabled.patch.
- patches.rt/trace-ktime-scalar.patch: Linux-RT 2.6.26-RT
  ftrace: print ktime values in readable form.
- patches.rt/warn-on-rt-scatterlist.patch: Linux-RT 2.6.26-RT
  remove warn on for scatterlist in preempt rt.
* Tue Jul 29 2008 trenn@suse.de
- patches.arch/acpi_thermal_passive_blacklist.patch: Avoid
  critical temp shutdowns on specific ThinkPad T4x(p) and R40
  (https://bugzilla.novell.com/show_bug.cgi?id=333043).
- patches.fixes/acpi_use_acpi_exception.patch: ACPI dock/bay:
  Use ACPI_EXCEPTION instead of printk(KERN_ERR.
- patches.suse/acpi_provide_non_windows_osi_boot_param.patch:
  ACPI: Provide a spec conform OSI interface to the BIOS.
* Mon Jul 28 2008 bphilips@suse.de
- rpm/kernel-binary.spec.in: uvcvideo merged.  Add Obsoletes.
* Fri Jul 25 2008 mszeredi@suse.cz
- supported.conf: Mark fuse as supported.
* Thu Jul 24 2008 gregkh@suse.de
- Enable CONFIG_MARKERS
* Thu Jul 24 2008 gregkh@suse.de
- Enable CONFIG_SECURITY_SELINUX
* Thu Jul 24 2008 agruen@suse.de
- Fix for using relative paths in /usr/src/linux-obj/$arch/
  $flavor/Makefile (bnc#409982).
* Fri Jul 18 2008 hare@suse.de
- Update config files for S/390.
* Thu Jul 17 2008 bwalle@suse.de
- patches.fixes/show-OSRELEASE-in-VMCOREINFO.diff:
  kdump: Report actual value of VMCOREINFO_OSRELEASE in VMCOREINFO
* Thu Jul 17 2008 jeffm@suse.de
- rpm/kernel-module-subpackage: Removed Supplements handling
  entirely. Use preamble instead.
* Thu Jul 17 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.26: Fix 32-bit build.
* Thu Jul 17 2008 jbeulich@novell.com
- Update Xen patches for 2.6.26.
- patches.xen/540-blkif-nr-segments-check.patch: Delete.
- patches.xen/560-x86_64-no-irq-affinity-break-msg.patch: Delete.
- patches.xen/xen3-patch-2.6.25.1: Delete.
- Update i386 and x86-64 config files.
- config.conf: Re-enable Xen configs.
* Thu Jul 17 2008 jbeulich@novell.com
- patches.fixes/seccomp-disable-tsc-option: Also handle x86-64 (191123).
- Update x86-64 config files.
- patches.suse/raw_device_max_minors_param.diff: Fix uninitialized
  return value.
- patches.apparmor/remove_suid.diff: Also handle fuse.
- supported.conf: Add e1000e, rtc-core, rtc-lib, and rtc-cmos.
* Mon Jul 14 2008 jeffm@suse.de
- patches.kernel.org/fsl-diu-fb-compile-fix: Delete.
* Mon Jul 14 2008 olh@suse.de
- disable unused fsl-diu-fb driver
* Mon Jul 14 2008 jeffm@suse.de
- Updated to 2.6.26-final.
* Mon Jul 14 2008 bwalle@suse.de
- patches.fixes/move-crashkernel-reservation.diff:
  x86: Move crashkernel reservation before dma32_reserve_bootmem().
* Mon Jul 14 2008 rgoldwyn@suse.de
- Enable patches.suse/convert-novfs-to-open-soure-coding-standards.patch
  Fix oops in novfs_daemon_lib_ioctl
* Fri Jul 11 2008 jeffm@suse.de
- Updated squashfs to v3.3. (bnc#373285)
* Thu Jul 10 2008 jeffm@suse.de
- Update config files: Enable raw devices on s390.
* Thu Jul 10 2008 jack@suse.cz
- patches.suse/raw_device_max_minors_param.diff: Allow setting
  of number of raw devices as a module parameter (FATE 302178).
* Thu Jul 10 2008 jeffm@suse.de
- patches.kernel.org/fsl-diu-fb-compile-fix: fsl-diu-fb:
  compile fix.
* Wed Jul  9 2008 jeffm@suse.de
- patches.suse/kdb-common: Removed obsolete file_lock_operations
  printing.
* Wed Jul  9 2008 jeffm@suse.de
- patches.fixes/reiserfs-discard-xattr-prealloc: Upstreamed with
  - git5.
* Wed Jul  9 2008 jeffm@suse.de
- patches.fixes/reiserfs-discard-xattr-prealloc: reiserfs:
  discard prealloc in reiserfs_delete_inode (bnc#389656).
* Wed Jul  9 2008 jeffm@suse.de
- Updated to 2.6.26-rc9-git5.
  - Eliminated 2 patches.
* Wed Jul  9 2008 jbohac@suse.cz
- Update config files.
- patches.suse/netfilter-ip_conntrack_slp.patch: connection
  tracking helper for SLP (fate#301134).
* Wed Jul  9 2008 olh@suse.de
- enable PHYP-assisted OS dump (fate#304131)
* Mon Jul  7 2008 trenn@suse.de
- patches.fixes/acpi_thermal_passive_cleanup.patch: Delete.
* Wed Jul  2 2008 jkosina@suse.de
- patches.fixes/input-add-gericom-bellagio-to-nomux.patch: Input:
  add Gericom Bellagio to nomux blacklist (bnc#404892).
* Wed Jul  2 2008 jkosina@suse.de
- patches.fixes/input-add-acer-aspire-1360-to-nomux.patch: Input:
  add Acer Aspire 1360 to nomux blacklist (bnc#216857).
* Wed Jul  2 2008 jeffm@suse.de
- patches.apparmor/__d_path-keep-connected.diff
  patches.apparmor/mount-consistent-__d_path.diff
  patches.suse/kdb-ia64: Edited to apply with --fuzz=0
- Added --fuzz=0 (-F0) to sequence-patch.sh and spec files
* Fri Jun 27 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: don't generate the makedumpfile.config
  any more, the new kernel, kexec-tools and makedumpfile is able to
  extract that information from the running kernel and pass it
  as ELF NOTE (in /proc/vmcore)
* Thu Jun 26 2008 olh@suse.de
- add patches.arch/ppc-ibmebus-modalias.patch
  autoload ehea and ehca (bnc#394602 - LTC44938)
* Thu Jun 26 2008 sdietrich@suse.de
- RT:  Update config files - enable CONFIG_CGROUPS
* Thu Jun 26 2008 sdietrich@suse.de
- Update config files - enable CPUSETs support:
  CONFIG_CGROUPS, CONFIG_CGROUP_NS, CONFIG_CGROUP_DEVICE,
  CONFIG_CPUSET, CONFIG_CGROUP_CPUACCT,
  CONFIG_RESOURCE_COUNTERS, CONFIG_MM_OWNER,
  CONFIG_CGROUP_MEM_RES_CTLR, CONFIG_PROC_PID_CPUSET
- debug only: CONFIG_CGROUP_DEBUG
* Wed Jun 25 2008 jeffm@suse.de
- Updated to 2.6.26-rc8
  - Eliminated 1 patch.
* Wed Jun 25 2008 jeffm@suse.de
- rpm/kernel-module-subpackage: Added Supplements tag copying and added
    coreutils and grep to Requires
- rpm/macros.kernel-source: Added kernel-syms to BuildRequires
* Wed Jun 25 2008 olh@suse.de
- enable 64K pages in config ppc64 (fate#304100)
- enable up to 1024 cpus in config ppc64 (fate#304180)
- enable up to 4 cpus in config kdump
- enable powermanagement in config ppc64
- enable cell be cpufreq
* Wed Jun 25 2008 jdelvare@suse.de
- supported.conf: Update the list of i2c bus drivers.
  - i2c-isa is gone.
  - i2c-i810, i2c-prosavage and i2c-savage4 are deprecated and will
    be removed soon, mark as unsupported.
  - i2c-voodoo3 has very limited usefulness, mark as unsupported.
  - i2c-powermac is new, mark as supported.
- supported.conf: Update the list of i2c chip drivers.
  - ds1337, ds1374, rtc8564 and x1205 are gone (RTC drivers, moved
    to drivers/rtc).
  - pca9539, pcf8574 and pcf8575 are deprecated (new GPIO drivers
    exist in drivers/gpio), mark as unsupported.
  - ds1682, max6875 and tsl2550 are new, mark as supported.
* Wed Jun 25 2008 jdelvare@suse.de
- supported.conf: Add two new hwmon drivers (dme1737 and thmc50,
  both unsupported.)
- supported.conf: Mark hwmon and hwmon-vid as supported. These are
  simple, software-only utility modules, it makes little sense
  to taint the kernel just because they are loaded.
* Mon Jun 23 2008 tiwai@suse.de
- disable CONFIG_SND_PCSP as it conflicts with input pcspkr and
  disturbs the order of sound devices
* Mon Jun 23 2008 agruen@suse.de
- genksyms: add support for checking against a reference ABI.
* Wed Jun 18 2008 jeffm@suse.de
- Updated to 2.6.26-rc6-git5.
  - Eliminated 2 patches.
* Fri Jun 13 2008 jeffm@suse.de
- Removed kABI reference symbols
- Restored make-symsets check for ignoring/tolerating kABI changes.
* Fri Jun 13 2008 jeffm@suse.de
- Update config files (vanilla).
* Fri Jun 13 2008 jeffm@suse.de
- Update config files.
* Fri Jun 13 2008 jeffm@suse.de
- Updated to 2.6.26-rc6-git1.
  - Eliminated 2 patches.
* Thu Jun 12 2008 sdietrich@suse.de
- config.conf: Suppress RT until forward-port is complete
* Thu Jun 12 2008 jeffm@suse.de
- patches.drivers/libata-ata_piix-macbook-fix: Delete.
* Thu Jun 12 2008 olh@suse.de
- update ps3 config, disable unused drivers
- disable patches.arch/ppc-efika-slowdown.patch
* Thu Jun 12 2008 jeffm@suse.de
- Updated to 2.6.26-rc5-git5.
  - Eliminated 91 patches.
  - Disabled OCFS2 userspace heartbeat.
  - Disabled Xen.
* Thu Jun 12 2008 sdietrich@suse.de
  Build fix: drop patches merged into 2.6.25.5
- patches.rt/x86-fix-tsc-cyc2ns-crap.patch: Delete.
- patches.rt/x86-prepare-to-fix-32bit-sched-clock-crap.patch:
  Delete.
- patches.rt/x86-fix-32bit-sched-clock-crap.patch: Delete.
  Update to 2.6.25-RT6:
- Update config files: enable (M) CONFIG_RWLOCK_TORTURE_TEST
  Resolve conflicts:
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.25.4-RT.
  Add:
- patches.rt/trace-eip2ip.patch: Re: 2.6.25.4-rt4 Compile Fix.
- patches.rt/rwlock-prio-fix.patch: rwlock: reset prio on unlocks
  and wakeups.
- patches.rt/rwlock-fixes.patch: rwlock: fix pi_list race
  conditions.
- patches.rt/event-trace-hrtimer-trace.patch: event-tracer:
  add clockevent trace.
- patches.rt/rwlock-torture.patch: rwlock: rwlock torture test.
- patches.rt/ftrace-wakeup-rawspinlock.patch: ftrace: user raw
  spin lock for wakeup function trace.
- patches.rt/radix-tree-lockdep-plus1.patch: lockdep: add +1 to
  radix tree array.
- patches.rt/sched-cpupri-hotplug-support.patch: sched: fix
  cpupri hotplug support.
- patches.rt/sched-cpupri-priocount.patch: sched: fix cpupri
  priocount.
- patches.rt/ftrace-hotplug-fix.patch: ftrace: cpu hotplug fix.
* Wed Jun 11 2008 agruen@suse.de
- rpm/make-symsets: update to the latest version which will ignore
  symset changes if the symset includes a symbol marked to be
  ignored.
* Wed Jun 11 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: only generate symsets for kernels
  with CONFIG_MODULES=y.
- rpm/macros.kernel-source: remove the ps3 specific check: we
  really want to check whether the kernel mas modules enabled,
  which is covered by the symsets check already now.
* Wed Jun 11 2008 gregkh@suse.de
- patches.drivers/usb-don-t-use-reset-resume-if-drivers-don-t-support-it.patch:
  USB: don't use reset-resume if drivers don't support it.
* Wed Jun 11 2008 gregkh@suse.de
- comment out
  patches.suse/convert-novfs-to-open-soure-coding-standards.patch in the
  series file as it is reported to fail some regression tests.
* Wed Jun 11 2008 gregkh@suse.de
- patches.suse/convert-novfs-to-open-soure-coding-standards.patch:
  Convert novfs to open soure coding standards.
* Mon Jun  9 2008 gregkh@suse.de
- patches.fixes/mptbase-vmware-fix: Delete as it's not needed anymore
* Mon Jun  9 2008 gregkh@suse.de
- refresh patches to apply cleanly
* Mon Jun  9 2008 gregkh@suse.de
- Update to 2.6.25.6
  - loads of bugfixes
  - remove the following patches that were already included in this release:
  - patches.arch/cpufreq_fix_acpi_driver_on_BIOS_changes.patch
  - patches.drivers/libata-force-hardreset-if-link-pm
  - patches.fixes/input-hid-apple-numlock-emulation.patch
  - patches.arch/check-for-acpi-resource-conflicts-in-i2c-bus-drivers.patch
* Mon Jun  9 2008 gregkh@suse.de
- patches.drivers/usb-sierra-option.patch: USB: update sierra
  and option device ids (bnc#374637).
* Mon Jun  9 2008 teheo@suse.de
- patches.drivers/libata-ahci-mcp65-workarounds: ahci: workarounds
  for mcp65 (bnc#398573).
* Mon Jun  9 2008 jkosina@suse.de
- patches.fixes/input-i8042-add-ctr-resume-timeout.patch: Input:
  add retry logic to resume with respect to CTR (bnc#351119).
* Sat Jun  7 2008 gregkh@suse.de
- Update to 2.6.25.5.
  - fixes CVE-2008-1673
* Fri Jun  6 2008 tiwai@suse.de
- add missing patches.rt/ftrace-add-nr_syscalls.patch for fixing
  i386-rt_debug
* Thu Jun  5 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.22,
  patches.xen/xen3-patch-2.6.23,
  patches.xen/xen3-patch-2.6.24,
  patches.xen/xen3-patch-2.6.25: netfront (bnc#394575) and page table
  handling (bnc#396858) fixes.
- patches.xen/540-blkif-nr-segments-check.patch: Avoid theoretical
  TOCTTOU bug in block backend nr_segments checking.
- patches.xen/560-x86_64-no-irq-affinity-break-msg.patch: x86_64:
  Remove warning message about 'Breaking affinity for irq'.
- patches.xen/xen-netfront-flip-prod: fix updating of req_prod_pvt
  in the receive ring for the flipping case.
* Wed Jun  4 2008 jblunck@suse.de
- patches.drivers/libata-acpi-fix-hotplug: Don't call ata_port_freeze()
  in ata_acpi_detach_device().
* Wed Jun  4 2008 schwab@suse.de
- Don't clean asm-offsets.h.
* Wed Jun  4 2008 jjohanse@suse.de
- patches.apparmor/apparmor-module_interface.diff: AppArmor:
  Update patch to properly set profile name_table size (bnc#396993)
* Tue Jun  3 2008 jkosina@suse.de
- patches.fixes/input-add-amilo-pro-v-to-nomux.patch: Add
  Fujitsu-Siemens Amilo Pro 2010 and 2030 to nomux list
  (bnc#345699 bnc#389169)
* Tue Jun  3 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-auto-resume-fix: hda - Fix
  resume of auto-config mode with Realtek codecs (bnc#385473).
* Tue Jun  3 2008 bphilips@suse.de
  Backport: e1000e for montevina systems
- patches.drivers/e1000e-backport-0001-remove-no-longer-used-e1000e_read_nvm_spi.patch:
  e1000e: remove no longer used e1000e_read_nvm_spi.
- patches.drivers/e1000e-backport-0002-remove-irq_sem.patch:
  e1000e: remove irq_sem.
- patches.drivers/e1000e-backport-0003-rename-mc_addr_list_update.patch:
  e1000e: rename mc_addr_list_update.
- patches.drivers/e1000e-backport-0004-reorganize-PHY-and-flow-control-interface.patch:
  e1000e: reorganize PHY and flow control interface.
- patches.drivers/e1000e-backport-0005-Make-arrays-out-of-these-Rx-Tx-registers.patch:
  e1000e: Make arrays out of these Rx/Tx registers.
- patches.drivers/e1000e-backport-0006-rename-a-few-functions.patch:
  e1000e: rename a few functions.
- patches.drivers/e1000e-backport-0007-cleanup-several-stats-issues.patch:
  e1000e: cleanup several stats issues.
- patches.drivers/e1000e-backport-0008-Fix-HW-Error-on-es2lan-ARP-capture-issue-by.patch:
  e1000e: Fix HW Error on es2lan, ARP capture issue by BMC.
- patches.drivers/e1000e-backport-0009-Add-support-for-BM-PHYs-on-ICH9.patch:
  e1000e: Add support for BM PHYs on ICH9.
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-hda-vt1708-pcm-noise-fix: Delete.
- patches.drivers/alsa-hda-backport-2.6.26-rc4: Backport ALSA
  HDA-Intel patches from 2.6.26-rc4 (bnc#390473).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-asus-a9t-fix: ac97 - Fix ASUS A9T laptop
  output (bnc#363987).
* Mon Jun  2 2008 jeffm@suse.de
- patches.fixes/reiserfs-prealloc-fix: reiserfs: Use list_del_init
  in use_preallocated_list_if_available (bnc#378095).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-hp2133-mic-fix: hda - Fix mic input on
  HP2133 (bnc#388540).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-emu10k1-audigy2-digital-fix: emu10k1 - Fix
  inverted Analog/Digital mixer switch on Audigy2 (bnc#396204).
* Sat May 31 2008 sdietrich@suse.de
  RT: Update to 2.5.25.4-rt4 (refreshed patches suppressed)
- Update config files.
  Added:
- patches.rt/adapt-remove-extra-try-to-lock.patch
- patches.rt/adaptive-adjust-pi-wakeup.patch
- patches.rt/adaptive-earlybreak-on-steal.patch
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch
- patches.rt/adaptive-task-oncpu.patch
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch
- patches.rt/arm-omap-02.patch
- patches.rt/arm-omap-03.patch
- patches.rt/arm-omap-04.patch
- patches.rt/arm-omap-05.patch
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch
- patches.rt/ftrace-compile-fixes.patch
- patches.rt/ftrace-disable-daemon.patch
- patches.rt/ftrace-dont-trace-markers.patch
- patches.rt/ftrace-fix-header.patch
- patches.rt/ftrace-function-record-nop.patch
- patches.rt/ftrace-print-missing-cmdline.patch
- patches.rt/ftrace-record-comm-on-ctrl.patch
- patches.rt/ftrace-safe-traversal-hlist.patch
- patches.rt/ftrace-trace-sched.patch
- patches.rt/ftrace-update-cnt-stat-fix.patch
- patches.rt/git-ignore-module-markers.patch
- patches.rt/git-ignore-script-lpp.patch
- patches.rt/lockdep-avoid-fork-waring.patch
- patches.rt/lockstat-fix-contention-points.patch
- patches.rt/lockstat-output.patch
- patches.rt/nmi-show-regs-fix.patch
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch
- patches.rt/realtime-preempt-warn-about-tracing.patch
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch
- patches.rt/rwlock-implement-downgrade-write.patch
- patches.rt/rwlocks-fix-no-preempt-rt.patch
- patches.rt/sched-fix-rt-task-wakeup.patch
- patches.rt/sched-fix-sched-fair-wakeup.patch
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch
- patches.rt/sched-wake_up_idle_cpu-rt.patch
- patches.rt/trace_hist-divzero.patch
- patches.rt/trace_hist-latediv.patch
- patches.rt/x86-delay-enable-preempt-tglx.patch
  Removed:
- patches.rt/rtmutex-optimize-wakeup.patch
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch
- patches.rt/rtmutex-remove-extra-try.patch
- patches.rt/ftrace-remove-print-of-max.patch
* Thu May 29 2008 sdietrich@suse.de
  RT: Update IBM EDAC and PRTM
- Update config files.
- patches.rt/drivers-edac-add-support-for-HS21XM-SMI-remediation:
  Add support for HS21XM SMI Remediation to the 2.6.22-based
  SLERT kernel.
- patches.rt/drivers-edac-add-support-for-HS21_LS21-SMI-remediation:
  Add support for HS21/LS21 SMI Remediation to the 2.6.22-based
  SLERT kernel.
- patches.rt/drivers-edac-i5000-turn-off-unsupported-check:
  Turn off unsupported EDAC check on the i5000 controller.
- patches.rt/drivers-edac-prevent-potential-printk-storm:
  Prevent potential EDAC printk storm.
- patches.rt/drivers-edac-test_device.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-new-k8-rev-f.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-add-sysfs_notify-calls.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-new-amd64.patch:
  drivers-edac-new-amd64.patch (revision 108).
  Obsolete:
- patches.rt/add-support-for-HS21_LS21-SMI-remediation: Delete.
- patches.rt/add-support-for-HS21XM-SMI-remediation: Delete.
- patches.rt/prevent-potential-EDAC-printk-storm: Delete.
* Thu May 29 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-macbook-fix: ata_piix: fix
  macbook ich8m problems (bnc#395407).
* Thu May 29 2008 agruen@suse.de
- Obsolete some KMPs which have been integrated into mainline
  meanwhile (bnc#357799).
* Thu May 29 2008 jbeulich@novell.com
- supported.conf: Mark 8250_pnp as supported.
* Wed May 28 2008 teheo@suse.de
- patches.drivers/libata-acpi-fix-hotplug: libata: Handle bay
  devices in dock stations (bnc#390822 bnc#395082).
* Wed May 28 2008 jkosina@suse.de
- patches.fixes/input-add-i8042-nopnp-for-D845PESV.patch: Input:
  Add i8042.nopnp for Intel D845PESV (bnc#386952).
* Mon May 26 2008 sdietrich@suse.de
  RT: Update to 2.6.25.4-rt3 - add RWSEM / RWLOCK patches:
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.25.4-RT3.
- patches.rt/multi-reader-account.patch: map tasks to reader
  locks held.
- patches.rt/multi-reader-limit.patch: implement reader limit
  on read write locks.
- patches.rt/multi-reader-lock-account.patch: map read/write
  locks back to their readers.
- patches.rt/multi-reader-pi.patch: read lock Priority Inheritance
  implementation.
- patches.rt/native-sched-clock-booboo.patch: Re: 2.6.25.4-rt2
  (native_sched_clock() booboo).
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch:
- patches.rt/rwlocks-multiple-readers.patch: implement rwlocks
  management.
- patches.rt/rwsems-multiple-readers.patch: add framework for
  multi readers on rwsems.
* Mon May 26 2008 olh@suse.de
- add patches.arch/ppc-efika-slowdown.patch
  slow down hot code paths to avoid hangs during install (bnc#374309)
* Sun May 25 2008 tiwai@suse.de
- Update config files: forgot to update vanilla kernel configs
* Sat May 24 2008 tiwai@suse.de
- Update config files: disable group scheduler for normal kernels
  for openSUSE 11.0, too (this should be enabled again later for
  11.1 once after the bugs get fixed...)
* Fri May 23 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dma-pos-fix: hda - Fix DMA position
  inaccuracy (bnc#362775, bnc#364421).
- patches.drivers/alsa-hda-vt1708-pcm-noise-fix: hda - Fix noise
  on VT1708 codec (bnc#390473).
* Fri May 23 2008 sdietrich@suse.de
  RT: Update config files: Disable Group Scheduler
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-simg3726-nosrst: libata: SRST can't
  be trusted on PMP sil3726 (bnc#393456).
* Thu May 22 2008 sdietrich@suse.de
  RT: update config files: Disable SYSFS_DEPRECATED
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-detection-fixes: libata: fix a
  number of PMP detection problems (bnc#393456).  series.conf not
  updated.  Fix it.
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-detection-fixes: libata: fix a
  number of PMP detection problems (bnc#393456).
* Thu May 22 2008 sdietrich@suse.de
  RT: build fix
- suppress adaptive locking patches that are not upstream.
- Update config files.
* Wed May 21 2008 jblunck@suse.de
- patches.fixes/acpi-bay-cleanup-and-exit.patch: bay: Exit if
  notify handler cannot be installed (bnc#390822).
* Wed May 21 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.25: Fix DomU boot issue.
* Wed May 21 2008 oneukum@suse.de
- patches.drivers/ehci_fix_remote_wakeup_regression.diff: EHCI:
  fix remote-wakeup regression. (bnc#373128)
* Tue May 20 2008 jblunck@suse.de
- doc/novell-kmp/novell-example-1.1.tar.bz2,
  doc/novell-kmp/novell-example.spec: Fix example spec and Kbuild
  because EXTRA_CFLAGS isn't taken from the environment anymore.
* Tue May 20 2008 sdietrich@suse.de
- Update config files: SLERT compatibility: SYSFS_DEPRECATED
* Tue May 20 2008 sdietrich@suse.de
  RT: Update to 2.5.25.4-rt2 (refreshed patches suppressed)
  Add:
- patches.rt/rtmutex-adaptive-locks.patch: adaptive real-time
  lock support.
- patches.rt/x86-fix-32bit-sched-clock-crap.patch: x86: disable TSC
  for sched_clock() when calibration failed
- patches.rt/x86-fix-tsc-cyc2ns-crap.patch: x86: fix setup of cyc2ns
  in tsc_64.c.
- patches.rt/x86-prepare-to-fix-32bit-sched-clock-crap.patch:
  x86: distangle user disabled TSC from unstable
- patches.rt/adaptive-spinlock-lite-v2.patch: adaptive spinlocks
  lite.
- patches.rt/rtmutex-remove-xchg.patch: rtmutex - remove double
  xchg.
  Update:
- patches.rt/rtmutex-rearrange.patch: rearrange
  rt_spin_lock_slowlock sleeping code.
  Resolve Conflicts:
- patches.rt/rtmutex-lateral-steal.patch: allow rt-mutex
  lock-stealing to include lateral priority.
- Update config files.
* Mon May 19 2008 sdietrich@suse.de
  RT: Adaptive locking patches:
- patches.rt/rtmutex-lateral-steal.patch: allow rt-mutex
  lock-stealing to include lateral priority.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: sysctl for
  runtime-control of lateral mutex stealing.
- patches.rt/rtmutex-rearrange.patch: rearrange
  rt_spin_lock_slowlock sleeping code.
- patches.rt/rtmutex-adaptive-locks.patch: adaptive real-time
  lock support.
- patches.rt/rtmutex-adaptive-timeout.patch: add a timeout
  mechanism to adaptive-locking.
- patches.rt/rtmutex-optimize-wakeup.patch: optimize rt lock
  wakeup.
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch:
  adjust pi_lock usage in wakeup.
- patches.rt/rtmutex-remove-extra-try.patch: remove the extra
  call to try_to_take_lock.
- Update config files:
  CONFIG_RTLOCK_LATERAL_STEAL=y
  CONFIG_ADAPTIVE_RTLOCK=y
  CONFIG_IBM_RTL (disable temporarily to address build error)
* Mon May 19 2008 tiwai@suse.de
- Update config files (missing for rt*).
* Mon May 19 2008 tiwai@suse.de
- patches.drivers/alsa-hda-backport-2.6.25-rc3: Backport ALSA
  HDA-Intel patches from 2.6.25-rc3 (bnc#390473, bnc#386422,
  bnc#385473).
- patches.drivers/alsa-intel8x0-8ch: intel8x0 - Add support of
  8 channel sound.
- patches.drivers/alsa-mixer-oss-map-fix: Add more fallbacks to
  OSS PHONEOUT mixer map.
- patches.drivers/alsa-usb-audio-disconnect-oops-fix: Fix Oops
  with usb-audio reconnection.
- patches.drivers/alsa-hda-intel-new-ati-id: Delete.
- patches.drivers/alsa-hda-intel-new-nvidia-id: Delete.
- patches.drivers/alsa-hda-intel-use-PCI_DEVICE: Delete.
- patches.drivers/alsa-dell-xps-m1330-hp-fix: Delete.
- Update config files.
* Mon May 19 2008 jbeulich@novell.com
- Update Xen patches to c/s 524 and 2.6.25.4.
- patches.xen/xen-balloon-hvm-min: don't allow ballooning down
  a HVM domain below a reasonable limit (172482).
- patches.xen/xen-swiotlb-heuristics: adjust Xen's swiotlb
  default size setting.
* Mon May 19 2008 jbeulich@novell.com
- patches.arch/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch:
  Add missing list terminator for acpi_rsdt_dmi_table[] and move to
  __initdata.
* Mon May 19 2008 sdietrich@suse.de
  RT: SMI latency fixes from IBM.
- patches.rt/add-support-for-HS21_LS21-SMI-remediation: [PATCH
  1/3] Add support for HS21/LS21 SMI Remediation.
- patches.rt/add-support-for-HS21XM-SMI-remediation: [PATCH 2/3]
  Add support for HS21XM SMI Remediation .
- patches.rt/prevent-potential-EDAC-printk-storm: [PATCH 3/3]
  Prevent potential EDAC printk storm.
- RT: Update config files.
* Mon May 19 2008 agruen@suse.de
- patches.suse/nfs4acl-ext3.diff: Fix compilation error when
  CONFIG_EXT3_FS_NFS4ACL is off.
* Mon May 19 2008 sdietrich@suse.de
- RT: Update config files.
* Mon May 19 2008 trenn@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: ACPI:
  initramfs DSDT override support.
  - > Did not make it into 2.6.25 again...
- Update config files.
* Sun May 18 2008 agruen@suse.de
- Update the nfs4acl patches (and split them out more explicitly).
  Export all new symbols als GPL only.
- patches.apparmor/parent-permission.diff: Rediff.
* Sun May 18 2008 sdietrich@suse.de
- RT: Update config files.
* Sun May 18 2008 sdietrich@suse.de
  RT: update to 2.6.25.4-rt1 patch queue.
* Sun May 18 2008 sdietrich@suse.de
  RT cleanup: Remove unused/obsolete RT patches.
* Sun May 18 2008 sdietrich@suse.de
- Update config files: update RT debug configs.
- config.conf: enable DEBUG flavors.
* Sat May 17 2008 sdietrich@suse.de
  Linux-RT 2.6.25-RT:
- Updated RT patch queue (not individually enumerated here)
- Update config files: RT
- config.conf: RT
* Fri May 16 2008 gregkh@suse.de
- Update config files.
- patches.drivers/usb-add-option-hso-driver.patch: USB: add
  option hso driver.
* Fri May 16 2008 gregkh@suse.de
- refresh patches due to fuzz
* Fri May 16 2008 gregkh@suse.de
- patches.fixes/bluetooth-wake-up-properly-after-ide-timeout-expires.patch:
  bluetooth: wake up properly after ide timeout expires
  (bnc#390839).
* Fri May 16 2008 olh@suse.de
- update patches.fixes/tg3-flowctrl.patch
  do not compare flow control settings in parallel detect mode
* Fri May 16 2008 trenn@suse.de
- patches.arch/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch:
  Introduce acpi_root_table=rsdt boot param and dmi list to
  force rsdt (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/acpi_thinkpad_introduce_acpica_rsdt_global_variable.patch:
  ACPICA: Add acpi_gbl_force_rsdt variable
  (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/acpi_thinkpad_remove_R40e_c-state_blacklist.patch:
  Remove R40e c-state blacklist
  (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/cpufreq_fix_acpi_driver_on_BIOS_changes.patch:
  CPUFREQ: Check against freq changes from the BIOS.
* Fri May 16 2008 jblunck@suse.de
- patches.fixes/vfs-2.6.git-9bc300eae0400efdfae3fec3352896e10468a78f.patch:
  return to old errno choice for fix mkdir -p with ro-bind mounts
* Fri May 16 2008 jblunck@suse.de
- rpm/kernel-{binary,source}.spec.in: use localversion and set
  KBUILD_BUILD_VERSION (used for Kernel:Vanilla)
* Thu May 15 2008 gregkh@suse.de
- Update to final version of 2.6.25.4
* Thu May 15 2008 jblunck@suse.de
- rpm/macros.kernel-source: Let KMPs fail when flavors_to_build is empty
- rpm/kernel-{dummy,source,syms,binary}.spec.in, scripts/tar-up.sh:
  fix release number changes introduced by bnc#271712 for OBS (bnc#378933)
* Thu May 15 2008 olh@suse.de
- add patches.fixes/tg3-flowctrl.patch
  revert 'Fix supporting flowctrl code' to fix JS21 (bnc#390314)
* Wed May 14 2008 oneukum@suse.de
- patches.drivers/appletouch_persist.diff: reset_resume and
  autosuspend for appletouch touchpads (bnc#388399).
* Wed May 14 2008 oneukum@suse.de
- patches.drivers/appletouch_persist.diff: reset_resume and
  autosuspend for appletouch touchpads (bnc#388399).
* Wed May 14 2008 teheo@suse.de
- patches.drivers/libata-force-hardreset-if-link-pm: libata:
  force hardreset if link is in powersave mode (bnc#381795).
- patches.drivers/libata-ahci-sb600-no-msi: ahci: SB600 ahci
  can't do MSI, blacklist that capability (bnc#384559).
* Tue May 13 2008 gregkh@suse.de
- Update config files for vanilla targets
* Tue May 13 2008 gregkh@suse.de
- Update to 2.6.25.4-rc1
  - lots of bug fixes
* Mon May 12 2008 sdietrich@suse.de
  Cleanup RT:
- patches.rt/*: Delete.
* Mon May 12 2008 jkosina@suse.de
- patches.fixes/input-hid-apple-numlock-emulation.patch:
  HID: split Numlock emulation quirk from
  HID_QUIRK_APPLE_HAS_FN. (bnc#381764).
* Sat May 10 2008 gregkh@suse.de
- Update to 2.6.25.3
  - fixes 2 security issues (one networking, one sparc, no CVE
    numbers issued just yet)
* Fri May  9 2008 jeffm@suse.de
- patches.apparmor/fsetattr-restore-ia_file: vfs: restore ia_file
  for compatibility with external modules. (bnc#381259)
* Fri May  9 2008 hare@suse.de
- patches.drivers/open-iscsi-git-update: Delete.
- patches.fixes/open-iscsi-nop-fixes: NOP timeout fixes.
* Thu May  8 2008 gregkh@suse.de
- patches.kernel.org/v4l-dvb-patch-for-various-dibcom-based-devices.patch:
  V4L/DVB (7473): PATCH for various Dibcom based devices
  (bnc#381632).
* Thu May  8 2008 gregkh@suse.de
- comment out vmware patch as it should no longer be needed
* Thu May  8 2008 gregkh@suse.de
- rediff patches to apply cleanly.
* Thu May  8 2008 gregkh@suse.de
- Update to 2.6.25.3-rc1
  - potential fix for increased power consumption and other bugs
* Thu May  8 2008 sassmann@suse.de
- Update config file ppc64.
- patches.arch/ppc-ps3-ps3vram-mtd.patch: ps3vram driver that
  allows you to access the extra ~240MB of DDR video.
* Wed May  7 2008 gregkh@suse.de
- patches.kernel.org/patch-2.6.25.1-2: Linux 2.6.25.2.
  - fixes CVE-2008-1669
* Tue May  6 2008 schwab@suse.de
- suse-ppc32-mol-semaphore: fix mol for 2.6.26-rc1.
* Mon May  5 2008 jack@suse.cz
  Bring UDF to state in 2.6.26-rc1 to support UDF 2.50.
- patches.suse/udf-10-simple-cleanup-of-truncate.c.patch: udf:
  simple cleanup of truncate.c (fate#303336).
- patches.suse/udf-11-truncate-create-function-for-updating-of-Alloc.patch:
  udf: truncate: create function for updating of Allocation Ext
  Descriptor (fate#303336).
- patches.suse/udf-12-replace-all-adds-to-little-endians-variables-wi.patch:
  udf: replace all adds to little endians variables with
  le*_add_cpu (fate#303336).
- patches.suse/udf-13-simplify-__udf_read_inode.patch: udf:
  simplify __udf_read_inode (fate#303336).
- patches.suse/udf-14-replace-udf_-_offset-macros-with-functions.patch:
  udf: replace udf_*_offset macros with functions (fate#303336).
- patches.suse/udf-15-convert-udf_count_free_bitmap-to-use-bitmap_wei.patch:
  udf: convert udf_count_free_bitmap to use bitmap_weight
  (fate#303336).
- patches.suse/udf-16-udf_get_block-inode_bmap-remove-unneeded-che.patch:
  udf: udf_get_block, inode_bmap - remove unneeded checks
  (fate#303336).
- patches.suse/udf-17-create-function-for-conversion-from-timestamp-t.patch:
  udf: create function for conversion from timestamp to timespec
  (fate#303336).
- patches.suse/udf-18-convert-udf_stamp_to_time-to-return-struct-time.patch:
  udf: convert udf_stamp_to_time to return struct timespec
  (fate#303336).
- patches.suse/udf-19-convert-udf_stamp_to_time-and-udf_time_to_stamp.patch:
  udf: convert udf_stamp_to_time and udf_time_to_stamp to use
  timestamps (fate#303336).
- patches.suse/udf-1-kill-udf_set_blocksize.patch: udf: kill
  udf_set_blocksize (fate#303336).
- patches.suse/udf-20-remove-unneeded-kernel_timestamp-type.patch:
  udf: remove unneeded kernel_timestamp type (fate#303336).
- patches.suse/udf-21-super.c-reorganization.patch: udf: super.c
  reorganization (fate#303336).
- patches.suse/udf-22-Mark-udf_process_sequence-as-noinline.patch:
  udf: Mark udf_process_sequence() as noinline (fate#303336).
- patches.suse/udf-23-Remove-checking-of-existence-of-filename-in-udf.patch:
  udf: Remove checking of existence of filename in udf_add_entry()
  (fate#303336).
- patches.suse/udf-24-Remove-declarations-of-arrays-of-size-UDF_NAME_.patch:
  udf: Remove declarations of arrays of size UDF_NAME_LEN (256
  bytes) (fate#303336).
- patches.suse/udf-25-fix-anchor-point-detection.patch: udf:
  fix anchor point detection (fate#303336).
- patches.suse/udf-26-Cleanup-volume-descriptor-sequence-processing.patch:
  udf: Cleanup volume descriptor sequence processing
  (fate#303336).
- patches.suse/udf-27-Improve-error-recovery-on-mount.patch:
  udf: Improve error recovery on mount (fate#303336).
- patches.suse/udf-28-Move-filling-of-partition-descriptor-info-into.patch:
  udf: Move filling of partition descriptor info into a separate
  function (fate#303336).
- patches.suse/udf-29-Move-processing-of-virtual-partitions.patch:
  udf: Move processing of virtual partitions (fate#303336).
- patches.suse/udf-2-kill-useless-file-header-comments-for-vfs-metho.patch:
  udf: kill useless file header comments for vfs method
  implementations (fate#303336).
- patches.suse/udf-30-Cleanup-anchor-block-detection.patch: udf:
  Cleanup anchor block detection. (fate#303336).
- patches.suse/udf-31-Improve-anchor-block-detection.patch: udf:
  Improve anchor block detection (fate#303336).
- patches.suse/udf-32-Silence-warning-about-accesses-beyond-end-of-de.patch:
  udf: Silence warning about accesses beyond end of device
  (fate#303336).
- patches.suse/udf-33-Fix-detection-of-VAT-version.patch: udf:
  Fix detection of VAT version (fate#303336).
- patches.suse/udf-34-Allow-loading-of-VAT-inode.patch: udf:
  Allow loading of VAT inode (fate#303336).
- patches.suse/udf-35-Handle-VAT-packed-inside-inode-properly.patch:
  udf: Handle VAT packed inside inode properly (fate#303336).
- patches.suse/udf-36-Mount-filesystem-read-only-if-it-has-pseudoover.patch:
  udf: Mount filesystem read-only if it has pseudooverwrite
  partition (fate#303336).
- patches.suse/udf-37-Fix-handling-of-multisession-media.patch:
  udf: Fix handling of multisession media (fate#303336).
- patches.suse/udf-38-Add-read-only-support-for-2.50-UDF-media.patch:
  udf: Add read-only support for 2.50 UDF media (fate#303336).
- patches.suse/udf-39-Fix-bug-in-VAT-mapping-code.patch: udf:
  Fix bug in VAT mapping code (fate#303336).
- patches.suse/udf-3-move-headers-out-include-linux.patch: udf:
  move headers out include/linux/ (fate#303336).
- patches.suse/udf-40-Fix-compilation-warnings-when-UDF-debug-is-on.patch:
  udf: Fix compilation warnings when UDF debug is on
  (fate#303336).
- patches.suse/udf-41-use-crc_itu_t-from-lib-instead-of-udf_crc.patch:
  udf: use crc_itu_t from lib instead of udf_crc (fate#303336).
- patches.suse/udf-42-fs-udf-partition.c-udf_get_pblock-mustn-t-be.patch:
  udf: fs/udf/partition.c:udf_get_pblock() mustn't be inline
  (fate#303336).
- patches.suse/udf-4-Use-DIV_ROUND_UP.patch: fs/udf: Use
  DIV_ROUND_UP (fate#303336).
- patches.suse/udf-5--udf_error-static.patch: make udf_error()
  static (fate#303336).
- patches.suse/udf-6-udf_CS0toUTF8-cleanup.patch: udf:
  udf_CS0toUTF8 cleanup (fate#303336).
- patches.suse/udf-7-fix-udf_build_ustr.patch: udf: fix
  udf_build_ustr (fate#303336).
- patches.suse/udf-8-udf_CS0toNLS-cleanup.patch: udf: udf_CS0toNLS
  cleanup (fate#303336).
- patches.suse/udf-9-constify-crc.patch: udf: constify crc
  (fate#303336).
* Fri May  2 2008 teheo@suse.de
- patches.drivers/libata-sata_inic162x-update-to-0.4:
  sata_inic162x: update to 0.4 (bnc#385599).
* Thu May  1 2008 gregkh@suse.de
- update to 2.6.25.1:
  - fixes CVE-2008-1375 and CVE-2008-1675
  - lots of other minor bugfixes
* Thu May  1 2008 agruen@suse.de
- Provide "kernel(flavor:symset) = version" instead of
  "kernel(symset) = version". This disambiguates the case where
  several kernel flavors end up with the same modver checksums
  (bnc#190163, bnc#355628).
* Thu May  1 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-verify-sidpr: ata_piix: verify
  SIDPR access before enabling it (bnc#385535).
* Wed Apr 30 2008 gregkh@suse.de
- novfs: fixes needed due to apparmor vfs core changes
  (extended attributes probably do not work now...)
* Wed Apr 30 2008 gregkh@suse.de
- patches.suse/novfs-add-the-novell-filesystem-client-kernel-module.patch:
  novfs: Add the Novell filesystem client kernel module.
- Update config files.
* Wed Apr 30 2008 jeffm@suse.de
- patches.suse/reiserfs-simplify-xattr-internal-file-lookups-opens.diff:
  removed fs.h changes, they weren't used.
* Mon Apr 28 2008 gregkh@suse.de
- Update config files.
  hopefully the build system is happy now
* Mon Apr 28 2008 gregkh@suse.de
- rpm/config-subst: add #!/bin/sh at start of script to keep future
  build issues (like bnc#382214) from causing problems.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove obsolete patches: ARM-ep93xx-timer, latency-tracing,
  RCU, KVM, mcount, PPC-gtod
- patches.rt/ep93xx-timer-accuracy.patch: Delete.
- patches.rt/ep93xx-clockevents.patch: Delete.
- patches.rt/ep93xx-clockevents-fix.patch: Delete.
- patches.rt/kvm-fix-preemption-bug.patch: Delete.
- patches.rt/kvm-lapic-migrate-latency-fix.patch: Delete.
- patches.rt/kvm-make-less-noise.patch: Delete.
- patches.rt/kvm-preempt-rt-resched-delayed.patch: Delete.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch: Delete.
- patches.rt/remove-unused-var-warning.patch: Delete.
- patches.rt/latency-tracing.patch: Delete.
- patches.rt/latency-tracing-remove-trace-array.patch: Delete.
- patches.rt/latency-tracer-disable-across-trace-cmdline.patch:
  Delete.
- patches.rt/latency-tracing-i386-paravirt-fastcall.patch: Delete.
- patches.rt/latency-tracing-i386.patch: Delete.
- patches.rt/latency-tracing-x86_64.patch: Delete.
- patches.rt/latency-tracing-ppc.patch: Delete.
- patches.rt/latency-tracer-printk-fix.patch: Delete.
- patches.rt/latency-tracing-exclude-printk.patch: Delete.
- patches.rt/latency-tracing-prctl-api-hack.patch: Delete.
- patches.rt/latency-tracing-raw-spinlock-hack.patch: Delete.
- patches.rt/latency-tracer-one-off-fix.patch: Delete.
- patches.rt/smaller-trace.patch: Delete.
- patches.rt/trace-name-plus.patch: Delete.
- patches.rt/trace-with-caller-addr.patch: Delete.
- patches.rt/trace-sti-mwait.patch: Delete.
- patches.rt/latency-tracer-optimize-a-bit.patch: Delete.
- patches.rt/idle-stop-critical-timing.patch: Delete.
- patches.rt/latency-tracer-variable-threshold.patch: Delete.
- patches.rt/reset-latency-histogram.patch: Delete.
- patches.rt/undo-latency-tracing-raw-spinlock-hack.patch: Delete.
- patches.rt/random-driver-latency-fix.patch: Delete.
- patches.rt/latency-tracing-use-now.patch: Delete.
- patches.rt/preempt_max_latency-in-all-modes.patch: Delete.
- patches.rt/latency-hist-add-resetting-for-all-timing-options.patch:
  Delete.
- patches.rt/latency-trace-sysctl-config-fix.patch: Delete.
- patches.rt/latency-trace-convert-back-to-ms.patch: Delete.
- patches.rt/latency-trace-fix.patch: Delete.
- patches.rt/trace-cpuidle.patch: Delete.
- patches.rt/lockdep-show-held-locks.patch: Delete.
- patches.rt/lockdep-lock_set_subclass.patch: Delete.
- patches.rt/lockdep-prettify.patch: Delete.
- patches.rt/lockdep-more-entries.patch: Delete.
- patches.rt/latency-tracer-arch-low-address.patch: Delete.
- patches.rt/latency-tracer-dont-panic-on-failed-bootmem-alloc.patch:
  Delete.
- patches.rt/mcount-add-x86_64-notrace-annotations.patch: Delete.
- patches.rt/mcount-add-x86-vdso-notrace-annotations.patch:
  Delete.
- patches.rt/mcount-nmi-notrace-annotations.patch: Delete.
- patches.rt/mcount-add-time-notrace-annotations.patch: Delete.
- patches.rt/mcount-lockdep-notrace-annotations.patch: Delete.
- patches.rt/mcount-preemptcount-notrace-annotations.patch:
  Delete.
- patches.rt/mcount-fault-notrace-annotations.patch: Delete.
- patches.rt/mcount-irqs-notrace-annotations.patch: Delete.
- patches.rt/mcount-rcu-notrace-annotations.patch: Delete.
- patches.rt/latency-measurement-drivers-fix.patch: Delete.
- patches.rt/latency-measurement-drivers.patch: Delete.
- patches.rt/redo-regparm-option.patch: Delete.
- patches.rt/nmi-profiling-base.patch: Delete.
- patches.rt/ppc-gtod-notrace-fix.patch: Delete.
- patches.rt/ppc-gtod-support.patch: Delete.
- patches.rt/ppc-gtod-support-fix.patch: Delete.
- patches.rt/ppc-a-2.patch: Delete.
- patches.rt/ppc-fix-clocksource-timebase-shift.patch: Delete.
- patches.rt/ppc-remove-broken-vsyscall.patch: Delete.
- patches.rt/ppc-read-persistent-clock.patch: Delete.
- patches.rt/ppc-clockevents.patch: Delete.
- patches.rt/ppc-clockevents-fix.patch: Delete.
- patches.rt/ppc-highres-dyntick.patch: Delete.
- patches.rt/inet-hash-bits-ipv6-fix.patch: Delete.
- patches.rt/inet_hash_bits.patch: Delete.
- patches.rt/rcu-1.patch: Delete.
- patches.rt/rcu-2.patch: Delete.
- patches.rt/rcu-3.patch: Delete.
- patches.rt/rcu-4.patch: Delete.
- patches.rt/rcu-preempt-fix-nmi-watchdog.patch: Delete.
- patches.rt/rcu-preempt-fix-rcu-torture.patch: Delete.
- patches.rt/dynticks-rcu-rt-fixlet.patch: Delete.
- patches.rt/rcu-tasklet-softirq.patch: Delete.
- patches.rt/rcu-classic-fixup.patch: Delete.
- patches.rt/rcu-warn-underflow.patch: Delete.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove obsolete Adaptive-locking patches
- patches.rt/rtmutex-adaptive-locks.patch: Delete.
- patches.rt/rtmutex-adaptive-mutexes.patch: Delete.
- patches.rt/rtmutex-adaptive-timeout.patch: Delete.
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch: Delete.
- patches.rt/rtmutex-lateral-steal.patch: Delete.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
- patches.rt/rtmutex-optimize-wakeup.patch: Delete.
- patches.rt/rtmutex-rearrange.patch: Delete.
- patches.rt/rtmutex-remove-extra-try.patch: Delete.
- patches.rt/x86-ticket-lock.patch: Delete.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove ARM and MIPS RT patches
- patches.rt/arm-cmpxchg-support-armv6.patch: Delete.
- patches.rt/arm-cmpxchg.patch: Delete.
- patches.rt/arm-compile-fix.patch: Delete.
- patches.rt/arm-fix-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-latency-tracer-support.patch: Delete.
- patches.rt/arm-leds-timer.patch: Delete.
- patches.rt/arm-preempt-config.patch: Delete.
- patches.rt/arm-trace-preempt-idle.patch: Delete.
- patches.rt/latency-tracing-arm.patch: Delete.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Delete.
- patches.rt/preempt-irqs-arm.patch: Delete.
- patches.rt/preempt-realtime-arm-bagde4.patch: Delete.
- patches.rt/preempt-realtime-arm-footbridge.patch: Delete.
- patches.rt/preempt-realtime-arm-integrator.patch: Delete.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Delete.
- patches.rt/preempt-realtime-arm-pxa.patch: Delete.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Delete.
- patches.rt/preempt-realtime-arm-shark.patch: Delete.
- patches.rt/preempt-realtime-arm.patch: Delete.
- patches.rt/preempt-irqs-mips.patch: Delete.
- patches.rt/preempt-realtime-mips.patch: Delete.
- patches.rt/rt-mutex-arm-fix.patch: Delete.
- patches.rt/rt-mutex-arm.patch: Delete.
- patches.rt/rt-mutex-mips.patch: Delete.
- patches.rt/mips-change-raw-spinlock-type.patch: Delete.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Delete.
- patches.rt/mips-remove-duplicate-kconfig.patch: Delete.
- patches.rt/mips-remove-finish-arch-switch.patch: Delete.
* Fri Apr 25 2008 carnold@novell.com
- rpm/kernel-binary.spec.in: kernel-xen does not obsolete/provide
  kernel-xenpae (bnc#382309)
* Fri Apr 25 2008 olh@suse.de
- update patches.arch/ppc-efika-mpc52xx-ac97.patch
  create /builtin/sound/cell-index, content == 1
* Thu Apr 24 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  add newline to devspec files
* Thu Apr 24 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  add devspec file for mac-io, it was created as a side effect
  in of/platform.c (bnc#374693)
* Thu Apr 24 2008 olh@suse.de
- use bzip2 instead of lzma as rpm compression method for vanilla
* Thu Apr 24 2008 olh@suse.de
- relax Conflicts for kernel-vanilla
  no version check for lvm, udev and apparmor
* Wed Apr 23 2008 olh@suse.de
- readd patches.arch/ppc-pegasos-console-autodetection.patch
  force speed 115200, device-tree has no current-speed property
* Wed Apr 23 2008 tiwai@suse.de
- patches.drivers/alsa-hda-intel-new-ati-id,
  patches.drivers/alsa-hda-intel-use-PCI_DEVICE,
  patches.drivers/alsa-hda-intel-new-nvidia-id: Add missing PCI
  ids for new ATI/Nvidia devices (bnc#370775)
- patches.drivers/alsa-dell-xps-m1330-hp-fix: Fix Dell XPS M1330
  outputs
* Tue Apr 22 2008 jack@suse.cz
- patches.fixes/quota_reiserfs_tail_fix.diff: reiserfs: Unpack
  tails on quota files (375179).
* Tue Apr 22 2008 olh@suse.de
- update patches.arch/ppc-efika-mpc52xx-ac97.patch
  fixes for 2.6.25
* Sat Apr 19 2008 schwab@suse.de
- Add compat handler for PTRACE_GETSIGINFO.
* Sat Apr 19 2008 aj@suse.de
- Conflict with apparmor-parser < 2.3 (not <=) in kernel-binary
  spec files.
* Fri Apr 18 2008 jeffm@suse.de
- Re-synced reiserfs patch set due to broken local repo.
* Fri Apr 18 2008 jeffm@suse.de
- Updated reiserfs patch set
  - Eliminated xattr interaction with AppArmor
  - Eliminated xattr deadlock under load between journal lock and
    xattr dir i_mutex
  - Properly annotated xattr i_mutex locking for lockdep
  - Code cleanup
* Fri Apr 18 2008 jjohanse@suse.de
- Update fsetattr.diff to EXPORT_SYMBOL_GPL(fnotify_change)
* Fri Apr 18 2008 jjohanse@suse.de
- patches.apparmor/__d_path-keep-connected.diff: Fix __d_path
  to allow for old and new behavior bnc#380763.
* Thu Apr 17 2008 gregkh@suse.de
- refresh patches to apply without fuzz
* Thu Apr 17 2008 gregkh@suse.de
- Update to 2.6.25-final
* Wed Apr 16 2008 jjohanse@suse.de
- Update to AppArmor 2.3 patch series
* Wed Apr 16 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Fixed accidental
  passing of -ENODATA to userspace during chown, and messages during
  chown and delete.
* Tue Apr 15 2008 jbeulich@novell.com
- Update Xen patches to 2.6.25-rc9 and c/s 517.
* Fri Apr 11 2008 gregkh@suse.de
- refresh patches to clean up fuzz
* Fri Apr 11 2008 gregkh@suse.de
- Update config files.
* Fri Apr 11 2008 gregkh@suse.de
- updat to 2.6.25-rc9
* Thu Apr 10 2008 gregkh@suse.de
- update to 2.6.25-rc8-git8
* Tue Apr  8 2008 gregkh@suse.de
- update to 2.6.25-rc8-git7
* Mon Apr  7 2008 gregkh@suse.de
- patches.kernel.org/pvrusb2-fix-broken-build-due-to-patch-order-dependency.patch:
  pvrusb2: fix broken build due to patch order dependency.
* Mon Apr  7 2008 gregkh@suse.de
- update to 2.6.25-rc8-git5
* Sun Apr  6 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Removed struct
  file use entirely.
* Sun Apr  6 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Eliminated use
  of vfsmount-less dentry_open().
* Thu Apr  3 2008 teheo@suse.de
- patches.drivers/libata-pata_ali-disable-ATAPI_DMA: pata_ali:
  disable ATAPI DMA (332588).
* Wed Apr  2 2008 gregkh@suse.de
- Update to 2.6.25-rc8
* Tue Apr  1 2008 jblunck@suse.de
- rpm/kernel-source.spec.in,kernel-binary.spec.in: Cleanup Requires
* Mon Mar 31 2008 jdelvare@suse.de
- supported.conf: Add new hwmon drivers, all unsupported.
* Thu Mar 27 2008 jeffm@suse.de
- Fixed up the rest of the reiserfs patch queue.
* Thu Mar 27 2008 jeffm@suse.de
- Updated reiserfs xattr patches.
* Thu Mar 27 2008 gregkh@suse.de
- fix merge error in patches.suse/supported-flag caused by me...
* Thu Mar 27 2008 gregkh@suse.de
- update to 2.6.25-rc7-git2
* Thu Mar 27 2008 gregkh@suse.de
- update to 2.6.25-rc7
  - note that reiserfs xattr patches are now disabled due to merge
    issues...
* Sun Mar 23 2008 teheo@suse.de
- patches.drivers/libata-improve-hpa-error-handling: libata:
  improve HPA error handling (365534).
* Thu Mar 20 2008 gregkh@suse.de
- fix up some EXPORT_SYMBOL() markings to be EXPORT_SYMBOL_GPL() as the
  code is not upstream and we aren't allowed to add non-GPL exports to
  our kernel tree.
* Thu Mar 20 2008 gregkh@suse.de
- update to 2.6.25-rc6-git5
- refresh patches to apply cleanly
* Thu Mar 20 2008 gregkh@suse.de
- update to 2.6.25-rc6-git4
- refresh patches to apply cleanly
* Thu Mar 20 2008 agruen@suse.de
- scripts/tar-up.sh: Rename --kbuild option to --source-timestamp.
  For generating the source timestamp, use HEAD as the branch
  name.
- rpm/get_release_number.sh.in: Don't try to synchronize release
  numbers with kernel-dummy if the release number has been
  specified explicitly (tar-up with --release-string, --timestamp,
  or --source-timestamp).
* Thu Mar 20 2008 olh@suse.de
- remove patches.kernel.org/powerpc-needs-uboot
  not needed without mpc51xx support
* Thu Mar 20 2008 olh@suse.de
- disable gianfar network driver and unused freescale drivers
* Wed Mar 19 2008 gregkh@suse.de
- patch refreshes due to version update
* Wed Mar 19 2008 gregkh@suse.de
- Update to 2.6.25-rc6-git3
- Update config files.
* Wed Mar 19 2008 gregkh@suse.de
- Update to 2.6.25-rc6
  - which deleted the following patches:
  - patches.fixes/hibernation-snapshot-numa-workaround.patch
  - patches.fixes/acpi-fix-double-log-level.patch
  - patches.fixes/acpi_fix_mem_corruption.patch
  - patches.kernel.org/patch-2.6.25-rc5
  - patches.kernel.org/patch-2.6.25-rc5-git3
- Update config files.
- delete patches.arch/x86-nvidia-timer-quirk as it is not being used.
* Wed Mar 19 2008 olh@suse.de
- remove patches.arch/ppc-efika-ipic.patch
  disable mpc51xx support instead
* Tue Mar 18 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Changed to just match %%ix86
* Mon Mar 17 2008 olh@suse.de
- add patches.arch/ppc-efika-ipic.patch
  fix a crash in init_ipic_sysfs on efika
* Mon Mar 17 2008 agruen@suse.de
- post.sh: Fix a syntax error when creating the initrd.
* Mon Mar 17 2008 jbeulich@novell.com
- patches.xen/xen-quicklist.patch: Delete.
- Update i386 Xen config file.
- patches.xen/xen3-patch-2.6.25-rc5-rc6: 2.6.25-rc6.
- patches.xen/xen3-auto-xen-kconfig.diff,
  patches.xen/xen3-fixup-kconfig,
  patches.xen/xen3-patch-2.6.19,
  patches.xen/xen3-patch-2.6.20,
  patches.xen/xen3-patch-2.6.21,
  patches.xen/xen3-patch-2.6.22,
  patches.xen/xen3-patch-2.6.23,
  patches.xen/xen3-patch-2.6.24,
  patches.xen/xen3-patch-2.6.25-rc5,
  patches.xen/xen-x86-no-lapic,
  patches.xen/xen-x86-panic-no-reboot: Various adjustments.
* Sun Mar 16 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Added an RPM conflict for 32-bit
  kernels and 64-bit glibc to avoid installing a 32-bit kernel
  with 64-bit userspace. (364433, et al)
* Fri Mar 14 2008 jeffm@suse.de
- scripts/tar-up.sh: Added --kbuild option to autogenerate
  release number based on branch and timestamp.
* Fri Mar 14 2008 jeffm@suse.de
- patches.apparmor/export-security_inode_permission-for-aufs:
  LSM: Export security_inode_permission for aufs (356902).
* Fri Mar 14 2008 agruen@suse.de
- Boot loader: do the same during initial installation as when
  updating a kernel package (FATE 302660).
* Thu Mar 13 2008 gregkh@suse.de
- Update to 2.6.25-rc5-git3
* Thu Mar 13 2008 olh@suse.de
- disable unuses pata platform and ibm newemac driver on powerpc
* Thu Mar 13 2008 olh@suse.de
- add patches.xen/xen-quicklist.patch
  fix kernel-xen compile, readd CONFIG_QUICKLIST for xen
* Wed Mar 12 2008 gregkh@suse.de
- remove alpha configs as they are no longer used
* Wed Mar 12 2008 gregkh@suse.de
- Enabled CONFIG_UNUSED_SYMBOLS for now.  It will be disabled
  after the next openSUSE alpha release.  It is being enabled
  for now to let some kmp packages still work while their
  maintainers are working to update them with the 2.6.25
  kernel changes.
* Wed Mar 12 2008 gregkh@suse.de
- refresh patches to apply cleanly
* Wed Mar 12 2008 gregkh@suse.de
- update to 2.6.25-rc5-git2
* Wed Mar 12 2008 sassmann@suse.de
- patches.arch/ppc-ps3-rename-wireless-interface.patch:
  rename ps3 wireless interface from eth? to wlan? for better
  handling in udev
* Wed Mar 12 2008 jbeulich@novell.com
- Update Xen patches to 2.6.25-rc5 and c/s 471.
- patches.xen/xen3-aslr-i386-and-x86_64-randomize-brk.patch:
  Delete.
- patches.xen/xen3-aslr-pie-executable-randomization.patch:
  Delete.
- patches.xen/xen3-early-firewire.diff: Delete.
- Update x86 config files.
- config.conf: Re-enable Xen configs.
* Tue Mar 11 2008 gregkh@suse.de
- add usb persist for storage devices across suspend to ram.  This is going to
  be in 2.6.26, just missed the .25 merge window.
* Tue Mar 11 2008 gregkh@suse.de
- Update to 2.6.26-rc5-git1
- Update config files.
* Tue Mar 11 2008 gregkh@suse.de
- update to 2.6.25-rc5
* Mon Mar 10 2008 agruen@suse.de
- scripts/tar-up.sh: Don't lose the EXTRAVERSION when overriding
  the release number with --release-string or --timestamp.
* Sun Mar  9 2008 jeffm@suse.de
- patches.fixes/hibernation-snapshot-numa-workaround.patch:
  swsusp: workaround for crash on NUMA (kernel.org#9966).
* Sat Mar  8 2008 agruen@suse.de
- Encode the EXTRAVERSION part of kernel release numbers in the
  RPM release instead of in the version. This resolves the problem
  that kernel releases like 2.6.25-rc4 would result in a package
  with a higher version than 2.6.25 according to RPM's versioning
  scheme (bug 271712).
* Fri Mar  7 2008 schwab@suse.de
- Update kdb patches.
* Thu Mar  6 2008 trenn@suse.de
- patches.fixes/acpi_fix_mem_corruption.patch: ACPI: Fix mem
  corruption (350017).
- patches.fixes/acpi_thermal_passive_cleanup.patch: Warn user
  about a BIOS bug in asus boards (350017).
* Thu Mar  6 2008 gregkh@suse.de
- Update s390 config files.
* Thu Mar  6 2008 gregkh@suse.de
- update to 2.6.24-rc5-git1
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_GROUP_SCHED
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_HIGH_RES_TIMERS on i386
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_USB_PERSIST for vanilla config files
* Wed Mar  5 2008 gregkh@suse.de
- refresh patches to apply cleanly with no fuzz
- enable CONFIG_USB_PERSIST so that users can enable this if they want
* Wed Mar  5 2008 gregkh@suse.de
- update the vanilla config files for CONFIG_DEBUG_RODATA
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_DEBUG_RODATA (Not really a debug option, something
  we need in all of our kernels.)
* Wed Mar  5 2008 gregkh@suse.de
- Update vanilla config files.
* Wed Mar  5 2008 jbeulich@novell.com
- patches.fixes/parport-mutex,
  patches.suse/stack-unwind: Fix merge mistakes.
- Update i386 config files.
* Wed Mar  5 2008 gregkh@suse.de
- Update tree to 2.6.25-rc4
* Wed Mar  5 2008 fseidel@suse.de
- add patches.fixes/fat_detect_media_wo_parttable.patch and
  patches.fixes/fat_valid_media.patch:
  detect FAT formated medias without partition table correctly
  (bnc 364365)
* Tue Mar  4 2008 olh@suse.de
- add patches.kernel.org/s390-defkeymap.patch
  Build fix for drivers/s390/char/defkeymap.c
* Tue Mar  4 2008 olh@suse.de
- enable ext2/3 acl support in ps3 kernel
* Tue Mar  4 2008 olh@suse.de
- Update to 2.6.25-rc3-git5
* Tue Mar  4 2008 olh@suse.de
- use suffix -ps3 for PS3 kernel, it is only used in otheros.bld
* Mon Mar  3 2008 lmb@suse.de
- rpm/kernel-binary.spec.in: Require udev >= 118.
* Mon Mar  3 2008 ak@suse.de
- patches.arch/x86-nvidia-timer-quirk: Delete.
  PCI device ID list still not complete and let's have the same
  crap as mainline for now. It would be better to fix the PCI
  ID lists (#302327)
* Sun Mar  2 2008 olh@suse.de
- add patches.fixes/ibmvstgt-fixes.patch
  fix oops in ibmvstgt init function
* Fri Feb 29 2008 olh@suse.de
- add patches.arch/ppc-pci-bogus-resources.patch
  fix bogus test for unassigned resources
* Thu Feb 28 2008 olh@suse.de
- disable CONFIG_CRYPTO_DEV_HIFN_795X on ppc32 due to __divdi3 usage
- update patches.kernel.org/powerpc-needs-uboot
  disable mkimage call in arch/powerpc/boot/wrapper
* Thu Feb 28 2008 olh@suse.de
- update patches.kernel.org/fixed-phy-select
  add dependency on libphy=y
* Wed Feb 27 2008 jdelvare@suse.de
- patches.fixes/acpi-fix-double-log-level.patch: ACPI: Fix a
  duplicate log level.
* Wed Feb 27 2008 trenn@suse.de
- patches.fixes/acpi_force-fan-active.patch: Delete.
* Tue Feb 26 2008 sdietrich@suse.de
- remove obsolete adaptive-locks patches
  patches.rt/rtmutex-adaptive-locks.patch: Delete.
  patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch: Delete.
  patches.rt/rtmutex-optimize-wakeup.patch: Delete.
  patches.rt/rtmutex-rearrange.patch: Delete.
  patches.rt/rtmutex-remove-extra-try.patch: Delete.
  patches.rt/rtmutex-adaptive-mutexes.patch: Delete.
  patches.rt/rtmutex-adaptive-timeout.patch: Delete.
  patches.rt/rtmutex-lateral-steal.patch: Delete.
  patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
* Tue Feb 26 2008 sassmann@suse.de
- remove patches included upstream
  patches.arch/ppc-ps3-gelic-cleanup.patch
  patches.arch/ppc-ps3-gelic-endianness.patch
  patches.arch/ppc-ps3-gelic-ethernet-linkstatus.patch
  patches.arch/ppc-ps3-gelic-fix-fallback.diff
  patches.arch/ppc-ps3-gelic-multiple-interface.patch
  patches.arch/ppc-ps3-gelic-remove-duplicate-ethtool-handlers.patch
  patches.arch/ppc-ps3-gelic-wireless-v2.patch
* Tue Feb 26 2008 jeffm@suse.de
- Update config files: Disabled CONFIG_INPUT_YEALINK per an old
  request from AJ.
* Tue Feb 26 2008 jeffm@suse.de
- Update to 2.6.25-rc3.
* Sun Feb 24 2008 sdietrich@suse.de
- patches.rt/0001-sched-count-of-queued-RT-tasks.patch: Delete.
- patches.rt/0002-sched-track-highest-prio-task-queued.patch:
  Delete.
- patches.rt/0003-sched-add-RT-task-pushing.patch: Delete.
- patches.rt/0004-sched-add-rt-overload-tracking.patch: Delete.
- patches.rt/0005-sched-pull-RT-tasks-from-overloaded-runqueues.patch:
  Delete.
- patches.rt/0006-sched-push-RT-tasks-from-overloaded-CPUs.patch:
  Delete.
- patches.rt/0007-sched-disable-standard-balancer-for-RT-tasks.patch:
  Delete.
- patches.rt/0008-sched-add-RT-balance-cpu-weight.patch: Delete.
- patches.rt/0009-sched-clean-up-this_rq-use-in-kernel-sched_rt.c.patch:
  Delete.
- patches.rt/0010-sched-de-SCHED_OTHER-ize-the-RT-path.patch:
  Delete.
- patches.rt/0011-sched-break-out-search-for-RT-tasks.patch:
  Delete.
- patches.rt/0012-sched-RT-balancing-include-current-CPU.patch:
  Delete.
- patches.rt/0013-sched-pre-route-RT-tasks-on-wakeup.patch:
  Delete.
- patches.rt/0014-sched-optimize-RT-affinity.patch: Delete.
- patches.rt/0015-sched-wake-balance-fixes.patch: Delete.
- patches.rt/0016-sched-RT-balance-avoid-overloading.patch:
  Delete.
- patches.rt/0017-sched-break-out-early-if-RT-task-cannot-be-migrated.patch:
  Delete.
- patches.rt/0018-sched-RT-balance-optimize.patch: Delete.
- patches.rt/0019-sched-RT-balance-optimize-cpu-search.patch:
  Delete.
- patches.rt/0020-sched-RT-balance-on-new-task.patch: Delete.
- patches.rt/0021-sched-clean-up-pick_next_highest_task_rt.patch:
  Delete.
- patches.rt/0022-sched-clean-up-find_lock_lowest_rq.patch:
  Delete.
- patches.rt/0023-sched-clean-up-overlong-line-in-kernel-sched_debug.patch:
  Delete.
- patches.rt/0024-sched-clean-up-kernel-sched_rt.c.patch: Delete.
- patches.rt/0025-sched-remove-rt_overload.patch: Delete.
- patches.rt/0026-sched-remove-leftover-debugging.patch: Delete.
- patches.rt/0027-sched-clean-up-pull_rt_task.patch: Delete.
- patches.rt/0028-sched-clean-up-schedule_balance_rt.patch:
  Delete.
- patches.rt/0029-sched-add-sched-domain-roots.patch: Delete.
- patches.rt/0030-sched-update-root-domain-spans-upon-departure.patch:
  Delete.
- patches.rt/0031-Subject-SCHED-Only-balance-our-RT-tasks-within-ou.patch:
  Delete.
- patches.rt/0032-sched-fix-sched_rt.c-join-leave_domain.patch:
  Delete.
- patches.rt/0033-sched-remove-unused-JIFFIES_TO_NS-macro.patch:
  Delete.
- patches.rt/0034-sched-style-cleanup-2.patch: Delete.
- patches.rt/0035-sched-add-credits-for-RT-balancing-improvements.patch:
  Delete.
- patches.rt/0036-sched-reactivate-fork-balancing.patch: Delete.
- patches.rt/0037-sched-whitespace-cleanups-in-topology.h.patch:
  Delete.
- patches.rt/0038-sched-no-need-for-affine-wakeup-balancing-in.patch:
  Delete.
- patches.rt/0039-sched-get-rid-of-new_cpu-in-try_to_wake_up.patch:
  Delete.
- patches.rt/0040-sched-remove-do_div-from-__sched_slice.patch:
  Delete.
- patches.rt/0041-sched-RT-balance-replace-hooks-with-pre-post-sched.patch:
  Delete.
- patches.rt/0042-sched-RT-balance-add-new-methods-to-sched_class.patch:
  Delete.
- patches.rt/0043-sched-RT-balance-only-adjust-overload-state-when-c.patch:
  Delete.
- patches.rt/0044-sched-remove-some-old-cpuset-logic.patch:
  Delete.
- Remove scheduler patches already upstream in 2.6.25-rc1
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/libertas-section-conflict: libertas: fix
  section conflict.
* Sat Feb 23 2008 jeffm@suse.de
- Enabled patches.kernel.org/ps3-lpm-include
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/spu_profiler-include: powerpc: spu_profiler
  build fix.
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/ps3-lpm-include: ps3: lpm build fix.
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/fixed-phy-select: powerpc: FSL_SOC requires
  FIXED_PHY.
- patches.kernel.org/lguest-fixups: lguest: Fix asm-offsets_32
  with correct config option.
* Sat Feb 23 2008 jeffm@suse.de
- Build fixes for ia64 and i386.
* Sat Feb 23 2008 jeffm@suse.de
- Update to 2.6.25-rc2-git6.
  - Removed:
  - patches.arch/ppc-pegasos-pata_via-fixup.patch: Delete.
  - patches.arch/ppc-pegasos-console-autodetection.patch: Delete.
  - patches.arch/ppc-ps3-make-dev_id-and-bus_id-u64.diff: Delete.
  - patches.arch/acpi_autoload_bay.patch: Delete.
  - patches.arch/small-acpica-extension-to-be-able-to-store-the-name-of.patch:
    Delete.
  - patches.arch/export-acpi_check_resource_conflict.patch: Delete.
  - patches.drivers/early-firewire.diff: Delete.
  - patches.drivers/scsi-throttle-SG_DXFER_TO_FROM_DEV-warning-better:
    Delete.
  - patches.drivers/libata-implement-force-parameter: Delete.
  - patches.drivers/igb-1.0.8-k2: Delete.
  - patches.drivers/always-announce-new-usb-devices.patch: Delete.
  - patches.drivers/nozomi.patch: Delete.
  - patches.drivers/libata-quirk_amd_ide_mode: Delete.
  - patches.fixes/acpi_autoload_baydock.patch: Delete.
  - patches.fixes/bluetooth_hci_dev_put.patch: Delete.
  - patches.fixes/bluetooth_hci_conn_childs.patch: Delete.
  - patches.fixes/mac80211-fix-hw-scan1.patch: Delete.
  - patches.fixes/mac80211-fix-hw-scan2.patch: Delete.
  - patches.fixes/libiscsi-missing-semicolon.diff: Delete.
  - patches.fixes/pci-quirk-enable-smbus-on-hp-xw4100.patch: Delete.
  - patches.kernel.org/patch-2.6.24.1: Delete.
  - patches.suse/acpi_dsdt_ssdt_initrd_initramfs.patch: Delete.
  - patches.suse/squashfs.patch.fixup: Delete.
  - patches.suse/aslr-pie-executable-randomization.patch: Delete.
  - patches.suse/aslr-i386-and-x86_64-randomize-brk.patch: Delete.
  - Xen and RT currently disabled.
  - SquashFS may not work.
* Fri Feb 22 2008 jeffm@suse.de
- scripts/embargo-filter: fixed and renabled check
* Fri Feb 22 2008 sdietrich@suse.de
- embargoed-patches: eliminate embargoed patches abuse.
* Fri Feb 22 2008 jeffm@suse.de
- scripts/embargo-filter: Disable check for non-existant patches.
* Fri Feb 22 2008 schwab@suse.de
- Update kdb patches.
* Fri Feb 22 2008 jbeulich@novell.com
- config/i386/xenpae: Rename to config/i386/xen.
- config.conf: Delete i386/xenpae.
* Thu Feb 21 2008 sdietrich@suse.de
- Update config files: update RT options for adaptive RT locks
* Thu Feb 21 2008 sdietrich@suse.de
- patches.rt/rtmutex-adaptive-mutexes.patch: cleanup.
- patches.rt/rtmutex-adaptive-timeout.patch: cleanup.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: sysctl for
  runtime-control of lateral mutex stealing.
* Thu Feb 21 2008 jbeulich@novell.com
- Update Xen patches to c/s 425.
- patches.xen/sfc-network-driver: Solarflare: Standard network driver
  (disabled until status clarified).
- patches.xen/sfc-resource-driver: Solarflare: Resource driver
  (disabled until status clarified).
- Update Xen config files.
* Wed Feb 20 2008 ghaskins@suse.de
- adaptive-locking v20
* Wed Feb 20 2008 ghaskins@suse.de
- adaptive-locking v19
* Wed Feb 20 2008 jeffm@suse.de
- Update config files for dmraid45.
* Wed Feb 20 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: add PAGESIZE detection for
  makedumpfile.config from the .config file also for PPC64
* Wed Feb 20 2008 fseidel@suse.de
- patches.fixes/bluetooth_hci_dev_put.patch,
  patches.fixes/bluetooth_hci_conn_childs.patch,
  patches.fixes/bluetooth_hci_unregister_sysfs.patch:
  fix kernel crash after removing bluetooth adapter (bnc 359546)
* Tue Feb 19 2008 jeffm@suse.de
- patches.suse/dm-raid45-2.6.24-20080602a.patch: DMRAID45 module.
* Fri Feb 15 2008 sdietrich@suse.de
- Update to latest patch set:
- patches.rt/rearrange_rtspinlock_sleep:
  [PATCH 02/10] rearrange rtspinlock sleep
- patches.rt/optimize_rtspinlock_wakeup:
  [PATCH 03/10] optimize rtspinlock wakeup
- patches.rt/adaptive_RT_spinlock_support:
  [PATCH 04/10] Adaptive RT spinlock support
- patches.rt/add_timeout_mechanism: [PATCH 05/10]
  add a loop counter based timeoutmechanism
- patches.rt/adaptive_mutexes: [PATCH 06/10] adaptive mutexes
- patches.rt/adjust_pi_lock_usage_in_wakeup:
  [PATCH 07/10] Adjust pi_lock usage in wakeup
- patches.rt/optimize_printk_fastpath: [PATCH 08/10]
  optimize the !printk fastpath throughthe lock acquisition
- patches.rt/remove_extra_call_try_to_take_lock:
  [PATCH 09/10] remove the extra call to try_to_take_lock
- patches.rt/lateral_lock_steal: [PATCH 10/10] allow
  rt-mutex lock-stealing toinclude lateral priority
* Fri Feb 15 2008 sdietrich@suse.de
- embargoed-patches: (embargo development RT throughput patches)
- Update config files (RT config options)
- patches.rt/optimize_rtspinlock_wakeup: optimize rtspinlock
  wakeup.
- patches.rt/adaptive_RT_spinlock_support: Adaptive RT spinlock
  support.
- patches.rt/add_timeout_mechanism: add
  a loop counter based timeout mechanism
- patches.rt/adaptive_mutexes: adaptive mutexes
- patches.rt/adjust_pi_lock_usage_in_wakeup:
  Adjust pi_lock usage in wakeup
- patches.rt/optimize_printk_fastpath: optimize
  the !printk fastpath through the lockacquisition
- patches.rt/remove_extra_call_try_to_take_lock:
  remove the extra call to try_to_take_lock
- patches.rt/lateral_lock_steal: allow rt-mutex
  lock-stealing to include lateralpriority
- patches.rt/rearrange_rtspinlock_sleep: cleanup rtspinlock sleep
* Thu Feb 14 2008 jeffm@suse.de
- Removed unused OCFS2 patches.
* Thu Feb 14 2008 jeffm@suse.de
- Removed old commented out ocfs2 patchset.
* Thu Feb 14 2008 teheo@suse.de
- patches.drivers/libata-quirk_amd_ide_mode: PCI: modify SATA
  IDE mode quirk (345124).
* Wed Feb 13 2008 jeffm@suse.de
- patches.suse/ocfs2-03-split-disk-heartbeat-out.diff: Fixed
  section conflict.
* Wed Feb 13 2008 jeffm@suse.de
- Update config files.
* Wed Feb 13 2008 jeffm@suse.de
- Merged and re-enabled OCFS2 userspace clustering
* Wed Feb 13 2008 jdelvare@suse.de
- config/*: Don't build i2c algorithm drivers that we do not use.
- supported.conf: Drop i2c-elektor and i2c-algo-pcf, we don't ship
  them.
* Tue Feb 12 2008 teheo@suse.de
  Build fix for section mismatch check.
- patches.drivers/libata-implement-force-parameter: libata:
  implement libata.force module parameter (337610).
* Mon Feb 11 2008 teheo@suse.de
- patches.drivers/libata-force-cable-type: Delete.
- patches.drivers/libata-implement-force-parameter: libata:
  implement libata.force module parameter (337610).
* Fri Feb  8 2008 gregkh@suse.de
- Update to 2.6.24.1
  - fixes CVE-2008-0007, CVE-2008-0009, CVE-2008-0010
  - lots of USB device ids updated
  - lots of other bugfixes
  - removed patches.fixes/bootstrap-memoryless-node.patch as it is now
    contained within.
* Fri Feb  8 2008 gregkh@suse.de
- Move ipv6-no-autoconf to xen directory as it is a Xen bugfix
* Fri Feb  8 2008 bwalle@suse.de
- patches.arch/ppc-fix-prpmc2800: remove patch since it's not needed
  with current binutils any more
* Fri Feb  8 2008 bwalle@suse.de
- patches.drivers/igb-2007-12-11: Delete.
- patches.drivers/igb-1.0.8-k2: Update to latest version which is
  also upstream now in the 2.6.25 tree.
* Fri Feb  8 2008 gregkh@suse.de
- Remove NO_BRP_NOEXECSTACK from the .spec files as it is obsolete
  and doesn't do anything anymore.
* Fri Feb  8 2008 jbeulich@novell.com
- patches.xen/xen3-auto-common.diff,
  patches.xen/xen3-patch-2.6.23: fix merge mistake.
* Fri Feb  8 2008 jbenc@suse.cz
- Update config files: disabled CONFIG_BCM43XX.
* Wed Feb  6 2008 jeffm@suse.de
- patches.apparmor/vfs-mkdir.diff: Added missing case in
  kernel/cgroup.c
* Wed Feb  6 2008 fseidel@suse.de
- updated patches.drivers/nozomi.patch: mainline info
* Wed Feb  6 2008 sdietrich@suse.de
- Update config files: RT@1KHz, sched groups & cpusets enabled.
* Wed Feb  6 2008 olh@suse.de
- enable bnx2 on ppc64 (bnc 359114 - LTC42106)
* Wed Feb  6 2008 gregkh@suse.de
- remove unused lockd patches:
  - patches.suse/lockd-switchable-statd
  - patches.suse/lockd-kernel-statd
  - patches.suse/lockd-suse-config
  - patches.suse/lockd-max-hosts-dynamic
* Tue Feb  5 2008 oneukum@suse.de
- patches.suse/usb_printer_no_auto.diff: Delete.
  Obsoleted by mainline change
* Tue Feb  5 2008 gregkh@suse.de
- Enable CONFIG_TASK_IO_ACCOUNTING (bnc 356547) for RT kernels
* Tue Feb  5 2008 gregkh@suse.de
- Enable CONFIG_TASK_IO_ACCOUNTING (bnc 356547)
* Thu Jan 31 2008 sdietrich@suse.de
- patches.rt/megasas_IRQF_NODELAY.patch: Convert megaraid sas
  IRQ to non-threaded IRQ.
- patches.rt/version.patch: Delete (unused).
* Thu Jan 31 2008 jbenc@suse.cz
- patches.fixes/mac80211-fix-hw-scan1.patch,
  patches.fixes/mac80211-fix-hw-scan2.patch: mac80211: hardware
  scan rework (bnc#307050).
* Thu Jan 31 2008 sdietrich@suse.de
- Remove a legacy tweak carried over from the 10.3 Kernel,
  enable the affinity load-balancing sysctl.
* Wed Jan 30 2008 sdietrich@suse.de
- patches.rt/x86-ticket-lock.patch: FIFO ticket lock spinlocks
  for x86 (RT).
- patches.rt/rt-mutex-i386.patch: Resolve conflicts.
* Tue Jan 29 2008 olh@suse.de
- really skip kernel-ps3 in suse_kernel_module_package rpm macro
* Tue Jan 29 2008 jbeulich@novell.com
- Update Xen patches to 2.6.24 final and c/s 399.
- patches.xen/xen3-seccomp-disable-tsc-option: [PATCH seccomp:
  make tsc disabling optional (191123).
* Sat Jan 26 2008 sdietrich@suse.de
- Linux-RT 2.6.24-rt1 (many patches in patches.rt refreshed).
- patches.rt/series: Delete (unused).
* Sat Jan 26 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  use struct device_attribute to fix oops on boot
* Fri Jan 25 2008 jeffm@suse.de
- scripts/sequence-patch.sh: Updated to include $EXTRA_SYMBOLS in
  $PATCH_DIR (e.g.: --symbol=RT creates linux-2.6.24-RT)
* Fri Jan 25 2008 jeffm@suse.de
- patches.rt/rcu-new-1.patch: Updated context against 2.6.24.
* Fri Jan 25 2008 olh@suse.de
- add patches.fixes/bootstrap-memoryless-node.patch
  slab: fix bootstrap on memoryless node
* Fri Jan 25 2008 gregkh@suse.de
- refresh allmost all patches to apply cleanly and have a proper
  diffstat (except for the xen patches, they were left alone...)
* Fri Jan 25 2008 gregkh@suse.de
- Update to 2.6.24
* Thu Jan 24 2008 olh@suse.de
- always skip kernel-ps3 in suse_kernel_module_package rpm macro
* Thu Jan 24 2008 sdietrich@suse.de
- Update config files: set SYSFS_DEPRECATED for reverse
  compatibility with SLERT
* Tue Jan 22 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  simplify patch
* Tue Jan 22 2008 agruen@suse.de
- patches.rpmify/cloneconfig.diff: Adjust to upstream i386 + x86_64
  merge (347712).
* Tue Jan 22 2008 sassmann@suse.de
- add defconfig for ps3 kernel
- add entry for ps3 defconfig in config.conf
- add support for kernels without loadable modules to rpm/kernel-binary.spec.in
- include ps3 target in scripts/tar-up_and_run_mbuild.sh
* Mon Jan 21 2008 sdietrich@suse.de
- Update config files (RT)
* Mon Jan 21 2008 sdietrich@suse.de
- Linux-RT 2.6.24-rc8-rt1
* Mon Jan 21 2008 olh@suse.de
- add patches.arch/ppc-pegasos-pata_via-fixup.patch
  call chrp_pci_fixup_vt8231_ata() later to allow pata_via usage
* Mon Jan 21 2008 aj@suse.de
- Remove unused config/s390/rt.
* Fri Jan 18 2008 jeffm@suse.de
- patches.rt/irq-flags-unsigned-long.patch: Delete.
* Fri Jan 18 2008 jeffm@suse.de
- Update to 2.6.24-rc8-git2.
* Fri Jan 18 2008 jeffm@suse.de
- Enabled 2.6.24-rc8-git1.
* Fri Jan 18 2008 jbenc@suse.cz
- patches.fixes/rt2x00-remove-duplicate-id.patch: Delete. The patch
  is not correct, there exist two cards with different chipsets but
  the same USB ID.
* Fri Jan 18 2008 jbenc@suse.cz
- patches.fixes/rt2x00-remove-duplicate-id.patch: rt2x00: remove
  duplicate USB ID (350956).
* Fri Jan 18 2008 olh@suse.de
- sync powerpc vanilla with default .config to enable libata
* Fri Jan 18 2008 olh@suse.de
- add patches.arch/ppc-pegasos-mv643xx_eth-modalias.patch
  provide module alias platform:mv643xx_eth
* Thu Jan 17 2008 jeffm@suse.de
- Update to 2.6.24-rc8-git1.
* Wed Jan 16 2008 jeffm@suse.de
- Update to 2.6.24-rc8.
* Sun Jan 13 2008 jeffm@suse.de
- Update to 2.6.24-rc7-git5.
* Fri Jan 11 2008 jeffm@suse.de
- Update to 2.6.24-rc7-git3.
* Fri Jan 11 2008 jbeulich@novell.com
- Update Xen patches to c/s 372 and 2.6.24-rc7.
- patches.xen/xen3-aux-at_vector_size.patch: Delete.
- Update Xen config files.
* Thu Jan 10 2008 olh@suse.de
- update patches.arch/ppc-efika-ethernet-phy.patch
  move Forth code to fixup_device_tree_efika
* Wed Jan  9 2008 schwab@suse.de
- Fix debug package build.
* Wed Jan  9 2008 oneukum@suse.de
- Update config files. CONFIG_USB_SUSPEND default
* Wed Jan  9 2008 schwab@suse.de
- Update kdb patches.
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Another try...
* Wed Jan  9 2008 jeffm@suse.de
- Update config files: Enabled CONFIG_SCSI_SAS_ATA. (346990)
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Fix CONFIG_FRAME_POINTER build.
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: DWARF2 EH-frame based stack
  unwinding.
- patches.xen/xen3-stack-unwind: DWARF2 EH-frame based stack
  unwinding.
- Update config files.
* Tue Jan  8 2008 jeffm@suse.de
- patches.fixes/seccomp-disable-tsc-option: Fixed so it only applies
  to i386, and updated config files.
* Tue Jan  8 2008 jeffm@suse.de
- patches.fixes/seccomp-disable-tsc-option: [PATCH] seccomp:
  make tsc disabling optional (191123).
* Tue Jan  8 2008 olh@suse.de
- add patches.arch/ppc-efika-ethernet-phy.patch
  drop patches.arch/ppc-efika-bestcomm-ethernet.patch
  provide phy-handle property for fec_mpc52xx (347234)
* Tue Jan  8 2008 teheo@suse.de
- patches.drivers/libata-force-cable-type: libata: implement
  libata.force_cbl parameter (337610).
* Mon Jan  7 2008 jeffm@suse.de
- Update to 2.6.24-rc7.
* Mon Jan  7 2008 teheo@suse.de
- patches.drivers/libata-sata_nv-disable-ADMA: sata_nv: disable
  ADMA by default (346508).
* Mon Jan  7 2008 teheo@suse.de
  Bug 347708.  port_info for vmw was being assigned to the wrong index.
- patches.drivers/libata-ata_piix-vmw-ign-DMA-err: ata_piix:
  ignore ATA_DMA_ERR on vmware ich4 (258256).
* Mon Jan  7 2008 teheo@suse.de
  As the rest of kernel has caught up now, this one is no longer
  necessary.
- patches.drivers/libata-fix-up-build-after-upstream-update.patch:
  Delete.
* Mon Jan  7 2008 teheo@suse.de
- patches.drivers/libata-fix-up-build-after-upstream-update.patch:
  Delete.
- patches.drivers/libata-ata_piix-vmw-ign-DMA-err: ata_piix:
  ignore ATA_DMA_ERR on vmware ich4 (258256).
* Fri Jan  4 2008 jeffm@suse.de
- Update config files for -vanilla.
* Fri Jan  4 2008 jeffm@suse.de
- patches.rt/timer-freq-tweaks.patch: Adjusted context.
* Fri Jan  4 2008 jeffm@suse.de
- Update config files.
* Fri Jan  4 2008 jeffm@suse.de
- Update to 2.6.24-rc6-git11.
* Wed Jan  2 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Copy debug sources to a proper location.
* Tue Jan  1 2008 jeffm@suse.de
- Update to 2.6.24-rc6-git7.
* Tue Jan  1 2008 jeffm@suse.de
- scripts/run_oldconfig.sh: Removed RT symbol from EXTRA_SYMBOLS.
  We add it manually when building the patch list. This allows
  the script to work with the RT kernel without having to remove
  all the other configs from config.conf first.
